(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1089038,      36050]*)
(*NotebookOutlinePosition[   1089985,      36082]*)
(*  CellTagsIndexPosition[   1089941,      36078]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["Gears & Chains"], "Title",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Example Mechanism for ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " 2D Gear Constraints"
}], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["by Robert Beretta"], "Subsubtitle",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.25 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .39286 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 .28571 m
.14286 .28571 L
.14286 .39286 L
s
.22857 .275 m
.25 .28571 L
.22857 .29643 L
s
.13214 .37143 m
.14286 .39286 L
.15357 .37143 L
s
gsave
.25 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .39286 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 .28571 m
.14286 .28571 L
.14286 .39286 L
s
.22857 .275 m
.25 .28571 L
.22857 .29643 L
s
.13214 .37143 m
.14286 .39286 L
.15357 .37143 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.86615 .71429 m
.86615 .77143 L
.58043 .77143 L
.58043 .71429 L
F
0 g
.01 w
.42857 .5 m
.70529 .42886 L
s
.02 w
.42857 .5 Mdot
.70529 .42886 Mdot
gsave
.53571 .42857 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .53571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.53571 .42857 m
.42857 .42857 L
.42857 .53571 L
s
.51429 .41786 m
.53571 .42857 L
.51429 .43929 L
s
.41786 .51429 m
.42857 .53571 L
.43929 .51429 L
s
gsave
.83043 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.72329 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.72329 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.83043 .71429 m
.72329 .71429 L
.72329 .82143 L
s
.80901 .70357 m
.83043 .71429 L
.80901 .725 L
s
.71258 .8 m
.72329 .82143 L
.73401 .8 L
s
gsave
.82122 .56468 -59.817 -4.15848 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.72104 .67836 -59.817 -4.15848 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -59.817 -4.15848 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82122 .56468 m
.71429 .57143 L
.72104 .67836 L
s
.79915 .55534 m
.82122 .56468 L
.8005 .57672 L
s
.70899 .65765 m
.72104 .67836 L
.73038 .6563 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol06goo00=l07ooOol01Goo00<007ooOol0
1Goo00<07gooOol08Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03
Ool00`00Oomoo`0DOol00g`0Oomoo`0LOol00g`0Oomoo`05Ool20005Ool00`0OOomoo`0POolF01lS
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01o
ogoo01aoo`03O01oogoo00Moo`8000=oo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001o
ogoo005oo`0027oo00<007oo000017oo0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0
Igoo0`000goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0<Ool00`00Oomoo`0=
Ool00g`0Oomoo`08Ool20002Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1Y
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo00aoo`04001o
ogooOol30009Ool00g`0Oomoo`06Ool20004Ool01@0O000007oo00007Woo2`0O00<0000O01l02@0O
8Woo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00g`0
Oomoo`0<Ool01000Oomoogoo0P002Goo00=l07ooOol01Goo0P001Woo00@07gooOol001moo`/07`03
00007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol057oo00=l07oo
Ool037oo00<007ooOol00goo00<007ooOol01Woo00=l07ooOol03Goo00D07goo001oo`0001ioo`/0
7`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l
07ooOol02goo00<007ooOol00goo00<007ooOol01Goo00=l07ooOol03Woo00<07gooOol08Goo2P0O
00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0
Oomoo`0;Ool01000Oomoogoo0`001goo00=l07ooOol03Woo00<07gooOol08Goo2P0O00<0000O01l0
200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0;Ool0
0`00Oomoo`0;Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROol901l00`0001l07`0701lTOol00`0OOomo
o`1YOol00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo00Yoo`03001oogoo00Yoo`03O01oogoo
00moo`0301moogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<0
07ooOol05goo00=l07ooOol02Goo00<007ooOol02Woo00=l07ooOol047oo00<07gooOol08goo1`0O
00<0000O01l01@0O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0
Oomoo`09Ool00`00Oomoo`09Ool00g`0Oomoo`0AOol00`0OOomoo`0SOol701l00`0001l07`0301lW
Ool00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03O01oogoo00Qoo`03001o
ogoo00Qoo`03O01oogoo019oo`0301moogoo02Eoo`D07`0400007`0O01lYOol00`0OOomoo`1ZOol0
0`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo00Moo`03001oogoo00Moo`03O01oogoo
01=oo`0301moogoo02Moo`<07`0300007goo02Yoo`0301moogoo06Yoo`03001oogoo005oo`003goo
00<007ooOol06Woo0W`01goo00<007ooOol01Woo00=l07ooOol057oo00<07gooOol097oo3@?P9Goo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0LOol3O004Ool00`00Oomoo`04Ool2
O00HOol00`0OOomoo`0NOolE0n0ROol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo
01moo`=l0004Ool007ooOol4O00JOol00`0OOomoo`0LOolI0n0OOol00`0OOomoo`1/Ool00`00Oomo
o`01Ool000moo`80029oo`9l0003001l07`001moo`0301moogoo01Yooad3h1aoo`0301moogoo06Yo
o`<000=oo`003goo00<007ooOol08goo00<007`0Ool07goo00<07gooOol067oo80?P6Woo00<07goo
Ool0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol00`00Ooml0002O00NOol00`0OOomoo`0F
OolR0n0IOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02=oo`03001oogoo009o
o`9l01aoo`0301moogoo01Eoob@3h1Moo`0301moogoo06ioo`03001oogoo005oo`003goo00<007oo
Ool08goo00<007ooOol017oo0W`06Woo00<07gooOol04goo9`?P5Woo00<07gooOol0KWoo00<007oo
Ool00Goo000?Ool00`00Oomoo`0SOol00`00Oomoo`06Ool2O00IOol00`0OOomoo`0BOolY0n0COol0
0`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02=oo`03001oogoo00Qoo`=l01Moo`03
01moogoo015oobX3h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P008Goo00@007ooOol0
009oo`03001oogoo00Qoo`9l01Eoo`0301moogoo011oob/3h15oo`0301moogoo06ioo`<000=oo`00
3goo00<007ooOol087oo00H007ooOol007oo000=Ool2O00DOol00`0OOomoo`0>Ool/0n0AOol00`0O
Oomoo`1`Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`05001oo`00Ool0000?Ool2O00BOol0
0`0OOomoo`0=Ool^0n0?Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo025oo`04
001oo`00000BOol3O00@Ool00`0OOomoo`0<Ool_0n0>Ool00`0OOomoo`1aOol00`00Oomoo`01Ool0
00moo`03001oogoo029oo`<001Eoo`9l00ioo`0301moogoo00]ooc43h0aoo`0301moogoo079oo`03
001oogoo005oo`003goo00<007ooOol08Woo0P0067oo0W`03Goo00<07gooOol02Woo<@?P37oo00<0
7gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol01000Oomoogoo0P005Goo0W`037oo
00<07gooOol02Goo<P?P2Woo00<07gooOol0Lgoo00<007ooOol00Goo000?Ool00`00Oomoo`0XOol0
0`00Oomoo`0EOol2O00;Ool00`0OOomoo`07Oolc0n09Ool00`0OOomoo`1dOol00`00Oomoo`01Ool0
00moo`8002Uoo`03001oogoo01Moo`=l00Qoo`0301moogoo00Mooc<3h0Qoo`0301moogoo07=oo`<0
00=oo`003goo00<007ooOol09goo00<007oo00006goo0W`01goo00<07gooOol01Goo=0?P27oo00<0
7gooOol0MGoo00<007ooOol00Goo000?Ool00`00Oomoo`0WOol01000Ool0000077oo0W`01Woo0P0O
1Goo=0?P1Woo0P0ON7oo00<007ooOol00Goo000?Ool00`00Oomoo`19Ool2O006Ool00`0OOomoo`02
Oole0n04Ool00`0OOomoo`1hOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`=l00Aoo`0301mo
ogoo03H3h0=oo`0301moogoo07Uoo`03001oogoo005oo`003goo00<007ooOol0CWoo0W`00goo00<0
7goo0n00<@?P00@000?P0n03h09oo`0301moogoo07Yoo`03001oogoo005oo`001goo1@000goo00<0
07ooOol0D7oo0W`00Woo00<07`?P0n00<@?P0P0000<3h7oo01l0OGoo00<007ooOol00Goo0009Ool0
0`00Oomoo`03Ool00`00Oomoo`1BOol2O0000goo0n03h00c0n02000]Ool2001?Ool00`00Oomoo`01
Ool000Uoo`03001oogoo00=oo`<005Aoo`03O003h0?P01T3h1h002Uoo`D004aoo`<000=oo`002Goo
00<007ooOol00goo00<007ooOol0EGoo6`?P00<000?P0n0060?P0P009Woo2@002G`OAGoo00<007oo
Ool00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolK0n000`000n03h0020n02000B0n020005
Ool200000goo001oo`0JOol80002O1l2000>O1m1Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001o
ogoo05Eooa/3h0040003h0?P0n03000@0n0200020n07Ool00`00Oomoo`0FOol8000JO1lmOol00`00
Oomoo`01Ool000moo`03001oogoo05Eooa/3h0070003h0?P0n0000?P000050?P1Woo00<007oo0000
4goo20007g`O?7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOolJ0n000`000n03h0020n000`00
0n03h00B0n0IOol8000UO1ljOol00`00Oomoo`01Ool000moo`03001oogoo05IooaX3h0030003h0?P
0083h0030003h0?P0183h1Eoo`P00003Ooml7g`O02Ql7cQoo`03001oogoo005oo`003goo0P00F7oo
6@?P00<000?P0n005`?P4Goo20000goo;G`O=Goo0`000goo000?Ool00`00Oomoo`1GOolI0n000`00
0n03h00G0n0=Ool80006Ool`O1leOol00`00Oomoo`01Ool000moo`03001oogoo05MooaT3h0030003
h0?P01L3h0Yoo`L000Qooc=l7cAoo`03001oogoo005oo`003goo00<007ooOol0F7oo60?P00<000?P
0n005P?P1goo1`0037oo=7`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`1HOolH0n000`000n03
h00F0n03Ool8000>OolfO1lbOol00`00Oomoo`01Ool000moo`03001oogoo05UooaL3h0030003h0?P
01D3h0P0015oocQl7c5oo`03001oogoo005oo`003goo00<007ooOol0FGoo5`?P00<000?P0n004@?P
200057oo>W`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`1IOolG0n000`000n03h00=0n08000G
OollO1l_Ool00`00Oomoo`01Ool000moo`8005]ooaH3h0030003h0?P00T3h0P00083h1Qoocel7beo
o`<000=oo`003goo00<007ooOol0Fgoo5@?P00<000?P0n001@?P20001P?P5goo?g`O;Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`1LOolD0n0010000n03h0?P20002@?P67oo?g`O;Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`1LOolC0n09000<0n0HOom2O1l/Ool00`00Oomoo`01Ool000moo`03001o
ogoo05eooa43h0H000l3h1Uood9l7baoo`03001oogoo005oo`003goo00<007ooOol0GWoo40?P1000
40?P6Goo@g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOol@0n02000@0n0IOom5O1l[Ool0
0`00Oomoo`01Ool000moo`03001oogoo061ooa03h0030003h0?P00`3h1]oodIl7bYoo`03001oogoo
005oo`003goo0P00I7oo2P?P00@000?P0n000083h0030003h0?P00P3h1]oodMl7bQoo`<000=oo`00
3goo00<007ooOol0IGoo20?P00H000?P0n0000?P00090n0MOom8O1lYOol00`00Oomoo`01Ool000mo
o`03001oogoo06Moo`L3h0050003h0000n0000070n0OOom8O1lYOol00`00Oomoo`01Ool000moo`03
001oogoo06Yoo`@3h0040003h00000050n0ROom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo
06moo`<002IoodUl7bUoo`03001oogoo005oo`003goo00<007ooOol0Kgoo0P000goo0P008WooBW`O
:7oo00<007ooOol00Goo000?Ool00`00Oomoo`1`Ool00`00Oomoo`02Ool00`00Oomoo`0POom:O1lX
Ool00`00Oomoo`01Ool000moo`8007Ioo`03001oogoo021oodYl7bIoo`<000=oo`003goo00<007oo
Ool0M7oo00<007oo000087ooBg`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`1dOol01000Ool0
00007gooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool0
00moo`03001oogoo09Moocel7`8000el7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo?g`O
0P002g`O9goo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOolmO1l70009O1lWOol00`00
Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo09Ioobml7`h000El7`03001l7g`O00Ql7bMo
o`03001oogoo005oo`002Goo00<007ooOol00goo0`00UWoo9g`O20004G`O0P001G`O0P0000Al7`00
O1ml7bEoo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0UWoo9g`O00<007`OO1l05G`O00<0
07`OO1l01g`O00@007`OO1ml7bMoo`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol0
UWoo9g`O00@007`OO1ml7`<0011l7`03001l7g`O00Ml7`03001l7`00009l7bMoo`03001oogoo005o
o`002Goo00<007ooOol00goo00<007ooOol0Ugoo9W`O00<007`OO1l00g`O00<007`OO1l07G`O9goo
00<007ooOol00Goo000?Ool00`00Oomoo`2GOolVO1l00`00O1ml7`03O1l00`00O1ml7`0MO1lWOol0
0`00Oomoo`01Ool000moo`03001oogoo09MoobIl7`04001l7g`OO1l2000PO1lWOol00`00Oomoo`01
Ool000moo`03001oogoo09MoobIl7`04001l7g`OO1l3000OO1lWOol00`00Oomoo`01Ool000moo`03
001oogoo09MoobIl7`03001l7g`O02=l7bMoo`03001oogoo005oo`003goo0P00V7oo9g`O00<007`O
O1l08G`O9Woo0`000goo000?Ool00`00Oomoo`2HOolVO1l00`00O1ml7`0QO1lXOol00`00Oomoo`01
Ool000moo`03001oogoo09QoobIl7`03001l7g`O025l7bQoo`03001oogoo005oo`003goo00<007oo
Ool0V7oo9W`O00<007`OO1l087`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolUO1l00`00
O1ml7`0PO1lYOol00`00Oomoo`01Ool000moo`03001oogoo09UoobEl7`03001l7g`O021l7bUoo`03
001oogoo005oo`003goo00<007ooOol0VGoo9G`O00<007`OO1l087`O:Goo00<007ooOol00Goo000?
Ool2002JOolUO1l00`00O1ml7`0OO1lXOol30003Ool000moo`03001oogoo09YoobAl7`03001l7g`O
01ml7bYoo`03001oogoo005oo`003goo00<007ooOol0VWoo97`O00<007`OO1l07W`O:goo00<007oo
Ool00Goo000?Ool00`00Oomoo`2KOolSO1l00`00O1ml7`0MO1l/Ool00`00Oomoo`01Ool000moo`03
001oogoo09aoob9l7`03001l7g`O01el7baoo`03001oogoo005oo`003goo00<007ooOol0W7oo8W`O
00<007`OO1l077`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolQO1l00`00O1ml7`0LO1l]
Ool00`00Oomoo`01Ool000moo`03001oogoo09eoob9l7`03001l7g`O01Yl7bioo`03001oogoo005o
o`003goo0P00Wgoo7G`O00L007`OO1ml7`00O1l0000IO1l]Ool30003Ool000moo`03001oogoo09mo
oael7`06001l7g`O001l7`006G`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2POolLO1l00`00
O1ml7`02000IO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo0:5ooaal7`04001l7`00000IO1l`
Ool00`00Oomoo`01Ool000moo`03001oogoo0:9ooaal7`<001Ql7c5oo`03001oogoo005oo`003goo
00<007ooOol0Xgoo6g`O0P0067`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2SOolLO1l01000
O1ml7g`O0P004W`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOolOO1l00`00O1ml7`0>O1le
Ool00`00Oomoo`01Ool000moo`800:Mooail7`03001l7g`O00al7cEoo`<000=oo`003goo00<007oo
Ool0Z7oo6g`O00<007`O000037`O>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOolIO1l01000
O1l000002G`O>Woo00<007ooOol00Goo000?Ool00`00Oomoo`2[OolSO1llOol00`00Oomoo`01Ool0
00moo`03001oogoo0:eoob1l7ceoo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0[goo77`O
2goo0P00<Woo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2bOolEO1lAOol3000_
Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<0071ood@000]l7d`000=oo`002Woo00<007oo
Ool00Woo00<007ooOol0VGoo9P?o00<000?o0ol060?o0P002P?o97oo00<007ooOol00Goo0008Ool0
0`00Ool00004Ool00`00Oomoo`2IOolV0ol010000ol3o`?o0`004P?o0P001@?o0P0000<3o`000ol0
0P?o97oo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2IOolV0ol01`000ol3o`?o
0003o`000103o`8000T3o`030003o`?o0083obAoo`03001oogoo005oo`003goo00<007ooOol0VGoo
9P?o00@000?o0ol3o`<001X3o`030003o`0000<3obAoo`03001oogoo005oo`003goo00<007ooOol0
VGoo9P?o00D000?o0ol3o`000283obAoo`03001oogoo005oo`003goo00<007ooOol0VGoo9P?o00<0
00?o0ol00P?o0P0080?o97oo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolV0ol00`000ol3o`0T
0olTOol00`00Oomoo`01Ool000moo`8009YoobH3o`030003o`?o02@3ob9oo`<000=oo`003goo00<0
07ooOol0VGoo9P?o00<000?o0ol090?o97oo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolV0ol0
0`000ol3o`0T0olTOol00`00Oomoo`01Ool000moo`03001oogoo09UoobH3o`030003o`?o02@3obAo
o`03001oogoo005oo`003goo00<007ooOol0VGoo9P?o00<000?o0ol090?o97oo00<007ooOol00Goo
000?Ool00`00Oomoo`2IOolV0ol00`000ol3o`0T0olTOol00`00Oomoo`01Ool000moo`03001oogoo
09UoobH3o`030003o`?o02@3obAoo`03001oogoo005oo`003goo00<007ooOol0VGoo9P?o00<000?o
0ol090?o97oo00<007ooOol00Goo000?Ool2002JOolV0ol00`000ol3o`0T0olROol30003Ool000mo
o`03001oogoo0;moo`03001oogoo04Qoo`03001oogoo005oo`003goo00<007ooOol0_goo00<007oo
Ool0B7oo00<007ooOol00Goo000?Ool00`00Oomoo`2oOol00`00Oomoo`18Ool00`00Oomoo`01Ool0
00moo`03001oogoo0;moo`03001oogoo04Qoo`03001oogoo005oo`003goo00<007ooOol0_goo00<0
07ooOol0B7oo00<007ooOol00Goo000?Ool00`00Oomoo`2oOol00`00Oomoo`18Ool00`00Oomoo`01
Ool000moo`03001oogoo0;moo`03001oogoo04Qoo`03001oogoo005oo`003goo0P00_Goo00@007oo
Ool0009oo`03001oogoo04=oo`<000=oo`003goo00<007ooOol0_Goo00D007oo001oo`0004Qoo`03
001oogoo005oo`003goo00<007ooOol0_Goo00D007oo001oo`0004Qoo`03001oogoo005oo`003goo
00<007ooOol0_Woo0`00BGoo00<007ooOol00Goo000?Ool00`00Oomoo`2nOol30019Ool00`00Oomo
o`01Ool000moo`03001oogoo0;moo`04001oogooOol20015Ool00`00Oomoo`01Ool000moo`03001o
ogoo0<Aoo`03001oogoo04=oo`03001oogoo005oo`003goo0P00aGoo00<007ooOol0@Goo0`000goo
000?Ool00`00Oomoo`33Ool00`00Ool00014Ool00`00Oomoo`01Ool000moo`03001oogoo0<=oo`04
001oo`000013Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00Uoo`<000=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0008Ool40003Ool3003oOol9Ool30003Ool000Qoo`03001oo`00
00Aoo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo0P0017oo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03
001oo`0000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo005oo`002Woo00<007ooOol00Wooo`003`000goo0008Ool2003oOolG
Ool000Qoo`03001oogoo0?mooaIoo`0027oo0`00ogoo5Woo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.21599 .36402 -63.1448 -3.72795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.06455 .35884 -63.1448 -3.72795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -63.1448 -3.72795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.21599 .36402 m
.14286 .28571 L
.06455 .35884 L
s
.20919 .34104 m
.21599 .36402 L
.19353 .35567 L
s
.0729 .33639 m
.06455 .35884 L
.08753 .35205 L
s
gsave
.21599 .36402 -63.1448 -3.72795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.06455 .35884 -63.1448 -3.72795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -63.1448 -3.72795 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.21599 .36402 m
.14286 .28571 L
.06455 .35884 L
s
.20919 .34104 m
.21599 .36402 L
.19353 .35567 L
s
.0729 .33639 m
.06455 .35884 L
.08753 .35205 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.85775 .71429 m
.85775 .77143 L
.57203 .77143 L
.57203 .71429 L
F
0 g
.01 w
.43692 .49951 m
.71368 .42857 L
s
.02 w
.43692 .49951 Mdot
.71368 .42857 Mdot
gsave
.53498 .41606 -59.6701 -4.21129 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.44109 .53498 -59.6701 -4.21129 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.6701 -4.21129 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.53498 .41606 m
.42857 .42857 L
.44109 .53498 L
s
.51245 .40792 m
.53498 .41606 L
.51495 .4292 L
s
.42794 .51495 m
.44109 .53498 L
.44922 .51245 L
s
gsave
.82203 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71489 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71489 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82203 .71429 m
.71489 .71429 L
.71489 .82143 L
s
.8006 .70357 m
.82203 .71429 L
.8006 .725 L
s
.70417 .8 m
.71489 .82143 L
.7256 .8 L
s
gsave
.82143 .57098 -59.9874 -4.10381 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71474 .67857 -59.9874 -4.10381 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -59.9874 -4.10381 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82143 .57098 m
.71429 .57143 L
.71474 .67857 L
s
.79995 .56035 m
.82143 .57098 L
.80004 .58178 L
s
.70393 .65719 m
.71474 .67857 L
.72536 .6571 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol06goo00=l07ooOol03Goo00<07gooOol0
8Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool00g`0Oomoo`0LOol00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo01aoo`03O01oogoo00ao
o`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo
0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool00004
Ool00`00Oomoo`0DOol00g`0Oomoo`0;Ool00`00Ool0000>Ool00g`0Oomoo`0<Ool00`0OOomoo`0P
Ool;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Ao
o`03001oogoo01Aoo`03O01oogoo00Yoo`05001oogooOol0000=Ool00g`0Oomoo`0<Ool00`0OOomo
o`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo
00=oo`03001oogoo01Aoo`03O01oogoo00Uoo`04001oogooOol3000;Ool00g`0Oomoo`0=Ool00`0O
Oomoo`0POol;01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001o
ogoo01Aoo`03O01oogoo00Qoo`03001oogoo009oo`800003Ool007oo00Uoo`03O01oogoo00eoo`03
01moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<0
07ooOol05Goo00=l07ooOol01Woo00<007ooOol01Goo00<007oo000027oo00=l07ooOol03Woo00<0
7gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00
Oomoo`0EOol00g`0Oomoo`05Ool00`00Oomoo`06Ool01000Oomoo`001goo00=l07ooOol03Woo00<0
7gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00
Oomoo`0EOol00g`0Oomoo`04Ool00`00Oomoo`05Ool30003Ool00`00Oomoo`04Ool00g`0Oomoo`0>
Ool00`0OOomoo`0ROol901l00`0001l07`0701lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000mo
o`8001Moo`03O01oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03O01oogoo00moo`0301mo
ogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<007ooOol05goo
00Al07ooOol0015oo`05001oogooOoml000BOol00`0OOomoo`0SOol701l00`0001l07`0501lUOol0
0`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Moo`03O000000001=oo`03001oog`0
01=oo`0301moogoo02=oo`L07`0300007`0O00<07bMoo`0301moogoo06Yoo`03001oogoo005oo`00
3goo00<007ooOol05goo00<007`0Ool04goo00<007`0Ool04goo00<07gooOol09Goo1@0O00@0000O
01l07bUoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol05Woo00@007ooOoml01=o
o`03O00007oo01=oo`0301moogoo02Moo`<07`0300007goo02Yoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05Goo00<007ooOol00Woo0W`047oo00Al07ooOol001=oo`0301moogoo
02Aoo`d3h2Eoo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol047oo00D007ooOomo
o`0000Moo`=l00]oo`9l00Aoo`03001oogoo015oo`0301moogoo01iooaD3h29oo`0301moogoo06]o
o`03001oogoo005oo`003goo00<007ooOol047oo00@007ooOol000]oo`=l00Aoo`Al00Moo`05001o
ogooOol0000>Ool00`0OOomoo`0LOolI0n0OOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`80
011oo`04001oogoo000>Ool5O00<Ool01000Oomoo`003goo00<07gooOol06Woo7@?P77oo00<07goo
Ool0JWoo0`000goo000?Ool00`00Oomoo`0?Ool00`00Ool0000AOol2O00>Ool01000Oomoo`003Woo
00<07gooOol067oo80?P6Woo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0?Ool2
0002Ool2000@Ool3O00<Ool00`00Ool0000?Ool00`0OOomoo`0FOolR0n0IOol00`0OOomoo`1]Ool0
0`00Oomoo`01Ool000moo`03001oogoo00ioo`D001Eoo`9l00Moo`80009oo`8000moo`0301moogoo
01Eoob@3h1Moo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol03Woo0`006Goo0W`0
1goo1@003Woo00<07gooOol04goo9`?P5Woo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00
Oomoo`0@Ool00`00Oomoo`0IOol2O008Ool2000?Ool00`0OOomoo`0BOolY0n0COol00`0OOomoo`1_
Ool00`00Oomoo`01Ool000moo`03001oogoo011oo`03001oogoo01]oo`=l01Moo`0301moogoo015o
obX3h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P0047oo00<007oo00007goo0W`05Goo
00<07gooOol047oo:`?P4Goo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0?Ool01000Ool0
000087oo0W`00Woo0P0000=oo`00Ool03Goo00<07gooOol03Woo;0?P4Goo00<07gooOol0L7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`0eOol2O002Ool00`00Oomoo`0=Ool00`0OOomoo`0=Ool^0n0?
Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Moo`04O00007`0000?Ool00`0O
Oomoo`0<Ool_0n0>Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Yoo`9l00io
o`0301moogoo00]ooc43h0aoo`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol0?7oo
0W`03Goo00<07gooOol02Woo<@?P37oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomo
o`0nOol2O00<Ool00`0OOomoo`09Oolb0n0:Ool00`0OOomoo`1cOol00`00Oomoo`01Ool000moo`03
001oogoo041oo`9l00]oo`0301moogoo00Mooc<3h0Uoo`0301moogoo07Aoo`03001oogoo005oo`00
3goo0P00@goo0g`027oo00<07gooOol01goo<`?P27oo00<07gooOol0Lgoo0`000goo000?Ool00`00
Oomoo`15Ool2O007Ool00`0OOomoo`05Oold0n08Ool00`0OOomoo`1eOol00`00Oomoo`01Ool000mo
o`03001oogoo04Moo`9l00Ioo`807`Eooc43h08000030n1oogoo00Aoo`807gQoo`03001oogoo005o
o`003goo00<007ooOol0BGoo0W`01Woo00<07gooOol00Woo<`?P0`000goo00<07gooOol0N7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`1;Ool3O004Ool00`0OOomoo`0e0n0400000`0OOomoo`1iOol0
0`00Oomoo`01Ool000moo`03001oogoo04ioo`9l00=oo`0301moo`?P02d3h0L000040n00000001ml
Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo051oo`9l009oo`0301l3h0?P02@3h0P000L3
h003001oo`0O00=oo`800003Ool007oo07Eoo`03001oogoo005oo`002Goo00<007ooOol00goo00<0
07ooOol0DWoo0W`000=oo`?P0n007@?P1`003@?P0P0000<3h00OOol01Goo00<007ooOol09Woo0P00
CGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001DOol00g`00n03h00I0n04000C0n001000
0n03h0?P1Woo00<007oo00009Woo1000BWoo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1E
OolK0n000`000n03h00H0n0YOol2O1l80007O1m5Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=o
o`03001oogoo05Eooa/3h0030003h0?P0083h08001@3h2Ioo`03O1l0000000H00003O1l0000000al
7d5oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0EGoo6`?P00@000?P0n03h0<001@3h29o
o`03O1l0000000H001Ml7ceoo`03001oogoo005oo`003goo00<007ooOol0EGoo6`?P00L000?P0n03
h0000n00000D0n0OOol8000LO1llOol00`00Oomoo`01Ool000moo`03001oogoo05Iooa/3h0050003
h0?P0n00000D0n0LOol8000RO1ljOol00`00Oomoo`01Ool000moo`03001oogoo05Iooa/3h0050003
h0?P0n00000D0n0HOol8000XO1lhOol00`00Oomoo`01Ool000moo`8005QooaX3h0030003h0?P01H3
h1Aoo`P002el7cEoo`<000=oo`003goo00<007ooOol0Egoo6P?P00<000?P0n005P?P47oo20000goo
<7`O=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolJ0n000`000n03h00F0n0<Ool80005Oolc
O1ldOol00`00Oomoo`01Ool000moo`03001oogoo05QooaT3h0030003h0?P01D3h0Uoo`P000UoocAl
7c=oo`03001oogoo005oo`003goo00<007ooOol0F7oo6@?P00<000?P0n005@?P1Goo200037oo=W`O
<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1IOolH0n000`000n03h00E0n000goo00000006000?
OolhO1laOol00`00Oomoo`01Ool000moo`03001oogoo05UooaP3h0030003h0?P0183h0P0019oocYl
7c1oo`03001oogoo005oo`003goo00<007ooOol0FGoo60?P00<000?P0n003P?P20005Goo?7`O;goo
00<007ooOol00Goo000?Ool2001KOolH0n000`000n03h0090n08000HOolmO1l]Ool30003Ool000mo
o`03001oogoo05]ooaL3h0030003h0?P00D3h0P000@3h1Moocml7bioo`03001oogoo005oo`003goo
00<007ooOol0G7oo5P?P00@000?P0n03h0P000L3h1Qoocml7bioo`03001oogoo005oo`003goo00<0
07ooOol0G7oo5@?P2@002P?P67oo@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1MOolC0n06
000=0n0IOom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05iooa83h0@000h3h1Uood=l7bao
o`03001oogoo005oo`003goo00<007ooOol0Ggoo4P?P0P003P?P6GooAG`O:goo00<007ooOol00Goo
000?Ool00`00Oomoo`1POolB0n001@000n03h0?P000020?P6gooAW`O:Woo00<007ooOol00Goo000?
Ool2001TOol=0n000`000n0000020n000`000n03h0060n0KOom7O1lXOol30003Ool000moo`03001o
ogoo06Eoo``3h0050003h0000n0000060n0MOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo
06Moo`X3h0040003h00000050n0OOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo06Yoo`P3
h0<00083h29oodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0Kgoo0`?P0P0097ooBG`O:Goo
00<007ooOol00Goo000?Ool00`00Oomoo`1cOol00`00Oomoo`02Ool2000NOom:O1lXOol00`00Oomo
o`01Ool000moo`03001oogoo07Uoo`03001oogoo01aoodYl7bQoo`03001oogoo005oo`003goo0P00
NWoo00<007ooOol077ooBW`O9Woo0`000goo000?Ool00`00Oomoo`1hOol00`00Ool0000LOom;O1lX
Ool00`00Oomoo`01Ool000moo`03001oogoo07Qoo`04001oo`00000KOom<O1lWOol00`00Oomoo`01
Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo
00<007ooOol00Goo000?Ool00`00Oomoo`2GOolmO1l00`00O1ml7`0<O1lWOol00`00Oomoo`01Ool0
00Qoo`<000Aoo`03001oogoo09Ioocml7`8000al7bMoo`03001oogoo005oo`0027oo00<007ooOol0
17oo00<007ooOol0UWoo@G`O0P002W`O9goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3002F
OolWO1lN0008O1lUOol30003Ool000Uoo`03001oogoo00=oo`03001oogoo09IoobMl7`03001l7g`O
01Ql7`8000Ul7bMoo`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol0UWoo9g`O00@0
07`OO1ml7`<0019l7`8000El7`800004O1l007`OO1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo
00=oo`03001oogoo09MoobIl7`03001l7g`O00=l7`03001l7g`O00il7`8000Ul7`04001l7g`OO1lW
Ool00`00Oomoo`01Ool000moo`03001oogoo09MoobIl7`03001l7g`O00=l7`03001l7g`O01Ql7`03
001l7`00009l7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo9W`O00@007`OO1ml7`80021l
7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo9W`O00@007`OO1ml7`<001ml7bMoo`03001o
ogoo005oo`003goo00<007ooOol0Ugoo9W`O00<007`OO1l08g`O9goo00<007ooOol00Goo000?Ool2
002HOolVO1l00`00O1ml7`0RO1lVOol30003Ool000moo`03001oogoo09QoobEl7`03001l7g`O029l
7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo9G`O00<007`OO1l08W`O:7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`2HOolUO1l00`00O1ml7`0QO1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo09UoobAl7`03001l7g`O025l7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo97`O00<0
07`OO1l08G`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolTO1l00`00O1ml7`0QO1lYOol0
0`00Oomoo`01Ool000moo`8009YoobAl7`03001l7g`O021l7bQoo`<000=oo`003goo00<007ooOol0
VWoo8g`O00<007`OO1l087`O:Woo00<007ooOol00Goo000?Ool00`00Oomoo`2JOolSO1l00`00O1ml
7`0OO1l[Ool00`00Oomoo`01Ool000moo`03001oogoo09]oob9l7`03001l7g`O01il7baoo`03001o
ogoo005oo`003goo00<007ooOol0W7oo8G`O00<007`OO1l07W`O;7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`2LOolQO1l00`00O1ml7`0MO1l]Ool00`00Oomoo`01Ool000moo`03001oogoo09eoob1l
7`03001l7g`O01el7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo87`O00<007`OO1l077`O
;Woo00<007ooOol00Goo000?Ool2002OOolLO1l01000O1ml7`000W`O00<007`OO1l067`O;Goo0`00
0goo000?Ool00`00Oomoo`2OOolKO1l01P00O1ml7`00O1l001]l7bmoo`03001oogoo005oo`003goo
00<007ooOol0X7oo6g`O00D007`O001l7`0001Yl7c1oo`03001oogoo005oo`003goo00<007ooOol0
XGoo6W`O00@007`O000001]l7c1oo`03001oogoo005oo`003goo00<007ooOol0XWoo6W`O0`006W`O
<Goo00<007ooOol00Goo000?Ool00`00Oomoo`2SOolIO1l2000JO1lbOol00`00Oomoo`01Ool000mo
o`03001oogoo0:=ooaYl7`04001l7g`OO1l2000DO1lcOol00`00Oomoo`01Ool000moo`03001oogoo
0:Eooael7`03001l7g`O011l7cEoo`03001oogoo005oo`003goo0P00Ygoo77`O00<007`OO1l03W`O
=Goo0`000goo000?Ool00`00Oomoo`2XOolIO1l00`00O1l0000>O1lhOol00`00Oomoo`01Ool000mo
o`03001oogoo0:YooaMl7`04001l7`00000;O1ljOol00`00Oomoo`01Ool000moo`03001oogoo0:]o
ob=l7caoo`03001oogoo005oo`003goo00<007ooOol0[Goo87`O?Goo00<007ooOol00Goo0008Ool2
0005Ool00`00Oomoo`2_OolLO1l9Ool2000dOol00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03
001oogoo0;9ooaEl7`moo`<0035oo`03001oogoo005oo`002Goo00<007ooOol00goo0`00L7ooA000
2G`OCP000goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2GOolV0ol00`000ol3o`0H0ol200090olW
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo09MoobH3o`040003o`?o0ol3000B
0ol200050ol2000010?o0003o`?o9goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`2GOolV0ol01`000ol3o`?o0003o`000103o`8000T3o`040003o`?o0olWOol00`00Oomoo`01Ool0
00moo`03001oogoo09MoobH3o`040003o`?o0ol3000J0ol00`000ol000020olWOol00`00Oomoo`01
Ool000moo`03001oogoo09MoobH3o`050003o`?o0ol0000Q0olWOol00`00Oomoo`01Ool000moo`03
001oogoo09MoobH3o`030003o`?o0083o`8001l3obMoo`03001oogoo005oo`003goo00<007ooOol0
Ugoo9P?o00<000?o0ol08`?o9goo00<007ooOol00Goo000?Ool2002HOolV0ol00`000ol3o`0S0olU
Ool30003Ool000moo`03001oogoo09MoobH3o`030003o`?o02<3obMoo`03001oogoo005oo`003goo
00<007ooOol0Ugoo9P?o00<000?o0ol08`?o9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolV
0ol00`000ol3o`0S0olWOol00`00Oomoo`01Ool000moo`03001oogoo09MoobH3o`030003o`?o02<3
obMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo9P?o00<000?o0ol08`?o9goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2GOolV0ol00`000ol3o`0S0olWOol00`00Oomoo`01Ool000moo`03001o
ogoo09MoobH3o`030003o`?o02<3obMoo`03001oogoo005oo`003goo0P00V7oo9P?o00<000?o0ol0
8`?o9Goo0`000goo000?Ool00`00Oomoo`2mOol00`00Oomoo`1:Ool00`00Oomoo`01Ool000moo`03
001oogoo0;eoo`03001oogoo04Yoo`03001oogoo005oo`003goo00<007ooOol0_Goo00<007ooOol0
BWoo00<007ooOol00Goo000?Ool00`00Oomoo`2mOol00`00Oomoo`1:Ool00`00Oomoo`01Ool000mo
o`03001oogoo0;eoo`03001oogoo04Yoo`03001oogoo005oo`003goo00<007ooOol0_Goo00<007oo
Ool0BWoo00<007ooOol00Goo000?Ool00`00Oomoo`2mOol00`00Oomoo`1:Ool00`00Oomoo`01Ool0
00moo`800;]oo`04001oogoo0002Ool00`00Oomoo`15Ool30003Ool000moo`03001oogoo0;]oo`05
001oo`00Ool0001:Ool00`00Oomoo`01Ool000moo`03001oogoo0;]oo`05001oo`00Ool0001:Ool0
0`00Oomoo`01Ool000moo`03001oogoo0;aoo`<004]oo`03001oogoo005oo`003goo00<007ooOol0
_7oo0`00Bgoo00<007ooOol00Goo000?Ool00`00Oomoo`2mOol01000Oomoogoo0P00Agoo00<007oo
Ool00Goo000?Ool00`00Oomoo`32Ool00`00Oomoo`15Ool00`00Oomoo`01Ool000moo`800<=oo`03
001oogoo04=oo`<000=oo`003goo00<007ooOol0`Goo00<007oo0000AWoo00<007ooOol00Goo000?
Ool00`00Oomoo`31Ool01000Ool00000AGoo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo10000goo0`00ogoo2Goo0`00
0goo0008Ool00`00Ool00004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`8000Aoo`03
001oogoo0?moo`]oo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`80
0?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000l0
00=oo`0027oo0P00ogoo5goo0008Ool00`00Oomoo`3oOolFOol000Qoo`<00?mooaIoo`00ogoo8Goo
003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.13555 .39261 -66.1977 -4.16352 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.03596 .2784 -66.1977 -4.16352 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.1977 -4.16352 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.13555 .39261 m
.14286 .28571 L
.03596 .2784 L
s
.1477 .37196 m
.13555 .39261 L
.12632 .3705 L
s
.05807 .26918 m
.03596 .2784 L
.05661 .29055 L
s
gsave
.13555 .39261 -66.1977 -4.16352 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.03596 .2784 -66.1977 -4.16352 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.1977 -4.16352 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.13555 .39261 m
.14286 .28571 L
.03596 .2784 L
s
.1477 .37196 m
.13555 .39261 L
.12632 .3705 L
s
.05807 .26918 m
.03596 .2784 L
.05661 .29055 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.84909 .71429 m
.84909 .77143 L
.56337 .77143 L
.56337 .71429 L
F
0 g
.01 w
.44514 .49805 m
.72234 .4288 L
s
.02 w
.44514 .49805 Mdot
.72234 .4288 Mdot
gsave
.53279 .40371 -59.3858 -4.33338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.45343 .53279 -59.3858 -4.33338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.3858 -4.33338 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.53279 .40371 m
.42857 .42857 L
.45343 .53279 L
s
.50946 .39826 m
.53279 .40371 L
.51443 .41911 L
s
.43804 .51443 m
.45343 .53279 L
.45888 .50946 L
s
gsave
.81337 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.70623 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.70623 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81337 .71429 m
.70623 .71429 L
.70623 .82143 L
s
.79194 .70357 m
.81337 .71429 L
.79194 .725 L
s
.69551 .8 m
.70623 .82143 L
.71694 .8 L
s
gsave
.82126 .57747 -60.1739 -4.0507 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.70825 .6784 -60.1739 -4.0507 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -60.1739 -4.0507 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82126 .57747 m
.71429 .57143 L
.70825 .6784 L
s
.80047 .56556 m
.82126 .57747 L
.79926 .58696 L
s
.69876 .6564 m
.70825 .6784 L
.72015 .65761 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
00]oo`8000Moo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo
06Uoo`03001oogoo005oo`003goo00<007ooOol02Goo0P002Goo00=l07ooOol06goo00=l07ooOol0
3Goo00<07gooOol08Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool200000goo000000050006Ool00g`0Oomoo`0LOol00g`0Oomoo`0<Ool00`0O
Oomoo`0POolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001o
ogoo00Eoo`04001oogoo0005Ool>000GOol00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0O
Oomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<000Eoo`04001oogooOol20009Ool0
0g`0Oomoo`05OomE000:01lSOol00`0OOomoo`1WOol30003Ool000Qoo`03001oo`0000Aoo`03001o
ogoo00Aoo`03001oo`0000Aoo`03001oogoo00Ioo`03O01oogoo00aoo`03001oogoo00eoo`03O01o
ogoo00aoo`0301moogoo021oo`/07`0300007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo005o
o`0027oo00<007oo000017oo00<007ooOol017oo00@007oo000000Aoo`03001oogoo00Eoo`03O01o
ogoo00Yoo`<000moo`03O01oogoo00aoo`0301moogoo021oo`/07`0300007`0O00T07b9oo`0301mo
ogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol02Woo
0`003Woo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo
00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`0<Ool00`00Oomoo`0<Ool00g`0Oomo
o`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00moo`03001oogoo01Eoo`03O01oogoo00]oo`03001oogoo00]oo`03O01oogoo00ioo`0301moogoo
025oo`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol0
5Goo00=l07ooOol02Goo0`003Goo00=l07ooOol03Woo00<07gooOol08Goo2P0O00<0000O01l0200O
8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0;Ool00`00
Oomoo`0;Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROol901l00`0001l07`0701lTOol00`0OOomoo`1Y
Ool00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo00Uoo`03001oogoo00]oo`03O01oogoo00mo
o`0301moogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<007oo
Ool05goo00=l07ooOol027oo00<007ooOol02goo00=l07ooOol047oo00<07gooOol08goo1`0O00<0
000O01l01@0O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomo
o`08Ool00`00Oomoo`0:Ool00g`0Oomoo`0AOol00`0OOomoo`0SOol701l00`0001l07`0301lWOol0
0`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03O01oogoo00Moo`03001oogoo
00Uoo`03O01oogoo019oo`0301moogoo02Eoo`D07`0400007`0O01lYOol00`0OOomoo`1ZOol00`00
Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo00Ioo`03001oogoo00Qoo`03O01oogoo01=o
o`0301moogoo02Moo`<07`0300007goo02Yoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<0
07ooOol06Woo0W`01Woo00<007ooOol01goo00=l07ooOol057oo00<07gooOol097oo3@?P9Goo00<0
7gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0LOol3O003Ool00`00Oomoo`05Ool2O00H
Ool00`0OOomoo`0NOolE0n0ROol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo01mo
o`=l0004001oogooOol4O00JOol00`0OOomoo`0LOolI0n0OOol00`0OOomoo`1/Ool00`00Oomoo`01
Ool000moo`80029oo`03O00007`0009l01moo`0301moogoo01Yooad3h1aoo`0301moogoo06Yoo`<0
00=oo`003goo00<007ooOol08Woo00<007`0O00087oo00<07gooOol067oo80?P6Woo00<07gooOol0
KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0ROol00`00Oomoo`03O00NOol00`0OOomoo`0FOolR
0n0IOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo029oo`03001oogoo00=oo`9l
01aoo`0301moogoo01Eoob@3h1Moo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol0
8Woo00<007ooOol01Goo0W`06Woo00<07gooOol04goo9`?P5Woo00<07gooOol0KWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0ROol00`00Oomoo`07Ool2O00IOol00`0OOomoo`0BOolY0n0COol00`0O
Oomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`03001oogoo00Yoo`=l01Moo`0301mo
ogoo015oobX3h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P0087oo00<007oo00003goo
0W`05Goo00<07gooOol047oo:`?P4Goo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0OOol0
0`00Ool00003Ool00`00Oomoo`0;Ool2O00DOol00`0OOomoo`0>Ool/0n0AOol00`0OOomoo`1`Ool0
0`00Oomoo`01Ool000moo`03001oogoo021oo`80009oo`03001oogoo00ioo`9l019oo`0301moogoo
00eoobh3h0moo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol087oo0P0000=oo`00
Ool04Woo0g`047oo00<07gooOol037oo;`?P3Woo00<07gooOol0LGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0POol200000goo001oo`0EOol2O00>Ool00`0OOomoo`0;Oola0n0<Ool00`0OOomoo`1b
Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`8001Uoo`9l00eoo`0301moogoo00Yooc43h0ao
o`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol08Goo00<007ooOol06Woo0W`037oo
00<07gooOol02Goo<P?P2Woo00<07gooOol0Lgoo00<007ooOol00Goo000?Ool00`00Oomoo`10Ool2
O00;Ool00`0OOomoo`07Oolc0n09Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`8001moo`80
0003Ool007oo01moo`=l00Qoo`0301moogoo00Moobl3h0<000030n1oogoo00Ioo`0301moogoo07=o
o`<000=oo`003goo00<007ooOol087oo00<007ooOol08Woo0W`01goo00<07gooOol01Goo<`?P1000
1Goo00<07gooOol0MGoo00<007ooOol00Goo000?Ool00`00Oomoo`0OOol00`00Ool0000UOol2O006
Ool201l5Oola0n050004Ool201mhOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l00Ioo`03
01moogoo009oobd3h0@00083h08000Aoo`0501l00000Ool0001fOol00`00Oomoo`01Ool000moo`03
001oogoo04]oo`=l00Aoo`0301moogoo02X3h0@000D3h0030003h0?P00=oo`0501moogooOol0001g
Ool00`00Oomoo`01Ool000moo`03001oogoo04ioo`9l00=oo`0301moo`?P02D3h0@000P3h0040003
h0?P0n02Ool01`0OOomoogoo001oo`0007Ioo`03001oogoo005oo`001goo1@000goo00<007ooOol0
D7oo0W`00Woo00<07`?P0n0080?P100040?P00=oo`0OOol0O7oo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`1BOol2O0000goo0n03h00L0n04000D0n000`0OOomoo`0`Ool2001:Ool0
0`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<005Aoo`03O003h0?P01T3h0<001P3h31oo`H004Mo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0EGoo6`?P00<000?P0n000`?P0P004`?P:Goo
0g`O2P0017`OAGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolK0n000`00
0n03h0020n03000C0n0VOol2O1l80003O1l20009O1m1Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03
001oogoo05Eooa`3h0070003h0?P0n0000?P00004`?P8Woo0W`O20005W`O?Goo00<007ooOol00Goo
000?Ool00`00Oomoo`1EOolL0n000`000n03h0020n000`000n03h00B0n0POol8000KO1llOol00`00
Oomoo`01Ool000moo`03001oogoo05Iooa/3h0030003h0?P0083h0030003h0?P0143h1aoo`T0025l
7cYoo`03001oogoo005oo`003goo00<007ooOol0EWoo6`?P00<000?P0n005P?P67oo2@009g`O>7oo
00<007ooOol00Goo000?Ool2001HOolK0n000`000n03h00E0n0DOol8000]O1leOol30003Ool000mo
o`03001oogoo05Mooa/3h0030003h0?P01D3h11oo`P000=ooc1l7cEoo`03001oogoo005oo`003goo
00<007ooOol0Egoo6`?P00<000?P0n005@?P37oo20001Goo<g`O=7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`1HOolJ0n000`000n03h00D0n09Ool80009OoldO1lcOol00`00Oomoo`01Ool000moo`03
001oogoo05Qooa/3h0030003h0?P01<3h0Eoo`P000aoocIl7c9oo`03001oogoo005oo`003goo00<0
07ooOol0FGoo6P?P00<000?P0n004`?P2@003goo>7`O<Goo00<007ooOol00Goo000?Ool00`00Oomo
o`1IOolJ0n000`000n03h00?0n09000BOoljO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo05Uo
oaX3h0030003h0?P00/3h0P001Ioocal7bmoo`03001oogoo005oo`003goo0P00Fgoo6P?P00<000?P
0n001P?P200000<3h7ooOol05Woo?G`O;Goo0`000goo000?Ool00`00Oomoo`1KOolI0n000`000n03
h0020n0800050n0GOoloO1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aooaP3h0T000P3h1Qo
ocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo5`?P1P002`?P67oo@W`O;7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`1MOolE0n04000=0n0IOom2O1l/Ool00`00Oomoo`01Ool000moo`03
001oogoo05iooa@3h0@000`3h1Uood=l7baoo`03001oogoo005oo`003goo00<007ooOol0Ggoo50?P
0`000P?P00<000?P0n001P?P6GooAG`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`1POolE0n00
10000n03h0001P?P6gooAW`O:Woo00<007ooOol00Goo000?Ool2001TOol@0n001P000n03h0000n00
00D3h1]oodMl7bQoo`<000=oo`003goo00<007ooOol0IGoo3`?P00D000?P0003h00000<3h1eoodQl
7bUoo`03001oogoo005oo`003goo00<007ooOol0Igoo3P?P0`000P?P7gooB7`O:Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`1ZOol;0n03000QOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo
06moo`<3h0Aoo`8000=oo`8001]oodUl7bUoo`03001oogoo005oo`003goo00<007ooOol0Mgoo00<0
07ooOol00Woo00<007ooOol06GooBW`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`1lOol00`00
Oomoo`0IOom:O1lXOol00`00Oomoo`01Ool000moo`8007aoo`03001oo`0001YoodYl7bIoo`<000=o
o`003goo00<007ooOol0Ngoo00@007oo000001Qood]l7bQoo`03001oogoo005oo`003goo00<007oo
Ool0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool0
00moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<0
07ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool000Qoo`03001o
ogoo00Aoo`03001oogoo09Ioocil7`03001l7g`O00al7bMoo`03001oogoo005oo`002Goo00<007oo
Ool00goo0`00UWoo9g`O1`004G`O0P0037`O9Goo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`2FOolWO1l00`00O1ml7`04O1l>0005O1l2000:O1lWOol00`00Oomoo`01Ool000Qoo`03001oo`00
00Aoo`03001oogoo09IoobMl7`04001l7g`OO1l3000>O1l80009O1lWOol00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo09MoobIl7`03001l7g`O00=l7`03001l7g`O011l7`8000]l7bMo
o`03001oogoo005oo`003goo00<007ooOol0Ugoo9W`O00<007`OO1l00g`O00<007`OO1l03W`O0P00
1W`O0P0000=l7`00O1l00W`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolVO1l01000O1ml
7g`O0P006g`O00<007`OO1l00W`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolVO1l01000
O1ml7g`O0`006G`O00<007`O00000g`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolVO1l0
0`00O1ml7`0SO1lWOol00`00Oomoo`01Ool000moo`8009QoobEl7`03001l7g`O02=l7bIoo`<000=o
o`003goo00<007ooOol0V7oo97`O00<007`OO1l08g`O:7oo00<007ooOol00Goo000?Ool00`00Oomo
o`2HOolTO1l00`00O1ml7`0SO1lXOol00`00Oomoo`01Ool000moo`03001oogoo09QoobAl7`03001l
7g`O029l7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo8g`O00<007`OO1l08W`O:Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`2IOolSO1l00`00O1ml7`0RO1lYOol00`00Oomoo`01Ool000mo
o`03001oogoo09Uoob=l7`03001l7g`O029l7bUoo`03001oogoo005oo`003goo0P00VWoo8g`O00<0
07`OO1l08G`O:7oo0`000goo000?Ool00`00Oomoo`2JOolRO1l00`00O1ml7`0QO1lZOol00`00Oomo
o`01Ool000moo`03001oogoo09Yoob9l7`03001l7g`O021l7b]oo`03001oogoo005oo`003goo00<0
07ooOol0Vgoo8G`O00<007`OO1l07g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolPO1l0
0`00O1ml7`0OO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09aoob1l7`03001l7g`O01il7beo
o`03001oogoo005oo`003goo00<007ooOol0WGoo7g`O00<007`OO1l07W`O;Goo00<007ooOol00Goo
000?Ool00`00Oomoo`2MOolNO1l00`00O1ml7`0NO1l^Ool00`00Oomoo`01Ool000moo`8009mooa]l
7`03001l7`00009l7`03001l7g`O01Yl7beoo`<000=oo`003goo00<007ooOol0Wgoo6W`O00D007`O
001l7`0001el7bmoo`03001oogoo005oo`003goo00<007ooOol0X7oo6W`O0P0000=l7`00O1l06g`O
<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2QOolIO1l3000MO1l`Ool00`00Oomoo`01Ool000mo
o`03001oogoo0:9ooaQl7`<001al7c5oo`03001oogoo005oo`003goo00<007ooOol0Xgoo67`O00<0
07`OO1l06W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2SOolHO1l01000O1ml7g`O0P005W`O
<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOolKO1l00`00O1ml7`0BO1leOol00`00Oomoo`01
Ool000moo`800:MooaYl7`03001l7g`O011l7cEoo`<000=oo`003goo00<007ooOol0Z7oo5g`O00<0
07`O000047`O>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOolEO1l01000O1l000003G`O>Woo
00<007ooOol00Goo000?Ool00`00Oomoo`2[OolSO1llOol00`00Oomoo`01Ool000moo`03001oogoo
0:eoob1l7ceoo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0[goo77`O1goo0P00=Woo00<0
07ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2bOolEO1l=Ool2000dOol00`00Oomoo`01
Ool000Uoo`03001oogoo00=oo`<0071ood@000Ml7e0000=oo`002Woo00<007ooOol00Woo00<007oo
Ool0U7oo9`?o00<000?o0ol05`?o0P002P?o:Goo00<007ooOol00Goo0008Ool00`00Ool00004Ool0
0`00Oomoo`2DOolW0ol010000ol3o`?o0`004@?o0P001@?o0P0000<3o`000ol00P?o:Goo00<007oo
Ool00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2DOolW0ol01`000ol3o`?o0003o`000103o`03
0003o`?o00L3o`030003o`?o0083obUoo`03001oogoo005oo`003goo00<007ooOol0U7oo9`?o00@0
00?o0ol3o`<001T3o`030003o`0000<3obUoo`03001oogoo005oo`003goo00<007ooOol0U7oo9`?o
00D000?o0ol3o`000243obUoo`03001oogoo005oo`003goo00<007ooOol0U7oo9`?o00<000?o0ol0
0P?o0P007`?o:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2DOolW0ol00`000ol3o`0S0olYOol0
0`00Oomoo`01Ool000moo`8009EoobL3o`030003o`?o02<3obMoo`<000=oo`003goo00<007ooOol0
U7oo9`?o00<000?o0ol08`?o:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2DOolW0ol00`000ol3
o`0S0olYOol00`00Oomoo`01Ool000moo`03001oogoo09AoobL3o`030003o`?o02<3obUoo`03001o
ogoo005oo`003goo00<007ooOol0U7oo9`?o00<000?o0ol08`?o:Goo00<007ooOol00Goo000?Ool0
0`00Oomoo`2DOolW0ol00`000ol3o`0S0olYOol00`00Oomoo`01Ool000moo`03001oogoo09AoobL3
o`030003o`?o02<3obUoo`03001oogoo005oo`003goo00<007ooOol0U7oo9`?o00<000?o0ol08`?o
:Goo00<007ooOol00Goo000?Ool2002EOolW0ol00`000ol3o`0S0olWOol30003Ool000moo`03001o
ogoo0;]oo`03001oogoo04aoo`03001oogoo005oo`003goo00<007ooOol0^goo00<007ooOol0C7oo
00<007ooOol00Goo000?Ool00`00Oomoo`2kOol00`00Oomoo`1<Ool00`00Oomoo`01Ool000moo`03
001oogoo0;]oo`03001oogoo04aoo`03001oogoo005oo`003goo00<007ooOol0^goo00<007ooOol0
C7oo00<007ooOol00Goo000?Ool00`00Oomoo`2kOol00`00Oomoo`1<Ool00`00Oomoo`01Ool000mo
o`03001oogoo0;]oo`03001oogoo04aoo`03001oogoo005oo`003goo0P00^Goo00H007ooOol007oo
001:Ool30003Ool000moo`03001oogoo0;Uoo`05001oo`00Ool0001<Ool00`00Oomoo`01Ool000mo
o`03001oogoo0;Uoo`04001oo`00001=Ool00`00Oomoo`01Ool000moo`03001oogoo0;Yoo`<004eo
o`03001oogoo005oo`003goo00<007ooOol0^Woo0P00CWoo00<007ooOol00Goo000?Ool00`00Oomo
o`2kOol01000Oomoogoo0P00BGoo00<007ooOol00Goo000?Ool00`00Oomoo`30Ool00`00Oomoo`17
Ool00`00Oomoo`01Ool000moo`800<5oo`03001oogoo04Eoo`<000=oo`003goo00<007ooOol0_goo
00<007oo0000B7oo00<007ooOol00Goo000?Ool00`00Oomoo`2oOol01000Ool00000Agoo00<007oo
Ool00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03
001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo
005oo`0027oo10000goo0`00ogoo2Goo0`000goo0008Ool00`00Ool00004Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Uoo`8000Aoo`03001oogoo0?moo`]oo`03001oogoo005oo`002Woo00<0
07ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<0
00=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<0
07ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`01Ool000Yoo`03001oogoo009oool000l000=oo`0027oo0P00ogoo5goo0008Ool00`00Oomoo`3o
OolFOol000Qoo`<00?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.05975 .35333 -67.2204 -5.13016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.07524 .2026 -67.2204 -5.13016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -67.2204 -5.13016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.05975 .35333 m
.14286 .28571 L
.07524 .2026 L
s
.08313 .34812 m
.05975 .35333 L
.06961 .3315 L
s
.09708 .21246 m
.07524 .2026 L
.08045 .22599 L
s
gsave
.05975 .35333 -67.2204 -5.13016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.07524 .2026 -67.2204 -5.13016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -67.2204 -5.13016 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.05975 .35333 m
.14286 .28571 L
.07524 .2026 L
s
.08313 .34812 m
.05975 .35333 L
.06961 .3315 L
s
.09708 .21246 m
.07524 .2026 L
.08045 .22599 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.84027 .71429 m
.84027 .77143 L
.55456 .77143 L
.55456 .71429 L
F
0 g
.01 w
.45315 .49564 m
.73112 .42957 L
s
.02 w
.45315 .49564 Mdot
.73112 .42957 Mdot
gsave
.52917 .39171 -59.151 -4.4646 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.46543 .52917 -59.151 -4.4646 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.151 -4.4646 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.52917 .39171 m
.42857 .42857 L
.46543 .52917 L
s
.50537 .38902 m
.52917 .39171 L
.51274 .40914 L
s
.448 .51274 m
.46543 .52917 L
.46812 .50537 L
s
gsave
.80456 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.69742 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.69742 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80456 .71429 m
.69742 .71429 L
.69742 .82143 L
s
.78313 .70357 m
.80456 .71429 L
.78313 .725 L
s
.6867 .8 m
.69742 .82143 L
.70813 .8 L
s
gsave
.82068 .58405 -60.3743 -4.00023 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.70166 .67783 -60.3743 -4.00023 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -60.3743 -4.00023 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82068 .58405 m
.71429 .57143 L
.70166 .67783 L
s
.80067 .57089 m
.82068 .58405 L
.79814 .59217 L
s
.69355 .65528 m
.70166 .67783 L
.71483 .65781 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000?Ool2000QOol3
O00DOol00`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo00moo`03001oo`00
01eoo`9l01Moo`0301moogoo04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0
3goo00<007oo00000P006Goo0W`067oo00<07gooOol0CWoo00<07gooOol0Kgoo00<007ooOol00Goo
000?Ool00`00Oomoo`0>Ool01@00Ool00000Ool00`0057oo0g`06Woo00<07gooOol0Cgoo00<07goo
Ool0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0>Ool01P00Ool00000Ool0009oo`80011oo`9l
01aoo`0301moogoo051oo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol04Woo00<0
07oo00004Goo0W`07Woo00<07gooOol0DGoo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00
Oomoo`0BOol01000Oomoo`003Goo0g`087oo00<07gooOol0DGoo00<07gooOol0KGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0BOol01@00Oomoogoo00002Woo0W`08Woo00<07gooOol0Dgoo00<07goo
Ool0K7oo00<007ooOol00Goo000?Ool2000HOol00`00Oomoo`05Ool7O00OOol00`0OOomoo`1COol0
0`0OOomoo`1ZOol30003Ool000moo`03001oogoo01Qoo`03001oogoo009oo`=l00Ioo`=l01]oo`03
01moogoo05Aoo`0301moogoo06aoo`03001oogoo005oo`003goo00<007ooOol067oo00@007ooOomo
o`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301moogoo06]oo`03001oogoo005oo`003goo00<007oo
Ool06Goo00<007`0O00047oo0W`05Goo00<07gooOol0EWoo00<07gooOol0Jgoo00<007ooOol00Goo
000?Ool00`00Oomoo`0IOol00g`0001oo`0BOol00g`0Oomoo`0BOol00`0OOomoo`1GOol00`0OOomo
o`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`04O01oogoo000COol00g`0Oomoo`0AOol0
0`0OOomoo`0TOol;01lXOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Moo`03
O01oogoo009oo`03001oogoo015oo`03O01oogoo011oo`0301moogoo02=oo`h07bIoo`0301moogoo
06Yoo`03001oogoo005oo`003goo00<007ooOol05Woo00=l07ooOol00goo00<007ooOol04Goo00=l
07ooOol03goo00<07gooOol08goo400O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool2000G
Ool00g`0Oomoo`04Ool00`00Oomoo`0AOol00g`0Oomoo`0>Ool00`0OOomoo`0ROolB01lUOol00`0O
Oomoo`1WOol30003Ool000moo`03001oogoo01Eoo`03O01oogoo00Ioo`03001oogoo011oo`03O01o
ogoo00ioo`0301moogoo029ooa<07bAoo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007oo
Ool05Goo00=l07ooOol01goo00<007ooOol047oo00=l07ooOol03Goo00<07gooOol08Goo500O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`09Ool00`00Oomo
o`0?Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00moo`03001oogoo01Aoo`03O01oogoo00Yoo`03001oogoo00ioo`03O01oogoo00eoo`0301moogoo
025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0
57oo00=l07ooOol02Woo00<007ooOol03goo00=l07ooOol037oo00<07gooOol087oo5P0O8goo00<0
7gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0;
Ool00`00Oomoo`0>Ool00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Qoo`03001oo`0000Aoo`<001Aoo`03O01oogoo00aoodh000X07b=oo`0301moogoo
06Moo`<000=oo`0027oo00<007oo000017oo00<007ooOol057oo00=l07ooOol02Goo0`0047oo00=l
07ooOol037oo00<07gooOol087oo2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol0
0Goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`09Ool2000AOol00g`0Oomoo`0<
Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo01Aoo`03O01oogoo00Qoo`800003Ool007oo00ioo`03O01oogoo
00eoo`0301moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`00
3goo00<007ooOol057oo00=l07ooOol01goo00D007ooOomoo`0000moo`03O01oogoo00eoo`0301mo
ogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007oo
Ool05Goo00=l07ooOol01Goo00<007ooOol00`003Woo00=l07ooOol03Woo00<07gooOol08Goo2P0O
00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0
Oomoo`04Ool00`00Oomoo`0BOol00g`0Oomoo`0>Ool00`0OOomoo`0QOol:01l00`0001l07`0801lS
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo00=oo`03001o
ogoo01=oo`03O01oogoo00ioo`0301moogoo029oo`T07`0300007`0O00L07bAoo`0301moogoo06Uo
o`03001oogoo005oo`003goo0P005goo00El07ooOomoo`0001Eoo`03O01oogoo00moo`0301moogoo
02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<007ooOol05goo00=l
07oo00005Woo00=l07ooOol047oo00<07gooOol08goo1`0O00<0000O01l01@0O9Goo00<07gooOol0
JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol2000FOol00g`0Oomoo`0AOol00`0OOomoo`0S
Ool701l00`0001l07`0301lWOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Io
o`03001oog`001Eoo`03O01oogoo019oo`0301moogoo02Eoo`D07`0400007`0O01lYOol00`0OOomo
o`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`05001oogooOoml000COol00g`0Oomoo`0C
Ool00`0OOomoo`0WOol301l00`0001moo`0ZOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03
001oogoo011oo`05001oogooOol00005Ool2O00@Ool00g`0Oomoo`0DOol00`0OOomoo`0TOol=0n0U
Ool00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo00moo`05001oogooOol00008Ool3
O00;Ool2O00HOol00`0OOomoo`0NOolE0n0ROol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03
001oogoo00moo`04001oogoo000<Ool3O004Ool4O00JOol00`0OOomoo`0LOolI0n0OOol00`0OOomo
o`1/Ool00`00Oomoo`01Ool000moo`8000moo`04001oo`00000?Ool5O00OOol00`0OOomoo`0JOolM
0n0LOol00`0OOomoo`1ZOol30003Ool000moo`03001oogoo00ioo`80009oo`8000moo`9l021oo`03
01moogoo01Qoob03h1Yoo`0301moogoo06eoo`03001oogoo005oo`003goo00<007ooOol03Goo1@00
4goo0g`07Woo00<07gooOol05Woo8P?P6Goo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00
Oomoo`09Ool2000017oo000000006Goo0W`077oo00<07gooOol05Goo90?P5goo00<07gooOol0KWoo
00<007ooOol00Goo000?Ool00`00Oomoo`0;Ool00`00Oomoo`0LOol2O00JOol00`0OOomoo`0COolW
0n0FOol00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo00Yoo`03001oo`0001moo`9l
01Uoo`0301moogoo019oobT3h1=oo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0
;Woo0g`05goo00<07gooOol04Goo:P?P4Woo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool2000b
Ool2O00EOol00`0OOomoo`0@Ool[0n0AOol00`0OOomoo`1^Ool30003Ool000moo`03001oogoo03=o
o`9l01Aoo`0301moogoo00ioob`3h15oo`0301moogoo071oo`03001oogoo005oo`003goo00<007oo
Ool0=Goo0W`04Woo00<07gooOol03Goo;P?P3goo00<07gooOol0LGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0gOol3O00@Ool00`0OOomoo`0<Ool_0n0>Ool00`0OOomoo`1aOol00`00Oomoo`01Ool0
00moo`03001oogoo03Yoo`9l00ioo`0301moogoo00]ooc43h0aoo`0301moogoo079oo`03001oogoo
005oo`003goo00<007ooOol0?7oo0W`03Goo00<07gooOol02Woo;@?P0`0000<3h7ooOol02Woo00<0
7gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0nOol2O00<Ool00`0OOomoo`09Ool`0n04
0008Ool00`0OOomoo`1cOol00`00Oomoo`01Ool000moo`03001oogoo041oo`9l00]oo`0301moogoo
00Mooc03h0@000Aoo`800003Ool0000O07Ioo`03001oogoo005oo`003goo0P00@goo0g`027oo00<0
7gooOol01goo;P?P0P000P?P00<007ooOol01Goo00<0000OOol0M7oo0`000goo000?Ool00`00Oomo
o`15Ool2O007Ool00`0OOomoo`05Ool/0n0300040n000`00Oomoo`04Ool00`00Ool0001gOol00`00
Oomoo`01Ool000moo`03001oogoo04Moo`9l00Ioo`807`EoobT3h0<000H3h0030003h7oo00Eoo`80
7gQoo`03001oogoo005oo`003goo00<007ooOol0BGoo0W`01Woo00<07gooOol00Woo9`?P0P0020?P
00@000?P0n03h0Aoo`0301moogoo07Qoo`03001oogoo005oo`003goo00<007ooOol0Bgoo0g`017oo
00<07gooOol09@?P0`003P?P0goo00<07gooOol0NGoo00<007ooOol00Goo000?Ool00`00Oomoo`1>
Ool2O003Ool00`0OOol3h00Q0n03000A0n02Ool00`0OOomoo`1jOol00`00Oomoo`01Ool000Moo`D0
00=oo`03001oogoo051oo`9l009oo`0301l3h0?P01h3h08001@3h003Ool07goo07aoo`03001oogoo
005oo`002Goo00<007ooOol00goo00<007ooOol0DWoo0W`000=oo`?P0n006`?P0`005P?P00<07goo
Ool0<Woo0P00B7oo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001DOol00g`00n03h00I0n02
000I0n0bOol60015Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooa/3h0030003h0?P
00<3h08001<3h2Uoo`El7`X0009l7dEoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007oo
Ool0EGoo70?P00@000?P0n03h0<001<3h2Ioo`Al7`P000=l7`8000Ml7d5oo`03001oogoo005oo`00
27oo0P001Goo00<007ooOol0EGoo70?P00L000?P0n03h0000n00000C0n0ROol4O1l8000DO1lmOol0
0`00Oomoo`01Ool000moo`03001oogoo05Eooa`3h0030003h0?P0083h0030003h0?P0183h21oo`9l
7`P001Ul7caoo`03001oogoo005oo`003goo00<007ooOol0EWoo70?P00D000?P0n03h00001<3h1mo
o`P001ml7cYoo`03001oogoo005oo`003goo00<007ooOol0EWoo70?P00<000?P0n005@?P6goo2000
9G`O>7oo00<007ooOol00Goo000?Ool2001HOolL0n000`000n03h00D0n0GOol8000ZO1leOol30003
Ool000moo`03001oogoo05Mooa`3h0030003h0?P01@3h19oo`T0031l7cEoo`03001oogoo005oo`00
3goo00<007ooOol0Egoo70?P00<000?P0n0050?P3Woo2@000Woo<g`O=7oo00<007ooOol00Goo000?
Ool00`00Oomoo`1HOolL0n000`000n03h00B0n0;Ool80007OoldO1lcOol00`00Oomoo`01Ool000mo
o`03001oogoo05Qooa`3h0030003h0?P0183h0Moo`P000YoocIl7c9oo`03001oogoo005oo`003goo
00<007ooOol0FGoo6`?P00<000?P0n004P?P0goo20003Goo>7`O<Goo00<007ooOol00Goo000?Ool0
0`00Oomoo`1IOolL0n000`000n03h00@0n08000@OoljO1l`Ool00`00Oomoo`01Ool000moo`03001o
ogoo05Uooa`3h0030003h0?P00`3h0P001=oocal7bmoo`03001oogoo005oo`003goo0P00Fgoo70?P
00<000?P0n001`?P20005Woo?G`O;Goo0`000goo000?Ool00`00Oomoo`1KOolK0n000`000n03h003
0n0800020n0GOoloO1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aooaT3h08000030n000000
00H000D3h1Qoocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo60?P200020?P67oo@W`O
;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1MOolG0n04000;0n0IOom2O1l/Ool00`00Oomoo`01
Ool000moo`03001oogoo05iooaL3h0<000<3h0030003h0?P00@3h1Uood=l7baoo`03001oogoo005o
o`003goo00<007ooOol0Ggoo6@?P00@000?P0n0000D3h1UoodEl7b]oo`03001oogoo005oo`003goo
00<007ooOol0H7oo5@?P00@000?P0n000083h0040003h0?P0n0KOom6O1lZOol00`00Oomoo`01Ool0
00moo`8006Aooa<3h0060003h0?P0003h0000P?P6gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1U
OolB0n001@000n0000000n007GooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1WOolA0n03
000NOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo06Yoo`d3h09oo`8000Aoo`8001QoodQl
7bUoo`03001oogoo005oo`003goo00<007ooOol0Kgoo0`?P27oo00<007ooOol00goo00<007ooOol0
5GooBG`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`20Ool00`00Oomoo`0EOom:O1lXOol00`00
Oomoo`01Ool000moo`03001oogoo07moo`03001oo`0001IoodYl7bQoo`03001oogoo005oo`003goo
0P00P7oo00@007oo000001EoodYl7bIoo`<000=oo`003goo00<007ooOol0UgooBg`O:7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal
7bMoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00
Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000Qoo`<000Aoo`03001oogoo09Ioodel7bMoo`03001o
ogoo005oo`0027oo00<007ooOol017oo00<007ooOol0UWooCG`O9goo00<007ooOol00Goo0009Ool0
0`00Oomoo`03Ool3002FOolWO1l4000CO1l00`00O1ml7`0<O1lUOol30003Ool000Uoo`03001oogoo
00=oo`03001oogoo09IoobMl7`04001l7g`OO1l7000=O1l00`00O1ml7`0;O1lWOol00`00Oomoo`01
Ool000Qoo`03001oo`0000Aoo`03001oogoo09IoobMl7`03001l7g`O00<000El7`L000Ml7`8000]l
7bMoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Ugoo9W`O00<007`OO1l00W`O
00<007`OO1l02W`O1`000W`O00<007`OO1l027`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2G
OolUO1l00`00O1ml7`03O1l00`00O1ml7`0AO1l40009O1lWOol00`00Oomoo`01Ool000moo`03001o
ogoo09MoobEl7`04001l7g`OO1l2000CO1l3000;O1lWOol00`00Oomoo`01Ool000moo`03001oogoo
09MoobEl7`04001l7g`OO1l3000@O1l20007O1l200000g`O001l7`02O1lWOol00`00Oomoo`01Ool0
00moo`03001oogoo09MoobEl7`03001l7g`O01ml7`03001l7g`O009l7bMoo`03001oogoo005oo`00
3goo0P00V7oo9G`O00<007`OO1l07W`O00<007`O00000W`O9Woo0`000goo000?Ool00`00Oomoo`2H
OolTO1l00`00O1ml7`0SO1lXOol00`00Oomoo`01Ool000moo`03001oogoo09QoobAl7`03001l7g`O
02=l7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo8g`O00<007`OO1l08g`O:Goo00<007oo
Ool00Goo000?Ool00`00Oomoo`2IOolRO1l00`00O1ml7`0SO1lYOol00`00Oomoo`01Ool000moo`03
001oogoo09Uoob9l7`03001l7g`O02=l7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo8W`O
00<007`OO1l08g`O:Goo00<007ooOol00Goo000?Ool2002JOolRO1l00`00O1ml7`0RO1lXOol30003
Ool000moo`03001oogoo09Yoob5l7`03001l7g`O029l7bYoo`03001oogoo005oo`003goo00<007oo
Ool0VWoo8G`O00<007`OO1l08G`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`2KOolPO1l00`00
O1ml7`0PO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09aooail7`03001l7g`O025l7baoo`03
001oogoo005oo`003goo00<007ooOol0W7oo7W`O00<007`OO1l087`O;Goo00<007ooOol00Goo000?
Ool00`00Oomoo`2MOolMO1l00`00O1ml7`0PO1l]Ool00`00Oomoo`01Ool000moo`03001oogoo09eo
oael7`03001l7g`O01ml7bioo`03001oogoo005oo`003goo0P00Wgoo6G`O00@007`OO1l0009l7`03
001l7g`O01]l7beoo`<000=oo`003goo00<007ooOol0Wgoo67`O00H007`OO1l007`O000NO1l_Ool0
0`00Oomoo`01Ool000moo`03001oogoo0:1ooaQl7`05001l7`00O1l0000MO1l`Ool00`00Oomoo`01
Ool000moo`03001oogoo0:5ooaMl7`800003O1l007`O01el7c1oo`03001oogoo005oo`003goo00<0
07ooOol0XWoo5W`O0`007W`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`2SOolFO1l2000MO1lb
Ool00`00Oomoo`01Ool000moo`03001oogoo0:=ooaIl7`04001l7g`OO1l2000HO1lcOol00`00Oomo
o`01Ool000moo`03001oogoo0:EooaUl7`03001l7g`O01Al7cEoo`03001oogoo005oo`003goo0P00
Ygoo67`O00<007`OO1l04W`O=Goo0`000goo000?Ool00`00Oomoo`2XOolEO1l00`00O1l0000BO1lh
Ool00`00Oomoo`01Ool000moo`03001oogoo0:Yooa=l7`04001l7`00000?O1ljOol00`00Oomoo`01
Ool000moo`03001oogoo0:]oob=l7caoo`03001oogoo005oo`003goo00<007ooOol0[Goo87`O?Goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`2_OolLO1l4Ool2000iOol00`00Oomoo`01Ool0
00Yoo`03001oogoo009oo`03001oogoo0;9ooaEl7`Yoo`<003Ioo`03001oogoo005oo`002Goo00<0
07ooOol00goo0`00L7ooA00017`OD`000goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2BOolV0ol0
0`000ol3o`0H0ol2000:0ol[Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo099o
obH3o`040003o`?o0ol3000B0ol200050ol200000`?o0003o`020ol[Ool00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo099oobH3o`070003o`?o0ol000?o000040?o0P002@?o00<000?o
0ol00P?o:goo00<007ooOol00Goo000?Ool00`00Oomoo`2BOolV0ol010000ol3o`?o0`006P?o00<0
00?o00000`?o:goo00<007ooOol00Goo000?Ool00`00Oomoo`2BOolV0ol01@000ol3o`?o00008P?o
:goo00<007ooOol00Goo000?Ool00`00Oomoo`2BOolV0ol00`000ol3o`020ol2000P0ol[Ool00`00
Oomoo`01Ool000moo`03001oogoo099oobH3o`030003o`?o02@3ob]oo`03001oogoo005oo`003goo
0P00Tgoo9P?o00<000?o0ol090?o:Goo0`000goo000?Ool00`00Oomoo`2BOolV0ol00`000ol3o`0T
0ol[Ool00`00Oomoo`01Ool000moo`03001oogoo099oobH3o`030003o`?o02@3ob]oo`03001oogoo
005oo`003goo00<007ooOol0TWoo9P?o00<000?o0ol090?o:goo00<007ooOol00Goo000?Ool00`00
Oomoo`2BOolV0ol00`000ol3o`0T0ol[Ool00`00Oomoo`01Ool000moo`03001oogoo099oobH3o`03
0003o`?o02@3ob]oo`03001oogoo005oo`003goo00<007ooOol0TWoo9P?o00<000?o0ol090?o:goo
00<007ooOol00Goo000?Ool00`00Oomoo`2BOolV0ol00`000ol3o`0T0ol[Ool00`00Oomoo`01Ool0
00moo`8009=oobH3o`030003o`?o02@3obUoo`<000=oo`003goo00<007ooOol0^7oo00<007ooOol0
Cgoo00<007ooOol00Goo000?Ool00`00Oomoo`2hOol00`00Oomoo`1?Ool00`00Oomoo`01Ool000mo
o`03001oogoo0;Qoo`03001oogoo04moo`03001oogoo005oo`003goo00<007ooOol0^7oo00<007oo
Ool0Cgoo00<007ooOol00Goo000?Ool00`00Oomoo`2hOol00`00Oomoo`1?Ool00`00Oomoo`01Ool0
00moo`03001oogoo0;Qoo`03001oogoo04moo`03001oogoo005oo`003goo00<007ooOol0^7oo00<0
07ooOol0Cgoo00<007ooOol00Goo000?Ool2002fOol01000Oomoo`000Woo00<007ooOol0BWoo0`00
0goo000?Ool00`00Oomoo`2fOol01@00Ool007oo0000Cgoo00<007ooOol00Goo000?Ool00`00Oomo
o`2fOol01@00Ool007oo0000Cgoo00<007ooOol00Goo000?Ool00`00Oomoo`2gOol3001@Ool00`00
Oomoo`01Ool000moo`03001oogoo0;Moo`<0051oo`03001oogoo005oo`003goo00<007ooOol0^7oo
00@007ooOomoo`8004aoo`03001oogoo005oo`003goo00<007ooOol0_Goo00<007ooOol0BWoo00<0
07ooOol00Goo000?Ool2002nOol00`00Oomoo`18Ool30003Ool000moo`03001oogoo0;aoo`03001o
o`0004]oo`03001oogoo005oo`003goo00<007ooOol0_7oo00@007oo000004Yoo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo0`000goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00Qoo`@000=oo`<00?moo`Uoo`<000=oo`0027oo00<007oo000017oo00<007ooOol0ogoo2goo00<0
07ooOol00Goo0009Ool20004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo
009oo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Goo
000:Ool00`00Oomoo`02Oooo000?0003Ool000Qoo`800?mooaMoo`0027oo00<007ooOol0ogoo5Woo
0008Ool3003oOolFOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.03671 .27113 -65.5636 -6.01417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.15745 .17957 -65.5636 -6.01417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -65.5636 -6.01417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.03671 .27113 m
.14286 .28571 L
.15745 .17957 L
s
.05648 .28466 m
.03671 .27113 L
.0594 .26343 L
s
.16514 .20226 m
.15745 .17957 L
.14391 .19934 L
s
gsave
.03671 .27113 -65.5636 -6.01417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.15745 .17957 -65.5636 -6.01417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -65.5636 -6.01417 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.03671 .27113 m
.14286 .28571 L
.15745 .17957 L
s
.05648 .28466 m
.03671 .27113 L
.0594 .26343 L
s
.16514 .20226 m
.15745 .17957 L
.14391 .19934 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.83145 .71429 m
.83145 .77143 L
.54573 .77143 L
.54573 .71429 L
F
0 g
.01 w
.46081 .49231 m
.73984 .43088 L
s
.02 w
.46081 .49231 Mdot
.73984 .43088 Mdot
gsave
.52418 .38021 -58.9689 -4.60314 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.47693 .52418 -58.9689 -4.60314 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -58.9689 -4.60314 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.52418 .38021 m
.42857 .42857 L
.47693 .52418 L
s
.50022 .38032 m
.52418 .38021 L
.50989 .39944 L
s
.4577 .50989 m
.47693 .52418 L
.47682 .50022 L
s
gsave
.79573 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68859 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68859 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.79573 .71429 m
.68859 .71429 L
.68859 .82143 L
s
.7743 .70357 m
.79573 .71429 L
.7743 .725 L
s
.67787 .8 m
.68859 .82143 L
.6993 .8 L
s
gsave
.8197 .5906 -60.5851 -3.9535 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.69512 .67684 -60.5851 -3.9535 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -60.5851 -3.9535 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.8197 .5906 m
.71429 .57143 L
.69512 .67684 L
s
.80053 .57622 m
.8197 .5906 L
.7967 .59731 L
s
.68841 .65384 m
.69512 .67684 L
.70949 .65768 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P009goo0P006Goo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool0
0`00Oomoo`0WOol00`00Oomoo`0EOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomo
o`01Ool000moo`03001oogoo02Moo`03001oogoo01=oo`9l00eoo`0301moogoo04Eoo`0301moogoo
07=oo`03001oogoo005oo`003goo00<007ooOol09Woo0`004Woo0W`03Woo00<07gooOol0Agoo00<0
7gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0VOol4000>Ool3O00?Ool00`0OOomoo`19
Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo02Eoo`04001oo`00000=Ool2O00A
Ool00`0OOomoo`1:Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo02Eoo`800003
Ool007oo00Yoo`9l01=oo`0301moogoo04]oo`0301moogoo071oo`03001oogoo005oo`003goo0P00
9Goo00<007oo00000Woo00<007ooOol01Goo0g`057oo00<07gooOol0C7oo00<07gooOol0KWoo0`00
0goo000?Ool00`00Oomoo`0VOol01000Oomoo`001Goo0W`05goo00<07gooOol0CGoo00<07gooOol0
Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0VOol00`00Oomoo`04Ool2O00HOol00`0OOomoo`1>
Ool00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02Ioo`04001oogooOol3O00JOol0
0`0OOomoo`1?Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Ioo`04001oog`0
O00LOol00`0OOomoo`1@Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Ioo`03
001l07oo01eoo`0301moogoo055oo`0301moogoo06eoo`03001oogoo005oo`003goo00<007ooOol0
8goo0W`000<007ooOol07Woo00<07gooOol0DGoo00<07gooOol0KGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0QOol2O002Ool00`00Oomoo`0MOol00`0OOomoo`1COol00`0OOomoo`1/Ool00`00Oomo
o`01Ool000moo`80021oo`Il0003001oogoo01eoo`0301moogoo05=oo`0301moogoo06Yoo`<000=o
o`003goo00<007ooOol07Goo0g`01Goo00@007`0O01l01]oo`0301moogoo05Aoo`0301moogoo06ao
o`03001oogoo005oo`003goo00<007ooOol077oo0W`01goo00@007ooOomoo`=l01Qoo`0301moogoo
05Eoo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`02Goo00<007ooOol0
17oo0W`05Goo00<07gooOol0EWoo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0I
Ool00g`0Oomoo`09Ool00`00Oomoo`06Ool00g`0Oomoo`0BOol00`0OOomoo`1GOol00`0OOomoo`1Z
Ool00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03O01oogoo00Uoo`03001oogoo00Qoo`03O01o
ogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007oo
Ool05goo00=l07ooOol02Woo00<007ooOol02Goo00=l07ooOol047oo00<07gooOol08goo3P0O9Woo
00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0;Ool00`00Oomo
o`09Ool00g`0Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool0
00moo`8001Moo`03O01oogoo00]oo`03001oogoo00Yoo`03O01oogoo00ioo`0301moogoo029ooa80
7bEoo`0301moogoo06Moo`<000=oo`003goo00<007ooOol037oo0P001goo00=l07ooOol037oo00<0
07ooOol02Woo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo00<07gooOol0JGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`09Ool30009Ool00g`0Oomoo`0<Ool00`00Oomoo`0;Ool00g`0Oomoo`0=
Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo00Ao
o`800003Ool00000008000Uoo`03O01oogoo00eoo`03001oogoo00]oo`03O01oogoo00eoo`0301mo
ogoo025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol01Woo00<007oo
00000Woo1`000Woo00=l07ooOol037oo00<007ooOol037oo00=l07ooOol03Goo00<07gooOol08Goo
5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
1000Ool007oo0P001goo1`002Woo00<007ooOol03Goo00=l07ooOol037oo00<07gooOol087oo5P0O
8goo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool00g`0Oomoo`02Ool70003Ool00`00Oomoo`0=Ool00g`0Oomoo`0<Ool00`0OOomoo`0P
OolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<000aoo`03001o
ogoo00Eoo`03O01oogoo00Uooe4000X07b=oo`0301moogoo06Moo`<000=oo`0027oo00<007oo0000
17oo00<007ooOol057oo00=l07ooOol02goo0P003goo00=l07ooOol037oo00<07gooOol087oo2`0O
00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00
Oomoo`0DOol00g`0Oomoo`0=Ool00`00Oomoo`0<Ool00g`0Oomoo`0<Ool00`0OOomoo`0POol;01l0
0`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001o
ogoo01Aoo`03O01oogoo00eoo`03001oogoo00]oo`03O01oogoo00eoo`0301moogoo021oo`/07`03
00007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol057oo00=l07oo
Ool02goo0`003Goo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07goo
Ool0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0IOol00g`0Oomoo`0>Ool0
0`0OOomoo`0QOol:01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03
001oogoo01Eoo`03O01oogoo01Uoo`03O01oogoo00ioo`0301moogoo025oo`X07`0300007`0O00P0
7b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l
07ooOol03Woo00<07gooOol08Woo2@0O00<0000O01l01`0O97oo00<07gooOol0JGoo00<007ooOol0
0Goo000?Ool2000GOol00g`0Oomoo`0GOol00g`0Oomoo`0?Ool00`0OOomoo`0SOol801l00`0001l0
7`0601lTOol00`0OOomoo`1XOol30003Ool000moo`03001oogoo01Moo`03O01oogoo01Ioo`03O01o
ogoo011oo`0301moogoo02=oo`L07`0300007`0O00D07bEoo`0301moogoo06Yoo`03001oogoo005o
o`003goo00<007ooOol05goo00=l07ooOol05Goo00=l07ooOol04Goo00<07gooOol08goo1`0O00<0
000O01l00`0O9goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol00g`0Oomo
o`0COol00g`0Oomoo`0BOol00`0OOomoo`0UOol501l0100001l07`0O:Goo00<07gooOol0JWoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomoo`0COol00`0OOomoo`0W
Ool301l00`0001moo`0ZOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Yoo`9l
011oo`03O01oogoo01Aoo`0301moogoo02Aoo`d3h2Eoo`0301moogoo06]oo`03001oogoo005oo`00
3goo00<007ooOol077oo0g`02goo0W`067oo00<07gooOol07Woo5@?P8Woo00<07gooOol0Jgoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0OOol3O004Ool4O00JOol00`0OOomoo`0LOolI0n0OOol00`0O
Oomoo`1/Ool00`00Oomoo`01Ool000moo`80029oo`El01moo`0301moogoo01Yooad3h1aoo`0301mo
ogoo06Yoo`<000=oo`003goo00<007ooOol08goo0W`087oo00<07gooOol067oo80?P6Woo00<07goo
Ool0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0UOol3O00NOol00`0OOomoo`0FOolR0n0IOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo01Eoob@3
h1Moo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol0:Woo0W`06Woo00<07gooOol0
4goo9`?P5Woo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0/Ool2O00IOol00`0O
Oomoo`0BOolY0n0COol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02ioo`=l01Mo
o`0301moogoo015oobX3h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P00<Woo0W`05Goo
00<07gooOol047oo:`?P4Goo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0cOol2O00DOol0
0`0OOomoo`0>Ool/0n0AOol00`0OOomoo`1`Ool00`00Oomoo`01Ool000moo`03001oogoo03Eoo`9l
019oo`0301moogoo00eoobh3h0moo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0
=goo0g`047oo00<07gooOol037oo:P?P20002goo00<07gooOol0LGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0jOol2O00>Ool00`0OOomoo`0;Ool`0n020004Ool200000goo001oo`02Ool00`0OOomo
o`1bOol00`00Oomoo`01Ool000moo`03001oogoo03aoo`9l00eoo`0301moogoo00Yoobh3h0<000Mo
o`03001oogoo009oo`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol0?Woo0W`037oo
00<07gooOol02Goo;0?P0P000P?P00<000?POol017oo00<007oo00000Woo00<07gooOol0Lgoo00<0
07ooOol00Goo000?Ool00`00Oomoo`10Ool2O00;Ool00`0OOomoo`07Ool[0n0200030n000`000n03
h009Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`8004=oo`=l00Qoo`0301moogoo00MoobT3
h08000@3h0040003h0?P0n08Ool00`0OOomoo`1cOol30003Ool000moo`03001oogoo04Eoo`9l00Mo
o`0301moogoo00EoobP3h08000X3h0Qoo`0301moogoo07Eoo`03001oogoo005oo`003goo00<007oo
Ool0Agoo0W`01Woo0P0O1Goo9P?P0P0030?P1Woo0P0ON7oo00<007ooOol00Goo000?Ool00`00Oomo
o`19Ool2O006Ool00`0OOomoo`02OolT0n02000?0n04Ool00`0OOomoo`1hOol00`00Oomoo`01Ool0
00moo`03001oogoo04]oo`=l00Aoo`0301moogoo02<3h0800143h0=oo`0301moogoo07Uoo`03001o
ogoo005oo`003goo00<007ooOol0CWoo0W`00goo00<07goo0n0080?P0P004`?P0Woo00<07gooOol0
NWoo00<007ooOol00Goo0007Ool50003Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00M0n02000E
0n000goo01moo`1lOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003
Ool3h0?P01/3h08001L3h00301moogoo03Aoo`<004Eoo`03001oogoo005oo`002Goo00<007ooOol0
0goo0`00E7oo00=l00?P0n006@?P0P006@?P=Goo1@00@goo0`000goo0009Ool00`00Oomoo`03Ool0
0`00Oomoo`1EOolL0n000`000n03h0020n02000C0n0YOol8O1l90015Ool00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo05Eooa`3h0040003h0?P0n03000C0n0VOol6O1l90002O1l20005
O1m1Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo05Eooad3h0060003h0?P0003h0004`?P
8Woo1W`O2@004G`O?Goo00<007ooOol00Goo000?Ool00`00Oomoo`1EOolM0n001@000n03h0?P0000
50?P87oo0g`O2@005g`O?7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOolM0n0010000n03h000
4`?P87oo2@007G`O>Woo00<007ooOol00Goo000?Ool00`00Oomoo`1FOolM0n000`000n03h00D0n0L
Ool8000TO1lhOol00`00Oomoo`01Ool000moo`8005Qooad3h0030003h0?P01<3h1Moo`T002Ul7cEo
o`<000=oo`003goo00<007ooOol0Egoo7@?P00<000?P0n004`?P4goo2@00;g`O=Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`1GOolN0n000`000n03h00B0n0>Ool90002OolcO1ldOol00`00Oomoo`01
Ool000moo`03001oogoo05Qooad3h0030003h0?P0143h0]oo`T000IoocAl7c=oo`03001oogoo005o
o`003goo00<007ooOol0F7oo7P?P00<000?P0n0040?P1goo20002Woo=W`O<Woo00<007ooOol00Goo
000?Ool00`00Oomoo`1IOolM0n000`000n03h00@0n02Ool9000=OolhO1laOol00`00Oomoo`01Ool0
00moo`03001oogoo05Uooah3h0030003h0?P00d3h0T0011oocYl7c1oo`03001oogoo005oo`003goo
00<007ooOol0FGoo7P?P00<000?P0n0020?P2@0057oo?7`O;goo00<007ooOol00Goo000?Ool2001K
OolN0n000`000n03h0030n09000GOolmO1l]Ool30003Ool000moo`03001oogoo05]ooad3h0X000@3
h1Moocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo6`?P1`001`?P67oo?g`O;Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`1LOolK0n0400090n0HOom2O1l/Ool00`00Oomoo`01Ool000mo
o`03001oogoo05eooa/3h0<00083h0030003h0?P00<3h1Uood9l7baoo`03001oogoo005oo`003goo
00<007ooOol0GWoo70?P00@000?P0n0000@3h1Uood=l7baoo`03001oogoo005oo`003goo00<007oo
Ool0Ggoo70?P00<000?P00000`?P6GooAG`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`1POolH
0n001`000n03h0000n0000?P01]oodIl7bYoo`03001oogoo005oo`003goo0P00I7oo5P?P0P0000<3
h00000006gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolF0n03000KOom8O1lYOol00`00Oomo
o`01Ool000moo`03001oogoo06Mooa<3h0=oo`03001oogoo009oo`8001EoodQl7bUoo`03001oogoo
005oo`003goo00<007ooOol0JWoo3@?P37oo00<007ooOol04gooB7`O:Goo00<007ooOol00Goo000?
Ool00`00Oomoo`1_Ool30n0AOol00`00Oomoo`0BOom9O1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo089oo`03001oo`0001=oodYl7bQoo`03001oogoo005oo`003goo00<007ooOol0PWoo00@007oo
0000019oodYl7bQoo`03001oogoo005oo`003goo0P00VGooBW`O9Woo0`000goo000?Ool00`00Oomo
o`2GOom;O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`00
3goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00
Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`0027oo0`0017oo00<007oo
Ool0UWooCG`O9goo00<007ooOol00Goo0008Ool00`00Oomoo`04Ool00`00Oomoo`2FOom=O1lWOol0
0`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<009IoobMl7`<002=l7bEoo`<000=oo`002Goo00<0
07ooOol00goo00<007ooOol0UWoo9g`O00<007`OO1l01P003W`O00<007`OO1l037`O9goo00<007oo
Ool00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2FOolWO1l00`00O1ml7`030003O1l5000:O1l0
0`00O1ml7`0;O1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo09MoobEl7`03
001l7g`O00=l7`03001l7g`O00Il7`H000El7`8000]l7bMoo`03001oogoo005oo`003goo00<007oo
Ool0Ugoo9G`O00<007`OO1l00g`O00<007`OO1l037`O1P0000=l7`00O1l02G`O9goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2GOolUO1l01000O1ml7g`O0P005G`O0`002G`O9goo00<007ooOol00Goo
000?Ool00`00Oomoo`2GOolUO1l01000O1ml7g`O0`004W`O0`002g`O9goo00<007ooOol00Goo000?
Ool00`00Oomoo`2GOolUO1l00`00O1ml7`0DO1l20006O1l200000g`O001l7`03O1lWOol00`00Oomo
o`01Ool000moo`8009QoobEl7`03001l7g`O01il7`03001l7g`O009l7bIoo`<000=oo`003goo00<0
07ooOol0V7oo8g`O00<007`OO1l07W`O00<007`O00000g`O:7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2HOolSO1l00`00O1ml7`0TO1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qoob=l7`03
001l7g`O02=l7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo8W`O00<007`OO1l08g`O:Goo
00<007ooOol00Goo000?Ool00`00Oomoo`2IOolRO1l00`00O1ml7`0SO1lYOol00`00Oomoo`01Ool0
00moo`03001oogoo09Uoob5l7`03001l7g`O02Al7bUoo`03001oogoo005oo`003goo0P00VWoo8G`O
00<007`OO1l08g`O:7oo0`000goo000?Ool00`00Oomoo`2JOolPO1l00`00O1ml7`0SO1lZOol00`00
Oomoo`01Ool000moo`03001oogoo09Yoob1l7`03001l7g`O029l7b]oo`03001oogoo005oo`003goo
00<007ooOol0Vgoo7g`O00<007`OO1l08G`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolN
O1l00`00O1ml7`0QO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09aooael7`03001l7g`O025l
7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo77`O00<007`OO1l08G`O;Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2MOolIO1l01000O1ml7`008W`O;Woo00<007ooOol00Goo000?Ool2002O
OolHO1l01P00O1ml7`00O1l001ml7beoo`<000=oo`003goo00<007ooOol0Wgoo67`O00@007`O0000
021l7bmoo`03001oogoo005oo`003goo00<007ooOol0X7oo5g`O00@007`O000001ml7c1oo`03001o
ogoo005oo`003goo00<007ooOol0XGoo5W`O0`0087`O<7oo00<007ooOol00Goo000?Ool00`00Oomo
o`2ROolFO1l2000OO1laOol00`00Oomoo`01Ool000moo`03001oogoo0:=ooaEl7`03001l7g`O0080
01]l7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo6G`O00<007`OO1l067`O<goo00<007oo
Ool00Goo000?Ool00`00Oomoo`2UOolGO1l00`00O1ml7`0FO1leOol00`00Oomoo`01Ool000moo`80
0:MooaEl7`03001l7`0001El7cEoo`<000=oo`003goo00<007ooOol0Z7oo4g`O00@007`O000001=l
7cQoo`03001oogoo005oo`003goo00<007ooOol0ZWoo9W`O>Woo00<007ooOol00Goo000?Ool00`00
Oomoo`2[OolSO1llOol00`00Oomoo`01Ool000moo`03001oogoo0:eoob1l7ceoo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0[goo77`O0Woo0P00>goo00<007ooOol00Goo000:Ool00`00Oomo
o`02Ool00`00Oomoo`2bOolEO1l8Ool3000hOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<0
071ood@0009l7eD000=oo`002Woo00<007ooOol00Woo00<007ooOol0Sgoo9`?o00<000?o0ol060?o
0P002@?o;Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2?OolW0ol010000ol3
o`?o0`004P?o0P001@?o0P0000@3o`000ol3obioo`03001oogoo005oo`002Goo00<007ooOol00goo
00<007ooOol0Sgoo9`?o00L000?o0ol3o`000ol0000@0ol200090ol010000ol3o`?o;Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`2?OolW0ol010000ol3o`?o0`006P?o00<000?o00000P?o;Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`2?OolW0ol01@000ol3o`?o00008@?o;Woo00<007ooOol00Goo
000?Ool00`00Oomoo`2?OolW0ol00`000ol3o`020ol2000O0ol^Ool00`00Oomoo`01Ool000moo`03
001oogoo08moobL3o`030003o`?o02<3obioo`03001oogoo005oo`003goo0P00T7oo9`?o00<000?o
0ol08`?o;7oo0`000goo000?Ool00`00Oomoo`2?OolW0ol00`000ol3o`0S0ol^Ool00`00Oomoo`01
Ool000moo`03001oogoo08moobL3o`030003o`?o02<3obioo`03001oogoo005oo`003goo00<007oo
Ool0Sgoo9`?o00<000?o0ol08`?o;Woo00<007ooOol00Goo000?Ool00`00Oomoo`2?OolW0ol00`00
0ol3o`0S0ol^Ool00`00Oomoo`01Ool000moo`03001oogoo08moobL3o`030003o`?o02<3obioo`03
001oogoo005oo`003goo00<007ooOol0Sgoo9`?o00<000?o0ol08`?o;Woo00<007ooOol00Goo000?
Ool00`00Oomoo`2?OolW0ol00`000ol3o`0S0ol^Ool00`00Oomoo`01Ool000moo`80091oobL3o`03
0003o`?o02<3obaoo`<000=oo`003goo00<007ooOol0]Woo00<007ooOol0DGoo00<007ooOol00Goo
000?Ool00`00Oomoo`2fOol00`00Oomoo`1AOol00`00Oomoo`01Ool000moo`03001oogoo0;Ioo`03
001oogoo055oo`03001oogoo005oo`003goo00<007ooOol0]Woo00<007ooOol0DGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`2fOol00`00Oomoo`1AOol00`00Oomoo`01Ool000moo`03001oogoo0;Io
o`03001oogoo055oo`03001oogoo005oo`003goo00<007ooOol0]Woo00<007ooOol0DGoo00<007oo
Ool00Goo000?Ool2002dOol01000Oomoo`000Woo00<007ooOol0C7oo0`000goo000?Ool00`00Oomo
o`2dOol01@00Ool007oo0000DGoo00<007ooOol00Goo000?Ool00`00Oomoo`2dOol01@00Ool007oo
0000DGoo00<007ooOol00Goo000?Ool00`00Oomoo`2eOol3001BOol00`00Oomoo`01Ool000moo`03
001oogoo0;Eoo`<0059oo`03001oogoo005oo`003goo00<007ooOol0]Woo00@007ooOomoo`8004io
o`03001oogoo005oo`003goo00<007ooOol0^goo00<007ooOol0C7oo00<007ooOol00Goo000?Ool2
002lOol00`00Oomoo`1:Ool30003Ool000moo`03001oogoo0;Yoo`03001oo`0004eoo`03001oogoo
005oo`003goo00<007ooOol0^Woo00@007oo000004aoo`03001oogoo005oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`002Goo0`000goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`@000=oo`<00?mo
o`Uoo`<000=oo`0027oo00<007oo000017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool2
0004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo0?mo
o`]oo`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Goo000:Ool00`00Oomoo`02
Oooo000?0003Ool000Qoo`800?mooaMoo`0027oo00<007ooOol0ogoo5Woo0008Ool3003oOolFOol0
0?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.08107 .19818 -62.2791 -6.25429 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.23039 .22393 -62.2791 -6.25429 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -62.2791 -6.25429 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.08107 .19818 m
.14286 .28571 L
.23039 .22393 L
s
.08467 .22187 m
.08107 .19818 L
.10218 .20951 L
s
.21906 .24504 m
.23039 .22393 L
.2067 .22753 L
s
gsave
.08107 .19818 -62.2791 -6.25429 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.23039 .22393 -62.2791 -6.25429 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -62.2791 -6.25429 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.08107 .19818 m
.14286 .28571 L
.23039 .22393 L
s
.08467 .22187 m
.08107 .19818 L
.10218 .20951 L
s
.21906 .24504 m
.23039 .22393 L
.2067 .22753 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.82277 .71429 m
.82277 .77143 L
.53706 .77143 L
.53706 .71429 L
F
0 g
.01 w
.46804 .48811 m
.74833 .43269 L
s
.02 w
.46804 .48811 Mdot
.74833 .43269 Mdot
gsave
.51787 .36937 -58.8419 -4.74712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.48777 .51787 -58.8419 -4.74712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -58.8419 -4.74712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.51787 .36937 m
.42857 .42857 L
.48777 .51787 L
s
.49409 .37228 m
.51787 .36937 L
.50593 .39014 L
s
.467 .50593 m
.48777 .51787 L
.48486 .49409 L
s
gsave
.78706 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67992 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67992 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.78706 .71429 m
.67992 .71429 L
.67992 .82143 L
s
.76563 .70357 m
.78706 .71429 L
.76563 .725 L
s
.6692 .8 m
.67992 .82143 L
.69063 .8 L
s
gsave
.81834 .59696 -60.8012 -3.91147 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68876 .67549 -60.8012 -3.91147 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -60.8012 -3.91147 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81834 .59696 m
.71429 .57143 L
.68876 .67549 L
s
.80008 .58145 m
.81834 .59696 L
.79498 .60226 L
s
.68346 .65212 m
.68876 .67549 L
.70427 .65723 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000DOol200000goo
001oo`0IOol3O00DOol00`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo01=o
o`<001Uoo`9l01Moo`0301moogoo04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007oo
Ool04goo0P0000=oo`0000005Goo0W`067oo00<07gooOol0CWoo00<07gooOol0Kgoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0COol00`00Ool00002Ool00`00Oomoo`0?Ool3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03001oo`00015oo`9l01ao
o`0301moogoo051oo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol057oo00<007oo
00003goo0W`057oo0P0027oo00<07gooOol0DGoo00<07gooOol0KGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0DOol01000Oomoo`002goo0g`05goo00<007ooOol01Woo00<07gooOol0DGoo00<07goo
Ool0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol00`00Oomoo`06Ool2O00EOol400000goo
001oo`06Ool00`0OOomoo`1COol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`8001Yoo`03001o
ogoo00=oo`Ml00ioo`@00007Ool00000Ool007oo00001Woo00<07gooOol0Dgoo00<07gooOol0JWoo
0`000goo000?Ool00`00Oomoo`0IOol01000Oomoogoo0g`01Woo0g`03goo00H007oo001oo`00Ool2
0004Ool00`0OOomoo`1DOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`03001oogoo01Yoo`04
001oog`0O00;Ool3O00:Ool200000goo001oo`09Ool00`0OOomoo`1EOol00`0OOomoo`1[Ool00`00
Oomoo`01Ool000moo`03001oogoo01Yoo`03O00007oo00moo`9l00Moo`05001oogooOol00009Ool0
0`0OOomoo`1FOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oo`00
019oo`03O01oogoo009oo`8000=oo`03001oogoo00Qoo`0301moogoo05Moo`0301moogoo06Yoo`03
001oogoo005oo`003goo00<007ooOol067oo00El07ooOomoo`00019oo`04O01oogoo000@Ool00`0O
Oomoo`0TOol;01lXOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Moo`03O01o
ogoo00=oo`03001oogoo011oo`80015oo`0301moogoo02=oo`h07bIoo`0301moogoo06Yoo`03001o
ogoo005oo`003goo00<007ooOol05Woo00=l07ooOol017oo00<007ooOol03goo00<007`0Ool047oo
00<07gooOol08goo400O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool2000GOol00g`0Oomo
o`05Ool00`00Oomoo`0<Ool20002Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROolB01lUOol00`0OOomo
o`1WOol30003Ool000moo`03001oogoo01Eoo`03O01oogoo00Moo`03001oogoo00Yoo`03001oogoo
009oo`03O01oogoo00ioo`0301moogoo029ooa<07bAoo`0301moogoo06Uoo`03001oogoo005oo`00
3goo00<007ooOol05Goo00=l07ooOol027oo00<007ooOol01goo0P001Woo00=l07ooOol03Goo00<0
7gooOol08Goo500O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lS
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oogoo00Yoo`03001o
ogoo00=oo`8000Uoo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03001o
ogoo005oo`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol02goo00D007ooOomoo`00
00aoo`03O01oogoo00aoo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`00
27oo00<007oo000017oo00<007ooOol057oo00=l07ooOol02goo00@007oo000000eoo`03O01oogoo
00aoo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo0000
17oo0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool0
0004Ool00`00Oomoo`0DOol00g`0Oomoo`0>Ool2000<Ool00g`0Oomoo`0<Ool00`0OOomoo`0POol;
01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03
001oogoo01Aoo`03O01oogoo011oo`03001oogoo00Uoo`03O01oogoo00aoo`0301moogoo021oo`/0
7`0300007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo00<0
07ooOol057oo00=l07ooOol047oo00<007ooOol027oo00=l07ooOol03Goo00<07gooOol087oo2`0O
00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0
Oomoo`0>Ool3000:Ool00g`0Oomoo`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol00`0O
Oomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo01Uoo`03O01oogoo00io
o`0301moogoo025oo`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo
00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Goo2P0O00<0000O01l0
200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0IOol0
0g`0Oomoo`0>Ool00`0OOomoo`0ROol901l00`0001l07`0701lTOol00`0OOomoo`1YOol00`00Oomo
o`01Ool000moo`8001Moo`03O01oogoo01Moo`03O01oogoo00moo`0301moogoo02=oo`P07`030000
7`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l
07ooOol047oo00<07gooOol08goo1`0O00<0000O01l01@0O9Goo00<07gooOol0JWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0EOol00g`0Oomoo`0AOol00`0OOomoo`0SOol701l0
0`0001l07`0301lWOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03O01o
ogoo01=oo`03O01oogoo019oo`0301moogoo02Eoo`D07`0400007`0O01lYOol00`0OOomoo`1ZOol0
0`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo015oo`03O01oogoo01=oo`0301moogoo
02Moo`<07`0300007goo02Yoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol06Woo
0W`047oo00=l07ooOol057oo00<07gooOol097oo3@?P9Goo00<07gooOol0Jgoo00<007ooOol00Goo
000?Ool00`00Oomoo`0LOol3O00;Ool2O00HOol00`0OOomoo`0NOolE0n0ROol00`0OOomoo`1[Ool0
0`00Oomoo`01Ool000moo`03001oogoo01moo`=l00Aoo`Al01Yoo`0301moogoo01aooaT3h1moo`03
01moogoo06aoo`03001oogoo005oo`003goo0P008Woo1G`07goo00<07gooOol06Woo7@?P77oo00<0
7gooOol0JWoo0`000goo000?Ool00`00Oomoo`0SOol2O00POol00`0OOomoo`0HOolP0n0JOol00`0O
Oomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02Eoo`=l01ioo`0301moogoo01Ioob83h1Uo
o`0301moogoo06eoo`03001oogoo005oo`003goo00<007ooOol0:7oo0W`077oo00<07gooOol05Goo
90?P5goo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol2O00JOol00`0OOomo
o`0COolW0n0FOol00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02aoo`9l01Uoo`03
01moogoo019oobT3h1=oo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Woo0g`0
5goo00<07gooOol04Goo:P?P4Woo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool2000bOol2O00E
Ool00`0OOomoo`0@Ool[0n03000>Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo03=oo`9l
01Aoo`0301moogoo00ioobP3h0H000Aoo`800003Ool007oo00Ioo`0301moogoo071oo`03001oogoo
005oo`003goo00<007ooOol0=Goo0W`04Woo00<07gooOol03Goo;0?P00<000?P00001Woo00<007oo
Ool01Goo00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0gOol3O00@Ool00`0OOomo
o`0<OolZ0n0200000`?P0003h005Ool00`00Ool00006Ool00`0OOomoo`1aOol00`00Oomoo`01Ool0
00moo`03001oogoo03Yoo`9l00ioo`0301moogoo00]oobX3h0050003h0?P0n0000020n0<Ool00`0O
Oomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo03aoo`9l00eoo`0301moogoo00YoobP3h080
00<3h0040003h0?P0n0<Ool00`0OOomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo03ioo`9l
00aoo`0301moogoo00UoobL3h0030003h0?P00P3h0Yoo`0301moogoo07=oo`03001oogoo005oo`00
3goo00<007ooOol0@7oo0W`02goo00<07gooOol01goo9P?P0P002`?P2Goo00<07gooOol0M7oo00<0
07ooOol00Goo000?Ool20013Ool3O008Ool00`0OOomoo`07OolU0n000`000n03h00;0n08Ool00`0O
Oomoo`1cOol30003Ool000moo`03001oogoo04Eoo`9l00Moo`0301moogoo00Eoob@3h08000h3h0Qo
o`0301moogoo07Eoo`03001oogoo005oo`003goo00<007ooOol0Agoo0W`01Woo0P0O1Goo8`?P00<0
00?P0n003P?P1Woo0P0ON7oo00<007ooOol00Goo000?Ool00`00Oomoo`19Ool2O006Ool00`0OOomo
o`02OolQ0n02000B0n04Ool00`0OOomoo`1hOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`=l
00Aoo`0301moogoo0243h0030003h0?P0183h0=oo`0301moogoo07Uoo`03001oogoo005oo`003goo
00<007ooOol0CWoo0W`00goo00<07goo0n007P?P0P005@?P0Woo00<07gooOol0NWoo00<007ooOol0
0Goo0007Ool50003Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00L0n000`000n03h00E0n000goo
01moo`1lOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool3h0?P
01X3h08001P3h00301moogoo07aoo`03001oogoo005oo`002Goo00<007ooOol00goo0`00E7oo00=l
00?P0n006@?P00<000?P0n0060?P>Woo0P00@Goo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`1EOolL0n000`000n03h0020n02000C0n0YOol>O1l60012Ool00`00Oomoo`01Ool000Uoo`03001o
ogoo00=oo`03001oogoo05Eooa`3h0040003h0?P0n03000C0n0VOol<O1l;00000g`OOomoo`0oOol0
0`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo05Eooad3h0060003h0?P0003h0004`?P8Woo2g`O
2P000g`O0P001W`O?Goo00<007ooOol00Goo000?Ool00`00Oomoo`1EOolN0n0010000n03h00050?P
87oo27`O2P004G`O?7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOolM0n0010000n03h0004`?P
87oo17`O2P0067`O>Woo00<007ooOol00Goo000?Ool00`00Oomoo`1FOolN0n000`000n03h00C0n0N
Ool00g`O00000008000OO1lhOol00`00Oomoo`01Ool000moo`8005Qooah3h0030003h0?P0183h1Yo
o`X002El7cEoo`<000=oo`003goo00<007ooOol0Egoo7P?P00<000?P0n004P?P57oo2`00;7`O=Goo
00<007ooOol00Goo000?Ool00`00Oomoo`1GOolO0n000`000n03h00A0n0?Ool;000bO1ldOol00`00
Oomoo`01Ool000moo`03001oogoo05Qooal3h0030003h0?P00l3h0]oo`X000EoocAl7c=oo`03001o
ogoo005oo`003goo00<007ooOol0F7oo7`?P00<000?P0n003`?P1Woo2P002Goo=W`O<Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`1IOolO0n000`000n03h00>0n000goo00000008000=OolhO1laOol0
0`00Oomoo`01Ool000moo`03001oogoo05Uoob03h0030003h0?P00T3h0X0015oocYl7c1oo`03001o
ogoo005oo`003goo00<007ooOol0FGoo80?P00<000?P0n0010?P2P005Goo?7`O;goo00<007ooOol0
0Goo000?Ool2001KOolO0n0<00000`?POomoo`0FOolmO1l]Ool30003Ool000moo`03001oogoo05]o
oad3h0P000H3h1Moocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo70?P10000`?P00<0
00?P0n000`?P67oo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolM0n0200001@?P0003
h0?P000010?P67oo@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1MOolP0n000`000n000003
0n0IOom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05iooal3h0030003h0000083h1Uood=l
7baoo`03001oogoo005oo`003goo00<007ooOol0Ggoo6`?P00L000?P0n03h0000n00000IOom5O1l[
Ool00`00Oomoo`01Ool000moo`03001oogoo061ooa/3h0800083h08001UoodIl7bYoo`03001oogoo
005oo`003goo0P00I7oo6P?P100017oo0P004WooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolG
0n03Ool20005Ool00`00Oomoo`0@Oom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo06Mooa<3
h0aoo`03001oogoo011oodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0JWoo3@?P3Woo00<0
07oo00004GooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0COol01000Ool00000
3gooBG`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomoo`01Ool000mo
o`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo0P00VGooBW`O9Woo0`000goo000?Ool0
0`00Oomoo`2GOom;O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo
005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lW
Ool00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`0027oo0`0017oo
00<007ooOol0UWooCG`O9goo00<007ooOol00Goo0008Ool00`00Oomoo`04Ool00`00Oomoo`2FOom=
O1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<009IoobMl7`8002Al7bEoo`<000=oo`00
2Goo00<007ooOol00goo00<007ooOol0UWoo9g`O00<007`O00000`0087`O9goo00<007ooOol00Goo
0008Ool00`00Ool00004Ool00`00Oomoo`2FOolVO1l01000O1ml7g`O1`0077`O9goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2GOolUO1l00`00O1ml7`03O1l00`00O1ml7`02O1l4
0009O1l00`00O1ml7`0<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09MoobEl7`03001l7g`O
00=l7`03001l7g`O00Il7`@000Il7`03001l7g`O00]l7bMoo`03001oogoo005oo`003goo00<007oo
Ool0Ugoo9G`O00@007`OO1ml7`8000el7`@000=l7`8000]l7bMoo`03001oogoo005oo`003goo00<0
07ooOol0Ugoo97`O00<007`OO1l00W`O0`0047`O100000=l7`00O1l02G`O9goo00<007ooOol00Goo
000?Ool00`00Oomoo`2GOolTO1l00`00O1ml7`0HO1l40009O1lWOol00`00Oomoo`01Ool000moo`80
09QoobAl7`03001l7g`O01Al7`@000al7bIoo`<000=oo`003goo00<007ooOol0V7oo8g`O00<007`O
O1l07G`O0P0000=l7`00O1l00W`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOolRO1l00`00
O1ml7`0PO1l00`00O1ml7`02O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qoob9l7`03001l
7g`O01ml7`03001l7`00009l7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo8G`O00<007`O
O1l097`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolQO1l00`00O1ml7`0TO1lYOol00`00
Oomoo`01Ool000moo`03001oogoo09Uoob1l7`03001l7g`O02El7bUoo`03001oogoo005oo`003goo
0P00VWoo87`O00<007`OO1l097`O:7oo0`000goo000?Ool00`00Oomoo`2JOolOO1l00`00O1ml7`0T
O1lZOol00`00Oomoo`01Ool000moo`03001oogoo09Yooaml7`03001l7g`O02=l7b]oo`03001oogoo
005oo`003goo00<007ooOol0Vgoo7G`O00<007`OO1l08g`O;7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2LOolLO1l00`00O1ml7`0SO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09aooaal7`03
001l7g`O029l7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo6g`O00<007`OO1l08W`O;Goo
00<007ooOol00Goo000?Ool00`00Oomoo`2MOolGO1l01000O1ml7`0097`O;Woo00<007ooOol00Goo
000?Ool2002OOolFO1l01000O1ml7`000W`O00<007`OO1l07W`O;Goo0`000goo000?Ool00`00Oomo
o`2OOolFO1l01@00O1l007`O00008G`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2POolEO1l0
1000O1l000008G`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2QOolDO1l200000g`O001l7`0P
O1l`Ool00`00Oomoo`01Ool000moo`03001oogoo0:9ooaAl7`80025l7c5oo`03001oogoo005oo`00
3goo00<007ooOol0Xgoo4g`O00<007`OO1l00P007G`O<Woo00<007ooOol00Goo000?Ool00`00Oomo
o`2SOolGO1l00`00O1ml7`0JO1lcOol00`00Oomoo`01Ool000moo`03001oogoo0:EooaEl7`03001l
7g`O01Ql7cEoo`03001oogoo005oo`003goo0P00Ygoo4g`O00<007`O00005g`O=Goo0`000goo000?
Ool00`00Oomoo`2XOolAO1l01000O1l000005G`O>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2Z
OolVO1ljOol00`00Oomoo`01Ool000moo`03001oogoo0:]oob=l7caoo`03001oogoo005oo`003goo
00<007ooOol0[Goo87`O?Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`2_OolLO1l2000m
Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0;9ooaEl7`Ioo`8003]oo`03001o
ogoo005oo`002Goo00<007ooOol00goo0`00L7ooV`000goo000:Ool00`00Oomoo`02Ool00`00Oomo
o`2=OolW0ol00`000ol3o`0G0ol2000:0ol`Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03
001oogoo08eoobL3o`040003o`?o0ol3000A0ol200050ol200000`?o0003o`020ol`Ool00`00Oomo
o`01Ool000Uoo`03001oogoo00=oo`03001oogoo08eoobL3o`070003o`?o0ol000?o000040?o00<0
00?o0ol01`?o00<000?o0ol00P?o<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2=OolW0ol01000
0ol3o`?o0`006@?o00<000?o00000`?o<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2=OolW0ol0
1@000ol3o`?o00008@?o<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2=OolW0ol00`000ol3o`02
0ol2000O0ol`Ool00`00Oomoo`01Ool000moo`03001oogoo08eoobL3o`030003o`?o02<3oc1oo`03
001oogoo005oo`003goo0P00SWoo9`?o00<000?o0ol08`?o;Woo0`000goo000?Ool00`00Oomoo`2=
OolW0ol00`000ol3o`0S0ol`Ool00`00Oomoo`01Ool000moo`03001oogoo08eoobL3o`030003o`?o
02<3oc1oo`03001oogoo005oo`003goo00<007ooOol0SGoo9`?o00<000?o0ol08`?o<7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`2=OolW0ol00`000ol3o`0S0ol`Ool00`00Oomoo`01Ool000moo`03
001oogoo08eoobL3o`030003o`?o02<3oc1oo`03001oogoo005oo`003goo00<007ooOol0SGoo9`?o
00<000?o0ol08`?o<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2=OolW0ol00`000ol3o`0S0ol`
Ool00`00Oomoo`01Ool000moo`8008ioobL3o`030003o`?o02<3obioo`<000=oo`003goo00<007oo
Ool0]7oo00<007ooOol0Dgoo00<007ooOol00Goo000?Ool00`00Oomoo`2dOol00`00Oomoo`1COol0
0`00Oomoo`01Ool000moo`03001oogoo0;Aoo`03001oogoo05=oo`03001oogoo005oo`003goo00<0
07ooOol0]7oo00<007ooOol0Dgoo00<007ooOol00Goo000?Ool00`00Oomoo`2dOol00`00Oomoo`1C
Ool00`00Oomoo`01Ool000moo`03001oogoo0;Aoo`03001oogoo05=oo`03001oogoo005oo`003goo
00<007ooOol0]7oo00<007ooOol0Dgoo00<007ooOol00Goo000?Ool2002bOol01P00Oomoo`00Ool0
055oo`<000=oo`003goo00<007ooOol0/Woo00D007oo001oo`0005=oo`03001oogoo005oo`003goo
00<007ooOol0/Woo00@007oo000005Aoo`03001oogoo005oo`003goo00<007ooOol0/goo0`00E7oo
00<007ooOol00Goo000?Ool00`00Oomoo`2cOol2001EOol00`00Oomoo`01Ool000moo`03001oogoo
0;Aoo`04001oogooOol2001@Ool00`00Oomoo`01Ool000moo`03001oogoo0;Uoo`03001oogoo04io
o`03001oogoo005oo`003goo0P00^Woo00<007ooOol0C7oo0`000goo000?Ool00`00Oomoo`2hOol0
0`00Ool0001?Ool00`00Oomoo`01Ool000moo`03001oogoo0;Qoo`04001oo`00001>Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`<000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0008Ool40003Ool3003oOol9Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`]o
o`03001oogoo005oo`002Goo0P0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
005oo`002Woo00<007ooOol00Wooo`003`000goo0008Ool2003oOolGOol000Qoo`03001oogoo0?mo
oaIoo`0027oo0`00ogoo5Woo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.16466 .18081 -59.4524 -5.69807 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.24776 .30751 -59.4524 -5.69807 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -59.4524 -5.69807 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.16466 .18081 m
.14286 .28571 L
.24776 .30751 L
s
.14981 .19961 m
.16466 .18081 L
.17079 .20397 L
s
.2246 .31364 m
.24776 .30751 L
.22896 .29266 L
s
gsave
.16466 .18081 -59.4524 -5.69807 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.24776 .30751 -59.4524 -5.69807 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -59.4524 -5.69807 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.16466 .18081 m
.14286 .28571 L
.24776 .30751 L
s
.14981 .19961 m
.16466 .18081 L
.17079 .20397 L
s
.2246 .31364 m
.24776 .30751 L
.22896 .29266 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.81445 .71429 m
.81445 .77143 L
.52874 .77143 L
.52874 .71429 L
F
0 g
.01 w
.47472 .48309 m
.75634 .4349 L
s
.02 w
.47472 .48309 Mdot
.75634 .4349 Mdot
gsave
.51035 .35935 -58.7719 -4.89457 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.4978 .51035 -58.7719 -4.89457 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -58.7719 -4.89457 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.51035 .35935 m
.42857 .42857 L
.4978 .51035 L
s
.48707 .36501 m
.51035 .35935 L
.50092 .38137 L
s
.47577 .50092 m
.4978 .51035 L
.49213 .48707 L
s
gsave
.77874 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.6716 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.6716 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.77874 .71429 m
.6716 .71429 L
.6716 .82143 L
s
.75731 .70357 m
.77874 .71429 L
.75731 .725 L
s
.66088 .8 m
.6716 .82143 L
.68231 .8 L
s
gsave
.81668 .60297 -61.0162 -3.87492 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68274 .67382 -61.0162 -3.87492 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.0162 -3.87492 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81668 .60297 m
.71429 .57143 L
.68274 .67382 L
s
.79936 .58642 m
.81668 .60297 L
.79305 .6069 L
s
.67881 .65019 m
.68274 .67382 L
.69929 .6565 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
02Uoo`04001oogooOol200000goo001oo`0;Ool2O00=Ool00`0OOomoo`15Ool00`0OOomoo`1cOol0
0`00Oomoo`01Ool000moo`03001oogoo02Qoo`8000Eoo`03001oogoo00Uoo`9l00ioo`0301moogoo
04Moo`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol09goo00@007oo000000=oo`03
001oo`0000Moo`=l00moo`0301moogoo04Uoo`0301moogoo075oo`03001oogoo005oo`003goo00<0
07ooOol09goo0P0000=oo`00Ool02Woo0W`04Goo00<07gooOol0BWoo00<07gooOol0LGoo00<007oo
Ool00Goo000?Ool00`00Oomoo`0VOol01@00Ool007oo00002Goo0W`04goo00<07gooOol0Bgoo00<0
7gooOol0L7oo00<007ooOol00Goo000?Ool2000VOol01000Oomoo`000Woo00<007ooOol00goo0g`0
57oo00<07gooOol0C7oo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0XOol01000Oomoo`00
0goo0W`05goo00<07gooOol0CGoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0W
Ool00`00Oomoo`03Ool2O00HOol00`0OOomoo`1>Ool00`0OOomoo`1_Ool00`00Oomoo`01Ool000mo
o`03001oogoo02Moo`03001oogoo00=l01Yoo`0301moogoo04moo`0301moogoo06ioo`03001oogoo
005oo`003goo00<007ooOol09goo00<007`0O00077oo00<07gooOol0D7oo00<07gooOol0KWoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0VOol00g`0001oo`0MOol00`0OOomoo`1AOol00`0OOomoo`1]
Ool00`00Oomoo`01Ool000moo`03001oogoo02=oo`=l0003Ool007oo01eoo`0301moogoo055oo`03
01moogoo06eoo`03001oogoo005oo`003goo00<007ooOol08Goo0W`00goo00<007ooOol077oo00<0
7gooOol0Dgoo00<07gooOol0K7oo00<007ooOol00Goo000?Ool2000POol7O0000`00Oomoo`0LOol0
0`0OOomoo`1COol00`0OOomoo`1ZOol30003Ool000moo`03001oogoo01eoo`=l00Ioo`03001l07`0
01]oo`0301moogoo05Aoo`0301moogoo06aoo`03001oogoo005oo`003goo00<007ooOol077oo0W`0
27oo00<007ooOol00g`067oo00<07gooOol0EGoo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0JOol2O00:Ool00`00Oomoo`03Ool2O00EOol00`0OOomoo`1FOol00`0OOomoo`1[Ool0
0`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo00Uoo`03001oogoo00Ioo`03O01oogoo
019oo`0301moogoo05Moo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol067oo00=l
07ooOol02Woo00<007ooOol01goo00=l07ooOol04Goo00<07gooOol097oo2`0O:7oo00<07gooOol0
JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0;Ool00`00Oomoo`08Ool00g`0
Oomoo`0@Ool00`0OOomoo`0SOol>01lVOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001o
ogoo01Ioo`03O01oogoo00aoo`03001oogoo00Qoo`03O01oogoo00moo`0301moogoo02=ooa007bEo
o`0301moogoo06Yoo`03001oogoo005oo`003goo0P005goo00=l07ooOol02goo00<007ooOol02Woo
00=l07ooOol03Woo00<07gooOol08Woo4P0O9Goo00<07gooOol0Igoo0`000goo000?Ool00`00Oomo
o`0EOol00g`0Oomoo`0<Ool00`00Oomoo`0:Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROolC01lTOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo00aoo`03001oogoo
00]oo`03O01oogoo00eoo`0301moogoo025ooa@07bAoo`0301moogoo06Uoo`03001oogoo005oo`00
3goo00<007ooOol057oo00=l07ooOol03Goo00<007ooOol02goo00=l07ooOol03Goo00<07gooOol0
8Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`0=
Ool00`00Oomoo`0;Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03O01oogoo00aoo`03001oogoo00eo
o`03O01oogoo00aoo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo
00<007oo000017oo00<007ooOol057oo00=l07ooOol037oo00<007ooOol03Goo00=l07ooOol037oo
00<07gooOol087oo5P0O8goo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool3
000DOol00g`0Oomoo`0<Oom>000:01lSOol00`0OOomoo`1WOol30003Ool000Qoo`03001oo`0000Ao
o`03001oogoo01Aoo`03O01oogoo00moo`D000Qoo`03O01oogoo00aoo`0301moogoo021oo`/07`03
00007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo00<007oo
Ool057oo00=l07ooOol04Goo1`0017oo00=l07ooOol017oo00<007ooOol01Goo00<07gooOol087oo
2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool0
0`00Oomoo`0DOol00g`0Oomoo`0COol00`00Oomoo`02Ool50007Ool00`00Oomoo`04Ool00`0OOomo
o`0POol;01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01=oo`03001oogoo00Eoo`03O01oo`0000<000Aoo`8000Aoo`0301moogoo021o
o`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo
00=l07ooOol047oo0`001Woo00=l07ooOol017oo1@0000=oo`00Ool00Woo00@07goo0000021oo`X0
7`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l
07ooOol06Goo00=l07ooOol02Goo0`000Woo00@07gooOol0021oo`X07`0300007`0O00P07b=oo`03
01moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol0
1goo0`0017oo00@07gooOol0025oo`T07`0300007`0O00L07bAoo`0301moogoo06Uoo`03001oogoo
005oo`003goo0P005goo00=l07ooOol05goo00=l07ooOol01Woo0P001goo00D07goo001oo`00025o
o`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<007ooOol05goo00=l07oo
Ool05Woo00=l07ooOol047oo00<07`00Ool00P008Goo1`0O00<0000O01l01@0O9Goo00<07gooOol0
JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0EOol00g`0Oomoo`0AOol00`0O
Oomoo`0SOol701l00`0001l07`0301lWOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001o
ogoo01Qoo`03O01oogoo01=oo`03O01oogoo019oo`0301moogoo02Eoo`D07`0400007`0O01lYOol0
0`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo015oo`03O01oogoo
01=oo`0301moogoo02Moo`<07`0300007goo02Yoo`0301moogoo06Yoo`03001oogoo005oo`003goo
00<007ooOol06Woo0W`047oo00=l07ooOol057oo00<07gooOol097oo3@?P9Goo00<07gooOol0Jgoo
00<007ooOol00Goo000?Ool00`00Oomoo`0LOol3O00;Ool2O00HOol00`0OOomoo`0NOolE0n0ROol0
0`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo01moo`=l00Aoo`Al01Yoo`0301moogoo
01aooaT3h1moo`0301moogoo06aoo`03001oogoo005oo`003goo0P008Woo1G`07goo00<07gooOol0
6Woo7@?P77oo00<07gooOol0JWoo0`000goo000?Ool00`00Oomoo`0SOol2O00POol00`0OOomoo`0H
OolP0n0JOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02Eoo`=l01ioo`0301mo
ogoo01Ioob83h1Uoo`0301moogoo06eoo`03001oogoo005oo`003goo00<007ooOol0:7oo0W`077oo
00<07gooOol05Goo90?P5goo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol2
O00JOol00`0OOomoo`0COolW0n02Ool2000BOol00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03
001oogoo02aoo`9l01Uoo`0301moogoo019oobH3h0@000Aoo`800003Ool007oo00Uoo`0301moogoo
06moo`03001oogoo005oo`003goo00<007ooOol0;Woo0g`05goo00<07gooOol04Goo90?P0P000P?P
0P001Woo00<007ooOol02Goo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool2000bOol2O00EOol0
0`0OOomoo`0@OolW0n0300000`?POomoo`03Ool00`00Ool00009Ool00`0OOomoo`1^Ool30003Ool0
00moo`03001oogoo03=oo`9l01Aoo`0301moogoo00ioobL3h0050003h0?P0003h00AOol00`0OOomo
o`1`Ool00`00Oomoo`01Ool000moo`03001oogoo03Eoo`9l019oo`0301moogoo00eoobL3h0040003
h0?P00030n0?Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Moo`=l011oo`03
01moogoo00aoobH3h0050003h0?P0n0000040n0>Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000mo
o`03001oogoo03Yoo`9l00ioo`0301moogoo00]oobH3h0030003h0?P00P3h0aoo`0301moogoo079o
o`03001oogoo005oo`003goo00<007ooOol0?7oo0W`03Goo00<07gooOol02Woo9@?P00<000?P0n00
2@?P37oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0nOol2O00<Ool00`0OOomo
o`09OolT0n000`000n03h00;0n0:Ool00`0OOomoo`1cOol00`00Oomoo`01Ool000moo`03001oogoo
041oo`9l00]oo`0301moogoo00Moob<3h08000h3h0Uoo`0301moogoo07Aoo`03001oogoo005oo`00
3goo0P00@goo0g`027oo00<07gooOol01goo8P?P00<000?P0n003P?P27oo00<07gooOol0Lgoo0`00
0goo000?Ool00`00Oomoo`15Ool2O007Ool00`0OOomoo`05OolR0n000`000n03h00?0n08Ool00`0O
Oomoo`1eOol00`00Oomoo`01Ool000moo`03001oogoo04Moo`9l00Ioo`807`Eoob43h0030003h0?P
0103h0Ioo`807gQoo`03001oogoo005oo`003goo00<007ooOol0BGoo0W`01Woo00<07gooOol00Woo
80?P00<000?P0n004P?P17oo00<07gooOol0N7oo00<007ooOol00Goo000?Ool00`00Oomoo`1;Ool3
O004Ool00`0OOomoo`0P0n000`000n03h00C0n03Ool00`0OOomoo`1iOol00`00Oomoo`01Ool000mo
o`03001oogoo04ioo`9l00=oo`0301moo`?P01d3h08001H3h09oo`0301moogoo07Yoo`03001oogoo
005oo`001goo1@000goo00<007ooOol0D7oo0W`00Woo00<07`?P0n006`?P00<000?P0n005P?P00=o
o`0OOol0O7oo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1BOol2O0000goo0n03
h00J0n000`000n03h00G0n000`0OOomoo`1lOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<0
05Aoo`03O003h0?P01T3h0030003h0?P01P3h3eoo`03001oogoo03eoo`<000=oo`002Goo00<007oo
Ool00goo00<007ooOol0EGoo70?P00<000?P0n000P?P0P004`?P:Goo3g`O1P00@Goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolM0n000`000n03h003000C0n0VOol<O1l=0010
Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo05Eooah3h0050003h0000n00000C0n0ROol:
O1l<0003O1l40003O1lmOol00`00Oomoo`01Ool000moo`03001oogoo05Eooah3h0040003h0?P000D
0n0POol6O1l<000:O1l20005O1llOol00`00Oomoo`01Ool000moo`03001oogoo05Iooah3h0030003
h00001<3h21oo`03O1l0000000X001Ul7cYoo`03001oogoo005oo`003goo00<007ooOol0EWoo7`?P
00<000?P0n004P?P6goo30008G`O>7oo00<007ooOol00Goo000?Ool2001HOolO0n000`000n03h00A
0n0FOol;000XO1leOol30003Ool000moo`03001oogoo05Moob03h0030003h0?P0103h11oo`/0031l
7cEoo`03001oogoo005oo`003goo00<007ooOol0Egoo8@?P00<000?P0n003`?P2Woo30000goo<g`O
=7oo00<007ooOol00Goo000?Ool00`00Oomoo`1HOolQ0n000`000n03h00=0n05Ool<0009OoldO1lc
Ool00`00Oomoo`01Ool000moo`03001oogoo05Qoob43h0030003h0?P00`3h0`000ioocIl7c9oo`03
001oogoo005oo`003goo00<007ooOol0FGoo8@?P00<000?P0n001@?P30004goo>7`O<Goo00<007oo
Ool00Goo000?Ool00`00Oomoo`1IOolR0n000`000n00000:000HOoljO1l`Ool00`00Oomoo`01Ool0
00moo`03001oogoo05Uoob83h0L000D3h1Qoocal7bmoo`03001oogoo005oo`003goo0P00Fgoo80?P
10000`?P00<000?P0n000P?P67oo?G`O;Goo0`000goo000?Ool00`00Oomoo`1KOolO0n0500020n00
0`000n03h0020n0GOoloO1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aooal3h0800083h004
0003h0?P00020n0HOoloO1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aoob@3h0040003h000
0n0HOom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05eoob03h0060003h0?P0003h0006Goo
@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1NOolP0n0200000`?P0000000HOom3O1l/Ool0
0`00Oomoo`01Ool000moo`03001oogoo05moob43h0@000Aoo`80011oodEl7b]oo`03001oogoo005o
o`003goo00<007ooOol0H7oo7`?P0goo0P001Goo00<007ooOol03WooAW`O:Woo00<007ooOol00Goo
000?Ool2001TOolK0n0;Ool00`00Oomoo`0=Oom7O1lXOol30003Ool000moo`03001oogoo06EooaL3
h0aoo`03001oo`0000ioodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0Igoo4`?P3Woo00@0
07oo000000eoodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0JWoo3@?P8WooB7`O:Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9O1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<007ooOol00Goo
000?Ool2002IOom:O1lVOol30003Ool000moo`03001oogoo09Mood]l7bQoo`03001oogoo005oo`00
3goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00
Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo
C7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool0
00Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`002Goo00<007ooOol0
0goo0`00UWoo9g`O0P0097`O9Goo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2FOolWO1l0
0`00O1l00002000QO1lWOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo09IoobIl
7`04001l7g`OO1l5000NO1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo09Mo
obEl7`03001l7g`O00=l7`03001l7g`O00<001]l7bMoo`03001oogoo005oo`003goo00<007ooOol0
Ugoo9G`O00<007`OO1l00g`O00<007`OO1l00g`O0`002G`O00<007`OO1l037`O9goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2GOolTO1l00`00O1ml7`02O1l20009O1l30007O1l00`00O1ml7`0;O1lW
Ool00`00Oomoo`01Ool000moo`03001oogoo09MoobAl7`03001l7g`O009l7`<000]l7`<000El7`03
001l7g`O00Yl7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo97`O00<007`OO1l04g`O0`00
0W`O00<007`OO1l02W`O9goo00<007ooOol00Goo000?Ool2002HOolSO1l00`00O1ml7`0GO1l4000:
O1lVOol30003Ool000moo`03001oogoo09Qoob9l7`03001l7g`O01Ul7`<000Ul7bQoo`03001oogoo
005oo`003goo00<007ooOol0V7oo8W`O00<007`OO1l05G`O100037`O:7oo00<007ooOol00Goo000?
Ool00`00Oomoo`2HOolQO1l00`00O1ml7`0NO1l200000g`O001l7`02O1lYOol00`00Oomoo`01Ool0
00moo`03001oogoo09Uoob1l7`03001l7g`O021l7`03001l7g`O009l7bUoo`03001oogoo005oo`00
3goo00<007ooOol0VGoo87`O00<007`OO1l07g`O00<007`O00000g`O:Goo00<007ooOol00Goo000?
Ool00`00Oomoo`2IOolOO1l00`00O1ml7`0VO1lYOol00`00Oomoo`01Ool000moo`8009Yooaml7`03
001l7g`O02El7bQoo`<000=oo`003goo00<007ooOol0VWoo7W`O00<007`OO1l09G`O:Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`2JOolNO1l00`00O1ml7`0TO1l[Ool00`00Oomoo`01Ool000moo`03
001oogoo09]ooaal7`03001l7g`O02Al7baoo`03001oogoo005oo`003goo00<007ooOol0W7oo6g`O
00<007`OO1l097`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolKO1l00`00O1ml7`0SO1l]
Ool00`00Oomoo`01Ool000moo`03001oogoo09eooaIl7`04001l7g`O000VO1l]Ool00`00Oomoo`01
Ool000moo`03001oogoo09eooaIl7`04001l7g`O000UO1l^Ool00`00Oomoo`01Ool000moo`8009mo
oaEl7`04001l7g`O0002O1l00`00O1ml7`0OO1l]Ool30003Ool000moo`03001oogoo09mooaAl7`03
001l7`00009l7`03001l7g`O021l7bmoo`03001oogoo005oo`003goo00<007ooOol0X7oo57`O0P00
00=l7`00O1l08G`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2QOolCO1l3000SO1l`Ool00`00
Oomoo`01Ool000moo`03001oogoo0:9ooa9l7`8002=l7c5oo`03001oogoo005oo`003goo00<007oo
Ool0Xgoo4G`O00<007`OO1l00P007g`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2SOolEO1l0
0`00O1ml7`0LO1lcOol00`00Oomoo`01Ool000moo`03001oogoo0:Eooa=l7`03001l7g`O01Yl7cEo
o`03001oogoo005oo`003goo0P00Ygoo4G`O00<007`O00006G`O=Goo0`000goo000?Ool00`00Oomo
o`2XOol?O1l01000O1l000005g`O>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOolVO1ljOol0
0`00Oomoo`01Ool000moo`03001oogoo0:]oob=l7caoo`03001oogoo005oo`003goo00<007ooOol0
[Goo87`O?Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`2_OolIO1l200000g`OOomoo`0m
Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0;9ooaEl7`=oo`<003eoo`03001o
ogoo005oo`002Goo00<007ooOol00goo0`00L7ooV`000goo000:Ool00`00Oomoo`02Ool00`00Oomo
o`2;OolV0ol00`000ol3o`0H0ol2000:0olbOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03
001oogoo08]oobH3o`040003o`?o0ol3000B0ol200050ol200000`?o0003o`020olbOol00`00Oomo
o`01Ool000Uoo`03001oogoo00=oo`03001oogoo08]oobH3o`070003o`?o0ol000?o000040?o0P00
2@?o00<000?o0ol00P?o<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2;OolV0ol010000ol3o`?o
0`006P?o00<000?o00000`?o<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2;OolV0ol01@000ol3
o`?o00008P?o<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2;OolV0ol00`000ol3o`020ol2000P
0olbOol00`00Oomoo`01Ool000moo`03001oogoo08]oobH3o`030003o`?o02@3oc9oo`03001oogoo
005oo`003goo0P00S7oo9P?o00<000?o0ol090?o<7oo0`000goo000?Ool00`00Oomoo`2;OolV0ol0
0`000ol3o`0T0olbOol00`00Oomoo`01Ool000moo`03001oogoo08]oobH3o`030003o`?o02@3oc9o
o`03001oogoo005oo`003goo00<007ooOol0Rgoo9P?o00<000?o0ol090?o<Woo00<007ooOol00Goo
000?Ool00`00Oomoo`2;OolV0ol00`000ol3o`0T0olbOol00`00Oomoo`01Ool000moo`03001oogoo
08]oobH3o`030003o`?o02@3oc9oo`03001oogoo005oo`003goo00<007ooOol0Rgoo9P?o00<000?o
0ol090?o<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2;OolV0ol00`000ol3o`0T0olbOol00`00
Oomoo`01Ool000moo`8008aoobH3o`030003o`?o02@3oc1oo`<000=oo`003goo00<007ooOol0/Goo
00<007ooOol0EWoo00<007ooOol00Goo000?Ool00`00Oomoo`2aOol00`00Oomoo`1FOol00`00Oomo
o`01Ool000moo`03001oogoo0;5oo`03001oogoo05Ioo`03001oogoo005oo`003goo00<007ooOol0
/Goo00<007ooOol0EWoo00<007ooOol00Goo000?Ool00`00Oomoo`2aOol00`00Oomoo`1FOol00`00
Oomoo`01Ool000moo`03001oogoo0;5oo`03001oogoo05Ioo`03001oogoo005oo`003goo00<007oo
Ool0/Goo00<007ooOol0EWoo00<007ooOol00Goo000?Ool2002_Ool01000Oomoo`000Woo00<007oo
Ool0DGoo0`000goo000?Ool00`00Oomoo`2_Ool01@00Ool007oo0000EWoo00<007ooOol00Goo000?
Ool00`00Oomoo`2_Ool01@00Ool007oo0000EWoo00<007ooOol00Goo000?Ool00`00Oomoo`2`Ool3
001GOol00`00Oomoo`01Ool000moo`03001oogoo0;1oo`<005Moo`03001oogoo005oo`003goo00<0
07ooOol0/Goo00@007ooOomoo`8005=oo`03001oogoo005oo`003goo00<007ooOol0]Woo00<007oo
Ool0DGoo00<007ooOol00Goo000?Ool2002gOol00`00Oomoo`1?Ool30003Ool000moo`03001oogoo
0;Eoo`03001oo`00059oo`03001oogoo005oo`003goo00<007ooOol0]Goo00@007oo0000055oo`03
001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo0`000goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000Qoo`@000=oo`<00?moo`Uoo`<000=oo`0027oo00<007oo000017oo00<007ooOol0
ogoo2goo00<007ooOol00Goo0009Ool20004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yo
o`03001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:
Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo00<007oo000017oo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol00Goo000:Ool00`00Oomoo`02Oooo000?0003Ool000Qoo`800?mooaMoo`0027oo00<007oo
Ool0ogoo5Woo0008Ool3003oOolFOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.2344 .23004 -58.878 -4.69865 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.19853 .37726 -58.878 -4.69865 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -58.878 -4.69865 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.2344 .23004 m
.14286 .28571 L
.19853 .37726 L
s
.21053 .23202 m
.2344 .23004 L
.22166 .25033 L
s
.17824 .36452 m
.19853 .37726 L
.19655 .35338 L
s
gsave
.2344 .23004 -58.878 -4.69865 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.19853 .37726 -58.878 -4.69865 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -58.878 -4.69865 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.2344 .23004 m
.14286 .28571 L
.19853 .37726 L
s
.21053 .23202 m
.2344 .23004 L
.22166 .25033 L
s
.17824 .36452 m
.19853 .37726 L
.19655 .35338 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.8067 .71429 m
.8067 .77143 L
.52099 .77143 L
.52099 .71429 L
F
0 g
.01 w
.48077 .47733 m
.76368 .43738 L
s
.02 w
.48077 .47733 Mdot
.76368 .43738 Mdot
gsave
.5017 .35027 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.50688 .5017 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.5017 .35027 m
.42857 .42857 L
.50688 .5017 L
s
.47925 .35862 m
.5017 .35027 L
.49491 .37324 L
s
.4839 .49491 m
.50688 .5017 L
.49853 .47925 L
s
gsave
.77099 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66385 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66385 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.77099 .71429 m
.66385 .71429 L
.66385 .82143 L
s
.74956 .70357 m
.77099 .71429 L
.74956 .725 L
s
.65313 .8 m
.66385 .82143 L
.67456 .8 L
s
gsave
.81482 .60848 -61.2224 -3.84431 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67724 .67196 -61.2224 -3.84431 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.2224 -3.84431 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81482 .60848 m
.71429 .57143 L
.67724 .67196 L
s
.79842 .59101 m
.81482 .60848 L
.79101 .61112 L
s
.67459 .64815 m
.67724 .67196 L
.6947 .65556 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`04goo100027oo00<07gooOol0Dgoo00<0
7gooOol0JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00<Ool400000goo00000008Ool0
0`0OOomoo`1DOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l
00aoo`800003Ool007oo00=oo`800003Ool0000O05Moo`0301moogoo06]oo`03001oogoo005oo`00
3goo00<007ooOol06Woo0W`047oo0W`02Goo00@007ooOol000Moo`0300007goo05Moo`0301moogoo
06]oo`03001oogoo005oo`003goo00<007ooOol06Goo00=l07ooOol04Woo00=l07ooOol017oo0P00
0Woo00<007ooOol01Goo00<007oo0000FGoo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00
Oomoo`0HOol00g`0Oomoo`0DOol017`0Oomoogoo0P0017oo00<007ooOol01goo00<07gooOol097oo
2`0O:7oo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0FOol0
0g`0Ool00005Ool00`00Oomoo`08Ool00`0OOomoo`0SOol>01lVOol00`0OOomoo`1ZOol00`00Oomo
o`01Ool000moo`03001oogoo01Ioo`03O01oogoo01Moo`80011oo`0301moogoo02=ooa007bEoo`03
01moogoo06Yoo`03001oogoo005oo`003goo0P005goo00=l07ooOol05Goo0P0000=oog`0Ool03goo
00<07gooOol08Woo4P0O9Goo00<07gooOol0Igoo0`000goo000?Ool00`00Oomoo`0EOol00g`0Oomo
o`0EOol01@00OomoogooO00047oo00<07gooOol08Woo4`0O97oo00<07gooOol0JGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0COol20005Ool00g`0Oomoo`0=Ool00`0OOomoo`0Q
OolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oogoo019o
o`8000Moo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005o
o`003goo00<007ooOol057oo00=l07ooOol04Goo00<007ooOol01goo00=l07ooOol03Goo00<07goo
Ool08Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`0DOol00g`0Oomoo`0?Ool2000;Ool00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomo
o`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo00eoo`80
00eoo`03O01oogoo00aoo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`00
27oo00<007oo000017oo0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0Igoo0`000goo
0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0=Ool00`00Oomoo`0<Ool00g`0Oomo
o`0<Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo00eoo`04001oogooOol30008Ool00g`0
Oomoo`0<Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01
Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03O01oogoo00ioo`03001oogoo008000Qoo`03
O01oogoo00eoo`0301moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo
005oo`003goo00<007ooOol057oo00=l07ooOol03Woo00<007ooOol00Woo00<007ooOol01Goo00=l
07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0>Ool01@00Oomoogoo00001Woo00=l07ooOol03Woo
00<07gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0EOol00g`0Oomoo`0?Ool40006Ool00g`0Oomoo`0>Ool00`0OOomoo`0QOol:01l00`00
01l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo
00moo`03001oogoo00Moo`03O01oogoo00ioo`0301moogoo029oo`T07`0300007`0O00L07bAoo`03
01moogoo06Uoo`03001oogoo005oo`003goo0P005goo00=l07ooOol03goo00<007ooOol01Goo00=l
07ooOol03goo00<07gooOol08goo200O00<0000O01l01P0O97oo00<07gooOol0J7oo0`000goo000?
Ool00`00Oomoo`0GOol00g`0Oomoo`0>Ool00`00Oomoo`05Ool00g`0Oomoo`0@Ool00`0OOomoo`0S
Ool701l00`0001l07`0501lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Mo
o`03O01oogoo00moo`03001oogoo00=oo`03O01oogoo015oo`0301moogoo02=oo`L07`0300007`0O
00<07bMoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol067oo00=l07ooOol03goo
00D007ooOomoog`001Aoo`0301moogoo02Eoo`D07`0400007`0O01lYOol00`0OOomoo`1ZOol00`00
Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo00ioo`04001oogooO00EOol00`0OOomoo`0W
Ool301l00`0001moo`0ZOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Yoo`9l
00moo`03001l07oo01Eoo`0301moogoo02Aoo`d3h2Eoo`0301moogoo06]oo`03001oogoo005oo`00
3goo00<007ooOol077oo0g`02goo00=l0000Ool05goo00<07gooOol07Woo5@?P8Woo00<07gooOol0
Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0OOol3O004Ool4O002Ool00`00Oomoo`0EOol00`0O
Oomoo`0LOolI0n0OOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`80029oo`El00Moo`03001o
ogoo01Eoo`0301moogoo01Yooad3h1aoo`0301moogoo06Yoo`<000=oo`003goo00<007ooOol08goo
0W`027oo00<007ooOol05Goo00<07gooOol067oo80?P6Woo00<07gooOol0KGoo00<007ooOol00Goo
000?Ool00`00Oomoo`0UOol3O006Ool00`00Oomoo`0EOol00`0OOomoo`0FOolR0n02Ool2000EOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l00Aoo`05001oogooOol0000C
Ool00`0OOomoo`0EOolR0n050003Ool200000goo001oo`0<Ool00`0OOomoo`1^Ool00`00Oomoo`01
Ool000moo`03001oogoo02Yoo`9l00=oo`04001oogoo000COol00`0OOomoo`0COolR0n0200020n02
0006Ool00`00Oomoo`0<Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02aoo`9l
009oo`03001oo`0001Aoo`0301moogoo019oobD3h0040003h0000n04Ool00`00Ool0000<Ool00`0O
Oomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02eoo`06001l07`0001oo`005Goo00<07goo
Ool04Goo90?P00@000?P0n000083h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P00;goo
0P0000=oo`0000005Goo00<07gooOol047oo90?P00@000?P0n0000<3h15oo`0301moogoo06ioo`<0
00=oo`003goo00<007ooOol0<7oo0`000W`00Woo0P0047oo00<07gooOol03Woo90?P00D000?P0n03
h00000<3h15oo`0301moogoo071oo`03001oogoo005oo`003goo00<007ooOol0<Woo00<007ooOol0
0W`000=oo`00Ool03goo00<07gooOol03Goo90?P00<000?P0n001`?P3goo00<07gooOol0LGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0gOol00g`0001l000@Ool00`0OOomoo`0<OolS0n000`000n03
h0090n0>Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Moo`03001oo`00009l
00ioo`0301moogoo00]oob<3h0030003h0?P00/3h0aoo`0301moogoo079oo`03001oogoo005oo`00
3goo00<007ooOol0=goo00D007oo000007oo009l00eoo`0301moogoo00Yoob83h0030003h0?P00`3
h0aoo`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol0?Woo0W`037oo00<07gooOol0
2Goo8P?P00<000?P0n003@?P2Woo00<07gooOol0Lgoo00<007ooOol00Goo000?Ool00`00Oomoo`10
Ool2O00;Ool00`0OOomoo`07OolR0n000`000n03h00>0n09Ool00`0OOomoo`1dOol00`00Oomoo`01
Ool000moo`8004=oo`=l00Qoo`0301moogoo00Moob43h0030003h0?P00l3h0Qoo`0301moogoo07=o
o`<000=oo`003goo00<007ooOol0AGoo0W`01goo00<07gooOol01Goo8@?P00<000?P0n0040?P27oo
00<07gooOol0MGoo00<007ooOol00Goo000?Ool00`00Oomoo`17Ool2O006Ool201l5OolP0n000`00
0n03h00A0n06Ool201mhOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l00Ioo`0301moogoo
009ooal3h0030003h0?P01<3h0Aoo`0301moogoo07Qoo`03001oogoo005oo`003goo00<007ooOol0
Bgoo0g`017oo00<07gooOol07`?P00<000?P0n0050?P0goo00<07gooOol0NGoo00<007ooOol00Goo
000?Ool00`00Oomoo`1>Ool2O003Ool00`0OOol3h00M0n000`000n03h00E0n02Ool00`0OOomoo`1j
Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo051oo`9l009oo`0301l3h0?P01/3h0030003
h0?P01H3h003Ool07goo07aoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0DWoo
0W`000=oo`?P0n006P?P00<000?P0n005`?P00<07gooOol0O7oo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool3001DOol00g`00n03h00I0n000`000n03h00H0n1mOol30003Ool000Uoo`03001oogoo
00=oo`03001oogoo05Eooa`3h0030003h0?P0083h08001<3h2Uooa5l7`Aoo`8003moo`03001oogoo
005oo`002Goo00<007ooOol00goo00<007ooOol0EGoo7@?P00<000?P0n000`004`?P9Woo4g`O2000
?Woo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1EOolN0n001@000n0000?P00004`?P8Woo
47`O3`0000=l7gooOol0>goo00<007ooOol00Goo000?Ool00`00Oomoo`1EOolO0n000`000n00000D
0n0POol;O1l>0005O1l20003O1llOol00`00Oomoo`01Ool000moo`03001oogoo05Iooal3h08001<3
h21oo`El7`h001=l7cYoo`03001oogoo005oo`003goo00<007ooOol0EWoo8@?P00<000?P0n0040?P
7Woo3P0077`O>7oo00<007ooOol00Goo000?Ool2001HOolQ0n000`000n03h00?0n0GOol>000TO1le
Ool30003Ool000moo`03001oogoo05Moob83h0030003h0?P00h3h11oo`h002el7cEoo`03001oogoo
005oo`003goo00<007ooOol0Egoo8`?P00<000?P0n003@?P2Goo3P000Woo<g`O=7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`1HOolS0n000`000n03h00;0n03Ool>0009OoldO1lcOol00`00Oomoo`01
Ool000moo`03001oogoo05Qoob@3h0030003h0?P00H3h0h000moocIl7c9oo`03001oogoo005oo`00
3goo00<007ooOol0FGoo90?P3`005Goo>7`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`1IOolS
0n0900030n0HOoljO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo05Uoob<3h0D00083h0040003
h0?P0n0HOollO1l_Ool00`00Oomoo`01Ool000moo`8005]oob<3h0800083h0050003h0?P0003h00H
OolmO1l]Ool30003Ool000moo`03001oogoo05]oobL3h0040003h0000n0GOoloO1l^Ool00`00Oomo
o`01Ool000moo`03001oogoo05aoobL3h08001Qoocml7bioo`03001oogoo005oo`003goo00<007oo
Ool0G7oo8`?P0`000P?P0P0017oo0P0047oo@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1M
OolU0n040005Ool00`00Oomoo`0>Oom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05ioob@3
h0Uoo`03001oogoo00eood=l7baoo`03001oogoo005oo`003goo00<007ooOol0Ggoo8P?P2Goo00<0
07oo00003GooAG`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`1POolO0n0;Ool01000Ool00000
37ooAW`O:Woo00<007ooOol00Goo000?Ool2001TOolK0n0KOom7O1lXOol30003Ool000moo`03001o
ogoo06EooaL3h1eoodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0Igoo4`?P7gooB7`O:Goo
00<007ooOol00Goo000?Ool00`00Oomoo`1ZOol=0n0ROom8O1lYOol00`00Oomoo`01Ool000moo`03
001oogoo06moo`<3h2IoodUl7bUoo`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomoo`01Ool000moo`8009UoodYl7bIo
o`<000=oo`003goo00<007ooOol0UgooBg`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<
O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<0
07ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01
Ool000Qoo`<000Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`0027oo00<007ooOol017oo
00<007ooOol0UWooCG`O9goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3002FOolWO1l2000T
O1lUOol30003Ool000Uoo`03001oogoo00=oo`03001oogoo09IoobMl7`03001l7`000080025l7bMo
o`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol0UWoo9W`O00@007`OO1ml7`@001ml
7bMoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Ugoo9G`O00<007`OO1l00g`O
00<007`O00000P0077`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolUO1l00`00O1ml7`03
O1l00`00O1ml7`02O1l3000IO1lWOol00`00Oomoo`01Ool000moo`03001oogoo09MoobAl7`03001l
7g`O009l7`8000Ql7`8000Ml7`03001l7g`O00el7bMoo`03001oogoo005oo`003goo00<007ooOol0
Ugoo97`O00<007`OO1l00W`O0`002G`O0`001G`O00<007`OO1l037`O9goo00<007ooOol00Goo000?
Ool00`00Oomoo`2GOolSO1l00`00O1ml7`0BO1l30003O1l00`00O1ml7`0;O1lWOol00`00Oomoo`01
Ool000moo`8009Qoob=l7`03001l7g`O01El7`80009l7`03001l7g`O00Ul7bIoo`<000=oo`003goo
00<007ooOol0V7oo8W`O00<007`OO1l05g`O10002W`O:7oo00<007ooOol00Goo000?Ool00`00Oomo
o`2HOolQO1l00`00O1ml7`0IO1l40009O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qoob5l
7`03001l7g`O01El7`@000al7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo87`O00<007`O
O1l07W`O0P0000=l7`00O1l00W`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolOO1l00`00
O1ml7`0QO1l00`00O1ml7`02O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09Uooaml7`03001l
7g`O021l7`03001l7`0000=l7bUoo`03001oogoo005oo`003goo0P00VWoo7W`O00<007`OO1l09W`O
:7oo0`000goo000?Ool00`00Oomoo`2JOolMO1l00`00O1ml7`0VO1lZOol00`00Oomoo`01Ool000mo
o`03001oogoo09Yooael7`03001l7g`O02El7b]oo`03001oogoo005oo`003goo00<007ooOol0Vgoo
6g`O00<007`OO1l09G`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolJO1l00`00O1ml7`0U
O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09aooaYl7`03001l7g`O02Al7beoo`03001oogoo
005oo`003goo00<007ooOol0WGoo5G`O00@007`OO1l002Ml7beoo`03001oogoo005oo`003goo00<0
07ooOol0WGoo5G`O00@007`OO1l002Il7bioo`03001oogoo005oo`003goo0P00Wgoo57`O00<007`O
00000W`O00<007`OO1l08G`O;Goo0`000goo000?Ool00`00Oomoo`2OOolCO1l01@00O1l007`O0000
97`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2POolCO1l3000TO1l`Ool00`00Oomoo`01Ool0
00moo`03001oogoo0:5ooa9l7`8002El7c1oo`03001oogoo005oo`003goo00<007ooOol0XWoo4G`O
00<007`OO1l00P008G`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`2SOolDO1l00`00O1ml7`0N
O1lbOol00`00Oomoo`01Ool000moo`03001oogoo0:=ooaAl7`03001l7g`O01el7c=oo`03001oogoo
005oo`003goo00<007ooOol0YGoo4G`O00<007`O000077`O=Goo00<007ooOol00Goo000?Ool2002W
Ool@O1l01000O1l000006G`O=Goo0`000goo000?Ool00`00Oomoo`2XOolZO1lhOol00`00Oomoo`01
Ool000moo`03001oogoo0:YoobIl7cYoo`03001oogoo005oo`003goo00<007ooOol0Zgoo8g`O?7oo
00<007ooOol00Goo000?Ool00`00Oomoo`2]OolPO1lmOol00`00Oomoo`01Ool000Qoo`8000Eoo`03
001oogoo0:mooaMl7`8000=l7cmoo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0
/Woo5G`O00Aoo`00000003moo`03001oogoo005oo`002Goo00<007ooOol00goo0`00L7ooV`000goo
000:Ool00`00Oomoo`02Ool00`00Oomoo`29OolV0ol00`000ol3o`0H0ol2000:0oldOol00`00Oomo
o`01Ool000Qoo`03001oo`0000Aoo`03001oogoo08UoobH3o`040003o`?o0ol3000B0ol200050ol2
00000`?o0003o`020oldOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo08UoobH3
o`070003o`?o0ol000?o000040?o0P002@?o00<000?o0ol00P?o=7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`29OolV0ol010000ol3o`?o0`006P?o00<000?o00000`?o=7oo00<007ooOol00Goo000?
Ool00`00Oomoo`29OolV0ol01@000ol3o`?o00008P?o=7oo00<007ooOol00Goo000?Ool00`00Oomo
o`29OolV0ol00`000ol3o`020ol2000P0oldOol00`00Oomoo`01Ool000moo`03001oogoo08UoobH3
o`030003o`?o02@3ocAoo`03001oogoo005oo`003goo0P00RWoo9P?o00<000?o0ol090?o<Woo0`00
0goo000?Ool00`00Oomoo`29OolV0ol00`000ol3o`0T0oldOol00`00Oomoo`01Ool000moo`03001o
ogoo08UoobH3o`030003o`?o02@3ocAoo`03001oogoo005oo`003goo00<007ooOol0RGoo9P?o00<0
00?o0ol090?o=7oo00<007ooOol00Goo000?Ool00`00Oomoo`29OolV0ol00`000ol3o`0T0oldOol0
0`00Oomoo`01Ool000moo`03001oogoo08UoobH3o`030003o`?o02@3ocAoo`03001oogoo005oo`00
3goo00<007ooOol0RGoo9P?o00<000?o0ol090?o=7oo00<007ooOol00Goo000?Ool00`00Oomoo`29
OolV0ol00`000ol3o`0T0oldOol00`00Oomoo`01Ool000moo`8008YoobH3o`030003o`?o02@3oc9o
o`<000=oo`003goo00<007ooOol0[goo00<007ooOol0F7oo00<007ooOol00Goo000?Ool00`00Oomo
o`2_Ool00`00Oomoo`1HOol00`00Oomoo`01Ool000moo`03001oogoo0:moo`03001oogoo05Qoo`03
001oogoo005oo`003goo00<007ooOol0[goo00<007ooOol0F7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2_Ool00`00Oomoo`1HOol00`00Oomoo`01Ool000moo`03001oogoo0:moo`03001oogoo05Qo
o`03001oogoo005oo`003goo00<007ooOol0[goo00<007ooOol0F7oo00<007ooOol00Goo000?Ool2
002]Ool01000Oomoo`000Woo00<007ooOol0Dgoo0`000goo000?Ool00`00Oomoo`2]Ool01@00Ool0
07oo0000F7oo00<007ooOol00Goo000?Ool00`00Oomoo`2]Ool01@00Ool007oo0000F7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`2^Ool3001IOol00`00Oomoo`01Ool000moo`03001oogoo0:ioo`<0
05Uoo`03001oogoo005oo`003goo00<007ooOol0[goo00@007ooOomoo`8005Eoo`03001oogoo005o
o`003goo00<007ooOol0]7oo00<007ooOol0Dgoo00<007ooOol00Goo000?Ool2002eOol00`00Oomo
o`1AOol30003Ool000moo`03001oogoo0;=oo`03001oo`0005Aoo`03001oogoo005oo`003goo00<0
07ooOol0/goo00@007oo000005=oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007oo
Ool00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03
001oogoo005oo`002Goo0`000goo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00Oomo
o`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`@000=oo`<00?moo`Uoo`<000=oo`00
27oo00<007oo000017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool20004Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<0
00=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:
Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo0?moo`]oo`03001oogoo
005oo`0027oo00<007oo000017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol00Goo000:Ool00`00Oomoo`02Oooo000?0003Ool0
00Qoo`800?mooaMoo`0027oo00<007ooOol0ogoo5Woo0008Ool3003oOolFOol00?moob5oo`00ogoo
8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.24603 .31462 -60.9206 -3.89056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.11395 .38888 -60.9206 -3.89056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60.9206 -3.89056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.24603 .31462 m
.14286 .28571 L
.11395 .38888 L
s
.22828 .29852 m
.24603 .31462 L
.2225 .31916 L
s
.10941 .36536 m
.11395 .38888 L
.13005 .37114 L
s
gsave
.24603 .31462 -60.9206 -3.89056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.11395 .38888 -60.9206 -3.89056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60.9206 -3.89056 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.24603 .31462 m
.14286 .28571 L
.11395 .38888 L
s
.22828 .29852 m
.24603 .31462 L
.2225 .31916 L
s
.10941 .36536 m
.11395 .38888 L
.13005 .37114 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.79975 .71429 m
.79975 .77143 L
.51404 .77143 L
.51404 .71429 L
F
0 g
.01 w
.48611 .47089 m
.77014 .43994 L
s
.02 w
.48611 .47089 Mdot
.77014 .43994 Mdot
gsave
.49205 .34226 -58.8058 -5.19175 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.51488 .49205 -58.8058 -5.19175 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -58.8058 -5.19175 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.49205 .34226 m
.42857 .42857 L
.51488 .49205 L
s
.47073 .35317 m
.49205 .34226 L
.48799 .36587 L
s
.49127 .48799 m
.51488 .49205 L
.50397 .47073 L
s
gsave
.76404 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.6569 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.6569 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.76404 .71429 m
.6569 .71429 L
.6569 .82143 L
s
.74261 .70357 m
.76404 .71429 L
.74261 .725 L
s
.64618 .8 m
.6569 .82143 L
.66761 .8 L
s
gsave
.8129 .61332 -61.4119 -3.81974 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67239 .67004 -61.4119 -3.81974 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.4119 -3.81974 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.8129 .61332 m
.71429 .57143 L
.67239 .67004 L
s
.79737 .59508 m
.8129 .61332 L
.78899 .61481 L
s
.67091 .64613 m
.67239 .67004 L
.69063 .65451 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol06goo00=l07ooOol03Goo00<07gooOol0
8Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool00g`0Oomoo`0LOol00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo01aoo`03O01oogoo00ao
o`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo
0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool00004
Ool00`00Oomoo`0DOol00g`0Oomoo`0<Ool00`00Ool00003000:Ool00g`0Oomoo`0<Ool00`0OOomo
o`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`00
00Aoo`03001oogoo01Aoo`03O01oogoo00]oo`04001oogooOol60007Ool00g`0Oomoo`0<Ool00`0O
Oomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001o
ogoo00=oo`03001oogoo01Aoo`03O01oogoo00]oo`04001oogooOol20004Ool40002Ool00g`0Oomo
o`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00moo`03001oogoo01Aoo`03O01oogoo00]oo`03001oogoo00=oo`03001oogoo00Eoo`<000Moo`03
001oogoo00Eoo`0301moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo
005oo`003goo00<007ooOol05Goo00=l07ooOol02Woo00<007ooOol00goo00<007ooOol01Woo00=l
07oo00000`0017oo00<007ooOol017oo00<07gooOol08Goo2P0O00<0000O01l0200O8goo00<07goo
Ool0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`09Ool00`00Oomoo`02Ool3
0008Ool00g`0Oomoo`03Ool30002Ool20004Ool00`0OOomoo`0QOol:01l00`0001l07`0801lSOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo00Uoo`03001oogoo
00eoo`03O01oogoo00Ioo`D000=oo`0301moogoo029oo`T07`0300007`0O00L07bAoo`0301moogoo
06Uoo`03001oogoo005oo`003goo0P005goo00=l07ooOol027oo00<007ooOol037oo00=l07ooOol0
2Woo0`000Woo00<07gooOol08goo200O00<0000O01l01P0O97oo00<07gooOol0J7oo0`000goo000?
Ool00`00Oomoo`0GOol00g`0Oomoo`06Ool00`00Oomoo`0=Ool00g`0Oomoo`06Ool40006Ool00`0O
Oomoo`0SOol701l00`0001l07`0501lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001o
ogoo01Moo`03O01oogoo00Ioo`03001oogoo00aoo`03O01oogoo00moo`80000301l007oo02=oo`L0
7`0300007`0O00<07bMoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol067oo00=l
07ooOol01Goo00<007ooOol02goo00=l07ooOol04Woo00<007ooOol09Goo1@0O00@0000O01l07bUo
o`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol06Goo00=l07ooOol017oo00<007oo
Ool02Woo00=l07ooOol04Woo00<0000O0000:7oo0`0O00<0000OOol0:Woo00<07gooOol0JWoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0JOol2O003Ool00`00Oomoo`0:Ool00g`0Oomoo`0DOol00`0O
Oomoo`0TOol=0n0UOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`=l0003
001oogoo00Qoo`9l01Qoo`0301moogoo01iooaD3h29oo`0301moogoo06]oo`03001oogoo005oo`00
3goo00<007ooOol07goo00<007`0O00017oo17`06Woo00<07gooOol077oo6@?P7goo00<07gooOol0
K7oo00<007ooOol00Goo000?Ool2000OOol00`00Oomoo`05O00OOol00`0OOomoo`0JOolM0n000goo
00000003Ool200000goo001oo`0AOol00`0OOomoo`1ZOol30003Ool000moo`03001oogoo01ioo`03
001oogoo009oo`9l021oo`0301moogoo01Qooad3h0D000Eoo`03001oogoo011oo`0301moogoo06eo
o`03001oogoo005oo`003goo00<007ooOol07Woo00<007ooOol017oo0g`07Woo00<07gooOol05Woo
70?P0P000`?P0P0017oo00<007oo00004Goo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00
Oomoo`0NOol00`00Oomoo`07Ool2O00LOol00`0OOomoo`0EOolQ0n0200000`?POomoo`0EOol00`0O
Oomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo01eoo`03001oogoo00Yoo`9l01Yoo`0301mo
ogoo01=oob83h0030003h0000083h1Ioo`0301moogoo06ioo`03001oogoo005oo`003goo00<007oo
Ool07Goo00<007ooOol037oo0W`06Goo00<07gooOol04Woo8@?P00@000?P0n0000@3h1=oo`0301mo
ogoo06moo`03001oogoo005oo`003goo00<007ooOol06Woo00@007ooOol0011oo`=l01Moo`0301mo
ogoo015oob43h0040003h0?P00050n0BOol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`8001]o
o`03001oo`0000=oo`03001oogoo00ioo`9l01Eoo`0301moogoo011oob43h0030003h0?P00L3h15o
o`0301moogoo06ioo`<000=oo`003goo00<007ooOol06Woo00<007oo00000Woo00<007ooOol04Goo
0W`057oo00<07gooOol03Woo8@?P00<000?P0n0020?P4Goo00<07gooOol0L7oo00<007ooOol00Goo
000?Ool00`00Oomoo`0JOol01@00Ool007oo00005Woo0W`04Woo00<07gooOol03Goo8@?P00<000?P
0n002P?P3goo00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0KOol3000IOol3O00@
Ool00`0OOomoo`0<OolQ0n000`000n03h00;0n0>Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000mo
o`03001oogoo01]oo`8001eoo`9l00ioo`0301moogoo00]oob43h0030003h0?P00d3h0aoo`0301mo
ogoo079oo`03001oogoo005oo`003goo00<007ooOol06goo00@007ooOomoo`8001]oo`9l00eoo`03
01moogoo00Yoob03h0030003h0?P00h3h0aoo`0301moogoo079oo`03001oogoo005oo`003goo00<0
07ooOol087oo00<007ooOol06goo0W`037oo00<07gooOol02Goo7`?P00<000?P0n0040?P2Woo00<0
7gooOol0Lgoo00<007ooOol00Goo000?Ool00`00Oomoo`0POol00`00Oomoo`0MOol2O00;Ool00`0O
Oomoo`07OolP0n000`000n03h00@0n09Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`80021o
o`03001oo`00021oo`=l00Qoo`0301moogoo00Mooal3h0030003h0?P0143h0Qoo`0301moogoo07=o
o`<000=oo`003goo00<007ooOol07goo00@007oo0000029oo`9l00Moo`0301moogoo00Eooal3h003
0003h0?P0183h0Qoo`0301moogoo07Eoo`03001oogoo005oo`003goo00<007ooOol0Agoo0W`01Woo
0P0O1Goo7P?P00<000?P0n004`?P1Woo0P0ON7oo00<007ooOol00Goo000?Ool00`00Oomoo`19Ool2
O006Ool00`0OOomoo`02OolN0n000`000n03h00D0n04Ool00`0OOomoo`1hOol00`00Oomoo`01Ool0
00moo`03001oogoo04]oo`=l00Aoo`0301moogoo01h3h0030003h0?P01D3h0=oo`0301moogoo07Uo
o`03001oogoo005oo`003goo00<007ooOol0CWoo0W`00goo00<07goo0n0070?P00<000?P0n005P?P
0Woo00<07gooOol0NWoo00<007ooOol00Goo0007Ool50003Ool00`00Oomoo`1@Ool2O002Ool00`0O
0n03h00J0n000`000n03h00G0n000goo01moo`1lOol00`00Oomoo`01Ool000Uoo`03001oogoo00=o
o`03001oogoo059oo`9l0003Ool3h0?P01X3h0030003h0?P01L3h00301moogoo07aoo`03001oogoo
005oo`002Goo00<007ooOol00goo0`00E7oo00=l00?P0n006@?P00<000?P0n0060?POGoo0`000goo
0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolL0n0200030n02000C0n0YOolAO1m5Ool00`00Oomo
o`01Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooah3h0030003h000008001<3h2IooaQl7`9o
o`8003eoo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0EGoo7`?P0P0000<3h0000n004P?P
8Woo5W`O2`00?7oo00<007ooOol00Goo000?Ool00`00Oomoo`1EOolP0n02000D0n0POol>O1lE000l
Ool00`00Oomoo`01Ool000moo`03001oogoo05Ioob03h0800183h21oo`Il7a<000Ql7`8000=l7cYo
o`03001oogoo005oo`003goo00<007ooOol0EWoo8P?P00<000?P0n003`?P77oo4`006G`O>7oo00<0
07ooOol00Goo000?Ool2001HOolR0n02000?0n0BOolD000SO1leOol30003Ool000moo`03001oogoo
05Moob@3h0030003h0?P00`3h0Uooa<002ml7cEoo`03001oogoo005oo`003goo00<007ooOol0Egoo
9@?P00<000?P0n002P?P4`001goo<g`O=7oo00<007ooOol00Goo000?Ool00`00Oomoo`1HOolU0n0F
000@OoldO1lcOol00`00Oomoo`01Ool000moo`03001oogoo05QoobD3h0`001UoocIl7c9oo`03001o
ogoo005oo`003goo00<007ooOol0FGoo90?P10000`?P00<000?P0n000P?P67oo>7`O<Goo00<007oo
Ool00Goo000?Ool00`00Oomoo`1IOolU0n0200000`?P000000020n000`000n03h00HOoljO1l`Ool0
0`00Oomoo`01Ool000moo`03001oogoo05UoobX3h0040003h0000n0HOollO1l_Ool00`00Oomoo`01
Ool000moo`8005]oobX3h0030003h00001Moocel7beoo`<000=oo`003goo00<007ooOol0Fgoo9P?P
0`0000<3h00000001Goo0P003goo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n04
0005Ool00`00Oomoo`0=OoloO1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aoobP3h0Uoo`03
001oogoo00aood9l7baoo`03001oogoo005oo`003goo00<007ooOol0GGoo9P?P2Goo00<007oo0000
3Goo@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1NOolT0n0:Ool01000Ool000002goo@g`O
;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR0n0IOom5O1l[Ool00`00Oomoo`01Ool000mo
o`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo005oo`003goo0P00I7oo6`?P6gooAg`O:7oo
0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo
06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0JWoo3@?P8WooB7`O:Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9O1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<007ooOol00Goo
000?Ool2002IOom:O1lVOol30003Ool000moo`03001oogoo09Mood]l7bQoo`03001oogoo005oo`00
3goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00
Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo
C7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool0
00Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`002Goo00<007ooOol0
0goo0`00UWoo9g`O0P0097`O9Goo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2FOolWO1l0
1000O1l000008W`O9goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2FOolVO1l0
0`00O1ml7`04000PO1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo09MoobEl
7`03001l7g`O009l7`03001l7`00008001el7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo
97`O00<007`OO1l00g`O00<007`OO1l00W`O0P006g`O9goo00<007ooOol00Goo000?Ool00`00Oomo
o`2GOolTO1l01000O1ml7g`O0P001g`O0P006G`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2G
OolSO1l00`00O1ml7`02O1l30008O1l30006O1l00`00O1ml7`0=O1lWOol00`00Oomoo`01Ool000mo
o`03001oogoo09Moob=l7`03001l7g`O011l7`8000El7`03001l7g`O00al7bMoo`03001oogoo005o
o`003goo0P00V7oo8W`O00<007`OO1l04g`O0`000g`O00<007`OO1l02W`O9Woo0`000goo000?Ool0
0`00Oomoo`2HOolQO1l00`00O1ml7`0FO1l200000g`O001l7`0;O1lXOol00`00Oomoo`01Ool000mo
o`03001oogoo09Qoob5l7`03001l7g`O01Ql7`<000]l7bQoo`03001oogoo005oo`003goo00<007oo
Ool0V7oo87`O00<007`OO1l06W`O0`002G`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolO
O1l00`00O1ml7`0FO1l4000<O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09Uooail7`03001l
7g`O02Ml7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo7W`O00<007`OO1l07g`O0P0000=l
7`00O1l00g`O:Goo00<007ooOol00Goo000?Ool2002JOolMO1l00`00O1ml7`0RO1l00`00O1ml7`02
O1lXOol30003Ool000moo`03001oogoo09Yooaal7`03001l7g`O025l7`03001l7`0000=l7bYoo`03
001oogoo005oo`003goo00<007ooOol0VWoo6g`O00<007`OO1l09g`O:goo00<007ooOol00Goo000?
Ool00`00Oomoo`2KOolJO1l00`00O1ml7`0VO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09ao
oaUl7`03001l7g`O02Il7baoo`03001oogoo005oo`003goo00<007ooOol0W7oo5G`O00@007`OO1l0
02Ql7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo57`O00@007`OO1l002Ql7beoo`03001o
ogoo005oo`003goo00<007ooOol0WGoo57`O00<007`O00000W`O00<007`OO1l08g`O;Woo00<007oo
Ool00Goo000?Ool2002OOolCO1l01@00O1l007`O00009G`O;Goo0`000goo000?Ool00`00Oomoo`2O
OolBO1l200000g`O001l7`0UO1l_Ool00`00Oomoo`01Ool000moo`03001oogoo0:1ooa5l7`<002Il
7c1oo`03001oogoo005oo`003goo00<007ooOol0XGoo47`O0P009g`O<7oo00<007ooOol00Goo000?
Ool00`00Oomoo`2ROol?O1l00`00O1ml7`02000SO1laOol00`00Oomoo`01Ool000moo`03001oogoo
0:=ooa9l7`03001l7g`O021l7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo4W`O00<007`O
O1l07g`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOol?O1l00`00O1l0000NO1leOol00`00
Oomoo`01Ool000moo`800:Moo`il7`04001l7`00000KO1leOol30003Ool000moo`03001oogoo0:Qo
obYl7cQoo`03001oogoo005oo`003goo00<007ooOol0ZWoo9W`O>Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`2[OolSO1llOol00`00Oomoo`01Ool000moo`03001oogoo0:eoob1l7ceoo`03001oogoo
005oo`0027oo0P001Goo00<007ooOol0[goo5G`O0P001G`O?goo00<007ooOol00Goo000:Ool00`00
Oomoo`02Ool00`00Oomoo`2bOolDO1l30011Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<0
071ooi/000=oo`002Woo00<007ooOol00Woo00<007ooOol0Qgoo9P?o00<000?o0ol060?o0P002P?o
=Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`27OolV0ol010000ol3o`?o0`00
4P?o0P001@?o0P0000<3o`000ol00P?o=Woo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00
Oomoo`27OolV0ol01`000ol3o`?o0003o`000103o`8000T3o`030003o`?o0083ocIoo`03001oogoo
005oo`003goo00<007ooOol0Qgoo9P?o00@000?o0ol3o`<001X3o`030003o`0000<3ocIoo`03001o
ogoo005oo`003goo00<007ooOol0Qgoo9P?o00D000?o0ol3o`000283ocIoo`03001oogoo005oo`00
3goo00<007ooOol0Qgoo9P?o00<000?o0ol00P?o0P0080?o=Woo00<007ooOol00Goo000?Ool00`00
Oomoo`27OolV0ol00`000ol3o`0T0olfOol00`00Oomoo`01Ool000moo`8008QoobH3o`030003o`?o
02@3ocAoo`<000=oo`003goo00<007ooOol0Qgoo9P?o00<000?o0ol090?o=Woo00<007ooOol00Goo
000?Ool00`00Oomoo`27OolV0ol00`000ol3o`0T0olfOol00`00Oomoo`01Ool000moo`03001oogoo
08MoobH3o`030003o`?o02@3ocIoo`03001oogoo005oo`003goo00<007ooOol0Qgoo9P?o00<000?o
0ol090?o=Woo00<007ooOol00Goo000?Ool00`00Oomoo`27OolV0ol00`000ol3o`0T0olfOol00`00
Oomoo`01Ool000moo`03001oogoo08MoobH3o`030003o`?o02@3ocIoo`03001oogoo005oo`003goo
00<007ooOol0Qgoo9P?o00<000?o0ol090?o=Woo00<007ooOol00Goo000?Ool20028OolV0ol00`00
0ol3o`0T0oldOol30003Ool000moo`03001oogoo0:eoo`03001oogoo05Yoo`03001oogoo005oo`00
3goo00<007ooOol0[Goo00<007ooOol0FWoo00<007ooOol00Goo000?Ool00`00Oomoo`2]Ool00`00
Oomoo`1JOol00`00Oomoo`01Ool000moo`03001oogoo0:eoo`03001oogoo05Yoo`03001oogoo005o
o`003goo00<007ooOol0[Goo00<007ooOol0FWoo00<007ooOol00Goo000?Ool00`00Oomoo`2]Ool0
0`00Oomoo`1JOol00`00Oomoo`01Ool000moo`03001oogoo0:eoo`03001oogoo05Yoo`03001oogoo
005oo`003goo0P00Zgoo00@007ooOol0009oo`03001oogoo05Eoo`<000=oo`003goo00<007ooOol0
Zgoo00D007oo001oo`0005Yoo`03001oogoo005oo`003goo00<007ooOol0Zgoo00D007oo001oo`00
05Yoo`03001oogoo005oo`003goo00<007ooOol0[7oo0`00Fgoo00<007ooOol00Goo000?Ool00`00
Oomoo`2/Ool3001KOol00`00Oomoo`01Ool000moo`03001oogoo0:eoo`04001oogooOol2001GOol0
0`00Oomoo`01Ool000moo`03001oogoo0;9oo`03001oogoo05Eoo`03001oogoo005oo`003goo0P00
/goo00<007ooOol0Dgoo0`000goo000?Ool00`00Oomoo`2aOol00`00Ool0001FOol00`00Oomoo`01
Ool000moo`03001oogoo0;5oo`04001oo`00001EOol00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000Uoo`<000=oo`03001oogoo0?moo`]oo`03001oogoo005oo`00
2Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool40003Ool3003oOol9
Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo0P00
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2
003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo005oo`002Woo00<007ooOol00Woo
o`003`000goo0008Ool2003oOolGOol000Qoo`03001oogoo0?mooaIoo`0027oo0`00ogoo5Woo003o
OolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.19215 .38084 -64.2835 -3.78684 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.04773 .33501 -64.2835 -3.78684 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -64.2835 -3.78684 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.19215 .38084 m
.14286 .28571 L
.04773 .33501 L
s
.1918 .35689 m
.19215 .38084 L
.17278 .36675 L
s
.06182 .31564 m
.04773 .33501 L
.07168 .33466 L
s
gsave
.19215 .38084 -64.2835 -3.78684 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.04773 .33501 -64.2835 -3.78684 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -64.2835 -3.78684 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.19215 .38084 m
.14286 .28571 L
.04773 .33501 L
s
.1918 .35689 m
.19215 .38084 L
.17278 .36675 L
s
.06182 .31564 m
.04773 .33501 L
.07168 .33466 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.79381 .71429 m
.79381 .77143 L
.50809 .77143 L
.50809 .71429 L
F
0 g
.01 w
.49066 .46388 m
.77557 .44238 L
s
.02 w
.49066 .46388 Mdot
.77557 .44238 Mdot
gsave
.48154 .33544 -58.9091 -5.33741 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.52171 .48154 -58.9091 -5.33741 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -58.9091 -5.33741 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.48154 .33544 m
.42857 .42857 L
.52171 .48154 L
s
.46163 .34877 m
.48154 .33544 L
.48026 .35936 L
s
.49778 .48026 m
.52171 .48154 L
.50838 .46163 L
s
gsave
.75809 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.65095 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.65095 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.75809 .71429 m
.65095 .71429 L
.65095 .82143 L
s
.73667 .70357 m
.75809 .71429 L
.73667 .725 L
s
.64024 .8 m
.65095 .82143 L
.66167 .8 L
s
gsave
.81107 .61739 -61.5769 -3.80095 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66833 .66821 -61.5769 -3.80095 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.5769 -3.80095 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81107 .61739 m
.71429 .57143 L
.66833 .66821 L
s
.79631 .59852 m
.81107 .61739 L
.78712 .61787 L
s
.66784 .64426 m
.66833 .66821 L
.6872 .65345 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol06goo00=l07ooOol03Goo00<07gooOol0
8Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool00g`0Oomoo`0LOol00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo01aoo`03O01oogoo00ao
o`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo
0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool00004
Ool00`00Oomoo`0DOol00g`0Oomoo`0:Ool3000?Ool00g`0Oomoo`0<Ool00`0OOomoo`0POol;01l0
0`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001o
ogoo01Aoo`03O01oogoo00Qoo`8000=oo`03001oogoo00aoo`03O01oogoo00aoo`0301moogoo021o
o`/07`0300007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo
00<007ooOol057oo00=l07ooOol01Woo0P0017oo0`0037oo00=l07ooOol03Goo00<07gooOol087oo
2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol0
0g`0Oomoo`04Ool20006Ool3000<Ool00g`0Oomoo`0=Ool00`0OOomoo`0POol;01l00`0001l07`08
01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo009oo`03
001oogoo00Qoo`03001oogoo00Uoo`03O01oogoo00ioo`0301moogoo025oo`X07`0300007`0O00P0
7b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol00P002goo
0P002Woo00=l07ooOol03Woo00<07gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo
00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`00000000;Ool4000:Ool00g`0Oomoo`0>Ool0
0`0OOomoo`0ROol901l00`0001l07`0701lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`80
00ioo`03001oogoo00Aoo`800003O01oogoo00ioo`03001oogoo00Ioo`03O01oogoo00moo`0301mo
ogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<007ooOol037oo
00<007ooOol017oo00D007ooOomoog`000moo`03001oogoo00Ioo`03O01oogoo011oo`0301moogoo
02=oo`L07`0300007`0O00D07bEoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol0
37oo00<007ooOol00Woo0P0017oo00=l07ooOol03Woo00<007ooOol017oo00=l07ooOol04Goo00<0
7gooOol08goo1`0O00<0000O01l00`0O9goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00
Oomoo`0;Ool01000Oomoogoo0P001goo00=l07ooOol03Goo00<007ooOol00goo00=l07ooOol04Woo
00<07gooOol09Goo1@0O00@0000O01l07bUoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<0
07ooOol02goo00@007oo000000Yoo`03O01oogoo00eoo`05001oogooOoml000EOol00`0OOomoo`0W
Ool301l00`0001moo`0ZOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo00Yoo`<0
00eoo`9l00eoo`04001oogooO00FOol00`0OOomoo`0TOol=0n0UOol00`0OOomoo`1[Ool00`00Oomo
o`01Ool000moo`03001oogoo00Uoo`P000]oo`=l00]oo`03001l07oo01Moo`0301moogoo01iooaD3
h0Aoo`04001oogooOol200000goo001oo`0EOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03
001oogoo00Yoo`03001oogoo019oo`=l00Aoo`Al0003001oogoo01Moo`0301moogoo01aooaT3h0<0
00Eoo`03001oogoo01Aoo`0301moogoo06aoo`03001oogoo005oo`003goo0P002goo00<007ooOol0
57oo1G`01Goo00<007ooOol05goo00<07gooOol06Woo60?P0P0000<3h000000017oo00<007oo0000
5Goo00<07gooOol0JWoo0`000goo000?Ool00`00Oomoo`09Ool00`00Ool0000GOol2O006Ool00`00
Oomoo`0GOol00`0OOomoo`0HOolI0n001`000n03h0000n0000?P01Yoo`0301moogoo06eoo`03001o
ogoo005oo`003goo00<007ooOol02Goo00@007oo000001Qoo`=l00Aoo`03001oogoo01Moo`0301mo
ogoo01Iooad3h0030003h0000083h1Uoo`0301moogoo06eoo`03001oogoo005oo`003goo00<007oo
Ool0:7oo0W`00Woo00D007ooOomoo`0001Eoo`0301moogoo01Eooad3h0040003h0?P00030n0GOol0
0`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Yoo`9l0005Ool007ooOol0000EOol0
0`0OOomoo`0COolO0n0010000n03h00010?P5Woo00<07gooOol0KWoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0/Ool01G`0001oogoo00005Woo00<07gooOol04Woo7P?P00<000?P0n0020?P4goo00<0
7gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0[Ool01P00Oomoo`00O00001Moo`0301mo
ogoo015ooah3h0030003h0?P00T3h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P00;Goo
00D007oo001oo`00009l01Eoo`0301moogoo011ooah3h0030003h0?P00X3h15oo`0301moogoo06io
o`<000=oo`003goo00<007ooOol0;Goo10000Woo0W`057oo00<07gooOol03Woo7P?P00<000?P0n00
2`?P4Goo00<07gooOol0L7oo00<007ooOol00Goo000?Ool00`00Oomoo`0_Ool20004Ool2O00BOol0
0`0OOomoo`0=OolO0n000`000n03h00<0n0?Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03
001oogoo031oo`03001oogoo00Aoo`=l011oo`0301moogoo00aooah3h0030003h0?P00h3h0ioo`03
01moogoo075oo`03001oogoo005oo`003goo00<007ooOol0>Woo0W`03Woo00<07gooOol02goo7`?P
00<000?P0n003`?P37oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0_Ool20000
0goo001oo`08Ool2O00=Ool00`0OOomoo`0:OolN0n000`000n03h00@0n0<Ool00`0OOomoo`1bOol0
0`00Oomoo`01Ool000moo`03001oogoo035oo`03001oogoo00Yoo`9l00aoo`0301moogoo00Uooah3
h0030003h0?P0143h0Yoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0<7oo00<0
07oo00003Goo0W`02goo00<07gooOol01goo7P?P00<000?P0n004P?P2Goo00<07gooOol0M7oo00<0
07ooOol00Goo000?Ool20013Ool3O008Ool00`0OOomoo`07OolM0n000`000n03h00C0n08Ool00`0O
Oomoo`1cOol30003Ool000moo`03001oogoo04Eoo`9l00Moo`0301moogoo00Eooah3h0030003h0?P
01<3h0Qoo`0301moogoo07Eoo`03001oogoo005oo`003goo00<007ooOol0Agoo0W`01Woo0P0O1Goo
7@?P00<000?P0n0050?P1Woo0P0ON7oo00<007ooOol00Goo000?Ool00`00Oomoo`19Ool2O006Ool0
0`0OOomoo`02OolM0n000`000n03h00E0n04Ool00`0OOomoo`1hOol00`00Oomoo`01Ool000moo`03
001oogoo04]oo`=l00Aoo`0301moogoo01d3h0030003h0?P01H3h0=oo`0301moogoo07Uoo`03001o
ogoo005oo`003goo00<007ooOol0CWoo0W`00goo00<07goo0n0070?P00<000?P0n005P?P0Woo00<0
7gooOol0NWoo00<007ooOol00Goo0007Ool50003Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00J
0n000`000n03h00G0n000goo01moo`1lOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001o
ogoo059oo`9l0003Ool3h0?P01X3h0030003h0?P01L3h00301moogoo07aoo`03001oogoo005oo`00
2Goo00<007ooOol00goo0`00E7oo00=l00?P0n006@?P00<000?P0n000`?P0P004`?POGoo0`000goo
0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolL0n0200020n03000C0n0YOolAO1m5Ool00`00Oomo
o`01Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooah3h0<000030n0000?P0183h2IooaQl7d5o
o`03001oogoo005oo`0027oo0P001Goo00<007ooOol0EGoo80?P0P0050?P8Woo57`O3@00?7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`1EOolQ0n03000B0n0POol9O1lK000kOol00`00Oomoo`01Ool0
00moo`03001oogoo05Ioob<3h0030003h0?P00h3h1eooaX000Yl7`@00003O1moogoo03Qoo`03001o
ogoo005oo`003goo00<007ooOol0EWoo90?P0P003P?P4Goo6@0067`O0P0017`O>7oo00<007ooOol0
0Goo000?Ool2001HOolU0n02000<0n04OolI000/O1leOol30003Ool000moo`03001oogoo05MoobL3
h1d000Yooc1l7cEoo`03001oogoo005oo`003goo00<007ooOol0Egoo:0?P3`005Goo<g`O=7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`1HOolW0n0400030n000`000n03h00JOoldO1lcOol00`00Oomo
o`01Ool000moo`03001oogoo05QoobP3h08000030n0000000083h0030003h7oo01QoocIl7c9oo`03
001oogoo005oo`003goo00<007ooOol0FGoo;0?P0`0000<3h7ooOol05Woo>7`O<Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`1IOol^0n020005Ool2000@OoljO1l`Ool00`00Oomoo`01Ool000moo`03
001oogoo05UoobX3h0L000Eoo`03001oogoo00eoocal7bmoo`03001oogoo005oo`003goo0P00Fgoo
;0?P2Goo00<007ooOol037oo?G`O;Goo0`000goo000?Ool00`00Oomoo`1KOol[0n08Ool00`00Ool0
000<OoloO1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aoobT3h0Uoo`04001oo`00000;Oolo
O1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aoobP3h1Qood9l7baoo`03001oogoo005oo`00
3goo00<007ooOol0GGoo9P?P6Goo@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1NOolT0n0I
Oom3O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05moob83h1UoodEl7b]oo`03001oogoo005o
o`003goo00<007ooOol0H7oo7`?P6gooAW`O:Woo00<007ooOol00Goo000?Ool2001TOolK0n0KOom7
O1lXOol30003Ool000moo`03001oogoo06EooaL3h1eoodQl7bUoo`03001oogoo005oo`003goo00<0
07ooOol0Igoo4`?P7gooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1ZOol=0n0ROom8O1lY
Ool00`00Oomoo`01Ool000moo`03001oogoo06moo`<3h2IoodUl7bUoo`03001oogoo005oo`003goo
00<007ooOol0V7ooBW`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomo
o`01Ool000moo`8009UoodYl7bIoo`<000=oo`003goo00<007ooOol0UgooBg`O:7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMo
o`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomo
o`2GOom<O1lWOol00`00Oomoo`01Ool000Qoo`<000Aoo`03001oogoo09Ioodel7bMoo`03001oogoo
005oo`0027oo00<007ooOol017oo00<007ooOol0UWooCG`O9goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool3002FOolWO1l2000TO1lUOol30003Ool000Uoo`03001oogoo00=oo`03001oogoo09Io
obIl7`03001l7g`O0080029l7bMoo`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol0
UWoo9W`O00<007`OO1l0100087`O9goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`2GOolTO1l00`00O1ml7`03O1l01000O1l000007W`O9goo00<007ooOol00Goo000?Ool00`00Oomo
o`2GOolTO1l00`00O1ml7`03O1l01000O1ml7g`O0P0077`O9goo00<007ooOol00Goo000?Ool00`00
Oomoo`2GOolSO1l00`00O1ml7`02O1l20006O1l2000JO1lWOol00`00Oomoo`01Ool000moo`03001o
ogoo09Moob=l7`03001l7g`O009l7`<000Ml7`<001Ml7bMoo`03001oogoo005oo`003goo00<007oo
Ool0Ugoo8W`O00<007`OO1l047`O0P001G`O00<007`OO1l03G`O9goo00<007ooOol00Goo000?Ool2
002HOolRO1l00`00O1ml7`0BO1l20004O1l00`00O1ml7`0;O1lVOol30003Ool000moo`03001oogoo
09Qoob1l7`03001l7g`O01El7`8000=l7`03001l7g`O00Yl7bQoo`03001oogoo005oo`003goo00<0
07ooOol0V7oo87`O00<007`OO1l05g`O0P0000=l7`00O1l02g`O:7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`2HOolOO1l00`00O1ml7`0JO1l3000:O1lYOol00`00Oomoo`01Ool000moo`03001oogoo
09Uooail7`03001l7g`O01Yl7`@000Ul7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo7G`O
00<007`OO1l05g`O10003G`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolMO1l00`00O1ml
7`0XO1lYOol00`00Oomoo`01Ool000moo`8009Yooaal7`03001l7g`O021l7`800003O1l007`O00=l
7bQoo`<000=oo`003goo00<007ooOol0VWoo6g`O00<007`OO1l08W`O00<007`OO1l00g`O:Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`2JOolJO1l00`00O1ml7`0RO1l00`00O1l00003O1l[Ool00`00
Oomoo`01Ool000moo`03001oogoo09]ooaUl7`03001l7g`O02Ml7baoo`03001oogoo005oo`003goo
00<007ooOol0W7oo5g`O00<007`OO1l0:7`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolD
O1l01000O1ml7`00:G`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolCO1l00`00O1l0000Z
O1l]Ool00`00Oomoo`01Ool000moo`03001oogoo09eooa=l7`03001l7`00009l7`03001l7g`O02Al
7bioo`03001oogoo005oo`003goo0P00Wgoo4W`O0P000W`O00<007`OO1l097`O;Goo0`000goo000?
Ool00`00Oomoo`2OOolAO1l4000WO1l_Ool00`00Oomoo`01Ool000moo`03001oogoo0:1ooa1l7`80
02Ql7c1oo`03001oogoo005oo`003goo00<007ooOol0XGoo3g`O00<007`OO1l00P009G`O<7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`2ROolBO1l00`00O1ml7`0RO1laOol00`00Oomoo`01Ool000mo
o`03001oogoo0:=ooa5l7`03001l7g`O025l7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo
47`O00<007`O00008G`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOol>O1l01000O1l00000
7W`O=Goo00<007ooOol00Goo000?Ool2002WOol]O1leOol30003Ool000moo`03001oogoo0:QoobYl
7cQoo`03001oogoo005oo`003goo00<007ooOol0ZWoo9W`O>Woo00<007ooOol00Goo000?Ool00`00
Oomoo`2[OolSO1llOol00`00Oomoo`01Ool000moo`03001oogoo0:eoob1l7ceoo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0[goo57`O0P001W`O?goo00<007ooOol00Goo000:Ool00`00Oomo
o`02Ool00`00Oomoo`2bOolCO1l30012Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<0071o
oi/000=oo`002Woo00<007ooOol00Woo00<007ooOol0QGoo9`?o00<000?o0ol060?o0P002@?o>7oo
00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`25OolW0ol010000ol3o`?o0`004P?o
0P001@?o0P0000@3o`000ol3ocQoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0
QGoo9`?o00L000?o0ol3o`000ol0000@0ol200090ol010000ol3o`?o>7oo00<007ooOol00Goo000?
Ool00`00Oomoo`25OolW0ol010000ol3o`?o0`006P?o00<000?o00000P?o>7oo00<007ooOol00Goo
000?Ool00`00Oomoo`25OolW0ol01@000ol3o`?o00008@?o>7oo00<007ooOol00Goo000?Ool00`00
Oomoo`25OolW0ol00`000ol3o`020ol2000O0olhOol00`00Oomoo`01Ool000moo`03001oogoo08Eo
obL3o`030003o`?o02<3ocQoo`03001oogoo005oo`003goo0P00QWoo9`?o00<000?o0ol08`?o=Woo
0`000goo000?Ool00`00Oomoo`25OolW0ol00`000ol3o`0S0olhOol00`00Oomoo`01Ool000moo`03
001oogoo08EoobL3o`030003o`?o02<3ocQoo`03001oogoo005oo`003goo00<007ooOol0QGoo9`?o
00<000?o0ol08`?o>7oo00<007ooOol00Goo000?Ool00`00Oomoo`25OolW0ol00`000ol3o`0S0olh
Ool00`00Oomoo`01Ool000moo`03001oogoo08EoobL3o`030003o`?o02<3ocQoo`03001oogoo005o
o`003goo00<007ooOol0QGoo9`?o00<000?o0ol08`?o>7oo00<007ooOol00Goo000?Ool00`00Oomo
o`25OolW0ol00`000ol3o`0S0olhOol00`00Oomoo`01Ool000moo`8008IoobL3o`030003o`?o02<3
ocIoo`<000=oo`003goo00<007ooOol0[7oo00<007ooOol0Fgoo00<007ooOol00Goo000?Ool00`00
Oomoo`2/Ool00`00Oomoo`1KOol00`00Oomoo`01Ool000moo`03001oogoo0:aoo`03001oogoo05]o
o`03001oogoo005oo`003goo00<007ooOol0[7oo00<007ooOol0Fgoo00<007ooOol00Goo000?Ool0
0`00Oomoo`2/Ool00`00Oomoo`1KOol00`00Oomoo`01Ool000moo`03001oogoo0:aoo`03001oogoo
05]oo`03001oogoo005oo`003goo00<007ooOol0[7oo00<007ooOol0Fgoo00<007ooOol00Goo000?
Ool2002ZOol01000Oomoo`000Woo00<007ooOol0EWoo0`000goo000?Ool00`00Oomoo`2ZOol01@00
Ool007oo0000Fgoo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol01@00Ool007oo0000Fgoo00<0
07ooOol00Goo000?Ool00`00Oomoo`2[Ool3001LOol00`00Oomoo`01Ool000moo`03001oogoo0:]o
o`<005aoo`03001oogoo005oo`003goo00<007ooOol0[7oo00@007ooOomoo`8005Qoo`03001oogoo
005oo`003goo00<007ooOol0/Goo00<007ooOol0EWoo00<007ooOol00Goo000?Ool2002bOol00`00
Oomoo`1DOol30003Ool000moo`03001oogoo0;1oo`03001oo`0005Moo`03001oogoo005oo`003goo
00<007ooOol0/7oo00@007oo000005Ioo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`002Goo0`000goo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`@000=oo`<00?moo`Uoo`<000=o
o`0027oo00<007oo000017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool20004Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo0?moo`]oo`03001o
ogoo005oo`0027oo00<007oo000017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Goo000:Ool00`00Oomoo`02Oooo000?0003
Ool000Qoo`800?mooaMoo`0027oo00<007ooOol0ogoo5Woo0008Ool3003oOolFOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.10698 .38667 -66.8314 -4.45336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.0419 .24983 -66.8314 -4.45336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.8314 -4.45336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.10698 .38667 m
.14286 .28571 L
.0419 .24983 L
s
.12425 .37007 m
.10698 .38667 L
.10406 .36289 L
s
.06568 .24691 m
.0419 .24983 L
.0585 .26711 L
s
gsave
.10698 .38667 -66.8314 -4.45336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.0419 .24983 -66.8314 -4.45336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.8314 -4.45336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.10698 .38667 m
.14286 .28571 L
.0419 .24983 L
s
.12425 .37007 m
.10698 .38667 L
.10406 .36289 L
s
.06568 .24691 m
.0419 .24983 L
.0585 .26711 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.78905 .71429 m
.78905 .77143 L
.50334 .77143 L
.50334 .71429 L
F
0 g
.01 w
.49436 .45639 m
.77983 .44449 L
s
.02 w
.49436 .45639 Mdot
.77983 .44449 Mdot
gsave
.4703 .32989 -59.0685 -5.47846 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.52726 .4703 -59.0685 -5.47846 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.0685 -5.47846 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.4703 .32989 m
.42857 .42857 L
.52726 .4703 L
s
.45208 .34545 m
.4703 .32989 L
.47182 .3538 L
s
.50335 .47182 m
.52726 .4703 L
.51169 .45208 L
s
gsave
.75334 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64619 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64619 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.75334 .71429 m
.64619 .71429 L
.64619 .82143 L
s
.73191 .70357 m
.75334 .71429 L
.73191 .725 L
s
.63548 .8 m
.64619 .82143 L
.65691 .8 L
s
gsave
.80949 .62059 -61.7107 -3.7874 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66513 .66663 -61.7107 -3.7874 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.7107 -3.7874 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80949 .62059 m
.71429 .57143 L
.66513 .66663 L
s
.79536 .60123 m
.80949 .62059 L
.78553 .62027 L
s
.66544 .64267 m
.66513 .66663 L
.68448 .65251 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo00Eoo`80
00Eoo`@000Qoo`03O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo
06Yoo`03001oogoo005oo`003goo00<007ooOol01Woo00<007oo00000`002goo00=l07ooOol05Woo
00=l07ooOol047oo00<07gooOol08goo3P0O9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool0
0`00Oomoo`06Ool00`00Oomoo`040009Ool00g`0Oomoo`0GOol00g`0Oomoo`0?Ool00`0OOomoo`0S
Ool@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8000Ioo`03001oo`00009oo`800004
Ool000000006Ool00g`0Oomoo`0HOol00g`0Oomoo`0>Ool00`0OOomoo`0ROolB01lUOol00`0OOomo
o`1WOol30003Ool000moo`03001oogoo00Eoo`04001oo`000003Ool01000Oomoogoo0`000Woo00=l
07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo00<07gooOol0JGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool3000LOol00g`0Oomoo`0=Ool00`0OOomoo`0Q
OolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oo`000080
01Uoo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005oo`00
3goo00<007ooOol057oo00=l07ooOol00Woo0`005Woo00=l07ooOol03Goo00<07gooOol08Goo5@0O
8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00g`0
Oomoo`05Ool3000DOol00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo00Qoo`<0015oo`03O01o
ogoo00aoo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo
000017oo0`0057oo00=l07ooOol02gooC`002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00
Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0<Ool00`00Oomoo`0=Ool00g`0Oomoo`0<Ool00`0O
Oomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001o
o`0000Aoo`03001oogoo01Aoo`03O01oogoo00Uoo`<0011oo`03O01oogoo00aoo`0301moogoo021o
o`/07`0300007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo
00<007ooOol057oo00=l07ooOol02Goo0`003goo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0
000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomo
o`0;Ool00`00Oomoo`0=Ool00g`0Oomoo`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo00Uoo`8000ioo`03
O01oogoo00ioo`0301moogoo025oo`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo
005oo`003goo00<007ooOol05Goo00=l07ooOol027oo0`003Woo00=l07ooOol03Woo00<07gooOol0
8Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0E
Ool00g`0Oomoo`09Ool00`00Oomoo`0=Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROol901l00`0001l0
7`0701lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo00Moo`03001o
ogoo00eoo`03O01oogoo00moo`0301moogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qo
o`<000=oo`003goo00<007ooOol05goo00=l07ooOol01Woo00<007ooOol03Goo00=l07ooOol047oo
00<07gooOol08goo1`0O00<0000O01l01@0O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0GOol00g`0Oomoo`06Ool00`00Oomoo`0<Ool00g`0Oomoo`0AOol00`0OOomoo`0SOol7
01l00`0001l07`0301lWOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo00Aoo`03001oogoo00aoo`03O01oogoo019oo`0301moogoo02Eoo`D07`0400007`0O01lY
Ool00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo00=oo`03001o
ogoo00]oo`03O01oogoo01=oo`0301moogoo02Moo`<07`0300007goo00Qoo`03001oogoo01moo`03
01moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol06Woo0W`00goo00<007ooOol02Woo00=l
07ooOol057oo00<07gooOol097oo3@?P0goo0P000goo0P0000=oo`00Ool067oo00<07gooOol0Jgoo
00<007ooOol00Goo000?Ool00`00Oomoo`0LOol2O0000`00Oomoo`09Ool2O00HOol00`0OOomoo`0N
OolC0n040005Ool00`00Oomoo`0HOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo
01ioo`04001l07`0O004Ool4O00JOol00`0OOomoo`0LOolD0n000`000n03h0020004Ool00`00Ool0
000HOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`8001moo`03001oogoo00El01moo`0301mo
ogoo01Yooa@3h0040003h0?P00020n000`000n03h00LOol00`0OOomoo`1ZOol30003Ool000moo`03
001oogoo01eoo`03001oogoo00=oo`9l021oo`0301moogoo01QooaT3h0040003h0?P00030n0JOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo01eoo`03001oogoo00Eoo`=l01ioo`03
01moogoo01IooaX3h0040003h0?P00040n0IOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03
001oogoo01eoo`03001oogoo00Qoo`9l01aoo`0301moogoo01EooaX3h0050003h0?P0n0000050n0G
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`03001oogoo00]oo`9l01Yo
o`0301moogoo01=ooa`3h0030003h0?P00P3h1Ioo`0301moogoo06ioo`03001oogoo005oo`003goo
00<007ooOol06Goo00@007ooOol000moo`9l01Uoo`0301moogoo019ooa/3h0030003h0?P00/3h1=o
o`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol06Goo00@007ooOol0015oo`=l01Mo
o`0301moogoo015ooa/3h0030003h0?P00`3h19oo`0301moogoo06moo`03001oogoo005oo`003goo
0P006Woo00<007oo00000Woo00<007ooOol047oo0W`05Goo00<07gooOol047oo70?P00<000?P0n00
30?P4Goo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0IOol01@00Ool007oo00005Goo0W`0
57oo00<07gooOol03Woo70?P00<000?P0n003@?P4Goo00<07gooOol0L7oo00<007ooOol00Goo000?
Ool00`00Oomoo`0JOol3000HOol2O00BOol00`0OOomoo`0=OolM0n000`000n03h00>0n0?Ool00`0O
Oomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo01Yoo`8001]oo`=l011oo`0301moogoo00ao
oa`3h0030003h0?P0103h0ioo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol06Woo
00<007ooOol07Goo0W`03Woo00<07gooOol02goo7@?P00<000?P0n004@?P37oo00<07gooOol0LWoo
00<007ooOol00Goo000?Ool00`00Oomoo`0lOol2O00=Ool00`0OOomoo`0:OolL0n000`000n03h00B
0n0<Ool00`0OOomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo01Ioo`800003Ool007oo02=o
o`9l00aoo`0301moogoo00Uooa`3h0030003h0?P01<3h0Yoo`0301moogoo07=oo`03001oogoo005o
o`003goo00<007ooOol067oo00<007ooOol09Goo0W`02goo00<07gooOol01goo7@?P00<000?P0n00
4`?P2Goo00<07gooOol0M7oo00<007ooOol00Goo000?Ool2000HOol00`00Ool0000XOol3O008Ool0
0`0OOomoo`07OolL0n000`000n03h00D0n08Ool00`0OOomoo`1cOol30003Ool000moo`03001oogoo
04Eoo`9l00Moo`0301moogoo00Eooad3h0030003h0?P01@3h0Qoo`0301moogoo07Eoo`03001oogoo
005oo`003goo00<007ooOol0Agoo0W`01Woo0P0O1Goo70?P00<000?P0n005@?P1Woo0P0ON7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`19Ool2O006Ool00`0OOomoo`02OolL0n000`000n03h00F0n04
Ool00`0OOomoo`1hOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`=l00Aoo`0301moogoo01d3
h0030003h0?P01H3h0=oo`0301moogoo07Uoo`03001oogoo005oo`003goo00<007ooOol0CWoo0W`0
0goo00<07goo0n006`?P00<000?P0n005`?P0Woo00<07gooOol0NWoo00<007ooOol00Goo0007Ool5
0003Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00J0n000`000n03h00G0n000goo01moo`1lOol0
0`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool3h0?P01T3h0030003
h0?P01P3h00301moogoo07aoo`03001oogoo005oo`002Goo00<007ooOol00goo0`00E7oo00=l00?P
0n006@?P0P0010?P0P004`?POGoo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolM0n02
000010?P000000004`?P:Goo4G`OAGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`1EOolO0n04000C0n0VOolHO1m1Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo05Eoob43
h0<00183h29oob1l7`8003]oo`03001oogoo005oo`003goo00<007ooOol0EGoo8@?P00<000?P0n00
0`003`?P87oo2W`O6`00>Woo00<007ooOol00Goo000?Ool00`00Oomoo`1FOolV0n02000<0n0BOold
000jOol00`00Oomoo`01Ool000moo`03001oogoo05IoobP3h08000030n000000038001Ql7`8000=l
7cQoo`03001oogoo005oo`003goo0P00F7oo:@?P70002Woo;G`O=Goo0`000goo000?Ool00`00Oomo
o`1GOolY0n0500030n000`000n1oo`0JOol`O1leOol00`00Oomoo`01Ool000moo`03001oogoo05Mo
obX3h0800083h0<000030n0007oo00Aoo`80019ooc=l7cAoo`03001oogoo005oo`003goo00<007oo
Ool0F7oo<0?P0`001Goo00<007ooOol047oo=7`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`1H
Ool/0n080004Ool00`00Oomoo`0?OolfO1lbOol00`00Oomoo`01Ool000moo`03001oogoo05Uooc03
h0Ioo`03001oo`0000moocQl7c5oo`03001oogoo005oo`003goo00<007ooOol0FGoo;`?P1goo00@0
07oo000000eoocYl7c1oo`03001oogoo005oo`003goo00<007ooOol0FGoo;P?P67oo?7`O;goo00<0
07ooOol00Goo000?Ool2001KOol/0n0HOolmO1l]Ool30003Ool000moo`03001oogoo05]oob/3h1Mo
ocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo:@?P67oo?g`O;Woo00<007ooOol00Goo
000?Ool00`00Oomoo`1LOolX0n0HOom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05eoobH3
h1Uood9l7baoo`03001oogoo005oo`003goo00<007ooOol0GWoo90?P6Goo@g`O;7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`1OOolR0n0IOom5O1l[Ool00`00Oomoo`01Ool000moo`03001oogoo061o
oal3h1]oodIl7bYoo`03001oogoo005oo`003goo0P00I7oo6`?P6gooAg`O:7oo0`000goo000?Ool0
0`00Oomoo`1UOolG0n0MOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo06Mooa<3h1moodQl
7bUoo`03001oogoo005oo`003goo00<007ooOol0JWoo3@?P8WooB7`O:Goo00<007ooOol00Goo000?
Ool00`00Oomoo`1_Ool30n0VOom9O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09QoodYl7bQo
o`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<007ooOol00Goo000?Ool2002IOom:
O1lVOol30003Ool000moo`03001oogoo09Mood]l7bQoo`03001oogoo005oo`003goo00<007ooOol0
UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000mo
o`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007oo
Ool00Goo0008Ool30004Ool00`00Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool000Qoo`03001oogoo
00Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`002Goo00<007ooOol00goo0`00UWoo9g`O
00<007`OO1l08g`O9Goo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2FOolVO1l01000O1l0
00008g`O9goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2FOolVO1l00`00O1ml
7`03000QO1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo09MoobAl7`03001l
7g`O00=l7`<001ml7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo97`O00<007`OO1l00g`O
00<007`OO1l00P007G`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolSO1l00`00O1ml7`02
O1l20005O1l2000KO1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moob=l7`03001l7g`O009l
7`<000Il7`8001Ul7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo8W`O00<007`OO1l03W`O
0P005g`O9goo00<007ooOol00Goo000?Ool2002HOolRO1l00`00O1ml7`0@O1l20005O1l00`00O1ml
7`0<O1lVOol30003Ool000moo`03001oogoo09Qoob1l7`03001l7g`O01=l7`8000Al7`03001l7g`O
00]l7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo87`O00<007`OO1l05G`O0P000W`O00<0
07`OO1l02g`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOolOO1l00`00O1ml7`0HO1l20000
0g`O001l7`0:O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09Uooail7`03001l7g`O01Yl7`80
00]l7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo7G`O00<007`OO1l05g`O1`002W`O:Goo
00<007ooOol00Goo000?Ool00`00Oomoo`2IOolMO1l00`00O1ml7`0XO1lYOol00`00Oomoo`01Ool0
00moo`8009Yooaal7`03001l7g`O02Ql7bQoo`<000=oo`003goo00<007ooOol0VWoo6g`O00<007`O
O1l087`O0P0000=l7`00O1l00g`O:Woo00<007ooOol00Goo000?Ool00`00Oomoo`2JOolJO1l00`00
O1ml7`0SO1l00`00O1ml7`02O1l[Ool00`00Oomoo`01Ool000moo`03001oogoo09]ooaUl7`03001l
7g`O029l7`03001l7`00009l7baoo`03001oogoo005oo`003goo00<007ooOol0W7oo57`O00@007`O
O1l002Yl7baoo`03001oogoo005oo`003goo00<007ooOol0W7oo57`O00@007`OO1l002Ul7beoo`03
001oogoo005oo`003goo00<007ooOol0WGoo4g`O00<007`O0000:W`O;Goo00<007ooOol00Goo000?
Ool00`00Oomoo`2MOolCO1l00`00O1l00002O1l00`00O1ml7`0TO1l^Ool00`00Oomoo`01Ool000mo
o`8009mooa9l7`80009l7`03001l7g`O02Al7beoo`<000=oo`003goo00<007ooOol0Wgoo4G`O1000
9g`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2POol@O1l2000XO1l`Ool00`00Oomoo`01Ool0
00moo`03001oogoo0:5oo`ml7`04001l7`00000VO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo
0:9ooa5l7`03001l7g`O02=l7c5oo`03001oogoo005oo`003goo00<007ooOol0Xgoo47`O00<007`O
O1l08W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2SOol?O1l00`00O1l0000RO1lcOol00`00
Oomoo`01Ool000moo`03001oogoo0:Eoo`el7`04001l7`00000OO1leOol00`00Oomoo`01Ool000mo
o`800:Moobel7cEoo`<000=oo`003goo00<007ooOol0Z7oo:W`O>7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`2ZOolVO1ljOol00`00Oomoo`01Ool000moo`03001oogoo0:]oob=l7caoo`03001oogoo
005oo`003goo00<007ooOol0[Goo87`O?Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`2_
OolBO1l20008O1loOol00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0;9ooa5l7`<0
0003O1moogoo045oo`03001oogoo005oo`002Goo00<007ooOol00goo0`00L7ooV`000goo000:Ool0
0`00Oomoo`02Ool00`00Oomoo`24OolV0ol00`000ol3o`0H0ol2000:0oliOol00`00Oomoo`01Ool0
00Qoo`03001oo`0000Aoo`03001oogoo08AoobH3o`040003o`?o0ol3000B0ol200050ol200000`?o
0003o`020oliOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo08AoobH3o`070003
o`?o0ol000?o000040?o0P002@?o00<000?o0ol00P?o>Goo00<007ooOol00Goo000?Ool00`00Oomo
o`24OolV0ol010000ol3o`?o0`006P?o00<000?o00000`?o>Goo00<007ooOol00Goo000?Ool00`00
Oomoo`24OolV0ol01@000ol3o`?o00008P?o>Goo00<007ooOol00Goo000?Ool00`00Oomoo`24OolV
0ol00`000ol3o`020ol2000P0oliOol00`00Oomoo`01Ool000moo`03001oogoo08AoobH3o`030003
o`?o02@3ocUoo`03001oogoo005oo`003goo0P00QGoo9P?o00<000?o0ol090?o=goo0`000goo000?
Ool00`00Oomoo`24OolV0ol00`000ol3o`0T0oliOol00`00Oomoo`01Ool000moo`03001oogoo08Ao
obH3o`030003o`?o02@3ocUoo`03001oogoo005oo`003goo00<007ooOol0Q7oo9P?o00<000?o0ol0
90?o>Goo00<007ooOol00Goo000?Ool00`00Oomoo`24OolV0ol00`000ol3o`0T0oliOol00`00Oomo
o`01Ool000moo`03001oogoo08AoobH3o`030003o`?o02@3ocUoo`03001oogoo005oo`003goo00<0
07ooOol0Q7oo9P?o00<000?o0ol090?o>Goo00<007ooOol00Goo000?Ool00`00Oomoo`24OolV0ol0
0`000ol3o`0T0oliOol00`00Oomoo`01Ool000moo`8008EoobH3o`030003o`?o02@3ocMoo`<000=o
o`003goo00<007ooOol0ZWoo00<007ooOol0GGoo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol0
0`00Oomoo`1MOol00`00Oomoo`01Ool000moo`03001oogoo0:Yoo`03001oogoo05eoo`03001oogoo
005oo`003goo00<007ooOol0ZWoo00<007ooOol0GGoo00<007ooOol00Goo000?Ool00`00Oomoo`2Z
Ool00`00Oomoo`1MOol00`00Oomoo`01Ool000moo`03001oogoo0:Yoo`03001oogoo05eoo`03001o
ogoo005oo`003goo00<007ooOol0ZWoo00<007ooOol0GGoo00<007ooOol00Goo000?Ool2002YOol0
0`00Ool00002Ool00`00Oomoo`1HOol30003Ool000moo`03001oogoo0:Qoo`05001oo`00Ool0001M
Ool00`00Oomoo`01Ool000moo`03001oogoo0:Uoo`800003Ool007oo05aoo`03001oogoo005oo`00
3goo00<007ooOol0ZGoo0`00GWoo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol2001NOol00`00
Oomoo`01Ool000moo`03001oogoo0:Yoo`04001oogooOol2001JOol00`00Oomoo`01Ool000moo`03
001oogoo0:moo`03001oogoo05Qoo`03001oogoo005oo`003goo0P00/7oo00<007ooOol0EWoo0`00
0goo000?Ool00`00Oomoo`2^Ool00`00Ool0001IOol00`00Oomoo`01Ool000moo`03001oogoo0:io
o`04001oo`00001HOol00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000Uoo`<000=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Woo00<007ooOol00Woo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0008Ool40003Ool3003oOol9Ool30003Ool000Qoo`03001o
o`0000Aoo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo0P0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<0
00=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qo
o`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo005oo`002Woo00<007ooOol00Wooo`003`000goo0008Ool2003o
OolGOol000Qoo`03001oogoo0?mooaIoo`0027oo0`00ogoo5Woo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.04458 .3284 -66.9468 -5.46693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.10017 .18744 -66.9468 -5.46693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.9468 -5.46693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.04458 .3284 m
.14286 .28571 L
.10017 .18744 L
s
.06851 .32969 m
.04458 .3284 L
.05997 .31004 L
s
.11854 .20283 m
.10017 .18744 L
.09888 .21136 L
s
gsave
.04458 .3284 -66.9468 -5.46693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.10017 .18744 -66.9468 -5.46693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.9468 -5.46693 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.04458 .3284 m
.14286 .28571 L
.10017 .18744 L
s
.06851 .32969 m
.04458 .3284 L
.05997 .31004 L
s
.11854 .20283 m
.10017 .18744 L
.09888 .21136 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.78561 .71429 m
.78561 .77143 L
.4999 .77143 L
.4999 .71429 L
F
0 g
.01 w
.49716 .44851 m
.78286 .44611 L
s
.02 w
.49716 .44851 Mdot
.78286 .44611 Mdot
gsave
.45848 .32569 -59.2818 -5.61295 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.53145 .45848 -59.2818 -5.61295 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.2818 -5.61295 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.45848 .32569 m
.42857 .42857 L
.53145 .45848 L
s
.44221 .34327 m
.45848 .32569 L
.46279 .34926 L
s
.50789 .46279 m
.53145 .45848 L
.51387 .44221 L
s
gsave
.7499 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64276 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64276 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.7499 .71429 m
.64276 .71429 L
.64276 .82143 L
s
.72847 .70357 m
.7499 .71429 L
.72847 .725 L
s
.63204 .8 m
.64276 .82143 L
.65347 .8 L
s
gsave
.80828 .62286 -61.8084 -3.77844 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66285 .66542 -61.8084 -3.77844 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.8084 -3.77844 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80828 .62286 m
.71429 .57143 L
.66285 .66542 L
s
.79462 .60318 m
.80828 .62286 L
.78433 .62197 L
s
.66374 .64148 m
.66285 .66542 L
.68254 .65176 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
01Eoo`8002Ioo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<0
07ooOol05Woo00<007ooOol08Woo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0FOol00`00Ool0000OOol3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1a
Ool00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03001oo`00008001aoo`9l015oo`0301moogoo
04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol05Goo00<007oo0000100067oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000HOol00`00Ool0
0002Ool00`00Oomoo`0BOol3O00DOol00`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03
001oogoo01Moo`04001oogoo0002Ool00`00Oomoo`0?Ool2O00GOol00`0OOomoo`1=Ool00`0OOomo
o`1_Ool00`00Oomoo`01Ool000moo`03001oogoo01Moo`04001oogoo000BOol2O00HOol00`0OOomo
o`1>Ool00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo01Moo`05001oogooOol0000>
Ool3O00JOol00`0OOomoo`1?Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo01]o
o`03001oogoo00Yoo`9l01aoo`0301moogoo051oo`0301moogoo06ioo`03001oogoo005oo`003goo
00<007ooOol06goo00<007ooOol027oo0W`07Woo00<07gooOol0DGoo00<07gooOol0KGoo00<007oo
Ool00Goo000?Ool00`00Oomoo`0LOol00`00Oomoo`04Ool3O00POol00`0OOomoo`1AOol00`0OOomo
o`1]Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`03001oogoo009oo`9l029oo`0301moogoo
05=oo`0301moogoo06aoo`03001oogoo005oo`003goo0P007Woo00<007ooO0001W`07goo00<07goo
Ool0Dgoo00<07gooOol0JWoo0`000goo000?Ool00`00Oomoo`0MOol00`00O01l0006Ool3O00KOol0
0`0OOomoo`1DOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`03O00007oo
00Yoo`=l01Qoo`0301moogoo05Eoo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol0
6Woo0W`00Woo00<007ooOol02goo0W`05Goo00<07gooOol0EWoo00<07gooOol0Jgoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`02Ool00`00Oomoo`0=Ool00g`0Oomoo`0BOol00`0O
Oomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03O01oogoo00Ao
o`03001oogoo00eoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001o
ogoo005oo`003goo00<007ooOol05goo00=l07ooOol01Goo00<007ooOol03Woo00=l07ooOol047oo
00<07gooOol08goo3P0O9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol0
0g`0Oomoo`07Ool00`00Oomoo`0=Ool00g`0Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomo
o`1ZOol00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo00Moo`03001oogoo00ioo`03O01oogoo
00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=oo`003goo00<007ooOol05Goo00=l
07ooOol027oo00<007ooOol03Woo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo00<07gooOol0
JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`09Ool00`00Oomoo`0>Ool00g`0
Oomoo`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001o
ogoo01Aoo`03O01oogoo00Yoo`03001oogoo00ioo`03O01oogoo00eoo`0301moogoo025ooaD07b=o
o`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol02goo00<007oo
Ool03Goo00=l07ooOol03Goo00<07gooOol08Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00g`0Oomoo`0;Ool00`00Oomoo`0>Ool00g`0Oomo
o`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`00
00Aoo`03001oogoo01Aoo`03O01oogoo00aoo`03001oogoo00eoo`03O01oogoo00aoo`0301moogoo
021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo0`0057oo00=l
07ooOol02gooC`002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool00004Ool00`00Oomo
o`0DOol00g`0Oomoo`09Ool3000@Ool00g`0Oomoo`0<Ool00`0OOomoo`0POol;01l00`0001l07`09
01lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03
O01oogoo00Moo`@0015oo`03O01oogoo00aoo`0301moogoo021oo`/07`0300007`0O00T07b9oo`03
01moogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol0
1Goo0P0017oo00<007ooOol03Goo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O
8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`03Ool20006
Ool00`00Oomoo`0=Ool00g`0Oomoo`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol00`0O
Oomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo008000Ioo`<000ioo`03
O01oogoo00ioo`0301moogoo025oo`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo
005oo`003goo00<007ooOol05Goo0`006Goo00=l07ooOol03Woo00<07gooOol08Goo2P0O00<0000O
01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0=Ool00`00Oomoo`03
Ool200000g`0Oomoo`0IOol00g`0Oomoo`0>Ool00`0OOomoo`0ROol901l00`0001l07`0701lTOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000moo`8000eoo`03001oogoo009oo`8000=oo`03O01oogoo
01Moo`03O01oogoo00moo`0301moogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<0
00=oo`003goo00<007ooOol02goo00@007ooOomoo`8000Ioo`03O01oogoo01Ioo`03O01oogoo011o
o`0301moogoo02=oo`L07`0300007`0O00D07bEoo`0301moogoo06Yoo`03001oogoo005oo`003goo
00<007ooOol02goo00@007oo000000Qoo`03O01oogoo01Eoo`03O01oogoo015oo`0301moogoo02=o
o`L07`0300007`0O00<07bMoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol02Woo
0`002goo00=l07ooOol04goo00=l07ooOol04Woo00<07gooOol09Goo1@0O00@0000O01l07`Aoo`04
001oogooOol200000goo001oo`0LOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo
00Eoo`800003Ool0000000H000Uoo`03O01oogoo015oo`03O01oogoo01=oo`0301moogoo02Moo`<0
7`0300007goo00Aoo`8000Eoo`03001oogoo01aoo`0301moogoo06Yoo`03001oogoo005oo`003goo
00<007ooOol01goo00<007ooOol047oo0W`047oo00=l07ooOol057oo00<07gooOol097oo30?P0`00
17oo00<007oo000077oo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`06Ool00`00
Ool0000COol3O00;Ool2O00HOol00`0OOomoo`0NOolA0n0300000`?POomoo`0POol00`0OOomoo`1[
Ool00`00Oomoo`01Ool000moo`03001oogoo01moo`=l00Aoo`Al01Yoo`0301moogoo01aooa83h005
0003h0000n0000020n0OOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`80029oo`El01moo`03
01moogoo01Yooa83h0060003h0?P0003h0001@?P77oo00<07gooOol0JWoo0`000goo000?Ool00`00
Oomoo`0SOol2O00POol00`0OOomoo`0HOolF0n0010000n03h0001P?P6Woo00<07gooOol0KGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0UOol3O00NOol00`0OOomoo`0FOolG0n000`000n03h0080n0I
Ool00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo01Eo
oaP3h0030003h0?P00T3h1Moo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol0:Woo
0W`06Woo00<07gooOol04goo6@?P00<000?P0n002`?P5Woo00<07gooOol0KWoo00<007ooOol00Goo
000?Ool00`00Oomoo`0/Ool2O00IOol00`0OOomoo`0BOolI0n000`000n03h00=0n0COol00`0OOomo
o`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02ioo`=l01Moo`0301moogoo015ooaT3h0030003
h0?P00h3h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P00<Woo0W`05Goo00<07gooOol0
47oo6P?P00<000?P0n003P?P4Goo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0cOol2O00D
Ool00`0OOomoo`0>OolJ0n000`000n03h00?0n0AOol00`0OOomoo`1`Ool00`00Oomoo`01Ool000mo
o`03001oogoo03Eoo`9l019oo`0301moogoo00eooa/3h0030003h0?P0103h0moo`0301moogoo075o
o`03001oogoo005oo`003goo00<007ooOol0=goo0g`047oo00<07gooOol037oo6`?P00<000?P0n00
4@?P3Woo00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0jOol2O00>Ool00`0OOomo
o`0;OolK0n000`000n03h00C0n0<Ool00`0OOomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo
03aoo`9l00eoo`0301moogoo00Yooa/3h0030003h0?P01<3h0aoo`0301moogoo079oo`03001oogoo
005oo`003goo00<007ooOol0?Woo0W`037oo00<07gooOol02Goo6`?P00<000?P0n0050?P2Woo00<0
7gooOol0Lgoo00<007ooOol00Goo000?Ool00`00Oomoo`10Ool2O00;Ool00`0OOomoo`07OolL0n00
0`000n03h00D0n09Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`8004=oo`=l00Qoo`0301mo
ogoo00Mooa/3h0030003h0?P01D3h0Qoo`0301moogoo07=oo`<000=oo`003goo00<007ooOol0AGoo
0W`01goo00<07gooOol01Goo70?P00<000?P0n005@?P27oo00<07gooOol0MGoo00<007ooOol00Goo
000?Ool00`00Oomoo`17Ool2O006Ool201l5OolL0n000`000n03h00E0n06Ool201mhOol00`00Oomo
o`01Ool000moo`03001oogoo04Uoo`9l00Ioo`0301moogoo009ooa/3h0030003h0?P01L3h0Aoo`03
01moogoo07Qoo`03001oogoo005oo`003goo00<007ooOol0Bgoo0g`017oo00<07gooOol070?P00<0
00?P0n005`?P0goo00<07gooOol0NGoo00<007ooOol00Goo000?Ool00`00Oomoo`1>Ool2O003Ool0
0`0OOol3h00K0n000`000n03h00G0n02Ool00`0OOomoo`1jOol00`00Oomoo`01Ool000Moo`D000=o
o`03001oogoo051oo`9l009oo`0301l3h0?P01X3h0030003h0?P01L3h003Ool07goo07aoo`03001o
ogoo005oo`002Goo00<007ooOol00goo00<007ooOol0DWoo0W`000=oo`?P0n006@?P00<000?P0n00
60?P00<07gooOol0O7oo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001DOol00g`00n03h00I
0n0200040n02000C0n1mOol30003Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooad3h0H001<3
h2Uooa5l7dEoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0EGoo80?P10004P?P
9Woo67`O@Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1EOolQ0n000`000n03h004000:
0n0010000n03h0?P8Woo87`O?Goo00<007ooOol00Goo000?Ool00`00Oomoo`1EOolQ0n000`000n03
h0040n0300000`?P0000001=000jOol00`00Oomoo`01Ool000moo`03001oogoo05IoobX3h54003Uo
o`03001oogoo005oo`003goo00<007ooOol0EWoo:P?P1`000`?P00<007ooOol00goo0P005Woo9G`O
100000=l7gooOol0=Woo00<007ooOol00Goo000?Ool2001HOolZ0n0200040n050005Ool00`00Oomo
o`0BOolXO1l20003O1leOol30003Ool000moo`03001oogoo05Mooc83h0@000Aoo`03001oogoo015o
oc1l7cEoo`03001oogoo005oo`003goo00<007ooOol0Egoo;P?P100000<3h7ooOol017oo00<007oo
000047oo<g`O=7oo00<007ooOol00Goo000?Ool00`00Oomoo`1HOola0n07Ool01000Ool000003goo
=7`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`1HOola0n0IOolfO1lbOol00`00Oomoo`01Ool0
00moo`03001oogoo05Uooc03h1QoocQl7c5oo`03001oogoo005oo`003goo00<007ooOol0FGoo;`?P
67oo>W`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol^0n0HOollO1l_Ool00`00Oomoo`01
Ool000moo`8005]oob`3h1Qoocel7beoo`<000=oo`003goo00<007ooOol0Fgoo:`?P5goo?g`O;Woo
00<007ooOol00Goo000?Ool00`00Oomoo`1LOolY0n0HOoloO1l^Ool00`00Oomoo`01Ool000moo`03
001oogoo05aoobP3h1Qood9l7baoo`03001oogoo005oo`003goo00<007ooOol0GGoo9P?P6Goo@W`O
;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1NOolT0n0IOom3O1l/Ool00`00Oomoo`01Ool000mo
o`03001oogoo05moob83h1UoodEl7b]oo`03001oogoo005oo`003goo00<007ooOol0H7oo7`?P6goo
AW`O:Woo00<007ooOol00Goo000?Ool2001TOolK0n0KOom7O1lXOol30003Ool000moo`03001oogoo
06EooaL3h1eoodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0Igoo4`?P7gooB7`O:Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`1ZOol=0n0ROom8O1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo06moo`<3h2IoodUl7bUoo`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomoo`01Ool000moo`8009UoodYl7bIoo`<0
00=oo`003goo00<007ooOol0UgooBg`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lW
Ool00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007oo
Ool0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool0
00Qoo`<000Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`0027oo00<007ooOol017oo00<0
07ooOol0UWooCG`O9goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3002FOolWO1l00`00O1ml
7`0SO1lUOol30003Ool000Uoo`03001oogoo00=oo`03001oogoo09IoobIl7`04001l7`00000SO1lW
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo09IoobIl7`03001l7g`O00<0025l
7bMoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Ugoo97`O00<007`OO1l00g`O
0`007g`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolTO1l00`00O1ml7`03O1l00`00O1ml
7`02000MO1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moob=l7`03001l7g`O009l7`8000El
7`03001l7g`O01Yl7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo8g`O00<007`OO1l00W`O
0`001G`O0P006W`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolRO1l00`00O1ml7`0=O1l2
000HO1lWOol00`00Oomoo`01Ool000moo`8009Qoob9l7`03001l7g`O00ml7`8001El7bIoo`<000=o
o`003goo00<007ooOol0V7oo87`O00<007`OO1l04W`O00<007`OO1l00W`O00<007`OO1l03G`O:7oo
00<007ooOol00Goo000?Ool00`00Oomoo`2HOolOO1l00`00O1ml7`0DO1l20003O1l00`00O1ml7`0<
O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qooaml7`03001l7g`O01Il7`80009l7`03001l
7g`O00Yl7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo7G`O00<007`OO1l06G`O0`0037`O
:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolMO1l00`00O1ml7`0KO1l2000;O1lYOol00`00
Oomoo`01Ool000moo`03001oogoo09Uooaal7`03001l7g`O01Ql7`L000Yl7bUoo`03001oogoo005o
o`003goo0P00VWoo77`O00<007`OO1l0:7`O:7oo0`000goo000?Ool00`00Oomoo`2JOolJO1l00`00
O1ml7`0PO1l200000g`O001l7`04O1lZOol00`00Oomoo`01Ool000moo`03001oogoo09YooaUl7`03
001l7g`O02=l7`03001l7g`O00=l7b]oo`03001oogoo005oo`003goo00<007ooOol0Vgoo67`O00<0
07`OO1l08W`O00<007`O00000g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolCO1l01000
O1ml7`00:g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolCO1l01000O1ml7`00:W`O;Goo
00<007ooOol00Goo000?Ool00`00Oomoo`2MOolBO1l00`00O1l0000[O1l]Ool00`00Oomoo`01Ool0
00moo`03001oogoo09eooa9l7`03001l7`00009l7`03001l7g`O02El7bioo`03001oogoo005oo`00
3goo0P00Wgoo4G`O0P0000=l7`0000009g`O;Goo0`000goo000?Ool00`00Oomoo`2OOol@O1l3000Y
O1l_Ool00`00Oomoo`01Ool000moo`03001oogoo0:1oo`ml7`03001l7g`O02Ql7c1oo`03001oogoo
005oo`003goo00<007ooOol0XGoo47`O0P009g`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2R
Ool@O1l00`00O1ml7`0TO1laOol00`00Oomoo`01Ool000moo`03001oogoo0:=oo`ml7`03001l7g`O
02=l7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo3W`O00<007`O00008g`O<goo00<007oo
Ool00Goo000?Ool00`00Oomoo`2UOol<O1l01000O1l0000087`O=Goo00<007ooOol00Goo000?Ool2
002WOol]O1leOol30003Ool000moo`03001oogoo0:QoobYl7cQoo`03001oogoo005oo`003goo00<0
07ooOol0ZWoo9W`O>Woo00<007ooOol00Goo000?Ool00`00Oomoo`2[OolSO1llOol00`00Oomoo`01
Ool000moo`03001oogoo0:eoob1l7ceoo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0[goo
4W`O0P0027`O?goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2bOolAO1l20002
O1m3Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<0071ooi/000=oo`002Woo00<007ooOol0
0Woo00<007ooOol0Pgoo9`?o00<000?o0ol05`?o0P002P?o>Woo00<007ooOol00Goo0008Ool00`00
Ool00004Ool00`00Oomoo`23OolW0ol010000ol3o`?o0`004@?o0P001@?o0P0000<3o`000ol00P?o
>Woo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`23OolW0ol01`000ol3o`?o0003
o`000103o`030003o`?o00L3o`030003o`?o0083ocYoo`03001oogoo005oo`003goo00<007ooOol0
Pgoo9`?o00@000?o0ol3o`<001T3o`030003o`0000<3ocYoo`03001oogoo005oo`003goo00<007oo
Ool0Pgoo9`?o00D000?o0ol3o`000243ocYoo`03001oogoo005oo`003goo00<007ooOol0Pgoo9`?o
00<000?o0ol00P?o0P007`?o>Woo00<007ooOol00Goo000?Ool00`00Oomoo`23OolW0ol00`000ol3
o`0S0oljOol00`00Oomoo`01Ool000moo`8008AoobL3o`030003o`?o02<3ocQoo`<000=oo`003goo
00<007ooOol0Pgoo9`?o00<000?o0ol08`?o>Woo00<007ooOol00Goo000?Ool00`00Oomoo`23OolW
0ol00`000ol3o`0S0oljOol00`00Oomoo`01Ool000moo`03001oogoo08=oobL3o`030003o`?o02<3
ocYoo`03001oogoo005oo`003goo00<007ooOol0Pgoo9`?o00<000?o0ol08`?o>Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`23OolW0ol00`000ol3o`0S0oljOol00`00Oomoo`01Ool000moo`03001o
ogoo08=oobL3o`030003o`?o02<3ocYoo`03001oogoo005oo`003goo00<007ooOol0Pgoo9`?o00<0
00?o0ol08`?o>Woo00<007ooOol00Goo000?Ool20024OolW0ol00`000ol3o`0S0olhOol30003Ool0
00moo`03001oogoo0:Yoo`03001oogoo05eoo`03001oogoo005oo`003goo00<007ooOol0ZWoo00<0
07ooOol0GGoo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol00`00Oomoo`1MOol00`00Oomoo`01
Ool000moo`03001oogoo0:Yoo`03001oogoo05eoo`03001oogoo005oo`003goo00<007ooOol0ZWoo
00<007ooOol0GGoo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol00`00Oomoo`1MOol00`00Oomo
o`01Ool000moo`03001oogoo0:Yoo`03001oogoo05eoo`03001oogoo005oo`003goo0P00Z7oo00H0
07ooOol007oo001KOol30003Ool000moo`03001oogoo0:Qoo`05001oo`00Ool0001MOol00`00Oomo
o`01Ool000moo`03001oogoo0:Qoo`04001oo`00001NOol00`00Oomoo`01Ool000moo`03001oogoo
0:Uoo`<005ioo`03001oogoo005oo`003goo00<007ooOol0ZGoo0P00Ggoo00<007ooOol00Goo000?
Ool00`00Oomoo`2ZOol01000Oomoogoo0P00FWoo00<007ooOol00Goo000?Ool00`00Oomoo`2_Ool0
0`00Oomoo`1HOol00`00Oomoo`01Ool000moo`800;1oo`03001oogoo05Ioo`<000=oo`003goo00<0
07ooOol0[Woo00<007oo0000FGoo00<007ooOol00Goo000?Ool00`00Oomoo`2^Ool01000Ool00000
F7oo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool30003
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0?moo`]o
o`03001oogoo005oo`0027oo10000goo0`00ogoo2Goo0`000goo0008Ool00`00Ool00004Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`8000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`80
0?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool00`00Ool00004
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000l000=oo`0027oo0P00ogoo5goo0008Ool0
0`00Oomoo`3oOolFOol000Qoo`<00?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.04458 .24303 -64.5564 -6.18405 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.18554 .18744 -64.5564 -6.18405 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -64.5564 -6.18405 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.04458 .24303 m
.14286 .28571 L
.18554 .18744 L
s
.05997 .26139 m
.04458 .24303 L
.06851 .24174 L
s
.18683 .21136 m
.18554 .18744 L
.16718 .20283 L
s
gsave
.04458 .24303 -64.5564 -6.18405 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.18554 .18744 -64.5564 -6.18405 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -64.5564 -6.18405 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.04458 .24303 m
.14286 .28571 L
.18554 .18744 L
s
.05997 .26139 m
.04458 .24303 L
.06851 .24174 L
s
.18683 .21136 m
.18554 .18744 L
.16718 .20283 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.78356 .71429 m
.78356 .77143 L
.49785 .77143 L
.49785 .71429 L
F
0 g
.01 w
.49902 .44036 m
.78465 .4471 L
s
.02 w
.49902 .44036 Mdot
.78465 .4471 Mdot
gsave
.44626 .3229 -59.5459 -5.73906 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.53424 .44626 -59.5459 -5.73906 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.5459 -5.73906 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.44626 .3229 m
.42857 .42857 L
.53424 .44626 L
s
.43216 .34226 m
.44626 .3229 L
.45329 .3458 L
s
.51134 .45329 m
.53424 .44626 L
.51488 .43216 L
s
gsave
.74785 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64071 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64071 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.74785 .71429 m
.64071 .71429 L
.64071 .82143 L
s
.72642 .70357 m
.74785 .71429 L
.72642 .725 L
s
.62999 .8 m
.64071 .82143 L
.65142 .8 L
s
gsave
.80753 .62421 -61.867 -3.77344 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66151 .66467 -61.867 -3.77344 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.867 -3.77344 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80753 .62421 m
.71429 .57143 L
.66151 .66467 L
s
.79416 .60433 m
.80753 .62421 L
.7836 .62297 L
s
.66274 .64075 m
.66151 .66467 L
.68139 .6513 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
02ioo`8000eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<0
07ooOol0;goo00<007ooOol02Goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0_Ool00`00Oomoo`06Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1a
Ool00`00Oomoo`01Ool000moo`03001oogoo02ioo`<000Eoo`9l015oo`0301moogoo04Yoo`0301mo
ogoo075oo`03001oogoo005oo`003goo00<007ooOol0;7oo1P000Woo0W`04goo00<07gooOol0Bgoo
00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000/Ool00`00Oomoo`02000017ooO01l07`057oo
00<07gooOol0C7oo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0ZOol01`00Oomoo`00Ool0
07`001Moo`0301moogoo04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo
00<007`000005goo00<07gooOol0CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomo
o`0ZOol2O0001000Oomoo`005goo00<07gooOol0Cgoo00<07gooOol0KWoo00<007ooOol00Goo000?
Ool00`00Oomoo`0XOol2O002Ool00`00Oomoo`0GOol00`0OOomoo`1@Ool00`0OOomoo`1^Ool00`00
Oomoo`01Ool000moo`03001oogoo02Ioo`9l00=oo`03001oogoo01Qoo`0301moogoo055oo`0301mo
ogoo06eoo`03001oogoo005oo`003goo00<007ooOol08goo0g`01Goo00<007ooOol067oo00<07goo
Ool0DGoo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0QOol2O007Ool00`00Oomo
o`0HOol00`0OOomoo`1COol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`80021oo`Ml00Aoo`03
001oogoo01Qoo`0301moogoo05=oo`0301moogoo06Yoo`<000=oo`003goo00<007ooOol07Goo0g`0
1Woo0g`000<007ooOol067oo00<07gooOol0E7oo00<07gooOol0K7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`0LOol2O00;Ool00`00O01l000HOol00`0OOomoo`1EOol00`0OOomoo`1[Ool00`00Oomo
o`01Ool000moo`03001oogoo01Yoo`9l00eoo`03001oogoo009l01Eoo`0301moogoo05Ioo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol01goo2@002Goo00=l07ooOol037oo00<007oo
Ool00goo00=l07ooOol04Woo00<07gooOol0Egoo00<07gooOol0JWoo00<007ooOol00Goo000?Ool0
0`00Oomoo`09Ool4000;Ool00g`0Oomoo`0=Ool00`00Oomoo`04Ool00g`0Oomoo`0AOol00`0OOomo
o`0TOol;01lXOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo00Qoo`05001oo`00
001oo`020008Ool00g`0Oomoo`0=Ool00`00Oomoo`06Ool00g`0Oomoo`0@Ool00`0OOomoo`0SOol>
01lVOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo00]oo`04001oogooOol30004
Ool00g`0Oomoo`0>Ool00`00Oomoo`06Ool00g`0Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0O
Oomoo`1ZOol00`00Oomoo`01Ool000moo`8000eoo`03001oogoo00=oo`80009oo`03O01oogoo00eo
o`03001oogoo00Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol03Goo00<007ooOol017oo0P0047oo00<007ooOol027oo00=l07ooOol03Woo
00<07gooOol08Woo4`0O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol0
17`00000000037oo00<007ooOol02Woo00=l07ooOol03Goo00<07gooOol08Goo500O97oo00<07goo
Ool0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`02Ool2000:Ool00`00Oomo
o`0:Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00moo`03001oogoo01Aoo`03O01oogoo00Aoo`<000Ioo`03001oogoo00]oo`03O01oogoo00eoo`03
01moogoo025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo00<0
07ooOol057oo00=l07ooOol01goo0P0017oo00<007ooOol037oo00=l07ooOol037oo00<07gooOol0
87oo5P0O8goo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0D
Ool00g`0Oomoo`09Ool200000goo001oo`0>Ool00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<001Aoo`03O01oogoo00]oodl0
00X07b=oo`0301moogoo06Moo`<000=oo`0027oo00<007oo000017oo00<007ooOol057oo00=l07oo
Ool037oo0P003Woo00=l07ooOol037oo00<07gooOol087oo2`0O00<0000O01l02@0O8Woo00<07goo
Ool0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0>Ool0
0`00Oomoo`0;Ool00g`0Oomoo`0<Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0OOomo
o`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03O01oogoo00ioo`03
001oogoo00Yoo`03O01oogoo00eoo`0301moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo
06Uoo`03001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol037oo0`0037oo00=l07ooOol0
3Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?
Ool00`00Oomoo`0EOol00g`0Oomoo`0IOol00g`0Oomoo`0>Ool00`0OOomoo`0QOol:01l00`0001l0
7`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo01Uo
o`03O01oogoo00ioo`0301moogoo025oo`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001o
ogoo005oo`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo
2@0O00<0000O01l01`0O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool2000GOol00g`0Oomo
o`0GOol00g`0Oomoo`0?Ool00`0OOomoo`0SOol801l00`0001l07`0601lTOol00`0OOomoo`1XOol3
0003Ool000moo`03001oogoo01Moo`03O01oogoo01Ioo`03O01oogoo011oo`0301moogoo02=oo`L0
7`0300007`0O00D07bEoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol05goo00=l
07ooOol05Goo00=l07ooOol04Goo00<07gooOol08goo1`0O00<0000O01l00P0O00<007ooOol09Goo
00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol00g`0Oomoo`0COol00g`0Oomo
o`0BOol00`0OOomoo`0UOol501l0100001l07`0O0P000Woo0P0000=oo`00Ool087oo00<07gooOol0
JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomoo`0COol00`0O
Oomoo`0WOol301l0100001moogoo0`000goo00<007ooOol087oo00<07gooOol0JWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0JOol2O00@Ool00g`0Oomoo`0DOol00`0OOomoo`0TOol90n0200001`?P
001oogoo001oo`00021oo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol077oo0g`0
2goo0W`067oo00<07gooOol07Woo3@?P00D000?P0003h00000<3h29oo`0301moogoo06]oo`03001o
ogoo005oo`003goo00<007ooOol07goo0g`017oo17`06Woo00<07gooOol077oo3`?P00D000?P0003
h00000D3h1moo`0301moogoo06aoo`03001oogoo005oo`003goo0P008Woo1G`07goo00<07gooOol0
6Woo3`?P00@000?P0n000083h0030003h0?P00D3h1aoo`0301moogoo06Yoo`<000=oo`003goo00<0
07ooOol08goo0W`087oo00<07gooOol067oo50?P00@000?P0n0000P3h1Yoo`0301moogoo06eoo`03
001oogoo005oo`003goo00<007ooOol09Goo0g`07Woo00<07gooOol05Woo5@?P00<000?P0n002P?P
6Goo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0XOol2O00LOol00`0OOomoo`0E
OolE0n000`000n03h00<0n0GOol00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Yo
o`9l01Yoo`0301moogoo01=ooaL3h0030003h0?P00d3h1Ioo`0301moogoo06ioo`03001oogoo005o
o`003goo00<007ooOol0;7oo0W`06Goo00<07gooOol04Woo5`?P00<000?P0n003`?P4goo00<07goo
Ool0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0^Ool3O00GOol00`0OOomoo`0AOolG0n000`00
0n03h00@0n0BOol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`80039oo`9l01Eoo`0301moogoo
011ooaP3h0030003h0?P0103h15oo`0301moogoo06ioo`<000=oo`003goo00<007ooOol0<goo0W`0
57oo00<07gooOol03Woo6@?P00<000?P0n0040?P4Goo00<07gooOol0L7oo00<007ooOol00Goo000?
Ool00`00Oomoo`0eOol2O00BOol00`0OOomoo`0=OolI0n000`000n03h00B0n0?Ool00`0OOomoo`1a
Ool00`00Oomoo`01Ool000moo`03001oogoo03Moo`=l011oo`0301moogoo00aooaT3h0030003h0?P
01<3h0ioo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0>Woo0W`03Woo00<07goo
Ool02goo6P?P00<000?P0n0050?P37oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomo
o`0lOol2O00=Ool00`0OOomoo`0:OolJ0n000`000n03h00D0n0<Ool00`0OOomoo`1bOol00`00Oomo
o`01Ool000moo`03001oogoo03ioo`9l00aoo`0301moogoo00UooaX3h0030003h0?P01D3h0Yoo`03
01moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0@7oo0W`02goo00<07gooOol01goo6`?P
00<000?P0n005@?P2Goo00<07gooOol0M7oo00<007ooOol00Goo000?Ool20013Ool3O008Ool00`0O
Oomoo`07OolJ0n000`000n03h00F0n08Ool00`0OOomoo`1cOol30003Ool000moo`03001oogoo04Eo
o`9l00Moo`0301moogoo00Eooa/3h0030003h0?P01H3h0Qoo`0301moogoo07Eoo`03001oogoo005o
o`003goo00<007ooOol0Agoo0W`01Woo0P0O1Goo6`?P00<000?P0n005P?P1Woo0P0ON7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`19Ool2O006Ool00`0OOomoo`02OolK0n000`000n03h00G0n04Ool0
0`0OOomoo`1hOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`=l00Aoo`0301moogoo01`3h003
0003h0?P01L3h0=oo`0301moogoo07Uoo`03001oogoo005oo`003goo00<007ooOol0CWoo0W`00goo
00<07goo0n006`?P00<000?P0n005`?P0Woo00<07gooOol0NWoo00<007ooOol00Goo0007Ool50003
Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00I0n000`000n03h00H0n000goo01moo`1lOol00`00
Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool3h0?P01T3h0030003h0?P
01P3h00301moogoo07aoo`03001oogoo005oo`002Goo00<007ooOol00goo0`00E7oo00=l00?P0n00
6@?P100000<3h000000050?POGoo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolO0n07
000<0n0010000n03h0?P:Goo4G`OAGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`1EOolO0n000`000n0000040n0900040n0200000`?POomoo`0TOolHO1m1Ool00`00Oomoo`01Ool0
00Qoo`8000Eoo`03001oogoo05Eoob03h0030003h0?P00T3h2T000=oob1l7ceoo`03001oogoo005o
o`003goo00<007ooOol0EGoo80?P00<000?P0n002@?PD000>Goo00<007ooOol00Goo000?Ool00`00
Oomoo`1FOol/0n0200040n030007Ool00`00Oomoo`0EOolX000hOol00`00Oomoo`01Ool000moo`03
001oogoo05Iooc03h0800083h0Moo`03001oo`0001AoobIl7`@003Qoo`03001oogoo005oo`003goo
0P00F7oo<`?P1goo00@007oo0000015oobUl7`80009l7cEoo`<000=oo`003goo00<007ooOol0Egoo
<`?P6goo<7`O=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolc0n0IOolcO1ldOol00`00Oomo
o`01Ool000moo`03001oogoo05Qooc43h1YoocAl7c=oo`03001oogoo005oo`003goo00<007ooOol0
F7oo<@?P6Goo=W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol`0n0HOolhO1laOol00`00
Oomoo`01Ool000moo`03001oogoo05Uoobl3h1QoocYl7c1oo`03001oogoo005oo`003goo00<007oo
Ool0FGoo;P?P67oo?7`O;goo00<007ooOol00Goo000?Ool2001KOol/0n0HOolmO1l]Ool30003Ool0
00moo`03001oogoo05]oob/3h1Moocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo:@?P
67oo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n0HOom2O1l/Ool00`00Oomoo`01
Ool000moo`03001oogoo05eoobH3h1Uood9l7baoo`03001oogoo005oo`003goo00<007ooOol0GWoo
90?P6Goo@g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR0n0IOom5O1l[Ool00`00Oomo
o`01Ool000moo`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo005oo`003goo0P00I7oo6`?P
6gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lYOol00`00Oomoo`01Ool000mo
o`03001oogoo06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0JWoo3@?P8Woo
B7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9O1lYOol00`00Oomoo`01Ool0
00moo`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<0
07ooOol00Goo000?Ool2002IOom:O1lVOol30003Ool000moo`03001oogoo09Mood]l7bQoo`03001o
ogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<
O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<0
07ooOol0UgooC7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOom=O1lWOol00`00
Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`002Goo
00<007ooOol00goo0`00UWoo9g`O00<007`OO1l08g`O9Goo0`000goo0009Ool00`00Oomoo`03Ool0
0`00Oomoo`2FOolVO1l01000O1l000008g`O9goo00<007ooOol00Goo0008Ool00`00Ool00004Ool0
0`00Oomoo`2FOolVO1l00`00O1ml7`03000QO1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=o
o`03001oogoo09MoobAl7`03001l7g`O00=l7`<001ml7bMoo`03001oogoo005oo`003goo00<007oo
Ool0Ugoo97`O00<007`OO1l00g`O00<007`OO1l00P007G`O9goo00<007ooOol00Goo000?Ool00`00
Oomoo`2GOolSO1l00`00O1ml7`02O1l20005O1l00`00O1ml7`0JO1lWOol00`00Oomoo`01Ool000mo
o`03001oogoo09Moob=l7`03001l7g`O009l7`<000El7`8001Yl7bMoo`03001oogoo005oo`003goo
00<007ooOol0Ugoo8W`O00<007`OO1l03G`O0P0067`O9goo00<007ooOol00Goo000?Ool2002HOolR
O1l00`00O1ml7`0?O1l2000EO1lVOol30003Ool000moo`03001oogoo09Qoob1l7`03001l7g`O019l
7`03001l7g`O009l7`03001l7g`O00el7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo7g`O
00<007`OO1l057`O0P000g`O00<007`OO1l037`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2H
OolOO1l00`00O1ml7`0FO1l20002O1l00`00O1ml7`0:O1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo09Uooael7`03001l7g`O01Ul7`<000al7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo
7G`O00<007`OO1l06g`O0P002g`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolLO1l00`00
O1ml7`0GO1l8000:O1lYOol00`00Oomoo`01Ool000moo`8009Yooaal7`03001l7g`O02Ql7bQoo`<0
00=oo`003goo00<007ooOol0VWoo6W`O00<007`OO1l0:G`O:Woo00<007ooOol00Goo000?Ool00`00
Oomoo`2JOolIO1l00`00O1ml7`0QO1l200000g`O001l7`03O1l[Ool00`00Oomoo`01Ool000moo`03
001oogoo09]ooaQl7`03001l7g`O02=l7`03001l7g`O009l7baoo`03001oogoo005oo`003goo00<0
07ooOol0W7oo4g`O00@007`OO1l002El7`03001l7`0000=l7baoo`03001oogoo005oo`003goo00<0
07ooOol0W7oo4g`O00@007`OO1l002Yl7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo4W`O
00<007`O0000:g`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolBO1l00`00O1l00002O1l0
0`00O1ml7`0UO1l^Ool00`00Oomoo`01Ool000moo`8009mooa5l7`800003O1l0000002Ml7beoo`<0
00=oo`003goo00<007ooOol0Wgoo47`O0`00:G`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2P
Ool?O1l01000O1l000009g`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2QOolAO1l00`00O1ml
7`0UO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo0:9ooa1l7`03001l7g`O02Al7c5oo`03001o
ogoo005oo`003goo00<007ooOol0Xgoo3W`O00<007`O000097`O<Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`2SOol>O1l01000O1l000008W`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOol`
O1leOol00`00Oomoo`01Ool000moo`800:Moobel7cEoo`<000=oo`003goo00<007ooOol0Z7oo:W`O
>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOolVO1ljOol00`00Oomoo`01Ool000moo`03001o
ogoo0:]oob=l7caoo`03001oogoo005oo`003goo00<007ooOol0[Goo87`O?Goo00<007ooOol00Goo
0008Ool20005Ool00`00Oomoo`2_OolAO1l20009O1loOol00`00Oomoo`01Ool000Yoo`03001oogoo
009oo`03001oogoo0;9ooa1l7`<0009l7d=oo`03001oogoo005oo`002Goo00<007ooOol00goo0`00
L7ooV`000goo000:Ool00`00Oomoo`02Ool00`00Oomoo`23OolV0ol00`000ol3o`0H0ol200090olk
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo08=oobH3o`040003o`?o0ol3000B
0ol200050ol2000010?o0003o`?o>goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`23OolV0ol01`000ol3o`?o0003o`000103o`8000T3o`040003o`?o0olkOol00`00Oomoo`01Ool0
00moo`03001oogoo08=oobH3o`040003o`?o0ol3000J0ol00`000ol000020olkOol00`00Oomoo`01
Ool000moo`03001oogoo08=oobH3o`050003o`?o0ol0000Q0olkOol00`00Oomoo`01Ool000moo`03
001oogoo08=oobH3o`030003o`?o0083o`8001l3oc]oo`03001oogoo005oo`003goo00<007ooOol0
Pgoo9P?o00<000?o0ol08`?o>goo00<007ooOol00Goo000?Ool20024OolV0ol00`000ol3o`0S0oli
Ool30003Ool000moo`03001oogoo08=oobH3o`030003o`?o02<3oc]oo`03001oogoo005oo`003goo
00<007ooOol0Pgoo9P?o00<000?o0ol08`?o>goo00<007ooOol00Goo000?Ool00`00Oomoo`23OolV
0ol00`000ol3o`0S0olkOol00`00Oomoo`01Ool000moo`03001oogoo08=oobH3o`030003o`?o02<3
oc]oo`03001oogoo005oo`003goo00<007ooOol0Pgoo9P?o00<000?o0ol08`?o>goo00<007ooOol0
0Goo000?Ool00`00Oomoo`23OolV0ol00`000ol3o`0S0olkOol00`00Oomoo`01Ool000moo`03001o
ogoo08=oobH3o`030003o`?o02<3oc]oo`03001oogoo005oo`003goo0P00Q7oo9P?o00<000?o0ol0
8`?o>Goo0`000goo000?Ool00`00Oomoo`2YOol00`00Oomoo`1NOol00`00Oomoo`01Ool000moo`03
001oogoo0:Uoo`03001oogoo05ioo`03001oogoo005oo`003goo00<007ooOol0ZGoo00<007ooOol0
GWoo00<007ooOol00Goo000?Ool00`00Oomoo`2YOol00`00Oomoo`1NOol00`00Oomoo`01Ool000mo
o`03001oogoo0:Uoo`03001oogoo05ioo`03001oogoo005oo`003goo00<007ooOol0ZGoo00<007oo
Ool0GWoo00<007ooOol00Goo000?Ool00`00Oomoo`2YOol00`00Oomoo`1NOol00`00Oomoo`01Ool0
00moo`800:Moo`04001oogoo0002Ool00`00Oomoo`1IOol30003Ool000moo`03001oogoo0:Moo`05
001oo`00Ool0001NOol00`00Oomoo`01Ool000moo`03001oogoo0:Moo`05001oo`00Ool0001NOol0
0`00Oomoo`01Ool000moo`03001oogoo0:Qoo`<005moo`03001oogoo005oo`003goo00<007ooOol0
Z7oo0`00Ggoo00<007ooOol00Goo000?Ool00`00Oomoo`2YOol01000Oomoogoo0P00Fgoo00<007oo
Ool00Goo000?Ool00`00Oomoo`2^Ool00`00Oomoo`1IOol00`00Oomoo`01Ool000moo`800:moo`03
001oogoo05Moo`<000=oo`003goo00<007ooOol0[Goo00<007oo0000FWoo00<007ooOol00Goo000?
Ool00`00Oomoo`2]Ool01000Ool00000FGoo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo10000goo0`00ogoo2Goo0`00
0goo0008Ool00`00Ool00004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`8000Aoo`03
001oogoo0?moo`]oo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`80
0?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000l0
00=oo`0027oo0P00ogoo5goo0008Ool00`00Oomoo`3oOolFOol000Qoo`<00?mooaIoo`00ogoo8Goo
003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.10698 .18476 -61.1779 -6.14943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.24381 .24983 -61.1779 -6.14943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -61.1779 -6.14943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.10698 .18476 m
.14286 .28571 L
.24381 .24983 L
s
.10406 .20854 m
.10698 .18476 L
.12425 .20136 L
s
.22721 .26711 m
.24381 .24983 L
.22003 .24691 L
s
gsave
.10698 .18476 -61.1779 -6.14943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.24381 .24983 -61.1779 -6.14943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -61.1779 -6.14943 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.10698 .18476 m
.14286 .28571 L
.24381 .24983 L
s
.10406 .20854 m
.10698 .18476 L
.12425 .20136 L
s
.22721 .26711 m
.24381 .24983 L
.22003 .24691 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.78292 .71429 m
.78292 .77143 L
.4972 .77143 L
.4972 .71429 L
F
0 g
.01 w
.49992 .43205 m
.78522 .44742 L
s
.02 w
.49992 .43205 Mdot
.78522 .44742 Mdot
gsave
.4338 .32156 -59.8573 -5.85504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.53559 .4338 -59.8573 -5.85504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.8573 -5.85504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.4338 .32156 m
.42857 .42857 L
.53559 .4338 L
s
.42205 .34244 m
.4338 .32156 L
.44345 .34348 L
s
.51366 .44345 m
.53559 .4338 L
.51471 .42205 L
s
gsave
.7472 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64006 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64006 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.7472 .71429 m
.64006 .71429 L
.64006 .82143 L
s
.72578 .70357 m
.7472 .71429 L
.72578 .725 L
s
.62935 .8 m
.64006 .82143 L
.65078 .8 L
s
gsave
.80729 .62463 -61.8854 -3.77191 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66109 .66443 -61.8854 -3.77191 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.8854 -3.77191 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80729 .62463 m
.71429 .57143 L
.66109 .66443 L
s
.79401 .60469 m
.80729 .62463 L
.78337 .62329 L
s
.66243 .64051 m
.66109 .66443 L
.68103 .65115 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
6Woo0`0000=oo`00Ool06goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo
000?Ool00`00Oomoo`0JOol200000goo001oo`0IOol3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1a
Ool00`00Oomoo`01Ool000moo`03001oogoo01Yoo`<00003Ool007oo01Ioo`9l015oo`0301moogoo
04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol06Woo0`005goo0W`04goo00<0
7gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000JOol01@00Ool007oo00004goo
0g`057oo00<07gooOol0C7oo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0IOol01P00Oomo
o`00Ool0011oo`9l01Moo`0301moogoo04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<0
07ooOol06Goo00@007ooOol0011oo`9l01Qoo`0301moogoo04ioo`0301moogoo06moo`03001oogoo
005oo`003goo00<007ooOol06Goo00@007ooOol000eoo`=l01Yoo`0301moogoo04moo`0301moogoo
06ioo`03001oogoo005oo`003goo00<007ooOol07Goo00<007ooOol027oo0W`077oo00<07gooOol0
D7oo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0MOol00`00Oomoo`06Ool2O00N
Ool00`0OOomoo`1AOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo01eoo`03001o
ogoo00=oo`=l021oo`0301moogoo055oo`0301moogoo06eoo`03001oogoo005oo`003goo00<007oo
Ool07Woo00<007ooOol00W`08Woo00<07gooOol0Dgoo00<07gooOol0K7oo00<007ooOol00Goo000?
Ool2000OOol00`00O01l0005O00OOol00`0OOomoo`1COol00`0OOomoo`1ZOol30003Ool000moo`03
001oogoo01eoo`03O00007`000Ioo`=l01]oo`0301moogoo05Aoo`0301moogoo06aoo`03001oogoo
005oo`003goo00<007ooOol077oo0W`000=oo`00Ool027oo0g`067oo00<07gooOol0EGoo00<07goo
Ool0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol2O003Ool00`00Oomoo`0:Ool2O00EOol0
0`0OOomoo`1FOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo
00=oo`03001oogoo00aoo`03O01oogoo011oo`80000301moogoo05Moo`0301moogoo06Yoo`03001o
ogoo005oo`003goo00<007ooOol067oo00=l07ooOol01Goo00<007ooOol037oo00=l07ooOol01Woo
0`001goo00<0000OOol09Goo2`0O:7oo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomo
o`0GOol00g`0Oomoo`06Ool00`00Oomoo`0=Ool00g`0Oomoo`08Ool40003Ool00`0001moo`0TOol>
01lVOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Ioo`03O01oogoo00Moo`03
001oogoo00eoo`03O01oogoo00Moo`@000=oo`0300007`0002Aooa007bEoo`0301moogoo06Yoo`03
001oogoo005oo`003goo0P005goo00=l07ooOol027oo00<007ooOol03Goo00=l07ooOol00goo0`00
0Woo00<007ooOol00Woo00@0000O0000029ooa807bEoo`0301moogoo06Moo`<000=oo`003goo00<0
07ooOol05Goo00=l07ooOol02Goo00<007ooOol03Goo00=l07ooOol00`0017oo00<007ooOol017oo
00<07gooOol08Woo4`0O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol0
0g`0Oomoo`09Ool00`00Oomoo`0=Ool30006Ool00`00Oomoo`05Ool00`0OOomoo`0QOolD01lTOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oogoo00]oo`03001oogoo
00Uoo`<00003Ooml07oo00ioo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005o
o`003goo00<007ooOol057oo00=l07ooOol02goo00<007ooOol01Woo0`0017oo00=l07ooOol03Goo
00<07gooOol08Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool0
0`00Oomoo`0DOol00g`0Oomoo`0;Ool00`00Oomoo`03Ool30008Ool00g`0Oomoo`0<Ool00`0OOomo
o`0POolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo
01Aoo`03O01oogoo00aoo`03001oo`00008000]oo`03O01oogoo00aoo`0301moogoo021ooaH07b=o
o`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo0`0057oo00=l07ooOol037oo
CP002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0
Oomoo`0?Ool2000;Ool00g`0Oomoo`0<Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0O
Oomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo015o
o`03001oogoo00Qoo`03O01oogoo00aoo`0301moogoo021oo`/07`0300007`0O00T07b9oo`0301mo
ogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol04Goo
00<007ooOol01goo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07goo
Ool0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`0?Ool30009Ool00g`0Oomo
o`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00moo`03001oogoo01Eoo`03O01oogoo01Uoo`03O01oogoo00ioo`0301moogoo025oo`X07`030000
7`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol0
6Goo00=l07ooOol03Woo00<07gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0IOol00g`0Oomoo`0>Ool00`0OOomoo`0R
Ool901l00`0001l07`0701lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`8001Moo`03O01o
ogoo01Moo`03O01oogoo00moo`0301moogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qo
o`<000=oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo
1`0O00<0000O01l01@0O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol0
0g`0Oomoo`0EOol00g`0Oomoo`0AOol00`0OOomoo`0SOol701l2000301l200000goo001oo`0SOol0
0`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03O01oogoo01=oo`03O01oogoo
019oo`0301moogoo02Eoo`D07`8000807`=oo`03001oogoo02=oo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol06Goo00=l07ooOol04Goo00=l07ooOol04goo00<07gooOol09goo0`0O
0`000goo00<007oo000097oo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol2
O00@Ool00g`0Oomoo`0DOol00`0OOomoo`0TOol50n0010000n00000010?P9Goo00<07gooOol0Jgoo
00<007ooOol00Goo000?Ool00`00Oomoo`0LOol3O00;Ool2O00HOol00`0OOomoo`0NOol:0n001@00
0n0000?P00001P?P8Woo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0OOol3O004
Ool4O00JOol00`0OOomoo`0LOol;0n001P000n03h0000n0000P3h1moo`0301moogoo06aoo`03001o
ogoo005oo`003goo0P008Woo1G`07goo00<07gooOol06Woo30?P00@000?P0n000083h0030003h0?P
00P3h1aoo`0301moogoo06Yoo`<000=oo`003goo00<007ooOol08goo0W`087oo00<07gooOol067oo
4@?P00<000?P0n0030?P6Woo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0UOol3
O00NOol00`0OOomoo`0FOolB0n000`000n03h00=0n0IOol00`0OOomoo`1]Ool00`00Oomoo`01Ool0
00moo`03001oogoo02Qoo`9l01aoo`0301moogoo01Eooa<3h0030003h0?P00h3h1Moo`0301moogoo
06ioo`03001oogoo005oo`003goo00<007ooOol0:Woo0W`06Woo00<07gooOol04goo5@?P00<000?P
0n003`?P5Woo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0/Ool2O00IOol00`0O
Oomoo`0BOolE0n000`000n03h00A0n0COol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001o
ogoo02ioo`=l01Moo`0301moogoo015ooaD3h0030003h0?P0183h19oo`0301moogoo06moo`03001o
ogoo005oo`003goo0P00<Woo0W`05Goo00<07gooOol047oo5P?P00<000?P0n004P?P4Goo00<07goo
Ool0KWoo0`000goo000?Ool00`00Oomoo`0cOol2O00DOol00`0OOomoo`0>OolG0n000`000n03h00B
0n0AOol00`0OOomoo`1`Ool00`00Oomoo`01Ool000moo`03001oogoo03Eoo`9l019oo`0301moogoo
00eooaL3h0030003h0?P01@3h0moo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0
=goo0g`047oo00<07gooOol037oo5`?P00<000?P0n005@?P3Woo00<07gooOol0LGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0jOol2O00>Ool00`0OOomoo`0;OolH0n000`000n03h00F0n0<Ool00`0O
Oomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo03aoo`9l00eoo`0301moogoo00YooaP3h003
0003h0?P01H3h0aoo`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol0?Woo0W`037oo
00<07gooOol02Goo60?P00<000?P0n005`?P2Woo00<07gooOol0Lgoo00<007ooOol00Goo000?Ool0
0`00Oomoo`10Ool2O00;Ool00`0OOomoo`07OolI0n000`000n03h00G0n09Ool00`0OOomoo`1dOol0
0`00Oomoo`01Ool000moo`8004=oo`=l00Qoo`0301moogoo00MooaT3h0030003h0?P01L3h0Qoo`03
01moogoo07=oo`<000=oo`003goo00<007ooOol0AGoo0W`01goo00<07gooOol01Goo6P?P00<000?P
0n005`?P27oo00<07gooOol0MGoo00<007ooOol00Goo000?Ool00`00Oomoo`17Ool2O006Ool201l5
OolJ0n000`000n03h00G0n06Ool201mhOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l00Io
o`0301moogoo009ooaX3h0030003h0?P01P3h0Aoo`0301moogoo07Qoo`03001oogoo005oo`003goo
00<007ooOol0Bgoo0g`017oo00<07gooOol06`?P00<000?P0n0060?P0goo00<07gooOol0NGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`1>Ool2O003Ool00`0OOol3h00J0n000`000n03h00H0n02Ool0
0`0OOomoo`1jOol00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo051oo`9l009oo`0301l3h0?P
01T3h0030003h0?P01@3h0060003h0?P0n1oo`0OOGoo00<007ooOol00Goo0009Ool00`00Oomoo`03
Ool00`00Oomoo`1BOol2O0000goo0n03h00I0n000`000n03h00E0n0200000`?P01moo`04Ool2001g
Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<005Aoo`03O003h0?P01T3h0l000<3h08000H3
h08000Ioo`03001oogoo07=oo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0EGoo7`?P0`00
20?P60007Goo4G`OAGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolO0n00
0`000n00000:0n0Y0007OolHO1m1Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo05Eoob03
h0030003h0?P00X3h08000D3h08000Ioo`04001oo`000002OolV000@O1lmOol00`00Oomoo`01Ool0
00moo`03001oogoo05Eoob03h0030003h0?P00l3h0800083h1moobL003Uoo`03001oogoo005oo`00
3goo00<007ooOol0EWoo=0?P87oo4g`O5@00>7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOold
0n0NOolVO1l4000hOol00`00Oomoo`01Ool000moo`8005Qooc<3h1aoobUl7`80009l7cEoo`<000=o
o`003goo00<007ooOol0Egoo<`?P6goo<7`O=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolc
0n0IOolcO1ldOol00`00Oomoo`01Ool000moo`03001oogoo05Qooc43h1YoocAl7c=oo`03001oogoo
005oo`003goo00<007ooOol0F7oo<@?P6Goo=W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1I
Ool`0n0HOolhO1laOol00`00Oomoo`01Ool000moo`03001oogoo05Uoobl3h1QoocYl7c1oo`03001o
ogoo005oo`003goo00<007ooOol0FGoo;P?P67oo?7`O;goo00<007ooOol00Goo000?Ool2001KOol/
0n0HOolmO1l]Ool30003Ool000moo`03001oogoo05]oob/3h1Moocml7bioo`03001oogoo005oo`00
3goo00<007ooOol0G7oo:@?P67oo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n0H
Oom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05eoobH3h1Uood9l7baoo`03001oogoo005o
o`003goo00<007ooOol0GWoo90?P6Goo@g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR
0n0IOom5O1l[Ool00`00Oomoo`01Ool000moo`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo
005oo`003goo0P00I7oo6`?P6gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lY
Ool00`00Oomoo`01Ool000moo`03001oogoo06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo
00<007ooOol0JWoo3@?P8WooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9
O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<0
07ooOol0V7ooBW`O:7oo00<007ooOol00Goo000?Ool2002IOom:O1lVOol30003Ool000moo`03001o
ogoo09Mood]l7bQoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo
000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03
001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00
Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMo
o`03001oogoo005oo`002Goo00<007ooOol00goo0`00UWoo9g`O00<007`OO1l08g`O9Goo0`000goo
0009Ool00`00Oomoo`03Ool00`00Oomoo`2FOolVO1l01000O1l000008g`O9goo00<007ooOol00Goo
0008Ool00`00Ool00004Ool00`00Oomoo`2FOolVO1l00`00O1ml7`03000QO1lWOol00`00Oomoo`01
Ool000Uoo`03001oogoo00=oo`03001oogoo09MoobAl7`03001l7g`O00=l7`<001ml7bMoo`03001o
ogoo005oo`003goo00<007ooOol0Ugoo97`O00<007`OO1l00g`O00<007`OO1l00P007G`O9goo00<0
07ooOol00Goo000?Ool00`00Oomoo`2GOolSO1l00`00O1ml7`02O1l20005O1l00`00O1ml7`0JO1lW
Ool00`00Oomoo`01Ool000moo`03001oogoo09Moob9l7`03001l7g`O00=l7`<000El7`8001Yl7bMo
o`03001oogoo005oo`003goo00<007ooOol0Ugoo8W`O00<007`OO1l03G`O0P0067`O9goo00<007oo
Ool00Goo000?Ool2002HOolQO1l00`00O1ml7`0@O1l2000EO1lVOol30003Ool000moo`03001oogoo
09Qoob1l7`03001l7g`O019l7`03001l7g`O009l7`03001l7g`O00el7bQoo`03001oogoo005oo`00
3goo00<007ooOol0V7oo7g`O00<007`OO1l057`O0P000g`O00<007`OO1l037`O:7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`2HOolNO1l00`00O1ml7`0GO1l20002O1l00`00O1ml7`0:O1lYOol00`00
Oomoo`01Ool000moo`03001oogoo09Uooael7`03001l7g`O01Ul7`<000al7bUoo`03001oogoo005o
o`003goo00<007ooOol0VGoo77`O00<007`OO1l077`O0P002g`O:Goo00<007ooOol00Goo000?Ool0
0`00Oomoo`2IOolLO1l00`00O1ml7`0GO1l8000:O1lYOol00`00Oomoo`01Ool000moo`8009Yooa]l
7`03001l7g`O02Ul7bQoo`<000=oo`003goo00<007ooOol0VWoo6G`O00<007`OO1l0:W`O:Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`2JOolIO1l00`00O1ml7`0QO1l200000g`O001l7`03O1l[Ool0
0`00Oomoo`01Ool000moo`03001oogoo09]ooaMl7`03001l7g`O02Al7`03001l7g`O009l7baoo`03
001oogoo005oo`003goo00<007ooOol0W7oo4g`O00@007`OO1l002El7`03001l7`0000=l7baoo`03
001oogoo005oo`003goo00<007ooOol0W7oo4g`O00<007`O0000:g`O;Goo00<007ooOol00Goo000?
Ool00`00Oomoo`2MOolBO1l2000/O1l]Ool00`00Oomoo`01Ool000moo`03001oogoo09eooa5l7`03
001l7`0000=l7`03001l7g`O02El7bioo`03001oogoo005oo`003goo0P00Wgoo47`O0P000W`O0P00
9g`O;Goo0`000goo000?Ool00`00Oomoo`2OOol?O1l4000YO1l_Ool00`00Oomoo`01Ool000moo`03
001oogoo0:1oo`il7`800003O1l0000002Ml7c1oo`03001oogoo005oo`003goo00<007ooOol0XGoo
4G`O00<007`OO1l09G`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ROol@O1l00`00O1ml7`0T
O1laOol00`00Oomoo`01Ool000moo`03001oogoo0:=oo`il7`03001l7`0002Al7c9oo`03001oogoo
005oo`003goo00<007ooOol0Xgoo3W`O00@007`O0000029l7c=oo`03001oogoo005oo`003goo00<0
07ooOol0YGoo<7`O=Goo00<007ooOol00Goo000?Ool2002WOol]O1leOol30003Ool000moo`03001o
ogoo0:QoobYl7cQoo`03001oogoo005oo`003goo00<007ooOol0ZWoo9W`O>Woo00<007ooOol00Goo
000?Ool00`00Oomoo`2[OolSO1llOol00`00Oomoo`01Ool000moo`03001oogoo0:eoob1l7ceoo`03
001oogoo005oo`0027oo0P001Goo00<007ooOol0[goo4G`O0P002G`O?goo00<007ooOol00Goo000:
Ool00`00Oomoo`02Ool00`00Oomoo`2bOol@O1l30002O1m3Ool00`00Oomoo`01Ool000Uoo`03001o
ogoo00=oo`<0071ooi/000=oo`002Woo00<007ooOol00Woo00<007ooOol0PWoo9`?o00<000?o0ol0
60?o0P002@?o>goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`22OolW0ol01000
0ol3o`?o0`004P?o0P001@?o0P0000@3o`000ol3oc]oo`03001oogoo005oo`002Goo00<007ooOol0
0goo00<007ooOol0PWoo9`?o00L000?o0ol3o`000ol0000@0ol200090ol010000ol3o`?o>goo00<0
07ooOol00Goo000?Ool00`00Oomoo`22OolW0ol010000ol3o`?o0`006P?o00<000?o00000P?o>goo
00<007ooOol00Goo000?Ool00`00Oomoo`22OolW0ol01@000ol3o`?o00008@?o>goo00<007ooOol0
0Goo000?Ool00`00Oomoo`22OolW0ol00`000ol3o`020ol2000O0olkOol00`00Oomoo`01Ool000mo
o`03001oogoo089oobL3o`030003o`?o02<3oc]oo`03001oogoo005oo`003goo0P00Pgoo9`?o00<0
00?o0ol08`?o>Goo0`000goo000?Ool00`00Oomoo`22OolW0ol00`000ol3o`0S0olkOol00`00Oomo
o`01Ool000moo`03001oogoo089oobL3o`030003o`?o02<3oc]oo`03001oogoo005oo`003goo00<0
07ooOol0PWoo9`?o00<000?o0ol08`?o>goo00<007ooOol00Goo000?Ool00`00Oomoo`22OolW0ol0
0`000ol3o`0S0olkOol00`00Oomoo`01Ool000moo`03001oogoo089oobL3o`030003o`?o02<3oc]o
o`03001oogoo005oo`003goo00<007ooOol0PWoo9`?o00<000?o0ol08`?o>goo00<007ooOol00Goo
000?Ool00`00Oomoo`22OolW0ol00`000ol3o`0S0olkOol00`00Oomoo`01Ool000moo`8008=oobL3
o`030003o`?o02<3ocUoo`<000=oo`003goo00<007ooOol0ZGoo00<007ooOol0GWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`2YOol00`00Oomoo`1NOol00`00Oomoo`01Ool000moo`03001oogoo0:Uo
o`03001oogoo05ioo`03001oogoo005oo`003goo00<007ooOol0ZGoo00<007ooOol0GWoo00<007oo
Ool00Goo000?Ool00`00Oomoo`2YOol00`00Oomoo`1NOol00`00Oomoo`01Ool000moo`03001oogoo
0:Uoo`03001oogoo05ioo`03001oogoo005oo`003goo00<007ooOol0ZGoo00<007ooOol0GWoo00<0
07ooOol00Goo000?Ool2002WOol01000Oomoo`000Woo00<007ooOol0FGoo0`000goo000?Ool00`00
Oomoo`2WOol01@00Ool007oo0000GWoo00<007ooOol00Goo000?Ool00`00Oomoo`2WOol01@00Ool0
07oo0000GWoo00<007ooOol00Goo000?Ool00`00Oomoo`2XOol3001OOol00`00Oomoo`01Ool000mo
o`03001oogoo0:Qoo`<005moo`03001oogoo005oo`003goo00<007ooOol0ZGoo00@007ooOomoo`80
05]oo`03001oogoo005oo`003goo00<007ooOol0[Woo00<007ooOol0FGoo00<007ooOol00Goo000?
Ool2002_Ool00`00Oomoo`1GOol30003Ool000moo`03001oogoo0:eoo`03001oo`0005Yoo`03001o
ogoo005oo`003goo00<007ooOol0[Goo00@007oo000005Uoo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`002Goo0`000goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`@000=oo`<0
0?moo`Uoo`<000=oo`0027oo00<007oo000017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0009
Ool20004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Goo000:Ool00`00Oomo
o`02Oooo000?0003Ool000Qoo`800?mooaMoo`0027oo00<007ooOol0ogoo5Woo0008Ool3003oOolF
Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.19215 .19058 -58.9562 -5.38504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.23799 .33501 -58.9562 -5.38504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -58.9562 -5.38504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.19215 .19058 m
.14286 .28571 L
.23799 .33501 L
s
.17278 .20468 m
.19215 .19058 L
.1918 .21454 L
s
.21403 .33466 m
.23799 .33501 L
.22389 .31564 L
s
gsave
.19215 .19058 -58.9562 -5.38504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.23799 .33501 -58.9562 -5.38504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -58.9562 -5.38504 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.19215 .19058 m
.14286 .28571 L
.23799 .33501 L
s
.17278 .20468 m
.19215 .19058 L
.1918 .21454 L
s
.21403 .33466 m
.23799 .33501 L
.22389 .31564 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.78364 .71429 m
.78364 .77143 L
.49792 .77143 L
.49792 .71429 L
F
0 g
.01 w
.49983 .4237 m
.78459 .44707 L
s
.02 w
.49983 .4237 Mdot
.78459 .44707 Mdot
gsave
.42126 .32168 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.53546 .42126 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.42126 .32168 m
.42857 .42857 L
.53546 .42126 L
s
.41203 .34379 m
.42126 .32168 L
.43341 .34233 L
s
.51482 .43341 m
.53546 .42126 L
.51335 .41203 L
s
gsave
.74792 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64078 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64078 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.74792 .71429 m
.64078 .71429 L
.64078 .82143 L
s
.72649 .70357 m
.74792 .71429 L
.72649 .725 L
s
.63007 .8 m
.64078 .82143 L
.65149 .8 L
s
gsave
.80756 .62416 -61.8648 -3.77361 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66156 .6647 -61.8648 -3.77361 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.8648 -3.77361 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80756 .62416 m
.71429 .57143 L
.66156 .6647 L
s
.79417 .60428 m
.80756 .62416 L
.78363 .62294 L
s
.66278 .64077 m
.66156 .6647 L
.68143 .65132 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo031o
o`03001oogoo009oo`800003O00007oo00moo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo
005oo`003goo00<007ooOol0;goo0P000goo0W`000=oo`00Ool047oo00<07gooOol0Bgoo00<07goo
Ool0L7oo00<007ooOol00Goo000?Ool2000^Ool40003O002Ool00`00Ool0000?Ool00`0OOomoo`1<
Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02aoo`05001oo`00O000000GOol00`0OOomo
o`1=Ool00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02]oo`06001oog`0001oo`00
5Woo00<07gooOol0CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O000
1000Oomoo`005Woo00<07gooOol0Cgoo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomo
o`0XOol2O003Ool01000Oomoo`005Goo00<07gooOol0D7oo00<07gooOol0KWoo00<007ooOol00Goo
000?Ool00`00Oomoo`0VOol2O004Ool00`00Oomoo`0GOol00`0OOomoo`1AOol00`0OOomoo`1]Ool0
0`00Oomoo`01Ool000moo`03001oogoo02=oo`=l00Ioo`03001oogoo01Moo`0301moogoo055oo`03
01moogoo06eoo`03001oogoo005oo`003goo00<007ooOol08Goo0W`027oo00<007ooOol05goo00<0
7gooOol0Dgoo00<07gooOol0K7oo00<007ooOol00Goo000?Ool2000POol7O005Ool00`00Oomoo`0G
Ool00`0OOomoo`1COol00`0OOomoo`1ZOol30003Ool000moo`03001oogoo01eoo`=l00Ioo`=l0003
Ool007oo01Qoo`0301moogoo05Aoo`0301moogoo06aoo`03001oogoo005oo`003goo00<007ooOol0
77oo0W`02goo00=l0000O00067oo00<07gooOol0EGoo00<07gooOol0Jgoo00<007ooOol00Goo000?
Ool00`00Oomoo`0JOol2O00=Ool00`00Oomoo`02O00EOol00`0OOomoo`1FOol00`0OOomoo`1[Ool0
0`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo00eoo`03001oogoo009oo`03O01oogoo
019oo`0301moogoo05Moo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol067oo00=l
07ooOol03Goo00<007ooOol017oo00=l07ooOol04Goo00<07gooOol097oo2`0O:7oo00<07gooOol0
JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0>Ool00`00Oomoo`05Ool00g`0
Oomoo`0@Ool00`0OOomoo`0SOol>01lVOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001o
ogoo01Ioo`03O01oogoo00ioo`03001oogoo00Ioo`03O01oogoo00moo`0301moogoo02=ooa007bEo
o`0301moogoo06Yoo`03001oogoo005oo`003goo0P005goo00=l07ooOol03Woo00<007ooOol01goo
00=l07ooOol03Woo00<07gooOol08Woo4P0O9Goo00<07gooOol0Igoo0`000goo000?Ool00`00Oomo
o`0EOol00g`0Oomoo`0>Ool00`00Oomoo`08Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROolC01lTOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01oogoo00ioo`03001oogoo
00Uoo`03O01oogoo00eoo`0301moogoo025ooa@07bAoo`0301moogoo06Uoo`03001oogoo005oo`00
3goo00<007ooOol057oo00=l07ooOol03Woo00<007ooOol02Woo00=l07ooOol03Goo00<07gooOol0
8Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`0>
Ool00`00Oomoo`0:Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03O01oogoo00eoo`03001oogoo00ao
o`03O01oogoo00aoo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo
00<007oo000017oo00<007ooOol057oo00=l07ooOol03Goo00<007ooOol037oo00=l07ooOol037oo
00<07gooOol087oo5P0O8goo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool3
000DOol00g`0Oomoo`0<Oom>000:01lSOol00`0OOomoo`1WOol30003Ool000Qoo`03001oo`0000Ao
o`03001oogoo01Aoo`03O01oogoo00eoo`80009oo`<000Qoo`03O01oogoo00aoo`0301moogoo021o
o`/07`0300007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo
00<007ooOol057oo00=l07ooOol03goo10002Goo00=l07ooOol037oo00<07gooOol087oo2`0O00<0
000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`0DOol00g`0Oomoo`0AOol30007Ool00g`0Oomoo`0=Ool00`0OOomoo`0POol;01l00`0001l07`08
01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oogoo01=oo`80
00Ioo`03O01oogoo00eoo`0301moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol047oo0`0000=oo`0000000goo00=l07oo
Ool03Woo00<07gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo
000?Ool00`00Oomoo`0EOol00g`0Oomoo`0FOol200000gooO01oo`0?Ool00`0OOomoo`0QOol:01l0
0`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01o
ogoo01Qoo`03001l07oo00moo`0301moogoo029oo`T07`0300007`0O00L07bAoo`0301moogoo06Uo
o`03001oogoo005oo`003goo0P005goo00=l07ooOol05goo00=l000000001Woo00<007ooOol01Woo
00<07gooOol08goo200O00<0000O01l01P0O97oo00<07gooOol0J7oo0`000goo000?Ool00`00Oomo
o`0GOol00g`0Oomoo`0FOol00g`0Oomoo`020005Ool00`00Oomoo`06Ool00`0OOomoo`0SOol701l0
0`0001l07`0501lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Moo`03O01o
ogoo01Eoo`03O01oogoo00=oo`8000=oo`03001oogoo00Ioo`0301moogoo02=oo`D07`0300007`00
0080000301l0000O02Moo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol067oo00=l
07ooOol04goo00=l07ooOol01Woo0P000Woo00<007ooOol01Goo00<07gooOol09Goo0`0O00<0000O
00000P0O00<007ooOol09goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol0
0g`0Oomoo`0AOol00g`0Oomoo`09Ool200000goo001oo`04Ool2000YOol40000100O001oo`00:7oo
00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol2O00@Ool00g`0Oomoo`0<Ool2
0006Ool00`00Oomoo`0TOol30n0300070n0UOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03
001oogoo01aoo`=l00]oo`9l00Yoo`P000Eoo`0300007goo01moo`P3h08000030n0000?P00P3h29o
o`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol07goo0g`017oo17`067oo00<007oo
00007Woo2@?P00D000?P0003h00000/3h1moo`0301moogoo06aoo`03001oogoo005oo`003goo0P00
8Woo1G`077oo00@007oo000001aoo`X3h0030003h0000083h0030003h0?P00/3h1aoo`0301moogoo
06Yoo`<000=oo`003goo00<007ooOol08goo0W`087oo00<07gooOol067oo3P?P00<000?P0n003`?P
6Woo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0UOol3O00NOol00`0OOomoo`0F
Ool@0n000`000n03h00?0n0IOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02Qo
o`9l01aoo`0301moogoo01Eooa43h0030003h0?P0103h1Moo`0301moogoo06ioo`03001oogoo005o
o`003goo00<007ooOol0:Woo0W`06Woo00<07gooOol04goo4`?P00<000?P0n004@?P5Woo00<07goo
Ool0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0/Ool2O00IOol00`0OOomoo`0BOolC0n000`00
0n03h00C0n0COol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02ioo`=l01Moo`03
01moogoo015ooa<3h0030003h0?P01@3h19oo`0301moogoo06moo`03001oogoo005oo`003goo0P00
<Woo0W`05Goo00<07gooOol047oo50?P00<000?P0n0050?P4Goo00<07gooOol0KWoo0`000goo000?
Ool00`00Oomoo`0cOol2O00DOol00`0OOomoo`0>OolE0n000`000n03h00D0n0AOol00`0OOomoo`1`
Ool00`00Oomoo`01Ool000moo`03001oogoo03Eoo`9l019oo`0301moogoo00eooaH3h0030003h0?P
01D3h0moo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=goo0g`047oo00<07goo
Ool037oo5P?P00<000?P0n005P?P3Woo00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomo
o`0jOol2O00>Ool00`0OOomoo`0;OolG0n000`000n03h00G0n0<Ool00`0OOomoo`1bOol00`00Oomo
o`01Ool000moo`03001oogoo03aoo`9l00eoo`0301moogoo00YooaL3h0030003h0?P01L3h0aoo`03
01moogoo079oo`03001oogoo005oo`003goo00<007ooOol0?Woo0W`037oo00<07gooOol02Goo5`?P
00<000?P0n0060?P2Woo00<07gooOol0Lgoo00<007ooOol00Goo000?Ool00`00Oomoo`10Ool2O00;
Ool00`0OOomoo`07OolH0n000`000n03h00H0n09Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000mo
o`8004=oo`=l00Qoo`0301moogoo00MooaP3h0030003h0?P01P3h0Qoo`0301moogoo07=oo`<000=o
o`003goo00<007ooOol0AGoo0W`01goo00<07gooOol01Goo6P?P00<000?P0n005`?P27oo00<07goo
Ool0MGoo00<007ooOol00Goo000?Ool00`00Oomoo`17Ool2O006Ool201l5OolJ0n000`000n03h00G
0n06Ool201mhOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l00Ioo`0301moogoo009ooaX3
h0030003h0?P01@3h0040003h0?P0n04Ool00`0OOomoo`1hOol00`00Oomoo`01Ool000moo`03001o
ogoo04]oo`=l00Aoo`0301moogoo01/3h0030003h0?P01D3h08000060n1oogooOol07goo0P00N7oo
00<007ooOol00Goo000?Ool00`00Oomoo`1>Ool2O003Ool00`0OOol3h00J0n000`000n03h00?0n00
0`000n03h0050n0200000goo01moo`02Ool00`00Oomoo`1fOol00`00Oomoo`01Ool000Moo`D000=o
o`03001oogoo051oo`9l009oo`0301l3h0?P01T3h0030003h0?P00l3h0`000=oo`03001oogoo07Io
o`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0DWoo0W`000=oo`?P0n006@?P00<0
00?P0n001@?P8@00LGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001DOol00g`00n03h00I
0n0800090n0400040n020003OolF001TOol30003Ool000Uoo`03001oogoo00=oo`03001oogoo05Eo
oal3h0<000/3h08000<3h0800083h0iooaL000Aooa5l7dEoo`03001oogoo005oo`002Goo00<007oo
Ool00goo00<007ooOol0EGoo7`?P00<000?P000050?P6Goo5`003W`O@Goo00<007ooOol00Goo0008
Ool20005Ool00`00Oomoo`1EOolP0n000`000n03h00C0n0ROol3O1lF0007O1lmOol00`00Oomoo`01
Ool000moo`03001oogoo05Eoob03h0030003h0?P01<3h21ooa1l7aH003Uoo`03001oogoo005oo`00
3goo00<007ooOol0EWoo=0?P87oo77`O3000>7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOold
0n0NOolVO1l4000hOol00`00Oomoo`01Ool000moo`8005Qooc<3h1aoobUl7`80009l7cEoo`<000=o
o`003goo00<007ooOol0Egoo<`?P6goo<7`O=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolc
0n0IOolcO1ldOol00`00Oomoo`01Ool000moo`03001oogoo05Qooc43h1YoocAl7c=oo`03001oogoo
005oo`003goo00<007ooOol0F7oo<@?P6Goo=W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1I
Ool`0n0HOolhO1laOol00`00Oomoo`01Ool000moo`03001oogoo05Uoobl3h1QoocYl7c1oo`03001o
ogoo005oo`003goo00<007ooOol0FGoo;P?P67oo?7`O;goo00<007ooOol00Goo000?Ool2001KOol/
0n0HOolmO1l]Ool30003Ool000moo`03001oogoo05]oob/3h1Moocml7bioo`03001oogoo005oo`00
3goo00<007ooOol0G7oo:@?P67oo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n0H
Oom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05eoobH3h1Uood9l7baoo`03001oogoo005o
o`003goo00<007ooOol0GWoo90?P6Goo@g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR
0n0IOom5O1l[Ool00`00Oomoo`01Ool000moo`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo
005oo`003goo0P00I7oo6`?P6gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lY
Ool00`00Oomoo`01Ool000moo`03001oogoo06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo
00<007ooOol0JWoo3@?P8WooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9
O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<0
07ooOol0V7ooBW`O:7oo00<007ooOol00Goo000?Ool2002IOom:O1lVOol30003Ool000moo`03001o
ogoo09Mood]l7bQoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo
000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03
001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00
Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMo
o`03001oogoo005oo`002Goo00<007ooOol00goo0`00UWoo9g`O00<007`OO1l08g`O9Goo0`000goo
0009Ool00`00Oomoo`03Ool00`00Oomoo`2FOolVO1l01000O1l000008g`O9goo00<007ooOol00Goo
0008Ool00`00Ool00004Ool00`00Oomoo`2FOolVO1l00`00O1ml7`03000QO1lWOol00`00Oomoo`01
Ool000Uoo`03001oogoo00=oo`03001oogoo09MoobAl7`03001l7g`O00=l7`<001ml7bMoo`03001o
ogoo005oo`003goo00<007ooOol0Ugoo97`O00<007`OO1l00g`O00<007`OO1l00P007G`O9goo00<0
07ooOol00Goo000?Ool00`00Oomoo`2GOolSO1l00`00O1ml7`02O1l20005O1l00`00O1ml7`0JO1lW
Ool00`00Oomoo`01Ool000moo`03001oogoo09Moob=l7`03001l7g`O009l7`<000El7`8001Yl7bMo
o`03001oogoo005oo`003goo00<007ooOol0Ugoo8W`O00<007`OO1l03G`O0P0067`O9goo00<007oo
Ool00Goo000?Ool2002HOolRO1l00`00O1ml7`0?O1l2000EO1lVOol30003Ool000moo`03001oogoo
09Qoob1l7`03001l7g`O019l7`03001l7g`O009l7`03001l7g`O00el7bQoo`03001oogoo005oo`00
3goo00<007ooOol0V7oo7g`O00<007`OO1l057`O0P000g`O00<007`OO1l037`O:7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`2HOolOO1l00`00O1ml7`0FO1l20002O1l00`00O1ml7`0:O1lYOol00`00
Oomoo`01Ool000moo`03001oogoo09Uooael7`03001l7g`O01Ul7`<000al7bUoo`03001oogoo005o
o`003goo00<007ooOol0VGoo7G`O00<007`OO1l06g`O0P002g`O:Goo00<007ooOol00Goo000?Ool0
0`00Oomoo`2IOolLO1l00`00O1ml7`0GO1l8000:O1lYOol00`00Oomoo`01Ool000moo`8009Yooaal
7`03001l7g`O02Ql7bQoo`<000=oo`003goo00<007ooOol0VWoo6W`O00<007`OO1l0:G`O:Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`2JOolIO1l00`00O1ml7`0QO1l200000g`O001l7`03O1l[Ool0
0`00Oomoo`01Ool000moo`03001oogoo09]ooaQl7`03001l7g`O02=l7`03001l7g`O009l7baoo`03
001oogoo005oo`003goo00<007ooOol0W7oo4g`O00@007`OO1l002El7`03001l7`0000=l7baoo`03
001oogoo005oo`003goo00<007ooOol0W7oo4g`O00@007`OO1l002Yl7beoo`03001oogoo005oo`00
3goo00<007ooOol0WGoo4W`O00<007`O0000:g`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2M
OolBO1l00`00O1l00002O1l00`00O1ml7`0UO1l^Ool00`00Oomoo`01Ool000moo`8009mooa5l7`80
0003O1l0000002Ml7beoo`<000=oo`003goo00<007ooOol0Wgoo47`O0`00:G`O;goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2POol?O1l01000O1l000009g`O<7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2QOolAO1l00`00O1ml7`0UO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo0:9ooa1l7`03
001l7g`O02Al7c5oo`03001oogoo005oo`003goo00<007ooOol0Xgoo3W`O00<007`O000097`O<Woo
00<007ooOol00Goo000?Ool00`00Oomoo`2SOol>O1l01000O1l000008W`O<goo00<007ooOol00Goo
000?Ool00`00Oomoo`2UOol`O1leOol00`00Oomoo`01Ool000moo`800:Moobel7cEoo`<000=oo`00
3goo00<007ooOol0Z7oo:W`O>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOolVO1ljOol00`00
Oomoo`01Ool000moo`03001oogoo0:]oob=l7caoo`03001oogoo005oo`003goo00<007ooOol0[Goo
87`O?Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`2_OolAO1l20009O1loOol00`00Oomo
o`01Ool000Yoo`03001oogoo009oo`03001oogoo0;9ooa1l7`<0009l7d=oo`03001oogoo005oo`00
2Goo00<007ooOol00goo0`00L7ooV`000goo000:Ool00`00Oomoo`02Ool00`00Oomoo`23OolV0ol0
0`000ol3o`0H0ol200090olkOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo08=o
obH3o`040003o`?o0ol3000B0ol200050ol2000010?o0003o`?o>goo00<007ooOol00Goo0009Ool0
0`00Oomoo`03Ool00`00Oomoo`23OolV0ol01`000ol3o`?o0003o`000103o`8000T3o`040003o`?o
0olkOol00`00Oomoo`01Ool000moo`03001oogoo08=oobH3o`040003o`?o0ol3000J0ol00`000ol0
00020olkOol00`00Oomoo`01Ool000moo`03001oogoo08=oobH3o`050003o`?o0ol0000Q0olkOol0
0`00Oomoo`01Ool000moo`03001oogoo08=oobH3o`030003o`?o0083o`8001l3oc]oo`03001oogoo
005oo`003goo00<007ooOol0Pgoo9P?o00<000?o0ol08`?o>goo00<007ooOol00Goo000?Ool20024
OolV0ol00`000ol3o`0S0oliOol30003Ool000moo`03001oogoo08=oobH3o`030003o`?o02<3oc]o
o`03001oogoo005oo`003goo00<007ooOol0Pgoo9P?o00<000?o0ol08`?o>goo00<007ooOol00Goo
000?Ool00`00Oomoo`23OolV0ol00`000ol3o`0S0olkOol00`00Oomoo`01Ool000moo`03001oogoo
08=oobH3o`030003o`?o02<3oc]oo`03001oogoo005oo`003goo00<007ooOol0Pgoo9P?o00<000?o
0ol08`?o>goo00<007ooOol00Goo000?Ool00`00Oomoo`23OolV0ol00`000ol3o`0S0olkOol00`00
Oomoo`01Ool000moo`03001oogoo08=oobH3o`030003o`?o02<3oc]oo`03001oogoo005oo`003goo
0P00Q7oo9P?o00<000?o0ol08`?o>Goo0`000goo000?Ool00`00Oomoo`2YOol00`00Oomoo`1NOol0
0`00Oomoo`01Ool000moo`03001oogoo0:Uoo`03001oogoo05ioo`03001oogoo005oo`003goo00<0
07ooOol0ZGoo00<007ooOol0GWoo00<007ooOol00Goo000?Ool00`00Oomoo`2YOol00`00Oomoo`1N
Ool00`00Oomoo`01Ool000moo`03001oogoo0:Uoo`03001oogoo05ioo`03001oogoo005oo`003goo
00<007ooOol0ZGoo00<007ooOol0GWoo00<007ooOol00Goo000?Ool00`00Oomoo`2YOol00`00Oomo
o`1NOol00`00Oomoo`01Ool000moo`800:Moo`04001oogoo0002Ool00`00Oomoo`1IOol30003Ool0
00moo`03001oogoo0:Moo`05001oo`00Ool0001NOol00`00Oomoo`01Ool000moo`03001oogoo0:Mo
o`05001oo`00Ool0001NOol00`00Oomoo`01Ool000moo`03001oogoo0:Qoo`<005moo`03001oogoo
005oo`003goo00<007ooOol0Z7oo0`00Ggoo00<007ooOol00Goo000?Ool00`00Oomoo`2YOol01000
Oomoogoo0P00Fgoo00<007ooOol00Goo000?Ool00`00Oomoo`2^Ool00`00Oomoo`1IOol00`00Oomo
o`01Ool000moo`800:moo`03001oogoo05Moo`<000=oo`003goo00<007ooOol0[Goo00<007oo0000
FWoo00<007ooOol00Goo000?Ool00`00Oomoo`2]Ool01000Ool00000FGoo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo
10000goo0`00ogoo2Goo0`000goo0008Ool00`00Ool00004Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000Uoo`8000Aoo`03001oogoo0?moo`]oo`03001oogoo005oo`002Woo00<007ooOol00Woo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`01Ool000Yo
o`03001oogoo009oool000l000=oo`0027oo0P00ogoo5goo0008Ool00`00Oomoo`3oOolFOol000Qo
o`<00?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.24603 .25681 -59.3019 -4.37619 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.17176 .38888 -59.3019 -4.37619 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -59.3019 -4.37619 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.24603 .25681 m
.14286 .28571 L
.17176 .38888 L
s
.2225 .25227 m
.24603 .25681 L
.22828 .27291 L
s
.15567 .37114 m
.17176 .38888 L
.1763 .36536 L
s
gsave
.24603 .25681 -59.3019 -4.37619 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.17176 .38888 -59.3019 -4.37619 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -59.3019 -4.37619 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.24603 .25681 m
.14286 .28571 L
.17176 .38888 L
s
.2225 .25227 m
.24603 .25681 L
.22828 .27291 L
s
.15567 .37114 m
.17176 .38888 L
.1763 .36536 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.78564 .71429 m
.78564 .77143 L
.49993 .77143 L
.49993 .71429 L
F
0 g
.01 w
.49878 .41541 m
.78284 .44609 L
s
.02 w
.49878 .41541 Mdot
.78284 .44609 Mdot
gsave
.40882 .32326 -60.6043 -6.05046 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.53388 .40882 -60.6043 -6.05046 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -60.6043 -6.05046 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.40882 .32326 m
.42857 .42857 L
.53388 .40882 L
s
.40224 .3463 m
.40882 .32326 L
.4233 .34235 L
s
.51479 .4233 m
.53388 .40882 L
.51084 .40224 L
s
gsave
.74993 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64279 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64279 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.74993 .71429 m
.64279 .71429 L
.64279 .82143 L
s
.7285 .70357 m
.74993 .71429 L
.7285 .725 L
s
.63207 .8 m
.64279 .82143 L
.6535 .8 L
s
gsave
.80829 .62284 -61.8076 -3.77851 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66287 .66543 -61.8076 -3.77851 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.8076 -3.77851 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80829 .62284 m
.71429 .57143 L
.66287 .66543 L
s
.79463 .60316 m
.80829 .62284 L
.78435 .62196 L
s
.66375 .64149 m
.66287 .66543 L
.68255 .65177 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol01Woo0P0027oo00<07gooOol0
8goo3P0O9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0G
Ool00g`0Oomoo`08Ool30004Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01
Ool000moo`8001Moo`03O01oogoo01Qoo`03O01oogoo00Yoo`80009oo`0301moogoo029ooa807bEo
o`0301moogoo06Moo`<000=oo`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol01Woo
1@000goo00D07`00001oo`00021ooa<07bAoo`0301moogoo06Uoo`03001oogoo005oo`003goo00<0
07ooOol05Goo00=l07ooOol06Woo00Al07ooOomoo`@0009oo`8000Aoo`0401moogoo000POolD01lT
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oogoo01]oo`@000Eo
o`03001oogoo00Aoo`0501moo`00Ool0000OOolE01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00moo`03001oogoo01Aoo`03O01oogoo01Moo`@00003O01oogoo00Eoo`03001oogoo00Eoo`0301mo
ogoo025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007oo
Ool057oo00=l07ooOol04goo10001Goo00=l07ooOol037oo00<07gooOol087oo5P0O8goo00<07goo
Ool0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0?Ool4
0009Ool00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00Qoo`03001oo`0000Aoo`<001Aoo`03O01oogoo00aoodh000X07b=oo`0301moogoo06Moo`<000=o
o`0027oo00<007oo000017oo00<007ooOol057oo00=l07ooOol037oo00<007ooOol03Goo00=l07oo
Ool037oo00<07gooOol087oo2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo
0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0=Ool01000Oomoogoo0`0027oo00=l
07ooOol037oo00<07gooOol087oo2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00g`0Oomoo`0=Ool01000Oomoogoo0P0027oo
00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007oo
Ool00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
0g`0Oomoo`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomo
o`01Ool000moo`03001oogoo01Eoo`03O01oogoo00aoo`03001oogoo00=oo`03001oogoo00Aoo`03
O01oogoo00ioo`0301moogoo025oo`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo
005oo`003goo00<007ooOol05Goo00=l07ooOol03Goo00<007ooOol00`001Woo00=l07ooOol03Woo
00<07gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0EOol00g`0Oomoo`0=Ool00`00Oomoo`09Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROol9
01l00`0001l07`0701lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo
00aoo`03001oogoo00Qoo`03O01oogoo00moo`0301moogoo02=oo`P07`0300007`0O00H07bAoo`03
01moogoo06Qoo`<000=oo`003goo00<007ooOol05goo00=l07ooOol037oo00<007ooOol01goo00=l
07ooOol047oo00<07gooOol08goo1`0O00<0000O01l01@0O9Goo00<07gooOol0JWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0<Ool00`00Oomoo`06Ool00g`0Oomoo`0AOol00`0O
Oomoo`0SOol201l01P0001l0000001l000D07bMoo`0301moogoo06Yoo`03001oogoo005oo`003goo
00<007ooOol067oo00=l07ooOol02goo00<007ooOol01Goo00=l07ooOol04Woo00<07gooOol09Goo
0P000P0O0P000`0O:Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0
Oomoo`0:Ool00`00Oomoo`04Ool00g`0Oomoo`0COol00`0OOomoo`0TOol300001@0O00007`0001l0
:goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol2O00;Ool00`00Oomoo`02
Ool00g`0Oomoo`0DOol00`0OOomoo`0TOol010000n0000002@?P9Goo00<07gooOol0Jgoo00<007oo
Ool00Goo000?Ool00`00Oomoo`0LOol3O008Ool00`00Oomoo`02O00HOol00`0OOomoo`0NOol50n00
1@000n0000?P00002`?P8Woo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0OOol3
O004Ool017`0001l07`06Woo00<07gooOol077oo1`?P00D000?P0003h00000d3h1moo`0301moogoo
06aoo`03001oogoo005oo`003goo0P008Woo1G`00Woo00<007ooOol06Woo00<07gooOol06Woo1`?P
00@000?P0n000083h0030003h0?P00d3h1aoo`0301moogoo06Yoo`<000=oo`003goo00<007ooOol0
8goo0W`00goo00<007ooOol06Woo00<07gooOol067oo2@?P00@000?P0n0001<3h1Yoo`0301moogoo
06eoo`03001oogoo005oo`003goo00<007ooOol09Goo0g`000<007ooOol06goo00<07gooOol05Woo
3@?P00<000?P0n004P?P6Goo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0XOol0
0`00O01oo`0KOol00`0OOomoo`0EOol?0n000`000n03h00B0n0GOol00`0OOomoo`1^Ool00`00Oomo
o`01Ool000moo`03001oogoo02Uoo`03001l07`001Yoo`0301moogoo01=ooa43h0030003h0?P01<3
h1Ioo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol0:Goo00<007ooOol00W`06Goo
00<07gooOol04Woo4@?P00<000?P0n005@?P4goo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0YOol01@00Oomoo`00Ool00g`05goo00<07gooOol04Goo4@?P00<000?P0n005P?P4Woo
00<07gooOol0Kgoo00<007ooOol00Goo000?Ool2000XOol01P00Oomoo`00Ool000Aoo`9l01Eoo`03
01moogoo011ooa83h0030003h0?P01H3h15oo`0301moogoo06ioo`<000=oo`003goo00<007ooOol0
:7oo00D007oo001oo`0000Ioo`9l01Aoo`0301moogoo00iooa<3h0030003h0?P01H3h15oo`0301mo
ogoo071oo`03001oogoo005oo`003goo00<007ooOol0:Goo0`002Goo0W`04Woo00<07gooOol03Goo
5@?P00<000?P0n005P?P3goo00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0YOol3
000;Ool3O00@Ool00`0OOomoo`0<OolE0n000`000n03h00G0n0>Ool00`0OOomoo`1aOol00`00Oomo
o`01Ool000moo`03001oogoo02Yoo`8000ioo`9l00ioo`0301moogoo00]ooaH3h0030003h0?P01P3
h0aoo`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol0:goo00<007ooOol00Woo0P00
2Woo0W`03Goo00<07gooOol02Woo5P?P00<000?P0n0060?P37oo00<07gooOol0LWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0aOol00`00Oomoo`0:Ool2O00<Ool00`0OOomoo`09OolF0n000`000n03
h00I0n0:Ool00`0OOomoo`1cOol00`00Oomoo`01Ool000moo`03001oogoo035oo`03001oogoo00ao
o`9l00]oo`0301moogoo00MooaL3h0030003h0?P01T3h0Uoo`0301moogoo07Aoo`03001oogoo005o
o`003goo0P00<Goo00<007oo00003goo0g`027oo00<07gooOol01goo60?P00<000?P0n0060?P1Woo
0P0000<07gooOol0Lgoo0`000goo000?Ool00`00Oomoo`0`Ool01000Ool000004Goo0W`01goo00<0
7gooOol01Goo6@?P00<000?P0n0050?P0`0000<3h7ooOol01Goo00<0000OOol0MWoo00<007ooOol0
0Goo000?Ool00`00Oomoo`17Ool2O006Ool201l5OolI0n000`000n03h00G0n040003Ool00`0O001o
o`1gOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l00Ioo`0301moogoo009ooaT3h0030003
h0?P0103h0800083h0@000030n0007oo009oo`0401l007oo001gOol00`00Oomoo`01Ool000moo`03
001oogoo04]oo`=l00Aoo`0301moogoo01X3h0030003h0?P00l3h0`00005Ool07goo001oo`02001f
Ool00`00Oomoo`01Ool000moo`03001oogoo04ioo`9l00=oo`0301moo`?P01T3h0030003h0?P00X3
h1/007=oo`03001oogoo005oo`001goo1@000goo00<007ooOol0D7oo0W`00Woo00<07`?P0n006@?P
00<000?P0n001@?P10001P?P0P000`?P00H000?P0n03h7oo01lC001ZOol00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo059oo`9l0003Ool3h0?P01T3h0030003h0?P00D001<3h00301mo
ogoo00Uooa80065oo`03001oogoo005oo`002Goo00<007ooOol00goo0`00E7oo00=l00?P0n006@?P
0`0000<3h00000005@?P5Goo4`00EGoo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolN
0n03000E0n0NOolC0009O1m5Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo05Eo
oah3h0030003h00001D3h2Ioo`9l7a<000=l7d5oo`03001oogoo005oo`0027oo0P001Goo00<007oo
Ool0EGoo7`?P00<000?P0n0050?P8Woo3g`O4`00>goo00<007ooOol00Goo000?Ool00`00Oomoo`1E
OolO0n000`000n03h00D0n0POolKO1l:000jOol00`00Oomoo`01Ool000moo`03001oogoo05Iooc@3
h21oob=l7`@003Uoo`03001oogoo005oo`003goo00<007ooOol0EWoo=0?P7Woo9G`O100000=l7goo
Ool0=Woo00<007ooOol00Goo000?Ool2001HOolc0n0LOolXO1l20003O1leOol30003Ool000moo`03
001oogoo05Mooc<3h1]ooc1l7cEoo`03001oogoo005oo`003goo00<007ooOol0Egoo<`?P6Goo<g`O
=7oo00<007ooOol00Goo000?Ool00`00Oomoo`1HOola0n0JOoldO1lcOol00`00Oomoo`01Ool000mo
o`03001oogoo05Qooc43h1UoocIl7c9oo`03001oogoo005oo`003goo00<007ooOol0FGoo<0?P67oo
>7`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol_0n0HOoljO1l`Ool00`00Oomoo`01Ool0
00moo`03001oogoo05Uoobh3h1Qoocal7bmoo`03001oogoo005oo`003goo0P00Fgoo;0?P67oo?G`O
;Goo0`000goo000?Ool00`00Oomoo`1KOol[0n0GOoloO1l^Ool00`00Oomoo`01Ool000moo`03001o
ogoo05aoobT3h1Qoocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo:0?P67oo@W`O;7oo
00<007ooOol00Goo000?Ool00`00Oomoo`1MOolV0n0IOom2O1l/Ool00`00Oomoo`01Ool000moo`03
001oogoo05ioob@3h1Uood=l7baoo`03001oogoo005oo`003goo00<007ooOol0Ggoo8P?P6GooAG`O
:goo00<007ooOol00Goo000?Ool00`00Oomoo`1POolO0n0KOom6O1lZOol00`00Oomoo`01Ool000mo
o`8006Aooa/3h1]oodMl7bQoo`<000=oo`003goo00<007ooOol0IGoo5`?P7GooB7`O:Goo00<007oo
Ool00Goo000?Ool00`00Oomoo`1WOolC0n0OOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo
06Yoo`d3h29oodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0Kgoo0`?P9WooBG`O:Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qo
odYl7bQoo`03001oogoo005oo`003goo0P00VGooBW`O9Woo0`000goo000?Ool00`00Oomoo`2GOom;
O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<0
07ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01
Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`0027oo0`0017oo00<007ooOol0UWoo
CG`O9goo00<007ooOol00Goo0008Ool00`00Oomoo`04Ool00`00Oomoo`2FOom=O1lWOol00`00Oomo
o`01Ool000Uoo`03001oogoo00=oo`<009IoobMl7`03001l7g`O02=l7bEoo`<000=oo`002Goo00<0
07ooOol00goo00<007ooOol0UWoo9W`O00@007`O000002=l7bMoo`03001oogoo005oo`0027oo00<0
07oo000017oo00<007ooOol0UWoo9W`O00<007`OO1l00`008G`O9goo00<007ooOol00Goo0009Ool0
0`00Oomoo`03Ool00`00Oomoo`2GOolTO1l00`00O1ml7`03O1l3000OO1lWOol00`00Oomoo`01Ool0
00moo`03001oogoo09MoobAl7`03001l7g`O00=l7`03001l7g`O008001el7bMoo`03001oogoo005o
o`003goo00<007ooOol0Ugoo8g`O00<007`OO1l00W`O0P001G`O00<007`OO1l06W`O9goo00<007oo
Ool00Goo000?Ool00`00Oomoo`2GOolSO1l00`00O1ml7`02O1l30005O1l2000JO1lWOol00`00Oomo
o`01Ool000moo`03001oogoo09Moob9l7`03001l7g`O00el7`8001Ql7bMoo`03001oogoo005oo`00
3goo0P00V7oo8W`O00<007`OO1l03g`O0P005G`O9Woo0`000goo000?Ool00`00Oomoo`2HOolPO1l0
0`00O1ml7`0BO1l00`00O1ml7`02O1l00`00O1ml7`0=O1lXOol00`00Oomoo`01Ool000moo`03001o
ogoo09Qooaml7`03001l7g`O01Al7`8000=l7`03001l7g`O00al7bQoo`03001oogoo005oo`003goo
00<007ooOol0V7oo7g`O00<007`OO1l05W`O0P000W`O00<007`OO1l02W`O:Goo00<007ooOol00Goo
000?Ool00`00Oomoo`2IOolMO1l00`00O1ml7`0IO1l3000<O1lYOol00`00Oomoo`01Ool000moo`03
001oogoo09Uooael7`03001l7g`O01]l7`8000]l7bUoo`03001oogoo005oo`003goo00<007ooOol0
VGoo77`O00<007`OO1l067`O1`002W`O:Goo00<007ooOol00Goo000?Ool2002JOolLO1l00`00O1ml
7`0XO1lXOol30003Ool000moo`03001oogoo09YooaYl7`03001l7g`O021l7`800003O1l007`O00Al
7bYoo`03001oogoo005oo`003goo00<007ooOol0VWoo6G`O00<007`OO1l08g`O00<007`OO1l00g`O
:goo00<007ooOol00Goo000?Ool00`00Oomoo`2KOolHO1l00`00O1ml7`0RO1l00`00O1l00003O1l/
Ool00`00Oomoo`01Ool000moo`03001oogoo09aooa=l7`04001l7g`O000[O1l/Ool00`00Oomoo`01
Ool000moo`03001oogoo09aooa=l7`04001l7g`O000ZO1l]Ool00`00Oomoo`01Ool000moo`03001o
ogoo09eooa9l7`03001l7`0002]l7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo4W`O00<0
07`O00000W`O00<007`OO1l09G`O;Woo00<007ooOol00Goo000?Ool2002OOolAO1l200000g`O0000
000WO1l]Ool30003Ool000moo`03001oogoo09mooa1l7`<002Ul7bmoo`03001oogoo005oo`003goo
00<007ooOol0X7oo3g`O00<007`OO1l0:7`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2QOol@
O1l2000WO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo0:9ooa1l7`03001l7g`O02Al7c5oo`03
001oogoo005oo`003goo00<007ooOol0Xgoo3g`O00<007`OO1l08g`O<Woo00<007ooOol00Goo000?
Ool00`00Oomoo`2SOol>O1l00`00O1l0000SO1lcOol00`00Oomoo`01Ool000moo`03001oogoo0:Eo
o`al7`04001l7`00000PO1leOol00`00Oomoo`01Ool000moo`800:Moobel7cEoo`<000=oo`003goo
00<007ooOol0Z7oo:W`O>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOolVO1ljOol00`00Oomo
o`01Ool000moo`03001oogoo0:]oob=l7caoo`03001oogoo005oo`003goo00<007ooOol0[Goo87`O
?Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`2_OolBO1l20008O1loOol00`00Oomoo`01
Ool000Yoo`03001oogoo009oo`03001oogoo0;9ooa5l7`80009l7d=oo`03001oogoo005oo`002Goo
00<007ooOol00goo0`00L7ooV`000goo000:Ool00`00Oomoo`02Ool00`00Oomoo`23OolW0ol00`00
0ol3o`0G0ol2000:0oljOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo08=oobL3
o`040003o`?o0ol3000A0ol200050ol200000`?o0003o`020oljOol00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`03001oogoo08=oobL3o`070003o`?o0ol000?o000040?o00<000?o0ol01`?o00<0
00?o0ol00P?o>Woo00<007ooOol00Goo000?Ool00`00Oomoo`23OolW0ol010000ol3o`?o0`006@?o
00<000?o00000`?o>Woo00<007ooOol00Goo000?Ool00`00Oomoo`23OolW0ol01@000ol3o`?o0000
8@?o>Woo00<007ooOol00Goo000?Ool00`00Oomoo`23OolW0ol00`000ol3o`020ol2000O0oljOol0
0`00Oomoo`01Ool000moo`03001oogoo08=oobL3o`030003o`?o02<3ocYoo`03001oogoo005oo`00
3goo0P00Q7oo9`?o00<000?o0ol08`?o>7oo0`000goo000?Ool00`00Oomoo`23OolW0ol00`000ol3
o`0S0oljOol00`00Oomoo`01Ool000moo`03001oogoo08=oobL3o`030003o`?o02<3ocYoo`03001o
ogoo005oo`003goo00<007ooOol0Pgoo9`?o00<000?o0ol08`?o>Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`23OolW0ol00`000ol3o`0S0oljOol00`00Oomoo`01Ool000moo`03001oogoo08=oobL3
o`030003o`?o02<3ocYoo`03001oogoo005oo`003goo00<007ooOol0Pgoo9`?o00<000?o0ol08`?o
>Woo00<007ooOol00Goo000?Ool00`00Oomoo`23OolW0ol00`000ol3o`0S0oljOol00`00Oomoo`01
Ool000moo`8008AoobL3o`030003o`?o02<3ocQoo`<000=oo`003goo00<007ooOol0ZWoo00<007oo
Ool0GGoo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol00`00Oomoo`1MOol00`00Oomoo`01Ool0
00moo`03001oogoo0:Yoo`03001oogoo05eoo`03001oogoo005oo`003goo00<007ooOol0ZWoo00<0
07ooOol0GGoo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol00`00Oomoo`1MOol00`00Oomoo`01
Ool000moo`03001oogoo0:Yoo`03001oogoo05eoo`03001oogoo005oo`003goo00<007ooOol0ZWoo
00<007ooOol0GGoo00<007ooOol00Goo000?Ool2002XOol01P00Oomoo`00Ool005]oo`<000=oo`00
3goo00<007ooOol0Z7oo00D007oo001oo`0005eoo`03001oogoo005oo`003goo00<007ooOol0Z7oo
00@007oo000005ioo`03001oogoo005oo`003goo00<007ooOol0ZGoo0`00GWoo00<007ooOol00Goo
000?Ool00`00Oomoo`2YOol2001OOol00`00Oomoo`01Ool000moo`03001oogoo0:Yoo`04001oogoo
Ool2001JOol00`00Oomoo`01Ool000moo`03001oogoo0:moo`03001oogoo05Qoo`03001oogoo005o
o`003goo0P00/7oo00<007ooOol0EWoo0`000goo000?Ool00`00Oomoo`2^Ool00`00Ool0001IOol0
0`00Oomoo`01Ool000moo`03001oogoo0:ioo`04001oo`00001HOol00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`<000=oo`03001oogoo0?moo`]oo`03001o
ogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool40003
Ool3003oOol9Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`002Goo0P0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo005oo`002Woo00<0
07ooOol00Wooo`003`000goo0008Ool2003oOolGOol000Qoo`03001oogoo0?mooaIoo`0027oo0`00
ogoo5Woo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.2344 .34138 -61.9955 -3.7634 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.08719 .37726 -61.9955 -3.7634 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -61.9955 -3.7634 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.2344 .34138 m
.14286 .28571 L
.08719 .37726 L
s
.22166 .3211 m
.2344 .34138 L
.21053 .3394 L
s
.08917 .35338 m
.08719 .37726 L
.10748 .36452 L
s
gsave
.2344 .34138 -61.9955 -3.7634 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.08719 .37726 -61.9955 -3.7634 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -61.9955 -3.7634 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.2344 .34138 m
.14286 .28571 L
.08719 .37726 L
s
.22166 .3211 m
.2344 .34138 L
.21053 .3394 L
s
.08917 .35338 m
.08719 .37726 L
.10748 .36452 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.78883 .71429 m
.78883 .77143 L
.50311 .77143 L
.50311 .71429 L
F
0 g
.01 w
.49676 .4073 m
.78003 .4446 L
s
.02 w
.49676 .4073 Mdot
.78003 .4446 Mdot
gsave
.39666 .32629 -61.0298 -6.12722 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.53085 .39666 -61.0298 -6.12722 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -61.0298 -6.12722 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.39666 .32629 m
.42857 .42857 L
.53085 .39666 L
s
.39281 .34994 m
.39666 .32629 L
.41327 .34356 L
s
.51359 .41327 m
.53085 .39666 L
.5072 .39281 L
s
gsave
.75311 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64597 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.64597 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.75311 .71429 m
.64597 .71429 L
.64597 .82143 L
s
.73168 .70357 m
.75311 .71429 L
.73168 .725 L
s
.63526 .8 m
.64597 .82143 L
.65668 .8 L
s
gsave
.80941 .62073 -61.7171 -3.78679 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66498 .66655 -61.7171 -3.78679 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.7171 -3.78679 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80941 .62073 m
.71429 .57143 L
.66498 .66655 L
s
.79532 .60136 m
.80941 .62073 L
.78545 .62039 L
s
.66533 .6426 m
.66498 .66655 L
.68435 .65246 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol06goo00=l07ooOol03Goo00<07gooOol0
8Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool00g`0Oomoo`0LOol00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo01aoo`03O01oogoo00ao
o`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo
0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool00004
Ool00`00Oomoo`0DOol00g`0Oomoo`0;Ool01000Ool000003Goo00=l07ooOol037oo00<07gooOol0
87oo2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004
Ool00`00Oomoo`0DOol00g`0Oomoo`0;Ool01000Oomoogoo0P002goo00=l07ooOol037oo00<07goo
Ool087oo2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomo
o`03Ool00`00Oomoo`0DOol00g`0Oomoo`0:Ool01000Oomoogoo10002Goo00=l07ooOol03Goo00<0
7gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00
Oomoo`0DOol00g`0Oomoo`0:Ool01000Oomoogoo0P000Woo0P001goo00=l07ooOol03Goo00<07goo
Ool087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomo
o`0EOol00g`0Oomoo`08Ool00`00Oomoo`04Ool01000Oomoogoo0P0017oo00=l07ooOol03Woo00<0
7gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00
Oomoo`0EOol00g`0Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00OomoogooO00047oo
00<07gooOol08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0EOol00g`0Oomoo`07Ool00`00Oomoo`03Ool30006Ool200000gooO01oo`0?Ool00`0O
Oomoo`0ROol901l00`0001l07`0701lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo00Eoo`03001oogoo00moo`80011oo`0301moogoo02=oo`P07`0300007`0O00H07bAo
o`0301moogoo06Qoo`<000=oo`003goo00<007ooOol05goo00=l07ooOol017oo00<007ooOol03goo
00=l07oo000047oo00<07gooOol08goo1`0O00<0000O01l01@0O9Goo00<07gooOol0JWoo00<007oo
Ool00Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`03Ool00`00Oomoo`0?Ool017`0Oomoogoo0P00
0goo00<007ooOol027oo00<07gooOol08goo1`0O00<0000O01l00`0O9goo00<07gooOol0JWoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0HOol01G`0Oomoogoo00004Goo00=l07ooOol017oo0P000Woo
00<007ooOol01goo00<07gooOol08Goo00H007oo0000000O000301l0100001l07`0O:Goo00<07goo
Ool0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol017`0Oomoo`0047oo00=l07ooOol01goo
00@007ooOol000Qoo`0301moogoo025oo`80009oo`03001oo`0O00807`0300007goo02Yoo`0301mo
ogoo06Yoo`03001oogoo005oo`003goo00<007ooOol06Woo00=l0000Ool03goo00=l07ooOol02Goo
0`0027oo00<07gooOol08Goo100000<3h0000n002@?P9Goo00<07gooOol0Jgoo00<007ooOol00Goo
000?Ool00`00Oomoo`0KOol01000O01l07`02goo0W`03Woo0P0027oo00<07gooOol07Woo0P?P0P00
00<3h0000n003P?P8Woo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol00`00
Oomoo`02Ool3O004Ool4O00;Ool80007Ool00`0OOomoo`0LOol30n000`000n0000020n000`000n03
h00>0n0OOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`8001Yoo`03001oogoo00Eoo`El01mo
o`0301moogoo01Yoo`@3h0040003h0?P00020n000`000n03h00@0n0LOol00`0OOomoo`1ZOol30003
Ool000moo`03001oogoo01Uoo`03001oogoo00Moo`9l021oo`0301moogoo01Qoo`H3h0040003h0?P
000F0n0JOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03001oogoo00Yo
o`=l01Eoo`800003Ool007oo00Aoo`0301moogoo01Ioo`L3h0040003h0?P000G0n0IOol00`0OOomo
o`1]Ool00`00Oomoo`01Ool000moo`03001oogoo01Eoo`04001oogoo000?Ool2O00EOol00`00Oomo
o`04Ool00`0OOomoo`0EOol<0n000`000n03h00E0n0GOol00`0OOomoo`1^Ool00`00Oomoo`01Ool0
00moo`03001oogoo01Eoo`03001oo`00019oo`9l019oo`03001oo`0000Eoo`0301moogoo01=oo`h3
h0030003h0?P01H3h1Ioo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol05Goo0P00
5Goo0W`06Goo00<07gooOol04Woo3P?P00<000?P0n0060?P4goo00<07gooOol0Kgoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0DOol00`00Ool00003Ool00`00Oomoo`0AOol3O00GOol00`0OOomoo`0A
Ool?0n000`000n03h00H0n0BOol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`8001Eoo`80009o
o`8001Moo`9l01Eoo`0301moogoo011ooa03h0030003h0?P01P3h15oo`0301moogoo06ioo`<000=o
o`003goo00<007ooOol057oo10006goo0W`057oo00<07gooOol03Woo4@?P00<000?P0n0060?P4Goo
00<07gooOol0L7oo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol4000MOol2O00BOol00`0OOomo
o`0=OolB0n000`000n03h00I0n0?Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo
01Moo`03001oogoo01eoo`=l011oo`0301moogoo00aooa<3h0030003h0?P01T3h0ioo`0301moogoo
075oo`03001oogoo005oo`003goo00<007ooOol05goo00<007ooOol087oo0W`03Woo00<07gooOol0
2goo50?P00<000?P0n006P?P37oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0F
Ool00`00Ool0000SOol2O00=Ool00`0OOomoo`0:OolD0n000`000n03h00J0n05Ool20005Ool00`0O
Oomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo01Ioo`04001oo`00000TOol2O00<Ool00`0O
Oomoo`09OolE0n000`000n03h00E0n0300020n05Ool00`00Oomoo`02Ool00`0OOomoo`1cOol00`00
Oomoo`01Ool000moo`03001oogoo041oo`9l00]oo`0301moogoo00MooaH3h0030003h0?P01P3h0@0
00=oo`05001oogooOol07`1fOol00`00Oomoo`01Ool000moo`8004=oo`=l00Qoo`0301moogoo00Mo
oaH3h0030003h0?P01L3h0@000=oo`05001oo`00Ool07`1eOol30003Ool000moo`03001oogoo04Eo
o`9l00Moo`0301moogoo00EooaP3h0030003h0?P0103h08000040n00000000020n000`00Oomoo`02
Ool01@00Ool0000001l0Mgoo00<007ooOol00Goo000?Ool00`00Oomoo`17Ool2O006Ool201l5OolH
0n000`000n03h00?0n0:0006Ool201mhOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l00Io
o`0301moogoo009ooaP3h0030003h0?P00d3h1@007Qoo`03001oogoo005oo`003goo00<007ooOol0
Bgoo0g`017oo00<07gooOol06P?P00<000?P0n002@?P0`000`?P0P0010?P00<000?P0n003`00LGoo
00<007ooOol00Goo000?Ool00`00Oomoo`1>Ool2O003Ool00`0OOol3h00I0n000`000n03h0060n03
000@0n02Ool00`0OOomoo`02Ool?001YOol00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo051o
o`9l009oo`0301l3h0?P01P3h0030003h0?P00<3h0<001<3h003Ool07goo00]oo`l0069oo`03001o
ogoo005oo`002Goo00<007ooOol00goo00<007ooOol0DWoo0W`000=oo`?P0n006@?P00<000?P0000
0P005P?P00<07gooOol04goo3`00FWoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001DOol0
0g`00n03h00I0n0200020n02000E0n0MOol@001@Ool30003Ool000Uoo`03001oogoo00=oo`03001o
ogoo05Eooah3h0<001D3h2Eoo`l000Il7dEoo`03001oogoo005oo`002Goo00<007ooOol00goo00<0
07ooOol0EGoo7P?P00<000?P00005@?P9Woo1g`O3`000W`O@Goo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`1EOolO0n000`000n03h00D0n0ROolBO1l@000kOol00`00Oomoo`01Ool000moo`03
001oogoo05Eooal3h0030003h0?P01@3h21ooaal7`T003Yoo`03001oogoo005oo`003goo00<007oo
Ool0EWoo=0?P87oo8W`O1000>Woo00<007ooOol00Goo000?Ool00`00Oomoo`1FOold0n0NOolUO1l2
0003O1lhOol00`00Oomoo`01Ool000moo`8005Qooc<3h1aoobel7cEoo`<000=oo`003goo00<007oo
Ool0Egoo<`?P6goo<7`O=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolc0n0IOolcO1ldOol0
0`00Oomoo`01Ool000moo`03001oogoo05Qooc43h1YoocAl7c=oo`03001oogoo005oo`003goo00<0
07ooOol0F7oo<@?P6Goo=W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol`0n0HOolhO1la
Ool00`00Oomoo`01Ool000moo`03001oogoo05Uoobl3h1QoocYl7c1oo`03001oogoo005oo`003goo
00<007ooOol0FGoo;P?P67oo?7`O;goo00<007ooOol00Goo000?Ool2001KOol/0n0HOolmO1l]Ool3
0003Ool000moo`03001oogoo05]oob/3h1Moocml7bioo`03001oogoo005oo`003goo00<007ooOol0
G7oo:@?P67oo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n0HOom2O1l/Ool00`00
Oomoo`01Ool000moo`03001oogoo05eoobH3h1Uood9l7baoo`03001oogoo005oo`003goo00<007oo
Ool0GWoo90?P6Goo@g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR0n0IOom5O1l[Ool0
0`00Oomoo`01Ool000moo`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo005oo`003goo0P00
I7oo6`?P6gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lYOol00`00Oomoo`01
Ool000moo`03001oogoo06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0JWoo
3@?P8WooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9O1lYOol00`00Oomo
o`01Ool000moo`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O
:7oo00<007ooOol00Goo000?Ool2002IOom:O1lVOol30003Ool000moo`03001oogoo09Mood]l7bQo
o`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomo
o`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`00
3goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOom=O1lW
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005o
o`002Goo00<007ooOol00goo0`00UWoo9g`O00<007`OO1l08g`O9Goo0`000goo0009Ool00`00Oomo
o`03Ool00`00Oomoo`2FOolVO1l01000O1l000008g`O9goo00<007ooOol00Goo0008Ool00`00Ool0
0004Ool00`00Oomoo`2FOolVO1l00`00O1ml7`03000QO1lWOol00`00Oomoo`01Ool000Uoo`03001o
ogoo00=oo`03001oogoo09MoobAl7`03001l7g`O00=l7`<001ml7bMoo`03001oogoo005oo`003goo
00<007ooOol0Ugoo97`O00<007`OO1l00g`O00<007`OO1l00P007G`O9goo00<007ooOol00Goo000?
Ool00`00Oomoo`2GOolSO1l00`00O1ml7`02O1l20005O1l2000KO1lWOol00`00Oomoo`01Ool000mo
o`03001oogoo09Moob=l7`03001l7g`O009l7`<000Il7`8001Ul7bMoo`03001oogoo005oo`003goo
00<007ooOol0Ugoo8W`O00<007`OO1l03W`O0P005g`O9goo00<007ooOol00Goo000?Ool2002HOolR
O1l00`00O1ml7`0@O1l20005O1l00`00O1ml7`0<O1lVOol30003Ool000moo`03001oogoo09Qoob1l
7`03001l7g`O01=l7`8000Al7`03001l7g`O00]l7bQoo`03001oogoo005oo`003goo00<007ooOol0
V7oo87`O00<007`OO1l05G`O0P000W`O00<007`OO1l02g`O:7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2HOolOO1l00`00O1ml7`0HO1l200000g`O001l7`0:O1lYOol00`00Oomoo`01Ool000moo`03
001oogoo09Uooail7`03001l7g`O01Yl7`8000]l7bUoo`03001oogoo005oo`003goo00<007ooOol0
VGoo7G`O00<007`OO1l05g`O1`002W`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolMO1l0
0`00O1ml7`0XO1lYOol00`00Oomoo`01Ool000moo`8009Yooaal7`03001l7g`O02Ql7bQoo`<000=o
o`003goo00<007ooOol0VWoo6g`O00<007`OO1l087`O0P0000=l7`00O1l00g`O:Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`2JOolJO1l00`00O1ml7`0SO1l00`00O1ml7`02O1l[Ool00`00Oomoo`01
Ool000moo`03001oogoo09]ooaUl7`03001l7g`O029l7`03001l7`00009l7baoo`03001oogoo005o
o`003goo00<007ooOol0W7oo57`O00@007`OO1l002Yl7baoo`03001oogoo005oo`003goo00<007oo
Ool0W7oo57`O00@007`OO1l002Ul7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo4g`O00<0
07`O0000:W`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolCO1l00`00O1l00002O1l00`00
O1ml7`0TO1l^Ool00`00Oomoo`01Ool000moo`8009mooa9l7`80009l7`03001l7g`O02Al7beoo`<0
00=oo`003goo00<007ooOol0Wgoo4G`O10009g`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2P
Ool@O1l2000XO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo0:5oo`ml7`04001l7`00000VO1l`
Ool00`00Oomoo`01Ool000moo`03001oogoo0:9ooa5l7`03001l7g`O02=l7c5oo`03001oogoo005o
o`003goo00<007ooOol0Xgoo47`O00<007`OO1l08W`O<Woo00<007ooOol00Goo000?Ool00`00Oomo
o`2SOol?O1l00`00O1l0000RO1lcOol00`00Oomoo`01Ool000moo`03001oogoo0:Eoo`el7`04001l
7`00000OO1leOol00`00Oomoo`01Ool000moo`800:Moobel7cEoo`<000=oo`003goo00<007ooOol0
Z7oo:W`O>7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOolVO1ljOol00`00Oomoo`01Ool000mo
o`03001oogoo0:]oob=l7caoo`03001oogoo005oo`003goo00<007ooOol0[Goo87`O?Goo00<007oo
Ool00Goo0008Ool20005Ool00`00Oomoo`2_OolBO1l20008O1loOol00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo0;9ooa5l7`<00003O1moogoo045oo`03001oogoo005oo`002Goo00<0
07ooOol00goo0`00L7ooV`000goo000:Ool00`00Oomoo`02Ool00`00Oomoo`24OolV0ol00`000ol3
o`0H0ol2000:0oliOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo08AoobH3o`04
0003o`?o0ol3000B0ol200050ol200000`?o0003o`020oliOol00`00Oomoo`01Ool000Uoo`03001o
ogoo00=oo`03001oogoo08AoobH3o`070003o`?o0ol000?o000040?o0P002@?o00<000?o0ol00P?o
>Goo00<007ooOol00Goo000?Ool00`00Oomoo`24OolV0ol010000ol3o`?o0`006P?o00<000?o0000
0`?o>Goo00<007ooOol00Goo000?Ool00`00Oomoo`24OolV0ol01@000ol3o`?o00008P?o>Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`24OolV0ol00`000ol3o`020ol2000P0oliOol00`00Oomoo`01
Ool000moo`03001oogoo08AoobH3o`030003o`?o02@3ocUoo`03001oogoo005oo`003goo0P00QGoo
9P?o00<000?o0ol090?o=goo0`000goo000?Ool00`00Oomoo`24OolV0ol00`000ol3o`0T0oliOol0
0`00Oomoo`01Ool000moo`03001oogoo08AoobH3o`030003o`?o02@3ocUoo`03001oogoo005oo`00
3goo00<007ooOol0Q7oo9P?o00<000?o0ol090?o>Goo00<007ooOol00Goo000?Ool00`00Oomoo`24
OolV0ol00`000ol3o`0T0oliOol00`00Oomoo`01Ool000moo`03001oogoo08AoobH3o`030003o`?o
02@3ocUoo`03001oogoo005oo`003goo00<007ooOol0Q7oo9P?o00<000?o0ol090?o>Goo00<007oo
Ool00Goo000?Ool00`00Oomoo`24OolV0ol00`000ol3o`0T0oliOol00`00Oomoo`01Ool000moo`80
08EoobH3o`030003o`?o02@3ocMoo`<000=oo`003goo00<007ooOol0ZWoo00<007ooOol0GGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`2ZOol00`00Oomoo`1MOol00`00Oomoo`01Ool000moo`03001o
ogoo0:Yoo`03001oogoo05eoo`03001oogoo005oo`003goo00<007ooOol0ZWoo00<007ooOol0GGoo
00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol00`00Oomoo`1MOol00`00Oomoo`01Ool000moo`03
001oogoo0:Yoo`03001oogoo05eoo`03001oogoo005oo`003goo00<007ooOol0ZWoo00<007ooOol0
GGoo00<007ooOol00Goo000?Ool2002YOol00`00Ool00002Ool00`00Oomoo`1HOol30003Ool000mo
o`03001oogoo0:Qoo`05001oo`00Ool0001MOol00`00Oomoo`01Ool000moo`03001oogoo0:Uoo`80
0003Ool007oo05aoo`03001oogoo005oo`003goo00<007ooOol0ZGoo0`00GWoo00<007ooOol00Goo
000?Ool00`00Oomoo`2ZOol2001NOol00`00Oomoo`01Ool000moo`03001oogoo0:Yoo`04001oogoo
Ool2001JOol00`00Oomoo`01Ool000moo`03001oogoo0:moo`03001oogoo05Qoo`03001oogoo005o
o`003goo0P00/7oo00<007ooOol0EWoo0`000goo000?Ool00`00Oomoo`2^Ool00`00Ool0001IOol0
0`00Oomoo`01Ool000moo`03001oogoo0:ioo`04001oo`00001HOol00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`<000=oo`03001oogoo0?moo`]oo`03001o
ogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool40003
Ool3003oOol9Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`002Goo0P0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo005oo`002Woo00<0
07ooOol00Wooo`003`000goo0008Ool2003oOolGOol000Qoo`03001oogoo0?mooaIoo`0027oo0`00
ogoo5Woo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.16466 .39062 -65.3269 -3.93571 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.03796 .30751 -65.3269 -3.93571 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -65.3269 -3.93571 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.16466 .39062 m
.14286 .28571 L
.03796 .30751 L
s
.17079 .36746 m
.16466 .39062 L
.14981 .37182 L
s
.05676 .29266 m
.03796 .30751 L
.06112 .31364 L
s
gsave
.16466 .39062 -65.3269 -3.93571 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.03796 .30751 -65.3269 -3.93571 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -65.3269 -3.93571 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.16466 .39062 m
.14286 .28571 L
.03796 .30751 L
s
.17079 .36746 m
.16466 .39062 L
.14981 .37182 L
s
.05676 .29266 m
.03796 .30751 L
.06112 .31364 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.79307 .71429 m
.79307 .77143 L
.50736 .77143 L
.50736 .71429 L
F
0 g
.01 w
.49381 .39948 m
.77623 .4427 L
s
.02 w
.49381 .39948 Mdot
.77623 .4427 Mdot
gsave
.38493 .33072 -61.4821 -6.18855 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.52642 .38493 -61.4821 -6.18855 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -61.4821 -6.18855 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.38493 .33072 m
.42857 .42857 L
.52642 .38493 L
s
.38387 .35465 m
.38493 .33072 L
.40344 .34593 L
s
.51122 .40344 m
.52642 .38493 L
.50249 .38387 L
s
gsave
.75736 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.65021 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.65021 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.75736 .71429 m
.65021 .71429 L
.65021 .82143 L
s
.73593 .70357 m
.75736 .71429 L
.73593 .725 L
s
.6395 .8 m
.65021 .82143 L
.66093 .8 L
s
gsave
.81083 .61789 -61.5976 -3.79876 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66783 .66797 -61.5976 -3.79876 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.5976 -3.79876 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81083 .61789 m
.71429 .57143 L
.66783 .66797 L
s
.79617 .59894 m
.81083 .61789 L
.78688 .61825 L
s
.66746 .64402 m
.66783 .66797 L
.68677 .65331 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol06goo00=l07ooOol03Goo00<07gooOol0
8Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0D
Ool00g`0Oomoo`0LOol00g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00
Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo01aoo`03O01oogoo00ao
o`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<007oo000017oo
0`0057oo00=l07ooOol02WooD0002P0O8goo00<07gooOol0Igoo0`000goo0008Ool00`00Ool00004
Ool00`00Oomoo`0DOol00g`0Oomoo`06Ool40002Ool00`00Oomoo`0=Ool00g`0Oomoo`0<Ool00`0O
Oomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001o
o`0000Aoo`03001oogoo00aoo`03001oogoo00Eoo`04O01oogooOol50005Ool3000>Ool00g`0Oomo
o`0<Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool0
00Uoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Eoo`D000Yoo`<000eoo`03O01oogoo
00eoo`0301moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`00
3goo00<007ooOol02Goo0P0017oo100000=oog`0Ool03Woo00<007ooOol02goo00=l07ooOol03Goo
00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`08Ool00`00Ool000040006Ool00g`0Oomoo`0<Ool00`00Oomoo`0:Ool00g`0Oomoo`0>
Ool00`0OOomoo`0QOol:01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000mo
o`03001oogoo00Ioo`@000]oo`03O01oogoo00Yoo`<000aoo`03O01oogoo00ioo`0301moogoo025o
o`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol01goo
00<007oo00000P002Goo00=l07ooOol037oo00<007ooOol02Woo00=l07ooOol03Woo00<07gooOol0
8Woo2@0O00<0000O01l01`0O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool20008Ool00`00
Oomoo`02Ool20008Ool00g`0Oomoo`0<Ool00`00Oomoo`08Ool00g`0Oomoo`0?Ool00`0OOomoo`0S
Ool801l00`0001l07`0601lTOol00`0OOomoo`1XOol30003Ool000moo`03001oogoo00Ioo`03001o
o`0000ioo`03O01oogoo00]oo`03001oogoo00Qoo`03O01oogoo011oo`0301moogoo02=oo`L07`03
00007`0O00D07bEoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol01Woo00@007oo
000000eoo`03O01oogoo00]oo`03001oogoo00Moo`03O01oogoo015oo`0301moogoo02=oo`L07`03
00007`0O00<07bMoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol067oo00=l07oo
Ool02Woo00<007ooOol01Woo00=l07ooOol04Woo00<07gooOol09Goo1@0O00@0000O01l07bUoo`03
01moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol06Goo00=l07ooOol02Goo00<007ooOol0
1Goo00=l07ooOol04goo00<07gooOol07Woo00H007oo000007oo0003Ool301l00`0001moo`0ZOol0
0`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Yoo`9l00Yoo`03001oogoo00=oo`03
O01oogoo01Aoo`0301moogoo01ioo`80009oo`03001oo`?P00`3h2Eoo`0301moogoo06]oo`03001o
ogoo005oo`003goo00<007ooOol077oo0g`01goo00@007ooOomoo`9l01Qoo`0301moogoo01eoo`@0
00030n0000?P00l3h29oo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol07goo0g`0
17oo00@007`0O01l01Yoo`0301moogoo01aoo`050n0000000n00000D0n0OOol00`0OOomoo`1/Ool0
0`00Oomoo`01Ool000moo`80029oo`El0003001oogoo01aoo`0301moogoo01Yoo`83h0050003h000
0n00000F0n0LOol00`0OOomoo`1ZOol30003Ool000moo`03001oogoo02=oo`9l009oo`03001oogoo
01]oo`0301moogoo01Qoo`@3h0030003h0000083h0030003h0?P01@3h1Yoo`0301moogoo06eoo`03
001oogoo005oo`003goo00<007ooOol09Goo0W`000<007ooOol077oo00<07gooOol05Woo1@?P00@0
00?P0n0001T3h1Uoo`0301moogoo06eoo`03001oogoo005oo`003goo00<007ooOol09goo00<007`0
O00077oo00<07gooOol05Goo1P?P00@000?P0n0001X3h1Moo`0301moogoo06ioo`03001oogoo005o
o`003goo00<007ooOol09goo00<007ooOol00W`06Woo00<07gooOol04goo30?P00<000?P0n0060?P
5Woo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0WOol00`00Oomoo`02Ool2O00I
Ool00`0OOomoo`0BOol<0n000`000n03h00J0n0COol00`0OOomoo`1_Ool00`00Oomoo`01Ool000mo
o`03001oogoo02Qoo`04001oogoo0002Ool3O00GOol00`0OOomoo`0AOol<0n000`000n03h00K0n0B
Ool00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`8002Ioo`04001oogoo0002Ool00`00Oomoo`03
Ool2O00EOol00`0OOomoo`0@Ool>0n000`000n03h00J0n0AOol00`0OOomoo`1^Ool30003Ool000mo
o`03001oogoo02Ioo`05001oo`00Ool00008Ool2O00DOol00`0OOomoo`0>Ool?0n000`000n03h00J
0n0AOol00`0OOomoo`1`Ool00`00Oomoo`01Ool000moo`03001oogoo02Ioo`05001oo`00Ool0000:
Ool2O00BOol00`0OOomoo`0=OolA0n000`000n03h00J0n06Ool20007Ool00`0OOomoo`1aOol00`00
Oomoo`01Ool000moo`03001oogoo02Moo`800003Ool007oo00]oo`=l011oo`0301moogoo00aooa43
h0030003h0?P01/3h0Ioo`03001oogoo00Eoo`0301moogoo075oo`03001oogoo005oo`003goo00<0
07ooOol0:7oo0`003goo0W`03Woo00<07gooOol02goo4`?P00<000?P0n005P?P1`000goo00<007oo
Ool017oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0XOol2000BOol2O00=Ool0
0`0OOomoo`0:OolC0n000`000n03h00I0n030003Ool00`00Ool00005Ool00`0OOomoo`1bOol00`00
Oomoo`01Ool000moo`03001oogoo02Uoo`03001oogoo019oo`9l00aoo`0301moogoo00Uooa@3h003
0003h0?P01H3h08000030n0000?P00=oo`04001oo`000003Ool00`0OOomoo`1cOol00`00Oomoo`01
Ool000moo`03001oogoo041oo`9l00]oo`0301moogoo00MooaD3h0030003h0?P0143h0D000<3h003
0003h7oo00Qoo`0301moogoo07Aoo`03001oogoo005oo`003goo0P00:7oo0P0000=oo`00Ool05Woo
0g`027oo00<07gooOol01goo5@?P00<000?P0n0040?P2P0000<3h7ooOol01Woo00<07gooOol0Lgoo
0`000goo000?Ool00`00Oomoo`0YOol00`00Oomoo`0IOol2O007Ool00`0OOomoo`05OolG0n000`00
0n03h00?0n0@0003Ool00`0OOomoo`1eOol00`00Oomoo`01Ool000moo`03001oogoo02Qoo`03001o
o`0001aoo`9l00Ioo`807`EooaL3h0030003h0?P00`3h0<000030n00000000L3h0`007Eoo`03001o
ogoo005oo`003goo00<007ooOol0BGoo0W`01Woo00<07gooOol00Woo60?P00<000?P0n002@?P0P00
3`?P17oo3@00KWoo00<007ooOol00Goo000?Ool00`00Oomoo`1;Ool3O004Ool00`0OOomoo`0I0n00
0`000n03h0070n02000A0n03Ool00`0OOomoo`04Ool=001XOol00`00Oomoo`01Ool000moo`03001o
ogoo04ioo`9l00=oo`0301moo`?P01T3h0030003h0?P00@3h08001<3h09oo`0301moogoo00aoo``0
069oo`03001oogoo005oo`001goo1@000goo00<007ooOol0D7oo0W`00Woo00<07`?P0n0060?P00<0
00?P0n000P?P0P005@?P00=oo`0OOol057oo3000G7oo00<007ooOol00Goo0009Ool00`00Oomoo`03
Ool00`00Oomoo`1BOol2O0000goo0n03h00I0n0010000n0000005`?P00<07gooOol06Woo3000EWoo
00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001DOol00g`00n03h00I0n0200020n02000E0n0S
Ool=001=Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooah3h0<001D3h2Uoo`d000Al
7dEoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0EGoo7P?P00<000?P00005@?P
9Woo2W`O30000W`O@Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1EOolO0n000`000n03
h00D0n0ROolDO1l=000lOol00`00Oomoo`01Ool000moo`03001oogoo05Eooal3h0030003h0?P01@3
h21ooaal7`P003]oo`03001oogoo005oo`003goo00<007ooOol0EWoo=0?P87oo8G`O100000=l7goo
Ool0>7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOold0n0NOolTO1l20004O1lhOol00`00Oomo
o`01Ool000moo`8005Qooc<3h1aoobel7cEoo`<000=oo`003goo00<007ooOol0Egoo<`?P6goo<7`O
=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolc0n0IOolcO1ldOol00`00Oomoo`01Ool000mo
o`03001oogoo05Qooc43h1YoocAl7c=oo`03001oogoo005oo`003goo00<007ooOol0F7oo<@?P6Goo
=W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol`0n0HOolhO1laOol00`00Oomoo`01Ool0
00moo`03001oogoo05Uoobl3h1QoocYl7c1oo`03001oogoo005oo`003goo00<007ooOol0FGoo;P?P
67oo?7`O;goo00<007ooOol00Goo000?Ool2001KOol/0n0HOolmO1l]Ool30003Ool000moo`03001o
ogoo05]oob/3h1Moocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo:@?P67oo?g`O;Woo
00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n0HOom2O1l/Ool00`00Oomoo`01Ool000moo`03
001oogoo05eoobH3h1Uood9l7baoo`03001oogoo005oo`003goo00<007ooOol0GWoo90?P6Goo@g`O
;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR0n0IOom5O1l[Ool00`00Oomoo`01Ool000mo
o`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo005oo`003goo0P00I7oo6`?P6gooAg`O:7oo
0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo
06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0JWoo3@?P8WooB7`O:Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9O1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<007ooOol00Goo
000?Ool2002IOom:O1lVOol30003Ool000moo`03001oogoo09Mood]l7bQoo`03001oogoo005oo`00
3goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00
Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo
C7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool0
00Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`002Goo00<007ooOol0
0goo0`00UWoo9g`O00<007`OO1l08g`O9Goo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2F
OolVO1l01000O1l000008g`O9goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2F
OolVO1l00`00O1ml7`03000QO1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo
09MoobAl7`03001l7g`O00=l7`<001ml7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo97`O
00<007`OO1l00g`O00<007`OO1l00P007G`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolS
O1l00`00O1ml7`02O1l20005O1l2000KO1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moob=l
7`03001l7g`O009l7`<000Il7`8001Ul7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo8W`O
00<007`OO1l03W`O0P005g`O9goo00<007ooOol00Goo000?Ool2002HOolRO1l00`00O1ml7`0@O1l2
0005O1l00`00O1ml7`0<O1lVOol30003Ool000moo`03001oogoo09Qoob1l7`03001l7g`O01=l7`80
00Al7`03001l7g`O00]l7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo87`O00<007`OO1l0
5G`O0P000g`O00<007`OO1l02W`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOolOO1l00`00
O1ml7`0HO1l200000g`O001l7`0:O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09Uooail7`03
001l7g`O01Yl7`<000Yl7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo7G`O00<007`OO1l0
5g`O20002G`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolMO1l00`00O1ml7`0XO1lYOol0
0`00Oomoo`01Ool000moo`8009Yooaal7`03001l7g`O021l7`800003O1l007`O00=l7bQoo`<000=o
o`003goo00<007ooOol0VWoo6g`O00<007`OO1l08W`O00<007`OO1l00g`O:Woo00<007ooOol00Goo
000?Ool00`00Oomoo`2JOolJO1l00`00O1ml7`0RO1l00`00O1l00003O1l[Ool00`00Oomoo`01Ool0
00moo`03001oogoo09]ooaUl7`03001l7g`O02Ml7baoo`03001oogoo005oo`003goo00<007ooOol0
W7oo5g`O00<007`OO1l0:7`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolDO1l01000O1ml
7`00:G`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolCO1l00`00O1l0000ZO1l]Ool00`00
Oomoo`01Ool000moo`03001oogoo09eooa=l7`03001l7`00009l7`03001l7g`O02Al7bioo`03001o
ogoo005oo`003goo0P00Wgoo4W`O0P000W`O00<007`OO1l097`O;Goo0`000goo000?Ool00`00Oomo
o`2OOolAO1l4000WO1l_Ool00`00Oomoo`01Ool000moo`03001oogoo0:1ooa1l7`8002Ql7c1oo`03
001oogoo005oo`003goo00<007ooOol0XGoo3g`O00<007`OO1l00P009G`O<7oo00<007ooOol00Goo
000?Ool00`00Oomoo`2ROolBO1l00`00O1ml7`0RO1laOol00`00Oomoo`01Ool000moo`03001oogoo
0:=ooa5l7`03001l7g`O025l7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo47`O00<007`O
00008G`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOol>O1l01000O1l000007W`O=Goo00<0
07ooOol00Goo000?Ool2002WOol]O1leOol30003Ool000moo`03001oogoo0:QoobYl7cQoo`03001o
ogoo005oo`003goo00<007ooOol0ZWoo9W`O>Woo00<007ooOol00Goo000?Ool00`00Oomoo`2[OolS
O1llOol00`00Oomoo`01Ool000moo`03001oogoo0:eoob1l7ceoo`03001oogoo005oo`0027oo0P00
1Goo00<007ooOol0[goo57`O0P001W`O?goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00
Oomoo`2bOolCO1l20013Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<0071ooi/000=oo`00
2Woo00<007ooOol00Woo00<007ooOol0QGoo9`?o00<000?o0ol05`?o0P002P?o>7oo00<007ooOol0
0Goo0008Ool00`00Ool00004Ool00`00Oomoo`25OolW0ol010000ol3o`?o0`004@?o0P001@?o0P00
00<3o`000ol00P?o>7oo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`25OolW0ol0
1`000ol3o`?o0003o`000103o`030003o`?o00L3o`030003o`?o0083ocQoo`03001oogoo005oo`00
3goo00<007ooOol0QGoo9`?o00@000?o0ol3o`<001T3o`030003o`0000<3ocQoo`03001oogoo005o
o`003goo00<007ooOol0QGoo9`?o00D000?o0ol3o`000243ocQoo`03001oogoo005oo`003goo00<0
07ooOol0QGoo9`?o00<000?o0ol00P?o0P007`?o>7oo00<007ooOol00Goo000?Ool00`00Oomoo`25
OolW0ol00`000ol3o`0S0olhOol00`00Oomoo`01Ool000moo`8008IoobL3o`030003o`?o02<3ocIo
o`<000=oo`003goo00<007ooOol0QGoo9`?o00<000?o0ol08`?o>7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`25OolW0ol00`000ol3o`0S0olhOol00`00Oomoo`01Ool000moo`03001oogoo08EoobL3
o`030003o`?o02<3ocQoo`03001oogoo005oo`003goo00<007ooOol0QGoo9`?o00<000?o0ol08`?o
>7oo00<007ooOol00Goo000?Ool00`00Oomoo`25OolW0ol00`000ol3o`0S0olhOol00`00Oomoo`01
Ool000moo`03001oogoo08EoobL3o`030003o`?o02<3ocQoo`03001oogoo005oo`003goo00<007oo
Ool0QGoo9`?o00<000?o0ol08`?o>7oo00<007ooOol00Goo000?Ool20026OolW0ol00`000ol3o`0S
0olfOol30003Ool000moo`03001oogoo0:aoo`03001oogoo05]oo`03001oogoo005oo`003goo00<0
07ooOol0[7oo00<007ooOol0Fgoo00<007ooOol00Goo000?Ool00`00Oomoo`2/Ool00`00Oomoo`1K
Ool00`00Oomoo`01Ool000moo`03001oogoo0:aoo`03001oogoo05]oo`03001oogoo005oo`003goo
00<007ooOol0[7oo00<007ooOol0Fgoo00<007ooOol00Goo000?Ool00`00Oomoo`2/Ool00`00Oomo
o`1KOol00`00Oomoo`01Ool000moo`03001oogoo0:aoo`03001oogoo05]oo`03001oogoo005oo`00
3goo0P00ZWoo00H007ooOol007oo001IOol30003Ool000moo`03001oogoo0:Yoo`05001oo`00Ool0
001KOol00`00Oomoo`01Ool000moo`03001oogoo0:Yoo`04001oo`00001LOol00`00Oomoo`01Ool0
00moo`03001oogoo0:]oo`<005aoo`03001oogoo005oo`003goo00<007ooOol0Zgoo0P00GGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`2/Ool01000Oomoogoo0P00F7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`2aOol00`00Oomoo`1FOol00`00Oomoo`01Ool000moo`800;9oo`03001oogoo05Aoo`<0
00=oo`003goo00<007ooOol0/7oo00<007oo0000Egoo00<007ooOol00Goo000?Ool00`00Oomoo`2`
Ool01000Ool00000EWoo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03
001oogoo0?moo`]oo`03001oogoo005oo`0027oo10000goo0`00ogoo2Goo0`000goo0008Ool00`00
Ool00004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`8000Aoo`03001oogoo0?moo`]o
o`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008
Ool00`00Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000l000=oo`0027oo0P00
ogoo5goo0008Ool00`00Oomoo`3oOolFOol000Qoo`<00?mooaIoo`00ogoo8Goo003oOolQOol00001
\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.08107 .37325 -67.1809 -4.78374 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.05532 .22393 -67.1809 -4.78374 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -67.1809 -4.78374 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.08107 .37325 m
.14286 .28571 L
.05532 .22393 L
s
.10218 .36192 m
.08107 .37325 L
.08467 .34956 L
s
.07901 .22753 m
.05532 .22393 L
.06665 .24504 L
s
gsave
.08107 .37325 -67.1809 -4.78374 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.05532 .22393 -67.1809 -4.78374 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -67.1809 -4.78374 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.08107 .37325 m
.14286 .28571 L
.05532 .22393 L
s
.10218 .36192 m
.08107 .37325 L
.08467 .34956 L
s
.07901 .22753 m
.05532 .22393 L
.06665 .24504 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.79824 .71429 m
.79824 .77143 L
.51253 .77143 L
.51253 .71429 L
F
0 g
.01 w
.48996 .39206 m
.77153 .44054 L
s
.02 w
.48996 .39206 Mdot
.77153 .44054 Mdot
gsave
.3738 .33649 -61.9553 -6.2336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.52066 .3738 -61.9553 -6.2336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -61.9553 -6.2336 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.3738 .33649 m
.42857 .42857 L
.52066 .3738 L
s
.37554 .36038 m
.3738 .33649 L
.39396 .34943 L
s
.50772 .39396 m
.52066 .3738 L
.49676 .37554 L
s
gsave
.76253 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.65539 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.65539 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.76253 .71429 m
.65539 .71429 L
.65539 .82143 L
s
.7411 .70357 m
.76253 .71429 L
.7411 .725 L
s
.64467 .8 m
.65539 .82143 L
.6661 .8 L
s
gsave
.81245 .61436 -61.4535 -3.81477 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67135 .66959 -61.4535 -3.81477 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.4535 -3.81477 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81245 .61436 m
.71429 .57143 L
.67135 .66959 L
s
.79711 .59596 m
.81245 .61436 L
.78852 .61559 L
s
.67012 .64567 m
.67135 .66959 L
.68976 .65425 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`09Ool2000HOol3O00POol00`0OOomo
o`1AOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo00Yoo`03001oo`000080019o
o`9l029oo`0301moogoo05=oo`0301moogoo06aoo`03001oogoo005oo`003goo0P002goo00<007oo
Ool01P0037oo1g`07goo00<07gooOol0Dgoo00<07gooOol0JWoo0`000goo000?Ool00`00Oomoo`09
Ool01`00Ool007oo001oo`0000eoo`=l00Ioo`=l01]oo`0301moogoo05Aoo`0301moogoo06aoo`03
001oogoo005oo`003goo00<007ooOol02Goo00L007oo000007oo001oo`02000:Ool2O00;Ool3O00H
Ool00`0OOomoo`1EOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo00ioo`05001o
ogooOol00007Ool2O00@Ool2O00EOol00`0OOomoo`1FOol00`0OOomoo`1[Ool00`00Oomoo`01Ool0
00moo`03001oogoo00moo`05001oogooOol00005Ool00g`0Oomoo`0BOol00g`0Oomoo`0BOol00`0O
Oomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`80009oo`03O01o
ogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo005o
o`003goo00<007ooOol05Woo00<007`0Ool05goo00=l07ooOol047oo00<07gooOol08goo3P0O9Woo
00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`00000000GOol00g`0Oomo
o`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Moo`04
O01oogoo000GOol00g`0Oomoo`0>Ool00`0OOomoo`0ROolB01lUOol00`0OOomoo`1WOol30003Ool0
00moo`03001oogoo01Eoo`03O01oogoo009oo`8001Eoo`03O01oogoo00ioo`0301moogoo029ooa<0
7bAoo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol017oo00<0
07ooOol04goo00=l07ooOol03Goo00<07gooOol08Goo500O97oo00<07gooOol0JGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`06Ool00`00Oomoo`0BOol00g`0Oomoo`0=Ool00`0O
Oomoo`0QOolE01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01o
ogoo00Moo`80019oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03001o
ogoo005oo`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol02Goo00<007ooOol047oo
00=l07ooOol037oo00<07gooOol087oo5P0O8goo00<07gooOol0JGoo00<007ooOol00Goo0008Ool0
0`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0:Ool2000@Ool00g`0Oomoo`0<Ool00`0OOomo
o`0POolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<001Aoo`03
O01oogoo00aoodh000X07b=oo`0301moogoo06Moo`<000=oo`0027oo00<007oo000017oo00<007oo
Ool057oo00=l07ooOol02goo00<007ooOol03Woo00=l07ooOol037oo00<07gooOol087oo2`0O00<0
000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomo
o`0DOol00g`0Oomoo`09Ool3000@Ool00g`0Oomoo`0<Ool00`0OOomoo`0POol;01l00`0001l07`09
01lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03
O01oogoo00Uoo`80011oo`03O01oogoo00eoo`0301moogoo021oo`/07`0300007`0O00P07b=oo`03
01moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol02Goo00<007oo0000
3goo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`08Ool00`00Ool0000>Ool00g`0Oomoo`0>
Ool00`0OOomoo`0QOol:01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000mo
o`03001oogoo01Eoo`03O01oogoo00Moo`@000ioo`03O01oogoo00ioo`0301moogoo025oo`X07`03
00007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07oo
Ool01Woo00<007ooOol047oo00=l07ooOol03Woo00<07gooOol08Woo2@0O00<0000O01l01`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool2000GOol00g`0Oomoo`05Ool00`00Oomoo`0?Ool0
0g`0Oomoo`0?Ool00`0OOomoo`0SOol801l00`0001l07`0601lTOol00`0OOomoo`1XOol30003Ool0
00moo`03001oogoo01Moo`03O01oogoo00=oo`03001oogoo011oo`03O01oogoo011oo`0301moogoo
02=oo`L07`0300007`0O00D07bEoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol0
5goo00=l07ooOol00Woo00<007ooOol047oo00=l07ooOol04Goo00<07gooOol08goo1`0O00<0000O
01l00`0O9goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol01G`0Oomoogoo
00004Goo00=l07ooOol04Woo00<07gooOol09Goo1@0O00@0000O01l07bUoo`0301moogoo06Yoo`03
001oogoo005oo`003goo00<007ooOol06Goo00=l07oo00004Goo00=l07ooOol04goo00<07gooOol0
9goo0`0O00<0000OOol0:Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol0
0`00O01oo`0?Ool00g`0Oomoo`0DOol00`0OOomoo`0TOol=0n0UOol00`0OOomoo`1[Ool00`00Oomo
o`01Ool000moo`03001oogoo01Yoo`03001oog`0009l00]oo`9l01Qoo`0301moogoo01Yoo`<00003
Ool000?P01<3h29oo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Goo00<007oo
Ool00goo0g`017oo17`06Woo00<07gooOol06Woo10005`?P7goo00<07gooOol0K7oo00<007ooOol0
0Goo000?Ool2000IOol00`00Oomoo`06Ool5O00OOol00`0OOomoo`0IOol5000I0n0LOol00`0OOomo
o`1ZOol30003Ool000moo`03001oogoo01Qoo`03001oogoo00Qoo`9l021oo`0301moogoo01Qoo`04
0n0000?P00020n02000H0n0JOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo01Ao
o`04001oogoo000=Ool3O00NOol00`0OOomoo`0FOol30n02000M0n0IOol00`0OOomoo`1]Ool00`00
Oomoo`01Ool000moo`03001oogoo01Aoo`03001oo`00015oo`9l01aoo`0301moogoo01Eoo`@3h003
0003h00001d3h1Moo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol057oo00<007oo
00004goo0W`06Woo00<07gooOol04goo1P?P00@000?P0n0001d3h1Ioo`0301moogoo06ioo`03001o
ogoo005oo`003goo00<007ooOol04goo00<007oo00000Woo00<007ooOol04Goo0W`06Goo00<07goo
Ool04Woo2@?P00<000?P0n007@?P4goo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomo
o`0COol200000goo0000000FOol3O00GOol00`0OOomoo`0AOol:0n000`000n03h00M0n05Ool2000;
Ool00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`8001Aoo`<001]oo`9l01Eoo`0301moogoo011o
o`/3h0030003h0?P01d3h0Ioo`03001oogoo00Qoo`0301moogoo06ioo`<000=oo`003goo00<007oo
Ool04goo00<007ooOol07Goo0W`057oo00<07gooOol03Woo3@?P00<000?P0n0060?P20000Woo00<0
07ooOol027oo00<07gooOol0L7oo00<007ooOol00Goo000?Ool00`00Oomoo`0?Ool200000goo001o
o`0QOol2O00BOol00`0OOomoo`0=Ool?0n000`000n03h00L0n020002Ool00`00Ool00008Ool00`0O
Oomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo015oo`03001oogoo02=oo`=l011oo`0301mo
ogoo00aoo`l3h0030003h0?P01X3h0<000=oo`04001oo`000007Ool00`0OOomoo`1aOol00`00Oomo
o`01Ool000moo`03001oogoo011oo`03001oo`0002Moo`9l00ioo`0301moogoo00]ooa43h0030003
h0?P01P3h0050003h0?P0003h00<Ool00`0OOomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo
03aoo`9l00eoo`0301moogoo00Yooa43h0030003h0?P01<3h08000030n0000000083h0030003h0?P
00aoo`0301moogoo079oo`03001oogoo005oo`003goo00<007ooOol0?Woo0W`037oo00<07gooOol0
2Goo4P?P00<000?P0n004@?P200010?P2Woo00<07gooOol0Lgoo00<007ooOol00Goo000?Ool00`00
Oomoo`10Ool2O00;Ool00`0OOomoo`07OolD0n000`000n03h00@0n0>0007Ool00`0OOomoo`1dOol0
0`00Oomoo`01Ool000moo`8004=oo`=l00Qoo`0301moogoo00Mooa@3h0030003h0?P00l3h0@000D3
h0`0000301moogoo07=oo`<000=oo`003goo00<007ooOol0AGoo0W`01goo00<07gooOol01Goo5P?P
00<000?P0n0030?P0P003@?P0Woo3000LWoo00<007ooOol00Goo000?Ool00`00Oomoo`17Ool2O006
Ool201l5OolF0n000`000n03h00;0n000`000n03h00=0n06Ool201l<001/Ool00`00Oomoo`01Ool0
00moo`03001oogoo04Uoo`9l00Ioo`0301moogoo009ooaL3h0030003h0?P00P3h0800143h0Aoo`03
01moogoo00Ioo``006Ioo`03001oogoo005oo`003goo00<007ooOol0Bgoo0g`017oo00<07gooOol0
6@?P00<000?P0n001@?P0P004`?P0goo00<07gooOol03Goo2`00HGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`1>Ool2O003Ool00`0OOol3h00H0n000`000n03h0040n000`000n03h00C0n02Ool00`0O
Oomoo`0DOol;001KOol00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo051oo`9l009oo`0301l3
h0?P01P3h0040003h0?P0n02000F0n000goo01moo`0KOol<001EOol00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`03001oogoo059oo`9l0003Ool3h0?P01P3h0040003h000000H0n000`0OOomoo`0Q
Ool<001?Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<005Aoo`03O003h0?P01T3h0030003
h0?P008001H3h2Yoo``004Moo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0EGoo7@?P0`00
5P?P:Goo1g`O3000@goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolM0n00
0`000n00000F0n0VOol@O1l<000mOol00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo05Eooah3
h0030003h0?P01D3h29ooaYl7`L003aoo`03001oogoo005oo`003goo00<007ooOol0EGoo7P?P00<0
00?P0n005@?P87oo7g`O1000?7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOold0n0POolQO1l2
0003O1ljOol00`00Oomoo`01Ool000moo`03001oogoo05Iooc@3h1ioobYl7cQoo`03001oogoo005o
o`003goo0P00F7oo<`?P77oo;G`O=Goo0`000goo000?Ool00`00Oomoo`1GOolc0n0KOol`O1leOol0
0`00Oomoo`01Ool000moo`03001oogoo05Mooc<3h1Uooc=l7cAoo`03001oogoo005oo`003goo00<0
07ooOol0F7oo<@?P6Woo=7`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`1HOola0n0IOolfO1lb
Ool00`00Oomoo`01Ool000moo`03001oogoo05Uooc03h1QoocQl7c5oo`03001oogoo005oo`003goo
00<007ooOol0FGoo;`?P67oo>W`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol^0n0HOoll
O1l_Ool00`00Oomoo`01Ool000moo`8005]oob`3h1Qoocel7beoo`<000=oo`003goo00<007ooOol0
Fgoo:`?P5goo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolY0n0HOoloO1l^Ool00`00
Oomoo`01Ool000moo`03001oogoo05aoobP3h1Qood9l7baoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo9P?P6Goo@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1NOolT0n0IOom3O1l/Ool0
0`00Oomoo`01Ool000moo`03001oogoo05moob83h1UoodEl7b]oo`03001oogoo005oo`003goo00<0
07ooOol0H7oo7`?P6gooAW`O:Woo00<007ooOol00Goo000?Ool2001TOolK0n0KOom7O1lXOol30003
Ool000moo`03001oogoo06EooaL3h1eoodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0Igoo
4`?P7gooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1ZOol=0n0ROom8O1lYOol00`00Oomo
o`01Ool000moo`03001oogoo06moo`<3h2IoodUl7bUoo`03001oogoo005oo`003goo00<007ooOol0
V7ooBW`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomoo`01Ool000mo
o`8009UoodYl7bIoo`<000=oo`003goo00<007ooOol0UgooBg`O:7oo00<007ooOol00Goo000?Ool0
0`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo
005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lW
Ool00`00Oomoo`01Ool000Qoo`<000Aoo`03001oogoo09Ioodel7bMoo`03001oogoo005oo`0027oo
00<007ooOol017oo00<007ooOol0UWooCG`O9goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3
002FOolWO1l2000TO1lUOol30003Ool000Uoo`03001oogoo00=oo`03001oogoo09IoobMl7`04001l
7`00000RO1lWOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo09IoobIl7`03001l
7g`O00@0021l7bMoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Ugoo9G`O00<0
07`OO1l00W`O00@007`O000001il7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo97`O00<0
07`OO1l00g`O00@007`OO1ml7`8001al7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo97`O
00@007`OO1ml7`8000Il7`8001Yl7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo8g`O00<0
07`OO1l00W`O0`001g`O0`005g`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolSO1l00`00
O1ml7`0?O1l20005O1l00`00O1ml7`0=O1lWOol00`00Oomoo`01Ool000moo`8009Qoob9l7`03001l
7g`O019l7`8000Al7`03001l7g`O00]l7bIoo`<000=oo`003goo00<007ooOol0V7oo8G`O00<007`O
O1l057`O0P000g`O00<007`OO1l02W`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOolPO1l0
0`00O1ml7`0GO1l200000g`O001l7`0;O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qoob1l
7`03001l7g`O01Ul7`<000Yl7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo7W`O00<007`O
O1l05g`O1`002G`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolNO1l00`00O1ml7`0WO1lY
Ool00`00Oomoo`01Ool000moo`03001oogoo09Uooail7`03001l7g`O01ml7`800003O1l007`O00=l
7bUoo`03001oogoo005oo`003goo0P00VWoo7G`O00<007`OO1l08W`O00<007`OO1l00W`O:7oo0`00
0goo000?Ool00`00Oomoo`2JOolLO1l00`00O1ml7`0QO1l00`00O1l00003O1lZOol00`00Oomoo`01
Ool000moo`03001oogoo09Yooa]l7`03001l7g`O02Ml7b]oo`03001oogoo005oo`003goo00<007oo
Ool0Vgoo6W`O00<007`OO1l09W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolHO1l00`00
O1ml7`0WO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09aooaEl7`04001l7g`O000XO1l]Ool0
0`00Oomoo`01Ool000moo`03001oogoo09eooaAl7`03001l7`0002Ul7beoo`03001oogoo005oo`00
3goo00<007ooOol0WGoo57`O00<007`O00000W`O00<007`OO1l08g`O;Woo00<007ooOol00Goo000?
Ool2002OOolCO1l20002O1l00`00O1ml7`0SO1l]Ool30003Ool000moo`03001oogoo09mooa9l7`@0
02Il7bmoo`03001oogoo005oo`003goo00<007ooOol0X7oo4G`O0P009g`O<7oo00<007ooOol00Goo
000?Ool00`00Oomoo`2QOol@O1l00`00O1ml7`0VO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo
0:9ooa9l7`8002=l7c5oo`03001oogoo005oo`003goo00<007ooOol0Xgoo4W`O00<007`OO1l087`O
<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2SOolBO1l00`00O1ml7`0OO1lcOol00`00Oomoo`01
Ool000moo`03001oogoo0:Eoo`ml7`03001l7`0001il7cEoo`03001oogoo005oo`003goo0P00Ygoo
3W`O00@007`O000001]l7cEoo`<000=oo`003goo00<007ooOol0Z7oo:W`O>7oo00<007ooOol00Goo
000?Ool00`00Oomoo`2ZOolVO1ljOol00`00Oomoo`01Ool000moo`03001oogoo0:]oob=l7caoo`03
001oogoo005oo`003goo00<007ooOol0[Goo87`O?Goo00<007ooOol00Goo0008Ool20005Ool00`00
Oomoo`2_OolEO1l20005O1loOol00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo0;9o
oaAl7`<0045oo`03001oogoo005oo`002Goo00<007ooOol00goo0`00L7ooV`000goo000:Ool00`00
Oomoo`02Ool00`00Oomoo`27OolV0ol00`000ol3o`0H0ol200090olgOol00`00Oomoo`01Ool000Qo
o`03001oo`0000Aoo`03001oogoo08MoobH3o`040003o`?o0ol3000B0ol200050ol2000010?o0003
o`?o=goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`27OolV0ol01`000ol3o`?o
0003o`000103o`8000T3o`040003o`?o0olgOol00`00Oomoo`01Ool000moo`03001oogoo08MoobH3
o`040003o`?o0ol3000J0ol00`000ol000020olgOol00`00Oomoo`01Ool000moo`03001oogoo08Mo
obH3o`050003o`?o0ol0000Q0olgOol00`00Oomoo`01Ool000moo`03001oogoo08MoobH3o`030003
o`?o0083o`8001l3ocMoo`03001oogoo005oo`003goo00<007ooOol0Qgoo9P?o00<000?o0ol08`?o
=goo00<007ooOol00Goo000?Ool20028OolV0ol00`000ol3o`0S0oleOol30003Ool000moo`03001o
ogoo08MoobH3o`030003o`?o02<3ocMoo`03001oogoo005oo`003goo00<007ooOol0Qgoo9P?o00<0
00?o0ol08`?o=goo00<007ooOol00Goo000?Ool00`00Oomoo`27OolV0ol00`000ol3o`0S0olgOol0
0`00Oomoo`01Ool000moo`03001oogoo08MoobH3o`030003o`?o02<3ocMoo`03001oogoo005oo`00
3goo00<007ooOol0Qgoo9P?o00<000?o0ol08`?o=goo00<007ooOol00Goo000?Ool00`00Oomoo`27
OolV0ol00`000ol3o`0S0olgOol00`00Oomoo`01Ool000moo`03001oogoo08MoobH3o`030003o`?o
02<3ocMoo`03001oogoo005oo`003goo0P00R7oo9P?o00<000?o0ol08`?o=Goo0`000goo000?Ool0
0`00Oomoo`2]Ool00`00Oomoo`1JOol00`00Oomoo`01Ool000moo`03001oogoo0:eoo`03001oogoo
05Yoo`03001oogoo005oo`003goo00<007ooOol0[Goo00<007ooOol0FWoo00<007ooOol00Goo000?
Ool00`00Oomoo`2]Ool00`00Oomoo`1JOol00`00Oomoo`01Ool000moo`03001oogoo0:eoo`03001o
ogoo05Yoo`03001oogoo005oo`003goo00<007ooOol0[Goo00<007ooOol0FWoo00<007ooOol00Goo
000?Ool00`00Oomoo`2]Ool00`00Oomoo`1JOol00`00Oomoo`01Ool000moo`800:]oo`04001oogoo
0002Ool00`00Oomoo`1EOol30003Ool000moo`03001oogoo0:]oo`05001oo`00Ool0001JOol00`00
Oomoo`01Ool000moo`03001oogoo0:]oo`05001oo`00Ool0001JOol00`00Oomoo`01Ool000moo`03
001oogoo0:aoo`<005]oo`03001oogoo005oo`003goo00<007ooOol0[7oo0`00Fgoo00<007ooOol0
0Goo000?Ool00`00Oomoo`2]Ool01000Oomoogoo0P00Egoo00<007ooOol00Goo000?Ool00`00Oomo
o`2bOol00`00Oomoo`1EOol00`00Oomoo`01Ool000moo`800;=oo`03001oogoo05=oo`<000=oo`00
3goo00<007ooOol0/Goo00<007oo0000EWoo00<007ooOol00Goo000?Ool00`00Oomoo`2aOol01000
Ool00000EGoo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009
Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo
0?moo`]oo`03001oogoo005oo`0027oo10000goo0`00ogoo2Goo0`000goo0008Ool00`00Ool00004
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`8000Aoo`03001oogoo0?moo`]oo`03001o
ogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool00`00
Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000l000=oo`0027oo0P00ogoo5goo
0008Ool00`00Oomoo`3oOolFOol000Qoo`<00?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.03671 .3003 -66.3806 -5.76907 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.12827 .17957 -66.3806 -5.76907 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.3806 -5.76907 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.03671 .3003 m
.14286 .28571 L
.12827 .17957 L
s
.0594 .308 m
.03671 .3003 L
.05648 .28677 L
s
.1418 .19934 m
.12827 .17957 L
.12057 .20226 L
s
gsave
.03671 .3003 -66.3806 -5.76907 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.12827 .17957 -66.3806 -5.76907 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -66.3806 -5.76907 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.03671 .3003 m
.14286 .28571 L
.12827 .17957 L
s
.0594 .308 m
.03671 .3003 L
.05648 .28677 L
s
.1418 .19934 m
.12827 .17957 L
.12057 .20226 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.80422 .71429 m
.80422 .77143 L
.51851 .77143 L
.51851 .71429 L
F
0 g
.01 w
.48527 .38513 m
.76601 .43826 L
s
.02 w
.48527 .38513 Mdot
.76601 .43826 Mdot
gsave
.36342 .34352 -62.4428 -6.26177 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.51363 .36342 -62.4428 -6.26177 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -62.4428 -6.26177 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.36342 .34352 m
.42857 .42857 L
.51363 .36342 L
s
.36794 .36704 m
.36342 .34352 L
.38495 .35401 L
s
.50313 .38495 m
.51363 .36342 L
.4901 .36794 L
s
gsave
.76851 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66136 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66136 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.76851 .71429 m
.66136 .71429 L
.66136 .82143 L
s
.74708 .70357 m
.76851 .71429 L
.74708 .725 L
s
.65065 .8 m
.66136 .82143 L
.67208 .8 L
s
gsave
.81416 .61022 -61.2897 -3.83522 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.6755 .6713 -61.2897 -3.83522 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.2897 -3.83522 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81416 .61022 m
.71429 .57143 L
.6755 .6713 L
s
.79806 .59247 m
.81416 .61022 L
.79031 .61245 L
s
.67327 .64745 m
.6755 .6713 L
.69324 .65521 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P007Woo0P008Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool0
0`00Oomoo`0NOol00`00Oomoo`0NOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomo
o`01Ool000moo`03001oogoo01ioo`8001eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03
001oogoo005oo`003goo00<007ooOol07Goo00@007oo000001Yoo`9l00ioo`0301moogoo04Moo`03
01moogoo079oo`03001oogoo005oo`003goo00<007ooOol07Goo1@005Woo0g`03goo00<07gooOol0
BGoo00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0NOol200000goo001oo`0COol2
O00AOol00`0OOomoo`1:Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo01ioo`05
001oo`00Ool0000AOol2O00COol00`0OOomoo`1;Ool00`0OOomoo`1`Ool00`00Oomoo`01Ool000mo
o`8001ioo`04001oogoo0002Ool00`00Oomoo`0;Ool3O00DOol00`0OOomoo`1<Ool00`0OOomoo`1^
Ool30003Ool000moo`03001oogoo01eoo`04001oogoo000>Ool2O00GOol00`0OOomoo`1=Ool00`0O
Oomoo`1_Ool00`00Oomoo`01Ool000moo`03001oogoo021oo`03001oogoo00Yoo`9l01Qoo`0301mo
ogoo04ioo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol087oo00<007ooOol01goo
0g`06Woo00<07gooOol0Cgoo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0POol0
0`00Oomoo`05Ool2O00LOol00`0OOomoo`1@Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03
001oogoo021oo`03001oogoo00=oo`9l01ioo`0301moogoo055oo`0301moogoo06eoo`03001oogoo
005oo`003goo00<007ooOol08Goo00<007ooO0000W`087oo00<07gooOol0DGoo00<07gooOol0KGoo
00<007ooOol00Goo000?Ool00`00Oomoo`0QOol00`00O01oo`0QOol00`0OOomoo`1COol00`0OOomo
o`1/Ool00`00Oomoo`01Ool000moo`80021oo`9l0003001l07`0009l01moo`0301moogoo05=oo`03
01moogoo06Yoo`<000=oo`003goo00<007ooOol07Goo0g`000=oo`00Ool00goo0g`06goo00<07goo
Ool0E7oo00<07gooOol0K7oo00<007ooOol00Goo000?Ool00`00Oomoo`0LOol2O003Ool00`00Oomo
o`05Ool3O00HOol00`0OOomoo`1EOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo
01Yoo`9l00Eoo`03001oogoo00Qoo`9l01Eoo`0301moogoo05Ioo`0301moogoo06]oo`03001oogoo
005oo`003goo00<007ooOol06Goo00=l07ooOol01Goo00<007ooOol02Woo00=l07ooOol04Woo00<0
7gooOol0Egoo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol00g`0Oomoo`07
Ool00`00Oomoo`0:Ool00g`0Oomoo`0AOol00`0OOomoo`0TOol;01lXOol00`0OOomoo`1ZOol00`00
Oomoo`01Ool000moo`03001oogoo01Moo`03O01oogoo00Qoo`03001oogoo00]oo`03O01oogoo011o
o`0301moogoo02=oo`h07bIoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol05Woo
00=l07ooOol02Goo00<007ooOol02goo00=l07ooOol03goo00<07gooOol08goo400O9Goo00<07goo
Ool0JWoo00<007ooOol00Goo000?Ool2000GOol00g`0Oomoo`09Ool00`00Oomoo`0<Ool00g`0Oomo
o`0>Ool00`0OOomoo`0ROolB01lUOol00`0OOomoo`1WOol30003Ool000moo`03001oogoo01Eoo`03
O01oogoo00Yoo`03001oogoo00aoo`03O01oogoo00ioo`0301moogoo029ooa<07bAoo`0301moogoo
06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol02Woo00<007ooOol03Goo00=l
07ooOol03Goo00<07gooOol08Goo500O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00
Oomoo`0DOol00g`0Oomoo`0;Ool00`00Oomoo`0=Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lS
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oogoo00aoo`03001o
ogoo00aoo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03001oogoo005o
o`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol037oo00<007ooOol03Goo00=l07oo
Ool037oo00<07gooOol087oo5P0O8goo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool0
0004Ool00`00Oomoo`0DOol00g`0Oomoo`0<Ool00`00Oomoo`0=Ool00g`0Oomoo`0<Ool00`0OOomo
o`0POolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<001Aoo`03
O01oogoo00Uooe4000X07b=oo`0301moogoo06Moo`<000=oo`0027oo00<007oo000017oo00<007oo
Ool037oo00<007ooOol01Goo00=l07ooOol00Woo1`0000Aoo`00000000moo`03O01oogoo00aoo`03
01moogoo021oo`/07`0300007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo005oo`0027oo00<0
07oo000017oo00<007ooOol02Woo0P001Woo1`0027oo0P0047oo00=l07ooOol037oo00<07gooOol0
87oo2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03
Ool00`00Oomoo`08Ool200000goo000000050002Ool00g`0Oomoo`0<Ool00`00Oomoo`0<Ool00g`0
Oomoo`0=Ool00`0OOomoo`0POol;01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01
Ool000moo`03001oogoo00Moo`@000Uoo`03O01oogoo00aoo`03001oogoo00aoo`03O01oogoo00eo
o`0301moogoo021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo
00<007ooOol00goo0P0000Aoo`00Oomoo`<000Uoo`03O01oogoo00Uoo`<000eoo`03O01oogoo00io
o`0301moogoo025oo`X07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo
00<007ooOol01Goo00<007ooOol017oo0P001goo00=l07ooOol06Goo00=l07ooOol03Woo00<07goo
Ool08Goo2P0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomo
o`04Ool00`00Ool0000>Ool00g`0Oomoo`0IOol00g`0Oomoo`0>Ool00`0OOomoo`0ROol901l00`00
01l07`0701lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo01Moo`03
O01oogoo00moo`0301moogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`00
3goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo1`0O00<0000O
01l01@0O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0E
Ool00g`0Oomoo`0AOol00`0OOomoo`0SOol701l00`0001l07`0301lWOol00`0OOomoo`1ZOol00`00
Oomoo`01Ool000moo`03001oogoo01Qoo`03O01oogoo01=oo`03O01oogoo019oo`0301moogoo02Eo
o`D07`0400007`0O01lYOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Uoo`03
O01oogoo015oo`03O01oogoo01=oo`0301moogoo02Moo`<07`0300007goo02Yoo`0301moogoo06Yo
o`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo00=l07ooOol057oo00<07gooOol097oo
3@?P9Goo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0LOol3O00;Ool2O00HOol0
0`0OOomoo`0NOolE0n0ROol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo01moo`=l
00Aoo`Al01Yoo`0301moogoo01aooaT3h1moo`0301moogoo06aoo`03001oogoo005oo`003goo0P00
8Woo1G`07goo00<07gooOol05Woo0`0000=oo`000n006`?P77oo00<07gooOol0JWoo0`000goo000?
Ool00`00Oomoo`0SOol2O00POol00`0OOomoo`0FOol4000N0n0JOol00`0OOomoo`1]Ool00`00Oomo
o`01Ool000moo`03001oogoo02Eoo`=l01ioo`0301moogoo01Ioo`@001h3h1Uoo`0301moogoo06eo
o`03001oogoo005oo`003goo00<007ooOol0:7oo0W`077oo00<07gooOol05Goo00<3h00000000P?P
0P007@?P1Woo0P003goo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol2O00J
Ool00`0OOomoo`0COol30n000`000n00000Q0n06Ool00`00Oomoo`0=Ool00`0OOomoo`1^Ool00`00
Oomoo`01Ool000moo`03001oogoo02aoo`9l01Uoo`0301moogoo019oo`@3h0030003h0000283h0<0
0003Ool007oo00eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Woo0g`05goo
00<07gooOol04Goo10?P00@000?P0n0001d3h0@000060n0007oo001oo`003Goo00<07gooOol0Kgoo
00<007ooOol00Goo000?Ool2000bOol2O00EOol00`0OOomoo`0@Ool80n000`000n03h00N0n030000
0goo001oo`02000;Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo03=oo`9l01Aoo`0301mo
ogoo00ioo`X3h0030003h0?P01`3h0030003h000015oo`0301moogoo071oo`03001oogoo005oo`00
3goo00<007ooOol0=Goo0W`04Woo00<07gooOol03Goo30?P00<000?P0n006P?P00D000?P0n0000?P
00moo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=goo0g`047oo00<07gooOol0
37oo3@?P00<000?P0n005@?P10000P?P00@000?P0n03h0ioo`0301moogoo075oo`03001oogoo005o
o`003goo00<007ooOol0>Woo0W`03Woo00<07gooOol02goo3`?P00<000?P0n004`?P200010?P37oo
00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0lOol2O00=Ool00`0OOomoo`0:Ool?
0n000`000n03h00C0n0=000;Ool00`0OOomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo03io
o`9l00aoo`0301moogoo00Uooa03h0030003h0?P0183h0<000D3h0/000Aoo`0301moogoo07=oo`03
001oogoo005oo`003goo00<007ooOol0@7oo0W`02goo00<07gooOol01goo4P?P00<000?P0n003`?P
0P003@?P2`00MGoo00<007ooOol00Goo000?Ool20013Ool3O008Ool00`0OOomoo`07OolC0n000`00
0n03h00=0n000`000n03h00=0n06Ool;001]Ool30003Ool000moo`03001oogoo04Eoo`9l00Moo`03
01moogoo00EooaD3h0030003h0?P00/3h0030003h0?P00h3h0Qoo`0301moogoo00/006Yoo`03001o
ogoo005oo`003goo00<007ooOol0Agoo0W`01Woo0P0O1Goo5@?P00<000?P0n002P?P00<000?P0n00
3`?P1Woo0P0O2Goo2P00IGoo00<007ooOol00Goo000?Ool00`00Oomoo`19Ool2O006Ool00`0OOomo
o`02OolF0n000`000n03h0070n02000C0n04Ool00`0OOomoo`0>Ool;001OOol00`00Oomoo`01Ool0
00moo`03001oogoo04]oo`=l00Aoo`0301moogoo01P3h0030003h0?P00D3h0030003h0?P01<3h0=o
o`0301moogoo01Aoo`/005Yoo`03001oogoo005oo`003goo00<007ooOol0CWoo0W`00goo00<07goo
0n0060?P00<000?P0n000`?P00<000?P0n0050?P0Woo00<07gooOol06goo2`00E7oo00<007ooOol0
0Goo0007Ool50003Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00G0n0010000n03h0?P0P005`?P
00=oo`0OOol08Woo2`00Cgoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1BOol2
O0000goo0n03h00H0n0010000n0000?P0P005P?P00<07gooOol0:7oo2`00BGoo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool3001DOol00g`00n03h00I0n000`000n000002000F0n0`Ool;0012Ool3
0003Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooad3h0030003h00001H3h2Uoo`el7`/003io
o`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0EGoo7P?P00<000?P0n005@?P9Woo
5G`O1`00?Goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1EOolN0n000`000n03h00E0n0R
OolLO1l4000mOol00`00Oomoo`01Ool000moo`03001oogoo05EoocH3h21ooaml7`80009l7caoo`03
001oogoo005oo`003goo00<007ooOol0EWoo=0?P87oo9W`O>Woo00<007ooOol00Goo000?Ool00`00
Oomoo`1FOold0n0NOolZO1lhOol00`00Oomoo`01Ool000moo`8005Qooc<3h1aoobel7cEoo`<000=o
o`003goo00<007ooOol0Egoo<`?P6goo<7`O=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolc
0n0IOolcO1ldOol00`00Oomoo`01Ool000moo`03001oogoo05Qooc43h1YoocAl7c=oo`03001oogoo
005oo`003goo00<007ooOol0F7oo<@?P6Goo=W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1I
Ool`0n0HOolhO1laOol00`00Oomoo`01Ool000moo`03001oogoo05Uoobl3h1QoocYl7c1oo`03001o
ogoo005oo`003goo00<007ooOol0FGoo;P?P67oo?7`O;goo00<007ooOol00Goo000?Ool2001KOol/
0n0HOolmO1l]Ool30003Ool000moo`03001oogoo05]oob/3h1Moocml7bioo`03001oogoo005oo`00
3goo00<007ooOol0G7oo:@?P67oo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n0H
Oom2O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05eoobH3h1Uood9l7baoo`03001oogoo005o
o`003goo00<007ooOol0GWoo90?P6Goo@g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR
0n0IOom5O1l[Ool00`00Oomoo`01Ool000moo`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo
005oo`003goo0P00I7oo6`?P6gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lY
Ool00`00Oomoo`01Ool000moo`03001oogoo06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo
00<007ooOol0JWoo3@?P8WooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9
O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<0
07ooOol0V7ooBW`O:7oo00<007ooOol00Goo000?Ool2002IOom:O1lVOol30003Ool000moo`03001o
ogoo09Mood]l7bQoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo
000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03
001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00
Oomoo`2FOom=O1lWOol00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMo
o`03001oogoo005oo`002Goo00<007ooOol00goo0`00UWoo9g`O0P0097`O9Goo0`000goo0009Ool0
0`00Oomoo`03Ool00`00Oomoo`2FOolWO1l01000O1l000008W`O9goo00<007ooOol00Goo0008Ool0
0`00Ool00004Ool00`00Oomoo`2FOolVO1l00`00O1ml7`05000OO1lWOol00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo09MoobEl7`03001l7g`O009l7`03001l7g`O008001el7bMoo`03
001oogoo005oo`003goo00<007ooOol0Ugoo97`O00<007`OO1l00g`O00<007`OO1l00W`O0`006W`O
9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolTO1l01000O1ml7g`O0P0027`O0P0067`O9goo
00<007ooOol00Goo000?Ool00`00Oomoo`2GOolTO1l01000O1ml7g`O0`002G`O0P001W`O00<007`O
O1l03G`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolSO1l00`00O1ml7`0@O1l30004O1l0
0`00O1ml7`0<O1lWOol00`00Oomoo`01Ool000moo`8009Qoob=l7`03001l7g`O01=l7`8000=l7`03
001l7g`O00Yl7bIoo`<000=oo`003goo00<007ooOol0V7oo8G`O00<007`OO1l05W`O0`0000=l7`00
O1l02W`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOolQO1l00`00O1ml7`0IO1l3000:O1lX
Ool00`00Oomoo`01Ool000moo`03001oogoo09Qoob5l7`03001l7g`O01El7`P000Ql7bUoo`03001o
ogoo005oo`003goo00<007ooOol0VGoo7g`O00<007`OO1l09W`O:Goo00<007ooOol00Goo000?Ool0
0`00Oomoo`2IOolOO1l00`00O1ml7`0NO1l200000g`O001l7`03O1lYOol00`00Oomoo`01Ool000mo
o`03001oogoo09Uooail7`03001l7g`O025l7`03001l7g`O00=l7bUoo`03001oogoo005oo`003goo
0P00VWoo7W`O00<007`OO1l087`O00<007`O00000g`O:7oo0`000goo000?Ool00`00Oomoo`2JOolL
O1l00`00O1ml7`0WO1lZOol00`00Oomoo`01Ool000moo`03001oogoo09Yooaal7`03001l7g`O02Il
7b]oo`03001oogoo005oo`003goo00<007ooOol0Vgoo6g`O00<007`OO1l09G`O;7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`2LOolIO1l00`00O1ml7`0VO1l/Ool00`00Oomoo`01Ool000moo`03001o
ogoo09aooaUl7`03001l7g`O02El7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo5G`O00<0
07`O0000:7`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolEO1l00`00O1l0000WO1l^Ool0
0`00Oomoo`01Ool000moo`8009mooaAl7`03001l7`00009l7`03001l7g`O025l7beoo`<000=oo`00
3goo00<007ooOol0Wgoo4g`O0P000W`O00<007`OO1l08W`O;goo00<007ooOol00Goo000?Ool00`00
Oomoo`2POolBO1l4000TO1l`Ool00`00Oomoo`01Ool000moo`03001oogoo0:5ooa5l7`8002Il7c1o
o`03001oogoo005oo`003goo00<007ooOol0XWoo47`O00<007`OO1l00P008W`O<Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2SOolCO1l00`00O1ml7`0OO1lbOol00`00Oomoo`01Ool000moo`03001o
ogoo0:=ooa=l7`03001l7g`O01il7c=oo`03001oogoo005oo`003goo00<007ooOol0YGoo47`O00<0
07`O00007G`O=Goo00<007ooOol00Goo000?Ool2002WOol?O1l01000O1l000006W`O=Goo0`000goo
000?Ool00`00Oomoo`2XOolZO1lhOol00`00Oomoo`01Ool000moo`03001oogoo0:YoobIl7cYoo`03
001oogoo005oo`003goo00<007ooOol0Zgoo8g`O?7oo00<007ooOol00Goo000?Ool00`00Oomoo`2]
OolPO1lmOol00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0:mooaMl7`8000=l7cmoo`03001o
ogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0/Woo5G`O00=oo`000000@7oo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3001`OonK0003Ool000Yoo`03001oogoo009oo`03001oogoo08Qo
obL3o`030003o`?o01L3o`8000X3ocEoo`03001oogoo005oo`0027oo00<007oo000017oo00<007oo
Ool0R7oo9`?o00@000?o0ol3o`<00143o`8000D3o`8000030ol000?o0083ocEoo`03001oogoo005o
o`002Goo00<007ooOol00goo00<007ooOol0R7oo9`?o00L000?o0ol3o`000ol0000@0ol00`000ol3
o`070ol00`000ol3o`020oleOol00`00Oomoo`01Ool000moo`03001oogoo08QoobL3o`040003o`?o
0ol3000I0ol00`000ol000030oleOol00`00Oomoo`01Ool000moo`03001oogoo08QoobL3o`050003
o`?o0ol0000Q0oleOol00`00Oomoo`01Ool000moo`03001oogoo08QoobL3o`030003o`?o0083o`80
01l3ocEoo`03001oogoo005oo`003goo00<007ooOol0R7oo9`?o00<000?o0ol08`?o=Goo00<007oo
Ool00Goo000?Ool20029OolW0ol00`000ol3o`0S0olcOol30003Ool000moo`03001oogoo08QoobL3
o`030003o`?o02<3ocEoo`03001oogoo005oo`003goo00<007ooOol0R7oo9`?o00<000?o0ol08`?o
=Goo00<007ooOol00Goo000?Ool00`00Oomoo`28OolW0ol00`000ol3o`0S0oleOol00`00Oomoo`01
Ool000moo`03001oogoo08QoobL3o`030003o`?o02<3ocEoo`03001oogoo005oo`003goo00<007oo
Ool0R7oo9`?o00<000?o0ol08`?o=Goo00<007ooOol00Goo000?Ool00`00Oomoo`28OolW0ol00`00
0ol3o`0S0oleOol00`00Oomoo`01Ool000moo`03001oogoo08QoobL3o`030003o`?o02<3ocEoo`03
001oogoo005oo`003goo0P00RGoo9`?o00<000?o0ol08`?o<goo0`000goo000?Ool00`00Oomoo`2_
Ool00`00Oomoo`1HOol00`00Oomoo`01Ool000moo`03001oogoo0:moo`03001oogoo05Qoo`03001o
ogoo005oo`003goo00<007ooOol0[goo00<007ooOol0F7oo00<007ooOol00Goo000?Ool00`00Oomo
o`2_Ool00`00Oomoo`1HOol00`00Oomoo`01Ool000moo`03001oogoo0:moo`03001oogoo05Qoo`03
001oogoo005oo`003goo00<007ooOol0[goo00<007ooOol0F7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2_Ool00`00Oomoo`1HOol00`00Oomoo`01Ool000moo`800:eoo`06001oogoo001oo`00EWoo
0`000goo000?Ool00`00Oomoo`2]Ool01@00Ool007oo0000F7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2]Ool01000Ool00000FGoo00<007ooOol00Goo000?Ool00`00Oomoo`2^Ool3001IOol00`00
Oomoo`01Ool000moo`03001oogoo0:ioo`8005Yoo`03001oogoo005oo`003goo00<007ooOol0[goo
00@007ooOomoo`8005Eoo`03001oogoo005oo`003goo00<007ooOol0]7oo00<007ooOol0Dgoo00<0
07ooOol00Goo000?Ool2002eOol00`00Oomoo`1AOol30003Ool000moo`03001oogoo0;=oo`03001o
o`0005Aoo`03001oogoo005oo`003goo00<007ooOol0/goo00@007oo000005=oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo0`000goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00Qoo`@000=oo`<00?moo`Uoo`<000=oo`0027oo00<007oo000017oo00<007ooOol0ogoo2goo00<0
07ooOol00Goo0009Ool20004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo
009oo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo00<007oo000017oo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Goo
000:Ool00`00Oomoo`02Oooo000?0003Ool000Qoo`800?mooaMoo`0027oo00<007ooOol0ogoo5Woo
0008Ool3003oOolFOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.05975 .2181 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.21047 .2026 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.05975 .2181 m
.14286 .28571 L
.21047 .2026 L
s
.06961 .23993 m
.05975 .2181 L
.08313 .22331 L
s
.20526 .22599 m
.21047 .2026 L
.18864 .21246 L
s
gsave
.05975 .2181 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.21047 .2026 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.05975 .2181 m
.14286 .28571 L
.21047 .2026 L
s
.06961 .23993 m
.05975 .2181 L
.08313 .22331 L
s
.20526 .22599 m
.21047 .2026 L
.18864 .21246 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.81088 .71429 m
.81088 .77143 L
.52516 .77143 L
.52516 .71429 L
F
0 g
.01 w
.47981 .37881 m
.75975 .436 L
s
.02 w
.47981 .37881 Mdot
.75975 .436 Mdot
gsave
.35393 .35171 -62.9379 -6.27266 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.50543 .35393 -62.9379 -6.27266 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -62.9379 -6.27266 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.35393 .35171 m
.42857 .42857 L
.50543 .35393 L
s
.36117 .37455 m
.35393 .35171 L
.37654 .35962 L
s
.49753 .37654 m
.50543 .35393 L
.4826 .36117 L
s
gsave
.77516 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66802 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.66802 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.77516 .71429 m
.66802 .71429 L
.66802 .82143 L
s
.75374 .70357 m
.77516 .71429 L
.75374 .725 L
s
.65731 .8 m
.66802 .82143 L
.67874 .8 L
s
gsave
.81586 .60552 -61.1106 -3.86039 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68019 .673 -61.1106 -3.86039 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -61.1106 -3.86039 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81586 .60552 m
.71429 .57143 L
.68019 .673 L
s
.79895 .58855 m
.81586 .60552 L
.79213 .60886 L
s
.67685 .64928 m
.68019 .673 L
.69717 .6561 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`00P004Goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O003
Ool00`00Oomoo`0>Ool00`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02mo
o`9l00Aoo`03001oo`00011oo`0301moogoo04eoo`0301moogoo06moo`03001oogoo005oo`003goo
00<007ooOol0;Goo0W`017oo100000=oo`00Ool03Goo00<07gooOol0CWoo00<07gooOol0Kgoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0ZOol3O004Ool3000017oo000007oo0P003Goo00<07gooOol0
Cgoo00<07gooOol0KWoo00<007ooOol00Goo000?Ool00`00Oomoo`0XOol2O006Ool00`00Oomoo`02
000AOol00`0OOomoo`1@Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo00eoo`80
0003Ool007oo01Aoo`9l00Yoo`03001oo`00015oo`0301moogoo055oo`0301moogoo06eoo`03001o
ogoo005oo`003goo00<007ooOol03Goo1@004Goo0g`02goo00@007ooOol0015oo`0301moogoo055o
o`0301moogoo06eoo`03001oogoo005oo`003goo00<007ooOol03Woo0`0000=oo`0000003Goo0W`0
3Goo00D007ooOomoo`00011oo`0301moogoo05=oo`0301moogoo06aoo`03001oogoo005oo`003goo
0P003goo00@007ooOol000eoo`Ml00Uoo`03001oogoo01=oo`0301moogoo05=oo`0301moogoo06Yo
o`<000=oo`003goo00<007ooOol03goo00@007ooOol000Yoo`=l00Ioo`=l00Eoo`03001oogoo01=o
o`0301moogoo05Aoo`0301moogoo06aoo`03001oogoo005oo`003goo00<007ooOol03goo00D007oo
Oomoo`0000Qoo`9l00]oo`=l009oo`03001oogoo01=oo`0301moogoo05Eoo`0301moogoo06]oo`03
001oogoo005oo`003goo00<007ooOol047oo00D007ooOomoo`0000Eoo`9l011oo`03O00007oo01Ao
o`0301moogoo05Ioo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol05Goo0P000Woo
00=l07ooOol047oo00<007ooO00057oo00<07gooOol0Egoo00<07gooOol0JWoo00<007ooOol00Goo
000?Ool00`00Oomoo`0GOol00`00O01oo`0AOol01@00OomoogooO0004goo00<07gooOol097oo2`0O
:7oo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0001oo`0@Ool00`00
Oomoo`03Ool00g`0Oomoo`0@Ool00`0OOomoo`0SOol>01lVOol00`0OOomoo`1ZOol00`00Oomoo`01
Ool000moo`03001oogoo01Ioo`04O01oogoo000@Ool00`00Oomoo`03Ool00g`0Oomoo`0?Ool00`0O
Oomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Moo`04O01oogooOol2
000=Ool00`00Oomoo`05Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROolB01lUOol00`0OOomoo`1WOol3
0003Ool000moo`03001oogoo01Eoo`03O01oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Ioo`03
O01oogoo00ioo`0301moogoo029ooa<07bAoo`0301moogoo06Uoo`03001oogoo005oo`003goo00<0
07ooOol05Goo00=l07ooOol01Goo00<007ooOol01goo00<007ooOol027oo00=l07ooOol03Goo00<0
7gooOol08Goo500O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lS
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Aoo`03O01oogoo00Qoo`03001o
ogoo00=oo`03001oogoo00Yoo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uo
o`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol02Goo0P000goo
00<007ooOol02goo00=l07ooOol037oo00<07gooOol087oo5P0O8goo00<07gooOol0JGoo00<007oo
Ool00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0;Ool00`00Ool0000>Ool0
0g`0Oomoo`0<Ool00`0OOomoo`0POolF01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03
001oo`0000Aoo`<001Aoo`03O01oogoo00aoodh000X07b=oo`0301moogoo06Moo`<000=oo`0027oo
00<007oo000017oo00<007ooOol057oo00=l07ooOol03Goo0P003Goo00=l07ooOol037oo00<07goo
Ool087oo2`0O00<0000O01l02@0O8Woo00<07gooOol0JGoo00<007ooOol00Goo0008Ool00`00Ool0
0004Ool00`00Oomoo`0DOol00g`0Oomoo`0?Ool00`00Oomoo`0:Ool00g`0Oomoo`0<Ool00`0OOomo
o`0POol;01l00`0001l07`0901lROol00`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo
00=oo`03001oogoo01Aoo`03O01oogoo00moo`03001oogoo00Uoo`03O01oogoo00eoo`0301moogoo
021oo`/07`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol0
57oo00=l07ooOol03Goo0`002goo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O
8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0IOol00g`0
Oomoo`0>Ool00`0OOomoo`0QOol:01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01
Ool000moo`03001oogoo01Eoo`03O01oogoo01Uoo`03O01oogoo00ioo`0301moogoo025oo`X07`03
00007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07oo
Ool06Goo00=l07ooOol03Woo00<07gooOol08Woo2@0O00<0000O01l01`0O97oo00<07gooOol0JGoo
00<007ooOol00Goo000?Ool2000GOol00g`0Oomoo`0GOol00g`0Oomoo`0?Ool00`0OOomoo`0SOol8
01l00`0001l07`0601lTOol00`0OOomoo`1XOol30003Ool000moo`03001oogoo01Moo`03O01oogoo
01Ioo`03O01oogoo011oo`0301moogoo02=oo`L07`0300007`0O00D07bEoo`0301moogoo06Yoo`03
001oogoo005oo`003goo00<007ooOol05goo00=l07ooOol05Goo00=l07ooOol04Goo00<07gooOol0
8goo1`0O00<0000O01l00`0O9goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0H
Ool00g`0Oomoo`0COol00g`0Oomoo`0BOol00`0OOomoo`0UOol501l0100001l07`0O:Goo00<07goo
Ool0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomoo`0COol0
0`0OOomoo`0WOol301l00`0001moo`0ZOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001o
ogoo01Yoo`9l011oo`03O01oogoo01Aoo`0301moogoo02Aoo`d3h2Eoo`0301moogoo06]oo`03001o
ogoo005oo`003goo00<007ooOol077oo0g`02goo0W`067oo00<07gooOol07Woo5@?P8Woo00<07goo
Ool0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0OOol3O004Ool4O00JOol00`0OOomoo`0LOolI
0n0OOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`80029oo`El01moo`0301moogoo01Yooad3
h0Moo`8001=oo`0301moogoo06Yoo`<000=oo`003goo00<007ooOol08goo0W`087oo00<07gooOol0
67oo80?P1goo00<007ooOol047oo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0U
Ool3O00NOol00`0OOomoo`0COol200000goo0003h00P0n06Ool00`00Oomoo`0@Ool00`0OOomoo`1]
Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo01=oo`D00243h09oo`<0
0003Ool007oo00moo`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol0:Woo0W`06Woo
00<07gooOol04goo00D3h000000000?P008001h3h0H00003Ool0000000moo`0301moogoo06ioo`03
001oogoo005oo`003goo00<007ooOol0;7oo0W`06Goo00<07gooOol04Woo00@3h0000n0001l3h080
0083h08001=oo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Woo0g`05goo00<0
7gooOol04Goo00D3h0000n03h0000243h0040003h0000n0BOol00`0OOomoo`1_Ool00`00Oomoo`01
Ool000moo`80039oo`9l01Eoo`0301moogoo011oo`<3h0040003h0?P000O0n001@000n03h0000n00
4Goo00<07gooOol0KWoo0`000goo000?Ool00`00Oomoo`0cOol2O00DOol00`0OOomoo`0>Ool40n00
1@000n03h0?P00006P?P0P0000D3h0000n03h0000083h15oo`0301moogoo071oo`03001oogoo005o
o`003goo00<007ooOol0=Goo0W`04Woo00<07gooOol03Goo2P?P00<000?P0n005P?P20000`?P3goo
00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0gOol3O00@Ool00`0OOomoo`0<Ool;
0n000`000n03h00E0n0<000>Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Yo
o`9l00ioo`0301moogoo00]oo`d3h0030003h0?P01D3h08000@3h0T000Uoo`0301moogoo079oo`03
001oogoo005oo`003goo00<007ooOol0?7oo0W`03Goo00<07gooOol02Woo3P?P00<000?P0n004`?P
00<000?P0n002@?P2@0017oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0nOol2
O00<Ool00`0OOomoo`09Ool>0n000`000n03h00A0n02000>0n02Ool:001dOol00`00Oomoo`01Ool0
00moo`03001oogoo041oo`9l00]oo`0301moogoo00Mooa03h0030003h0?P00l3h0030003h0?P00h3
h0Moo`X006moo`03001oogoo005oo`003goo0P00@goo0g`027oo00<07gooOol01goo4@?P00<000?P
0n003@?P00<000?P0n003`?P27oo00@07gooOomoo`T006Uoo`<000=oo`003goo00<007ooOol0AGoo
0W`01goo00<07gooOol01Goo4`?P00<000?P0n002`?P00<000?P0n0040?P27oo00<07gooOol01Woo
2@00IWoo00<007ooOol00Goo000?Ool00`00Oomoo`17Ool2O006Ool201l5OolD0n000`000n03h009
0n000`000n03h00A0n06Ool201l=Ool:001QOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l
00Ioo`0301moogoo009ooaD3h0030003h0?P00L3h0030003h0?P01<3h0Aoo`0301moogoo019oo`T0
05eoo`03001oogoo005oo`003goo00<007ooOol0Bgoo0g`017oo00<07gooOol05`?P00<000?P0n00
1@?P00<000?P0n0050?P0goo00<07gooOol067oo2@00F7oo00<007ooOol00Goo000?Ool00`00Oomo
o`1>Ool2O003Ool00`0OOol3h00G0n000`000n03h0030n000`000n03h00E0n02Ool00`0OOomoo`0M
Ool:001COol00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo051oo`9l009oo`0301l3h0?P01L3
h0050003h0?P0n00000H0n000goo01moo`0TOol:001>Ool00`00Oomoo`01Ool000Uoo`03001oogoo
00=oo`03001oogoo059oo`9l0003Ool3h0?P01P3h0030003h000008001L3h00301moogoo02Uoo`T0
04Yoo`03001oogoo005oo`002Goo00<007ooOol00goo0`00E7oo00=l00?P0n006@?P10005`?P<Goo
2@00@goo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolL0n000`000n00000G0n0YOol<
O1l:0010Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooad3h0030003h0?P
01H3h2IooaAl7`H003moo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0EGoo7@?P00<000?P
0n005P?P8Woo6W`O10000W`O?Goo00<007ooOol00Goo000?Ool00`00Oomoo`1EOolf0n0POolMO1l2
0004O1llOol00`00Oomoo`01Ool000moo`03001oogoo05Iooc@3h21oobIl7cYoo`03001oogoo005o
o`003goo00<007ooOol0EWoo=0?P7Woo:W`O>7oo00<007ooOol00Goo000?Ool2001HOolc0n0LOol]
O1leOol30003Ool000moo`03001oogoo05Mooc<3h1]ooc1l7cEoo`03001oogoo005oo`003goo00<0
07ooOol0Egoo<`?P6Goo<g`O=7oo00<007ooOol00Goo000?Ool00`00Oomoo`1HOola0n0JOoldO1lc
Ool00`00Oomoo`01Ool000moo`03001oogoo05Qooc43h1UoocIl7c9oo`03001oogoo005oo`003goo
00<007ooOol0FGoo<0?P67oo>7`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol_0n0HOolj
O1l`Ool00`00Oomoo`01Ool000moo`03001oogoo05Uoobh3h1Qoocal7bmoo`03001oogoo005oo`00
3goo0P00Fgoo;0?P67oo?G`O;Goo0`000goo000?Ool00`00Oomoo`1KOol[0n0GOoloO1l^Ool00`00
Oomoo`01Ool000moo`03001oogoo05aoobT3h1Qoocml7bioo`03001oogoo005oo`003goo00<007oo
Ool0G7oo:0?P67oo@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1MOolV0n0IOom2O1l/Ool0
0`00Oomoo`01Ool000moo`03001oogoo05ioob@3h1Uood=l7baoo`03001oogoo005oo`003goo00<0
07ooOol0Ggoo8P?P6GooAG`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`1POolO0n0KOom6O1lZ
Ool00`00Oomoo`01Ool000moo`8006Aooa/3h1]oodMl7bQoo`<000=oo`003goo00<007ooOol0IGoo
5`?P7GooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1WOolC0n0OOom8O1lYOol00`00Oomo
o`01Ool000moo`03001oogoo06Yoo`d3h29oodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0
Kgoo0`?P9WooBG`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomoo`01
Ool000moo`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo0P00VGooBW`O9Woo0`000goo
000?Ool00`00Oomoo`2GOom;O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03
001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2G
Oom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`0027oo
0`0017oo00<007ooOol0UWooCG`O9goo00<007ooOol00Goo0008Ool00`00Oomoo`04Ool00`00Oomo
o`2FOom=O1lWOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<009IoobMl7`8002Al7bEoo`<0
00=oo`002Goo00<007ooOol00goo00<007ooOol0UWoo9g`O00<007`O00000P008G`O9goo00<007oo
Ool00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2FOolVO1l01000O1ml7g`O1@007W`O9goo00<0
07ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`2GOolUO1l00`00O1ml7`03O1l00`00O1ml
7`03000KO1lWOol00`00Oomoo`01Ool000moo`03001oogoo09MoobEl7`03001l7g`O00=l7`03001l
7g`O00=l7`<001Ql7bMoo`03001oogoo005oo`003goo00<007ooOol0Ugoo97`O00<007`OO1l00W`O
0P002G`O0`001G`O00<007`OO1l03G`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolTO1l0
0`00O1ml7`02O1l3000;O1l30003O1l00`00O1ml7`0<O1lWOol00`00Oomoo`01Ool000moo`03001o
ogoo09MoobAl7`03001l7g`O01=l7`<00003O1l0000000al7bMoo`03001oogoo005oo`003goo0P00
V7oo8g`O00<007`OO1l05g`O10002W`O9Woo0`000goo000?Ool00`00Oomoo`2HOolRO1l00`00O1ml
7`0IO1l30009O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qoob9l7`03001l7g`O01El7`@0
00al7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo8G`O00<007`OO1l07W`O0P0000=l7`00
O1l00W`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolPO1l00`00O1ml7`0PO1l00`00O1ml
7`02O1lYOol00`00Oomoo`01Ool000moo`03001oogoo09Uoob1l7`03001l7g`O01ml7`03001l7`00
00=l7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo7g`O00<007`OO1l09W`O:Goo00<007oo
Ool00Goo000?Ool2002JOolOO1l00`00O1ml7`0UO1lXOol30003Ool000moo`03001oogoo09Yooail
7`03001l7g`O02El7bYoo`03001oogoo005oo`003goo00<007ooOol0VWoo7G`O00<007`OO1l09G`O
:goo00<007ooOol00Goo000?Ool00`00Oomoo`2KOolLO1l00`00O1ml7`0TO1l/Ool00`00Oomoo`01
Ool000moo`03001oogoo09aooa]l7`03001l7g`O02Al7baoo`03001oogoo005oo`003goo00<007oo
Ool0W7oo6W`O00<007`OO1l097`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolFO1l01000
O1ml7`009W`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolFO1l01000O1ml7`009G`O;Woo
00<007ooOol00Goo000?Ool2002OOolEO1l00`00O1l00002O1l00`00O1ml7`0PO1l]Ool30003Ool0
00moo`03001oogoo09mooaAl7`05001l7`00O1l0000SO1l_Ool00`00Oomoo`01Ool000moo`03001o
ogoo0:1ooaAl7`<002=l7c1oo`03001oogoo005oo`003goo00<007ooOol0XGoo4g`O0P0097`O<7oo
00<007ooOol00Goo000?Ool00`00Oomoo`2ROolBO1l00`00O1ml7`0RO1laOol00`00Oomoo`01Ool0
00moo`03001oogoo0:=ooa=l7`80021l7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo57`O
00<007`OO1l07G`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOolBO1l00`00O1ml7`0KO1le
Ool00`00Oomoo`01Ool000moo`800:Mooa1l7`03001l7`0001Yl7cEoo`<000=oo`003goo00<007oo
Ool0Z7oo3W`O00@007`O000001Ql7cQoo`03001oogoo005oo`003goo00<007ooOol0ZWoo9W`O>Woo
00<007ooOol00Goo000?Ool00`00Oomoo`2[OolSO1llOol00`00Oomoo`01Ool000moo`03001oogoo
0:eoob1l7ceoo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0[goo67`O0P000W`O?goo00<0
07ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2bOolEO1l2Ool3000nOol00`00Oomoo`01
Ool000Uoo`03001oogoo00=oo`<0071ooi/000=oo`002Woo00<007ooOol00Woo00<007ooOol0RWoo
9P?o00<000?o0ol060?o0P002P?o<goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomo
o`2:OolV0ol010000ol3o`?o0`004P?o0P001@?o0P0000<3o`000ol00P?o<goo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool00`00Oomoo`2:OolV0ol01`000ol3o`?o0003o`000103o`8000T3o`03
0003o`?o0083oc=oo`03001oogoo005oo`003goo00<007ooOol0RWoo9P?o00@000?o0ol3o`<001X3
o`030003o`0000<3oc=oo`03001oogoo005oo`003goo00<007ooOol0RWoo9P?o00D000?o0ol3o`00
0283oc=oo`03001oogoo005oo`003goo00<007ooOol0RWoo9P?o00<000?o0ol00P?o0P0080?o<goo
00<007ooOol00Goo000?Ool00`00Oomoo`2:OolV0ol00`000ol3o`0T0olcOol00`00Oomoo`01Ool0
00moo`8008]oobH3o`030003o`?o02@3oc5oo`<000=oo`003goo00<007ooOol0RWoo9P?o00<000?o
0ol090?o<goo00<007ooOol00Goo000?Ool00`00Oomoo`2:OolV0ol00`000ol3o`0T0olcOol00`00
Oomoo`01Ool000moo`03001oogoo08YoobH3o`030003o`?o02@3oc=oo`03001oogoo005oo`003goo
00<007ooOol0RWoo9P?o00<000?o0ol090?o<goo00<007ooOol00Goo000?Ool00`00Oomoo`2:OolV
0ol00`000ol3o`0T0olcOol00`00Oomoo`01Ool000moo`03001oogoo08YoobH3o`030003o`?o02@3
oc=oo`03001oogoo005oo`003goo00<007ooOol0RWoo9P?o00<000?o0ol090?o<goo00<007ooOol0
0Goo000?Ool2002;OolV0ol00`000ol3o`0T0olaOol30003Ool000moo`03001oogoo0;1oo`03001o
ogoo05Moo`03001oogoo005oo`003goo00<007ooOol0/7oo00<007ooOol0Egoo00<007ooOol00Goo
000?Ool00`00Oomoo`2`Ool00`00Oomoo`1GOol00`00Oomoo`01Ool000moo`03001oogoo0;1oo`03
001oogoo05Moo`03001oogoo005oo`003goo00<007ooOol0/7oo00<007ooOol0Egoo00<007ooOol0
0Goo000?Ool00`00Oomoo`2`Ool00`00Oomoo`1GOol00`00Oomoo`01Ool000moo`03001oogoo0;1o
o`03001oogoo05Moo`03001oogoo005oo`003goo0P00[Woo00@007ooOol0009oo`03001oogoo059o
o`<000=oo`003goo00<007ooOol0[Woo00D007oo001oo`0005Moo`03001oogoo005oo`003goo00<0
07ooOol0[Woo00D007oo001oo`0005Moo`03001oogoo005oo`003goo00<007ooOol0[goo0`00F7oo
00<007ooOol00Goo000?Ool00`00Oomoo`2_Ool3001HOol00`00Oomoo`01Ool000moo`03001oogoo
0;1oo`04001oogooOol2001DOol00`00Oomoo`01Ool000moo`03001oogoo0;Eoo`03001oogoo059o
o`03001oogoo005oo`003goo0P00]Woo00<007ooOol0D7oo0`000goo000?Ool00`00Oomoo`2dOol0
0`00Ool0001COol00`00Oomoo`01Ool000moo`03001oogoo0;Aoo`04001oo`00001BOol00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`<000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0008Ool40003Ool3003oOol9Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`]o
o`03001oogoo005oo`002Goo0P0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
005oo`002Woo00<007ooOol00Wooo`003`000goo0008Ool2003oOolGOol000Qoo`03001oogoo0?mo
oaIoo`0027oo0`00ogoo5Woo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.13555 .17882 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.24975 .2784 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.13555 .17882 m
.14286 .28571 L
.24975 .2784 L
s
.12632 .20093 m
.13555 .17882 L
.1477 .19947 L
s
.2291 .29055 m
.24975 .2784 L
.22764 .26918 L
s
gsave
.13555 .17882 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.24975 .2784 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60.2117 -5.95932 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.13555 .17882 m
.14286 .28571 L
.24975 .2784 L
s
.12632 .20093 m
.13555 .17882 L
.1477 .19947 L
s
.2291 .29055 m
.24975 .2784 L
.22764 .26918 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.81811 .71429 m
.81811 .77143 L
.53239 .77143 L
.53239 .71429 L
F
0 g
.01 w
.47365 .37316 m
.75284 .43387 L
s
.02 w
.47365 .37316 Mdot
.75284 .43387 Mdot
gsave
.34546 .36095 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.49619 .34546 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -63.4339 -6.26612 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.34546 .36095 m
.42857 .42857 L
.49619 .34546 L
s
.35532 .38279 m
.34546 .36095 L
.36884 .36617 L
s
.49098 .36884 m
.49619 .34546 L
.47435 .35532 L
s
gsave
.78239 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67525 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67525 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.78239 .71429 m
.67525 .71429 L
.67525 .82143 L
s
.76096 .70357 m
.78239 .71429 L
.76096 .725 L
s
.66453 .8 m
.67525 .82143 L
.68596 .8 L
s
gsave
.81745 .60034 -60.9209 -3.89051 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68537 .6746 -60.9209 -3.89051 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -60.9209 -3.89051 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81745 .60034 m
.71429 .57143 L
.68537 .6746 L
s
.79971 .58424 m
.81745 .60034 L
.79393 .60488 L
s
.68084 .65107 m
.68537 .6746 L
.70147 .65685 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
025oo`03001oogoo00800003Ool007oo01Aoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03
001oogoo005oo`003goo00<007ooOol08Goo0P000goo00<007ooOol04Woo0W`03Woo00<07gooOol0
Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0POol200001Woo001oo`00Ool0
011oo`=l00moo`0301moogoo04Uoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0
87oo0P0000=oo`00Ool04Goo0W`04Goo00<07gooOol0BWoo00<07gooOol0LGoo00<007ooOol00Goo
000?Ool00`00Oomoo`0POol20002Ool00`00Oomoo`0=Ool2O00COol00`0OOomoo`1;Ool00`0OOomo
o`1`Ool00`00Oomoo`01Ool000moo`80021oo`03001oo`0000=oo`03001oogoo00Uoo`=l01Aoo`03
01moogoo04aoo`0301moogoo06ioo`<000=oo`003goo00<007ooOol07goo00<007oo00003Goo0W`0
5goo00<07gooOol0CGoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0QOol00`00
Oomoo`09Ool2O00HOol00`0OOomoo`1>Ool00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`03001o
ogoo029oo`03001oogoo00Eoo`=l01Yoo`0301moogoo04moo`0301moogoo06ioo`03001oogoo005o
o`003goo00<007ooOol08Woo00<007ooOol00goo0W`077oo00<07gooOol0D7oo00<07gooOol0KWoo
00<007ooOol00Goo000?Ool00`00Oomoo`0ROol01000Oomoogoo0W`07Woo00<07gooOol0DGoo00<0
7gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0ROol01000O01l07`087oo00<07gooOol0
DGoo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0QOol00g`0001oo`0QOol00`0O
Oomoo`1COol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`80021oo`=l0004001l07`0O00OOol0
0`0OOomoo`1COol00`0OOomoo`1ZOol30003Ool000moo`03001oogoo01eoo`=l009oo`04001oogoo
Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`03001oogoo01ao
o`9l00Aoo`03001oogoo00Aoo`=l01Qoo`0301moogoo05Eoo`0301moogoo06]oo`03001oogoo005o
o`003goo00<007ooOol06Woo0W`01Woo00<007ooOol01goo0W`05Goo00<07gooOol0EWoo00<07goo
Ool0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`06Ool00`00Oomoo`09Ool0
0g`0Oomoo`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo
01Qoo`03O01oogoo00Moo`03001oogoo00Yoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`03
01moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol05goo00=l07ooOol027oo00<007ooOol0
2goo00=l07ooOol047oo00<07gooOol08goo3P0O9Woo00<07gooOol0JWoo00<007ooOol00Goo000?
Ool00`00Oomoo`0FOol00g`0Oomoo`09Ool00`00Oomoo`0;Ool00g`0Oomoo`0?Ool00`0OOomoo`0S
Ool@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo00Uoo`03001o
ogoo00aoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=oo`003goo
00<007ooOol05Goo00=l07ooOol02goo00<007ooOol02goo00=l07ooOol03Woo00<07gooOol08Woo
4`0O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0;Ool0
0`00Oomoo`0<Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomo
o`01Ool000moo`03001oogoo01Aoo`03O01oogoo00aoo`03001oogoo00aoo`03O01oogoo00Eoo`80
00Ioo`0401moo`00000POolE01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo00aoo`03001oogoo00aoo`03O01oogoo00Moo`<000=oo`0401moogoo000POolE
01lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03
O01oogoo00aoo`03001oogoo00eoo`03O01oogoo00=oo`P00005Ool07gooOol0000OOolF01lSOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo
00aoo`03001oogoo00Eoo`h000Eoo`80009oo`0501moo`00Ool0000NOolF01lSOol00`0OOomoo`1Y
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<001Aoo`03O01oogoo00aoodh000X07b=oo`03
01moogoo06Moo`<000=oo`0027oo00<007oo000017oo00<007ooOol057oo00=l07ooOol047oo0P00
2Woo00=l07ooOol01Goo0P001Goo00<07gooOol087oo2`0O00<0000O01l02@0O8Woo00<07gooOol0
JGoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0BOol00`00
Oomoo`07Ool00g`0Oomoo`04Ool00`00Oomoo`05Ool00`0OOomoo`0POol;01l00`0001l07`0901lR
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03O01o
ogoo019oo`03001oogoo00Ioo`03O01oogoo00eoo`0301moogoo021oo`/07`0300007`0O00P07b=o
o`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol047oo0`0027oo
00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<007oo
Ool00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0IOol00g`0Oomoo`0>Ool00`0OOomoo`0QOol:
01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03
O01oogoo01Uoo`03O01oogoo00ioo`0301moogoo025oo`X07`0300007`0O00P07b=oo`0301moogoo
06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<0
7gooOol08Woo2@0O00<0000O01l01`0O97oo00<07gooOol0JGoo00<007ooOol00Goo000?Ool2000G
Ool00g`0Oomoo`0GOol00g`0Oomoo`0?Ool00`0OOomoo`0SOol801l00`0001l07`0601lTOol00`0O
Oomoo`1XOol30003Ool000moo`03001oogoo01Moo`03O01oogoo01Ioo`03O01oogoo011oo`0301mo
ogoo02=oo`L07`0300007`0O00D07bEoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007oo
Ool05goo00=l07ooOol05Goo00=l07ooOol04Goo00<07gooOol08goo1`0O00<0000O01l00`0O9goo
00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol00g`0Oomoo`0COol00g`0Oomo
o`0BOol00`0OOomoo`0UOol501l0100001l07`0O:Goo00<07gooOol0JWoo00<007ooOol00Goo000?
Ool00`00Oomoo`0IOol00g`0Oomoo`0AOol00g`0Oomoo`0COol00`0OOomoo`0WOol301l00`0001mo
o`0ZOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Yoo`9l011oo`03O01oogoo
01Aoo`0301moogoo02Aoo`d3h2Eoo`0301moogoo06]oo`03001oogoo005oo`003goo00<007ooOol0
77oo0g`02goo0W`067oo00<07gooOol07Woo5@?P2Goo0P005goo00<07gooOol0Jgoo00<007ooOol0
0Goo000?Ool00`00Oomoo`0OOol3O004Ool4O00JOol00`0OOomoo`0LOolI0n08Ool00`00Oomoo`0D
Ool00`0OOomoo`1/Ool00`00Oomoo`01Ool000moo`80029oo`El01moo`0301moogoo01Yooad3h0=o
o`03001oo`0001Ioo`0301moogoo06Yoo`<000=oo`003goo00<007ooOol08goo0W`087oo00<07goo
Ool067oo80?P100000=oo`00Ool04goo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomo
o`0UOol3O00NOol00`0OOomoo`0FOolO0n03000017oo000007oo0P004goo00<07gooOol0KGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0XOol2O00LOol00`0OOomoo`0EOolN0n0200020n000`000n00
000FOol00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Yoo`9l01Yoo`0301moogoo
011oo`800003Ool000?P0243h0040003h0000n0FOol00`0OOomoo`1^Ool00`00Oomoo`01Ool000mo
o`03001oogoo02aoo`9l01Uoo`0301moogoo011oo`<00243h0040003h0?P00030n0COol00`0OOomo
o`1_Ool00`00Oomoo`01Ool000moo`03001oogoo02ioo`=l01Moo`0301moogoo00moo`L001`3h005
0003h0?P0n0000040n0BOol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`80039oo`9l01Eoo`03
01moogoo011oo`<001d3h0<000<3h0030003h0?P0083h15oo`0301moogoo06ioo`<000=oo`003goo
00<007ooOol0<goo0W`057oo00<07gooOol03Woo00D3h0000n03h00001/3h0L000D3h15oo`0301mo
ogoo071oo`03001oogoo005oo`003goo00<007ooOol0=Goo0W`04Woo00<07gooOol03Goo0`?P00@0
00?P0n0001X3h0`000030n1oogoo00eoo`0301moogoo075oo`03001oogoo005oo`003goo00<007oo
Ool0=goo0g`047oo00<07gooOol037oo0`?P00D000?P0n03h00001T3h0<000@3h0T000aoo`0301mo
ogoo075oo`03001oogoo005oo`003goo00<007ooOol0>Woo0W`03Woo00<07gooOol02goo2@?P00<0
00?P0n005@?P00<000?P0n002P?P2@001Woo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00
Oomoo`0lOol2O00=Ool00`0OOomoo`0:Ool:0n02000E0n000`000n03h00=0n000goo000000080000
0goo01moo`1cOol00`00Oomoo`01Ool000moo`03001oogoo03ioo`9l00aoo`0301moogoo00Uoo``3
h0030003h0?P0143h0030003h0?P00l3h0Eoo`X0075oo`03001oogoo005oo`003goo00<007ooOol0
@7oo0W`02goo00<07gooOol01goo3P?P00<000?P0n003`?P00<000?P0n0040?P2Goo00<07`000000
1`00KGoo00<007ooOol00Goo000?Ool20013Ool3O008Ool00`0OOomoo`07Ool?0n000`000n03h00=
0n000`000n03h00A0n08Ool00`0OOomoo`04Ool9001VOol30003Ool000moo`03001oogoo04Eoo`9l
00Moo`0301moogoo00Eooa43h08000`3h0030003h0?P0183h0Qoo`0301moogoo00Qoo`X006=oo`03
001oogoo005oo`003goo00<007ooOol0Agoo0W`01Woo0P0O1Goo4`?P00<000?P0n002@?P00<000?P
0n004P?P1Woo0P0O47oo2@00Ggoo00<007ooOol00Goo000?Ool00`00Oomoo`19Ool2O006Ool00`0O
Oomoo`02OolD0n000`000n03h0070n000`000n03h00D0n04Ool00`0OOomoo`0EOol9001JOol00`00
Oomoo`01Ool000moo`03001oogoo04]oo`=l00Aoo`0301moogoo01H3h0030003h0?P00D3h0030003
h0?P01D3h0=oo`0301moogoo01Yoo`X005Eoo`03001oogoo005oo`003goo00<007ooOol0CWoo0W`0
0goo00<07goo0n005P?P00<000?P0n000`?P00<000?P0n005P?P0Woo00<07gooOol087oo2P00D7oo
00<007ooOol00Goo0007Ool50003Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00F0n0200030n00
0`000n03h00F0n000goo01moo`0WOol9001<Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03
001oogoo059oo`9l0003Ool3h0?P01P3h0030003h000008001L3h00301moogoo02aoo`T004Moo`03
001oogoo005oo`002Goo00<007ooOol00goo0`00E7oo00=l00?P0n006@?P10005`?P<goo2P00@7oo
0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolL0n000`000n00000G0n0YOol?O1l60011
Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo05Eooad3h0030003h0?P01H3h2Io
oaAl7`@0045oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0EGoo7@?P00<000?P0n005P?P
8Woo6G`O0P001G`O?Goo00<007ooOol00Goo000?Ool00`00Oomoo`1EOolf0n0POolSO1llOol00`00
Oomoo`01Ool000moo`03001oogoo05Iooc@3h21oobIl7cYoo`03001oogoo005oo`003goo00<007oo
Ool0EWoo=0?P7Woo:W`O>7oo00<007ooOol00Goo000?Ool2001HOolc0n0LOol]O1leOol30003Ool0
00moo`03001oogoo05Mooc<3h1]ooc1l7cEoo`03001oogoo005oo`003goo00<007ooOol0Egoo<`?P
6Goo<g`O=7oo00<007ooOol00Goo000?Ool00`00Oomoo`1HOola0n0JOoldO1lcOol00`00Oomoo`01
Ool000moo`03001oogoo05Qooc43h1UoocIl7c9oo`03001oogoo005oo`003goo00<007ooOol0FGoo
<0?P67oo>7`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol_0n0HOoljO1l`Ool00`00Oomo
o`01Ool000moo`03001oogoo05Uoobh3h1Qoocal7bmoo`03001oogoo005oo`003goo0P00Fgoo;0?P
67oo?G`O;Goo0`000goo000?Ool00`00Oomoo`1KOol[0n0GOoloO1l^Ool00`00Oomoo`01Ool000mo
o`03001oogoo05aoobT3h1Qoocml7bioo`03001oogoo005oo`003goo00<007ooOol0G7oo:0?P67oo
@W`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1MOolV0n0IOom2O1l/Ool00`00Oomoo`01Ool0
00moo`03001oogoo05ioob@3h1Uood=l7baoo`03001oogoo005oo`003goo00<007ooOol0Ggoo8P?P
6GooAG`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`1POolO0n0KOom6O1lZOol00`00Oomoo`01
Ool000moo`8006Aooa/3h1]oodMl7bQoo`<000=oo`003goo00<007ooOol0IGoo5`?P7GooB7`O:Goo
00<007ooOol00Goo000?Ool00`00Oomoo`1WOolC0n0OOom8O1lYOol00`00Oomoo`01Ool000moo`03
001oogoo06Yoo`d3h29oodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0Kgoo0`?P9WooBG`O
:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2HOom:O1lXOol00`00Oomoo`01Ool000moo`03001o
ogoo09QoodYl7bQoo`03001oogoo005oo`003goo0P00VGooBW`O9Woo0`000goo000?Ool00`00Oomo
o`2GOom;O1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`00
3goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00
Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005oo`0027oo0`0017oo00<007oo
Ool0UWooCG`O9goo00<007ooOol00Goo0008Ool00`00Oomoo`04Ool00`00Oomoo`2FOom=O1lWOol0
0`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<009IoobMl7`8002Al7bEoo`<000=oo`002Goo00<0
07ooOol00goo00<007ooOol0UWoo9g`O00<007`O00000`0087`O9goo00<007ooOol00Goo0008Ool0
0`00Ool00004Ool00`00Oomoo`2FOolVO1l01000O1ml7g`O1P007G`O9goo00<007ooOol00Goo0009
Ool00`00Oomoo`03Ool00`00Oomoo`2GOolUO1l00`00O1ml7`03O1l01000O1ml7g`O0`006W`O9goo
00<007ooOol00Goo000?Ool00`00Oomoo`2GOolUO1l00`00O1ml7`03O1l00`00O1ml7`04O1l40007
O1l00`00O1ml7`0<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09MoobEl7`04001l7g`OO1l2
000;O1l30005O1l00`00O1ml7`0;O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09MoobAl7`03
001l7g`O009l7`<000el7`<000=l7`03001l7g`O00Yl7bMoo`03001oogoo005oo`003goo00<007oo
Ool0Ugoo97`O00<007`OO1l05G`O1@002g`O9goo00<007ooOol00Goo000?Ool2002HOolTO1l00`00
O1ml7`0HO1l30009O1lVOol30003Ool000moo`03001oogoo09Qoob9l7`03001l7g`O01El7`@000al
7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo8W`O00<007`OO1l07W`O0P0000=l7`00O1l0
0W`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOolRO1l00`00O1ml7`0PO1l01000O1ml7g`O
:Goo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolQO1l00`00O1ml7`0OO1l00`00O1l00002O1lY
Ool00`00Oomoo`01Ool000moo`03001oogoo09Uoob1l7`03001l7g`O02El7bUoo`03001oogoo005o
o`003goo00<007ooOol0VGoo87`O00<007`OO1l09G`O:Goo00<007ooOol00Goo000?Ool2002JOolP
O1l00`00O1ml7`0TO1lXOol30003Ool000moo`03001oogoo09Yooail7`03001l7g`O02El7bYoo`03
001oogoo005oo`003goo00<007ooOol0VWoo7W`O00<007`OO1l097`O:goo00<007ooOol00Goo000?
Ool00`00Oomoo`2KOolMO1l00`00O1ml7`0SO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09ao
oaal7`03001l7g`O02=l7baoo`03001oogoo005oo`003goo00<007ooOol0W7oo6g`O00<007`OO1l0
8g`O;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOolJO1l00`00O1ml7`0SO1l]Ool00`00Oomo
o`01Ool000moo`03001oogoo09eooaMl7`04001l7g`O000TO1l^Ool00`00Oomoo`01Ool000moo`80
09mooaIl7`03001l7`00009l7`03001l7g`O01ml7beoo`<000=oo`003goo00<007ooOol0Wgoo5G`O
00D007`O001l7`00029l7bmoo`03001oogoo005oo`003goo00<007ooOol0X7oo57`O00@007`O0000
029l7c1oo`03001oogoo005oo`003goo00<007ooOol0XGoo57`O0`008W`O<7oo00<007ooOol00Goo
000?Ool00`00Oomoo`2ROolCO1l2000RO1laOol00`00Oomoo`01Ool000moo`03001oogoo0:=ooa9l
7`03001l7g`O008001il7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo5W`O00<007`OO1l0
6g`O<goo00<007ooOol00Goo000?Ool00`00Oomoo`2UOolDO1l00`00O1ml7`0IO1leOol00`00Oomo
o`01Ool000moo`800:Mooa9l7`03001l7`0001Ql7cEoo`<000=oo`003goo00<007ooOol0Z7oo47`O
00@007`O000001Il7cQoo`03001oogoo005oo`003goo00<007ooOol0ZWoo9W`O>Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`2[OolSO1llOol00`00Oomoo`01Ool000moo`03001oogoo0:eoob1l7ceo
o`03001oogoo005oo`0027oo0P001Goo00<007ooOol0[goo6W`O0P00?goo00<007ooOol00Goo000:
Ool00`00Oomoo`02Ool00`00Oomoo`2bOolEO1l4Ool3000lOol00`00Oomoo`01Ool000Uoo`03001o
ogoo00=oo`<0071ooi/000=oo`002Woo00<007ooOol00Woo00<007ooOol0S7oo9P?o00<000?o0ol0
60?o0P002P?o<Goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2<OolV0ol01000
0ol3o`?o0`004P?o0P001@?o0P0000<3o`000ol00P?o<Goo00<007ooOol00Goo0009Ool00`00Oomo
o`03Ool00`00Oomoo`2<OolV0ol01`000ol3o`?o0003o`000103o`8000T3o`030003o`?o0083oc5o
o`03001oogoo005oo`003goo00<007ooOol0S7oo9P?o00@000?o0ol3o`<001X3o`030003o`0000<3
oc5oo`03001oogoo005oo`003goo00<007ooOol0S7oo9P?o00D000?o0ol3o`000283oc5oo`03001o
ogoo005oo`003goo00<007ooOol0S7oo9P?o00<000?o0ol00P?o0P0080?o<Goo00<007ooOol00Goo
000?Ool00`00Oomoo`2<OolV0ol00`000ol3o`0T0olaOol00`00Oomoo`01Ool000moo`8008eoobH3
o`030003o`?o02@3obmoo`<000=oo`003goo00<007ooOol0S7oo9P?o00<000?o0ol090?o<Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`2<OolV0ol00`000ol3o`0T0olaOol00`00Oomoo`01Ool000mo
o`03001oogoo08aoobH3o`030003o`?o02@3oc5oo`03001oogoo005oo`003goo00<007ooOol0S7oo
9P?o00<000?o0ol090?o<Goo00<007ooOol00Goo000?Ool00`00Oomoo`2<OolV0ol00`000ol3o`0T
0olaOol00`00Oomoo`01Ool000moo`03001oogoo08aoobH3o`030003o`?o02@3oc5oo`03001oogoo
005oo`003goo00<007ooOol0S7oo9P?o00<000?o0ol090?o<Goo00<007ooOol00Goo000?Ool2002=
OolV0ol00`000ol3o`0T0ol_Ool30003Ool000moo`03001oogoo0;9oo`03001oogoo05Eoo`03001o
ogoo005oo`003goo00<007ooOol0/Woo00<007ooOol0EGoo00<007ooOol00Goo000?Ool00`00Oomo
o`2bOol00`00Oomoo`1EOol00`00Oomoo`01Ool000moo`03001oogoo0;9oo`03001oogoo05Eoo`03
001oogoo005oo`003goo00<007ooOol0/Woo00<007ooOol0EGoo00<007ooOol00Goo000?Ool00`00
Oomoo`2bOol00`00Oomoo`1EOol00`00Oomoo`01Ool000moo`03001oogoo0;9oo`03001oogoo05Eo
o`03001oogoo005oo`003goo0P00/7oo00@007ooOol0009oo`03001oogoo051oo`<000=oo`003goo
00<007ooOol0/7oo00D007oo001oo`0005Eoo`03001oogoo005oo`003goo00<007ooOol0/7oo00D0
07oo001oo`0005Eoo`03001oogoo005oo`003goo00<007ooOol0/Goo0`00EWoo00<007ooOol00Goo
000?Ool00`00Oomoo`2aOol3001FOol00`00Oomoo`01Ool000moo`03001oogoo0;9oo`04001oogoo
Ool2001BOol00`00Oomoo`01Ool000moo`03001oogoo0;Moo`03001oogoo051oo`03001oogoo005o
o`003goo0P00^7oo00<007ooOol0CWoo0`000goo000?Ool00`00Oomoo`2fOol00`00Ool0001AOol0
0`00Oomoo`01Ool000moo`03001oogoo0;Ioo`04001oo`00001@Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`<000=oo`03001oogoo0?moo`]oo`03001o
ogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool40003
Ool3003oOol9Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`002Goo0P0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo005oo`002Woo00<0
07ooOol00Wooo`003`000goo0008Ool2003oOolGOol000Qoo`03001oogoo0?mooaIoo`0027oo0`00
ogoo5Woo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.21599 .20741 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.22116 .35884 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.21599 .20741 m
.14286 .28571 L
.22116 .35884 L
s
.19353 .21576 m
.21599 .20741 L
.20919 .23038 L
s
.19819 .35205 m
.22116 .35884 L
.21281 .33639 L
s
gsave
.21599 .20741 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.22116 .35884 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -58.7598 -5.04345 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.21599 .20741 m
.14286 .28571 L
.22116 .35884 L
s
.19353 .21576 m
.21599 .20741 L
.20919 .23038 L
s
.19819 .35205 m
.22116 .35884 L
.21281 .33639 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.82579 .71429 m
.82579 .77143 L
.54008 .77143 L
.54008 .71429 L
F
0 g
.01 w
.46687 .36828 m
.74539 .432 L
s
.02 w
.46687 .36828 Mdot
.74539 .432 Mdot
gsave
.33813 .37113 -63.9239 -6.24225 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.48602 .33813 -63.9239 -6.24225 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -63.9239 -6.24225 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.33813 .37113 m
.42857 .42857 L
.48602 .33813 L
s
.35047 .39166 m
.33813 .37113 L
.36196 .37357 L
s
.48357 .36196 m
.48602 .33813 L
.46548 .35047 L
s
gsave
.79008 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68293 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.68293 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.79008 .71429 m
.68293 .71429 L
.68293 .82143 L
s
.76865 .70357 m
.79008 .71429 L
.76865 .725 L
s
.67222 .8 m
.68293 .82143 L
.69365 .8 L
s
gsave
.81886 .59475 -60.7251 -3.92565 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.69096 .676 -60.7251 -3.92565 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -60.7251 -3.92565 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.81886 .59475 m
.71429 .57143 L
.69096 .676 L
s
.80028 .57963 m
.81886 .59475 L
.79561 .60055 L
s
.68517 .65275 m
.69096 .676 L
.70608 .65742 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`027oo00<007ooOol0
3Goo00<07gooOol0CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O008
Ool30003Ool200000goo001oo`07Ool00`0OOomoo`1?Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool0
00moo`03001oogoo02Qoo`9l00Uoo`@000Ioo`03001oogoo00Ioo`0301moogoo051oo`0301moogoo
06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`02Goo0P0000Aoo`00Ool000Eoo`03001o
o`0000Moo`0301moogoo055oo`0301moogoo06eoo`03001oogoo005oo`003goo00<007ooOol08goo
0g`03Goo00@007ooOol000moo`0301moogoo055oo`0301moogoo06eoo`03001oogoo005oo`003goo
00<007ooOol08Goo0W`03goo00@007ooOol000moo`0301moogoo05=oo`0301moogoo06aoo`03001o
ogoo005oo`003goo0P0087oo1g`02goo00D007ooOomoo`0000moo`0301moogoo05=oo`0301moogoo
06Yoo`<000=oo`003goo00<007ooOol07Goo0g`01Woo0g`01goo00<007ooOol04Goo00<07gooOol0
E7oo00<07gooOol0K7oo00<007ooOol00Goo000?Ool00`00Oomoo`0LOol2O00;Ool3O003Ool00`00
Oomoo`0BOol00`0OOomoo`1EOol00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03001oogoo01Yo
o`9l011oo`9l0003001oogoo019oo`0301moogoo05Ioo`0301moogoo06]oo`03001oogoo005oo`00
3goo00<007ooOol06Goo00=l07ooOol04Goo00<007`0Ool04goo00<07gooOol0Egoo00<07gooOol0
JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol00g`0Oomoo`0BOol00`00Ooml000COol00`0O
Oomoo`0TOol;01lXOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Moo`03O01o
ogoo019oo`05001oogooOoml000BOol00`0OOomoo`0SOol>01lVOol00`0OOomoo`1ZOol00`00Oomo
o`01Ool000moo`03001oogoo01Ioo`03O01oogoo019oo`03001oogoo009oo`03O01oogoo00moo`03
01moogoo02=ooa007bEoo`0301moogoo06Yoo`03001oogoo005oo`003goo0P005goo00=l07ooOol0
4Goo00<007ooOol017oo00=l07ooOol03Woo00<07gooOol08Woo4P0O9Goo00<07gooOol0Igoo0`00
0goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0AOol00`00Oomoo`05Ool00g`0Oomoo`0>Ool00`0O
Oomoo`0ROolC01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03O01o
ogoo011oo`03001oogoo00Moo`03O01oogoo00eoo`0301moogoo025ooa@07bAoo`0301moogoo06Uo
o`03001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol047oo00<007ooOol027oo00=l07oo
Ool03Goo00<07gooOol08Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomo
o`0DOol00g`0Oomoo`0?Ool00`00Oomoo`09Ool00g`0Oomoo`0=Ool00`0OOomoo`0QOolE01lSOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo01Aoo`03O01oogoo
00ioo`03001oogoo00]oo`03O01oogoo00aoo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03
001oogoo005oo`0027oo00<007oo000017oo00<007ooOol057oo00=l07ooOol03Goo00<007ooOol0
37oo00=l07ooOol037oo00<07gooOol087oo5P0O8goo00<07gooOol0JGoo00<007ooOol00Goo0008
Ool00`00Ool00004Ool3000DOol00g`0Oomoo`0<Oom>000:01lSOol00`0OOomoo`1WOol30003Ool0
00Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo00eoo`03001oogoo009oo`<000Moo`03
O01oogoo00aoo`0301moogoo021oo`/07`0300007`0O00T07b9oo`0301moogoo06Uoo`03001oogoo
005oo`0027oo00<007oo000017oo00<007ooOol057oo00=l07ooOol03Woo00@007ooOomoo`8000Qo
o`03O01oogoo00aoo`0301moogoo021oo`/07`0300007`0O00T07b9oo`0301moogoo06Uoo`03001o
ogoo005oo`002Goo00<007ooOol00goo00<007ooOol057oo00=l07ooOol03goo00<007ooOol00Woo
00<007ooOol017oo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07goo
Ool0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`0@Ool01@00Oomoogoo0000
1Woo00=l07ooOol03Goo00<07gooOol087oo2`0O00<0000O01l0200O8goo00<07gooOol0JGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0@Ool40005Ool00g`0Oomoo`0>Ool00`0O
Oomoo`0QOol:01l00`0001l07`0801lSOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001o
ogoo01Eoo`03O01oogoo015oo`03001oogoo00Eoo`03O01oogoo00ioo`0301moogoo025oo`X07`03
00007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l07oo
Ool04Woo00<007ooOol017oo00=l07ooOol03Woo00<07gooOol08Woo2@0O00<0000O01l01`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool2000GOol00g`0Oomoo`0BOol00`00Oomoo`02Ool0
0g`0Oomoo`0?Ool00`0OOomoo`0SOol801l00`0001l07`0601lTOol00`0OOomoo`1XOol30003Ool0
00moo`03001oogoo01Moo`03O01oogoo019oo`05001oogooOoml000BOol00`0OOomoo`0SOol701l0
0`0001l07`0501lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Moo`03O01o
ogoo01=oo`800003O01oogoo015oo`0301moogoo02=oo`L07`0300007`0O00<07bMoo`0301moogoo
06Yoo`03001oogoo005oo`003goo00<007ooOol067oo00=l07ooOol04goo00=l0000Ool04Woo00<0
7gooOol09Goo1@0O00@0000O01l07bUoo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007oo
Ool06Goo00=l07ooOol04Goo00Al07ooOol0019oo`0301moogoo02Moo`<07`0300007goo00eoo`80
01]oo`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo00=l07ooOol0
0Woo00<007ooOol03goo00<07gooOol097oo3@?P2Woo00<007ooOol067oo00<07gooOol0Jgoo00<0
07ooOol00Goo000?Ool00`00Oomoo`0LOol3O00;Ool2O006Ool01@00Oomoogoo00003Goo00<07goo
Ool07Woo5@?P1Goo00<007oo00006Woo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomo
o`0OOol3O004Ool4O009Ool01000Oomoo`003Goo00<07gooOol077oo6@?P0Woo0`0000=oo`00Ool0
5goo00<07gooOol0K7oo00<007ooOol00Goo000?Ool2000ROol5O00>Ool01000Oomoo`003Goo00<0
7gooOol06Woo6P?P1@0000=oo`0000005goo00<07gooOol0JWoo0`000goo000?Ool00`00Oomoo`0S
Ool2O00@Ool00`00Ool0000=Ool00`0OOomoo`0HOolK0n001@000n0000?P00006Woo00<07gooOol0
KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0UOol3O00:Ool20002Ool2000>Ool00`0OOomoo`0F
OolK0n001`000n03h0000n0000?P01Uoo`0301moogoo06eoo`03001oogoo005oo`003goo00<007oo
Ool0:7oo0W`02Woo1@001Goo0P001Woo00<07gooOol05Goo7P?P00@000?P0n000083h1Moo`0301mo
ogoo06ioo`03001oogoo005oo`003goo00<007ooOol0:Woo0W`02goo0P001Woo00<007ooOol017oo
00<07gooOol04goo7`?P00D000?P0n03h00000<3h1Ioo`0301moogoo06ioo`03001oogoo005oo`00
3goo00<007ooOol0;7oo0W`04Goo00<007ooOol01Goo00<07gooOol04Woo7`?P00D000?P0n03h000
00D3h1=oo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Woo0g`03Goo00<007oo
00001goo00<07gooOol04Goo7@?P0P002`?P4Woo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool2
000bOol2O00;Ool01000Ool000001Woo00<07gooOol037oo10007@?P1`001`?P4Goo00<07gooOol0
KWoo0`000goo000?Ool00`00Oomoo`0cOol2O00DOol00`0OOomoo`0<Ool7000I0n0;00030n0AOol0
0`0OOomoo`1`Ool00`00Oomoo`01Ool000moo`03001oogoo03Eoo`9l019oo`0301moogoo00aoo`@0
01`3h0<000@3h0T000ioo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=goo0g`0
47oo00<07gooOol037oo00<000?P0n000P006P?P00<000?P0n0020?P2@002Woo00<07gooOol0LGoo
00<007ooOol00Goo000?Ool00`00Oomoo`0jOol2O00>Ool00`0OOomoo`0;Ool20n001@000n03h0?P
000060?P00<000?P0n003P?P2@0017oo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomo
o`0lOol2O00=Ool00`0OOomoo`0:Ool20n000`000n03h0020n02000F0n000`000n03h00?0n03Ool9
00000`0OOomoo`1bOol00`00Oomoo`01Ool000moo`03001oogoo03ioo`9l00aoo`0301moogoo00Uo
o`<3h0030003h0?P00<3h0030003h0?P0183h0030003h0?P0143h0Moo`P0075oo`03001oogoo005o
o`003goo00<007ooOol0@7oo0W`02goo00<07gooOol01goo2`?P0P004@?P00<000?P0n004P?P2Goo
00<07goo00002000K7oo00<007ooOol00Goo000?Ool20013Ool3O008Ool00`0OOomoo`07Ool=0n00
0`000n03h00>0n000`000n03h00B0n08Ool00`0OOomoo`04Ool9001VOol30003Ool000moo`03001o
ogoo04Eoo`9l00Moo`0301moogoo00Eoo`l3h08000d3h0030003h0?P01<3h0Qoo`0301moogoo00Uo
o`T006=oo`03001oogoo005oo`003goo00<007ooOol0Agoo0W`01Woo0P0O1Goo4@?P00<000?P0n00
2P?P00<000?P0n004`?P1Woo0P0O47oo2@00Ggoo00<007ooOol00Goo000?Ool00`00Oomoo`19Ool2
O006Ool00`0OOomoo`02OolB0n0200090n000`000n03h00E0n04Ool00`0OOomoo`0EOol8001KOol0
0`00Oomoo`01Ool000moo`03001oogoo04]oo`=l00Aoo`0301moogoo01D3h0030003h0?P00D3h003
0003h0?P01H3h0=oo`0301moogoo01Yoo`T005Ioo`03001oogoo005oo`003goo00<007ooOol0CWoo
0W`00goo00<07goo0n005@?P0P001@?P00<000?P0n005P?P0Woo00<07gooOol07goo2@00DWoo00<0
07ooOol00Goo0007Ool50003Ool00`00Oomoo`1@Ool2O002Ool00`0O0n03h00F0n001@000n03h0?P
00006@?P00=oo`0OOol09Woo2@00CGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomo
o`1BOol2O0000goo0n03h00G0n0200000`?P0000000H0n000`0OOomoo`0ZOol90019Ool00`00Oomo
o`01Ool000Uoo`03001oogoo00=oo`<005Aoo`03O003h0?P01T3h0<001P3h39oo`T0049oo`<000=o
o`002Goo00<007ooOol00goo00<007ooOol0EGoo6`?P00<000?P000060?P:Goo3G`O1P00@goo00<0
07ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1EOolL0n000`000n03h00G0n0VOolBO1l4
0002O1m1Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo05Eooa`3h0030003h0?P01L3h29o
oaMl7`8000Ml7ceoo`03001oogoo005oo`003goo00<007ooOol0EGoo=P?P87oo8g`O?7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`1FOold0n0POolVO1ljOol00`00Oomoo`01Ool000moo`03001oogoo
05Iooc@3h1ioobYl7cQoo`03001oogoo005oo`003goo0P00F7oo<`?P77oo;G`O=Goo0`000goo000?
Ool00`00Oomoo`1GOolc0n0KOol`O1leOol00`00Oomoo`01Ool000moo`03001oogoo05Mooc<3h1Uo
oc=l7cAoo`03001oogoo005oo`003goo00<007ooOol0F7oo<@?P6Woo=7`O<goo00<007ooOol00Goo
000?Ool00`00Oomoo`1HOola0n0IOolfO1lbOol00`00Oomoo`01Ool000moo`03001oogoo05Uooc03
h1QoocQl7c5oo`03001oogoo005oo`003goo00<007ooOol0FGoo;`?P67oo>W`O<7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`1IOol^0n0HOollO1l_Ool00`00Oomoo`01Ool000moo`8005]oob`3h1Qo
ocel7beoo`<000=oo`003goo00<007ooOol0Fgoo:`?P5goo?g`O;Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`1LOolY0n0HOoloO1l^Ool00`00Oomoo`01Ool000moo`03001oogoo05aoobP3h1Qood9l
7baoo`03001oogoo005oo`003goo00<007ooOol0GGoo9P?P6Goo@W`O;7oo00<007ooOol00Goo000?
Ool00`00Oomoo`1NOolT0n0IOom3O1l/Ool00`00Oomoo`01Ool000moo`03001oogoo05moob83h1Uo
odEl7b]oo`03001oogoo005oo`003goo00<007ooOol0H7oo7`?P6gooAW`O:Woo00<007ooOol00Goo
000?Ool2001TOolK0n0KOom7O1lXOol30003Ool000moo`03001oogoo06EooaL3h1eoodQl7bUoo`03
001oogoo005oo`003goo00<007ooOol0Igoo4`?P7gooB7`O:Goo00<007ooOol00Goo000?Ool00`00
Oomoo`1ZOol=0n0ROom8O1lYOol00`00Oomoo`01Ool000moo`03001oogoo06moo`<3h2IoodUl7bUo
o`03001oogoo005oo`003goo00<007ooOol0V7ooBW`O:7oo00<007ooOol00Goo000?Ool00`00Oomo
o`2HOom:O1lXOol00`00Oomoo`01Ool000moo`8009UoodYl7bIoo`<000=oo`003goo00<007ooOol0
UgooBg`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000mo
o`03001oogoo09Moodal7bMoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007oo
Ool00Goo000?Ool00`00Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000Qoo`<000Aoo`03001oogoo
09Ioodel7bMoo`03001oogoo005oo`0027oo00<007ooOol017oo00<007ooOol0UWooCG`O9goo00<0
07ooOol00Goo0009Ool00`00Oomoo`03Ool3002FOolWO1l3000SO1lUOol30003Ool000Uoo`03001o
ogoo00=oo`03001oogoo09IoobMl7`03001l7g`O00@001ml7bMoo`03001oogoo005oo`0027oo00<0
07oo000017oo00<007ooOol0UWoo9W`O00@007`OO1ml7`<00003O1l0000000<000]l7`03001l7g`O
00al7bMoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Ugoo9G`O00<007`OO1l0
0g`O00<007`OO1l017`O1@001g`O00<007`OO1l02g`O9goo00<007ooOol00Goo000?Ool00`00Oomo
o`2GOolUO1l00`00O1ml7`03O1l00`00O1ml7`09O1l40004O1l2000;O1lWOol00`00Oomoo`01Ool0
00moo`03001oogoo09MoobEl7`04001l7g`OO1l2000@O1l500000g`O001l7`09O1lWOol00`00Oomo
o`01Ool000moo`03001oogoo09MoobAl7`03001l7g`O009l7`<001Al7`<000Ul7bMoo`03001oogoo
005oo`003goo00<007ooOol0Ugoo97`O00<007`OO1l05g`O0`002g`O9goo00<007ooOol00Goo000?
Ool2002HOolTO1l00`00O1ml7`0EO1l20006O1l200000g`O001l7`02O1lVOol30003Ool000moo`03
001oogoo09Qoob=l7`03001l7g`O01ml7`03001l7g`O009l7bQoo`03001oogoo005oo`003goo00<0
07ooOol0V7oo8W`O00<007`OO1l07g`O00<007`O00000g`O:7oo00<007ooOol00Goo000?Ool00`00
Oomoo`2HOolRO1l00`00O1ml7`0TO1lYOol00`00Oomoo`01Ool000moo`03001oogoo09Uoob5l7`03
001l7g`O02Al7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo8G`O00<007`OO1l097`O:Goo
00<007ooOol00Goo000?Ool00`00Oomoo`2IOolPO1l00`00O1ml7`0UO1lYOol00`00Oomoo`01Ool0
00moo`8009Yoob1l7`03001l7g`O02Al7bQoo`<000=oo`003goo00<007ooOol0VWoo7g`O00<007`O
O1l097`O:Woo00<007ooOol00Goo000?Ool00`00Oomoo`2JOolOO1l00`00O1ml7`0SO1l[Ool00`00
Oomoo`01Ool000moo`03001oogoo09]ooael7`03001l7g`O02=l7baoo`03001oogoo005oo`003goo
00<007ooOol0W7oo77`O00<007`OO1l08g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolL
O1l00`00O1ml7`0RO1l]Ool00`00Oomoo`01Ool000moo`03001oogoo09eooa]l7`03001l7g`O029l
7beoo`03001oogoo005oo`003goo00<007ooOol0WGoo67`O00<007`O000097`O;Woo00<007ooOol0
0Goo000?Ool2002OOolGO1l00`00O1l00003O1l00`00O1ml7`0MO1l]Ool30003Ool000moo`03001o
ogoo09mooaIl7`03001l7`00009l7`03001l7g`O01il7bmoo`03001oogoo005oo`003goo00<007oo
Ool0X7oo5G`O00D007`O001l7`00021l7c1oo`03001oogoo005oo`003goo00<007ooOol0XGoo5G`O
00<007`O00008G`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ROolDO1l2000QO1laOol00`00
Oomoo`01Ool000moo`03001oogoo0:=ooa=l7`04001l7g`OO1l2000LO1lbOol00`00Oomoo`01Ool0
00moo`03001oogoo0:=ooaQl7`03001l7g`O01Ul7c=oo`03001oogoo005oo`003goo00<007ooOol0
YGoo5W`O00<007`OO1l05g`O=Goo00<007ooOol00Goo000?Ool2002WOolDO1l00`00O1l0000FO1le
Ool30003Ool000moo`03001oogoo0:Qooa9l7`04001l7`00000DO1lhOol00`00Oomoo`01Ool000mo
o`03001oogoo0:YoobIl7cYoo`03001oogoo005oo`003goo00<007ooOol0Zgoo8g`O?7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`2]OolPO1lmOol00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo
0:mooaal7`8003eoo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0/Woo5G`O1Woo
0`00>Woo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001`OonK0003Ool000Yoo`03001oogoo
009oo`03001oogoo08ioobH3o`030003o`?o01P3o`8000X3obmoo`03001oogoo005oo`0027oo00<0
07oo000017oo00<007ooOol0SWoo9P?o00@000?o0ol3o`<00183o`8000D3o`8000030ol000?o0083
obmoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0SWoo9P?o00L000?o0ol3o`00
0ol0000@0ol200090ol00`000ol3o`020ol_Ool00`00Oomoo`01Ool000moo`03001oogoo08ioobH3
o`040003o`?o0ol3000J0ol00`000ol000030ol_Ool00`00Oomoo`01Ool000moo`03001oogoo08io
obH3o`050003o`?o0ol0000R0ol_Ool00`00Oomoo`01Ool000moo`03001oogoo08ioobH3o`030003
o`?o0083o`800203obmoo`03001oogoo005oo`003goo00<007ooOol0SWoo9P?o00<000?o0ol090?o
;goo00<007ooOol00Goo000?Ool2002?OolV0ol00`000ol3o`0T0ol]Ool30003Ool000moo`03001o
ogoo08ioobH3o`030003o`?o02@3obmoo`03001oogoo005oo`003goo00<007ooOol0SWoo9P?o00<0
00?o0ol090?o;goo00<007ooOol00Goo000?Ool00`00Oomoo`2>OolV0ol00`000ol3o`0T0ol_Ool0
0`00Oomoo`01Ool000moo`03001oogoo08ioobH3o`030003o`?o02@3obmoo`03001oogoo005oo`00
3goo00<007ooOol0SWoo9P?o00<000?o0ol090?o;goo00<007ooOol00Goo000?Ool00`00Oomoo`2>
OolV0ol00`000ol3o`0T0ol_Ool00`00Oomoo`01Ool000moo`03001oogoo08ioobH3o`030003o`?o
02@3obmoo`03001oogoo005oo`003goo0P00Sgoo9P?o00<000?o0ol090?o;Goo0`000goo000?Ool0
0`00Oomoo`2dOol00`00Oomoo`1COol00`00Oomoo`01Ool000moo`03001oogoo0;Aoo`03001oogoo
05=oo`03001oogoo005oo`003goo00<007ooOol0]7oo00<007ooOol0Dgoo00<007ooOol00Goo000?
Ool00`00Oomoo`2dOol00`00Oomoo`1COol00`00Oomoo`01Ool000moo`03001oogoo0;Aoo`03001o
ogoo05=oo`03001oogoo005oo`003goo00<007ooOol0]7oo00<007ooOol0Dgoo00<007ooOol00Goo
000?Ool00`00Oomoo`2dOol00`00Oomoo`1COol00`00Oomoo`01Ool000moo`800;9oo`04001oogoo
0002Ool00`00Oomoo`1>Ool30003Ool000moo`03001oogoo0;9oo`05001oo`00Ool0001COol00`00
Oomoo`01Ool000moo`03001oogoo0;9oo`05001oo`00Ool0001COol00`00Oomoo`01Ool000moo`03
001oogoo0;=oo`<005Aoo`03001oogoo005oo`003goo00<007ooOol0/goo0`00E7oo00<007ooOol0
0Goo000?Ool00`00Oomoo`2dOol01000Oomoogoo0P00D7oo00<007ooOol00Goo000?Ool00`00Oomo
o`2iOol00`00Oomoo`1>Ool00`00Oomoo`01Ool000moo`800;Yoo`03001oogoo04aoo`<000=oo`00
3goo00<007ooOol0^7oo00<007oo0000Cgoo00<007ooOol00Goo000?Ool00`00Oomoo`2hOol01000
Ool00000CWoo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009
Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo
0?moo`]oo`03001oogoo005oo`0027oo10000goo0`00ogoo2Goo0`000goo0008Ool00`00Ool00004
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`8000Aoo`03001oogoo0?moo`]oo`03001o
ogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool00`00
Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000l000=oo`0027oo0P00ogoo5goo
0008Ool00`00Oomoo`3oOolFOol000Qoo`<00?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.25 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .39286 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 .28571 m
.14286 .28571 L
.14286 .39286 L
s
.22857 .275 m
.25 .28571 L
.22857 .29643 L
s
.13214 .37143 m
.14286 .39286 L
.15357 .37143 L
s
gsave
.25 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .39286 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 .28571 m
.14286 .28571 L
.14286 .39286 L
s
.22857 .275 m
.25 .28571 L
.22857 .29643 L
s
.13214 .37143 m
.14286 .39286 L
.15357 .37143 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.83384 .71429 m
.83384 .77143 L
.54812 .77143 L
.54812 .71429 L
F
0 g
.01 w
.45956 .36422 m
.73749 .43047 L
s
.02 w
.45956 .36422 Mdot
.73749 .43047 Mdot
gsave
.33204 .38208 -64.4013 -6.20137 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.47506 .33204 -64.4013 -6.20137 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -64.4013 -6.20137 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.33204 .38208 m
.42857 .42857 L
.47506 .33204 L
s
.3467 .40103 m
.33204 .38208 L
.35599 .38173 L
s
.47541 .35599 m
.47506 .33204 L
.45611 .3467 L
s
gsave
.79812 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.69098 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.69098 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.79812 .71429 m
.69098 .71429 L
.69098 .82143 L
s
.77669 .70357 m
.79812 .71429 L
.77669 .725 L
s
.68026 .8 m
.69098 .82143 L
.70169 .8 L
s
gsave
.82001 .58883 -60.5271 -3.96577 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.69688 .67715 -60.5271 -3.96577 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -60.5271 -3.96577 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82001 .58883 m
.71429 .57143 L
.69688 .67715 L
s
.8006 .57478 m
.82001 .58883 L
.79712 .59592 L
s
.68979 .65426 m
.69688 .67715 L
.71094 .65774 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool003Eoo`03001oogoo025oo`D0029oo`<002Aoo`8002Eoo`<002Aoo`03001oogoo029oo`8000Ao
o`00=7oo00<007oo000097oo00<007ooOol08Woo00<007ooOol09Woo00<007ooOol08goo00<007oo
Ool08Woo00<007oo00008goo00<007oo00000goo000dOol00`00Ool0000TOol00`00Oomoo`0SOol0
0`00Oomoo`0TOol00`00Oomoo`0ROol4000UOol00`00Oomoo`0QOol00`00Ool00003Ool003Aoo`03
001oo`0002Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo025oo`03001oo`0002Aoo`80
02Aoo`8000Aoo`00=7oo00<007oo000097oo00<007ooOol08Woo00<007oo000097oo00<007oo0000
97oo0P0097oo00<007ooOol08goo00<007ooOol00goo000eOol00`00Oomoo`0ROol2000UOol00`00
Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0ROol3000TOol20003Ool00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol000moool000l000=oo`003goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`8006eoo`T07i=oo`<000=oo`003goo00<007ooOol0
IWoo1P0O2Goo1P0OSgoo00<007ooOol00Goo000?Ool00`00Oomoo`1SOol301lEOol301n<Ool00`00
Oomoo`01Ool000moo`03001oogoo05moo`@07a]oo`@07hQoo`03001oogoo005oo`003goo00<007oo
Ool0GGoo0P0O8goo0P0OQWoo00<007ooOol00Goo000?Ool00`00Oomoo`1KOol201lWOol201n4Ool0
0`00Oomoo`01Ool000Moo`D000=oo`03001oogoo05Uoo`807b]oo`807h9oo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EWoo0W`000<07gooOol0;Goo00<07gooOol0Ogoo00<007oo
Ool00Goo0003Ool30003Ool00`00Oomoo`03Ool3001DOol2O0000goo01moo`0`Ool00`0OOomoo`1l
Ool30003Ool000Uoo`03001oogoo00=oo`03001oogoo059oo`9l0003Ool07`0O03=oo`807gioo`03
001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Cgoo0g`000=oo`0O01l0=goo0P0OO7oo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`1=Ool2O003Ool00`0OOomoo`0hOol00`0OOomo
o`1jOol00`00Oomoo`01Ool000moo`03001oogoo04]oo`9l00Eoo`0301moogoo03Uoo`0301moogoo
07Uoo`03001oogoo005oo`003goo00<007ooOol0B7oo0g`01Goo0P0O?Goo0P0ONGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`16Ool2O007Ool00`0OOomoo`0oOol00`0OOomoo`1fOol00`00Oomoo`01
Ool000moo`03001oogoo04Aoo`9l00Qoo`0301moogoo045oo`0301moogoo07Eoo`03001oogoo005o
o`003goo0P00@Woo0g`02Goo00<07gooOol0@Woo00<07gooOol0Lgoo0`000goo000?Ool00`00Oomo
o`0oOol2O00<Ool00`0OOomoo`13Ool00`0OOomoo`1dOol00`00Oomoo`01Ool000moo`03001oogoo
03eoo`9l00eoo`0301moogoo04Eoo`0301moogoo07=oo`03001oogoo005oo`003goo00<007ooOol0
>goo0W`03Woo00<07gooOol0Agoo00<07gooOol0LWoo00<007ooOol00Goo000?Ool00`00Oomoo`0h
Ool3O00?Ool00`0OOomoo`19Ool00`0OOomoo`1aOol00`00Oomoo`01Ool000moo`03001oogoo03Io
o`9l015oo`0301moogoo04Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0=7oo
0W`04goo00<07gooOol0Bgoo00<07gooOol0L7oo00<007ooOol00Goo000?Ool2000bOol3O00DOol0
0`0OOomoo`1<Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo02moo`9l01Moo`0301moogoo
04eoo`0301moogoo06moo`03001oogoo005oo`003goo00<007ooOol0;Goo0W`067oo00<07gooOol0
CWoo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol3O00JOol00`0OOomoo`1?
Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02Qoo`9l01aoo`0301moogoo051o
o`0301moogoo06ioo`03001oogoo005oo`003goo00<007ooOol09Woo0W`07Woo00<07gooOol0DGoo
00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol3O00POol00`0OOomoo`1AOol0
0`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo025oo`9l029oo`0301moogoo05=oo`03
01moogoo06aoo`03001oogoo005oo`003goo0P0087oo1g`07goo00<07gooOol0Dgoo00<07gooOol0
JWoo0`000goo000?Ool00`00Oomoo`0MOol3O006Ool3O00KOol00`0OOomoo`1DOol00`0OOomoo`1/
Ool00`00Oomoo`01Ool000moo`03001oogoo01aoo`9l00]oo`=l01Qoo`0301moogoo05Eoo`0301mo
ogoo06]oo`03001oogoo005oo`003goo00<007ooOol06Woo0W`047oo0W`05Goo00<07gooOol0EWoo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0IOol00g`0Oomoo`0BOol00g`0Oomo
o`0BOol00`0OOomoo`1GOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03
O01oogoo01Aoo`03O01oogoo015oo`0301moogoo02Aoo`/07bQoo`0301moogoo06Yoo`03001oogoo
005oo`003goo00<007ooOol05goo00=l07ooOol05Woo00=l07ooOol047oo00<07gooOol08goo3P0O
9Woo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0FOol00g`0Oomoo`0GOol00g`0
Oomoo`0?Ool00`0OOomoo`0SOol@01lUOol00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`8001Mo
o`03O01oogoo01Qoo`03O01oogoo00ioo`0301moogoo029ooa807bEoo`0301moogoo06Moo`<000=o
o`003goo00<007ooOol05Goo00=l07ooOol06Goo00=l07ooOol03Woo00<07gooOol08Woo4`0O97oo
00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomo
o`0=Ool00`0OOomoo`0QOolD01lTOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Aoo`03O01oogoo01]oo`03O01oogoo00eoo`0301moogoo025ooaD07b=oo`0301moogoo06Uoo`03
001oogoo005oo`003goo00<007ooOol057oo00=l07ooOol06goo00=l07ooOol01Goo00<007ooOol0
1Goo00<07gooOol08Goo5@0O8goo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03
Ool00`00Oomoo`0DOol00g`0Oomoo`0LOol00g`0Oomoo`05Ool20005Ool00`0OOomoo`0POolF01lS
Ool00`0OOomoo`1YOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01o
ogoo01aoo`03O01oogoo00Moo`8000=oo`0301moogoo021ooaH07b=oo`0301moogoo06Uoo`03001o
ogoo005oo`0027oo00<007oo000017oo0`0057oo00=l07ooOol037ooCP002P0O8goo00<07gooOol0
Igoo0`000goo0008Ool00`00Ool00004Ool00`00Oomoo`0DOol00g`0Oomoo`0<Ool00`00Oomoo`0=
Ool00g`0Oomoo`08Ool20002Ool00`0OOomoo`0POol;01l00`0001l07`0901lROol00`0OOomoo`1Y
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo01Aoo`03O01oogoo00aoo`04001o
ogooOol30009Ool00g`0Oomoo`06Ool20004Ool01@0O000007oo00007Woo2`0O00<0000O01l02@0O
8Woo00<07gooOol0JGoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00g`0
Oomoo`0<Ool01000Oomoogoo0P002Goo00=l07ooOol01Goo0P001Woo00@07gooOol001moo`/07`03
00007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol057oo00=l07oo
Ool037oo00<007ooOol00goo00<007ooOol01Woo00=l07ooOol03Goo00D07goo001oo`0001ioo`/0
7`0300007`0O00P07b=oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007ooOol05Goo00=l
07ooOol02goo00<007ooOol00goo00<007ooOol01Goo00=l07ooOol03Woo00<07gooOol08Goo2P0O
00<0000O01l0200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0
Oomoo`0;Ool01000Oomoogoo0`001goo00=l07ooOol03Woo00<07gooOol08Goo2P0O00<0000O01l0
200O8goo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0;Ool0
0`00Oomoo`0;Ool00g`0Oomoo`0>Ool00`0OOomoo`0ROol901l00`0001l07`0701lTOol00`0OOomo
o`1YOol00`00Oomoo`01Ool000moo`8001Moo`03O01oogoo00Yoo`03001oogoo00Yoo`03O01oogoo
00moo`0301moogoo02=oo`P07`0300007`0O00H07bAoo`0301moogoo06Qoo`<000=oo`003goo00<0
07ooOol05goo00=l07ooOol02Goo00<007ooOol02Woo00=l07ooOol047oo00<07gooOol08goo1`0O
00<0000O01l01@0O9Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0
Oomoo`09Ool00`00Oomoo`09Ool00g`0Oomoo`0AOol00`0OOomoo`0SOol701l00`0001l07`0301lW
Ool00`0OOomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Qoo`03O01oogoo00Qoo`03001o
ogoo00Qoo`03O01oogoo019oo`0301moogoo02Eoo`D07`0400007`0O01l8Ool2000OOol00`0OOomo
o`1ZOol00`00Oomoo`01Ool000moo`03001oogoo01Uoo`03O01oogoo00Moo`03001oogoo00Moo`03
O01oogoo01=oo`0301moogoo02Moo`<07`0300007goo00Yoo`03001oogoo01eoo`0301moogoo06Yo
o`03001oogoo005oo`003goo00<007ooOol06Woo0W`01goo00<007ooOol01Woo00=l07ooOol057oo
00<07gooOol097oo3@?P1Goo0P007Woo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomo
o`0LOol3O004Ool00`00Oomoo`04Ool2O00HOol00`0OOomoo`0NOolE0n001Goo000007oo00007Goo
00<07gooOol0Jgoo00<007ooOol00Goo000?Ool00`00Oomoo`0OOol3O00017oo001oogoo17`06Woo
00<07gooOol077oo5P?P100000=oo`0000006goo00<07gooOol0K7oo00<007ooOol00Goo000?Ool2
000ROol2O0000`00O01l000OOol00`0OOomoo`0JOolF0n000`000n03h00200020n0LOol00`0OOomo
o`1ZOol30003Ool000moo`03001oogoo02=oo`03001l07oo01moo`0301moogoo01QooaL3h0040003
h0?P00020n000`000n03h00JOol00`0OOomoo`1]Ool00`00Oomoo`01Ool000moo`03001oogoo02=o
o`03001oog`0009l01ioo`0301moogoo01Iooa/3h0040003h0?P00030n0IOol00`0OOomoo`1]Ool0
0`00Oomoo`01Ool000moo`03001oogoo02=oo`03001oogoo009oo`9l01aoo`0301moogoo01Eooa/3
h0050003h0?P0n0000040n0GOol00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo02=o
o`03001oogoo00Aoo`9l01Yoo`0301moogoo01=ooa/3h0<000T3h1Ioo`0301moogoo06ioo`03001o
ogoo005oo`003goo00<007ooOol08goo00<007ooOol01Woo0W`06Goo00<07gooOol04Woo6`?P1P00
20?P4goo00<07gooOol0Kgoo00<007ooOol00Goo000?Ool00`00Oomoo`0SOol00`00Oomoo`08Ool3
O00GOol00`0OOomoo`0AOolJ0n0;00050n0BOol00`0OOomoo`1_Ool00`00Oomoo`01Ool000moo`80
025oo`04001oogoo0002Ool00`00Oomoo`08Ool2O00EOol00`0OOomoo`0@OolK0n0400030n080000
0`?POomoo`0?Ool00`0OOomoo`1^Ool30003Ool000moo`03001oogoo021oo`06001oogoo001oo`00
3Goo0W`057oo00<07gooOol03Woo7@?P0P0020?P20003Woo00<07gooOol0L7oo00<007ooOol00Goo
000?Ool00`00Oomoo`0QOol01@00Ool007oo00003goo0W`04Woo00<07gooOol03Goo7@?P00<000?P
0n0030?P20002Goo00<07gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0QOol01000Ool0
00004Woo0g`047oo00<07gooOol027oo20006@?P00<000?P0n003`?P00=oo`0000001`0017oo00<0
7gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0ROol3000EOol2O00>Ool00`0OOomoo`0:
Ool2000M0n000`000n03h00@0n04Ool9001dOol00`00Oomoo`01Ool000moo`03001oogoo029oo`80
01Qoo`9l00eoo`0301moogoo00Qoo`03001oo`00008001X3h0030003h0?P0143h0Uoo`P0071oo`03
001oogoo005oo`003goo00<007ooOol08goo00@007ooOomoo`8001Eoo`9l00aoo`0301moogoo00Uo
o`030003h0?P008001P3h0030003h0?P0183h0Yoo`0301moo`0000L006aoo`03001oogoo005oo`00
3goo00<007ooOol0:7oo00<007ooOol05Goo0W`02goo00<07gooOol01goo0P?P00@000?P0n03h080
01D3h0030003h0?P01<3h0Uoo`0301moogoo00Aoo`P006Qoo`03001oogoo005oo`003goo0P00:Goo
00<007ooOol05goo0g`027oo00<07gooOol01goo0`?P00<000?P0n000P?P0P004`?P00<000?P0n00
4`?P27oo00<07gooOol02Goo2000HWoo0`000goo000?Ool00`00Oomoo`0WOol00`00Ool0000KOol2
O007Ool00`0OOomoo`05Ool;0n02000@0n000`000n03h00D0n08Ool00`0OOomoo`0=Ool8001POol0
0`00Oomoo`01Ool000moo`03001oogoo02Moo`04001oo`00000LOol2O006Ool201l5Ool=0n02000>
0n000`000n03h00D0n06Ool201lDOol9001KOol00`00Oomoo`01Ool000moo`03001oogoo04Uoo`9l
00Ioo`0301moogoo009oo`l3h08000/3h0030003h0?P01H3h0Aoo`0301moogoo01Qoo`T005Moo`03
001oogoo005oo`003goo00<007ooOol0Bgoo0g`017oo00<07gooOol04P?P0P002@?P00<000?P0n00
5P?P0goo00<07gooOol07Woo2000Dgoo00<007ooOol00Goo000?Ool00`00Oomoo`1>Ool2O003Ool0
0`0OOol3h00C0n0200060n000`000n03h00G0n02Ool00`0OOomoo`0SOol8001?Ool00`00Oomoo`01
Ool000Moo`D000=oo`03001oogoo051oo`9l009oo`0301l3h0?P01@3h08000@3h0030003h0?P01L3
h003Ool07goo02Uoo`P004]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0DWoo
0W`000=oo`?P0n005P?P0P0000<3h0000n006@?P00<07gooOol0;Goo2@00AWoo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool3001DOol00g`00n03h00H0n04000H0n0dOol60013Ool30003Ool000Uo
o`03001oogoo00=oo`03001oogoo05Eooa/3h0<001P3h2Uoo`el7`@004Eoo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0EGoo6`?P00<000?P000060?P9Woo4G`O0P001G`O@Goo00<0
07ooOol00Goo0008Ool20005Ool00`00Oomoo`1EOolL0n000`000n03h00G0n0ROolPO1lmOol00`00
Oomoo`01Ool000moo`03001oogoo05Eooa`3h0030003h0?P01L3h21oob=l7caoo`03001oogoo005o
o`003goo00<007ooOol0EWoo=0?P87oo9W`O>Woo00<007ooOol00Goo000?Ool00`00Oomoo`1FOold
0n0NOolZO1lhOol00`00Oomoo`01Ool000moo`8005Qooc<3h1aoobel7cEoo`<000=oo`003goo00<0
07ooOol0Egoo<`?P6goo<7`O=Goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolc0n0IOolcO1ld
Ool00`00Oomoo`01Ool000moo`03001oogoo05Qooc43h1YoocAl7c=oo`03001oogoo005oo`003goo
00<007ooOol0F7oo<@?P6Goo=W`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`1IOol`0n0HOolh
O1laOol00`00Oomoo`01Ool000moo`03001oogoo05Uoobl3h1QoocYl7c1oo`03001oogoo005oo`00
3goo00<007ooOol0FGoo;P?P67oo?7`O;goo00<007ooOol00Goo000?Ool2001KOol/0n0HOolmO1l]
Ool30003Ool000moo`03001oogoo05]oob/3h1Moocml7bioo`03001oogoo005oo`003goo00<007oo
Ool0G7oo:@?P67oo?g`O;Woo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolX0n0HOom2O1l/Ool0
0`00Oomoo`01Ool000moo`03001oogoo05eoobH3h1Uood9l7baoo`03001oogoo005oo`003goo00<0
07ooOol0GWoo90?P6Goo@g`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1OOolR0n0IOom5O1l[
Ool00`00Oomoo`01Ool000moo`03001oogoo061ooal3h1]oodIl7bYoo`03001oogoo005oo`003goo
0P00I7oo6`?P6gooAg`O:7oo0`000goo000?Ool00`00Oomoo`1UOolG0n0MOom8O1lYOol00`00Oomo
o`01Ool000moo`03001oogoo06Mooa<3h1moodQl7bUoo`03001oogoo005oo`003goo00<007ooOol0
JWoo3@?P8WooB7`O:Goo00<007ooOol00Goo000?Ool00`00Oomoo`1_Ool30n0VOom9O1lYOol00`00
Oomoo`01Ool000moo`03001oogoo09QoodYl7bQoo`03001oogoo005oo`003goo00<007ooOol0V7oo
BW`O:7oo00<007ooOol00Goo000?Ool2002IOom:O1lVOol30003Ool000moo`03001oogoo09Mood]l
7bQoo`03001oogoo005oo`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo000?Ool00`00
Oomoo`2GOom<O1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Moodal7bMoo`03001oogoo005o
o`003goo00<007ooOol0UgooC7`O9goo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`2FOom=
O1lWOol00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo09Ioodel7bMoo`03001oogoo
005oo`002Goo00<007ooOol00goo0`00UWoo9g`O0`008g`O9Goo0`000goo0009Ool00`00Oomoo`03
Ool00`00Oomoo`2FOolWO1l00`00O1ml7`06000>O1l00`00O1ml7`0<O1lWOol00`00Oomoo`01Ool0
00Qoo`03001oo`0000Aoo`03001oogoo09IoobMl7`03001l7g`O00<000=l7`D000Yl7`03001l7g`O
00]l7bMoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Ugoo9G`O00<007`OO1l0
0g`O00<007`OO1l01W`O1P001G`O0P002g`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2GOolU
O1l00`00O1ml7`03O1l00`00O1ml7`0<O1l600000g`O001l7`09O1lWOol00`00Oomoo`01Ool000mo
o`03001oogoo09MoobEl7`04001l7g`OO1l2000EO1l30009O1lWOol00`00Oomoo`01Ool000moo`03
001oogoo09MoobEl7`04001l7g`OO1l3000BO1l3000;O1lWOol00`00Oomoo`01Ool000moo`03001o
ogoo09MoobEl7`03001l7g`O01Al7`8000Ml7`800003O1l007`O009l7bMoo`03001oogoo005oo`00
3goo0P00V7oo9G`O00<007`OO1l07g`O00@007`OO1ml7bIoo`<000=oo`003goo00<007ooOol0V7oo
8g`O00<007`OO1l07g`O00<007`O00000W`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2HOolS
O1l00`00O1ml7`0TO1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Qoob=l7`03001l7g`O02=l
7bUoo`03001oogoo005oo`003goo00<007ooOol0VGoo8W`O00<007`OO1l08g`O:Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2IOolRO1l00`00O1ml7`0SO1lYOol00`00Oomoo`01Ool000moo`03001o
ogoo09Uoob9l7`03001l7g`O02=l7bUoo`03001oogoo005oo`003goo0P00VWoo8G`O00<007`OO1l0
8g`O:7oo0`000goo000?Ool00`00Oomoo`2JOolPO1l00`00O1ml7`0SO1lZOol00`00Oomoo`01Ool0
00moo`03001oogoo09Yoob1l7`03001l7g`O029l7b]oo`03001oogoo005oo`003goo00<007ooOol0
Vgoo7g`O00<007`OO1l08G`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2LOolNO1l00`00O1ml
7`0QO1l/Ool00`00Oomoo`01Ool000moo`03001oogoo09aooail7`03001l7g`O021l7beoo`03001o
ogoo005oo`003goo00<007ooOol0WGoo77`O00<007`OO1l08G`O;Goo00<007ooOol00Goo000?Ool0
0`00Oomoo`2MOolIO1l01000O1ml7`008W`O;Woo00<007ooOol00Goo000?Ool2002OOolHO1l01000
O1ml7`000W`O00<007`OO1l077`O;Goo0`000goo000?Ool00`00Oomoo`2OOolHO1l01@00O1l007`O
00007g`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2POolGO1l01@00O1l007`O00007W`O<7oo
00<007ooOol00Goo000?Ool00`00Oomoo`2QOolFO1l01000O1l000007g`O<7oo00<007ooOol00Goo
000?Ool00`00Oomoo`2ROolEO1l3000OO1laOol00`00Oomoo`01Ool000moo`03001oogoo0:=ooaEl
7`8001il7c9oo`03001oogoo005oo`003goo00<007ooOol0Xgoo5G`O00@007`OO1ml7`8001Ul7c=o
o`03001oogoo005oo`003goo00<007ooOol0YGoo67`O00<007`OO1l05G`O=Goo00<007ooOol00Goo
000?Ool2002WOolGO1l00`00O1ml7`0CO1leOol30003Ool000moo`03001oogoo0:QooaAl7`03001l
7`0001=l7cQoo`03001oogoo005oo`003goo00<007ooOol0ZWoo4W`O00@007`O0000011l7cYoo`03
001oogoo005oo`003goo00<007ooOol0Zgoo8g`O?7oo00<007ooOol00Goo000?Ool00`00Oomoo`2]
OolPO1lmOol00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0:mooaal7`=oo`8003Yoo`03001o
ogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0/Woo5G`O2Goo0P00>7oo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool3001`Oom40002O1mE0003Ool000Yoo`03001oogoo009oo`03001oogoo
091oobH3o`030003o`?o01P3o`8000X3obeoo`03001oogoo005oo`0027oo00<007oo000017oo00<0
07ooOol0T7oo9P?o00@000?o0ol3o`<00183o`8000D3o`8000030ol000?o0083obeoo`03001oogoo
005oo`002Goo00<007ooOol00goo00<007ooOol0T7oo9P?o00L000?o0ol3o`000ol0000A0ol00`00
0ol3o`070ol00`000ol3o`020ol]Ool00`00Oomoo`01Ool000moo`03001oogoo091oobH3o`040003
o`?o0ol3000J0ol00`000ol000030ol]Ool00`00Oomoo`01Ool000moo`03001oogoo091oobH3o`05
0003o`?o0ol0000R0ol]Ool00`00Oomoo`01Ool000moo`03001oogoo091oobH3o`030003o`?o0083
o`800203obeoo`03001oogoo005oo`003goo00<007ooOol0T7oo9P?o00<000?o0ol090?o;Goo00<0
07ooOol00Goo000?Ool2002AOolV0ol00`000ol3o`0T0ol[Ool30003Ool000moo`03001oogoo091o
obH3o`030003o`?o02@3obeoo`03001oogoo005oo`003goo00<007ooOol0T7oo9P?o00<000?o0ol0
90?o;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2@OolV0ol00`000ol3o`0T0ol]Ool00`00Oomo
o`01Ool000moo`03001oogoo091oobH3o`030003o`?o02@3obeoo`03001oogoo005oo`003goo00<0
07ooOol0T7oo9P?o00<000?o0ol090?o;Goo00<007ooOol00Goo000?Ool00`00Oomoo`2@OolV0ol0
0`000ol3o`0T0ol]Ool00`00Oomoo`01Ool000moo`03001oogoo091oobH3o`030003o`?o02@3obeo
o`03001oogoo005oo`003goo0P00TGoo9P?o00<000?o0ol090?o:goo0`000goo000?Ool00`00Oomo
o`2fOol00`00Oomoo`1AOol00`00Oomoo`01Ool000moo`03001oogoo0;Ioo`03001oogoo055oo`03
001oogoo005oo`003goo00<007ooOol0]Woo00<007ooOol0DGoo00<007ooOol00Goo000?Ool00`00
Oomoo`2fOol00`00Oomoo`1AOol00`00Oomoo`01Ool000moo`03001oogoo0;Ioo`03001oogoo055o
o`03001oogoo005oo`003goo00<007ooOol0]Woo00<007ooOol0DGoo00<007ooOol00Goo000?Ool0
0`00Oomoo`2fOol00`00Oomoo`1AOol00`00Oomoo`01Ool000moo`800;Eoo`03001oo`00009oo`03
001oogoo04aoo`<000=oo`003goo00<007ooOol0]7oo00D007oo001oo`00055oo`03001oogoo005o
o`003goo00<007ooOol0]Goo0P0000=oo`00Ool0D7oo00<007ooOol00Goo000?Ool00`00Oomoo`2e
Ool3001BOol00`00Oomoo`01Ool000moo`03001oogoo0;Ioo`80059oo`03001oogoo005oo`003goo
00<007ooOol0]Woo00@007ooOomoo`8004ioo`03001oogoo005oo`003goo00<007ooOol0^goo00<0
07ooOol0C7oo00<007ooOol00Goo000?Ool2002lOol00`00Oomoo`1:Ool30003Ool000moo`03001o
ogoo0;Yoo`03001oo`0004eoo`03001oogoo005oo`003goo00<007ooOol0^Woo00@007oo000004ao
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo0`000goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`@000=oo`<00?moo`Uoo`<000=oo`0027oo00<007oo000017oo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0009Ool20004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00Yoo`03001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo
00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool0
00Uoo`03001oogoo00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo00<007oo000017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol00Goo000:Ool00`00Oomoo`02Oooo000?0003Ool000Qoo`800?mooaMoo`0027oo00<0
07ooOol0ogoo5Woo0008Ool3003oOolFOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-1.40022, -2.34159, 0.0260573, 
  0.0260573}}]
}, Closed]],

Cell["Gear and Chain Animation", "Subsubtitle",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference", "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Context",
    FontWeight->"Bold"],
  "\nMech`Mech2D`\n",
  StyleBox["Package Version",
    FontWeight->"Bold"],
  "\n1.3\n",
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" Version",
    FontWeight->"Bold"],
  "\n2.2/3.0\n",
  StyleBox["Copyright",
    FontWeight->"Bold"],
  "\nCopyright 1996, Dynamic Modeling"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Discussion"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Gear-Pump Function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This sample notebook analyzes the motion of a reciprocating gear driven \
pump mechanism using the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " kinematics package. This mechanism is used to demonstrate the use of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s 2D gear constraints. Three of these constraints, ",
  StyleBox["TwoGears2", "Input"],
  ", ",
  StyleBox["RackAndPinion2", "Input"],
  ", and ",
  StyleBox["TwoPulleys2", "Input"],
  " are demonstrated in this single mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Gear-Pump Model"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The gear-pump mechanism consists of six bodies:\n   1\tground body,\t\t\t\t\
(Black)\n   2\tdrive sprocket,\t\t\t(",
  StyleBox["Red",
    FontColor->RGBColor[1, 0, 0]],
  ")\n   3\tdriven sprocket (drive gear)\t\t(",
  StyleBox["Blue",
    FontColor->RGBColor[0, 0, 1]],
  ")\n   4\tdriven gear,\t\t\t\t(",
  StyleBox["Green",
    FontColor->RGBColor[0, 1, 0]],
  ")\n   5\tdrive pinion,\t\t\t\t(",
  StyleBox["Magenta",
    FontColor->RGBColor[1, 0, 1]],
  ")\n   6\tdriven rack,\t\t\t\t(",
  StyleBox["Cyan",
    FontColor->RGBColor[0, 1, 1]],
  ")\nGear-pump function in a nutshell:\n   The drive sprocket is driven by a \
motor.\n   The drive sprocket drives the driven sprocket via a chain.\n   The \
driven sprocket is solidly attached to the drive gear (hence they are one \
body).\n   The drive gear drives the driven gear.\n   The driven gear is \
linked by a connecting rod to the reciprocating drive pinion.\n   The pinion \
drives the rack."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Kinematic Model "], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Preparation "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D", "Input"],
  " package is loaded into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " with the ",
  StyleBox["Needs", "Input"],
  " command."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The following symbols are used to reference each of the bodies in the \
gear-pump model throughout the analysis. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(drivesprocket = 2; \)\), 
    \(\(drivensprocket = 3; \)\), 
    \(\(drivengear = 4; \)\), 
    \(\(pinion = 5; \)\), 
    \(\(rack = 6; \)\), 
    \(On[General::"\<spell1\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Body Definitions "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["The Ground"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Five points are defined on body 1, the ground body:\n    P1.  The rotational \
axis of the drive sprocket.\n    P2.  The rotational axis of the driven \
sprocket.\n    P3.  The rotational axis of the driven gear.\n    P4.  The \
rotational axis of the pinion.\n    P5.  A point that is used to define the \
translation line of the rack."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bd[ground] = 
      Body[ground, 
        PointList 
          \[Rule] {\n\t\t\t\t (*P1*) \ {0, 0}, \n\t\t\t\t (*P2*) \ {2, 0}, \n
            \t\t\t\t (*P3*) \ {2, 1}, \n\t\t\t\t (*P4*) \ {4, 2}, \n\t\t\t\t
             (*P5*) \ {5, 3}}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The Drive Sprocket and Driven Sprocket"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"No points are defined on bodies 2 or 3, the drive and driven sprockets. \
Because these bodies are simply sprockets, their only defining features are \
their axes at local point 0 which need not be defined, and their radii which \
are specified in the constraint objects, not the body objects."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The Driven Gear and the Pinion "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two points are defined on each of bodies 4 and 5, the driven gear and the \
pinion:\n    P1.  The rotational axis of each body (at the local origin).\n   \
 P2.  The points of attachment of the connecting rod on each body."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bd[drivengear] = 
      Body[drivengear, 
        PointList 
          \[Rule] {\n\t\t\t\t (*P1*) \ {0, 0}, \n\t\t\t\t
             (*P2*) \ {0, 0.5}}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[BoxData[
    \(\(bd[pinion] = 
      Body[pinion, 
        PointList 
          \[Rule] {\n\t\t\t\t (*P1*) \ {0, 0}, \n\t\t\t\t
             (*P2*) \ {0, \(-1.0\)}}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["The Rack"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two points are defined on body 6, the rack:\n    P1.  One end of the \
translation line of the rack (at the local origin).\n    P2.  The other end \
of the horizontal translation line of the rack."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bd[rack] = 
      Body[rack, 
        PointList 
          \[Rule] {\n\t\t\t\t (*P1*) \ {0, 0}, \n\t\t\t\t (*P2*) \ {1, 0}}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["SetBodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The data contained in each of the body objects is incorporated into the \
current model with the SetBodies command. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[drivengear], bd[pinion], bd[rack]]\)], "Input",\

  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraint Definitions "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Ten constraints, including one driving constraint, are used to model the \
gear-pump mechanism. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Drive Sprocket Constraints "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"    1.  A rotational driver for the drive sprocket that causes it to rotate \
as time T advances.\n    2.  A revolute joint to force the axis of the drive \
sprocket to be coincident with its specified location on the ground."], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cs[1] = RotationLock1[1, drivesprocket, 2\ \[Pi]\ T]; \)\), 
    \(cs[2] = 
      Revolute2[2, \n\t\tPoint[drivesprocket, 0], Point[ground, 1]]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["Revolute2", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Driven Sprocket Constraints "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"    3.  A constraint to enforce the relationship between the drive and \
driven sprockets.\n    4.  A one degree of freedom constraint that prevents \
the driven sprocket from orbiting the drive sprocket."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TwoPulleys2\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \("TwoPulleys2[cnum, point1, rad1, point2, rad2, dist, C] models a chain \
and sprocket or belt set.  The axes of the two sprockets point1 & point2 are \
constrained to be dist units apart, and the rotational positions of the \
sprockets are related as per their respective radii.  The constant C sets the \
initial rotational position of the pulleys.  Constrains 2 DOF."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["TwoPulleys2", "Input"],
  " controls two of the three degrees of freedom of the driven sprocket; the \
distance between the two sprockets is held constant, and the rotational \
position of one sprocket is controlled relative to the other. The remaining \
degree of freedom allows the second sprocket to swing in an orbit around the \
first.\n\nIn this case, a valid position for the two sprockets is to place \
both sprocket's axes on the global X axis, and point both local x axes along \
the global X axis, also. This leads to an initial condition constant of C = \
0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[3] = 
      TwoPulleys2[3, Point[drivesprocket, 0], 0.4, Point[drivensprocket, 0], 
        1.2, 2.0, 0]; \)\), 
    \(\(cs[4] = RelativeY1[4, Point[drivensprocket, 0], 0]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Driven Gear Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"    5.  A gear constraint to enforce the relationship between the drive and \
driven gears.\n    6.  A one degree of freedom constraint that stops the \
driven gear from orbiting the drive gear."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?TwoGears2\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \("TwoGears2[cnum, point1, rad1, point2, rad2, C] models a gear set.  The \
axes of the two gears point1 & point2 are constrained to be rad1+rad2 units \
apart, and the rotational positions of the gears are related as per their \
respective radii.  The constant C sets the initial rotational positions of \
the gears.  Constrains 2 DOF."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "Like ",
  StyleBox["TwoPulleys2", "Input"],
  ", this constraint controls only two of the three degrees of freedom of the \
driven gear. The remaining orbital degree of freedom is controlled with \
another constraint.\n\nIn this case, a valid position for the two gears is to \
place the driven gear directly above the drive gear, and align each of their \
local axes with the global axes. This leads to an initial condition constant \
of C = -\[Pi]/2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(cs[5] = 
      TwoGears2[5, Point[drivensprocket, 0], 0.3, Point[drivengear, 1], 0.7, 
        \(-\[Pi]\)/2.0]; \ncs[6] = RelativeX1[6, Point[drivengear, 1], 2.0]; 
    \)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Pinion Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"    7.  A revolute joint to locate the axis of the pinion.\n    8.  An \
absolute distance constraint to model the connecting rod."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[7] = Revolute2[7, Point[pinion, 1], Point[ground, 4]]; \)\), 
    \(\(cs[8] = 
      RelativeDistance1[8, Point[drivengear, 2], Point[pinion, 2], 2.0]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Rack Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "    9.  A constraint to enforce the rolling gear relationship between the \
rack and the pinion.\n    10.  A 1 degree of freedom constraint to support \
the other end of the rack. ",
  StyleBox["PointOnLine1", "Input"],
  " is used to orient the rack relative to the center of a support roller, \
following the concept of the actual pump mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["?RackAndPinion2", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \("RackAndPinion2[cnum, point, rad, axis, C] models a rack and pinion \
gear set.  The center of the pinion (point) is constrained to lie rad units \
to the left of the rack (axis) and the angular orientation of the rack and \
pinion are related as per the pinion radius.  The constant C sets the initial \
orientation of the rack and pinion.  Constrains 2 DOF"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "Like the other gear constraints, this constraint controls only two degrees \
of freedom. The pinion is placed at a constant distance away from the rack \
and the rotational position of the pinion is related to its position along \
the rack, but the rack is still free to swing around the pinion.\n\nWhen the \
local axes of both the rack and the pinion are aligned with the global X \
axis, the axis of the pinion is directly adjacent to the second point used to \
define the rack (",
  StyleBox["Point[6,1]", "Input"],
  "), thus the initial condition constant C is 0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[9] = 
      RackAndPinion2[9, Point[pinion, 1], \(-1.0\), Line[rack, 1, 2], 0]; 
    \)\), 
    \(\(cs[10] = PointOnLine1[10, \n\t\tPoint[ground, 5], Line[rack, 1, 2]]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["SetConstraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The data contained in each of the constraint objects is incorporated into \
the current model with the SetConstraints command."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 10]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Initial Guesses  "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Initial guesses must be given for the X, Y, and Theta coordinates of all \
bodies. Guesses that are not specified are initially set to zero. Note that \
permanent initial guesses could have been specified earlier in the body \
objects, and entered with the ",
  StyleBox["SetBodies", "Input"],
  " command. Setting the initial guesses with ",
  StyleBox["SetGuess", "Input"],
  " affects only the very next solution cycle. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetGuess[
      guesslist = {X3 \[Rule] 2, X4 \[Rule] 2, Y4 \[Rule] 1, X5 \[Rule] 4, 
          Y5 \[Rule] 2, X6 \[Rule] 4, Y6 \[Rule] 3}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 0, X3 \[Rule] 2, 
      Y3 \[Rule] 0, Th3 \[Rule] 0, X4 \[Rule] 2, Y4 \[Rule] 1, Th4 \[Rule] 0, 
      X5 \[Rule] 4, Y5 \[Rule] 2, Th5 \[Rule] 0, X6 \[Rule] 4, Y6 \[Rule] 3, 
      Th6 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Running the Model  "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CheckSystem", "Input"],
  " test for several modeling errors. A return value of ",
  StyleBox["True", "Input"],
  " is OK."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckSystem[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["SolveMech[", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " runs the current model at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and returns a list of rules containing the X, Y, and \[CapitalTheta] \
coordinates of each body."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[.05]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.314159265358979311`\), ",", 
        \(X3 \[Rule] 2.`\), ",", \(Y3 \[Rule] 0.`\), ",", 
        \(Th3 \[Rule] 0.104719755119659785`\), ",", \(X4 \[Rule] 2.`\), ",", 
        \(Y4 \[Rule] 1.`\), ",", \(Th4 \[Rule] \(-0.044879895051282812`\)\), 
        ",", \(X5 \[Rule] 4.`\), ",", \(Y5 \[Rule] 2.`\), ",", 
        \(Th5 \[Rule] \(-0.0407433996880588544`\)\), ",", 
        \(X6 \[Rule] 4.04074339968805862`\), ",", \(Y6 \[Rule] 3.`\), ",", 
        \(Th6 \[Rule] 0.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Graphics "], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Gear-Pump Image"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Here is a graphic image if the chain drive system.", "Text"],

Cell["\<\
chain = Graphics[{
  (* drive sprocket *) {
    RGBColor[1,0,0],
    Circle[Location[drivesprocket, 0], 0.4],
    Tangent[Location[drivesprocket, 0], 0.4,
            Location[drivensprocket, 0], 1.2]},
  (* drive gear *) {
    RGBColor[0,0,1],
    Circle[Location[drivensprocket, 0], 1.2],
    Disk[Location[drivensprocket, 0], 0.3] },
  (* Axes *)
  LocalAxes[{drivesprocket,drivesprocket}, 0.75]},
  Frame->True,
  PlotRange->{{-1,6},{-2,5}},
  AspectRatio->Automatic];\
\>", "Input",
  AspectRatioFixed->True],

Cell["Here is a graphic of the pump", "Text"],

Cell["\<\
pump = Graphics[{
  (* Ground *) {
    Edge[ground, {1,2,3}],
    Line[{{2,3},{6,3}}]},
  (* driven gear *) {
    RGBColor[0,1,0],
    Disk[Location[drivengear, 0], 0.7] },
  (* pinion *) {
    RGBColor[1,0,1],
    Disk[Location[pinion, 0], 1.0] },
  (* rack *) {
    RGBColor[0,1,1],
    Bar[ Line[rack, 2, {-1,0}], 0, 0.4]},
  (* link *) {
    Thickness[.01],
    Line[{Location[drivengear, 2],
          Location[pinion, 2]}],
    PointSize[.02],
    Point[Location[drivengear, 2]],
    Point[Location[pinion, 2]]},
  (* Axes *)
  LocalAxes[{drivengear, rack, pinion}, 0.75]},
  Frame->True,
  PlotRange->{{-1,6},{-2,5}},
  AspectRatio->Automatic];\
\>", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{chain, pump} /. LastSolve[]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
newpath
.14286 .28571 .05714 0 365.73 arc
s
.12 .23334 m
.36 .1286 L
s
.36 .44283 m
.12 .33809 L
s
0 0 1 r
newpath
.42857 .28571 .17143 0 365.73 arc
s
.42857 .28571 m
.42857 .28571 .04286 0 365.73 arc
F
0 g
gsave
.24476 .31882 -61.0739 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.10975 .38761 -61.0739 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -61.0739 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.24476 .31882 m
.14286 .28571 L
.10975 .38761 L
s
.22769 .30201 m
.24476 .31882 L
.22107 .32239 L
s
.10618 .36392 m
.10975 .38761 L
.12656 .37054 L
s
gsave
.24476 .31882 -61.0739 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.10975 .38761 -61.0739 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.14286 .28571 -61.0739 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.24476 .31882 m
.14286 .28571 L
.10975 .38761 L
s
.22769 .30201 m
.24476 .31882 L
.22107 .32239 L
s
.10618 .36392 m
.10975 .38761 L
.12656 .37054 L
s
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
0 1 1 r
.86296 .71429 m
.86296 .77143 L
.57725 .77143 L
.57725 .71429 L
F
0 g
.01 w
.43178 .49993 m
.70847 .42869 L
s
.02 w
.43178 .49993 Mdot
.70847 .42869 Mdot
gsave
.53561 .42376 -59.8684 -4.14128 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.43338 .53561 -59.8684 -4.14128 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -59.8684 -4.14128 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.53561 .42376 m
.42857 .42857 L
.43338 .53561 L
s
.51372 .41402 m
.53561 .42376 L
.51468 .43543 L
s
.42171 .51468 m
.43338 .53561 L
.44312 .51372 L
s
gsave
.82725 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.72011 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.72011 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82725 .71429 m
.72011 .71429 L
.72011 .82143 L
s
.80582 .70357 m
.82725 .71429 L
.80582 .725 L
s
.70939 .8 m
.72011 .82143 L
.73082 .8 L
s
gsave
.82134 .56706 -59.8803 -4.13741 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71865 .67848 -59.8803 -4.13741 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -59.8803 -4.13741 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.82134 .56706 m
.71429 .57143 L
.71865 .67848 L
s
.79949 .55723 m
.82134 .56706 L
.80037 .57864 L
s
.70707 .65751 m
.71865 .67848 L
.72848 .65664 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016Q000`40O003h00Oogoo6goo003oOolK
Ool003Aoo`03001oogoo021oo`D0029oo`<0029oo`8002Eoo`<0029oo`03001oogoo029oo`8000Ao
o`00<goo00<007oo00008goo00<007ooOol08Woo00<007ooOol097oo00<007ooOol08goo00<007oo
Ool087oo00<007oo00008goo00<007oo00000goo000cOol00`00Ool0000SOol00`00Oomoo`0SOol0
0`00Oomoo`0ROol00`00Oomoo`0ROol4000SOol00`00Oomoo`0QOol00`00Ool00003Ool003=oo`03
001oo`0002=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo025oo`03001oo`00029oo`80
02Aoo`8000Aoo`00<goo00<007oo00008goo00<007ooOol08Woo00<007oo00008Woo00<007oo0000
97oo0P008Woo00<007ooOol08goo00<007ooOol00goo000dOol00`00Oomoo`0QOol2000UOol00`00
Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0POol3000TOol20003Ool00?mooa]oo`00ogoo6goo
003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol000moool000T000=oo`003goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001o
ogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo0P00ogoo1Goo0P00
0goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001o
ogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`800?moo`Eo
o`8000=oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`Eoo`03001oogoo005oo`003goo0P00ogoo1Goo0P000goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`8006Iooa407heoo`8000=oo`003goo00<007ooOol0
HGoo100O4Goo1@0ORGoo00<007ooOol00Goo000?Ool00`00Oomoo`1OOol201lJOol201n7Ool00`00
Oomoo`01Ool000moo`03001oogoo05Yoo`9l0003Ool07`0O01ioo`807hEoo`03001oogoo005oo`00
3goo00<007ooOol0F7oo0W`000=oo`0O01l08Woo0P0OPgoo00<007ooOol00Goo0007Ool50003Ool0
0`00Oomoo`1FOol2O0000goo01l07`0VOol201n1Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=o
o`03001oogoo05Aoo`9l0003Ool07`0O02Yoo`807gmoo`03001oogoo005oo`000goo0`000goo00<0
07ooOol00goo0P00DWoo0g`000=oo`0O01l0;Woo0P0ONgoo0`000goo0009Ool00`00Oomoo`03Ool0
0`00Oomoo`1?Ool2O002Ool201lbOol201mkOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03
001oogoo04eoo`9l009oo`807cIoo`0301moogoo07Qoo`03001oogoo005oo`0027oo0P001Goo00<0
07ooOol0Bgoo0W`00goo00<07gooOol0=goo00<07gooOol0Mgoo00<007ooOol00Goo000?Ool00`00
Oomoo`18Ool3O005Ool00`0OOomoo`0hOol00`0OOomoo`1fOol00`00Oomoo`01Ool000moo`03001o
ogoo04Ioo`9l00Ioo`807caoo`807gIoo`03001oogoo005oo`003goo00<007ooOol0A7oo0W`01goo
00<07gooOol0?Goo00<07gooOol0M7oo00<007ooOol00Goo000?Ool00`00Oomoo`12Ool2O008Ool0
0`0OOomoo`0oOol00`0OOomoo`1cOol00`00Oomoo`01Ool000moo`80041oo`=l00Uoo`0301moogoo
045oo`0301moogoo075oo`8000=oo`003goo00<007ooOol0?Goo0W`037oo00<07gooOol0@Woo00<0
7gooOol0LGoo00<007ooOol00Goo000?Ool00`00Oomoo`0kOol2O00<Ool201m6Ool00`0OOomoo`1`
Ool00`00Oomoo`01Ool000moo`03001oogoo03Uoo`9l00eoo`0301moogoo04Moo`0301moogoo06mo
o`03001oogoo005oo`003goo00<007ooOol0=Woo0g`03goo00<07gooOol0B7oo00<07gooOol0KWoo
00<007ooOol00Goo000?Ool00`00Oomoo`0dOol2O00AOol00`0OOomoo`19Ool00`0OOomoo`1^Ool0
0`00Oomoo`01Ool000moo`03001oogoo039oo`9l01=oo`0301moogoo04Yoo`0301moogoo06eoo`03
001oogoo005oo`003goo0P00<Goo0W`057oo00<07gooOol0Bgoo00<07gooOol0K7oo0P000goo000?
Ool00`00Oomoo`0]Ool3O00FOol00`0OOomoo`1<Ool00`0OOomoo`1/Ool00`00Oomoo`01Ool000mo
o`03001oogoo02]oo`9l01Qoo`0301moogoo04eoo`0301moogoo06aoo`03001oogoo005oo`003goo
00<007ooOol0:Goo0W`06Woo00<07gooOol0CWoo00<07gooOol0Jgoo00<007ooOol00Goo000?Ool0
0`00Oomoo`0WOol2O00KOol00`0OOomoo`1?Ool00`0OOomoo`1[Ool00`00Oomoo`01Ool000moo`03
001oogoo02Aoo`=l01eoo`0301moogoo051oo`0301moogoo06Yoo`03001oogoo005oo`003goo00<0
07ooOol08Woo0W`07goo00<07gooOol0DGoo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00
Oomoo`0POol2O00QOol00`0OOomoo`1BOol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`8001mo
o`Yl01Yoo`0301moogoo05=oo`0301moogoo06Qoo`8000=oo`003goo00<007ooOol077oo0W`02Woo
0W`067oo00<07gooOol0Dgoo00<07gooOol0JGoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol2
O00>Ool2O00FOol00`0OOomoo`1COol00`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo
01Qoo`9l019oo`03O01oogoo01=oo`0301moogoo05Aoo`0301moogoo06Qoo`03001oogoo005oo`00
3goo00<007ooOol05goo00=l07ooOol04goo00=l07ooOol04Woo00<07gooOol09Goo1P0O:Goo00<0
7gooOol0J7oo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomoo`0DOol00g`0Oomoo`0@
Ool00`0OOomoo`0TOol;01lWOol00`0OOomoo`1WOol00`00Oomoo`01Ool000moo`03001oogoo01Io
o`03O01oogoo01Ioo`03O01oogoo00moo`0301moogoo029oo`h07bIoo`0301moogoo06Moo`03001o
ogoo005oo`003goo0P005Woo00=l07ooOol067oo00=l07ooOol03Woo00<07gooOol08Goo4@0O97oo
00<07gooOol0IWoo0P000goo000?Ool00`00Oomoo`0EOol00g`0Oomoo`0HOol00g`0Oomoo`0>Ool0
0`0OOomoo`0POolC01lSOol00`0OOomoo`1WOol00`00Oomoo`01Ool000moo`03001oogoo01Eoo`03
O01oogoo01Uoo`03O01oogoo00eoo`0301moogoo021ooa<07b=oo`0301moogoo06Moo`03001oogoo
005oo`003goo00<007ooOol057oo00=l07ooOol06Woo00=l07ooOol03Goo00<07gooOol07goo5@0O
8Woo00<07gooOol0Igoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0Oomoo`0JOol00g`0
Oomoo`0<Ool00`0OOomoo`0POolE01lROol00`0OOomoo`1WOol00`00Oomoo`01Ool000moo`03001o
ogoo01Aoo`03O01oogoo01Yoo`03O01oogoo00aoo`0301moogoo01mooaL07b5oo`0301moogoo06Mo
o`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol04goo00=l07ooOol06goo00=l07oo
Ool037oo00<07gooOol07goo5`0O8Goo00<07gooOol0Igoo00<007ooOol00Goo0008Ool00`00Ool0
0004Ool00`00Oomoo`0COol00g`0Oomoo`0KOol00g`0Oomoo`0<Ool00`0OOomoo`0OOolG01lQOol0
0`0OOomoo`1WOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`8001Aoo`03O01oogoo00aood`0
00/07b5oo`0301moogoo06Eoo`<000=oo`0027oo00<007oo000017oo00<007ooOol04goo00=l07oo
Ool037oo00<007oo00000`002Goo00=l07ooOol037oo00<07gooOol07goo2`0O00<0000O01l02@0O
8Goo00<07gooOol0Igoo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`0COol00g`0
Oomoo`0;Ool01000Oomoogoo1P001Woo00=l07ooOol037oo00<07gooOol087oo2P0O00<0000O01l0
200O8Woo00<07gooOol0Igoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0COol0
0g`0Oomoo`0;Ool01000Oomoogoo0P0017oo0`000goo00=l07ooOol037oo00<07gooOol087oo2P0O
00<0000O01l0200O8Woo00<07gooOol0Igoo00<007ooOol00Goo000?Ool00`00Oomoo`0DOol00g`0
Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`04Ool40007Ool00`00Oomoo`05Ool00`0OOomoo`0P
Ool901l00`0001l07`0801lROol00`0OOomoo`1WOol00`00Oomoo`01Ool000moo`03001oogoo01Ao
o`03O01oogoo00Uoo`03001oogoo00Aoo`03001oogoo00Ioo`03O01oo`00008000Eoo`03001oogoo
00Aoo`0301moogoo021oo`T07`0300007`0O00P07b9oo`0301moogoo06Moo`03001oogoo005oo`00
3goo00<007ooOol05Goo00=l07ooOol027oo00<007ooOol00Woo0`0027oo00=l07ooOol00Woo0`00
0goo00<007ooOol00goo00<07gooOol08Goo200O00<0000O01l01`0O8goo00<07gooOol0Igoo00<0
07ooOol00Goo000?Ool2000GOol00g`0Oomoo`07Ool00`00Oomoo`0<Ool00g`0Oomoo`06Ool50004
Ool00`0OOomoo`0QOol801l00`0001l07`0601lTOol00`0OOomoo`1VOol20003Ool000moo`03001o
ogoo01Ioo`03O01oogoo00Moo`03001oogoo00aoo`03O01oogoo00Uoo`<000=oo`0301moogoo029o
o`L07`0300007`0O00D07bEoo`0301moogoo06Moo`03001oogoo005oo`003goo00<007ooOol05goo
00=l07ooOol01Goo00<007ooOol037oo00=l07ooOol01Woo10001Woo00<07gooOol08goo1P0O00<0
000O01l00`0O9goo00<07gooOol0Igoo00<007ooOol00Goo000?Ool00`00Oomoo`0GOol00g`0Oomo
o`05Ool00`00Oomoo`0;Ool00g`0Oomoo`0?Ool200000`0O001oo`0UOol401l0100001l07`0O:7oo
00<07gooOol0J7oo00<007ooOol00Goo000?Ool00`00Oomoo`0HOol2O005Ool00`00Oomoo`09Ool2
O00DOol00`0001moo`0WOol201l00`0001moo`0YOol00`0OOomoo`1XOol00`00Oomoo`01Ool000mo
o`03001oogoo01Yoo`05O01oogooOol0000;Ool00g`0Oomoo`0COol00`00Ool0000UOol<0n0TOol0
0`0OOomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo01]oo`=l0003001oogoo00Qoo`03O01o
ogoo01Ioo`0301moogoo01iooa@3h25oo`0301moogoo06Uoo`03001oogoo005oo`003goo00<007oo
Ool07Woo00<007`0O0000goo1G`06Goo00<07gooOol06goo6@?P7goo00<07gooOol0JGoo00<007oo
Ool00Goo000?Ool2000NOol00`00Oomoo`04O00OOol00`0OOomoo`0IOolM0n0LOol00`0OOomoo`1X
Ool20003Ool000moo`03001oogoo01eoo`03001oogoo009oo`9l01moo`0301moogoo01Qooal3h1Yo
o`0301moogoo06Yoo`03001oogoo005oo`003goo00<007ooOol07Goo00<007ooOol017oo0g`07Goo
00<07gooOol05Goo8P?P6Goo00<07gooOol0JWoo00<007ooOol00Goo000?Ool00`00Oomoo`0LOol0
0`00Oomoo`08Ool2O00KOol00`0OOomoo`0DOolU0n0FOol00`0OOomoo`1[Ool00`00Oomoo`01Ool0
00moo`03001oogoo01aoo`03001oogoo00Yoo`9l01Yoo`0301moogoo019oobL3h1Eoo`0301moogoo
06]oo`03001oogoo005oo`003goo00<007ooOol06Goo00@007ooOol000ioo`9l01Qoo`0301moogoo
015oobT3h1=oo`0301moogoo06aoo`03001oogoo005oo`003goo00<007ooOol06Goo00@007ooOol0
011oo`=l01Ioo`0301moogoo00moob/3h19oo`0301moogoo06aoo`03001oogoo005oo`003goo0P00
6Woo00<007oo00000Woo00<007ooOol03goo0W`057oo00<07gooOol03goo:`?P4Goo00<07gooOol0
K7oo0P000goo000?Ool00`00Oomoo`0IOol01@00Ool007oo000057oo0W`04goo00<07gooOol03Goo
;@?P47oo00<07gooOol0KGoo00<007ooOol00Goo000?Ool00`00Oomoo`0JOol3000GOol2O00AOol0
0`0OOomoo`0=Ool]0n0?Ool00`0OOomoo`1^Ool00`00Oomoo`01Ool000moo`03001oogoo01Yoo`80
01Yoo`=l00moo`0301moogoo00aoobd3h0moo`0301moogoo06ioo`03001oogoo005oo`003goo00<0
07ooOol06Woo00<007ooOol00P006Woo0W`03Goo00<07gooOol02goo;`?P3Goo00<07gooOol0Kgoo
00<007ooOol00Goo000?Ool00`00Oomoo`0NOol00`00Oomoo`0JOol2O00<Ool00`0OOomoo`0:Ool`
0n0;Ool00`0OOomoo`1`Ool00`00Oomoo`01Ool000moo`03001oogoo01ioo`03001oogoo01aoo`9l
00]oo`0301moogoo00Qooc43h0Yoo`0301moogoo075oo`03001oogoo005oo`003goo00<007ooOol0
7Goo00<007oo00007goo0g`02Goo00<07gooOol01goo<@?P2Woo00<07gooOol0LGoo00<007ooOol0
0Goo000?Ool2000NOol01000Ool000008Goo0W`027oo00<07gooOol01Woo<P?P1goo0P0OLgoo0P00
0goo000?Ool00`00Oomoo`14Ool2O007Ool00`0OOomoo`04Oolc0n06Ool00`0OOomoo`1dOol00`00
Oomoo`01Ool000moo`03001oogoo04Ioo`9l00Ioo`0301moogoo00=ooc<3h0Ioo`0301moogoo07Ao
o`03001oogoo005oo`003goo00<007ooOol0B7oo0g`017oo0P0O0Woo<@?P00@000?P0n03h0=oo`80
7gMoo`03001oogoo005oo`003goo00<007ooOol0Bgoo0W`00goo00<07gooOol0<P?P0P0000@3h7oo
Ool07gUoo`03001oogoo005oo`001goo1@000goo00<007ooOol0CGoo0W`00Woo00<07goo0n00<`?P
0P0000<07gooOol0N7oo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1?Ool2O000
0goo01l3h00X0n0>000/Ool2001<Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`80059oo`9l
01X3h0l000/3h08002]oo`D004Uoo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0Dgoo6P?P
00<000?P0n005@?P0P0000<3h7ooOol00goo0P0000=oo`00Ool07Woo2@001W`OAGoo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1COolJ0n000`000n03h0030n02000?0n0010000n03
h0?P1goo00<007ooOol06Woo20000W`O0P002g`O@Goo00<007ooOol00Goo0008Ool20005Ool00`00
Oomoo`1COolJ0n000`000n03h0020n03000C0n06Ool00`00Ool0000GOol8000FO1lnOol00`00Oomo
o`01Ool000moo`03001oogoo05=ooaX3h0030003h0?P0083h0030003h00001<3h1aoo`P001il7cYo
o`03001oogoo005oo`003goo00<007ooOol0E7oo6@?P00<000?P0n000`?P00<000?P0n004@?P6Goo
20008g`O>Goo00<007ooOol00Goo000?Ool00`00Oomoo`1DOolI0n000`000n03h0030n000`000n03
h00A0n0FOol7000YO1lgOol00`00Oomoo`01Ool000moo`03001oogoo05AooaT3h0030003h0?P01L3
h19oo`L000=oob]l7cIoo`03001oogoo005oo`003goo0P00EWoo6@?P00<000?P0n005@?P3goo2000
1Goo;W`O<goo0P000goo000?Ool00`00Oomoo`1EOolI0n000`000n03h00E0n0;Ool80008Ool`O1lc
Ool00`00Oomoo`01Ool000moo`03001oogoo05IooaP3h0030003h0?P01D3h0Moo`P000]ooc9l7c9o
o`03001oogoo005oo`003goo00<007ooOol0EWoo60?P00<000?P0n005@?P0goo20003Woo=7`O<Goo
00<007ooOol00Goo000?Ool00`00Oomoo`1FOolH0n000`000n03h00D0n000goo00000005000@Oolg
O1l`Ool00`00Oomoo`01Ool000moo`03001oogoo05MooaL3h0030003h0?P0143h0L001AoocQl7bmo
o`03001oogoo005oo`003goo00<007ooOol0Egoo5`?P00<000?P0n003@?P20005Woo>G`O;goo00<0
07ooOol00Goo000?Ool2001IOolF0n000`000n03h0090n0800000`?POomoo`0FOolkO1l]Ool20003
Ool000moo`03001oogoo05QooaH3h0030003h0?P00D3h0P000D3h1Moocel7beoo`03001oogoo005o
o`003goo00<007ooOol0FGoo5@?P00@000?P0n03h0P000P3h1Moocil7beoo`03001oogoo005oo`00
3goo00<007ooOol0FWoo4`?P2@002`?P5goo@7`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`1K
OolA0n06000>0n0HOom1O1l[Ool00`00Oomoo`01Ool000moo`03001oogoo05aooa03h0@000l3h1Qo
od9l7b]oo`03001oogoo005oo`003goo00<007ooOol0GWoo3`?P0P003`?P6Goo@g`O:Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`1OOol@0n000`000n00000:0n0KOom4O1lYOol00`00Oomoo`01Ool0
00moo`80065oo``3h0060003h0?P0003h0002@?P6gooAG`O:7oo0P000goo000?Ool00`00Oomoo`1S
Ool:0n0010000n00000020?P7GooAW`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`1UOol80n00
10000n0000001P?P7WooAg`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`1XOol60n0300000`?P
Oomoo`0QOom7O1lXOol00`00Oomoo`01Ool000moo`03001oogoo06ioo`8002EoodMl7bQoo`03001o
ogoo005oo`003goo00<007ooOol0Kgoo00@007ooOomoo`8001moodUl7bMoo`03001oogoo005oo`00
3goo00<007ooOol0M7oo00<007ooOol07GooBG`O9goo00<007ooOol00Goo000?Ool2001eOol00`00
Oomoo`0MOom9O1lVOol20003Ool000moo`03001oogoo07=oo`03001oo`0001ioodYl7bIoo`03001o
ogoo005oo`003goo00<007ooOol0Lgoo00@007oo000001aood]l7bIoo`03001oogoo005oo`003goo
00<007ooOol0TgooBg`O9Woo00<007ooOol00Goo000?Ool00`00Oomoo`2COollO1l00`00O1ml7`0<
O1lVOol00`00Oomoo`01Ool000moo`03001oogoo09=oocel7`8000al7bIoo`03001oogoo005oo`00
27oo0`0017oo00<007ooOol0Tgoo?g`O0P002W`O9Woo00<007ooOol00Goo0008Ool00`00Oomoo`04
Ool00`00Oomoo`2COoldO1l?0008O1lVOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`8009Ao
obEl7`l000al7`8000=l7`800004O1l007`OO1lTOol30003Ool000Uoo`03001oogoo00=oo`03001o
ogoo09=oobEl7`03001l7g`O01Il7`8000Ml7`04001l7g`OO1lVOol00`00Oomoo`01Ool000Qoo`03
001oo`0000Aoo`03001oogoo09=oobEl7`03001l7g`O009l7`<000ml7`8000Ql7`03001l7`00009l
7bIoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0Tgoo9G`O00<007`OO1l017`O
00<007`OO1l077`O9Woo00<007ooOol00Goo000?Ool00`00Oomoo`2COolUO1l00`00O1ml7`04O1l0
0`00O1ml7`0LO1lVOol00`00Oomoo`01Ool000moo`03001oogoo09=oobEl7`03001l7g`O009l7`80
01ml7bIoo`03001oogoo005oo`003goo00<007ooOol0U7oo97`O00<007`OO1l00W`O0`007W`O9Woo
00<007ooOol00Goo000?Ool2002EOolTO1l00`00O1ml7`0RO1lVOol20003Ool000moo`03001oogoo
09AoobEl7`03001l7g`O025l7bMoo`03001oogoo005oo`003goo00<007ooOol0U7oo9G`O00<007`O
O1l08G`O9goo00<007ooOol00Goo000?Ool00`00Oomoo`2EOolTO1l00`00O1ml7`0QO1lWOol00`00
Oomoo`01Ool000moo`03001oogoo09EoobAl7`03001l7g`O021l7bQoo`03001oogoo005oo`003goo
00<007ooOol0UGoo97`O00<007`OO1l087`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2FOolS
O1l00`00O1ml7`0PO1lXOol00`00Oomoo`01Ool000moo`03001oogoo09Ioob=l7`03001l7g`O01ml
7bUoo`03001oogoo005oo`003goo0P00V7oo8W`O00<007`OO1l07g`O:7oo0P000goo000?Ool00`00
Oomoo`2GOolRO1l00`00O1ml7`0NO1lZOol00`00Oomoo`01Ool000moo`03001oogoo09Moob9l7`03
001l7g`O01il7bYoo`03001oogoo005oo`003goo00<007ooOol0Ugoo8W`O00<007`OO1l07G`O:goo
00<007ooOol00Goo000?Ool00`00Oomoo`2HOolQO1l00`00O1ml7`0LO1l/Ool00`00Oomoo`01Ool0
00moo`03001oogoo09Uoob1l7`03001l7g`O01al7baoo`03001oogoo005oo`003goo00<007ooOol0
VGoo87`O00<007`OO1l06g`O;Goo00<007ooOol00Goo000?Ool2002LOolLO1l01P00O1ml7`00O1l0
01Yl7baoo`8000=oo`003goo00<007ooOol0W7oo6g`O00H007`OO1l007`O000IO1l^Ool00`00Oomo
o`01Ool000moo`03001oogoo09eooa]l7`04001l7`00000IO1l_Ool00`00Oomoo`01Ool000moo`03
001oogoo09eooa]l7`04001l7`00000IO1l_Ool00`00Oomoo`01Ool000moo`03001oogoo09iooa]l
7`<001Ql7c1oo`03001oogoo005oo`003goo00<007ooOol0Wgoo6W`O0P0067`O<Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2POolJO1l01000O1ml7g`O0P004W`O<Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`2ROolMO1l00`00O1ml7`0>O1ldOol00`00Oomoo`01Ool000moo`800:Aooaal7`03001l
7g`O00el7cAoo`8000=oo`003goo00<007ooOol0Y7oo6W`O00<007`O000037`O=goo00<007ooOol0
0Goo000?Ool00`00Oomoo`2VOolHO1l01000O1l000002G`O>Goo00<007ooOol00Goo000?Ool00`00
Oomoo`2WOolSO1ljOol00`00Oomoo`01Ool000moo`03001oogoo0:Uooaml7`Qoo`03001oogoo035o
o`03001oogoo005oo`0027oo0P001Goo00<007ooOol0Zgoo6g`O2goo0P00<Goo00<007ooOol00Goo
000:Ool00`00Oomoo`02Ool00`00Oomoo`2^OolEO1l@Ool2000_Ool00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`8006ioodD000Ql7d/000=oo`002Woo00<007ooOol00Woo00<007ooOol0U7oo9P?o
00<000?o0ol05`?o0P002@?o9Goo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`2D
OolV0ol010000ol3o`?o0`004@?o0P001@?o0P0000@3o`000ol3obEoo`03001oogoo005oo`002Goo
00<007ooOol00goo00<007ooOol0U7oo9P?o00L000?o0ol3o`000ol0000?0ol200090ol010000ol3
o`?o9Goo00<007ooOol00Goo000?Ool00`00Oomoo`2DOolV0ol010000ol3o`?o0`006@?o00<000?o
00000P?o9Goo00<007ooOol00Goo000?Ool00`00Oomoo`2DOolV0ol01@000ol3o`?o000080?o9Goo
00<007ooOol00Goo000?Ool00`00Oomoo`2DOolV0ol00`000ol3o`020ol2000N0olUOol00`00Oomo
o`01Ool000moo`03001oogoo09AoobH3o`030003o`?o0283obEoo`03001oogoo005oo`003goo0P00
UGoo9P?o00<000?o0ol08P?o97oo0P000goo000?Ool00`00Oomoo`2DOolV0ol00`000ol3o`0R0olU
Ool00`00Oomoo`01Ool000moo`03001oogoo09AoobH3o`030003o`?o0283obEoo`03001oogoo005o
o`003goo00<007ooOol0U7oo9P?o00<000?o0ol08P?o9Goo00<007ooOol00Goo000?Ool00`00Oomo
o`2DOolV0ol00`000ol3o`0R0olUOol00`00Oomoo`01Ool000moo`03001oogoo09AoobH3o`030003
o`?o0283obEoo`03001oogoo005oo`003goo00<007ooOol0U7oo9P?o00<000?o0ol08P?o9Goo00<0
07ooOol00Goo000?Ool2002EOolV0ol00`000ol3o`0R0olTOol20003Ool000moo`03001oogoo0;Yo
o`03001oogoo04Moo`03001oogoo005oo`003goo00<007ooOol0^Woo00<007ooOol0Agoo00<007oo
Ool00Goo000?Ool00`00Oomoo`2jOol00`00Oomoo`17Ool00`00Oomoo`01Ool000moo`03001oogoo
0;Yoo`03001oogoo04Moo`03001oogoo005oo`003goo00<007ooOol0^Woo00<007ooOol0Agoo00<0
07ooOol00Goo000?Ool00`00Oomoo`2jOol00`00Oomoo`17Ool00`00Oomoo`01Ool000moo`03001o
ogoo0;Yoo`03001oogoo04Moo`03001oogoo005oo`003goo0P00^7oo00@007ooOol0009oo`03001o
ogoo04=oo`8000=oo`003goo00<007ooOol0^7oo00D007oo001oo`0004Moo`03001oogoo005oo`00
3goo00<007ooOol0^7oo00D007oo001oo`0004Moo`03001oogoo005oo`003goo00<007ooOol0^Goo
0`00B7oo00<007ooOol00Goo000?Ool00`00Oomoo`2iOol30018Ool00`00Oomoo`01Ool000moo`03
001oogoo0;Yoo`04001oogooOol20014Ool00`00Oomoo`01Ool000moo`03001oogoo0;moo`03001o
ogoo049oo`03001oogoo005oo`003goo0P00`7oo00<007ooOol0@Goo0P000goo000?Ool00`00Oomo
o`2nOol00`00Ool00013Ool00`00Oomoo`01Ool000moo`03001oogoo0;ioo`04001oo`000012Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000Uoo`<000=oo`03
001oogoo0?moo`Eoo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo1Goo00<0
07ooOol00Goo0008Ool40003Ool2003oOol4Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo
0?moo`Eoo`03001oogoo005oo`002Goo0P0017oo00<007ooOol0ogoo1Goo00<007ooOol00Goo000:
Ool00`00Oomoo`02Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eo
o`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool5Ool00`00Oomoo`01Ool000moo`800?moo`Eoo`8000=oo`003goo00<007ooOol0ogoo1Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eo
o`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007oo
Ool0ogoo1Goo00<007ooOol00Goo000?Ool2003oOol5Ool20003Ool000moo`03001oogoo0?moo`Eo
o`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007oo
Ool0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`80
0?moo`Eoo`8000=oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007oo
Ool0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?
Ool2003oOol5Ool20003Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007oo
Ool0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`Eoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo1Goo00<0
07ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000T0
00=oo`0027oo0P00ogoo4Goo0008Ool00`00Oomoo`3oOol@Ool000Qoo`<00?mooa1oo`00ogoo6goo
003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-1.40728, -2.34732, 0.026645, 
  0.026645}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Animation "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The following input will generate the series of 24 graphics in the animation \
cell at the beginning of this notebook."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(postab = SolveMech[{0.0, 3.0}, 24]; \)\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\((Show[{chain, pump} /. #1]&)\)/@postab; \)\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Removing a Body "], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[
"It is not necessary to use body numbers that are consecutive integers; body \
numbers can be skipped. For example, the gear-pump can have the drive and \
driven sprockets (bodies 2 and 3) removed and a rotational driving constraint \
and revolute joint can be attached directly to the driven gear (body 5), \
making it the motion input to the model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[11] = RotationLock1[11, drivengear, 2\ \[Pi]\ T]; \)\), 
    \(\(cs[12] = Revolute2[12, \n\t\tPoint[drivengear, 1], Point[ground, 3]]; 
    \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The constraints that are required from the original model are constraint 7 \
through 12."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs[7], cs[8], cs[9], cs[10], cs[11], cs[12]]\)], "Input",\

  AspectRatioFixed->True],

Cell[TextData[
"This resets the initial guesses to the the values defined earlier. Some of \
the initial guesses are not needed."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SetGuess[guesslist]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetGuess::"unksym" \( : \ \) 
      "Warning: SetGuess received and ignored rules for symbols that are not \
currently system variables: \!\({X3}\)"\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "The only bodies included in this model are bodies 1, 4, 5, and 6. None of \
the constraints passed to ",
  StyleBox["SetConstraints", "Input"],
  " involved bodies 2 or 3, so these bodies are not included in the solution. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[.2]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.2`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X4 \[Rule] 2.`\), ",", 
        \(Y4 \[Rule] 1.`\), ",", \(Th4 \[Rule] 1.25663706143591724`\), ",", 
        \(X5 \[Rule] 4.`\), ",", \(Y5 \[Rule] 2.`\), ",", 
        \(Th5 \[Rule] \(-0.495894015197088844`\)\), ",", 
        \(X6 \[Rule] 4.49589401519708875`\), ",", \(Y6 \[Rule] 3.`\), ",", 
        \(Th6 \[Rule] 0.`\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[pump /. LastSolve[]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.142857 0.142857 0.285714 0.142857 [
[.14286 -0.0125 -3 -9 ]
[.14286 -0.0125 3 0 ]
[.28571 -0.0125 -3 -9 ]
[.28571 -0.0125 3 0 ]
[.42857 -0.0125 -3 -9 ]
[.42857 -0.0125 3 0 ]
[.57143 -0.0125 -3 -9 ]
[.57143 -0.0125 3 0 ]
[.71429 -0.0125 -3 -9 ]
[.71429 -0.0125 3 0 ]
[.85714 -0.0125 -3 -9 ]
[.85714 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .14286 -12 -4.5 ]
[-0.0125 .14286 0 4.5 ]
[-0.0125 .28571 -6 -4.5 ]
[-0.0125 .28571 0 4.5 ]
[-0.0125 .42857 -6 -4.5 ]
[-0.0125 .42857 0 4.5 ]
[-0.0125 .57143 -6 -4.5 ]
[-0.0125 .57143 0 4.5 ]
[-0.0125 .71429 -6 -4.5 ]
[-0.0125 .71429 0 4.5 ]
[-0.0125 .85714 -6 -4.5 ]
[-0.0125 .85714 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.14286 0 m
.14286 .00625 L
s
[(0)] .14286 -0.0125 0 1 Mshowa
.28571 0 m
.28571 .00625 L
s
[(1)] .28571 -0.0125 0 1 Mshowa
.42857 0 m
.42857 .00625 L
s
[(2)] .42857 -0.0125 0 1 Mshowa
.57143 0 m
.57143 .00625 L
s
[(3)] .57143 -0.0125 0 1 Mshowa
.71429 0 m
.71429 .00625 L
s
[(4)] .71429 -0.0125 0 1 Mshowa
.85714 0 m
.85714 .00625 L
s
[(5)] .85714 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(6)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.02857 0 m
.02857 .00375 L
s
.05714 0 m
.05714 .00375 L
s
.08571 0 m
.08571 .00375 L
s
.11429 0 m
.11429 .00375 L
s
.17143 0 m
.17143 .00375 L
s
.2 0 m
.2 .00375 L
s
.22857 0 m
.22857 .00375 L
s
.25714 0 m
.25714 .00375 L
s
.31429 0 m
.31429 .00375 L
s
.34286 0 m
.34286 .00375 L
s
.37143 0 m
.37143 .00375 L
s
.4 0 m
.4 .00375 L
s
.45714 0 m
.45714 .00375 L
s
.48571 0 m
.48571 .00375 L
s
.51429 0 m
.51429 .00375 L
s
.54286 0 m
.54286 .00375 L
s
.6 0 m
.6 .00375 L
s
.62857 0 m
.62857 .00375 L
s
.65714 0 m
.65714 .00375 L
s
.68571 0 m
.68571 .00375 L
s
.74286 0 m
.74286 .00375 L
s
.77143 0 m
.77143 .00375 L
s
.8 0 m
.8 .00375 L
s
.82857 0 m
.82857 .00375 L
s
.88571 0 m
.88571 .00375 L
s
.91429 0 m
.91429 .00375 L
s
.94286 0 m
.94286 .00375 L
s
.97143 0 m
.97143 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .14286 m
.00625 .14286 L
s
[(-1)] -0.0125 .14286 1 0 Mshowa
0 .28571 m
.00625 .28571 L
s
[(0)] -0.0125 .28571 1 0 Mshowa
0 .42857 m
.00625 .42857 L
s
[(1)] -0.0125 .42857 1 0 Mshowa
0 .57143 m
.00625 .57143 L
s
[(2)] -0.0125 .57143 1 0 Mshowa
0 .71429 m
.00625 .71429 L
s
[(3)] -0.0125 .71429 1 0 Mshowa
0 .85714 m
.00625 .85714 L
s
[(4)] -0.0125 .85714 1 0 Mshowa
0 1 m
.00625 1 L
s
[(5)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .02857 m
.00375 .02857 L
s
0 .05714 m
.00375 .05714 L
s
0 .08571 m
.00375 .08571 L
s
0 .11429 m
.00375 .11429 L
s
0 .17143 m
.00375 .17143 L
s
0 .2 m
.00375 .2 L
s
0 .22857 m
.00375 .22857 L
s
0 .25714 m
.00375 .25714 L
s
0 .31429 m
.00375 .31429 L
s
0 .34286 m
.00375 .34286 L
s
0 .37143 m
.00375 .37143 L
s
0 .4 m
.00375 .4 L
s
0 .45714 m
.00375 .45714 L
s
0 .48571 m
.00375 .48571 L
s
0 .51429 m
.00375 .51429 L
s
0 .54286 m
.00375 .54286 L
s
0 .6 m
.00375 .6 L
s
0 .62857 m
.00375 .62857 L
s
0 .65714 m
.00375 .65714 L
s
0 .68571 m
.00375 .68571 L
s
0 .74286 m
.00375 .74286 L
s
0 .77143 m
.00375 .77143 L
s
0 .8 m
.00375 .8 L
s
0 .82857 m
.00375 .82857 L
s
0 .88571 m
.00375 .88571 L
s
0 .91429 m
.00375 .91429 L
s
0 .94286 m
.00375 .94286 L
s
0 .97143 m
.00375 .97143 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.14286 .99375 m
.14286 1 L
s
.28571 .99375 m
.28571 1 L
s
.42857 .99375 m
.42857 1 L
s
.57143 .99375 m
.57143 1 L
s
.71429 .99375 m
.71429 1 L
s
.85714 .99375 m
.85714 1 L
s
.125 Mabswid
.02857 .99625 m
.02857 1 L
s
.05714 .99625 m
.05714 1 L
s
.08571 .99625 m
.08571 1 L
s
.11429 .99625 m
.11429 1 L
s
.17143 .99625 m
.17143 1 L
s
.2 .99625 m
.2 1 L
s
.22857 .99625 m
.22857 1 L
s
.25714 .99625 m
.25714 1 L
s
.31429 .99625 m
.31429 1 L
s
.34286 .99625 m
.34286 1 L
s
.37143 .99625 m
.37143 1 L
s
.4 .99625 m
.4 1 L
s
.45714 .99625 m
.45714 1 L
s
.48571 .99625 m
.48571 1 L
s
.51429 .99625 m
.51429 1 L
s
.54286 .99625 m
.54286 1 L
s
.6 .99625 m
.6 1 L
s
.62857 .99625 m
.62857 1 L
s
.65714 .99625 m
.65714 1 L
s
.68571 .99625 m
.68571 1 L
s
.74286 .99625 m
.74286 1 L
s
.77143 .99625 m
.77143 1 L
s
.8 .99625 m
.8 1 L
s
.82857 .99625 m
.82857 1 L
s
.88571 .99625 m
.88571 1 L
s
.91429 .99625 m
.91429 1 L
s
.94286 .99625 m
.94286 1 L
s
.97143 .99625 m
.97143 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .14286 m
1 .14286 L
s
.99375 .28571 m
1 .28571 L
s
.99375 .42857 m
1 .42857 L
s
.99375 .57143 m
1 .57143 L
s
.99375 .71429 m
1 .71429 L
s
.99375 .85714 m
1 .85714 L
s
.125 Mabswid
.99625 .02857 m
1 .02857 L
s
.99625 .05714 m
1 .05714 L
s
.99625 .08571 m
1 .08571 L
s
.99625 .11429 m
1 .11429 L
s
.99625 .17143 m
1 .17143 L
s
.99625 .2 m
1 .2 L
s
.99625 .22857 m
1 .22857 L
s
.99625 .25714 m
1 .25714 L
s
.99625 .31429 m
1 .31429 L
s
.99625 .34286 m
1 .34286 L
s
.99625 .37143 m
1 .37143 L
s
.99625 .4 m
1 .4 L
s
.99625 .45714 m
1 .45714 L
s
.99625 .48571 m
1 .48571 L
s
.99625 .51429 m
1 .51429 L
s
.99625 .54286 m
1 .54286 L
s
.99625 .6 m
1 .6 L
s
.99625 .62857 m
1 .62857 L
s
.99625 .65714 m
1 .65714 L
s
.99625 .68571 m
1 .68571 L
s
.99625 .74286 m
1 .74286 L
s
.99625 .77143 m
1 .77143 L
s
.99625 .8 m
1 .8 L
s
.99625 .82857 m
1 .82857 L
s
.99625 .88571 m
1 .88571 L
s
.99625 .91429 m
1 .91429 L
s
.99625 .94286 m
1 .94286 L
s
.99625 .97143 m
1 .97143 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
.14286 .28571 m
.42857 .28571 L
.42857 .42857 L
s
.42857 .71429 m
1 .71429 L
s
0 1 0 r
.42857 .42857 m
.42857 .42857 .1 0 365.73 arc
F
1 0 1 r
.71429 .57143 m
.71429 .57143 .14286 0 365.73 arc
F
1 .5 0 r
.92798 .71429 m
.92798 .77143 L
.64227 .77143 L
.64227 .71429 L
F
0 g
.01 w
.36064 .45064 m
.64631 .44578 L
s
.02 w
.36064 .45064 Mdot
.64631 .44578 Mdot
gsave
.46168 .53047 -64.9261 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.32667 .46168 -64.9261 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .42857 -64.9261 -3.86593 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(4) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.5 Mabswid
.46168 .53047 m
.42857 .42857 L
.32667 .46168 L
s
.46525 .50678 m
.46168 .53047 L
.44487 .5134 L
s
.34374 .44487 m
.32667 .46168 L
.35036 .46525 L
s
gsave
.89227 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.78513 .82143 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.78513 .71429 -60 -4.1 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(6) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.89227 .71429 m
.78513 .71429 L
.78513 .82143 L
s
.87084 .70357 m
.89227 .71429 L
.87084 .725 L
s
.77441 .8 m
.78513 .82143 L
.79584 .8 L
s
gsave
.80852 .52045 -58.9339 -4.63665 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.76527 .66567 -58.9339 -4.63665 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.71429 .57143 -58.9339 -4.63665 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 10 translate 1 -1 scale
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
63.000000 5.000000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.80852 .52045 m
.71429 .57143 L
.76527 .66567 L
s
.78458 .52122 m
.80852 .52045 L
.79477 .54007 L
s
.74565 .65192 m
.76527 .66567 L
.76449 .64172 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00016Q000`40O003h00Oogoo6goo003oOolK
Ool003Aoo`03001oogoo021oo`D0029oo`<0029oo`8002Eoo`<0029oo`03001oogoo029oo`8000Ao
o`00<goo00<007oo00008goo00<007ooOol08Woo00<007ooOol097oo00<007ooOol08goo00<007oo
Ool087oo00<007oo00008goo00<007oo00000goo000cOol00`00Ool0000SOol00`00Oomoo`0SOol0
0`00Oomoo`0ROol00`00Oomoo`0ROol4000SOol00`00Oomoo`0QOol00`00Ool00003Ool003=oo`03
001oo`0002=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo025oo`03001oo`00029oo`80
02Aoo`8000Aoo`00<goo00<007oo00008goo00<007ooOol08Woo00<007oo00008Woo00<007oo0000
97oo0P008Woo00<007ooOol08goo00<007ooOol00goo000dOol00`00Oomoo`0QOol2000UOol00`00
Oomoo`0ROol00`00Oomoo`0TOol00`00Oomoo`0POol3000TOol20003Ool00?mooa]oo`00ogoo6goo
003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol000moool000T000=oo`003goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001o
ogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo0P00ogoo1Goo0P00
0goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001o
ogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`800?moo`Eo
o`8000=oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`Eoo`03001oogoo005oo`003goo0P00ogoo1Goo0P000goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`800?moo`Eoo`8000=oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo0007Ool50003
Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo0?moo`Eo
o`03001oogoo005oo`000goo0`000goo00<007ooOol00goo0P00ogoo17oo0`000goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo
0?moo`Eoo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005o
o`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomo
o`01Ool000moo`800?moo`Eoo`8000=oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005o
o`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo0P00ogoo1Goo0P000goo000?
Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005o
o`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`800?moo`Eoo`8000=o
o`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eo
o`03001oogoo005oo`003goo0P00ogoo1Goo0P000goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eo
o`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo1Goo00<007ooOol00Goo0008
Ool00`00Ool00004Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`80
02=ood`009Aoo`<000=oo`0027oo00<007oo000017oo00<007ooOol0KGoo00<007ooOol0U7oo00<0
07ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`1]Ool00`00Oomoo`2DOol00`00Oomoo`01
Ool000Uoo`03001oogoo00=oo`03001oogoo06eoo`03001oogoo09Aoo`03001oogoo005oo`003goo
00<007ooOol0KGoo00<007ooOol0U7oo00<007ooOol00Goo000?Ool00`00Oomoo`1]Ool00`00Oomo
o`2DOol00`00Oomoo`01Ool000moo`03001oogoo06eoo`03001oogoo09Aoo`03001oogoo005oo`00
3goo0P00KWoo00<007ooOol0Tgoo0P000goo000?Ool00`00Oomoo`1]Ool00`00Oomoo`2DOol00`00
Oomoo`01Ool000moo`03001oogoo06eoo`03001oogoo09Aoo`03001oogoo005oo`003goo00<007oo
Ool0KGoo00<007ooOol0U7oo00<007ooOol00Goo000?Ool00`00Oomoo`1]Ool00`00Oomoo`2DOol0
0`00Oomoo`01Ool000moo`03001oogoo06Qoo``3h91oo`03001oogoo005oo`003goo00<007ooOol0
Hgoo50?PSGoo00<007ooOol00Goo000?Ool00`00Oomoo`1POolI0n2;Ool00`00Oomoo`01Ool000mo
o`80061ooad3h8Moo`8000=oo`003goo00<007ooOol0GWoo7`?PQgoo00<007ooOol00Goo000?Ool0
0`00Oomoo`1LOolR0n26Ool00`00Oomoo`01Ool000moo`03001oogoo05]oobD3h8Aoo`03001oogoo
005oo`003goo00<007ooOol0FWoo9`?PPgoo00<007ooOol00Goo000?Ool00`00Oomoo`1IOolY0n22
Ool00`00Oomoo`01Ool000moo`03001oogoo05Qoob/3h85oo`03001oogoo005oo`003goo0P00FGoo
:`?PP7oo0P000goo000?Ool00`00Oomoo`1GOol]0n20Ool00`00Oomoo`01Ool000moo`03001oogoo
05Moobd3h81oo`03001oogoo005oo`003goo00<007ooOol0Egoo;@?PP7oo00<007ooOol00Goo000?
Ool00`00Oomoo`1FOol_0n1oOol00`00Oomoo`01Ool000moo`03001oogoo05Iooc03h7ioo`03001o
ogoo005oo`003goo00<007ooOol0EGoo<@?POWoo00<007ooOol00Goo000?Ool00`00Oomoo`1EOola
0n1nOol00`00Oomoo`01Ool000moo`8005Iooc83h7aoo`8000=oo`003goo00<007ooOol0E7oo<`?P
OGoo00<007ooOol00Goo000?Ool00`00Oomoo`1DOolc0n1mOol00`00Oomoo`01Ool000moo`03001o
ogoo05=oocD3h7aoo`03001oogoo005oo`003goo00<007ooOol0Dgoo=@?PO7oo00<007ooOol00Goo
0007Ool50003Ool00`00Oomoo`1COole0n1lOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03
001oogoo05=oocD3h7aoo`03001oogoo005oo`002Goo00<007ooOol00goo0P00E7oo6@?P0P006P?P
NWoo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1COolF0n0300000`?P0003h00I0n0ZOol=
O1m5Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo05=ooa<3h0<000@3h08001T3
h2IooaEl7d5oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0Dgoo40?P0`001P?P0`006@?P
8goo6g`O?Woo00<007ooOol00Goo000?Ool00`00Oomoo`1COol40n000`000n03h0070n0200090n00
0`000n00000I0n0MOol2000SO1ljOol00`00Oomoo`01Ool000moo`03001oogoo05Aoo`83h0040003
h0?P0n1>000SO1liOol00`00Oomoo`01Ool000moo`03001oogoo05Aoo`030n0000?P0083h4l002El
7cMoo`03001oogoo005oo`003goo00<007ooOol0E7oo00@3h0000n03h0D00183h0030003h0?P01D3
h1aoo`9l7`8002Ml7cIoo`03001oogoo005oo`003goo0P00EGoo10000P?P0P0050?P00<000?P0n00
4`?P77oo;W`O<goo0P000goo000?Ool00`00Oomoo`1BOol4000J0n000`000n03h00C0n0KOol`O1lc
Ool00`00Oomoo`01Ool000moo`03001oogoo05=oo`03001oogoo00@001H3h0030003h0?P01<3h1Yo
oc9l7c9oo`03001oogoo005oo`003goo00<007ooOol0Dgoo00<007ooOol06`?P00<000?P0n004P?P
6Goo=7`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`1BOol01000Ool007oo6`?P00<000?P0n00
4@?P67oo=g`O<7oo00<007ooOol00Goo000?Ool00`00Oomoo`1BOol01@00Ool00000Ool06P?P00<0
00?P0n0040?P6Goo>7`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`1GOolK0n000`000n03h00?
0n0HOoliO1l_Ool00`00Oomoo`01Ool000moo`8005UooaX3h0030003h0?P00h3h1Qooc]l7beoo`80
00=oo`003goo00<007ooOol0F7oo6P?P00<000?P0n003P?P5goo?G`O;Goo00<007ooOol00Goo000?
Ool00`00Oomoo`1IOolJ0n000`000n03h00<0n0GOolnO1l]Ool00`00Oomoo`01Ool000moo`03001o
ogoo05YooaT3h0030003h0?P00/3h1Mood1l7baoo`03001oogoo005oo`003goo00<007ooOol0Fgoo
60?P00<000?P0n002P?P67oo@G`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`1LOolH0n000`00
0n03h0080n0HOom2O1l[Ool00`00Oomoo`01Ool000moo`03001oogoo05iooaH3h0040003h0?P0006
0n0IOom3O1lZOol00`00Oomoo`01Ool000moo`03001oogoo05mooa<3h0030003h0000083h0030003
h0?P0083h1]oodAl7bUoo`03001oogoo005oo`003goo0P00HGoo4`?P00D000?P0003h00000<3h1]o
odEl7bQoo`8000=oo`003goo00<007ooOol0Hgoo4@?P0`000P?P7Goo=G`O1`002W`O:7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`1UOol?0n03000NOoljO1l2000;O1lXOol00`00Oomoo`01Ool000mo
o`03001oogoo06Qoo`X3h0=oo`8001ioocQl7`800003O1l007`O00=l7`800003O1l007`O009l7bQo
o`03001oogoo005oo`003goo00<007ooOol0MWoo00<007ooOol077oo=W`O0P000W`O00<007`OO1l0
1G`O00<007`OO1l00W`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2DOoleO1l20004O1l00`00
O1ml7`04O1l00`00O1l00004O1lWOol00`00Oomoo`01Ool000moo`03001oogoo07Aoo`800003Ool0
07oo01]oocAl7`03001l7g`O00=l7`03001l7g`O00al7bMoo`03001oogoo005oo`003goo0P00Mgoo
00<007ooOol06goo<W`O0P005G`O9Woo0P000goo000?Ool00`00Oomoo`1eOol00`00Ool0000LOol`
O1l2000HO1lVOol00`00Oomoo`01Ool000moo`03001oogoo09=oobml7`8001Yl7bIoo`03001oogoo
005oo`003goo00<007ooOol0Tgoo;W`O00<007`OO1l06W`O9Woo00<007ooOol00Goo000?Ool00`00
Oomoo`2COol/O1l2000MO1lVOol00`00Oomoo`01Ool000moo`03001oogoo09=oobYl7`8001ml7bIo
o`03001oogoo005oo`0027oo0`0017oo00<007ooOol0Tgoo:7`O0P008G`O9Woo00<007ooOol00Goo
0008Ool00`00Oomoo`04Ool00`00Oomoo`2COolVO1l2000SO1lVOol00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`8009AoobEl7`03001l7g`O02=l7bAoo`<000=oo`002Goo00<007ooOol00goo00<0
07ooOol0Tgoo9W`O00<007`OO1l00W`O0`007G`O9Woo00<007ooOol00Goo0008Ool00`00Ool00004
Ool00`00Oomoo`2COolVO1l00`00O1ml7`04O1l00`00O1ml7`0KO1lVOol00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`03001oogoo09=oobMl7`03001l7g`O00=l7`03001l7g`O01]l7bIoo`03001o
ogoo005oo`003goo00<007ooOol0Tgoo9g`O00@007`OO1ml7`8001il7bIoo`03001oogoo005oo`00
3goo00<007ooOol0Tgoo:7`O00<007`OO1l00`007G`O9Woo00<007ooOol00Goo000?Ool00`00Oomo
o`2DOolWO1l00`00O1ml7`0PO1lVOol00`00Oomoo`01Ool000moo`8009EoobQl7`03001l7g`O01il
7bIoo`8000=oo`003goo00<007ooOol0U7oo:G`O00<007`OO1l07G`O9goo00<007ooOol00Goo000?
Ool00`00Oomoo`2DOolYO1l00`00O1ml7`0MO1lWOol00`00Oomoo`01Ool000moo`03001oogoo09Eo
obUl7`03001l7g`O01al7bMoo`03001oogoo005oo`003goo00<007ooOol0UGoo:G`O00<007`OO1l0
6g`O:7oo00<007ooOol00Goo000?Ool00`00Oomoo`2EOolZO1l00`00O1ml7`0JO1lXOol00`00Oomo
o`01Ool000moo`03001oogoo09IoobYl7`03001l7g`O01Ul7bQoo`03001oogoo005oo`003goo00<0
07ooOol0UWoo:W`O00<007`OO1l067`O:Goo00<007ooOol00Goo000?Ool2002HOolZO1l00`00O1ml
7`0GO1lXOol20003Ool000moo`03001oogoo09MoobYl7`03001l7g`O01Il7bYoo`03001oogoo005o
o`003goo00<007ooOol0Ugoo:g`O00<007`OO1l05G`O:Woo00<007ooOol00Goo000?Ool00`00Oomo
o`2GOol[O1l01@00O1ml7g`O00004W`O:goo00<007ooOol00Goo000?Ool00`00Oomoo`2HOol[O1l0
1000O1ml7`004G`O;7oo00<007ooOol00Goo000?Ool00`00Oomoo`2IOol[O1l00`00O1l0000AO1l/
Ool00`00Oomoo`01Ool000moo`03001oogoo09UoobQl7`06001l7g`O001l7`0047`O;Goo00<007oo
Ool00Goo000?Ool2002LOolWO1l200000g`O0000000@O1l/Ool20003Ool000moo`03001oogoo09ao
obQl7`<000ml7bioo`03001oogoo005oo`003goo00<007ooOol0WGoo:G`O00<007`OO1l00W`O0P00
27`O;goo00<007ooOol00Goo000?Ool00`00Oomoo`2MOol_O1l00`00O1ml7`06O1l_Ool00`00Oomo
o`01Ool000moo`03001oogoo09ioobil7`03001l7g`O00El7c1oo`03001oogoo005oo`003goo00<0
07ooOol0Wgoo;7`O00<007`O00001G`O<Goo00<007ooOol00Goo000?Ool00`00Oomoo`2POol[O1l0
1000O1l000000g`O<Woo00<007ooOol00Goo000?Ool00`00Oomoo`2ROol^O1ldOol00`00Oomoo`01
Ool000moo`800:Aoobal7cAoo`8000=oo`003goo00<007ooOol0Y7oo:G`O=goo00<007ooOol00Goo
000?Ool00`00Oomoo`2VOolUO1liOol00`00Oomoo`01Ool000moo`03001oogoo0:Moob=l7cYoo`03
001oogoo005oo`003goo00<007ooOol0ZGoo7g`O6Woo00<007ooOol07goo00<007ooOol00Goo0008
Ool20005Ool00`00Oomoo`2[OolKO1lMOol2000OOol00`00Oomoo`01Ool000Yoo`03001oogoo009o
o`03001oogoo0:iooaEl7b9oo`8001eoo`03001oogoo005oo`002Goo00<007ooOol00goo0P00KWoo
A@003G`OAP000goo000:Ool00`00Oomoo`02Ool00`00Oomoo`2VOolUON000`00ON1mh00GON02000:
ON0COol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo0:IoobEmh004001mh7gPON03
000AON020005ON0200000ggP001mh002ON0COol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03
001oogoo0:IoobEmh007001mh7gPON0007gP000047gP00<007gPON001ggP00<007gPON000WgP4goo
00<007ooOol00Goo000?Ool00`00Oomoo`2VOolUON001000ON1mh7gP0`006GgP00<007gP00000ggP
4goo00<007ooOol00Goo000?Ool00`00Oomoo`2VOolUON001@00ON1mh7gP00008GgP4goo00<007oo
Ool00Goo000?Ool00`00Oomoo`2VOolUON000`00ON1mh002ON02000OON0COol00`00Oomoo`01Ool0
00moo`03001oogoo0:IoobEmh003001mh7gP02=mh1=oo`03001oogoo005oo`003goo0P00Ygoo9GgP
00<007gPON008ggP4Woo0P000goo000?Ool00`00Oomoo`2VOolUON000`00ON1mh00SON0COol00`00
Oomoo`01Ool000moo`03001oogoo0:IoobEmh003001mh7gP02=mh1=oo`03001oogoo005oo`003goo
00<007ooOol0YWoo9GgP00<007gPON008ggP4goo00<007ooOol00Goo000?Ool00`00Oomoo`2VOolU
ON000`00ON1mh00SON0COol00`00Oomoo`01Ool000moo`03001oogoo0:IoobEmh003001mh7gP02=m
h1=oo`03001oogoo005oo`003goo00<007ooOol0YWoo9GgP00<007gPON008ggP4goo00<007ooOol0
0Goo000?Ool2002WOolUON000`00ON1mh00SON0BOol20003Ool000moo`03001oogoo0<]oo`03001o
ogoo03Ioo`03001oogoo005oo`003goo00<007ooOol0bgoo00<007ooOol0=Woo00<007ooOol00Goo
000?Ool00`00Oomoo`3;Ool00`00Oomoo`0fOol00`00Oomoo`01Ool000moo`03001oogoo0<]oo`03
001oogoo03Ioo`03001oogoo005oo`003goo00<007ooOol0bgoo00<007ooOol0=Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`3;Ool00`00Oomoo`0fOol00`00Oomoo`01Ool000moo`03001oogoo0<]o
o`03001oogoo03Ioo`03001oogoo005oo`003goo0P00bGoo00@007ooOol0009oo`03001oogoo039o
o`8000=oo`003goo00<007ooOol0bGoo00D007oo001oo`0003Ioo`03001oogoo005oo`003goo00<0
07ooOol0bGoo00D007oo001oo`0003Ioo`03001oogoo005oo`003goo00<007ooOol0bWoo0`00=goo
00<007ooOol00Goo000?Ool00`00Oomoo`3:Ool3000gOol00`00Oomoo`01Ool000moo`03001oogoo
0<]oo`04001oogooOol2000cOol00`00Oomoo`01Ool000moo`03001oogoo0=1oo`03001oogoo035o
o`03001oogoo005oo`003goo0P00dGoo00<007ooOol0<7oo0P000goo000?Ool00`00Oomoo`3?Ool0
0`00Ool0000bOol00`00Oomoo`01Ool000moo`03001oogoo0<moo`04001oo`00000aOol00`00Oomo
o`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000Uoo`<000=oo`03001oogoo
0?moo`Eoo`03001oogoo005oo`002Woo00<007ooOol00Woo00<007ooOol0ogoo1Goo00<007ooOol0
0Goo0008Ool40003Ool2003oOol4Ool30003Ool000Qoo`03001oo`0000Aoo`03001oogoo0?moo`Eo
o`03001oogoo005oo`002Goo0P0017oo00<007ooOol0ogoo1Goo00<007ooOol00Goo000:Ool00`00
Oomoo`02Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001o
ogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`800?moo`Eoo`8000=oo`003goo00<007ooOol0ogoo1Goo00<007ooOol0
0Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001o
ogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool2003oOol5Ool20003Ool000moo`03001oogoo0?moo`Eoo`03001o
ogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`800?moo`Eo
o`8000=oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo1Goo00<007ooOol00Goo000?Ool2003o
Ool5Ool20003Ool000moo`03001oogoo0?moo`Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo
1Goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol5Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`Eoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo1Goo00<007ooOol0
0Goo0008Ool00`00Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`01Ool000Yoo`03001oogoo009oool000T000=oo`00
27oo0P00ogoo4Goo0008Ool00`00Oomoo`3oOol@Ool000Qoo`<00?mooa1oo`00ogoo6goo003oOolK
Ool00001\
\>"],
  ImageRangeCache->{{{0, 281}, {281, 0}} -> {-1.40728, -2.34732, 0.026645, 
  0.026645}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["End "], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D", "Input"],
  " packages from ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " entirely. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{426, 636},
WindowMargins->{{22, Automatic}, {Automatic, 11}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 113, 3, 105, "Title",
  PageBreakAbove->True],
Cell[1847, 56, 191, 7, 85, "Subtitle"],
Cell[2041, 65, 123, 3, 48, "Subsubtitle",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[2189, 72, 41262, 1362, 296, 20057, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[43454, 1436, 41315, 1362, 296, 20166, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[84772, 2800, 41339, 1362, 296, 20154, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[126114, 4164, 41414, 1363, 296, 20156, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[167531, 5529, 41314, 1362, 296, 20157, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[208848, 6893, 41430, 1363, 296, 20168, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[250281, 8258, 41510, 1364, 296, 20159, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[291794, 9624, 41373, 1363, 296, 20151, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[333170, 10989, 41397, 1363, 296, 20163, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[374570, 12354, 41315, 1362, 296, 20170, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[415888, 13718, 41283, 1361, 296, 20155, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[457174, 15081, 41359, 1362, 296, 20162, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[498536, 16445, 41230, 1361, 296, 20162, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[539769, 17808, 41161, 1360, 296, 20162, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[580933, 19170, 41177, 1360, 296, 20166, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[622113, 20532, 41247, 1361, 296, 20163, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[663363, 21895, 41316, 1362, 296, 20151, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[704682, 23259, 41384, 1363, 296, 20170, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[746069, 24624, 41285, 1361, 296, 20161, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[787357, 25987, 41329, 1362, 296, 20152, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[828689, 27351, 41330, 1362, 296, 20149, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[870022, 28715, 41325, 1362, 296, 20160, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[911350, 30079, 41449, 1363, 296, 20163, 1096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[952802, 31444, 41287, 1362, 296, 20094, 1096, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]],
Cell[994104, 32809, 120, 3, 32, "Subsubtitle",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[994261, 32817, 100, 3, 53, "Section",
  PageBreakAbove->True],
Cell[994364, 32822, 393, 16, 166, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[994794, 32843, 111, 3, 33, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[994930, 32850, 98, 2, 47, "Subsection"],
Cell[995031, 32854, 595, 17, 92, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[995663, 32876, 95, 2, 31, "Subsection"],
Cell[995761, 32880, 1033, 25, 280, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[996843, 32911, 117, 3, 33, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[996985, 32918, 92, 2, 47, "Subsection"],
Cell[997080, 32922, 258, 11, 34, "Text"],
Cell[997341, 32935, 84, 2, 25, "Input"],
Cell[997428, 32939, 188, 4, 52, "Text"],
Cell[997619, 32945, 302, 9, 165, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[997958, 32959, 97, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[998080, 32965, 93, 2, 43, "Subsubsection"],
Cell[998176, 32969, 411, 7, 128, "Text"],
Cell[998590, 32978, 303, 7, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[998930, 32990, 121, 2, 43, "Subsubsection"],
Cell[999054, 32994, 368, 6, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[999459, 33005, 114, 2, 43, "Subsubsection"],
Cell[999576, 33009, 297, 5, 71, "Text"],
Cell[999876, 33016, 216, 6, 65, "Input"]
}, Open  ]],
Cell[1000107, 33025, 213, 6, 65, "Input"],

Cell[CellGroupData[{
Cell[1000345, 33035, 91, 2, 43, "Subsubsection"],
Cell[1000439, 33039, 271, 5, 71, "Text"],
Cell[1000713, 33046, 194, 6, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1000944, 33057, 92, 2, 43, "Subsubsection"],
Cell[1001039, 33061, 191, 4, 52, "Text"],
Cell[1001233, 33067, 120, 3, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1001402, 33076, 103, 2, 31, "Subsection"],
Cell[1001508, 33080, 171, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[1001704, 33088, 110, 2, 43, "Subsubsection"],
Cell[1001817, 33092, 302, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[1002144, 33102, 209, 5, 65, "Input"],
Cell[1002356, 33109, 59, 1, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1002464, 33116, 111, 2, 43, "Subsubsection"],
Cell[1002578, 33120, 279, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[1002882, 33129, 75, 2, 25, "Input"],
Cell[1002960, 33133, 402, 5, 70, "Print"]
}, Open  ]],
Cell[1003377, 33141, 659, 12, 167, "Text"],
Cell[1004039, 33155, 241, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1004317, 33165, 106, 2, 43, "Subsubsection"],
Cell[1004426, 33169, 269, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[1004720, 33178, 73, 2, 25, "Input"],
Cell[1004796, 33182, 368, 5, 70, "Print"]
}, Open  ]],
Cell[1005179, 33190, 532, 11, 148, "Text"],
Cell[1005714, 33203, 228, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1005979, 33213, 101, 2, 43, "Subsubsection"],
Cell[1006083, 33217, 205, 4, 52, "Text"],
Cell[1006291, 33223, 225, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1006553, 33233, 99, 2, 43, "Subsubsection"],
Cell[1006655, 33237, 428, 9, 92, "Text"],

Cell[CellGroupData[{
Cell[1007108, 33250, 58, 1, 25, "Input"],
Cell[1007169, 33253, 392, 5, 70, "Print"]
}, Open  ]],
Cell[1007576, 33261, 649, 12, 168, "Text"],
Cell[1008228, 33275, 242, 6, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1008507, 33286, 97, 2, 43, "Subsubsection"],
Cell[1008607, 33290, 201, 4, 52, "Text"],
Cell[1008811, 33296, 88, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1008948, 33304, 97, 2, 31, "Subsection"],
Cell[1009048, 33308, 503, 11, 92, "Text"],

Cell[CellGroupData[{
Cell[1009576, 33323, 197, 4, 45, "Input"],
Cell[1009776, 33329, 283, 4, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1010108, 33339, 99, 2, 31, "Subsection"],
Cell[1010210, 33343, 211, 7, 34, "Text"],

Cell[CellGroupData[{
Cell[1010446, 33354, 72, 2, 25, "Input"],
Cell[1010521, 33358, 38, 1, 70, "Output"]
}, Open  ]],
Cell[1010574, 33362, 360, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[1010959, 33378, 73, 2, 25, "Input"],
Cell[1011035, 33382, 751, 14, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1011847, 33403, 110, 3, 33, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[1011982, 33410, 95, 2, 47, "Subsection"],
Cell[1012080, 33414, 66, 0, 33, "Text"],
Cell[1012149, 33416, 523, 17, 277, "Input"],
Cell[1012675, 33435, 45, 0, 33, "Text"],
Cell[1012723, 33437, 702, 27, 457, "Input"],

Cell[CellGroupData[{
Cell[1013450, 33468, 99, 2, 25, "Input"],
Cell[1013552, 33472, 40963, 1359, 290, 20173, 1096, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1054564, 34837, 90, 2, 31, "Subsection"],
Cell[1054657, 34841, 193, 4, 52, "Text"],
Cell[1054853, 34847, 121, 3, 25, "Input"],
Cell[1054977, 34852, 127, 3, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1055153, 34861, 117, 3, 33, "Section",
  PageBreakAbove->True],
Cell[1055273, 34866, 424, 7, 90, "Text"],
Cell[1055700, 34875, 208, 4, 65, "Input"],
Cell[1055911, 34881, 163, 4, 33, "Text"],
Cell[1056077, 34887, 120, 3, 25, "Input"],
Cell[1056200, 34892, 187, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[1056412, 34900, 84, 2, 25, "Input"],
Cell[1056499, 34904, 183, 3, 63, "Message"]
}, Open  ]],
Cell[1056697, 34910, 304, 8, 72, "Text"],

Cell[CellGroupData[{
Cell[1057026, 34922, 72, 2, 25, "Input"],
Cell[1057101, 34926, 528, 11, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1057666, 34942, 90, 2, 25, "Input"],
Cell[1057759, 34946, 30816, 1077, 290, 14408, 868, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[1088624, 36029, 105, 3, 33, "Section",
  PageBreakAbove->True],
Cell[1088732, 36034, 218, 9, 34, "Text"],
Cell[1088953, 36045, 69, 2, 25, "Input"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

