(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    104427,       4140]*)
(*NotebookOutlinePosition[    127609,       4893]*)
(*  CellTagsIndexPosition[    121809,       4706]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mech2D", "Subtitle",
  GeneratedCell->True,
  CellTags->"Mech2D"],

Cell[TextData[{
  StyleBox["Absolute", "Input"],
  " is a setting for the ",
  StyleBox["Magnitude", "Input"],
  " option for ",
  StyleBox["Force", "Input"],
  " and ",
  StyleBox["Moment", "Input"],
  ".  ",
  StyleBox["Magnitude->", "Input"],
  StyleBox["Absolute", "Input"],
  " causes the magnitude of the applied load to be equal to the magnitude \
specified in the ",
  StyleBox["Force", "Input"],
  " or ",
  StyleBox["Moment", "Input"],
  " object."
}], "Text",
  GeneratedCell->True,
  CellTags->"Absolute"],

Cell[TextData[{
  StyleBox["Acceleration", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->Acceleration", "Input"],
  " causes such functions to seek a solution for the location, velocity, and \
acceleration of the current mechanism.  ",
  StyleBox["Acceleration[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the global acceleration vector ",
  Cell[BoxData[
      \(TraditionalForm\`{x\&\[DoubleDot], y\&\[DoubleDot]}\)]],
  " of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Acceleration"],

Cell[TextData[{
  StyleBox["AccelerationTerms[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the part of the right hand-term of the current acceleration \
constraint expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"AccelerationTerms"],

Cell[TextData[{
  StyleBox["AddLoads", "Input"],
  " is an option for ",
  StyleBox["SetLoads", "Input"],
  " that specifies whether the supplied loads are to replace the existing \
load vector or be added to the existing load vector.  The default setting is \
",
  StyleBox["AddLoads->", "Input"],
  StyleBox["False", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"AddLoads"],

Cell[TextData[{
  StyleBox["Alpha[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the angular acceleration of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Alpha"],

Cell[TextData[{
  StyleBox["Angle", "Input"],
  " is an option for ",
  StyleBox["Mech", "Input"],
  " graphics functions that specifies the range of the revolution angle of \
revolved objects.  ",
  StyleBox["Angle->{", "Input"],
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " revolves the object from ",
  StyleBox["a",
    FontSlant->"Italic"],
  " to ",
  StyleBox["b",
    FontSlant->"Italic"],
  " radians.  The default setting is ",
  StyleBox["Angle->{", "Input"],
  "0, 2\[Pi]",
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["Angle[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the direction angle of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " relative to the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  "-axis."
}], "Text",
  CellTags->"Angle"],

Cell[TextData[{
  StyleBox["Angular", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SetSymbols", "Input"],
  " that causes all subsequently built models to represent angular velocity \
and acceleration explicitly in their coordinates."
}], "Text",
  GeneratedCell->True,
  CellTags->"Angular"],

Cell[TextData[{
  StyleBox["Applied", "Input"],
  " is the default setting for the ",
  StyleBox["Type", "Input"],
  " option for ",
  StyleBox["Loads", "Input"],
  ".  Specifying ",
  StyleBox["Type->", "Input"],
  StyleBox["Applied", "Input"],
  " causes ",
  StyleBox["Loads", "Input"],
  " to return the total external load applied to a body."
}], "Text",
  GeneratedCell->True,
  CellTags->"Applied"],

Cell[TextData[{
  StyleBox["ArcLength[", "Input"],
  StyleBox["spline",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a one-dimensional cubic  ",
  StyleBox["SplineFunction", "Input"],
  " object approximately representing the arc length of the given ",
  StyleBox["spline",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["spline",
    FontSlant->"Italic"],
  " must be ",
  StyleBox["SplineFunction", "Input"],
  " object such as is returned by ",
  StyleBox["SplineFit", "Input"],
  "."
}], "Text",
  CellTags->"ArcLength"],

Cell[TextData[{
  StyleBox["Arrow[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["len",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a graphics object representing an arrow of length ",
  StyleBox["len",
    FontSlant->"Italic"],
  " emanating from the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and pointing in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Reverse->True", "Input"],
  " causes the arrow to terminate at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and point in the opposite direction.  ",
  StyleBox["HeadSize->", "Input"],
  StyleBox["number",
    FontSlant->"Italic"],
  " specifies the width of the head of the arrow.  ",
  StyleBox["Magnitude->Relative", "Input"],
  " causes the length of the arrow to be equal to ",
  StyleBox["len",
    FontSlant->"Italic"],
  " times the length of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Arrow"],

Cell[TextData[{
  StyleBox["Bar[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["c",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a rectangular bar of width ",
  Cell[BoxData[
      \(TraditionalForm\`2  c\)]],
  " spanning from the origin to the end of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Bar", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " option."
}], "Text",
  CellTags->"Bar"],

Cell[TextData[{
  StyleBox["Body[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is used to define points and properties on a ",
  StyleBox["Mech", "Input"],
  " body.  ",
  StyleBox["Body", "Input"],
  " returns a ",
  StyleBox["SysBody", "Input"],
  " data object containing information to be passed to ",
  StyleBox["SetBodies", "Input"],
  ".  The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " must be a positive integer specifying an index number for the body that \
is used to reference the body in other ",
  StyleBox["Mech", "Input"],
  " functions.  ",
  StyleBox["Body", "Input"],
  " accepts the ",
  StyleBox["PointList", "Input"],
  ", ",
  StyleBox["InitialGuess", "Input"],
  ", ",
  StyleBox["Mass", "Input"],
  ", ",
  StyleBox["Inertia", "Input"],
  ", and ",
  StyleBox["Centroid", "Input"],
  " options.  The default setting for all options is ",
  StyleBox["Automatic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Body"],

Cell[TextData[{
  StyleBox["BodyEnergy[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the kinetic energy possessed by body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"BodyEnergy"],

Cell[TextData[{
  StyleBox["Box[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " generates a box with two opposing corners located at local points ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  The sides of the box are aligned with the local axes of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Box", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"Box"],

Cell[TextData[{
  StyleBox["BuildMech", "Input"],
  " is an option for ",
  StyleBox["SetConstraints", "Input"],
  " that specifies which parts of the mathematical mechanism model will be \
built immediately.  The default setting is ",
  StyleBox["BuildMech->", "Input"],
  StyleBox["Location", "Input"],
  ".  ",
  StyleBox["BuildMech[", "Input"],
  "level",
  StyleBox["]", "Input"],
  " is used to force a build of the mechanism equations to the specified \
level at any time. level can be ",
  StyleBox["None", "Input"],
  ", ",
  StyleBox["Location", "Input"],
  ", ",
  StyleBox["Velocity", "Input"],
  ", ",
  StyleBox["Acceleration", "Input"],
  ", ",
  StyleBox["Static", "Input"],
  ", ",
  StyleBox["Kinematic", "Input"],
  ", or ",
  StyleBox["Dynamic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"BuildMech"],

Cell[TextData[{
  StyleBox["CamPlot[", "Input"],
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["min",
    FontSlant->"Italic"],
  ", ",
  StyleBox["max",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns a ",
  StyleBox["SysPlot", "Input"],
  " object representing the cam profile, a planar curve, that is defined by \
the locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ".  The coordinates of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"CamPlot"],

Cell[TextData[{
  StyleBox["CamToCam1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " models two cam profiles that work against each other.  The locus of ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " defines the first cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", while the locus of ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " defines the second cam surface as a function of the symbol ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " & ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " must be defined as functions of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " & beta).  ",
  StyleBox["CamToCam1", "Input"],
  " enforces that the surfaces of the two cam profiles lie tangent to each \
other.  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToCam1"],

Cell[TextData[{
  StyleBox["CamToCircle1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a cam surface with a circular follower.  The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ").  ",
  StyleBox["CamToCircle1", "Input"],
  " enforces that the surface of the cam profile lies tangent to a circle of \
specified radius centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".  The circular follower lies on the left side of the cam profile if ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " is positive, when traveling along the locus in the direction of \
increasing ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToCircle1"],

Cell[TextData[{
  StyleBox["CamToLine1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a cam surface with a flat follower.  The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ").  ",
  StyleBox["CamToLine1", "Input"],
  " enforces that the surface of the cam profile lies tangent to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToLine1"],

Cell[TextData[{
  StyleBox["CamToPoint1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a cam surface with a point follower.  The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ").  ",
  StyleBox["CamToPoint1", "Input"],
  " enforces that ",
  StyleBox["point",
    FontSlant->"Italic"],
  " lies on the surface of the cam profile.  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToPoint1"],

Cell[TextData[{
  StyleBox["Centrifugal[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the vector of centrifugal forces associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Centrifugal"],

Cell[TextData[{
  StyleBox["Centroid", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that specifies the location vector of a body's centroid, in the body's \
local coordinates.  The default setting is ",
  StyleBox["Centroid->", "Input"],
  StyleBox["Automatic", "Input"],
  ".  ",
  StyleBox["Centroid[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a point object corresponding to the centroid of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Centroid"],

Cell[TextData[{
  StyleBox["CheckRules", "Input"],
  " is an option for ",
  StyleBox["SolveMech", "Input"],
  " that determines whether solution rules passed into ",
  StyleBox["SolveMech", "Input"],
  " are assumed to be correct, or are checked against the constraints to see \
if they constitute a valid solution.  The default setting is ",
  StyleBox["CheckRules->", "Input"],
  StyleBox["True", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"CheckRules"],

Cell[TextData[{
  StyleBox["CheckSystem[", "Input"],
  StyleBox["]", "Input"],
  " checks the current model for undefined variables or inconsistent \
constraint sets.  ",
  StyleBox["CheckSystem", "Input"],
  " returns ",
  StyleBox["True", "Input"],
  " if all is well, ",
  StyleBox["False", "Input"],
  " and an error message otherwise."
}], "Text",
  GeneratedCell->True,
  CellTags->"CheckSystem"],

Cell[TextData[{
  StyleBox["ClearMech[", "Input"],
  StyleBox["]", "Input"],
  " clears the entire ",
  StyleBox["Mech", "Input"],
  " database and resets all internal variables to their initial states."
}], "Text",
  GeneratedCell->True,
  CellTags->"ClearMech"],

Cell[TextData[{
  StyleBox["ClearParameters[", "Input"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " deletes the rules from the current parameters list that are associated \
with the given ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"ClearParameters"],

Cell[TextData[{
  StyleBox["Closed", "Input"],
  " is a setting for the ",
  StyleBox["EndConditions", "Input"],
  " option for ",
  StyleBox["SplineFit", "Input"],
  " that specifies that the slope and curvature of the spline at the  two \
ends shall be equal."
}], "Text",
  GeneratedCell->True,
  CellTags->"Closed"],

Cell[TextData[{
  StyleBox["CompositeInertia[{", "Input"],
  StyleBox["centroid1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mass1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertia1",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ..., ",
  StyleBox["{", "Input"],
  StyleBox["centroidn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["massn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertian",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns the list, ",
  StyleBox["{", "Input"],
  StyleBox["centroid",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mass",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertia",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", of the inertia properties of a composite body made up of the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " specified subcomponents."
}], "Text",
  CellTags->"CompositeInertia"],

Cell[TextData[{
  StyleBox["Constraint[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["equation",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{{", "Input"],
  StyleBox["extravar",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "..",
  StyleBox["}]", "Input"],
  " returns a constraint object that contains a user-defined constraint \
equation(s).  ",
  StyleBox["equation",
    FontSlant->"Italic"],
  " can be a single equation or a list of equations, each of which must have \
the head ",
  StyleBox["Equal", "Input"],
  ".  The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "'s are an optional list of the body numbers of those bodies that are \
constrained by the equations.  ",
  StyleBox["{", "Input"],
  StyleBox["extravar",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " (or ",
  StyleBox["{{", "Input"],
  StyleBox["extravar",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "..",
  StyleBox["}", "Input"],
  " ) is an optional list of symbols that appear in the model (and their \
associated initial guesses), that are added to the model's dependent variable \
list and solved for."
}], "Text",
  CellTags->"Constraint"],

Cell[TextData[{
  StyleBox["ConstraintCorrection", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  ". With ",
  StyleBox["ConstraintCorrection->", "Input"],
  StyleBox["True", "Input"],
  ", each body's location and velocity are corrected at each integration step \
so as to be consistent with the constraints."
}], "Text",
  GeneratedCell->True,
  CellTags->"ConstraintCorrection"],

Cell[TextData[{
  StyleBox["Constraints[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the list of constraint expressions that were generated by \
constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ".  The expressions returned are assumed to be set equal to zero to satisfy \
the constraint."
}], "Text",
  GeneratedCell->True,
  CellTags->"Constraints"],

Cell[TextData[{
  StyleBox["Coordinates", "Input"],
  " is an option for ",
  StyleBox["Reaction", "Input"],
  " that specifies whether the force and moment vectors returned are to be in \
",
  StyleBox["Global", "Input"],
  " or ",
  StyleBox["Local", "Input"],
  " coordinates.  The default setting is ",
  StyleBox["Coordinates->", "Input"],
  StyleBox["Global", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Coordinates"],

Cell[TextData[{
  StyleBox["Corrector", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ". The ",
  StyleBox["Corrector", "Input"],
  " method uses an Adams-Moulton predictor-corrector integration algorithm."
}], "Text",
  GeneratedCell->True,
  CellTags->"Corrector"],

Cell[TextData[{
  StyleBox["CoupleSystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetCouple", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"CoupleSystem"],

Cell[TextData[{
  StyleBox["Cross[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the cross product of the direction vectors of the two ",
  StyleBox["Mech", "Input"],
  " vector objects."
}], "Text",
  GeneratedCell->True,
  CellTags->"Cross"],

Cell[TextData[{
  StyleBox["Cubic", "Input"],
  " is the default setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ".  ",
  StyleBox["Cubic", "Input"],
  " specifies a cubic approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Cubic"],

Cell[TextData[{
  StyleBox["CutOff", "Input"],
  " is an option for ",
  StyleBox["Force", "Input"],
  " that specifies a cutoff value for the magnitude of an applied load.  ",
  StyleBox["If", "Input"],
  " ",
  StyleBox["CutOff", "Input"],
  " is nonzero, The magnitude of the load drops to one half of the specified \
magnitude when the length of the direction vector of the load is equal to ",
  StyleBox["CutOff", "Input"],
  ", and the magnitude of the load drops to zero when the length of the \
direction vector is zero."
}], "Text",
  CellTags->"CutOff"],

Cell[TextData[{
  StyleBox["D2DistanceDT2[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the second time derivative of the absolute distance between the \
two points."
}], "Text",
  GeneratedCell->True,
  CellTags->"D2DistanceDT2"],

Cell[TextData[{
  StyleBox["DDistanceDT[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the time derivative of the absolute distance between the two \
points."
}], "Text",
  GeneratedCell->True,
  CellTags->"DDistanceDT"],

Cell[TextData[{
  StyleBox["Diagnostics", "Input"],
  " is an element of the ",
  StyleBox["MakeRules", "Input"],
  " option setting for ",
  StyleBox["SolveFree", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Diagnostics"],

Cell[TextData[{
  StyleBox["DirectedDistance1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", measured in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"DirectedDistance1"],

Cell[TextData[{
  StyleBox["DirectedPosition2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus a vector that is parallel to ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units long.  Constrains 2 DOF."
}], "Text",
  CellTags->"DirectedPosition2"],

Cell[TextData[{
  StyleBox["Direction[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the direction vector of a ",
  StyleBox["Mech", "Input"],
  " vector object in global coordinates."
}], "Text",
  CellTags->"Direction"],

Cell[TextData[{
  StyleBox["Distance[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the absolute distance between the two points."
}], "Text",
  GeneratedCell->True,
  CellTags->"Distance"],

Cell[TextData[{
  StyleBox["Dynamic", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->", "Input"],
  StyleBox["Dynamic", "Input"],
  " causes such functions to seek a solution for the location, velocity, \
acceleration, and dynamic loading of the current mechanism.  ",
  StyleBox["Dynamic", "Input"],
  " is also a setting for the ",
  StyleBox["Type", "Input"],
  " option for ",
  StyleBox["Loads", "Input"],
  ".  Specifying ",
  StyleBox["Type->", "Input"],
  StyleBox["Dynamic", "Input"],
  " causes ",
  StyleBox["Loads", "Input"],
  " to return the total inertial load on a body."
}], "Text",
  GeneratedCell->True,
  CellTags->"Dynamic"],

Cell[TextData[{
  StyleBox["Edge[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " generates n-1 lines passing from each local point to the next on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "}.  ",
  StyleBox["Edge[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts1",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts2",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ...",
  StyleBox["]", "Input"],
  " generates several sequences of lines."
}], "Text",
  CellTags->"Edge"],

Cell[TextData[{
  StyleBox["EndConditions", "Input"],
  " is an option for ",
  StyleBox["SplineFit", "Input"],
  " that is used to specify the end conditions of the spline.  ",
  StyleBox["EndConditions", "Input"],
  " can be either ",
  StyleBox["Natural", "Input"],
  ", ",
  StyleBox["Closed", "Input"],
  ", or a list of two vectors, specifying the tangency direction at the \
beginning and end of the spline, respectively."
}], "Text",
  GeneratedCell->True,
  CellTags->"EndConditions"],

Cell[TextData[{
  StyleBox["Euler", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SetSymbols", "Input"],
  " that causes all subsequently built models to use Euler parameters and \
their derivatives to represent angular orientation and velocity."
}], "Text",
  CellTags->"Euler"],

Cell[TextData[{
  StyleBox["EulerParameters[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the Euler parameters associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", {e",
  StyleBox["i",
    FontSlant->"Italic"],
  ", e",
  StyleBox["j",
    FontSlant->"Italic"],
  "}."
}], "Text",
  CellTags->"EulerParameters"],

Cell[TextData[{
  StyleBox["Faces", "Input"],
  " is an option for ",
  StyleBox["Mech", "Input"],
  " graphics functions that specifies whether faces of polygons should be \
drawn.  The default setting is ",
  StyleBox["Faces->", "Input"],
  StyleBox["True", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Faces"],

Cell[TextData[{
  StyleBox["Facet[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " generates a filled polygon with vertices at each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "}.  ",
  StyleBox["Facet[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts1",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts2",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ...",
  StyleBox["]", "Input"],
  " generates several polygons."
}], "Text",
  CellTags->"Facet"],

Cell[TextData[{
  StyleBox["FindSwitchTime[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["snum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " seeks the point in time at which the the two constraints in ",
  StyleBox["TimeSwitch", "Input"],
  " number ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " separated by switch time number ",
  StyleBox["snum",
    FontSlant->"Italic"],
  " are both satisfied.  ",
  StyleBox["FindSwitchTime[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["snum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["TangentConstraint->True]", "Input"],
  " finds the switch point when the two constraints in question approach each \
other tangentially.  ",
  StyleBox["FindSwitchTime", "Input"],
  " also accepts the ",
  StyleBox["RequiredEquations", "Input"],
  " option."
}], "Text",
  CellTags->"FindSwitchTime"],

Cell[TextData[{
  StyleBox["FindTime[", "Input"],
  StyleBox["eqn",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " seeks the solution to the current model that satisfies the given equation \
",
  StyleBox["eqn",
    FontSlant->"Italic"],
  " with time treated as a dependent variable. The equation must have the \
head ",
  StyleBox["Equal", "Input"],
  ".  ",
  StyleBox["FindTime", "Input"],
  " accepts the ",
  StyleBox["Solution", "Input"],
  " option to specify what level of solution is needed."
}], "Text",
  GeneratedCell->True,
  CellTags->"FindTime"],

Cell[TextData[{
  StyleBox["FitDegree", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  " that specifies the degree of polynomial that is used to approximate each \
section of the integrand at each time step.  Valid settings for ",
  StyleBox["FitDegree", "Input"],
  " are ",
  StyleBox["Linear", "Input"],
  ", ",
  StyleBox["Quadratic", "Input"],
  ", ",
  StyleBox["Cubic", "Input"],
  ", and ",
  StyleBox["Quartic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"FitDegree"],

Cell[TextData[{
  StyleBox["Force[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mag",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a ",
  StyleBox["Mech", "Input"],
  " load object that applies a force to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " along the specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Force", "Input"],
  " accepts the ",
  StyleBox["Magnitude", "Input"],
  " and ",
  StyleBox["CutOff", "Input"],
  " options."
}], "Text",
  GeneratedCell->True,
  CellTags->"Force"],

Cell[TextData[{
  StyleBox["Free", "Input"],
  " is a setting for the ",
  StyleBox["Time", "Input"],
  " option for ",
  StyleBox["SetCouple", "Input"],
  " that is used to omit the time specification so that time becomes a \
dependent variable.  ",
  StyleBox["If", "Input"],
  " ",
  StyleBox["SetCouple", "Input"],
  " is passed ",
  StyleBox["Time->Free", "Input"],
  " instead of ",
  StyleBox["Time->", "Input"],
  StyleBox["number",
    FontSlant->"Italic"],
  ", time is considered to be a dependent variable to be solved for."
}], "Text",
  GeneratedCell->True,
  CellTags->"Free"],

Cell[TextData[{
  StyleBox["FreeSystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetFree", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"FreeSystem"],

Cell[TextData[{
  StyleBox["FunctionOfTime", "Input"],
  " is an option for several ",
  StyleBox["Mech", "Input"],
  " functions that causes returned ",
  StyleBox["InterpolatingFunction", "Input"],
  " objects to be explicitly functions of the current time variable."
}], "Text",
  GeneratedCell->True,
  CellTags->"FunctionOfTime"],

Cell[TextData[{
  StyleBox["Generalized[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the list of generalized forces, or Lagrange multipliers, ",
  StyleBox["{Lmb1", "Input"],
  ", ",
  StyleBox["Lmb2", "Input"],
  ", ...",
  StyleBox["}", "Input"],
  " associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " in the current model.  ",
  StyleBox["Generalized", "Input"],
  " is also an element of the ",
  StyleBox["MakeRules", "Input"],
  " option setting.  Specifying ",
  StyleBox["MakeRules->{", "Input"],
  "..., ",
  StyleBox["Generalized", "Input"],
  ", ...",
  StyleBox["}", "Input"],
  " causes the generalized forces to be included in the interpolated rules \
returned."
}], "Text",
  CellTags->"Generalized"],

Cell[TextData[{
  StyleBox["Global", "Input"],
  " is a setting for the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"Global"],

Cell[TextData[{
  StyleBox["Gravity[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["G",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a list of ",
  StyleBox["Mech", "Input"],
  " load objects that apply a force of magnitude ",
  StyleBox["mass\[Times]G",
    FontSlant->"Italic"],
  " in the direction of the specified vector to the centroid of each body in \
the current model."
}], "Text",
  CellTags->"Gravity"],

Cell[TextData[{
  StyleBox["HeadSize", "Input"],
  " is an option for ",
  StyleBox["Arrow", "Input"],
  " that specifies the width of the arrowhead."
}], "Text",
  GeneratedCell->True,
  CellTags->"HeadSize"],

Cell[TextData[{
  StyleBox["IMatrix", "Input"],
  " returns the 2D identity matrix ",
  StyleBox["{{1, 0}, {0, 1}}", "Input"],
  "."
}], "Text",
  CellTags->"IMatrix"],

Cell[TextData[{
  StyleBox["IncludedAngle[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the positive angle between the global direction vectors of the \
two ",
  StyleBox["Mech", "Input"],
  " vector objects."
}], "Text",
  GeneratedCell->True,
  CellTags->"IncludedAngle"],

Cell[TextData[{
  StyleBox["Inertia", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that specifies the centroidal rotational inertia of a body.  The polar \
moment of inertia is specified by a scalar.  The default setting is ",
  StyleBox["Inertia", "Input"],
  " ->",
  StyleBox["Automatic", "Input"],
  ".  ",
  StyleBox["Inertia[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the inertia of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Inertia"],

Cell[TextData[{
  StyleBox["InitialCondition", "Input"],
  " is an option for ",
  StyleBox["Mech", "Input"],
  " functions that specifies initial conditions to be used in subsequent \
solutions.  ",
  StyleBox["InitialCondition", "Input"],
  " should specify rules giving the values of current system dependent \
variables, or current parameters, or time.  The default, ",
  StyleBox["InitialCondition->", "Input"],
  StyleBox["Automatic", "Input"],
  ", takes the initial conditions from the current default initial guess, ",
  StyleBox["LastSolve[", "Input"],
  StyleBox["]", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"InitialCondition"],

Cell[TextData[{
  StyleBox["InitialGuess", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " and other ",
  StyleBox["Mech", "Input"],
  " functions.  With ",
  StyleBox["Body", "Input"],
  ", ",
  StyleBox["InitialGuess", "Input"],
  " specifies the initial guesses that are used for a body's location \
coordinates.  The default setting is ",
  StyleBox["InitialGuess->Automatic", "Input"],
  ".  Guesses are given as a nested list of numbers of the form ",
  StyleBox["InitialGuess", "Input"],
  " -> ",
  StyleBox["{{", "Input"],
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["Th",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "."
}], "Text",
  CellTags->"InitialGuess"],

Cell[TextData[{
  StyleBox["Interference", "Input"],
  " is an option for ",
  StyleBox["Involute", "Input"],
  ".  ",
  StyleBox["Interference->", "Input"],
  StyleBox["True", "Input"],
  " specifies that the involute locus shall blend into a straight line from \
the point where the involute meets the base circle to the center of the base \
circle."
}], "Text",
  GeneratedCell->True,
  CellTags->"Interference"],

Cell[TextData[{
  StyleBox["IntersectionPoint[", "Input"],
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the point of intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " in global coordinates."
}], "Text",
  CellTags->"IntersectionPoint"],

Cell[TextData[{
  StyleBox["Involute[", "Input"],
  StyleBox["sym",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["baseradius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["pitchradius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  "  returns the equation of an involute gear tooth as a function of the \
parameter ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".  The involute has a base circle of ",
  StyleBox["baseradius",
    FontSlant->"Italic"],
  " centered at {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "}.  The involute profile is rotationally located such that the point where \
the profile intersects the pitch circle lies on a ray that passes through {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "} in the direction of ",
  StyleBox["angle",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Involute", "Input"],
  " accepts the ",
  StyleBox["Interference", "Input"],
  " option."
}], "Text",
  CellTags->"Involute"],

Cell[TextData[{
  StyleBox["Jacobian[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the submatrix of the current Jacobian associated with constraint \
",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " and body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Jacobian"],

Cell[TextData[{
  StyleBox["KillMech[]", "Input"],
  " completely removes the ",
  StyleBox["Mech", "Input"],
  " packages from the current Mathematica session.  All of the symbols in the \
Mech2D` contexts are removed, as well as the contexts themselves."
}], "Text",
  CellTags->"KillMech"],

Cell[TextData[{
  StyleBox["Kinematic", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->", "Input"],
  StyleBox["Kinematic", "Input"],
  " causes such functions to seek a solution for the location, velocity, and \
velocity- dependent loading of the current model."
}], "Text",
  GeneratedCell->True,
  CellTags->"Kinematic"],

Cell[TextData[{
  StyleBox["LambdaGuess", "Input"],
  " is an option for ",
  StyleBox["SetLoads", "Input"],
  " that specifies the initial guesses for the Lagrange multipliers.  ",
  StyleBox["LambdaGuess", "Input"],
  " can be set to a number that specifies the same guess for all Lagrange \
multipliers, or a list of numbers that specify guesses for each.  The default \
setting is ",
  StyleBox["LambdaGuess->", "Input"],
  StyleBox["Automatic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"LambdaGuess"],

Cell[TextData[{
  StyleBox["LastSolve[", "Input"],
  StyleBox["]", "Input"],
  " returns the last solution rule returned by ",
  StyleBox["SolveMech", "Input"],
  ".  The values returned by ",
  StyleBox["LastSolve[", "Input"],
  StyleBox["]", "Input"],
  " are used as the initial guesses at the next invocation of ",
  StyleBox["SolveMech", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"LastSolve"],

Cell[TextData[{
  StyleBox["Line[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is a ",
  StyleBox["Mech", "Input"],
  " data object that specifies two local points on body bnum that define a \
line.  The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be point numbers (positive integers) referencing points that were \
defined with ",
  StyleBox["SetBodies", "Input"],
  " or they can be coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\({x, y}\ \)\)]],
  "of points in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Line[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " uses two ",
  StyleBox["Mech", "Input"],
  " point objects to define the line."
}], "Text",
  CellTags->"Line"],

Cell[TextData[{
  StyleBox["Linear", "Input"],
  " is a setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ". ",
  StyleBox["Linear", "Input"],
  " specifies a linear approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Linear"],

Cell[TextData[{
  StyleBox["Load[", "Input"],
  StyleBox["sym",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mag",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a ",
  StyleBox["Mech", "Input"],
  " load object that applies a load of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " directly to coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Load"],

Cell[TextData[{
  StyleBox["Loads[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the total external load applied to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["Type->", "Input"],
  StyleBox["Reaction", "Input"],
  " option may be specified to return the total reaction force applied by all \
constraints to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Type->", "Input"],
  StyleBox["Dynamic", "Input"],
  " returns the total inertial load on the body."
}], "Text",
  GeneratedCell->True,
  CellTags->"Loads"],

Cell[TextData[{
  StyleBox["Local", "Input"],
  " is a setting for the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"Local"],

Cell[TextData[{
  StyleBox["LocalAxes[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a graphics object placing local ",
  StyleBox["x-y",
    FontSlant->"Italic"],
  " axes of specified ",
  StyleBox["size",
    FontSlant->"Italic"],
  " at the origin of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["LocalAxes[{", "Input"],
  StyleBox["bnum1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " places axes on several bodies.  ",
  StyleBox["LocalAxes[All", "Input"],
  ", ",
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " places axes on all bodies in the current model."
}], "Text",
  CellTags->"LocalAxes"],

Cell[TextData[{
  StyleBox["Location", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->Location", "Input"],
  " causes such functions to seek a solution for the location of the current \
mechanism.  ",
  StyleBox["Location[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the global coordinates, {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "} of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Location"],

Cell[TextData[{
  StyleBox["LockMech[", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds a solution to the mechanism equations at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and then embeds the numerical values of the dependent variables into the \
mechanism equations so that they cannot be changed until a new system is \
built with ",
  StyleBox["SetConstraints", "Input"],
  ".  ",
  StyleBox["LockMech", "Input"],
  " accepts the ",
  StyleBox["Solution", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"LockMech"],

Cell[TextData[{
  StyleBox["LocusPlot[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{{", "Input"],
  StyleBox["rules1",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["rules2",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ..., ",
  StyleBox["{", "Input"],
  StyleBox["rulesn",
    FontSlant->"Italic"],
  StyleBox["}}]", "Input"],
  " returns a graphics primitive representing the locus of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " as it moves through successive locations specified by the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"LocusPlot"],

Cell[TextData[{
  StyleBox["Magnitude[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the length of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " or ",
  StyleBox["Mech", "Input"],
  " vector object.  ",
  StyleBox["Magnitude", "Input"],
  " is also an option for ",
  StyleBox["Force", "Input"],
  " and ",
  StyleBox["Moment", "Input"],
  ".  Setting ",
  StyleBox["Magnitude->Relative", "Input"],
  " causes the magnitude of the applied load to be equal to the length of the \
load vector times the given magnitude.  The default setting is ",
  StyleBox["Magnitude->Absolute", "Input"],
  "."
}], "Text",
  CellTags->"Magnitude"],

Cell[TextData[{
  StyleBox["MakeRules", "Input"],
  " is an option to several ",
  StyleBox["Mech", "Input"],
  " functions that is used to specify which dependent variables to generate ",
  
  StyleBox["InterpolatingFunction", "Input"],
  "'s for.  The default: ",
  StyleBox["MakeRules->{Parameters, Location, Generalized}", "Input"],
  " will generate rules for the location coordinates, (",
  StyleBox["X2", "Input"],
  ", ",
  StyleBox["Y3", "Input"],
  ", ...), and the generalized forces, (",
  StyleBox["Lmb1", "Input"],
  ", ",
  StyleBox["Lmb2", "Input"],
  ", ...), if they are present, and also any system parameters.  Settings for \
",
  StyleBox["MakeRules", "Input"],
  " may be any subset of: ",
  StyleBox[
  "{Parameters, Location, Velocity, Acceleration, Generalized}", "Input"],
  "."
}], "Text",
  CellTags->"MakeRules"],

Cell[TextData[{
  StyleBox["Mass", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that specifies the mass of a body.  The default setting is ",
  StyleBox["Mass->", "Input"],
  StyleBox["Automatic", "Input"],
  ".  ",
  StyleBox["Mass[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the mass of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Mass"],

Cell[TextData[{
  StyleBox["MassMatrix[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the submatrix of the current system mass matrix associated with \
body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"MassMatrix"],

Cell[TextData[{
  StyleBox["MaxError", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  " that is used to specify the maximum allowable estimated error in any \
dependent variable in a single time step.  The default setting is ",
  StyleBox["MaxError->", "Input"],
  "0.0001."
}], "Text",
  GeneratedCell->True,
  CellTags->"MaxError"],

Cell[TextData[{
  StyleBox["Mech", "Input"],
  " is the symbol name for all Mechanical Systems Pack general messages."
}], "Text",
  GeneratedCell->True,
  CellTags->"Mech"],

Cell[TextData[{
  StyleBox["MechPrimitive", "Input"],
  " is the head of the ",
  StyleBox["Graphics", "Input"],
  " primitive generating functions that are returned by some ",
  StyleBox["Mech", "Input"],
  " graphics functions.  ",
  StyleBox["MechPrimitive", "Input"],
  " functions will evaluate to a list of Mathematica graphics primitives when \
all of the ",
  StyleBox["Mech", "Input"],
  " system symbols on which they depend are replaced by numbers."
}], "Text",
  GeneratedCell->True,
  CellTags->"MechPrimitive"],

Cell[TextData[{
  StyleBox["Moment[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mag",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a load object that applies a moment of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Moment"],

Cell[TextData[{
  StyleBox["Natural", "Input"],
  " is a setting for the ",
  StyleBox["EndConditions", "Input"],
  " option for ",
  StyleBox["SplineFit", "Input"],
  " that specifies that the curvature of the spline shall be zero at the \
ends."
}], "Text",
  GeneratedCell->True,
  CellTags->"Natural"],

Cell[TextData[{
  StyleBox["Omega[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the angular velocity of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Omega"],

Cell[TextData[{
  StyleBox["OriginLock2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " locks the position of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to that of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".  The local origins of the two bodies are coincident.  If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted, ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is located relative to the global origin.  Constrains 2 DOF."
}], "Text",
  CellTags->"OriginLock2"],

Cell[TextData[{
  StyleBox["Orthogonal1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be orthogonal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Orthogonal1"],

Cell[TextData[{
  StyleBox["Parallel1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Parallel1"],

Cell[TextData[{
  StyleBox["ParallelAxis[", "Input"],
  StyleBox["vec",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mass",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertia",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " uses the parallel axes theorem to transform the inertia properties of a \
body into or out of a centroidal reference frame.  Assuming that the given \
inertia properties are centroidal, ",
  StyleBox["ParallelAxis", "Input"],
  " returns the inertia properties relative to a noncentroidal reference \
frame in which ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " is the vector from the origin of the noncentroidal frame to the centroid \
of the body."
}], "Text",
  GeneratedCell->True,
  CellTags->"ParallelAxis"],

Cell[TextData[{
  StyleBox["Parameterize[", "Input"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " takes the given ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  " (each of which must have a numeric value defined) unsets them and puts \
them in the parameters list with a current value equal to their previously \
defined value."
}], "Text",
  GeneratedCell->True,
  CellTags->"Parameterize"],

Cell[TextData[{
  StyleBox["Parameters[", "Input"],
  StyleBox["]", "Input"],
  " returns the current ",
  StyleBox["Mech", "Input"],
  " parameters list.  ",
  StyleBox["Parameters", "Input"],
  " is also an element of the setting for the ",
  StyleBox["MakeRules", "Input"],
  " option.  ",
  StyleBox["MakeRules->", "Input"],
  StyleBox["{Parameters", "Input"],
  ", ...",
  StyleBox["}", "Input"],
  " causes the current parameters to be included in the returned rules.  ",
  StyleBox["Parameters", "Input"],
  " is also an option for ",
  StyleBox["SplineFit", "Input"],
  " that specifies the value of the spline parameter at each knot point."
}], "Text",
  GeneratedCell->True,
  CellTags->"Parameters"],

Cell[TextData[{
  StyleBox["PathSystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetPath", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"PathSystem"],

Cell[TextData[{
  StyleBox["Point[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is a ",
  StyleBox["Mech", "Input"],
  " data object that specifies a point on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a point number (positive integer) referencing a point that was \
defined with ",
  StyleBox["SetBodies", "Input"],
  " or it can be the coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  " of a point in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Point"],

Cell[TextData[{
  StyleBox["PointLabel[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " labels ",
  StyleBox["Point[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  ", just to the right of the local point.  ",
  StyleBox["PointLabel[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["All]", "Input"],
  " labels all of the points on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " that were defined with a body object."
}], "Text",
  GeneratedCell->True,
  CellTags->"PointLabel"],

Cell[TextData[{
  StyleBox["PointList", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that is used to specify a list of local point coordinates on a body.  ",
  StyleBox["PointList->{{", "Input"],
  StyleBox["x1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y1",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["x2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y2",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ..., ",
  StyleBox["{", "Input"],
  StyleBox["xn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["yn",
    FontSlant->"Italic"],
  StyleBox["}}", "Input"],
  " specifies ",
  StyleBox["n",
    FontSlant->"Italic"],
  " points on the body that are referenced by their point numbers 1 through ",
  
  StyleBox["n",
    FontSlant->"Italic"],
  ".  The specified list replaces any points that are currently defined on \
the body.  ",
  StyleBox["PointList->{}", "Input"],
  " removes all points currently on the body. The default setting ",
  StyleBox["Automatic", "Input"],
  " leaves points that were previously defined unchanged.  ",
  StyleBox["PointList[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the local coordinates of point ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"PointList"],

Cell[TextData[{
  StyleBox["PointOnLine1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a planar slider in which ",
  StyleBox["point",
    FontSlant->"Italic"],
  " is constrained to lie on ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " may be a ",
  StyleBox["Line", "Input"],
  " or ",
  StyleBox["Axis", "Input"],
  " object.  Constrains 1 DOF."
}], "Text",
  CellTags->"PointOnLine1"],

Cell[TextData[{
  StyleBox["PointOnLines2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie at the intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 2 DOF."
}], "Text",
  CellTags->"PointOnLines2"],

Cell[TextData[{
  StyleBox["PointToLineDistance[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the shortest distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"PointToLineDistance"],

Cell[TextData[{
  StyleBox["PointToLocal[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the local coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " in the coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"PointToLocal"],

Cell[TextData[{
  StyleBox["PolarToXY[{", "Input"],
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " converts the given point from polar to Cartesian coordinates and returns \
",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"PolarToXY"],

Cell[TextData[{
  StyleBox["Predictor", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ". The ",
  StyleBox["Predictor", "Input"],
  " method uses an Adams-Bashforth predictor integration algorithm."
}], "Text",
  GeneratedCell->True,
  CellTags->"Predictor"],

Cell[TextData[{
  StyleBox["ProjectOnLine[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " projects ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " onto ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " and returns the vector component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is in the direction of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["ProjectOnLine[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " orthogonally projected onto ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"ProjectOnLine"],

Cell[TextData[{
  StyleBox["Quadratic", "Input"],
  " is a setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ".  ",
  StyleBox["Quadratic", "Input"],
  " specifies a quadratic approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Quadratic"],

Cell[TextData[{
  StyleBox["Quartic", "Input"],
  " is a setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ".  ",
  StyleBox["Quartic", "Input"],
  " specifies a quartic approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Quartic"],

Cell[TextData[{
  StyleBox["RackAndPinion2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a rack and pinion gear set.  The center of the pinion ",
  StyleBox["point",
    FontSlant->"Italic"],
  " is constrained to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units to the left of the rack (",
  StyleBox["axis",
    FontSlant->"Italic"],
  ") and the angular orientation of the rack and pinion are related as per \
the pinion radius.  The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " sets the initial orientation of the rack and pinion.  Constrains 2 DOF"
}], "Text",
  CellTags->"RackAndPinion2"],

Cell[TextData[{
  StyleBox["Reaction[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the reaction loads applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", calculated about ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Loads", "Input"],
  " are returned in the format: ",
  StyleBox["{", "Input"],
  "force, moment",
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["Reaction", "Input"],
  " accepts the option ",
  StyleBox["Coordinates->Local", "Input"],
  " to return the load vectors in local coordinates, relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Reaction", "Input"],
  " is also a setting for the ",
  StyleBox["Type", "Input"],
  " option for ",
  StyleBox["Loads", "Input"],
  "."
}], "Text",
  CellTags->"Reaction"],

Cell[TextData[{
  StyleBox["Relative", "Input"],
  " is a setting for the ",
  StyleBox["Magnitude", "Input"],
  " option for ",
  StyleBox["Force", "Input"],
  " and ",
  StyleBox["Moment", "Input"],
  ".  ",
  StyleBox["Magnitude->", "Input"],
  StyleBox["Relative", "Input"],
  " causes the magnitude of the applied load to be equal to the specified \
magnitude times the length of the vector used to specify the direction of the \
load."
}], "Text",
  GeneratedCell->True,
  CellTags->"Relative"],

Cell[TextData[{
  StyleBox["RelativeAngle1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " , ",
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the angle between ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeAngle1"],

Cell[TextData[{
  StyleBox["RelativeDistance1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a connecting link.  The absolute distance from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is constrained to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeDistance1"],

Cell[TextData[{
  StyleBox["RelativeVelocity[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the velocity of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", in global coordinates."
}], "Text",
  CellTags->"RelativeVelocity"],

Cell[TextData[{
  StyleBox["RelativeX1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeX1"],

Cell[TextData[{
  StyleBox["RelativeY1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeY1"],

Cell[TextData[{
  StyleBox["RequiredEquations", "Input"],
  " is an option for ",
  StyleBox["FindSwitchTime", "Input"],
  " that specifies which equations, of a constraint that restrains more than \
one DOF, are to be retained in seeking the switch time.  ",
  StyleBox["RequiredEquations", "Input"],
  " should be a two element list; the first element applies to the first set \
of equations of the ",
  StyleBox["TimeSwitch", "Input"],
  " pair,  the second element applies to the second set.  Allowable values \
for each element are: an integer or list of integers, 1 through the number of \
DOF's in the constraint, ",
  StyleBox["All", "Input"],
  ", or ",
  StyleBox["Sum", "Input"],
  ".  The default setting is ",
  StyleBox["RequiredEquations->", "Input"],
  StyleBox["{All", "Input"],
  ", ",
  StyleBox["Sum}", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"RequiredEquations"],

Cell[TextData[{
  StyleBox["Revolute2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a rotational joint.  ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " is constrained to be coincident with ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  Constrains 2 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Revolute2"],

Cell[TextData[{
  StyleBox["RMatrix", "Input"],
  " returns the 2D orthogonal rotation matrix ",
  StyleBox["{{0, -1}, {1, 0}}", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"RMatrix"],

Cell[TextData[{
  StyleBox["Rotation[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the angle of rotation of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Rotation"],

Cell[TextData[{
  StyleBox["RotationLock1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the angular coordinate of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " units greater than the angular coordinate of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".  If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted, ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is oriented relative to the global coordinate system.  ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " defaults to zero.  Constrains 1 DOF."
}], "Text",
  CellTags->"RotationLock1"],

Cell[TextData[{
  StyleBox["RotationMatrix[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the rotation matrix associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"RotationMatrix"],

Cell[TextData[{
  StyleBox["SaveMech[", "Input"],
  "\"file\"",
  StyleBox["]", "Input"],
  " saves the entire state of the current ",
  StyleBox["Mech", "Input"],
  " system in file such that it can be restored with ",
  StyleBox["Get[", "Input"],
  "\"file\"",
  StyleBox["]", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SaveMech"],

Cell[TextData[{
  StyleBox["SensitivitySystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetSensitivity", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SensitivitySystem"],

Cell[TextData[{
  StyleBox["SetBodies[", "Input"],
  StyleBox["bodies",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " incorporates the local coordinates, initial guesses, and inertia \
properties provided by ",
  StyleBox["bodies",
    FontSlant->"Italic"],
  " into the current mechanism model.  ",
  StyleBox["bodies",
    FontSlant->"Italic"],
  " must be a list or sequence of ",
  StyleBox["SysBody", "Input"],
  " data objects that are built by the ",
  StyleBox["Body", "Input"],
  " function."
}], "Text",
  CellTags->"SetBodies"],

Cell[TextData[{
  StyleBox["SetConstraints[", "Input"],
  StyleBox["constraints",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the mathematical mechanism model represented by the constraints.  \
",
  StyleBox["constraints",
    FontSlant->"Italic"],
  " must be a list or sequence of ",
  StyleBox["SysCon", "Input"],
  " data objects that are returned by any of the standard ",
  StyleBox["Mech", "Input"],
  " constraint functions.  The ",
  StyleBox["SetGuess", "Input"],
  " option is used to specify that the initial guesses shall be reset to the \
defaults, regardless of whether or not they must be.  The ",
  StyleBox["BuildMech", "Input"],
  " option determines which system equations are built immediately."
}], "Text",
  CellTags->"SetConstraints"],

Cell[TextData[{
  StyleBox["SetCouple[", "Input"],
  StyleBox["sym",
    FontSlant->"Italic"],
  ", ",
  StyleBox["eq",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Time->", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds a ",
  StyleBox["CoupleSystem", "Input"],
  " in which the value of the symbol ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " is sought that satisfies the equation ",
  StyleBox["eq",
    FontSlant->"Italic"],
  " at time = ",
  StyleBox["t",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetCouple"],

Cell[TextData[{
  StyleBox["SetFree[", "Input"],
  StyleBox["dropcon",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the mathematical equations required to find equilibrium conditions \
of the current model.  The ",
  StyleBox["dropcon",
    FontSlant->"Italic"],
  " argument is used to specify the constraint number(s) that are dropped to \
make the system underconstrained.  The ",
  StyleBox["Solution", "Input"],
  " option specifies whether to seek ",
  StyleBox["Static", "Input"],
  ", ",
  StyleBox["Kinematic", "Input"],
  ", or ",
  StyleBox["Dynamic", "Input"],
  " equilibrium."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetFree"],

Cell[TextData[{
  StyleBox["SetGuess[", "Input"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " sets the current values of the system initial guesses.  Guesses are given \
as a sequence or list of rules, specifying the new values of the variables \
that are to have their current guesses changed.  ",
  StyleBox["SetGuess[]", "Input"],
  " restores all of the initial guesses to their default values as specified \
with ",
  StyleBox["SetBodies", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetGuess"],

Cell[TextData[{
  StyleBox["SetLoads[", "Input"],
  StyleBox["loads",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " prepares the applied load vector and incorporates the given ",
  StyleBox["loads",
    FontSlant->"Italic"],
  " into the current model.  Each load must have the head ",
  StyleBox["SysLoad", "Input"],
  ".  ",
  StyleBox["SysLoad", "Input"],
  " objects are returned by all of the ",
  StyleBox["Mech", "Input"],
  " forcing functions.  The ",
  StyleBox["AddLoads", "Input"],
  " option is used to specify whether the ",
  StyleBox["loads",
    FontSlant->"Italic"],
  " are to be added to or replace the current load vector.  The ",
  StyleBox["LambdaGuess", "Input"],
  " option specifies the default initial guess for the Lagrange multipliers."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetLoads"],

Cell[TextData[{
  StyleBox["SetParameters[", "Input"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " adds a sequence or list of rules to the current parameters list and \
returns the entire ",
  StyleBox["Parameters", "Input"],
  " list.  Each of the ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " must be of the form ",
  StyleBox["Symbol->", "Input"],
  StyleBox["number",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetParameters"],

Cell[TextData[{
  StyleBox["SetPath[", "Input"],
  StyleBox["constraints",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the differential equations necessary to find the time domain \
motion of a fully constrained nonholonomic system.  ",
  StyleBox["Kinematic", "Input"],
  " constraints in the current model are replaced with the given velocity \
dependent ",
  StyleBox["constraints",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SetPath", "Input"],
  " accepts the ",
  StyleBox["InitialCondition", "Input"],
  " option to specify the initial location of each body in the model.  ",
  StyleBox["SetPath", "Input"],
  " returns a ",
  StyleBox["PathSystem", "Input"],
  " object that is solved with ",
  StyleBox["SolvePath", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetPath"],

Cell[TextData[{
  StyleBox["SetSensitivity[", "Input"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the equations necessary to find the sensitivity of the current \
model to changes in the ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SetSensitivity", "Input"],
  " returns a ",
  StyleBox["SensitivitySystem", "Input"],
  " object that is solved with ",
  StyleBox["SolveSensitivity", "Input"],
  "."
}], "Text",
  CellTags->"SetSensitivity"],

Cell[TextData[{
  StyleBox["SetSymbols[", "Input"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is used with the ",
  StyleBox["SymbolBasis", "Input"],
  " option to specify the basis for the symbols that ",
  StyleBox["Mech", "Input"],
  " creates.  The ",
  StyleBox["Method", "Input"],
  " option is used to specify whether angular or Euler coordinates are used \
to represent the angular orientation and velocity of a mechanism body.  \
Settings for ",
  StyleBox["Method", "Input"],
  " are ",
  StyleBox["Angular", "Input"],
  " and ",
  StyleBox["Euler", "Input"],
  "."
}], "Text",
  CellTags->"SetSymbols"],

Cell[TextData[{
  StyleBox["Solution", "Input"],
  " is an option for certain ",
  StyleBox["Mech", "Input"],
  " functions that specifies the level of solution sought.  Valid settings \
for ",
  StyleBox["Solution", "Input"],
  " are ",
  StyleBox["Location", "Input"],
  ", ",
  StyleBox["Velocity", "Input"],
  ", ",
  StyleBox["Acceleration", "Input"],
  ", ",
  StyleBox["Static", "Input"],
  ", ",
  StyleBox["Kinematic", "Input"],
  ", and ",
  StyleBox["Dynamic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Solution"],

Cell[TextData[{
  StyleBox["SolveCouple[", "Input"],
  StyleBox["cpsys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " solves the coupled system built by ",
  StyleBox["SetCouple", "Input"],
  ".  The ",
  StyleBox["cpsys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["CoupleSystem", "Input"],
  ".  ",
  StyleBox["SolveCouple", "Input"],
  " returns a list of rules representing the solution to the ",
  StyleBox["CoupleSystem", "Input"],
  " object."
}], "Text",
  GeneratedCell->True,
  CellTags->"SolveCouple"],

Cell[TextData[{
  StyleBox["SolveFree[", "Input"],
  StyleBox["freesys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds the solution to a free system built by ",
  StyleBox["SetFree", "Input"],
  ".  The specified object ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["FreeSystem", "Input"],
  ".  ",
  StyleBox["SolveFree", "Input"],
  " returns a list of rules representing the solution to the ",
  StyleBox["FreeSystem", "Input"],
  " object.  ",
  StyleBox["SolveFree[", "Input"],
  StyleBox["freesys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " integrates the equations of motion in the ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " and returns the time domain free response."
}], "Text",
  GeneratedCell->True,
  CellTags->"SolveFree"],

Cell[TextData[{
  StyleBox["SolveMech[", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " attempts to find a location solution to the current model at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SolveMech", "Input"],
  " returns a list of rules containing the global coordinates of each body.  \
",
  StyleBox["SolveMech[{", "Input"],
  StyleBox["t1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["t2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["tn",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns a nested list of solution rules containing solution points at all \
of the ",
  StyleBox["ti",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SolveMech", "Input"],
  " accepts the ",
  StyleBox["Solution", "Input"],
  " option to determine what order of solution to seek.  ",
  StyleBox["Interpolation->True", "Input"],
  " causes ",
  StyleBox["SolveMech", "Input"],
  " to interpolate the solution rules returned."
}], "Text",
  CellTags->"SolveMech"],

Cell[TextData[{
  StyleBox["SolvePath[", "Input"],
  StyleBox["pathsys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds the solution to the nonholonomic system built by ",
  StyleBox["SetPath", "Input"],
  ".  The ",
  StyleBox["pathsys",
    FontSlant->"Italic"],
  " object must have the head ",
  StyleBox["PathSystem", "Input"],
  ".  ",
  StyleBox["SolvePath", "Input"],
  " integrates the equations of motion from the initial time to ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SolvePath"],

Cell[TextData[{
  StyleBox["SolveSensitivity[", "Input"],
  StyleBox["senssys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds the solution to the sensitivity system built by ",
  StyleBox["SetSensitivity", "Input"],
  ".  The ",
  StyleBox["senssys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["SensitivitySystem", "Input"],
  ".  ",
  StyleBox["SolveSensitivity", "Input"],
  " returns a list of rules representing the solution to the ",
  StyleBox["SensitivitySystem", "Input"],
  " object."
}], "Text",
  CellTags->"SolveSensitivity"],

Cell[TextData[{
  StyleBox["SplineFit[", "Input"],
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a ",
  StyleBox["SplineFunction", "Input"],
  " object representing ",
  StyleBox["data",
    FontSlant->"Italic"],
  " as a cubic spline."
}], "Text",
  CellTags->"SplineFit"],

Cell[TextData[{
  StyleBox["SplineFunction[", "Input"],
  StyleBox["range",
    FontSlant->"Italic"],
  ", ",
  StyleBox["intdata",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " represents a spline created by ",
  StyleBox["SplineFit", "Input"],
  ". The ",
  StyleBox["SplineFunction", "Input"],
  " accepts an argument within ",
  StyleBox["range",
    FontSlant->"Italic"],
  " for evaluation at some point along the spline."
}], "Text",
  CellTags->"SplineFunction"],

Cell[TextData[{
  StyleBox["StageSwitch[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["test1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["const1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["test2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["const2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["]", "Input"],
  " can be used in place of a single constraint supplied to ",
  StyleBox["SetConstraints", "Input"],
  ".  ",
  StyleBox["StageSwitch", "Input"],
  " evaluates each of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " in turn, and applies the consti corresponding to the first ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " that returns ",
  StyleBox["True", "Input"],
  ".  ",
  StyleBox["StageSwitch[", "Input"],
  StyleBox["test1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["load1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["test2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["load2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["]", "Input"],
  " can be used in place of a load supplied to ",
  StyleBox["SetLoads", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"StageSwitch"],

Cell[TextData[{
  StyleBox["Static", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->", "Input"],
  StyleBox["Static", "Input"],
  " causes such functions to seek a solution for the location and static \
loading of the current mechanism."
}], "Text",
  GeneratedCell->True,
  CellTags->"Static"],

Cell[TextData[{
  StyleBox["Step[", "Input"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " represents a step function.  ",
  StyleBox["Step[", "Input"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns 1 if ",
  StyleBox["num",
    FontSlant->"Italic"],
  " >= 0 and returns 0 if ",
  StyleBox["num",
    FontSlant->"Italic"],
  " < 0, otherwise ",
  StyleBox["Step[", "Input"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is returned unevaluated.  All derivatives of ",
  StyleBox["Step", "Input"],
  " are equal to zero."
}], "Text",
  CellTags->"Step"],

Cell[TextData[{
  StyleBox["StepMech[", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " steps the constraint equations through one iteration of the \
Newton-Rhapson solution block with time set to ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", regardless of any convergence criteria."
}], "Text",
  GeneratedCell->True,
  CellTags->"StepMech"],

Cell[TextData[{
  StyleBox["StepSize", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  " that sets the constant time step size used by the numerical integration \
algorithm."
}], "Text",
  GeneratedCell->True,
  CellTags->"StepSize"],

Cell[TextData[{
  StyleBox["SymbolBasis", "Input"],
  " is an option for ",
  StyleBox["SetSymbols", "Input"],
  ".  ",
  StyleBox["SymbolBasis", "Input"],
  " is given as a nested list of strings that specifies the basis for the \
symbol names that will be hard coded into the model."
}], "Text",
  GeneratedCell->True,
  CellTags->"SymbolBasis"],

Cell[TextData[{
  StyleBox["SysBody", "Input"],
  " is the head of a system body object returned by the ",
  StyleBox["Body", "Input"],
  " function."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysBody"],

Cell[TextData[{
  StyleBox["SysCon", "Input"],
  " is the head of a system constraint object returned by all ",
  StyleBox["Mech", "Input"],
  " constraint functions."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysCon"],

Cell[TextData[{
  StyleBox["SysLoad", "Input"],
  " is the head of a system load object returned by all ",
  StyleBox["Mech", "Input"],
  " load functions."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysLoad"],

Cell[TextData[{
  StyleBox["SysPlot", "Input"],
  " is used by ",
  StyleBox["CamPlot", "Input"],
  " to carry a plot object that  evaluates to a ",
  StyleBox["Graphics", "Input"],
  " object when numerical values are available for the coordinates of the cam \
body."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysPlot"],

Cell[TextData[{
  StyleBox["Tangent[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a pair of lines tangent to two implied circles.  ",
  StyleBox["If", "Input"],
  " a circle of radius ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  " is centered at ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", and another of radius ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  " is centered at ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Tangent", "Input"],
  " generates two lines tangent to both circles, representing a belt or chain \
between two pulleys."
}], "Text",
  GeneratedCell->True,
  CellTags->"Tangent"],

Cell[TextData[{
  StyleBox["TangentConstraint", "Input"],
  " is an option for ",
  StyleBox["FindSwitchTime", "Input"],
  " that specifies whether or not the constraint pair in question comes into \
conjunction tangentially.  The default setting is ",
  StyleBox["TangentConstraint->", "Input"],
  StyleBox["False", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"TangentConstraint"],

Cell[TextData[{
  StyleBox["Time", "Input"],
  " is an option for ",
  StyleBox["SetCouple", "Input"],
  " that is used to specify the value of time.  ",
  StyleBox["Time->", "Input"],
  StyleBox["Free", "Input"],
  " specifies that time is a dependent variable.  The default setting is ",
  StyleBox["Time->", "Input"],
  StyleBox["None", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Time"],

Cell[TextData[{
  StyleBox["TimeInterpolate[", "Input"],
  StyleBox["expr",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["rules1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rules2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " returns an ",
  StyleBox["InterpolatingFunction", "Input"],
  " object representing ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " as a function of time.  Each of the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  " must be a list of rules containing numerical replacements for all of the \
subexpressions in ",
  StyleBox["expr",
    FontSlant->"Italic"],
  ", as well as a rule for the value of time, ",
  StyleBox["T", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"TimeInterpolate"],

Cell[TextData[{
  StyleBox["TimeSwitch[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["con0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["time1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["con1",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["timen",
    FontSlant->"Italic"],
  ", ",
  StyleBox["conn",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " can be used in place of a single constraint supplied to ",
  StyleBox["SetConstraints", "Input"],
  ".  ",
  StyleBox["TimeSwitch", "Input"],
  " applies ",
  StyleBox["coni",
    FontSlant->"Italic"],
  " if ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " < ",
  StyleBox["T", "Input"],
  " < ",
  StyleBox["time(i+",
    FontSlant->"Italic"],
  "1",
  StyleBox[")",
    FontSlant->"Italic"],
  ".  The first and last constraints are applied when ",
  StyleBox["T", "Input"],
  " < ",
  StyleBox["time1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["T", "Input"],
  " > ",
  StyleBox["timen",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["TimeSwitch[", "Input"],
  StyleBox["load0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["time1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["load1",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["timen",
    FontSlant->"Italic"],
  ", ",
  StyleBox["loadn",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " can be used in place of a single forcing function supplied to ",
  StyleBox["SetLoads", "Input"],
  ".  ",
  StyleBox["TimeSwitch", "Input"],
  " applies loadi if ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " < ",
  StyleBox["T", "Input"],
  " < ",
  StyleBox["time(i+",
    FontSlant->"Italic"],
  "1",
  StyleBox[")",
    FontSlant->"Italic"],
  ".  The first and last loadi are applied when ",
  StyleBox["T", "Input"],
  " < ",
  StyleBox["time1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["T", "Input"],
  " > ",
  StyleBox["timen",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"TimeSwitch"],

Cell[TextData[{
  StyleBox["Translate2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel and coincident with ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 2 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Translate2"],

Cell[TextData[{
  StyleBox["TwoGears1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a gear set.  ",
  StyleBox["Function", "Input"],
  " is identical to ",
  StyleBox["TwoGears2", "Input"],
  ", except ",
  StyleBox["TwoGears1", "Input"],
  " does not constrain the distance between the axes of the two gears, only \
their angular orientations.  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"TwoGears1"],

Cell[TextData[{
  StyleBox["TwoGears2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a gear set.  The axes of the two gears ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " & ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " are constrained to be rad1+rad2 units apart, and the rotational positions \
of the gears are related as per their respective radii.  The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " sets the initial rotational positions of the gears.  Constrains 2 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"TwoGears2"],

Cell[TextData[{
  StyleBox["TwoPulleys2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a chain and sprocket or belt set.  The axes of the two sprockets ",
  
  StyleBox["point1",
    FontSlant->"Italic"],
  " & ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " are constrained to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the rotational positions of the sprockets are related as \
per their respective radii.  The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " sets the initial rotational position of the pulleys.  Constrains 2 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"TwoPulleys2"],

Cell[TextData[{
  StyleBox["Type", "Input"],
  " is an option for ",
  StyleBox["Loads", "Input"],
  " that specifies whether ",
  StyleBox["Applied", "Input"],
  ", ",
  StyleBox["Reaction", "Input"],
  ", or ",
  StyleBox["Dynamic", "Input"],
  " loads are returned.  The default setting is ",
  StyleBox["Type->", "Input"],
  StyleBox["Applied", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Type"],

Cell[TextData[{
  StyleBox["Unit[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a unit vector pointed in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Unit"],

Cell[TextData[{
  StyleBox["Vector[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is a ",
  StyleBox["Mech", "Input"],
  " data object that represents a vector in the local coordinate system of \
body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a vector {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "} in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", or it can be a point number (positive integer) referencing a coordinate \
that was defined with ",
  StyleBox["SetBodies", "Input"],
  "."
}], "Text",
  CellTags->"Vector"],

Cell[TextData[{
  StyleBox["Velocity", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->Velocity", "Input"],
  " causes such functions to seek a solution for the location and velocity of \
the current mechanism.  ",
  StyleBox["Velocity[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the global velocity vector ",
  Cell[BoxData[
      \(TraditionalForm\`{x\&., y\&.}\)]],
  " of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Velocity"],

Cell[TextData[{
  StyleBox["VelocityTerms[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the part of the right-hand term of the current velocity \
constraint expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"VelocityTerms"],

Cell[TextData[{
  StyleBox["Vertex[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " generates point graphics primitives at each of the ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "}."
}], "Text",
  CellTags->"Vertex"],

Cell[TextData[{
  StyleBox["Wheel[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["facets",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a circular disk of specified radius and number of ",
  StyleBox["facets",
    FontSlant->"Italic"],
  ", centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Wheel", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " and ",
  StyleBox["Angle", "Input"],
  " options."
}], "Text",
  CellTags->"Wheel"],

Cell[TextData[{
  StyleBox["XYToPolar[{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " converts the given point from Cartesian to polar coordinates and returns \
",
  StyleBox["{", "Input"],
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["angle",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"XYToPolar"],

Cell[TextData[{
  StyleBox["$MechPostIterate", "Input"],
  " is a function that is applied to the iteration counter at each iteration \
of ",
  StyleBox["Mech", "Input"],
  "'s iterative solution block."
}], "Text",
  CellTags->"$MechPostIterate"],

Cell[TextData[{
  StyleBox["$MechPreSolve", "Input"],
  " is applied to the numeric value of the time variable before each run of \
the location solution block."
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechPreSolve"],

Cell[TextData[{
  StyleBox["$MechPrimeRules", "Input"],
  " returns a list of replacement rules for all of the current ",
  StyleBox["Mech", "Input"],
  " dependent variables to convert them to explicit functions of time with \
the ",
  StyleBox["Derivative", "Input"],
  " operator replacing ",
  StyleBox["Mech", "Input"],
  "'s symbolic derivatives.  ",
  StyleBox["$MechPrimeRules", "Input"],
  " is of the form ",
  StyleBox["{X2->X2[T]", "Input"],
  ", ..., ",
  StyleBox["Y3d->Y3'[T]", "Input"],
  ", ...",
  StyleBox["}", "Input"]
}], "Text",
  CellTags->"$MechPrimeRules"],

Cell[TextData[{
  StyleBox["$MechProcessFunction", "Input"],
  " a function that is applied to ",
  StyleBox["Mech", "Input"],
  "'s internal lists of modeling equations as they are generated. ",
  StyleBox["$MechProcessFunction", "Input"],
  " is initially set equal to ",
  StyleBox["Chop", "Input"],
  "."
}], "Text",
  CellTags->"$MechProcessFunction"],

Cell[TextData[{
  StyleBox["$MechTimeRules", "Input"],
  " returns a list of replacement rules for all of the current ",
  StyleBox["Mech", "Input"],
  " dependent variables to convert them to explicit functions of time.  ",
  StyleBox["$MechTimeRules", "Input"],
  " is of the form ",
  StyleBox["{X2->", "Input"],
  StyleBox["X2", "Input"],
  StyleBox["[T]", "Input"],
  ", ..., ",
  StyleBox["Y3d->", "Input"],
  StyleBox["Y3d", "Input"],
  StyleBox["[T]", "Input"],
  ", ...",
  StyleBox["}", "Input"]
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechTimeRules"],

Cell[TextData[{
  StyleBox["$MechVariables", "Input"],
  " returns a list of the names of all of the user variables that are present \
in the current model.  Changes in the values of these variables affect the \
model."
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechVariables"],

Cell[TextData[{
  StyleBox["$MechVersion", "Input"],
  " returns the version number of the ",
  StyleBox["Mech", "Input"],
  " packages."
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechVersion"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowSize->{399, 609},
WindowMargins->{{105, Automatic}, {Automatic, 20}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Mech2D"->{
    Cell[1731, 51, 71, 2, 54, "Subtitle",
      CellTags->"Mech2D"]},
  "Absolute"->{
    Cell[1805, 55, 517, 19, 94, "Text",
      CellTags->"Absolute"]},
  "Acceleration"->{
    Cell[2325, 76, 703, 22, 112, "Text",
      CellTags->"Acceleration"]},
  "AccelerationTerms"->{
    Cell[3031, 100, 375, 12, 72, "Text",
      CellTags->"AccelerationTerms"]},
  "AddLoads"->{
    Cell[3409, 114, 393, 12, 73, "Text",
      CellTags->"AddLoads"]},
  "Alpha"->{
    Cell[3805, 128, 272, 11, 34, "Text",
      CellTags->"Alpha"]},
  "Angle"->{
    Cell[4080, 141, 902, 36, 113, "Text",
      CellTags->"Angle"]},
  "Angular"->{
    Cell[4985, 179, 346, 10, 72, "Text",
      CellTags->"Angular"]},
  "Applied"->{
    Cell[5334, 191, 405, 14, 73, "Text",
      CellTags->"Applied"]},
  "ArcLength"->{
    Cell[5742, 207, 546, 19, 94, "Text",
      CellTags->"ArcLength"]},
  "Arrow"->{
    Cell[6291, 228, 1024, 36, 132, "Text",
      CellTags->"Arrow"]},
  "Bar"->{
    Cell[7318, 266, 481, 20, 54, "Text",
      CellTags->"Bar"]},
  "Body"->{
    Cell[7802, 288, 1063, 39, 154, "Text",
      CellTags->"Body"]},
  "BodyEnergy"->{
    Cell[8868, 329, 286, 11, 53, "Text",
      CellTags->"BodyEnergy"]},
  "Box"->{
    Cell[9157, 342, 780, 32, 93, "Text",
      CellTags->"Box"]},
  "BuildMech"->{
    Cell[9940, 376, 841, 30, 132, "Text",
      CellTags->"BuildMech"]},
  "CamPlot"->{
    Cell[10784, 408, 767, 32, 91, "Text",
      CellTags->"CamPlot"]},
  "CamToCam1"->{
    Cell[11554, 442, 1361, 52, 150, "Text",
      CellTags->"CamToCam1"]},
  "CamToCircle1"->{
    Cell[12918, 496, 1336, 49, 168, "Text",
      CellTags->"CamToCircle1"]},
  "CamToLine1"->{
    Cell[14257, 547, 980, 38, 111, "Text",
      CellTags->"CamToLine1"]},
  "CamToPoint1"->{
    Cell[15240, 587, 978, 38, 111, "Text",
      CellTags->"CamToPoint1"]},
  "Centrifugal"->{
    Cell[16221, 627, 305, 11, 53, "Text",
      CellTags->"Centrifugal"]},
  "Centroid"->{
    Cell[16529, 640, 585, 19, 93, "Text",
      CellTags->"Centroid"]},
  "CheckRules"->{
    Cell[17117, 661, 476, 13, 93, "Text",
      CellTags->"CheckRules"]},
  "CheckSystem"->{
    Cell[17596, 676, 402, 13, 74, "Text",
      CellTags->"CheckSystem"]},
  "ClearMech"->{
    Cell[18001, 691, 263, 8, 53, "Text",
      CellTags->"ClearMech"]},
  "ClearParameters"->{
    Cell[18267, 701, 345, 12, 53, "Text",
      CellTags->"ClearParameters"]},
  "Closed"->{
    Cell[18615, 715, 319, 10, 72, "Text",
      CellTags->"Closed"]},
  "CompositeInertia"->{
    Cell[18937, 727, 892, 38, 92, "Text",
      CellTags->"CompositeInertia"]},
  "Constraint"->{
    Cell[19832, 767, 1463, 56, 170, "Text",
      CellTags->"Constraint"]},
  "ConstraintCorrection"->{
    Cell[21298, 825, 404, 11, 92, "Text",
      CellTags->"ConstraintCorrection"]},
  "Constraints"->{
    Cell[21705, 838, 413, 13, 72, "Text",
      CellTags->"Constraints"]},
  "Coordinates"->{
    Cell[22121, 853, 443, 15, 74, "Text",
      CellTags->"Coordinates"]},
  "Corrector"->{
    Cell[22567, 870, 343, 11, 73, "Text",
      CellTags->"Corrector"]},
  "CoupleSystem"->{
    Cell[22913, 883, 205, 7, 34, "Text",
      CellTags->"CoupleSystem"]},
  "Cross"->{
    Cell[23121, 892, 351, 13, 54, "Text",
      CellTags->"Cross"]},
  "Cubic"->{
    Cell[23475, 907, 335, 11, 54, "Text",
      CellTags->"Cubic"]},
  "CutOff"->{
    Cell[23813, 920, 563, 14, 112, "Text",
      CellTags->"CutOff"]},
  "D2DistanceDT2"->{
    Cell[24379, 936, 337, 12, 53, "Text",
      CellTags->"D2DistanceDT2"]},
  "DDistanceDT"->{
    Cell[24719, 950, 326, 12, 53, "Text",
      CellTags->"DDistanceDT"]},
  "Diagnostics"->{
    Cell[25048, 964, 241, 9, 54, "Text",
      CellTags->"Diagnostics"]},
  "DirectedDistance1"->{
    Cell[25292, 975, 695, 31, 72, "Text",
      CellTags->"DirectedDistance1"]},
  "DirectedPosition2"->{
    Cell[25990, 1008, 738, 31, 72, "Text",
      CellTags->"DirectedPosition2"]},
  "Direction"->{
    Cell[26731, 1041, 272, 9, 53, "Text",
      CellTags->"Direction"]},
  "Distance"->{
    Cell[27006, 1052, 295, 11, 53, "Text",
      CellTags->"Distance"]},
  "Dynamic"->{
    Cell[27304, 1065, 773, 24, 132, "Text",
      CellTags->"Dynamic"]},
  "Edge"->{
    Cell[28080, 1091, 1074, 47, 93, "Text",
      CellTags->"Edge"]},
  "EndConditions"->{
    Cell[29157, 1140, 493, 14, 93, "Text",
      CellTags->"EndConditions"]},
  "Euler"->{
    Cell[29653, 1156, 332, 9, 72, "Text",
      CellTags->"Euler"]},
  "EulerParameters"->{
    Cell[29988, 1167, 382, 16, 53, "Text",
      CellTags->"EulerParameters"]},
  "Faces"->{
    Cell[30373, 1185, 331, 11, 74, "Text",
      CellTags->"Faces"]},
  "Facet"->{
    Cell[30707, 1198, 1113, 50, 93, "Text",
      CellTags->"Facet"]},
  "FindSwitchTime"->{
    Cell[31823, 1250, 967, 35, 134, "Text",
      CellTags->"FindSwitchTime"]},
  "FindTime"->{
    Cell[32793, 1287, 570, 19, 92, "Text",
      CellTags->"FindTime"]},
  "FitDegree"->{
    Cell[33366, 1308, 519, 18, 93, "Text",
      CellTags->"FitDegree"]},
  "Force"->{
    Cell[33888, 1328, 700, 31, 74, "Text",
      CellTags->"Force"]},
  "Free"->{
    Cell[34591, 1361, 591, 20, 93, "Text",
      CellTags->"Free"]},
  "FreeSystem"->{
    Cell[35185, 1383, 199, 7, 34, "Text",
      CellTags->"FreeSystem"]},
  "FunctionOfTime"->{
    Cell[35387, 1392, 334, 9, 73, "Text",
      CellTags->"FunctionOfTime"]},
  "Generalized"->{
    Cell[35724, 1403, 794, 27, 132, "Text",
      CellTags->"Generalized"]},
  "Global"->{
    Cell[36521, 1432, 180, 7, 34, "Text",
      CellTags->"Global"]},
  "Gravity"->{
    Cell[36704, 1441, 465, 16, 72, "Text",
      CellTags->"Gravity"]},
  "HeadSize"->{
    Cell[37172, 1459, 209, 7, 53, "Text",
      CellTags->"HeadSize"]},
  "IMatrix"->{
    Cell[37384, 1468, 167, 6, 34, "Text",
      CellTags->"IMatrix"]},
  "IncludedAngle"->{
    Cell[37554, 1476, 382, 14, 54, "Text",
      CellTags->"IncludedAngle"]},
  "Inertia"->{
    Cell[37939, 1492, 557, 19, 92, "Text",
      CellTags->"Inertia"]},
  "InitialCondition"->{
    Cell[38499, 1513, 661, 17, 134, "Text",
      CellTags->"InitialCondition"]},
  "InitialGuess"->{
    Cell[39163, 1532, 791, 29, 114, "Text",
      CellTags->"InitialGuess"]},
  "Interference"->{
    Cell[39957, 1563, 415, 12, 91, "Text",
      CellTags->"Interference"]},
  "IntersectionPoint"->{
    Cell[40375, 1577, 404, 16, 53, "Text",
      CellTags->"IntersectionPoint"]},
  "Involute"->{
    Cell[40782, 1595, 1253, 51, 130, "Text",
      CellTags->"Involute"]},
  "Jacobian"->{
    Cell[42038, 1648, 403, 17, 53, "Text",
      CellTags->"Jacobian"]},
  "KillMech"->{
    Cell[42444, 1667, 292, 7, 72, "Text",
      CellTags->"KillMech"]},
  "Kinematic"->{
    Cell[42739, 1676, 451, 13, 92, "Text",
      CellTags->"Kinematic"]},
  "LambdaGuess"->{
    Cell[43193, 1691, 527, 14, 113, "Text",
      CellTags->"LambdaGuess"]},
  "LastSolve"->{
    Cell[43723, 1707, 418, 13, 74, "Text",
      CellTags->"LastSolve"]},
  "Line"->{
    Cell[44144, 1722, 1004, 38, 131, "Text",
      CellTags->"Line"]},
  "Linear"->{
    Cell[45151, 1762, 328, 11, 54, "Text",
      CellTags->"Linear"]},
  "Load"->{
    Cell[45482, 1775, 444, 19, 53, "Text",
      CellTags->"Load"]},
  "Loads"->{
    Cell[45929, 1796, 620, 21, 94, "Text",
      CellTags->"Loads"]},
  "Local"->{
    Cell[46552, 1819, 178, 7, 34, "Text",
      CellTags->"Local"]},
  "LocalAxes"->{
    Cell[46733, 1828, 916, 38, 94, "Text",
      CellTags->"LocalAxes"]},
  "Location"->{
    Cell[47652, 1868, 665, 25, 94, "Text",
      CellTags->"Location"]},
  "LockMech"->{
    Cell[48320, 1895, 591, 19, 111, "Text",
      CellTags->"LockMech"]},
  "LocusPlot"->{
    Cell[48914, 1916, 711, 28, 70, "Text",
      CellTags->"LocusPlot"]},
  "Magnitude"->{
    Cell[49628, 1946, 690, 23, 70, "Text",
      CellTags->"Magnitude"]},
  "MakeRules"->{
    Cell[50321, 1971, 841, 25, 174, "Text",
      CellTags->"MakeRules"]},
  "Mass"->{
    Cell[51165, 1998, 476, 18, 73, "Text",
      CellTags->"Mass"]},
  "MassMatrix"->{
    Cell[51644, 2018, 320, 12, 53, "Text",
      CellTags->"MassMatrix"]},
  "MaxError"->{
    Cell[51967, 2032, 356, 10, 73, "Text",
      CellTags->"MaxError"]},
  "Mech"->{
    Cell[52326, 2044, 173, 5, 53, "Text",
      CellTags->"Mech"]},
  "MechPrimitive"->{
    Cell[52502, 2051, 524, 14, 113, "Text",
      CellTags->"MechPrimitive"]},
  "Moment"->{
    Cell[53029, 2067, 378, 16, 53, "Text",
      CellTags->"Moment"]},
  "Natural"->{
    Cell[53410, 2085, 305, 10, 53, "Text",
      CellTags->"Natural"]},
  "Omega"->{
    Cell[53718, 2097, 268, 11, 70, "Text",
      CellTags->"Omega"]},
  "OriginLock2"->{
    Cell[53989, 2110, 661, 25, 91, "Text",
      CellTags->"OriginLock2"]},
  "Orthogonal1"->{
    Cell[54653, 2137, 463, 20, 53, "Text",
      CellTags->"Orthogonal1"]},
  "Parallel1"->{
    Cell[55119, 2159, 457, 20, 53, "Text",
      CellTags->"Parallel1"]},
  "ParallelAxis"->{
    Cell[55579, 2181, 755, 23, 131, "Text",
      CellTags->"ParallelAxis"]},
  "Parameterize"->{
    Cell[56337, 2206, 431, 13, 72, "Text",
      CellTags->"Parameterize"]},
  "Parameters"->{
    Cell[56771, 2221, 710, 21, 133, "Text",
      CellTags->"Parameters"]},
  "PathSystem"->{
    Cell[57484, 2244, 199, 7, 34, "Text",
      CellTags->"PathSystem"]},
  "Point"->{
    Cell[57686, 2253, 716, 27, 92, "Text",
      CellTags->"Point"]},
  "PointLabel"->{
    Cell[58405, 2282, 698, 28, 73, "Text",
      CellTags->"PointLabel"]},
  "PointList"->{
    Cell[59106, 2312, 1481, 56, 172, "Text",
      CellTags->"PointList"]},
  "PointOnLine1"->{
    Cell[60590, 2370, 603, 26, 73, "Text",
      CellTags->"PointOnLine1"]},
  "PointOnLines2"->{
    Cell[61196, 2398, 557, 25, 53, "Text",
      CellTags->"PointOnLines2"]},
  "PointToLineDistance"->{
    Cell[61756, 2425, 381, 16, 53, "Text",
      CellTags->"PointToLineDistance"]},
  "PointToLocal"->{
    Cell[62140, 2443, 395, 16, 53, "Text",
      CellTags->"PointToLocal"]},
  "PolarToXY"->{
    Cell[62538, 2461, 471, 20, 54, "Text",
      CellTags->"PolarToXY"]},
  "Predictor"->{
    Cell[63012, 2483, 335, 11, 73, "Text",
      CellTags->"Predictor"]},
  "ProjectOnLine"->{
    Cell[63350, 2496, 862, 36, 92, "Text",
      CellTags->"ProjectOnLine"]},
  "Quadratic"->{
    Cell[64215, 2534, 341, 11, 73, "Text",
      CellTags->"Quadratic"]},
  "Quartic"->{
    Cell[64559, 2547, 333, 11, 73, "Text",
      CellTags->"Quartic"]},
  "RackAndPinion2"->{
    Cell[64895, 2560, 878, 32, 110, "Text",
      CellTags->"RackAndPinion2"]},
  "Reaction"->{
    Cell[65776, 2594, 1027, 41, 134, "Text",
      CellTags->"Reaction"]},
  "Relative"->{
    Cell[66806, 2637, 500, 16, 92, "Text",
      CellTags->"Relative"]},
  "RelativeAngle1"->{
    Cell[67309, 2655, 590, 26, 53, "Text",
      CellTags->"RelativeAngle1"]},
  "RelativeDistance1"->{
    Cell[67902, 2683, 632, 26, 72, "Text",
      CellTags->"RelativeDistance1"]},
  "RelativeVelocity"->{
    Cell[68537, 2711, 402, 16, 53, "Text",
      CellTags->"RelativeVelocity"]},
  "RelativeX1"->{
    Cell[68942, 2729, 701, 32, 72, "Text",
      CellTags->"RelativeX1"]},
  "RelativeY1"->{
    Cell[69646, 2763, 701, 32, 72, "Text",
      CellTags->"RelativeY1"]},
  "RequiredEquations"->{
    Cell[70350, 2797, 906, 24, 191, "Text",
      CellTags->"RequiredEquations"]},
  "Revolute2"->{
    Cell[71259, 2823, 489, 20, 53, "Text",
      CellTags->"Revolute2"]},
  "RMatrix"->{
    Cell[71751, 2845, 202, 7, 54, "Text",
      CellTags->"RMatrix"]},
  "Rotation"->{
    Cell[71956, 2854, 252, 10, 34, "Text",
      CellTags->"Rotation"]},
  "RotationLock1"->{
    Cell[72211, 2866, 852, 34, 110, "Text",
      CellTags->"RotationLock1"]},
  "RotationMatrix"->{
    Cell[73066, 2902, 275, 10, 53, "Text",
      CellTags->"RotationMatrix"]},
  "SaveMech"->{
    Cell[73344, 2914, 353, 13, 54, "Text",
      CellTags->"SaveMech"]},
  "SensitivitySystem"->{
    Cell[73700, 2929, 220, 7, 54, "Text",
      CellTags->"SensitivitySystem"]},
  "SetBodies"->{
    Cell[73923, 2938, 548, 18, 93, "Text",
      CellTags->"SetBodies"]},
  "SetConstraints"->{
    Cell[74474, 2958, 777, 20, 151, "Text",
      CellTags->"SetConstraints"]},
  "SetCouple"->{
    Cell[75254, 2980, 602, 26, 53, "Text",
      CellTags->"SetCouple"]},
  "SetFree"->{
    Cell[75859, 3008, 722, 24, 112, "Text",
      CellTags->"SetFree"]},
  "SetGuess"->{
    Cell[76584, 3034, 551, 15, 113, "Text",
      CellTags->"SetGuess"]},
  "SetLoads"->{
    Cell[77138, 3051, 834, 24, 133, "Text",
      CellTags->"SetLoads"]},
  "SetParameters"->{
    Cell[77975, 3077, 506, 18, 74, "Text",
      CellTags->"SetParameters"]},
  "SetPath"->{
    Cell[78484, 3097, 821, 25, 154, "Text",
      CellTags->"SetPath"]},
  "SetSensitivity"->{
    Cell[79308, 3124, 510, 17, 94, "Text",
      CellTags->"SetSensitivity"]},
  "SetSymbols"->{
    Cell[79821, 3143, 649, 21, 112, "Text",
      CellTags->"SetSymbols"]},
  "Solution"->{
    Cell[80473, 3166, 546, 22, 74, "Text",
      CellTags->"Solution"]},
  "SolveCouple"->{
    Cell[81022, 3190, 599, 22, 94, "Text",
      CellTags->"SolveCouple"]},
  "SolveFree"->{
    Cell[81624, 3214, 987, 36, 133, "Text",
      CellTags->"SolveFree"]},
  "SolveMech"->{
    Cell[82614, 3252, 1037, 36, 153, "Text",
      CellTags->"SolveMech"]},
  "SolvePath"->{
    Cell[83654, 3290, 683, 26, 93, "Text",
      CellTags->"SolvePath"]},
  "SolveSensitivity"->{
    Cell[84340, 3318, 629, 21, 94, "Text",
      CellTags->"SolveSensitivity"]},
  "SplineFit"->{
    Cell[84972, 3341, 368, 15, 53, "Text",
      CellTags->"SplineFit"]},
  "SplineFunction"->{
    Cell[85343, 3358, 480, 17, 73, "Text",
      CellTags->"SplineFunction"]},
  "StageSwitch"->{
    Cell[85826, 3377, 1177, 50, 134, "Text",
      CellTags->"StageSwitch"]},
  "Static"->{
    Cell[87006, 3429, 422, 13, 73, "Text",
      CellTags->"Static"]},
  "Step"->{
    Cell[87431, 3444, 647, 25, 74, "Text",
      CellTags->"Step"]},
  "StepMech"->{
    Cell[88081, 3471, 380, 12, 72, "Text",
      CellTags->"StepMech"]},
  "StepSize"->{
    Cell[88464, 3485, 255, 8, 53, "Text",
      CellTags->"StepSize"]},
  "SymbolBasis"->{
    Cell[88722, 3495, 347, 10, 72, "Text",
      CellTags->"SymbolBasis"]},
  "SysBody"->{
    Cell[89072, 3507, 208, 7, 53, "Text",
      CellTags->"SysBody"]},
  "SysCon"->{
    Cell[89283, 3516, 224, 7, 53, "Text",
      CellTags->"SysCon"]},
  "SysLoad"->{
    Cell[89510, 3525, 214, 7, 53, "Text",
      CellTags->"SysLoad"]},
  "SysPlot"->{
    Cell[89727, 3534, 326, 10, 73, "Text",
      CellTags->"SysPlot"]},
  "Tangent"->{
    Cell[90056, 3546, 859, 34, 93, "Text",
      CellTags->"Tangent"]},
  "TangentConstraint"->{
    Cell[90918, 3582, 400, 11, 93, "Text",
      CellTags->"TangentConstraint"]},
  "Time"->{
    Cell[91321, 3595, 410, 13, 74, "Text",
      CellTags->"Time"]},
  "TimeInterpolate"->{
    Cell[91734, 3610, 818, 31, 112, "Text",
      CellTags->"TimeInterpolate"]},
  "TimeSwitch"->{
    Cell[92555, 3643, 1988, 92, 174, "Text",
      CellTags->"TimeSwitch"]},
  "Translate2"->{
    Cell[94546, 3737, 468, 20, 53, "Text",
      CellTags->"Translate2"]},
  "TwoGears1"->{
    Cell[95017, 3759, 739, 30, 92, "Text",
      CellTags->"TwoGears1"]},
  "TwoGears2"->{
    Cell[95759, 3791, 874, 33, 110, "Text",
      CellTags->"TwoGears2"]},
  "TwoPulleys2"->{
    Cell[96636, 3826, 1007, 40, 110, "Text",
      CellTags->"TwoPulleys2"]},
  "Type"->{
    Cell[97646, 3868, 419, 16, 74, "Text",
      CellTags->"Type"]},
  "Unit"->{
    Cell[98068, 3886, 260, 10, 34, "Text",
      CellTags->"Unit"]},
  "Vector"->{
    Cell[98331, 3898, 786, 31, 112, "Text",
      CellTags->"Vector"]},
  "Velocity"->{
    Cell[99120, 3931, 646, 22, 94, "Text",
      CellTags->"Velocity"]},
  "VelocityTerms"->{
    Cell[99769, 3955, 363, 12, 53, "Text",
      CellTags->"VelocityTerms"]},
  "Vertex"->{
    Cell[100135, 3969, 734, 32, 72, "Text",
      CellTags->"Vertex"]},
  "Wheel"->{
    Cell[100872, 4003, 581, 25, 74, "Text",
      CellTags->"Wheel"]},
  "XYToPolar"->{
    Cell[101456, 4030, 471, 20, 54, "Text",
      CellTags->"XYToPolar"]},
  "$MechPostIterate"->{
    Cell[101930, 4052, 247, 7, 54, "Text",
      CellTags->"$MechPostIterate"]},
  "$MechPreSolve"->{
    Cell[102180, 4061, 225, 6, 53, "Text",
      CellTags->"$MechPreSolve"]},
  "$MechPrimeRules"->{
    Cell[102408, 4069, 581, 18, 114, "Text",
      CellTags->"$MechPrimeRules"]},
  "$MechProcessFunction"->{
    Cell[102992, 4089, 356, 10, 74, "Text",
      CellTags->"$MechProcessFunction"]},
  "$MechTimeRules"->{
    Cell[103351, 4101, 570, 18, 94, "Text",
      CellTags->"$MechTimeRules"]},
  "$MechVariables"->{
    Cell[103924, 4121, 284, 7, 72, "Text",
      CellTags->"$MechVariables"]},
  "$MechVersion"->{
    Cell[104211, 4130, 200, 7, 34, "Text",
      CellTags->"$MechVersion"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Mech2D", 105026, 4156},
  {"Absolute", 105112, 4159},
  {"Acceleration", 105202, 4162},
  {"AccelerationTerms", 105302, 4165},
  {"AddLoads", 105398, 4168},
  {"Alpha", 105482, 4171},
  {"Angle", 105563, 4174},
  {"Angular", 105647, 4177},
  {"Applied", 105732, 4180},
  {"ArcLength", 105819, 4183},
  {"Arrow", 105904, 4186},
  {"Bar", 105985, 4189},
  {"Body", 106063, 4192},
  {"BodyEnergy", 106150, 4195},
  {"Box", 106234, 4198},
  {"BuildMech", 106317, 4201},
  {"CamPlot", 106405, 4204},
  {"CamToCam1", 106493, 4207},
  {"CamToCircle1", 106588, 4210},
  {"CamToLine1", 106684, 4213},
  {"CamToPoint1", 106778, 4216},
  {"Centrifugal", 106873, 4219},
  {"Centroid", 106964, 4222},
  {"CheckRules", 107054, 4225},
  {"CheckSystem", 107147, 4228},
  {"ClearMech", 107239, 4231},
  {"ClearParameters", 107334, 4234},
  {"Closed", 107427, 4237},
  {"CompositeInertia", 107521, 4240},
  {"Constraint", 107619, 4243},
  {"ConstraintCorrection", 107723, 4246},
  {"Constraints", 107826, 4249},
  {"Coordinates", 107920, 4252},
  {"Corrector", 108012, 4255},
  {"CoupleSystem", 108105, 4258},
  {"Cross", 108193, 4261},
  {"Cubic", 108275, 4264},
  {"CutOff", 108358, 4267},
  {"D2DistanceDT2", 108450, 4270},
  {"DDistanceDT", 108546, 4273},
  {"Diagnostics", 108640, 4276},
  {"DirectedDistance1", 108739, 4279},
  {"DirectedPosition2", 108845, 4282},
  {"Direction", 108944, 4285},
  {"Distance", 109033, 4288},
  {"Dynamic", 109121, 4291},
  {"Edge", 109206, 4294},
  {"EndConditions", 109297, 4297},
  {"Euler", 109388, 4300},
  {"EulerParameters", 109480, 4303},
  {"Faces", 109573, 4306},
  {"Facet", 109656, 4309},
  {"FindSwitchTime", 109749, 4312},
  {"FindTime", 109845, 4315},
  {"FitDegree", 109935, 4318},
  {"Force", 110022, 4321},
  {"Free", 110104, 4324},
  {"FreeSystem", 110191, 4327},
  {"FunctionOfTime", 110287, 4330},
  {"Generalized", 110384, 4333},
  {"Global", 110475, 4336},
  {"Gravity", 110560, 4339},
  {"HeadSize", 110648, 4342},
  {"IMatrix", 110735, 4345},
  {"IncludedAngle", 110827, 4348},
  {"Inertia", 110920, 4351},
  {"InitialCondition", 111016, 4354},
  {"InitialGuess", 111118, 4357},
  {"Interference", 111216, 4360},
  {"IntersectionPoint", 111318, 4363},
  {"Involute", 111416, 4366},
  {"Jacobian", 111507, 4369},
  {"KillMech", 111596, 4372},
  {"Kinematic", 111685, 4375},
  {"LambdaGuess", 111778, 4378},
  {"LastSolve", 111872, 4381},
  {"Line", 111958, 4384},
  {"Linear", 112043, 4387},
  {"Load", 112126, 4390},
  {"Loads", 112208, 4393},
  {"Local", 112291, 4396},
  {"LocalAxes", 112377, 4399},
  {"Location", 112467, 4402},
  {"LockMech", 112556, 4405},
  {"LocusPlot", 112647, 4408},
  {"Magnitude", 112738, 4411},
  {"MakeRules", 112829, 4414},
  {"Mass", 112916, 4417},
  {"MassMatrix", 113003, 4420},
  {"MaxError", 113094, 4423},
  {"Mech", 113179, 4426},
  {"MechPrimitive", 113268, 4429},
  {"Moment", 113361, 4432},
  {"Natural", 113447, 4435},
  {"Omega", 113532, 4438},
  {"OriginLock2", 113621, 4441},
  {"Orthogonal1", 113716, 4444},
  {"Parallel1", 113809, 4447},
  {"ParallelAxis", 113903, 4450},
  {"Parameterize", 114001, 4453},
  {"Parameters", 114096, 4456},
  {"PathSystem", 114190, 4459},
  {"Point", 114277, 4462},
  {"PointLabel", 114365, 4465},
  {"PointList", 114457, 4468},
  {"PointOnLine1", 114553, 4471},
  {"PointOnLines2", 114651, 4474},
  {"PointToLineDistance", 114756, 4477},
  {"PointToLocal", 114860, 4480},
  {"PolarToXY", 114954, 4483},
  {"Predictor", 115045, 4486},
  {"ProjectOnLine", 115140, 4489},
  {"Quadratic", 115235, 4492},
  {"Quartic", 115324, 4495},
  {"RackAndPinion2", 115418, 4498},
  {"Reaction", 115514, 4501},
  {"Relative", 115605, 4504},
  {"RelativeAngle1", 115700, 4507},
  {"RelativeDistance1", 115804, 4510},
  {"RelativeVelocity", 115910, 4513},
  {"RelativeX1", 116009, 4516},
  {"RelativeY1", 116102, 4519},
  {"RequiredEquations", 116202, 4522},
  {"Revolute2", 116302, 4525},
  {"RMatrix", 116391, 4528},
  {"Rotation", 116478, 4531},
  {"RotationLock1", 116572, 4534},
  {"RotationMatrix", 116673, 4537},
  {"SaveMech", 116768, 4540},
  {"SensitivitySystem", 116866, 4543},
  {"SetBodies", 116964, 4546},
  {"SetConstraints", 117060, 4549},
  {"SetCouple", 117157, 4552},
  {"SetFree", 117246, 4555},
  {"SetGuess", 117335, 4558},
  {"SetLoads", 117425, 4561},
  {"SetParameters", 117520, 4564},
  {"SetPath", 117613, 4567},
  {"SetSensitivity", 117708, 4570},
  {"SetSymbols", 117805, 4573},
  {"Solution", 117897, 4576},
  {"SolveCouple", 117989, 4579},
  {"SolveFree", 118082, 4582},
  {"SolveMech", 118174, 4585},
  {"SolvePath", 118267, 4588},
  {"SolveSensitivity", 118365, 4591},
  {"SplineFit", 118463, 4594},
  {"SplineFunction", 118559, 4597},
  {"StageSwitch", 118657, 4600},
  {"Static", 118749, 4603},
  {"Step", 118832, 4606},
  {"StepMech", 118917, 4609},
  {"StepSize", 119006, 4612},
  {"SymbolBasis", 119097, 4615},
  {"SysBody", 119188, 4618},
  {"SysCon", 119273, 4621},
  {"SysLoad", 119358, 4624},
  {"SysPlot", 119444, 4627},
  {"Tangent", 119531, 4630},
  {"TangentConstraint", 119628, 4633},
  {"Time", 119722, 4636},
  {"TimeInterpolate", 119814, 4639},
  {"TimeSwitch", 119913, 4642},
  {"Translate2", 120008, 4645},
  {"TwoGears1", 120100, 4648},
  {"TwoGears2", 120191, 4651},
  {"TwoPulleys2", 120285, 4654},
  {"Type", 120375, 4657},
  {"Unit", 120456, 4660},
  {"Vector", 120539, 4663},
  {"Velocity", 120627, 4666},
  {"VelocityTerms", 120721, 4669},
  {"Vertex", 120813, 4672},
  {"Wheel", 120898, 4675},
  {"XYToPolar", 120986, 4678},
  {"$MechPostIterate", 121085, 4681},
  {"$MechPreSolve", 121187, 4684},
  {"$MechPrimeRules", 121288, 4687},
  {"$MechProcessFunction", 121398, 4690},
  {"$MechTimeRules", 121506, 4693},
  {"$MechVariables", 121608, 4696},
  {"$MechVersion", 121707, 4699}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 71, 2, 54, "Subtitle",
  CellTags->"Mech2D"],
Cell[1805, 55, 517, 19, 94, "Text",
  CellTags->"Absolute"],
Cell[2325, 76, 703, 22, 112, "Text",
  CellTags->"Acceleration"],
Cell[3031, 100, 375, 12, 72, "Text",
  CellTags->"AccelerationTerms"],
Cell[3409, 114, 393, 12, 73, "Text",
  CellTags->"AddLoads"],
Cell[3805, 128, 272, 11, 34, "Text",
  CellTags->"Alpha"],
Cell[4080, 141, 902, 36, 113, "Text",
  CellTags->"Angle"],
Cell[4985, 179, 346, 10, 72, "Text",
  CellTags->"Angular"],
Cell[5334, 191, 405, 14, 73, "Text",
  CellTags->"Applied"],
Cell[5742, 207, 546, 19, 94, "Text",
  CellTags->"ArcLength"],
Cell[6291, 228, 1024, 36, 132, "Text",
  CellTags->"Arrow"],
Cell[7318, 266, 481, 20, 54, "Text",
  CellTags->"Bar"],
Cell[7802, 288, 1063, 39, 154, "Text",
  CellTags->"Body"],
Cell[8868, 329, 286, 11, 53, "Text",
  CellTags->"BodyEnergy"],
Cell[9157, 342, 780, 32, 93, "Text",
  CellTags->"Box"],
Cell[9940, 376, 841, 30, 132, "Text",
  CellTags->"BuildMech"],
Cell[10784, 408, 767, 32, 91, "Text",
  CellTags->"CamPlot"],
Cell[11554, 442, 1361, 52, 150, "Text",
  CellTags->"CamToCam1"],
Cell[12918, 496, 1336, 49, 168, "Text",
  CellTags->"CamToCircle1"],
Cell[14257, 547, 980, 38, 111, "Text",
  CellTags->"CamToLine1"],
Cell[15240, 587, 978, 38, 111, "Text",
  CellTags->"CamToPoint1"],
Cell[16221, 627, 305, 11, 53, "Text",
  CellTags->"Centrifugal"],
Cell[16529, 640, 585, 19, 93, "Text",
  CellTags->"Centroid"],
Cell[17117, 661, 476, 13, 93, "Text",
  CellTags->"CheckRules"],
Cell[17596, 676, 402, 13, 74, "Text",
  CellTags->"CheckSystem"],
Cell[18001, 691, 263, 8, 53, "Text",
  CellTags->"ClearMech"],
Cell[18267, 701, 345, 12, 53, "Text",
  CellTags->"ClearParameters"],
Cell[18615, 715, 319, 10, 72, "Text",
  CellTags->"Closed"],
Cell[18937, 727, 892, 38, 92, "Text",
  CellTags->"CompositeInertia"],
Cell[19832, 767, 1463, 56, 170, "Text",
  CellTags->"Constraint"],
Cell[21298, 825, 404, 11, 92, "Text",
  CellTags->"ConstraintCorrection"],
Cell[21705, 838, 413, 13, 72, "Text",
  CellTags->"Constraints"],
Cell[22121, 853, 443, 15, 74, "Text",
  CellTags->"Coordinates"],
Cell[22567, 870, 343, 11, 73, "Text",
  CellTags->"Corrector"],
Cell[22913, 883, 205, 7, 34, "Text",
  CellTags->"CoupleSystem"],
Cell[23121, 892, 351, 13, 54, "Text",
  CellTags->"Cross"],
Cell[23475, 907, 335, 11, 54, "Text",
  CellTags->"Cubic"],
Cell[23813, 920, 563, 14, 112, "Text",
  CellTags->"CutOff"],
Cell[24379, 936, 337, 12, 53, "Text",
  CellTags->"D2DistanceDT2"],
Cell[24719, 950, 326, 12, 53, "Text",
  CellTags->"DDistanceDT"],
Cell[25048, 964, 241, 9, 54, "Text",
  CellTags->"Diagnostics"],
Cell[25292, 975, 695, 31, 72, "Text",
  CellTags->"DirectedDistance1"],
Cell[25990, 1008, 738, 31, 72, "Text",
  CellTags->"DirectedPosition2"],
Cell[26731, 1041, 272, 9, 53, "Text",
  CellTags->"Direction"],
Cell[27006, 1052, 295, 11, 53, "Text",
  CellTags->"Distance"],
Cell[27304, 1065, 773, 24, 132, "Text",
  CellTags->"Dynamic"],
Cell[28080, 1091, 1074, 47, 93, "Text",
  CellTags->"Edge"],
Cell[29157, 1140, 493, 14, 93, "Text",
  CellTags->"EndConditions"],
Cell[29653, 1156, 332, 9, 72, "Text",
  CellTags->"Euler"],
Cell[29988, 1167, 382, 16, 53, "Text",
  CellTags->"EulerParameters"],
Cell[30373, 1185, 331, 11, 74, "Text",
  CellTags->"Faces"],
Cell[30707, 1198, 1113, 50, 93, "Text",
  CellTags->"Facet"],
Cell[31823, 1250, 967, 35, 134, "Text",
  CellTags->"FindSwitchTime"],
Cell[32793, 1287, 570, 19, 92, "Text",
  CellTags->"FindTime"],
Cell[33366, 1308, 519, 18, 93, "Text",
  CellTags->"FitDegree"],
Cell[33888, 1328, 700, 31, 74, "Text",
  CellTags->"Force"],
Cell[34591, 1361, 591, 20, 93, "Text",
  CellTags->"Free"],
Cell[35185, 1383, 199, 7, 34, "Text",
  CellTags->"FreeSystem"],
Cell[35387, 1392, 334, 9, 73, "Text",
  CellTags->"FunctionOfTime"],
Cell[35724, 1403, 794, 27, 132, "Text",
  CellTags->"Generalized"],
Cell[36521, 1432, 180, 7, 34, "Text",
  CellTags->"Global"],
Cell[36704, 1441, 465, 16, 72, "Text",
  CellTags->"Gravity"],
Cell[37172, 1459, 209, 7, 53, "Text",
  CellTags->"HeadSize"],
Cell[37384, 1468, 167, 6, 34, "Text",
  CellTags->"IMatrix"],
Cell[37554, 1476, 382, 14, 54, "Text",
  CellTags->"IncludedAngle"],
Cell[37939, 1492, 557, 19, 92, "Text",
  CellTags->"Inertia"],
Cell[38499, 1513, 661, 17, 134, "Text",
  CellTags->"InitialCondition"],
Cell[39163, 1532, 791, 29, 114, "Text",
  CellTags->"InitialGuess"],
Cell[39957, 1563, 415, 12, 91, "Text",
  CellTags->"Interference"],
Cell[40375, 1577, 404, 16, 53, "Text",
  CellTags->"IntersectionPoint"],
Cell[40782, 1595, 1253, 51, 130, "Text",
  CellTags->"Involute"],
Cell[42038, 1648, 403, 17, 53, "Text",
  CellTags->"Jacobian"],
Cell[42444, 1667, 292, 7, 72, "Text",
  CellTags->"KillMech"],
Cell[42739, 1676, 451, 13, 92, "Text",
  CellTags->"Kinematic"],
Cell[43193, 1691, 527, 14, 113, "Text",
  CellTags->"LambdaGuess"],
Cell[43723, 1707, 418, 13, 74, "Text",
  CellTags->"LastSolve"],
Cell[44144, 1722, 1004, 38, 131, "Text",
  CellTags->"Line"],
Cell[45151, 1762, 328, 11, 54, "Text",
  CellTags->"Linear"],
Cell[45482, 1775, 444, 19, 53, "Text",
  CellTags->"Load"],
Cell[45929, 1796, 620, 21, 94, "Text",
  CellTags->"Loads"],
Cell[46552, 1819, 178, 7, 34, "Text",
  CellTags->"Local"],
Cell[46733, 1828, 916, 38, 94, "Text",
  CellTags->"LocalAxes"],
Cell[47652, 1868, 665, 25, 94, "Text",
  CellTags->"Location"],
Cell[48320, 1895, 591, 19, 111, "Text",
  CellTags->"LockMech"],
Cell[48914, 1916, 711, 28, 70, "Text",
  CellTags->"LocusPlot"],
Cell[49628, 1946, 690, 23, 70, "Text",
  CellTags->"Magnitude"],
Cell[50321, 1971, 841, 25, 174, "Text",
  CellTags->"MakeRules"],
Cell[51165, 1998, 476, 18, 73, "Text",
  CellTags->"Mass"],
Cell[51644, 2018, 320, 12, 53, "Text",
  CellTags->"MassMatrix"],
Cell[51967, 2032, 356, 10, 73, "Text",
  CellTags->"MaxError"],
Cell[52326, 2044, 173, 5, 53, "Text",
  CellTags->"Mech"],
Cell[52502, 2051, 524, 14, 113, "Text",
  CellTags->"MechPrimitive"],
Cell[53029, 2067, 378, 16, 53, "Text",
  CellTags->"Moment"],
Cell[53410, 2085, 305, 10, 53, "Text",
  CellTags->"Natural"],
Cell[53718, 2097, 268, 11, 70, "Text",
  CellTags->"Omega"],
Cell[53989, 2110, 661, 25, 91, "Text",
  CellTags->"OriginLock2"],
Cell[54653, 2137, 463, 20, 53, "Text",
  CellTags->"Orthogonal1"],
Cell[55119, 2159, 457, 20, 53, "Text",
  CellTags->"Parallel1"],
Cell[55579, 2181, 755, 23, 131, "Text",
  CellTags->"ParallelAxis"],
Cell[56337, 2206, 431, 13, 72, "Text",
  CellTags->"Parameterize"],
Cell[56771, 2221, 710, 21, 133, "Text",
  CellTags->"Parameters"],
Cell[57484, 2244, 199, 7, 34, "Text",
  CellTags->"PathSystem"],
Cell[57686, 2253, 716, 27, 92, "Text",
  CellTags->"Point"],
Cell[58405, 2282, 698, 28, 73, "Text",
  CellTags->"PointLabel"],
Cell[59106, 2312, 1481, 56, 172, "Text",
  CellTags->"PointList"],
Cell[60590, 2370, 603, 26, 73, "Text",
  CellTags->"PointOnLine1"],
Cell[61196, 2398, 557, 25, 53, "Text",
  CellTags->"PointOnLines2"],
Cell[61756, 2425, 381, 16, 53, "Text",
  CellTags->"PointToLineDistance"],
Cell[62140, 2443, 395, 16, 53, "Text",
  CellTags->"PointToLocal"],
Cell[62538, 2461, 471, 20, 54, "Text",
  CellTags->"PolarToXY"],
Cell[63012, 2483, 335, 11, 73, "Text",
  CellTags->"Predictor"],
Cell[63350, 2496, 862, 36, 92, "Text",
  CellTags->"ProjectOnLine"],
Cell[64215, 2534, 341, 11, 73, "Text",
  CellTags->"Quadratic"],
Cell[64559, 2547, 333, 11, 73, "Text",
  CellTags->"Quartic"],
Cell[64895, 2560, 878, 32, 110, "Text",
  CellTags->"RackAndPinion2"],
Cell[65776, 2594, 1027, 41, 134, "Text",
  CellTags->"Reaction"],
Cell[66806, 2637, 500, 16, 92, "Text",
  CellTags->"Relative"],
Cell[67309, 2655, 590, 26, 53, "Text",
  CellTags->"RelativeAngle1"],
Cell[67902, 2683, 632, 26, 72, "Text",
  CellTags->"RelativeDistance1"],
Cell[68537, 2711, 402, 16, 53, "Text",
  CellTags->"RelativeVelocity"],
Cell[68942, 2729, 701, 32, 72, "Text",
  CellTags->"RelativeX1"],
Cell[69646, 2763, 701, 32, 72, "Text",
  CellTags->"RelativeY1"],
Cell[70350, 2797, 906, 24, 191, "Text",
  CellTags->"RequiredEquations"],
Cell[71259, 2823, 489, 20, 53, "Text",
  CellTags->"Revolute2"],
Cell[71751, 2845, 202, 7, 54, "Text",
  CellTags->"RMatrix"],
Cell[71956, 2854, 252, 10, 34, "Text",
  CellTags->"Rotation"],
Cell[72211, 2866, 852, 34, 110, "Text",
  CellTags->"RotationLock1"],
Cell[73066, 2902, 275, 10, 53, "Text",
  CellTags->"RotationMatrix"],
Cell[73344, 2914, 353, 13, 54, "Text",
  CellTags->"SaveMech"],
Cell[73700, 2929, 220, 7, 54, "Text",
  CellTags->"SensitivitySystem"],
Cell[73923, 2938, 548, 18, 93, "Text",
  CellTags->"SetBodies"],
Cell[74474, 2958, 777, 20, 151, "Text",
  CellTags->"SetConstraints"],
Cell[75254, 2980, 602, 26, 53, "Text",
  CellTags->"SetCouple"],
Cell[75859, 3008, 722, 24, 112, "Text",
  CellTags->"SetFree"],
Cell[76584, 3034, 551, 15, 113, "Text",
  CellTags->"SetGuess"],
Cell[77138, 3051, 834, 24, 133, "Text",
  CellTags->"SetLoads"],
Cell[77975, 3077, 506, 18, 74, "Text",
  CellTags->"SetParameters"],
Cell[78484, 3097, 821, 25, 154, "Text",
  CellTags->"SetPath"],
Cell[79308, 3124, 510, 17, 94, "Text",
  CellTags->"SetSensitivity"],
Cell[79821, 3143, 649, 21, 112, "Text",
  CellTags->"SetSymbols"],
Cell[80473, 3166, 546, 22, 74, "Text",
  CellTags->"Solution"],
Cell[81022, 3190, 599, 22, 94, "Text",
  CellTags->"SolveCouple"],
Cell[81624, 3214, 987, 36, 133, "Text",
  CellTags->"SolveFree"],
Cell[82614, 3252, 1037, 36, 153, "Text",
  CellTags->"SolveMech"],
Cell[83654, 3290, 683, 26, 93, "Text",
  CellTags->"SolvePath"],
Cell[84340, 3318, 629, 21, 94, "Text",
  CellTags->"SolveSensitivity"],
Cell[84972, 3341, 368, 15, 53, "Text",
  CellTags->"SplineFit"],
Cell[85343, 3358, 480, 17, 73, "Text",
  CellTags->"SplineFunction"],
Cell[85826, 3377, 1177, 50, 134, "Text",
  CellTags->"StageSwitch"],
Cell[87006, 3429, 422, 13, 73, "Text",
  CellTags->"Static"],
Cell[87431, 3444, 647, 25, 74, "Text",
  CellTags->"Step"],
Cell[88081, 3471, 380, 12, 72, "Text",
  CellTags->"StepMech"],
Cell[88464, 3485, 255, 8, 53, "Text",
  CellTags->"StepSize"],
Cell[88722, 3495, 347, 10, 72, "Text",
  CellTags->"SymbolBasis"],
Cell[89072, 3507, 208, 7, 53, "Text",
  CellTags->"SysBody"],
Cell[89283, 3516, 224, 7, 53, "Text",
  CellTags->"SysCon"],
Cell[89510, 3525, 214, 7, 53, "Text",
  CellTags->"SysLoad"],
Cell[89727, 3534, 326, 10, 73, "Text",
  CellTags->"SysPlot"],
Cell[90056, 3546, 859, 34, 93, "Text",
  CellTags->"Tangent"],
Cell[90918, 3582, 400, 11, 93, "Text",
  CellTags->"TangentConstraint"],
Cell[91321, 3595, 410, 13, 74, "Text",
  CellTags->"Time"],
Cell[91734, 3610, 818, 31, 112, "Text",
  CellTags->"TimeInterpolate"],
Cell[92555, 3643, 1988, 92, 174, "Text",
  CellTags->"TimeSwitch"],
Cell[94546, 3737, 468, 20, 53, "Text",
  CellTags->"Translate2"],
Cell[95017, 3759, 739, 30, 92, "Text",
  CellTags->"TwoGears1"],
Cell[95759, 3791, 874, 33, 110, "Text",
  CellTags->"TwoGears2"],
Cell[96636, 3826, 1007, 40, 110, "Text",
  CellTags->"TwoPulleys2"],
Cell[97646, 3868, 419, 16, 74, "Text",
  CellTags->"Type"],
Cell[98068, 3886, 260, 10, 34, "Text",
  CellTags->"Unit"],
Cell[98331, 3898, 786, 31, 112, "Text",
  CellTags->"Vector"],
Cell[99120, 3931, 646, 22, 94, "Text",
  CellTags->"Velocity"],
Cell[99769, 3955, 363, 12, 53, "Text",
  CellTags->"VelocityTerms"],
Cell[100135, 3969, 734, 32, 72, "Text",
  CellTags->"Vertex"],
Cell[100872, 4003, 581, 25, 74, "Text",
  CellTags->"Wheel"],
Cell[101456, 4030, 471, 20, 54, "Text",
  CellTags->"XYToPolar"],
Cell[101930, 4052, 247, 7, 54, "Text",
  CellTags->"$MechPostIterate"],
Cell[102180, 4061, 225, 6, 53, "Text",
  CellTags->"$MechPreSolve"],
Cell[102408, 4069, 581, 18, 114, "Text",
  CellTags->"$MechPrimeRules"],
Cell[102992, 4089, 356, 10, 74, "Text",
  CellTags->"$MechProcessFunction"],
Cell[103351, 4101, 570, 18, 94, "Text",
  CellTags->"$MechTimeRules"],
Cell[103924, 4121, 284, 7, 72, "Text",
  CellTags->"$MechVariables"],
Cell[104211, 4130, 200, 7, 34, "Text",
  CellTags->"$MechVersion"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

