(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    112479,       3613]*)
(*NotebookOutlinePosition[    113417,       3645]*)
(*  CellTagsIndexPosition[    113373,       3641]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["Cable Pendulum"], "Title",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData["Example Mechanism for Mech3D"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["by Robert Beretta"], "Subsubtitle",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .72888 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.06283 -0.109331 1.06283 [
[ 0 0 0 0 ]
[ 1 .72888 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .72888 L
0 .72888 L
closepath
clip
newpath
0 g
.001 w
.53141 .40972 m
.53141 .71672 L
s
.53141 .40972 m
.82365 .36729 L
s
.53141 .71672 m
.16485 .589 L
s
.83484 .69029 m
.53141 .71672 L
s
.82365 .36729 m
.53141 .1373 L
s
.82365 .36729 m
.83484 .69029 L
s
.53141 .54517 m
.83484 .69029 L
s
.5 Mabswid
.31909 .46637 m .32961 .44353 L .33871 .47546 L closepath p .955 .741 .575 r
F P
0 g
s
.33558 .46406 m .34598 .44117 L .35505 .47321 L closepath p .957 .742 .572 r
F P
0 g
s
.33697 .48432 m .38566 .4777 L .33735 .45466 L p .481 .816 .999 r
F P
0 g
s
.33735 .45466 m .28754 .46173 L .33697 .48432 L p .481 .816 .999 r
F P
0 g
s
.38566 .4777 m .33697 .48432 L .33656 .50238 L p .585 .426 .632 r
F P
0 g
s
.33697 .48432 m .28754 .46173 L .28701 .48032 L p .953 .74 .577 r
F P
0 g
s
.28701 .48032 m .33656 .50238 L .33697 .48432 L p .953 .74 .577 r
F P
0 g
s
.33656 .50238 m .38535 .49591 L .38566 .4777 L p .585 .426 .632 r
F P
0 g
s
.33656 .50238 m .38535 .49591 L .33692 .47342 L p .474 .815 .999 r
F P
0 g
s
.005 w
.37404 .5074 m
.53141 .71672 L
s
.36721 .49831 m
.37404 .5074 L
s
.5 Mabswid
.33692 .47342 m .28701 .48032 L .33656 .50238 L p .474 .815 .999 r
F P
0 g
s
.33735 .45466 m .38566 .4777 L .38535 .49591 L p .958 .743 .569 r
F P
0 g
s
.38535 .49591 m .33692 .47342 L .33735 .45466 L p .958 .743 .569 r
F P
0 g
s
.33451 .43973 m .34606 .43806 L .34107 .44499 L p .442 .056 .209 r
F P
0 g
s
.34107 .44499 m .32948 .44665 L .33451 .43973 L p .442 .056 .209 r
F P
0 g
s
.27019 .2619 m .27545 .27594 L .26256 .28128 L p .742 .638 .745 r
F P
0 g
s
.27545 .27594 m .27969 .29 L .26981 .2941 L p .711 .55 .668 r
F P
0 g
s
.26981 .2941 m .26256 .28128 L .27545 .27594 L p .711 .55 .668 r
F P
0 g
s
.27969 .29 m .28165 .2991 L p .27692 .30427 L .66 .431 .563 r
F P
0 g
s
.28165 .2991 m .28228 .30204 L .28097 .30259 L p .66 .431 .563 r
F P
0 g
s
.28097 .30259 m .27692 .30427 L p .28165 .2991 L .66 .431 .563 r
F P
0 g
s
.25621 .26769 m .26256 .28128 L .25137 .28785 L p .813 .666 .7 r
F P
0 g
s
.26256 .28128 m .25621 .26769 L .27019 .2619 L p .742 .638 .745 r
F P
0 g
s
.26256 .28128 m .26981 .2941 L .26126 .29916 L p .77 .568 .625 r
F P
0 g
s
.26126 .29916 m .25137 .28785 L .26256 .28128 L p .77 .568 .625 r
F P
0 g
s
.27692 .30427 m .26981 .2941 L .27969 .29 L p .66 .431 .563 r
F P
0 g
s
.26981 .2941 m .27692 .30427 L .27229 .30702 L p .703 .44 .523 r
F P
0 g
s
.27229 .30702 m .26126 .29916 L .26981 .2941 L p .703 .44 .523 r
F P
0 g
s
.34606 .43806 m .33451 .43973 L .27897 .30635 L p .606 .606 .825 r
F P
0 g
s
.28097 .30259 m .27692 .30427 L .27897 .30635 L p .54 .208 .354 r
F P
0 g
s
.28132 .30622 m .28136 .30631 L .27897 .30635 L .606 .606 .825 r
F
.28105 .30635 m .2812 .30666 L .2791 .3066 L F
.28143 .30712 m .34606 .43806 L .27964 .30766 L F
.28138 .30635 m .34606 .43806 L .28105 .30635 L F
.29198 .30036 m .28742 .30531 L p .29132 .30313 L .389 .053 .27 r
F P
0 g
s
.29069 .30432 m .29485 .30116 L p .29132 .30313 L .389 .053 .27 r
F P
0 g
s
.29132 .30313 m .28742 .30531 L .29069 .30432 L .389 .053 .27 r
F
.29198 .30036 m .28757 .30067 L .28503 .30583 L p .457 .133 .328 r
F P
0 g
s
.28742 .30531 m .29198 .30036 L p .28503 .30583 L .457 .133 .328 r
F P
0 g
s
.28757 .30067 m .28228 .30204 L .28256 .30615 L p .506 .184 .354 r
F P
0 g
s
.28503 .30583 m .28757 .30067 L p .28256 .30615 L .506 .184 .354 r
F P
0 g
s
.29125 .30567 m .34606 .43806 L p .28198 .30756 L .606 .606 .825 r
F P
0 g
s
.28132 .30622 m .28632 .30594 L .28198 .30756 L .606 .606 .825 r
F
.28632 .30594 m .29125 .30567 L .28198 .30756 L F
.28395 .25825 m .28815 .27259 L .27545 .27594 L p .659 .595 .772 r
F P
0 g
s
.27545 .27594 m .27019 .2619 L .28395 .25825 L p .659 .595 .772 r
F P
0 g
s
.27969 .29 m .27545 .27594 L .28815 .27259 L p .637 .507 .688 r
F P
0 g
s
.28815 .27259 m .28942 .28746 L .27969 .29 L p .637 .507 .688 r
F P
0 g
s
.28228 .30204 m .27969 .29 L .28942 .28746 L p .599 .393 .573 r
F P
0 g
s
.28942 .28746 m .28757 .30067 L .28228 .30204 L p .599 .393 .573 r
F P
0 g
s
.28757 .30067 m .28942 .28746 L .29757 .28685 L p .51 .313 .549 r
F P
0 g
s
.29757 .28685 m .29198 .30036 L .28757 .30067 L p .51 .313 .549 r
F P
0 g
s
.26552 .27404 m .27728 .27193 L .29125 .30567 L p .606 .606 .825 r
F P
0 g
s
.28097 .30259 m .27897 .30635 L .28185 .30619 L .54 .208 .354 r
F
.28228 .30204 m .28097 .30259 L p .28185 .30619 L F P
0 g
s
.28256 .30615 m .28228 .30204 L p .28185 .30619 L .54 .208 .354 r
F P
0 g
s
.26552 .27404 m .29125 .30567 L .28132 .30622 L .606 .606 .825 r
F
.28617 .31287 m .34107 .44499 L p .29009 .30668 L .956 .742 .572 r
F P
0 g
s
.28924 .30743 m .28617 .31287 L .29009 .30668 L .956 .742 .572 r
F
.28937 .30682 m .28617 .31287 L .28992 .30622 L F
.28707 .30932 m .28284 .31027 L .28533 .31085 L p .075 0 0 r
F P
0 g
s
.28822 .30807 m .28284 .31027 L .28707 .30932 L p .123 0 0 r
F P
0 g
s
.28981 .30592 m .28617 .31287 L .28982 .30596 L .956 .742 .572 r
F
.28954 .30628 m .28617 .31287 L .28981 .30592 L F
.28599 .31204 m .28617 .31287 L .28832 .30867 L F
.28782 .30904 m .28832 .30867 L .28977 .30582 L F
.28599 .31204 m .28832 .30867 L .28782 .30904 L F
.27984 .30845 m .33451 .43973 L p .27788 .31864 L .955 .741 .574 r
F P
0 g
s
.33451 .43973 m .32948 .44665 L .27413 .31422 L p .955 .741 .574 r
F P
0 g
s
.27229 .30702 m .27756 .30865 L p .27897 .30635 L .557 .206 .329 r
F P
0 g
s
.27343 .30635 m .27229 .30702 L p .27897 .30635 L .557 .206 .329 r
F P
0 g
s
.26126 .29916 m .27229 .30702 L .26909 .30988 L p .729 .412 .444 r
F P
0 g
s
.27229 .30702 m .26909 .30988 L .27648 .31009 L p .556 .177 .278 r
F P
0 g
s
.27489 .31224 m .27984 .30845 L .27788 .31864 L .955 .741 .574 r
F
.2678 .31242 m .26864 .31425 L .27357 .31287 L p .476 .02 .09 r
F P
0 g
s
.27596 .31079 m .27984 .30845 L .27489 .31224 L .955 .741 .574 r
F
.27532 .31135 m .2678 .31242 L p .27357 .31287 L .476 .02 .09 r
F P
0 g
s
.26909 .30988 m .2678 .31242 L .27532 .31135 L p .531 .116 .199 r
F P
0 g
s
.27648 .31009 m .26909 .30988 L p .27532 .31135 L .531 .116 .199 r
F P
0 g
s
.27756 .30865 m .27229 .30702 L p .27648 .31009 L .556 .177 .278 r
F P
0 g
s
.27897 .30635 m .27692 .30427 L .27343 .30635 L p .557 .206 .329 r
F P
0 g
s
.26003 .28046 m .2788 .30697 L .27489 .31224 L .955 .741 .574 r
F
.27413 .31422 m .27357 .31287 L p .27509 .31267 L F P
0 g
s
.27357 .31287 m .26003 .28046 L p .27477 .312 L .955 .741 .574 r
F P
0 g
s
.27477 .312 m .27509 .31267 L .27357 .31287 L .955 .741 .574 r
F
.27509 .31267 m .33451 .43973 L .27413 .31422 L F
.27897 .30635 m .26552 .27404 L p .28132 .30622 L .606 .606 .825 r
F P
0 g
s
.26003 .28046 m .26552 .27404 L .27897 .30635 L p .955 .741 .574 r
F P
0 g
s
.26003 .28046 m .27897 .30635 L .27871 .30684 L .955 .741 .574 r
F
.27183 .27835 m .26003 .28046 L .27357 .31287 L p .605 .606 .825 r
F P
0 g
s
.28533 .31085 m .28284 .31027 L p .2827 .31164 L .086 0 0 r
F P
0 g
s
.28347 .31233 m .27972 .31253 L .32948 .44665 L .605 .606 .825 r
F
.27717 .31267 m .28284 .31027 L .27357 .31287 L p .385 0 0 r
F P
0 g
s
.27357 .31287 m .28284 .31027 L .27532 .31135 L p .476 .02 .09 r
F P
0 g
s
.27648 .31009 m .27713 .30978 L .27596 .31079 L .955 .741 .574 r
F
.27713 .30978 m .27984 .30845 L .27596 .31079 L F
.2788 .30697 m .27905 .30732 L .27648 .31009 L F
.27905 .30732 m .27984 .30845 L .27648 .31009 L F
.27532 .31135 m .28284 .31027 L .27648 .31009 L p .531 .116 .199 r
F P
0 g
s
.27648 .31009 m .28284 .31027 L .27756 .30865 L p .556 .177 .278 r
F P
0 g
s
.2812 .30666 m .28143 .30712 L .27933 .30706 L .606 .606 .825 r
F
.28143 .30712 m .27964 .30766 L .27933 .30706 L F
.2812 .30666 m .27933 .30706 L .2791 .3066 L F
.28136 .30631 m .2791 .3066 L .27897 .30635 L F
.27897 .30635 m .27984 .30845 L p .27871 .30684 L .955 .741 .574 r
F P
0 g
s
.27756 .30865 m .28284 .31027 L .27897 .30635 L p .557 .206 .329 r
F P
0 g
s
.28284 .31027 m .28204 .31183 L p .2827 .31164 L .086 0 0 r
F P
0 g
s
.28136 .30631 m .28138 .30635 L .28105 .30635 L .606 .606 .825 r
F
.27897 .30635 m .28284 .31027 L p .28185 .30619 L .54 .208 .354 r
F P
0 g
s
.28321 .31158 m .2785 .3126 L .28347 .31233 L .605 .606 .825 r
F
.27357 .31287 m .27413 .31422 L p .27972 .31253 L F P
0 g
s
.27413 .31422 m .32948 .44665 L p .27972 .31253 L .605 .606 .825 r
F P
0 g
s
.27149 .31508 m .27591 .31478 L .27965 .31235 L p .27 0 0 r
F P
0 g
s
.27965 .31235 m .28284 .31027 L .27717 .31267 L p .27 0 0 r
F P
0 g
s
.27848 .3125 m .27717 .31267 L .2785 .3126 L .605 .606 .825 r
F
.28204 .31183 m .28284 .31027 L .27965 .31235 L p .158 0 0 r
F P
0 g
s
.27183 .27835 m .2785 .3126 L .28321 .31158 L .605 .606 .825 r
F
.27717 .31267 m .27149 .31508 L p .27965 .31235 L .27 0 0 r
F P
0 g
s
.27183 .27835 m .27357 .31287 L .27717 .31267 L .605 .606 .825 r
F
.27183 .27835 m .27717 .31267 L .27848 .3125 L F
.27591 .31478 m .28124 .3134 L .28204 .31183 L p .158 0 0 r
F P
0 g
s
.27965 .31235 m .27591 .31478 L p .28204 .31183 L .158 0 0 r
F P
0 g
s
.28318 .31149 m .32948 .44665 L .28533 .31085 L .605 .606 .825 r
F
.28257 .31285 m .28533 .31085 L .2827 .31164 L .086 0 0 r
F
.27149 .31508 m .27717 .31267 L p .27357 .31287 L .385 0 0 r
F P
0 g
s
.27357 .31287 m .26864 .31425 L .27079 .31488 L p .385 0 0 r
F P
0 g
s
.27079 .31488 m .27149 .31508 L p .27357 .31287 L .385 0 0 r
F P
0 g
s
.32948 .44665 m .34107 .44499 L .28533 .31085 L p .605 .606 .825 r
F P
0 g
s
.28929 .30662 m .28284 .31027 L .28822 .30807 L p .209 0 .05 r
F P
0 g
s
.28284 .31027 m .28929 .30662 L p .28957 .30616 L .305 0 .177 r
F P
0 g
s
.28977 .30582 m .28954 .30628 L .28981 .30592 L .956 .742 .572 r
F
.28982 .30596 m .28937 .30682 L .28992 .30622 L F
.34107 .44499 m .34606 .43806 L .29069 .30432 L p F P
0 g
s
.29069 .30432 m .28284 .31027 L p .28957 .30616 L .305 0 .177 r
F P
0 g
s
.28977 .30582 m .28982 .30596 L .29069 .30432 L .956 .742 .572 r
F
.28982 .30596 m .34107 .44499 L .29069 .30432 L F
.29553 .30252 m .29069 .30432 L .28957 .30616 L .305 0 .177 r
F
.28742 .30531 m .28284 .31027 L .29069 .30432 L p .389 .053 .27 r
F P
0 g
s
.29069 .30432 m .27728 .27193 L p .28977 .30582 L .956 .742 .572 r
F P
0 g
s
.28503 .30583 m .28284 .31027 L .28742 .30531 L p .457 .133 .328 r
F P
0 g
s
.28256 .30615 m .28284 .31027 L .28503 .30583 L p .506 .184 .354 r
F P
0 g
s
.28284 .31027 m .28256 .30615 L p .28185 .30619 L .54 .208 .354 r
F P
0 g
s
.28533 .31085 m .27183 .27835 L p .28318 .31149 L .605 .606 .825 r
F P
0 g
s
.28124 .3134 m .28257 .31285 L p .2827 .31164 L .086 0 0 r
F P
0 g
s
.28204 .31183 m .28124 .3134 L p .2827 .31164 L .086 0 0 r
F P
0 g
s
.27728 .27193 m .28599 .31204 L .28977 .30582 L .956 .742 .572 r
F
.27183 .27835 m .28617 .31287 L p .27728 .27193 L F P
0 g
s
.28257 .31285 m .28666 .31115 L .28533 .31085 L p .086 0 0 r
F P
0 g
s
.28992 .30622 m .28924 .30743 L .29009 .30668 L .956 .742 .572 r
F
.29451 .30549 m .29575 .30296 L .28929 .30662 L p .209 0 .05 r
F P
0 g
s
.28822 .30807 m .29451 .30549 L p .28929 .30662 L .209 0 .05 r
F P
0 g
s
.29575 .30296 m .29553 .30252 L p .28957 .30616 L .305 0 .177 r
F P
0 g
s
.28929 .30662 m .29575 .30296 L p .28957 .30616 L .305 0 .177 r
F P
0 g
s
.28666 .31115 m .29132 .30837 L .28707 .30932 L p .075 0 0 r
F P
0 g
s
.28533 .31085 m .28666 .31115 L p .28707 .30932 L .075 0 0 r
F P
0 g
s
.29132 .30837 m .29451 .30549 L .28822 .30807 L p .123 0 0 r
F P
0 g
s
.28707 .30932 m .29132 .30837 L p .28822 .30807 L .123 0 0 r
F P
0 g
s
.29553 .30252 m .29485 .30116 L .29069 .30432 L p .305 0 .177 r
F P
0 g
s
.29485 .30116 m .29268 .30056 L p .29132 .30313 L .389 .053 .27 r
F P
0 g
s
.29268 .30056 m .29198 .30036 L p .29132 .30313 L .389 .053 .27 r
F P
0 g
s
.001 w
.18105 .20624 m
.1872 .20981 L
s
.1872 .20981 m
.21006 .22308 L
s
.21006 .22308 m
.23079 .23512 L
s
.23079 .23512 m
.23106 .23528 L
s
.23106 .23528 m
.25642 .25001 L
s
.25642 .25001 m
.26618 .25568 L
s
.26618 .25568 m
.2748 .26068 L
s
.28668 .26758 m
.29581 .27288 L
s
.29581 .27288 m
.53141 .40972 L
s
.5 Mabswid
.32688 .48372 m .33611 .51595 L .34647 .49263 L closepath p .956 .741 .573 r
F P
0 g
s
.005 w
.33611 .51595 m
.70281 .62714 L
s
.5 Mabswid
.28754 .46173 m .33735 .45466 L .33692 .47342 L p .579 .419 .628 r
F P
0 g
s
.33692 .47342 m .28701 .48032 L .28754 .46173 L p .579 .419 .628 r
F P
0 g
s
.26467 .24995 m .27019 .2619 L .25621 .26769 L p .764 .725 .816 r
F P
0 g
s
.27742 .24655 m .28395 .25825 L .27019 .2619 L p .67 .681 .851 r
F P
0 g
s
.27019 .2619 m .26467 .24995 L .27742 .24655 L p .67 .681 .851 r
F P
0 g
s
.29547 .2573 m .29879 .27175 L .28815 .27259 L p .533 .517 .783 r
F P
0 g
s
.28815 .27259 m .28395 .25825 L .29547 .2573 L p .533 .517 .783 r
F P
0 g
s
.28942 .28746 m .28815 .27259 L .29879 .27175 L p .529 .425 .681 r
F P
0 g
s
.25171 .25531 m .25621 .26769 L .24407 .27478 L p .845 .762 .771 r
F P
0 g
s
.25621 .26769 m .25171 .25531 L .26467 .24995 L p .764 .725 .816 r
F P
0 g
s
.25137 .28785 m .24407 .27478 L .25621 .26769 L p .813 .666 .7 r
F P
0 g
s
.29879 .27175 m .29757 .28685 L .28942 .28746 L p .529 .425 .681 r
F P
0 g
s
.24407 .27478 m .25137 .28785 L .24355 .29468 L p .884 .678 .618 r
F P
0 g
s
.25137 .28785 m .26126 .29916 L .25531 .30441 L p .821 .559 .542 r
F P
0 g
s
.25531 .30441 m .24355 .29468 L .25137 .28785 L p .821 .559 .542 r
F P
0 g
s
.28808 .24563 m .29547 .2573 L .28395 .25825 L p .524 .609 .88 r
F P
0 g
s
.28395 .25825 m .27742 .24655 L .28808 .24563 L p .524 .609 .88 r
F P
0 g
s
.26909 .30988 m .25531 .30441 L .26126 .29916 L p .729 .412 .444 r
F P
0 g
s
.005 w
.16485 .589 m
.30285 .47516 L
s
.30285 .47516 m
.31208 .46754 L
s
.5 Mabswid
.24045 .26185 m .24407 .27478 L .23556 .28213 L p .932 .798 .69 r
F P
0 g
s
.24407 .27478 m .24045 .26185 L .25171 .25531 L p .845 .762 .771 r
F P
0 g
s
.24355 .29468 m .23556 .28213 L .24407 .27478 L p .884 .678 .618 r
F P
0 g
s
.30577 .27357 m .3029 .28829 L .29757 .28685 L p .327 .25 .615 r
F P
0 g
s
.29757 .28685 m .29879 .27175 L .30577 .27357 L p .327 .25 .615 r
F P
0 g
s
.29198 .30036 m .29757 .28685 L .3029 .28829 L p .364 .163 .468 r
F P
0 g
s
.30303 .25919 m .30577 .27357 L .29879 .27175 L p .272 .332 .742 r
F P
0 g
s
.29879 .27175 m .29547 .2573 L .30303 .25919 L p .272 .332 .742 r
F P
0 g
s
.25972 .24187 m .26467 .24995 L .25171 .25531 L p .773 .831 .897 r
F P
0 g
s
.26951 .23925 m .27742 .24655 L .26467 .24995 L p .663 .786 .94 r
F P
0 g
s
.26467 .24995 m .25972 .24187 L .26951 .23925 L p .663 .786 .94 r
F P
0 g
s
.24974 .246 m .25171 .25531 L .24045 .26185 L p .862 .879 .849 r
F P
0 g
s
.25171 .25531 m .24974 .246 L .25972 .24187 L p .773 .831 .897 r
F P
0 g
s
.3029 .28829 m .29485 .30116 L .29198 .30036 L p .364 .163 .468 r
F P
0 g
s
.24355 .29468 m .25531 .30441 L .25288 .30908 L p .853 .488 .36 r
F P
0 g
s
.25531 .30441 m .26909 .30988 L .2678 .31242 L p .722 .323 .292 r
F P
0 g
s
.2678 .31242 m .25288 .30908 L .25531 .30441 L p .722 .323 .292 r
F P
0 g
s
.27769 .23852 m .28808 .24563 L .27742 .24655 L p .476 .714 .974 r
F P
0 g
s
.27742 .24655 m .26951 .23925 L .27769 .23852 L p .476 .714 .974 r
F P
0 g
s
.29505 .24733 m .30303 .25919 L .29547 .2573 L p .182 .416 .852 r
F P
0 g
s
.29547 .2573 m .28808 .24563 L .29505 .24733 L p .182 .416 .852 r
F P
0 g
s
.23556 .28213 m .24355 .29468 L .24031 .30075 L p .949 .641 .417 r
F P
0 g
s
.25288 .30908 m .24031 .30075 L .24355 .29468 L p .853 .488 .36 r
F P
0 g
s
.24108 .25101 m .24045 .26185 L .23255 .26861 L p .944 .934 .758 r
F P
0 g
s
.24045 .26185 m .24108 .25101 L .24974 .246 L p .862 .879 .849 r
F P
0 g
s
.23556 .28213 m .23255 .26861 L .24045 .26185 L p .932 .798 .69 r
F P
0 g
s
.30458 .29157 m .29575 .30296 L .29485 .30116 L p .099 0 .257 r
F P
0 g
s
.29485 .30116 m .3029 .28829 L .30458 .29157 L p .099 0 .257 r
F P
0 g
s
.30799 .27779 m .30458 .29157 L .3029 .28829 L p 0 0 .327 r
F P
0 g
s
.3029 .28829 m .30577 .27357 L .30799 .27779 L p 0 0 .327 r
F P
0 g
s
.23255 .26861 m .23556 .28213 L .232 .28865 L p .999 .791 .46 r
F P
0 g
s
.24031 .30075 m .232 .28865 L .23556 .28213 L p .949 .641 .417 r
F P
0 g
s
.25288 .30908 m .2678 .31242 L .26864 .31425 L p .622 .104 0 r
F P
0 g
s
.30542 .2637 m .30799 .27779 L .30577 .27357 L p 0 0 .36 r
F P
0 g
s
.30577 .27357 m .30303 .25919 L .30542 .2637 L p 0 0 .36 r
F P
0 g
s
.283 .23981 m .29505 .24733 L .28808 .24563 L p .016 .474 .874 r
F P
0 g
s
.28808 .24563 m .27769 .23852 L .283 .23981 L p .016 .474 .874 r
F P
0 g
s
.24031 .30075 m .25288 .30908 L .25438 .31245 L p .727 .197 0 r
F P
0 g
s
.26864 .31425 m .25438 .31245 L .25288 .30908 L p .622 .104 0 r
F P
0 g
s
.30232 .29622 m .29451 .30549 L .29575 .30296 L p 0 0 0 r
F P
0 g
s
.29575 .30296 m .30458 .29157 L .30232 .29622 L p 0 0 0 r
F P
0 g
s
.25606 .23893 m .25972 .24187 L .24974 .246 L p .685 .952 .954 r
F P
0 g
s
.26139 .2375 m .26951 .23925 L .25972 .24187 L p .541 .89 .981 r
F P
0 g
s
.25972 .24187 m .25606 .23893 L .26139 .2375 L p .541 .89 .981 r
F P
0 g
s
.25064 .24118 m .24974 .246 L .24108 .25101 L p .757 .992 .881 r
F P
0 g
s
.24974 .246 m .25064 .24118 L .25606 .23893 L p .685 .952 .954 r
F P
0 g
s
.25438 .31245 m .26864 .31425 L .27149 .31508 L p .283 0 0 r
F P
0 g
s
.26582 .23711 m .27769 .23852 L .26951 .23925 L p .26 .748 .92 r
F P
0 g
s
.26951 .23925 m .26139 .2375 L .26582 .23711 L p .26 .748 .92 r
F P
0 g
s
.29722 .25145 m .30542 .2637 L .30303 .25919 L p .664 .229 0 r
F P
0 g
s
.30303 .25919 m .29505 .24733 L .29722 .25145 L p .664 .229 0 r
F P
0 g
s
.232 .28865 m .24031 .30075 L .24221 .30512 L p .721 .28 0 r
F P
0 g
s
.25438 .31245 m .24221 .30512 L .24031 .30075 L p .727 .197 0 r
F P
0 g
s
.23501 .25617 m .23255 .26861 L .22924 .27458 L p .893 .878 .445 r
F P
0 g
s
.23255 .26861 m .23501 .25617 L .24108 .25101 L p .944 .934 .758 r
F P
0 g
s
.232 .28865 m .22924 .27458 L .23255 .26861 L p .999 .791 .46 r
F P
0 g
s
.30504 .28382 m .30232 .29622 L .30458 .29157 L p .855 .852 .393 r
F P
0 g
s
.30458 .29157 m .30799 .27779 L .30504 .28382 L p .855 .852 .393 r
F P
0 g
s
.29642 .30153 m .29132 .30837 L .29451 .30549 L p .675 .936 .65 r
F P
0 g
s
.29451 .30549 m .30232 .29622 L .29642 .30153 L p .675 .936 .65 r
F P
0 g
s
.26552 .27404 m .27728 .27193 L .27183 .27835 L p .379 0 .113 r
F P
0 g
s
.27183 .27835 m .26003 .28046 L .26552 .27404 L p .379 0 .113 r
F P
0 g
s
.24592 .2439 m .24108 .25101 L .23501 .25617 L p .721 .963 .697 r
F P
0 g
s
.24108 .25101 m .24592 .2439 L .25064 .24118 L p .757 .992 .881 r
F P
0 g
s
.27149 .31508 m .25961 .31399 L .25438 .31245 L p .283 0 0 r
F P
0 g
s
.25961 .31399 m .27149 .31508 L .27591 .31478 L p .202 .718 .882 r
F P
0 g
s
.28777 .30669 m .28666 .31115 L .29132 .30837 L p .735 .991 .864 r
F P
0 g
s
.29132 .30837 m .29642 .30153 L .28777 .30669 L p .735 .991 .864 r
F P
0 g
s
.26868 .2378 m .283 .23981 L .27769 .23852 L p .22 0 0 r
F P
0 g
s
.27769 .23852 m .26582 .23711 L .26868 .2378 L p .22 0 0 r
F P
0 g
s
.24221 .30512 m .25438 .31245 L .25961 .31399 L p 0 .439 .841 r
F P
0 g
s
.24221 .30512 m .23401 .29333 L .232 .28865 L p .721 .28 0 r
F P
0 g
s
.22924 .27458 m .232 .28865 L .23401 .29333 L p 0 0 .301 r
F P
0 g
s
.28462 .24293 m .29722 .25145 L .29505 .24733 L p .696 .155 0 r
F P
0 g
s
.29505 .24733 m .283 .23981 L .28462 .24293 L p .696 .155 0 r
F P
0 g
s
.2678 .31344 m .27591 .31478 L .28124 .3134 L p .509 .885 .971 r
F P
0 g
s
.27591 .31478 m .2678 .31344 L .25961 .31399 L p .202 .718 .882 r
F P
0 g
s
.30221 .27017 m .30504 .28382 L .30799 .27779 L p .996 .788 .431 r
F P
0 g
s
.30799 .27779 m .30542 .2637 L .30221 .27017 L p .996 .788 .431 r
F P
0 g
s
.001 w
.18105 .20624 m
.16485 .589 L
s
.53141 .1373 m
.18105 .20624 L
s
.5 Mabswid
.27771 .31088 m .28124 .3134 L .28666 .31115 L p .665 .955 .947 r
F P
0 g
s
.28666 .31115 m .28777 .30669 L .27771 .31088 L p .665 .955 .947 r
F P
0 g
s
.28124 .3134 m .27771 .31088 L .2678 .31344 L p .509 .885 .971 r
F P
0 g
s
.23501 .25617 m .24264 .24669 L .24592 .2439 L p .721 .963 .697 r
F P
0 g
s
.22924 .27458 m .23249 .2607 L .23501 .25617 L p .893 .878 .445 r
F P
0 g
s
.24264 .24669 m .23501 .25617 L .23249 .2607 L p 0 0 0 r
F P
0 g
s
.29731 .29075 m .29642 .30153 L .30232 .29622 L p .945 .943 .75 r
F P
0 g
s
.30232 .29622 m .30504 .28382 L .29731 .29075 L p .945 .943 .75 r
F P
0 g
s
.25064 .24118 m .2543 .24167 L .25606 .23893 L closepath p .024 0 0 r
F P
0 g
s
.25606 .23893 m .2543 .24167 L .26139 .2375 L closepath p .1 0 0 r
F P
0 g
s
.24592 .2439 m .2543 .24167 L .25064 .24118 L closepath p .013 0 0 r
F P
0 g
s
.23249 .2607 m .22924 .27458 L .23109 .27885 L p 0 0 .282 r
F P
0 g
s
.23401 .29333 m .23109 .27885 L .22924 .27458 L p 0 0 .301 r
F P
0 g
s
.26139 .2375 m .2543 .24167 L .26582 .23711 L closepath p .221 0 0 r
F P
0 g
s
.23401 .29333 m .24221 .30512 L .24902 .30711 L p .141 .396 .845 r
F P
0 g
s
.25961 .31399 m .24902 .30711 L .24221 .30512 L p 0 .439 .841 r
F P
0 g
s
.29421 .25738 m .30221 .27017 L .30542 .2637 L p .953 .637 .395 r
F P
0 g
s
.30542 .2637 m .29722 .25145 L .29421 .25738 L p .953 .637 .395 r
F P
0 g
s
.26953 .23949 m .28462 .24293 L .283 .23981 L p .599 .064 0 r
F P
0 g
s
.283 .23981 m .26868 .2378 L .26953 .23949 L p .599 .064 0 r
F P
0 g
s
.24902 .30711 m .25961 .31399 L .2678 .31344 L p .455 .714 .979 r
F P
0 g
s
.24264 .24669 m .2543 .24167 L .24592 .2439 L closepath p .067 0 0 r
F P
0 g
s
.26582 .23711 m .2543 .24167 L .26868 .2378 L closepath p .348 0 0 r
F P
0 g
s
.28595 .29749 m .28777 .30669 L .29642 .30153 L p .865 .89 .851 r
F P
0 g
s
.29642 .30153 m .29731 .29075 L .28595 .29749 L p .865 .89 .851 r
F P
0 g
s
.24128 .24913 m .2543 .24167 L .24264 .24669 L closepath p .164 0 0 r
F P
0 g
s
.23249 .2607 m .24128 .24913 L .24264 .24669 L p 0 0 0 r
F P
0 g
s
.24128 .24913 m .23249 .2607 L .23391 .26391 L p .05 0 .216 r
F P
0 g
s
.23109 .27885 m .23391 .26391 L .23249 .2607 L p 0 0 .282 r
F P
0 g
s
.2938 .27763 m .29731 .29075 L .30504 .28382 L p .938 .805 .686 r
F P
0 g
s
.30504 .28382 m .30221 .27017 L .2938 .27763 L p .938 .805 .686 r
F P
0 g
s
.28226 .24744 m .29421 .25738 L .29722 .25145 L p .854 .479 .338 r
F P
0 g
s
.29722 .25145 m .28462 .24293 L .28226 .24744 L p .854 .479 .338 r
F P
0 g
s
.23109 .27885 m .23401 .29333 L .24137 .29543 L p .244 .315 .738 r
F P
0 g
s
.24902 .30711 m .24137 .29543 L .23401 .29333 L p .141 .396 .845 r
F P
0 g
s
.25974 .30637 m .2678 .31344 L .27771 .31088 L p .658 .792 .947 r
F P
0 g
s
.2678 .31344 m .25974 .30637 L .24902 .30711 L p .455 .714 .979 r
F P
0 g
s
.26868 .2378 m .2543 .24167 L .26953 .23949 L closepath p .45 0 .044 r
F P
0 g
s
.27273 .30299 m .27771 .31088 L .28777 .30669 L p .773 .84 .903 r
F P
0 g
s
.28777 .30669 m .28595 .29749 L .27273 .30299 L p .773 .84 .903 r
F P
0 g
s
.27771 .31088 m .27273 .30299 L .25974 .30637 L p .658 .792 .947 r
F P
0 g
s
.24207 .25084 m .2543 .24167 L .24128 .24913 L closepath p .27 0 .135 r
F P
0 g
s
.23391 .26391 m .24207 .25084 L .24128 .24913 L p .05 0 .216 r
F P
0 g
s
.26823 .24192 m .28226 .24744 L .28462 .24293 L p .718 .306 .266 r
F P
0 g
s
.28462 .24293 m .26953 .23949 L .26823 .24192 L p .718 .306 .266 r
F P
0 g
s
.24137 .29543 m .24902 .30711 L .25974 .30637 L p .513 .608 .885 r
F P
0 g
s
.23391 .26391 m .23109 .27885 L .23788 .28073 L p .304 .231 .607 r
F P
0 g
s
.24137 .29543 m .23788 .28073 L .23109 .27885 L p .244 .315 .738 r
F P
0 g
s
.2449 .25157 m .2543 .24167 L .24207 .25084 L closepath p .365 .019 .239 r
F P
0 g
s
.26953 .23949 m .2543 .24167 L .26823 .24192 L closepath p .514 .085 .164 r
F P
0 g
s
.26823 .24192 m .2543 .24167 L .26496 .24473 L closepath p .543 .152 .251 r
F P
0 g
s
.26496 .24473 m .2543 .24167 L .26021 .24748 L closepath p .545 .185 .307 r
F P
0 g
s
.26021 .24748 m .2543 .24167 L .25473 .24975 L closepath p .528 .187 .333 r
F P
0 g
s
.25473 .24975 m .2543 .24167 L .24935 .25118 L closepath p .492 .161 .333 r
F P
0 g
s
.24935 .25118 m .2543 .24167 L .2449 .25157 L closepath p .438 .106 .303 r
F P
0 g
s
.28639 .26423 m .2938 .27763 L .30221 .27017 L p .89 .681 .614 r
F P
0 g
s
.30221 .27017 m .29421 .25738 L .28639 .26423 L p .89 .681 .614 r
F P
0 g
s
.24207 .25084 m .23391 .26391 L .23912 .2653 L p .343 .138 .451 r
F P
0 g
s
.23788 .28073 m .23912 .2653 L .23391 .26391 L p .304 .231 .607 r
F P
0 g
s
.23912 .2653 m .2449 .25157 L .24207 .25084 L p .343 .138 .451 r
F P
0 g
s
.28145 .28492 m .28595 .29749 L .29731 .29075 L p .849 .768 .772 r
F P
0 g
s
.29731 .29075 m .2938 .27763 L .28145 .28492 L p .849 .768 .772 r
F P
0 g
s
.28226 .24744 m .26823 .24192 L .26496 .24473 L p .728 .403 .431 r
F P
0 g
s
.27625 .25266 m .28639 .26423 L .29421 .25738 L p .824 .557 .535 r
F P
0 g
s
.29421 .25738 m .28226 .24744 L .27625 .25266 L p .824 .557 .535 r
F P
0 g
s
.23788 .28073 m .24137 .29543 L .25299 .29458 L p .526 .513 .785 r
F P
0 g
s
.25974 .30637 m .25299 .29458 L .24137 .29543 L p .513 .608 .885 r
F P
0 g
s
.25299 .29458 m .25974 .30637 L .27273 .30299 L p .668 .684 .856 r
F P
0 g
s
.26496 .24473 m .27625 .25266 L .28226 .24744 L p .728 .403 .431 r
F P
0 g
s
.2449 .25157 m .23912 .2653 L .24734 .26462 L p .5 .301 .541 r
F P
0 g
s
.24734 .26462 m .24935 .25118 L .2449 .25157 L p .5 .301 .541 r
F P
0 g
s
.26709 .29089 m .27273 .30299 L .28595 .29749 L p .766 .729 .819 r
F P
0 g
s
.28595 .29749 m .28145 .28492 L .26709 .29089 L p .766 .729 .819 r
F P
0 g
s
.27625 .25266 m .26496 .24473 L .26021 .24748 L p .702 .434 .515 r
F P
0 g
s
.27273 .30299 m .26709 .29089 L .25299 .29458 L p .668 .684 .856 r
F P
0 g
s
.24935 .25118 m .24734 .26462 L .25731 .26198 L p .594 .385 .567 r
F P
0 g
s
.25731 .26198 m .25473 .24975 L .24935 .25118 L p .594 .385 .567 r
F P
0 g
s
.23912 .2653 m .23788 .28073 L .24862 .27989 L p .521 .419 .679 r
F P
0 g
s
.25299 .29458 m .24862 .27989 L .23788 .28073 L p .526 .513 .785 r
F P
0 g
s
.24862 .27989 m .24734 .26462 L .23912 .2653 L p .521 .419 .679 r
F P
0 g
s
.27495 .27094 m .28145 .28492 L .2938 .27763 L p .816 .668 .7 r
F P
0 g
s
.2938 .27763 m .28639 .26423 L .27495 .27094 L p .816 .668 .7 r
F P
0 g
s
.26021 .24748 m .26748 .25777 L .27625 .25266 L p .702 .434 .515 r
F P
0 g
s
.26748 .25777 m .26021 .24748 L .25473 .24975 L p .658 .426 .557 r
F P
0 g
s
.25473 .24975 m .25731 .26198 L .26748 .25777 L p .658 .426 .557 r
F P
0 g
s
.28639 .26423 m .27625 .25266 L .26748 .25777 L p .772 .567 .622 r
F P
0 g
s
.24862 .27989 m .25299 .29458 L .26709 .29089 L p .657 .595 .774 r
F P
0 g
s
.26748 .25777 m .27495 .27094 L .28639 .26423 L p .772 .567 .622 r
F P
0 g
s
.24734 .26462 m .24862 .27989 L .26166 .27646 L p .635 .505 .687 r
F P
0 g
s
.26166 .27646 m .25731 .26198 L .24734 .26462 L p .635 .505 .687 r
F P
0 g
s
.26166 .27646 m .26709 .29089 L .28145 .28492 L p .743 .64 .746 r
F P
0 g
s
.28145 .28492 m .27495 .27094 L .26166 .27646 L p .743 .64 .746 r
F P
0 g
s
.26709 .29089 m .26166 .27646 L .24862 .27989 L p .657 .595 .774 r
F P
0 g
s
.27495 .27094 m .26748 .25777 L .25731 .26198 L p .711 .549 .667 r
F P
0 g
s
.25731 .26198 m .26166 .27646 L .27495 .27094 L p .711 .549 .667 r
F P
0 g
s
.001 w
.16485 .589 m
.53141 .54517 L
s
.53141 .1373 m
.53141 .54517 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{357, 260.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005U000111000`40O003h00OogooIWoo003oOomV
Ool00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00
ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomV
Ool00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00
ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomV
Ool00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00
ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomVOol00?moofIoo`00ogooIWoo003oOomV
Ool00?moofIoo`00ogooIWoo002kOol3002WOol00;Ioo`D0009oo`800:Ioo`00/Goo1@001goo00@0
07oo00000:Aoo`00[7oo1@0037oo00D007ooOomoo`000:=oo`00Ygoo1@004Goo00<007ooOol00Woo
00<007ooOol0X7oo002ROol5000FOol00`00Oomoo`03Ool00`00Oomoo`2OOol009eoo`D001]oo`03
001oogoo00Aoo`8009moo`00V7oo1@0087oo00<007ooOol01Woo00<007ooOol0W7oo002COol5000U
Ool00`00Oomoo`07Ool00`00Oomoo`2KOol008ioo`D002Yoo`03001oogoo00Qoo`8009]oo`00RGoo
1@00;goo00<007ooOol02Woo00<007ooOol0V7oo0024Ool5000dOol00`00Oomoo`0;Ool00`00Oomo
o`2GOol007moo`D003Uoo`03001oogoo00aoo`03001oogoo09Ioo`00NWoo1@00?Woo00<007ooOol0
3Goo0P00UWoo001eOol50013Ool00`00Oomoo`0?Ool00`00Oomoo`2COol0071oo`D004Qoo`03001o
ogoo011oo`03001oogoo099oo`00Jgoo1@00CGoo00<007ooOol04Goo00<007ooOol0TGoo001VOol5
001BOol00`00Oomoo`0BOol2002AOol0065oo`D005Moo`03001oogoo01Aoo`03001oogoo08ioo`00
G7oo1@00G7oo00<007ooOol05Goo00<007ooOol0SGoo001GOol5001QOol00`00Oomoo`0FOol00`00
Oomoo`2<Ool0059oo`D006Ioo`03001oogoo01Moo`8008aoo`00CGoo1@00Jgoo00<007ooOol06Goo
00<007ooOol0RGoo0018Ool5001`Ool00`00Oomoo`0JOol00`00Oomoo`28Ool004=oo`D007Eoo`03
001oogoo01]oo`8008Qoo`00@7oo0`00NWoo00<007ooOol07Goo00<007ooOol0QGoo0010Ool3001j
Ool00`00Oomoo`0NOol00`00Oomoo`24Ool0041oo`03001oogoo008007Qoo`03001oogoo01moo`03
001oogoo08=oo`00@7oo00<007ooOol00Woo00<007ooOol0MGoo00<007ooOol087oo0P00Pgoo0010
Ool00`00Oomoo`03Ool2001eOol00`00Oomoo`0ROol00`00Oomoo`20Ool0041oo`03001oogoo00Eo
o`8007=oo`03001oogoo02=oo`03001oogoo07moo`00@7oo00<007ooOol01goo00<007ooOol0L7oo
00<007ooOol097oo00<007ooOol0OWoo0010Ool00`00Oomoo`08Ool2001`Ool00`00Oomoo`0UOol2
001nOol0041oo`03001oogoo00Yoo`8006ioo`03001oogoo02Moo`03001oogoo07]oo`00@7oo00<0
07ooOol037oo0P00K7oo00<007ooOol0:7oo00<007ooOol0NWoo0010Ool00`00Oomoo`0>Ool2001Z
Ool00`00Oomoo`0YOol2001jOol0041oo`03001oogoo011oo`8000Ioo`P005Yoo`03001oogoo02]o
o`03001oogoo07Moo`00?goo00<007ooOol04goo0P000Woo3@00Egoo00<007ooOol0;7oo00<007oo
Ool0MWoo000oOol00`00Oomoo`0EOol80002GHd7001EOol00`00Oomoo`0]Ool00`00Oomoo`1eOol0
03moo`03001oogoo01Aoo`D00005@:X00000FK000004GHd01000KNX005R00P00Dgoo00<007ooOol0
;Woo0P00MGoo000oOol00`00Oomoo`0COol400001CbZ000005Fa00000UV`0P0000EMS@00JS4006gZ
00<005=oo`03001oogoo031oo`03001oogoo079oo`00?goo00<007ooOol04Woo1`000UFa00<005V`
FK000UV`00D006XaJS5Z<@00009]jP80059oo`03001oogoo035oo`03001oogoo075oo`00?goo00<0
07ooOol04Goo0`0000DXSP00001=TP0000=E/@06001I/000001RD`000fXa0P0000=jS000Ool0DGoo
00<007ooOol0<Woo00<007ooOol0L7oo000oOol00`00Oomoo`0@Ool3000012R>000m<@000TfB00D0
05FaEK5E/@0000ARD`06001Z<FXaJS4007Z<0P00DGoo00<007ooOol0<goo0P00L7oo000oOol00`00
Oomoo`0@Ool01`0010H002R>000m<@00009=TP03001E/@00008000ERD`07001Z<@00L[<007Z<0000
DGoo00<007ooOol0=Goo00<007ooOol0KGoo000oOol00`00Oomoo`0@Ool01@09000XSP00?C401P00
0eXe00<0069CHU<00f9C00@007:cL[<0009jS003001oogoo04ioo`03001oogoo03Ioo`03001oogoo
06aoo`00?goo00<007ooOol047oo00<02@0000000P0000E1]@00DQEB5@0000AJ=@04001RDf9CHU<3
0003L[<3001@Ool00`00Oomoo`0gOol00`00Oomoo`1[Ool003moo`03001oogoo00moo`0500002@00
9?<00002@KD01@00DQEB5E8E000015Xe0`000fZf00@007:cL[=b/`80051oo`03001oogoo03Qoo`80
06]oo`00?goo00<007ooOol03goo0P000RCc00@0046e@KD000=B5@03001J=EXe009J=@03001Z]VZf
00=Z]P03001b/g:c00800003Obd007oo04ioo`03001oogoo03Yoo`03001oogoo06Qoo`00?goo00<0
07ooOol03goo0P0000<Tl`00@KD00T6e00<0058EDQD00U8E00H005Xe000005jG0005J[H2000017/e
001o;@00Cgoo00<007ooOol0>goo00<007ooOol0Igoo000oOol00`00Oomoo`0?Ool200000bCc0011
]@02@KD00`00DQEB5@040003GYL00`00J[IZ]P03J[H01000NcEk=G/e0P00Cgoo00<007ooOol0?7oo
0P00Igoo000oOol00`00Oomoo`0?Ool:0002EWP00`00GYMNU`03GYL01000J[IZ]VZf0P000g/e0`00
CWoo00<007ooOol0?Woo00<007ooOol0I7oo000oOol00`00Oomoo`0@Ool00`007EL00003@QT00`00
EWQFN003EWP00`00GYMNU`02GYL01P00J[H00000KaP000=k=@800003Ool0000004aoo`03001oogoo
03moo`03001oogoo06=oo`00?goo00<007ooOol047oo00@001eG7EL000=26@03001FN5Ih009FN003
001NUejG009NU`8000A_6004001k=@000004Ool2001:Ool00`00Oomoo`10Ool00`00Oomoo`1ROol0
03moo`03001oogoo011oo`8000037EL0048I00926@03001FN5Ih00=FN006001NU`00001RnP0016lH
0P0000=ke`00Ool01Goo0P00B7oo00<007ooOol0@Goo0P00HWoo000oOol00`00Oomoo`0@Ool20002
7EL01@00@QU26D8I00000UIh10000f;j00<006lHKaP00VlH00@007_G000000Qoo`03001oogoo04Eo
o`03001oogoo04=oo`03001oogoo05moo`00?goo00<007ooOol04Goo2P000UJk00<006;jH_X00f;j
00<006lH00000P0000=ke`00Ool02Goo0P00AGoo00<007ooOol0A7oo00<007ooOol0GWoo000oOol0
0`00Oomoo`0BOol24I/01@00@Wa2O49l00001EJk00<006;jH_X00V;j0P000VnK00<007_G000037oo
0P00@goo00<007ooOol0AGoo00<007ooOol0GGoo000oOol00`00Oomoo`0BOol010004I/AV`000d9l
00<005JkE[/00UJk00<006;jH_X00`000fnK0P003goo00<007ooOol0@7oo00<007ooOol0AWoo0P00
GGoo000nOol00`00Oomoo`0DOol00`004I/00003@W`01000E[]F^eJk10000f=L00@006nK0000015o
o`80041oo`03001oogoo04Qoo`03001oogoo05Yoo`00?Woo00<007ooOol05Goo00<0016K00000T9l
10000ULn00<006=LHe`00V=L0`0057oo0P00?Woo00<007ooOol0BGoo00<007ooOol0FGoo000nOol0
0`00Oomoo`0FOol40002>]l00`00EciG?P02Ech00`00He`00003000GOol2000lOol00`00Oomoo`1:
Ool00`00Oomoo`1HOol003ioo`03001oogoo01Qoo`8000<jg`03001G?ULn00<0009GgP03001jlP00
01Qoo`03001oogoo03Uoo`03001oogoo04]oo`8005Qoo`00?Woo00<007ooOol06Woo1P000T>O0`00
0W[b00<007ooOol05goo0P00>Goo00<007ooOol0CGoo00<007ooOol0EGoo000nOol00`00Oomoo`0P
Ool00`00CWY>NP02CWX01000N_9jlP006Woo0P00=goo00<007ooOol0CWoo00<007ooOol0E7oo000n
Ool00`00Oomoo`0QOol01@00CWY>NTij00000W[b00<007ooOol06Woo00<007ooOol0=7oo00<007oo
Ool0Cgoo0P00E7oo000nOol00`00Oomoo`0QOol00`00CWY>NP02CWX01000N_9jlP0077oo0P00=7oo
00<007ooOol0DGoo00<007ooOol0DGoo000nOol00`00Oomoo`0ROol01@00CWY>NTij00000W[b00<0
07ooOol077oo0P00<Woo00<007ooOol0DWoo00<007ooOol0D7oo000nOol00`00Oomoo`0ROol01@00
CWY>NTij00000W[b00<007ooOol07Woo0P00<7oo00<007ooOol0Dgoo00<007ooOol0Cgoo000nOol0
0`00Oomoo`0SOol01@00CWY>NTij00000W[b00<007ooOol07goo00<007ooOol0;Goo00<007ooOol0
E7oo0P00Cgoo000nOol00`00Oomoo`0SOol01@00CWY>NTij00000W[b00<007ooOol087oo0P00;Goo
00<007ooOol0EWoo00<007ooOol0C7oo000nOol00`00Oomoo`0SOol00`00CWY>NP02CWX01000N_9j
lP008goo0P00:goo00<007ooOol0Egoo00<007ooOol0Bgoo000nOol00`00Oomoo`0TOol01@00CWY>
NTij00000W[b00<007ooOol08goo00<007ooOol0:7oo00<007ooOol0F7oo00<007ooOol0BWoo000n
Ool00`00Oomoo`0TOol00`00CWY>NP02CWX01000N_9jlP009Goo0P00:7oo00<007ooOol0FGoo0P00
BWoo000nOol00`00Oomoo`0UOol01@00CWY>NTij00000W[b00<007ooOol09Goo0P009Woo00<007oo
Ool0Fgoo00<007ooOol0Agoo000nOol00`00Oomoo`0UOol01@00CWY>NTij00000W[b00<007ooOol0
9goo0P0097oo00<007ooOol0G7oo00<007ooOol0AWoo000nOol00`00Oomoo`0VOol01@00CWY>NTij
00000W[b00<007ooOol0:7oo00<007ooOol08Goo00<007ooOol0GGoo0P00AWoo000nOol00`00Oomo
o`0VOol01@00CWY>NTij00000W[b00<007ooOol0:Goo0P008Goo00<007ooOol0Ggoo00<007ooOol0
@goo000nOol00`00Oomoo`0VOol00`00CWY>NP02CWX01000N_9jlP00;7oo0P007goo00<007ooOol0
H7oo00<007ooOol0@Woo000nOol00`00Oomoo`0WOol01@00CWY>NTij00000W[b00<007ooOol0;7oo
00<007ooOol077oo00<007ooOol0HGoo00<007ooOol0@Goo000nOol00`00Oomoo`0WOol01@00CWY>
NTij00000g[b00<007ooOol0;7oo0P0077oo00<007ooOol0HWoo0P00@Goo000nOol00`00Oomoo`0X
Ool01@00CWY>NTij00000W[b00<007ooOol0;Woo0P006Woo00<007ooOol0I7oo00<007ooOol0?Woo
000mOol00`00Oomoo`0YOol01@00CWY>NTij00000W[b00<007ooOol0<7oo0P0067oo00<007ooOol0
HWoo1000?goo000mOol00`00Oomoo`0ZOol01@00CWY>NTij00000W[b00<007ooOol0<Goo00<007oo
Ool05Goo00<007ooOol0Fgoo1`000goo00<007ooOol0?Goo000mOol00`00Oomoo`0ZOol01@00CWY>
NTij00000W[b00<007ooOol0<Woo0P005Goo00<007ooOol0E7oo1`002Woo00<007ooOol0?Goo000m
Ool00`00Oomoo`0ZOol00`00CWY>NP02CWX01000N_9jlP00=Goo0P004goo00<007ooOol0CGoo1`00
4Goo00<007ooOol0?Goo000mOol00`00Oomoo`0[Ool01@00CWY>NTij00000W[b00<007ooOol0=Goo
00<007ooOol047oo00<007ooOol0AWoo1`0067oo00<007ooOol0?Goo000mOol00`00Oomoo`0[Ool0
1@00CWY>NTij00000W[b00<007ooOol0=Woo0P0047oo00<007ooOol0?goo1`007goo00<007ooOol0
?Goo000mOol00`00Oomoo`0/Ool01@00CWY>NTij00000W[b00<007ooOol0=goo0P003Woo00<007oo
Ool0>7oo1`009Woo00<007ooOol0?Goo000mOol00`00Oomoo`0/Ool01@00CWY>NTij00000W[b00<0
07ooOol0>Goo0P0037oo00<007ooOol0<Woo1P00;Goo00<007ooOol0?Goo000mOol00`00Oomoo`0/
Ool00`00CWY>NP02CWX01000N_9jlP00?7oo00<007ooOol02Goo00<007ooOol0:goo1`00<goo00<0
07ooOol0?Goo000mOol00`00Oomoo`0]Ool01@00CWY>NTij00000W[b00<007ooOol0>goo0P002Goo
00<007ooOol097oo1`00>Woo00<007ooOol0?Goo000mOol00`00Oomoo`0]Ool01@00CWY>NTij0000
0g[b00<007ooOol0?7oo0P001goo00<007ooOol07Goo1`00@Goo00<007ooOol0?Goo000mOol00`00
Oomoo`0^Ool01@00CWY>NTij00000W[b00<007ooOol0?Woo00<007ooOol017oo00<007ooOol05Woo
1`00B7oo00<007ooOol0?Goo000mOol00`00Oomoo`0^Ool01@00CWY>NTij00000W[b00<007ooOol0
?goo0P0017oo00<007ooOol03goo1`00Cgoo00<007ooOol0?Goo000mOol00`00Oomoo`0_Ool01@00
CWY>NTij00000W[b00<007ooOol0@7oo0P000Woo00<007ooOol027oo1`00EWoo00<007ooOol0?Goo
000mOol00`00Oomoo`0_Ool01@00CWY>NTij00000W[b00<007ooOol0@Woo0`000goo1`00GGoo00<0
07ooOol0?Goo000mOol00`00Oomoo`0_Ool00`00CWY>NP02CWX01000N_9jlP00AGoo1000IGoo00<0
07ooOol0?7oo000mOol00`00Oomoo`0`Ool01@00CWY>NTij00000W[b00<007ooOol0@goo00<007oo
Ool0IWoo00<007ooOol0?7oo000mOol00`00Oomoo`0`Ool01@00CWY>NTij00000g[b00<007ooOol0
@Woo00<007ooOol0IWoo00<007ooOol0?7oo000mOol00`00Oomoo`0aOol01@00CWY>NTij00000W[b
00<007ooOol0@Woo00<007ooOol0IWoo00<007ooOol0?7oo000mOol00`00Oomoo`0aOol01@00CWY>
NTij00000W[b00<007ooOol0@Woo00<007ooOol0IWoo00<007ooOol0?7oo000mOol00`00Oomoo`0b
Ool01@00CWY>NTij00000W[b00<007ooOol0@Goo00<007ooOol0IWoo00<007ooOol0?7oo000mOol0
0`00Oomoo`0bOol01@00CWY>NTij00000W[b00<007ooOol0@Goo00<007ooOol0IWoo00<007ooOol0
?7oo000mOol00`00Oomoo`0bOol01@00CWY>NTij00000g[b00<007ooOol0@7oo00<007ooOol0IWoo
00<007ooOol0?7oo000lOol00`00Oomoo`0dOol01@00CWY>NTij00000W[b00<007ooOol0@7oo00<0
07ooOol0IWoo00<007ooOol0?7oo000lOol00`00Oomoo`0dOol01@00CWY>NTij00000g[b00<007oo
Ool0?goo00<007ooOol0IWoo00<007ooOol0?7oo000lOol00`00Oomoo`0eOol4CWX3N_800`00Oomo
o`0oOol00`00Oomoo`1VOol00`00Oomoo`0lOol003aoo`03001oogoo03Eoo`06001>NTijCWX007[b
0P00@Goo00<007ooOol0IWoo00<007ooOol0?7oo000lOol00`00Oomoo`0fOol4CWX00g[b00000011
Ool00`00Oomoo`1VOol00`00Oomoo`0lOol003aoo`03001oogoo03Eoo`P0045oo`03001oogoo06Io
o`03001oogoo03aoo`00?7oo00<007ooOol0=Goo00<007[b00000Woo00@007[bN_80041oo`03001o
ogoo06Ioo`03001oogoo03aoo`00?7oo00<007ooOol0=7oo00@007[bN_80009oo`04001jlW[b0010
Ool00`00Oomoo`1VOol00`00Oomoo`0lOol003aoo`03001oogoo03Aoo`03001jlW[b00@0009jlP03
001oogoo03ioo`03001oogoo06Ioo`03001oogoo03aoo`00?7oo00<007ooOol0<Goo1P000TVd00<0
07[b00000P00@7oo00<007ooOol0IWoo00<007ooOol0?7oo000lOol00`00Oomoo`0[Ool60008BK@0
1000N_9jlW[b0P00?goo00<007ooOol0IWoo00<007ooOol0?7oo000lOol00`00Oomoo`0WOol4000>
BK@00`00N_9jlP03N_82000mOol00`00Oomoo`1VOol00`00Oomoo`0lOol003aoo`03001oogoo02Mo
o`030019]4Vd00m9]003001jlW[b00EjlP8003]oo`03001oogoo06Ioo`03001oogoo03aoo`00?7oo
00<007ooOol09goo00<004VdBK@01TVd00<004VdBK@01TVd00<007[bN_801g[b0P00>Goo00<007oo
Ool0IWoo00<007ooOol0?7oo000lOol00`00Oomoo`0WOol00`00BKA9]004BK@20009BK@00`00N_9j
lP09N_82000gOol00`00Oomoo`1VOol00`00Oomoo`0lOol003aoo`03001oogoo02Moo`030019]4Vd
0099]08000M9]0H000ajlP8003Eoo`03001oogoo06Ioo`03001oogoo03aoo`00?7oo00<007ooOol0
9goo00@004VdBKA9]0X000HoG`8000ajlP8003=oo`03001oogoo06Ioo`03001oogoo03aoo`00?7oo
00<007ooOol09goo1@004CmO0P002g[b00<007ooOol0<Goo00<007ooOol0IWoo00<007ooOol0?7oo
000lOol00`00Oomoo`0XOol3000:?el00`00?eloG`07?el20009N_800`00Oomoo`0aOol00`00Oomo
o`1VOol00`00Oomoo`0lOol003aoo`03001oogoo02Moo`04001oogooOol20008?el30009?el20007
N_800`00Oomoo`0aOol00`00Oomoo`1VOol00`00Oomoo`0lOol003aoo`03001oogoo02Ioo`03001o
ogoo00Aoo`8000HoG`03001jlW[b008000ToG`8000EjlP03001oogoo035oo`03001oogoo06Ioo`03
001oogoo03aoo`00?7oo00<007ooOol09Goo00<007ooOol01goo0P001CmO00@007[bN_9jlP8000To
G`8000=jlP03001oogoo035oo`03001oogoo06Moo`03001oogoo03]oo`00>goo00<007ooOol09Goo
00<007ooOol02Woo0P000cmO00<007[bN_800g[b00<003mO?el023mO0P0000=jlP00Ool0<Woo00<0
07ooOol0Igoo00<007ooOol0>goo000kOol00`00Oomoo`0SOol2000?Ool200000cmO001jlP03N_80
0`00?eloG`08?el5000cOol00`00Oomoo`1WOol00`00Oomoo`0kOol003]oo`03001oogoo029oo`03
001oogoo015oo`8000AjlP03000oG`0000P003Qoo`03001oogoo06Moo`03001oogoo03]oo`00>goo
00<007ooOol08Goo00<007ooOol057oo00<007[bN_800`001goo00<007ooOol0=goo00<007ooOol0
Igoo00<007ooOol0>goo000kOol00`00Oomoo`0POol00`00Oomoo`0EOol01000N_9jlP002Woo00<0
07ooOol0=Woo00<007ooOol0Igoo00<007ooOol0>goo000kOol00`00Oomoo`0OOol00`00Oomoo`0F
Ool00`00N_80000<Ool00`00Oomoo`0eOol00`00Oomoo`1WOol00`00Oomoo`0kOol003]oo`03001o
ogoo01eoo`8001Uoo`03001jlP0000eoo`03001oogoo03Aoo`03001oogoo06Moo`03001oogoo03]o
o`00>goo00<007ooOol077oo00<007ooOol06Woo00<007ooOol03Goo00<007ooOol0<goo00<007oo
Ool0Igoo00<007ooOol0>goo000kOol00`00Oomoo`0KOol00`00Oomoo`0KOol2000>Ool00`00Oomo
o`0cOol00`00Oomoo`1WOol00`00Oomoo`0kOol003]oo`03001oogoo01Yoo`03001oogoo01ioo`@0
00]oo`03001oogoo039oo`03001oogoo06Moo`03001oogoo03]oo`00>goo00<007ooOol06Goo00<0
07ooOol08goo0`002Goo00<007ooOol0<Goo00<007ooOol0Igoo00<007ooOol0>goo000kOol00`00
Oomoo`0GOol2000YOol30007Ool00`00Oomoo`0`Ool00`00Oomoo`1WOol00`00Oomoo`0kOol003]o
o`03001oogoo01Ioo`03001oogoo02aoo`@000=oo`03001oogoo031oo`03001oogoo06Moo`03001o
ogoo03]oo`00>goo00<007ooOol05Goo00<007ooOol0<Goo0`0000=oo`00Ool0<7oo00<007ooOol0
Igoo00<007ooOol0>goo000kOol00`00Oomoo`0DOol00`00Oomoo`0eOol3000`Ool00`00Oomoo`1W
Ool00`00Oomoo`0kOol003]oo`03001oogoo01=oo`03001oogoo03Uoo`@002aoo`03001oogoo06Mo
o`03001oogoo03]oo`00>goo00<007ooOol04Goo0P00?7oo00@007ooOomoo`<002Uoo`03001oogoo
06Moo`03001oogoo03]oo`00>goo00<007ooOol047oo00<007ooOol0?Goo00<007ooOol00goo0`00
9Woo00<007ooOol0Igoo00<007ooOol0>goo000kOol00`00Oomoo`0?Ool00`00Oomoo`0oOol00`00
Oomoo`05Ool4000NOol6001XOol00`00Oomoo`0kOol003]oo`03001oogoo00ioo`03001oogoo045o
o`03001oogoo00Qoo`<001=oo`P000Aoo`04001oo`00001VOol00`00Oomoo`0kOol003]oo`03001o
ogoo00eoo`03001oogoo049oo`03001oogoo00]oo`<000Qoo`P000aoo`04001oogooOol2001TOol0
0`00Oomoo`0kOol003]oo`03001oogoo00]oo`8004Ioo`03001oogoo00eoo`P001Aoo`03001oogoo
00=oo`80069oo`03001oogoo03]oo`00>goo00<007ooOol02Woo00<007ooOol0Agoo00<007ooOol0
17oo200017oo0`005Goo00<007ooOol01Goo0P00H7oo00<007ooOol0>goo000jOol00`00Oomoo`0:
Ool00`00Oomoo`16Ool9000?Ool4000AOol00`00Oomoo`07Ool2001NOol00`00Oomoo`0kOol003Yo
o`03001oogoo00Uoo`03001oogoo03moo`P000=oo`03001oogoo01Ioo`<000ioo`03001oogoo00Uo
o`8005aoo`03001oogoo03]oo`00>Woo00<007ooOol027oo00<007ooOol0>7oo200037oo00<007oo
Ool067oo0`002goo00<007ooOol02goo0P00FWoo00<007ooOol0>goo000jOol00`00Oomoo`06Ool2
000cOol8000EOol00`00Oomoo`0JOol40007Ool00`00Oomoo`0=Ool2001HOol00`00Oomoo`0kOol0
03Yoo`03001oogoo00Eoo`03001oogoo02]oo`P001ioo`03001oogoo01eoo`<000Aoo`03001oogoo
00moo`8005Moo`03001oogoo03Yoo`00>Woo00<007ooOol017oo00<007ooOol097oo20009Woo00<0
07ooOol087oo0`0000=oo`00Ool04Woo0P00EGoo00<007ooOol0>Woo000jOol00`00Oomoo`03Ool0
0`00Oomoo`0LOol9000_Ool00`00Oomoo`0ROol4000COol2001COol00`00Oomoo`0jOol003Yoo`03
001oogoo009oo`03001oogoo01Eoo`P003Uoo`03001oogoo029oo`03001oogoo00<0019oo`80055o
o`03001oogoo03Yoo`00>Woo00<007ooOol00P0047oo2000@Woo00<007ooOol08Goo00<007ooOol0
0goo0`004Goo0`00CWoo00<007ooOol0>Woo000jOol00`00Ool0000:Ool8001:Ool00`00Oomoo`0Q
Ool00`00Oomoo`06Ool4000@Ool2001<Ool00`00Oomoo`0jOol003Yoo`8000=oo`P005=oo`03001o
ogoo021oo`03001oogoo00Yoo`<000moo`8004Yoo`03001oogoo03Yoo`00>Woo1@00G7oo00<007oo
Ool07goo00<007ooOol03Goo10003Goo0P00B7oo00<007ooOol0>Woo000lOol3001MOol00`00Oomo
o`0NOol00`00Oomoo`0AOol3000<Ool20016Ool00`00Oomoo`0jOol003moo`<005Yoo`03001oogoo
01ioo`03001oogoo01Aoo`<000]oo`8004Aoo`03001oogoo03Yoo`00@Woo0`00F7oo00<007ooOol0
7Goo00<007ooOol05goo10002Goo0P00@Woo00<007ooOol0>Woo0015Ool3001FOol00`00Oomoo`0L
Ool00`00Oomoo`0KOol30008Ool20010Ool00`00Oomoo`0jOol004Qoo`<005Aoo`03001oogoo01]o
o`03001oogoo01ioo`<000Moo`8003ioo`03001oogoo03Yoo`00Bgoo0P00DWoo00<007ooOol06goo
00<007ooOol08Goo10001Goo0P00?7oo00<007ooOol0>Woo001=Ool3001@Ool00`00Oomoo`0JOol0
0`00Oomoo`0UOol30004Ool2000jOol00`00Oomoo`0jOol0051oo`<004ioo`03001oogoo01Uoo`03
001oogoo02Qoo`<000=oo`8003Qoo`03001oogoo03Yoo`00Dgoo0`00C7oo00<007ooOol067oo00<0
07ooOol0:goo100000=oo`000000=Woo00<007ooOol0>Woo001FOol3001:Ool00`00Oomoo`0GOol0
0`00Oomoo`0_Ool6000cOol00`00Oomoo`0jOol005Uoo`<004Moo`03001oogoo01Moo`03001oogoo
039oo`D0035oo`03001oogoo03Yoo`00G7oo0`00AGoo00<007ooOol05Woo00<007ooOol0=Goo1000
;goo00<007ooOol0>Woo001OOol30013Ool00`00Oomoo`0EOol00`00Oomoo`0iOol2000]Ool00`00
Oomoo`0jOol0069oo`<0045oo`03001oogoo01Aoo`03001oogoo03]oo`8002]oo`03001oogoo03Yo
o`00IGoo0`00?Woo00<007ooOol057oo00<007ooOol0?Goo0P00:Goo00<007ooOol0>Woo001XOol3
000lOol00`00Oomoo`0COol00`00Oomoo`0oOol2000WOol00`00Oomoo`0jOol006]oo`8003]oo`03
001oogoo019oo`03001oogoo045oo`8002Eoo`03001oogoo03Yoo`00KGoo0`00>Goo00<007ooOol0
4Goo00<007ooOol0@goo0P008goo00<007ooOol0>Woo001`Ool3000fOol00`00Oomoo`0AOol00`00
Oomoo`15Ool2000QOol00`00Oomoo`0jOol007=oo`<003Aoo`03001oogoo011oo`03001oogoo04Mo
o`8001moo`03001oogoo03Yoo`00MWoo0`00<Woo00<007ooOol03goo00<007ooOol0BGoo0P007Goo
00<007ooOol0>Woo001iOol3000`Ool00`00Oomoo`0>Ool00`00Oomoo`1;Ool2000LOol00`00Oomo
o`0iOol007aoo`<002eoo`03001oogoo00ioo`03001oogoo04eoo`<001Uoo`03001oogoo03Uoo`00
Ogoo0`00:goo00<007ooOol03Goo00<007ooOol0D7oo0P005goo00<007ooOol0>Goo0022Ool3000Y
Ool00`00Oomoo`0<Ool00`00Oomoo`1BOol2000EOol00`00Oomoo`0iOol008Eoo`<002Moo`03001o
ogoo00]oo`03001oogoo05Aoo`8001=oo`03001oogoo03Uoo`00R7oo0`0097oo00<007ooOol02goo
00<007ooOol0EWoo0P004Goo00<007ooOol0>Goo002;Ool2000SOol00`00Oomoo`0:Ool00`00Oomo
o`1HOol2000?Ool00`00Oomoo`0iOol008eoo`<0025oo`03001oogoo00Uoo`03001oogoo05Yoo`80
00eoo`03001oogoo03Uoo`00T7oo0`007goo00<007ooOol027oo00<007ooOol0G7oo0P002goo00<0
07ooOol0>Goo002COol3000LOol00`00Oomoo`08Ool00`00Oomoo`1NOol20009Ool00`00Oomoo`0i
Ool009Ioo`<001Yoo`03001oogoo00Moo`03001oogoo061oo`8000Moo`03001oogoo03Uoo`00VGoo
0`0067oo00<007ooOol01Woo00<007ooOol0HWoo0P001Goo00<007ooOol0>Goo002LOol3000FOol0
0`00Oomoo`05Ool00`00Oomoo`1TOol20003Ool00`00Oomoo`0iOol009moo`<001=oo`03001oogoo
00Eoo`03001oogoo06Ioo`800003Ool007oo03Yoo`00XWoo0`004Goo00<007ooOol017oo00<007oo
Ool0I7oo1P00>goo002UOol3000?Ool00`00Oomoo`03Ool00`00Oomoo`1HOol<0011Ool00:Qoo`<0
00eoo`03001oogoo009oo`03001oogoo04aoo``004eoo`00Zgoo0P002goo00<007ooOol00Woo00<0
07ooOol0@7oo3000FGoo002]Ool30009Ool01@00Oomoogoo0000=Woo3000IGoo002`Ool30007Ool0
1000Oomoo`00:Woo3000LGoo002cOol30005Ool00`00Ool0000NOol<001mOol00;Ioo`<0009oo`03
001oo`00019oo``008Uoo`00^Goo1@001Woo3000UGoo002lOol8002QOol00?moofIoo`00ogooIWoo
003oOomVOol00?moofIoo`00\
\>"],
  ImageRangeCache->{{{0, 356}, {259.125, 0}} -> {-0.000651538, 0.102864, 
  0.00264659, 0.00264659}}],

Cell[TextData["Cable Pendulum Graphic"], "Subsubtitle",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Reference"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Context",
    FontWeight->"Bold"],
  "\nMech`Mech3D`\n",
  StyleBox["Package Version",
    FontWeight->"Bold"],
  "\n1.3\n",
  StyleBox["Mathematica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" Version",
    FontWeight->"Bold"],
  "\n2.2/3.0\n",
  StyleBox["Copyright",
    FontWeight->"Bold"],
  "\nCopyright 1996, Dynamic Modeling"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Discussion"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This sample notebook uses ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " to analyze the dynamic motion of a 3D cable pendulum. The model consists \
of three bodies: the ground, the block, and the pendulum.\n\nThe pendulum is \
attached to the block by a revolute joint, or hinge. This joint allows one \
degree of dynamic freedom between the block and the pendulum. \n\nThe block \
is attached to the ground by two cables. One cable is fixed to a point on the \
ground and a point on the block, effectively forcing the point on the block \
to lie on a spherical surface in inertial space. The other cable is attached \
to two points on the ground and passes frictionlessly through a hole in the \
block. This effectively forces a point a the block to lie approximately on \
the surface of an ellipse in inertial space. The combination of the two \
cables constrains two degrees of freedom, leaving the block four degrees of \
dynamic freedom. \n\nBecause of the offset attachment points of the two \
cables on the block, the five degrees of dynamic freedom of the cable \
pendulum are highly coupled, and the free response of the system is rather \
complex."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Kinematic Model"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Preparation"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package is loaded with the ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Names are defined to reference each of the bodies in the model, and the X, \
Y, and Z unit vectors are named for convenience."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(block = 2; \)\), 
    \(\(pend = 3; \)\), 
    \(\(X = {1, 0, 0}; \)\), 
    \(\(Y = {0, 1, 0}; \)\), 
    \(\(Z = {0, 0, 1}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"No local point definitions are made in this model, so the only need for body \
objects is to define the inertia properties of the block and the pendulum. \
The pendulum is assumed to be a point mass, thus its moments and products of \
inertia are zero."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bd[2] = 
      Body[block, Mass \[Rule] 10, Inertia \[Rule] {4, 16, 20, 0, 0, 0}]; 
    \)\), 
    \(\(bd[3] = Body[pend, Mass \[Rule] 20]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[2], bd[3]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A total of eight constraint objects are used in the cable pendulum model, \
but three of them are present only so that the model can be fully constrained \
and assembled prior to doing the dynamic simulation. These constraints will \
be dropped for the simulation. The remaining five constraint objects \
represent the two cables and the revolute joint.\n\n    1.  The revolute \
joint between the block and the pendulum is modeled by a ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, which constrains five degrees of freedom."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cs[1] = 
      Revolute5[1, \n\t\tAxis[pend, {0, 0, 2}, Y], \n\t\t
        Axis[block, {0, 0, \(-0.4\)}, Y]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "    2.  The first cable, which is attached solidly to the ground and the \
block, is modeled by a ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cs[2] = 
      RelativeDistance1[2, \n\t\tPoint[ground, {4, 4, 4}], \n\t\t
        Point[block, {0, 0, 0.4}], 4]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "    3, 4, and 5.  The second cable, which is allowed to slide through a \
hole in the block, is modeled by two ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints. Each constraint represents one side of the cable, but the \
length of each side is equal to a constant length ",
  StyleBox["8",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " minus the length of the other side. A new dependent variable ",
  StyleBox["s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is added to the model to represent the length of one side of the cable, \
thus, the length of the other side is ",
  StyleBox["8 - s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The variable ",
  StyleBox["s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is added to the model with ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", with an empty list as its ",
  StyleBox["equation",
    FontSlant->"Italic"],
  " argument. Thus, the combination of these three constraints removes two \
degrees of freedom, but adds one new one for a net constraint of one degree \
of freedom."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(cs[3] = 
      RelativeDistance1[3, \n\t\tPoint[ground, {8, 0, 4}], \n\t\t
        Point[block, {0.5, 0, 0}], s]; \n
    cs[4] = RelativeDistance1[4, \n\t\tPoint[ground, {0, 0, 4}], \n\t\t
        Point[block, {\(-0.5\), 0, 0}], 8 - s]; \n
    \(cs[5] = Constraint[5, {}, {s, 5}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "    6 and 7.  A ",
  StyleBox["RotationLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint and a ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are used to temporarily constrain the rotation and translation \
of the block. These constraints are used to set up the initial configuration \
of the model to prepare it for simulation, at which time they will be dropped \
to give the block dynamic freedom."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[6] = RotationLock3[6, block]; \)\), 
    \(\(cs[7] = RelativeX1[7, Point[block, 0], xset]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "    8.  A ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used to initially lock the revolute joint. This constraint \
will also be dropped for the dynamic simulation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cs[8] = 
      RelativeAngle1[8, \n\t\tVector[pend, X], \n\t\tVector[block, Z], 
        \[Pi]/2 + aset]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 8]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Loads"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Loads must be applied to the model (or nonzero initial velocity conditions) \
or its response will not be very interesting. A simple gravitational load is \
applied to the block and the pendulum."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ld[1] = Gravity[\(-Z\), 9.81]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The kinematic model is now complete. The parameters must be defined before \
the model can be run."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetParameters[xset \[Rule] 6, aset \[Rule] \(-.8\)]; \)\)], "Input",
  AspectRatioFixed->True],

Cell["\<\
The initial guesses need to be pushed a little closer to reality than {0, 0, \
0, 0, ...} or the model cannot converge.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetGuess[X2 \[Rule] 4, Z2 \[Rule] 1]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run to bring the model to the initial configuration that will be used \
as the initial condition for the dynamic simulation. The ",
  StyleBox["Solution->Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used so that ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " calculates the values of the Lagrange multipliers so that some reaction \
forces can be examined, and to calculate velocities so that they will be \
available as initial conditions. The velocities are all zero because the \
model has no explicit time dependence. If initial velocities were not \
available for the dynamic simulation, zero velocities would be assumed \
anyway.\n\nA time specification, 0, is given to ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to make an initial time available for the dynamic simulation. The initial \
time would also be assumed to be zero if none was available."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0, Solution \[Rule] Kinematic]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(T \[Rule] 0\), ",", 
        RowBox[{"aset", "\[Rule]", 
          RowBox[{"-", 
            StyleBox["0.8`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}]}], ",", \(xset \[Rule] 6\), ",", 
        \(X2 \[Rule] 6.`\), ",", \(Y2 \[Rule] 0.720104606314506323`\), ",", 
        \(Z2 \[Rule] 2.48542106314506305`\), ",", \(Eo2 \[Rule] 1.`\), ",", 
        \(Ei2 \[Rule] 0.`\), ",", \(Ej2 \[Rule] 0.`\), ",", 
        \(Ek2 \[Rule] 0.`\), ",", \(X3 \[Rule] 7.43471218179904536`\), ",", 
        \(Y3 \[Rule] 0.720104606314506323`\), ",", 
        \(Z3 \[Rule] 0.692007644450732684`\), ",", 
        \(Eo3 \[Rule] 0.921060994002884925`\), ",", \(Ei3 \[Rule] 0.`\), ",", 
        \(Ej3 \[Rule] \(-0.389418342308650586`\)\), ",", \(Ek3 \[Rule] 0.`\), 
        ",", \(s \[Rule] 2.25`\), ",", \(X2d \[Rule] 0.`\), ",", 
        \(Y2d \[Rule] 0.`\), ",", \(Z2d \[Rule] 0.`\), ",", 
        \(Eo2d \[Rule] 0.`\), ",", \(Ei2d \[Rule] 0.`\), ",", 
        \(Ej2d \[Rule] 0.`\), ",", \(Ek2d \[Rule] 0.`\), ",", 
        \(X3d \[Rule] 0.`\), ",", \(Y3d \[Rule] 0.`\), ",", 
        \(Z3d \[Rule] 0.`\), ",", \(Eo3d \[Rule] 0.`\), ",", 
        \(Ei3d \[Rule] 0.`\), ",", \(Ej3d \[Rule] 0.`\), ",", 
        \(Ek3d \[Rule] 0.`\), ",", \(sd \[Rule] 0.`\), ",", 
        \(Lmb1 \[Rule] \(-3.0857575790811289`*^-14\)\), ",", 
        \(Lmb2 \[Rule] \(-2.9170370631520468`*^-15\)\), ",", 
        \(Lmb3 \[Rule] \(-196.199999999999974`\)\), ",", 
        \(Lmb4 \[Rule] \(-3.14532717701232478`*^-15\)\), ",", 
        \(Lmb5 \[Rule] \(-2.12382812811323962`*^-14\)\), ",", 
        \(Lmb6 \[Rule] 18.3636677505566616`\), ",", 
        \(Lmb7 \[Rule] 60.1176074357583534`\), ",", 
        \(Lmb8 \[Rule] 23.5242811705141363`\), ",", 
        \(Lmb9 \[Rule] \(-26.3510228039719685`\)\), ",", 
        \(Lmb10 \[Rule] \(-196.685180477282699`\)\), ",", 
        \(Lmb11 \[Rule] \(-48.1847274129773417`\)\), ",", 
        \(Lmb12 \[Rule] \(-151.868941570607258`\)\), ",", 
        \(Lmb13 \[Rule] \(-404.030169786563142`\)\), ",", 
        \(Lmb14 \[Rule] 1208.49533323512581`\), ",", 
        \(Lmb15 \[Rule] 955.621215951386915`\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here is the reaction that constraint 3 applies to the coordinate ",
  StyleBox["s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; the tension in the sliding cable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[3, s] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(270.529233460912532`\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Graphics"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[
"Here is a graphic of the cable pendulum model in its initial \
configuration."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(graph := 
      Graphics3D[{\n\t\t\t
          Box[block, {{.5, .3, .1}, {\(-.5\), \(-.3\), \(-.1\)}}], \n\t\t\t
          Facet[block, {{0.2, 0, .1}, {0, 0, .4}, {\(-0.2\), 0, .1}}], \n
          \t\t\tFacet[block, \n
            \t\t\t\t{{0.2, .1, \(-.1\)}, {0, .1, \(-.4\)}, {\(-0.2\), .1, 
                \(-.1\)}}, {{0.2, \(-.1\), \(-.1\)}, {0, \(-.1\), \(-.4\)}, {
                \(-0.2\), \(-.1\), \(-.1\)}}], \n
          \t\t\t{Thickness[.005], \n\t\t\t\t
            Edge[{{4, 4, 4}, Point[block, {0, 0, .4}]}], \n\t\t\t\t
            Edge[{{8, 0, 4}, Point[block, {.5, 0, 0}], \n\t\t\t\t\t\t
                Point[block, {\(-.5\), 0, 0}], {0, 0, 4}}]}, \n
          \t\t\t{Thickness[.001], \n\t\t\t\t
            Box[ground, {{0, 0, 0}, {8, 4, 4}}, Faces \[Rule] False]}, \n
          \t\t\tBar[Axis[pend, 0, {0, 0, 2}], .1, 4, 
            Angle \[Rule] {\[Pi]/4, 9\ \[Pi]/4}], \n\t\t\t
          Sphere[Axis[pend, 0, Z], .4, 16]}, \n\t\t
        ViewPoint \[Rule] {3, 1.5, 1}, \n\t\tBoxed \[Rule] False, \n\t\t
        PlotRange \[Rule] {{0, 8}, {\(-2\), 6}, {\(-1\), 4}}]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The following command will generate the graphic that is displayed at the \
beginning of this notebook."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[graph /. LastSolve[]]; \)\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Dynamics"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to create a new set of equations of motion with constraints 6, 7, \
and 8 dropped. The new equations are contained in the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object which is solved with ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(freesys = SetFree[{6, 7, 8}, Solution \[Rule] Dynamic]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(FreeSystem[Dynamic, "<>"]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " integrates the equations of motion from the initial time, which was \
pulled from the last available solution rule along with the other initial \
conditions, to the specified final time 5.0. The ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option causes the generalized forces and the location coordinates to be \
returned by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so that reaction forces can be plotted."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      sol = SolveFree[freesys, 5.0, 
          MakeRules \[Rule] {Location, Generalized}]; ]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({22.2319999999999939`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here is a plot of the sliding cable parameter ",
  StyleBox["s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[s /. sol], {T, 0, 5}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -0.30725 0.15146 [
[.21429 -0.01683 -3 -9 ]
[.21429 -0.01683 3 0 ]
[.40476 -0.01683 -3 -9 ]
[.40476 -0.01683 3 0 ]
[.59524 -0.01683 -3 -9 ]
[.59524 -0.01683 3 0 ]
[.78571 -0.01683 -3 -9 ]
[.78571 -0.01683 3 0 ]
[.97619 -0.01683 -3 -9 ]
[.97619 -0.01683 3 0 ]
[.01131 .14713 -6 -4.5 ]
[.01131 .14713 0 4.5 ]
[.01131 .29859 -6 -4.5 ]
[.01131 .29859 0 4.5 ]
[.01131 .45005 -6 -4.5 ]
[.01131 .45005 0 4.5 ]
[.01131 .60151 -6 -4.5 ]
[.01131 .60151 0 4.5 ]
[ 0 -0.00433 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 -0.00433 m
.21429 .00192 L
s
[(1)] .21429 -0.01683 0 1 Mshowa
.40476 -0.00433 m
.40476 .00192 L
s
[(2)] .40476 -0.01683 0 1 Mshowa
.59524 -0.00433 m
.59524 .00192 L
s
[(3)] .59524 -0.01683 0 1 Mshowa
.78571 -0.00433 m
.78571 .00192 L
s
[(4)] .78571 -0.01683 0 1 Mshowa
.97619 -0.00433 m
.97619 .00192 L
s
[(5)] .97619 -0.01683 0 1 Mshowa
.125 Mabswid
.0619 -0.00433 m
.0619 -0.00058 L
s
.1 -0.00433 m
.1 -0.00058 L
s
.1381 -0.00433 m
.1381 -0.00058 L
s
.17619 -0.00433 m
.17619 -0.00058 L
s
.25238 -0.00433 m
.25238 -0.00058 L
s
.29048 -0.00433 m
.29048 -0.00058 L
s
.32857 -0.00433 m
.32857 -0.00058 L
s
.36667 -0.00433 m
.36667 -0.00058 L
s
.44286 -0.00433 m
.44286 -0.00058 L
s
.48095 -0.00433 m
.48095 -0.00058 L
s
.51905 -0.00433 m
.51905 -0.00058 L
s
.55714 -0.00433 m
.55714 -0.00058 L
s
.63333 -0.00433 m
.63333 -0.00058 L
s
.67143 -0.00433 m
.67143 -0.00058 L
s
.70952 -0.00433 m
.70952 -0.00058 L
s
.74762 -0.00433 m
.74762 -0.00058 L
s
.82381 -0.00433 m
.82381 -0.00058 L
s
.8619 -0.00433 m
.8619 -0.00058 L
s
.9 -0.00433 m
.9 -0.00058 L
s
.9381 -0.00433 m
.9381 -0.00058 L
s
.25 Mabswid
0 -0.00433 m
1 -0.00433 L
s
.02381 .14713 m
.03006 .14713 L
s
[(3)] .01131 .14713 1 0 Mshowa
.02381 .29859 m
.03006 .29859 L
s
[(4)] .01131 .29859 1 0 Mshowa
.02381 .45005 m
.03006 .45005 L
s
[(5)] .01131 .45005 1 0 Mshowa
.02381 .60151 m
.03006 .60151 L
s
[(6)] .01131 .60151 1 0 Mshowa
.125 Mabswid
.02381 .02596 m
.02756 .02596 L
s
.02381 .05625 m
.02756 .05625 L
s
.02381 .08655 m
.02756 .08655 L
s
.02381 .11684 m
.02756 .11684 L
s
.02381 .17742 m
.02756 .17742 L
s
.02381 .20771 m
.02756 .20771 L
s
.02381 .23801 m
.02756 .23801 L
s
.02381 .2683 m
.02756 .2683 L
s
.02381 .32888 m
.02756 .32888 L
s
.02381 .35917 m
.02756 .35917 L
s
.02381 .38947 m
.02756 .38947 L
s
.02381 .41976 m
.02756 .41976 L
s
.02381 .48034 m
.02756 .48034 L
s
.02381 .51063 m
.02756 .51063 L
s
.02381 .54093 m
.02756 .54093 L
s
.02381 .57122 m
.02756 .57122 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .03354 m
.02499 .03353 L
.02605 .03353 L
.02729 .03352 L
.02846 .03351 L
.03053 .03347 L
.03279 .03342 L
.03527 .03335 L
.0379 .03326 L
.04262 .03302 L
.04749 .0327 L
.05205 .0323 L
.05706 .03175 L
.06244 .031 L
.06784 .03006 L
.07373 .02879 L
.08445 .02579 L
.09501 .0221 L
.10458 .01862 L
.10945 .01708 L
.11201 .01639 L
.11471 .01577 L
.11708 .01533 L
.11833 .01514 L
.11968 .01498 L
.12092 .01486 L
.12205 .01478 L
.12318 .01473 L
.12425 .01472 L
.12546 .01473 L
.12614 .01475 L
.12678 .01478 L
.12808 .01487 L
.1288 .01494 L
.12947 .01501 L
.13182 .01537 L
.1343 .01589 L
.137 .01665 L
.13952 .01752 L
.14523 .02012 L
.15027 .02314 L
.15575 .02717 L
.16568 .03654 L
.18427 .06131 L
.20415 .09891 L
.22519 .15185 L
.26308 .26777 L
.28416 .33015 L
.30342 .38075 L
.32356 .42423 L
Mistroke
.34224 .45386 L
.35145 .46483 L
.36126 .47441 L
.382 .48999 L
.42364 .51535 L
.46375 .54729 L
.50236 .58073 L
.52233 .59323 L
.53239 .59781 L
.53805 .59982 L
.54341 .60134 L
.54832 .60237 L
.55109 .60279 L
.55241 .60295 L
.55364 .60307 L
.55477 .60316 L
.55579 .60323 L
.55694 .60328 L
.55816 .60331 L
.55928 .60332 L
.5605 .6033 L
.56178 .60325 L
.56296 .60319 L
.56427 .60308 L
.56569 .60293 L
.56827 .60256 L
.57078 .60208 L
.57309 .60153 L
.57834 .59987 L
.58389 .5975 L
.59335 .59202 L
.6035 .58435 L
.62183 .56734 L
.66316 .52305 L
.70297 .47502 L
.74127 .421 L
.78202 .34383 L
.82125 .24766 L
.85897 .15371 L
.87992 .1088 L
.88909 .0922 L
.89914 .07678 L
.90889 .06489 L
.91796 .05663 L
.92298 .0532 L
.92755 .05076 L
.93008 .04967 L
.93282 .04869 L
.93522 .048 L
.9378 .04742 L
Mistroke
.93902 .04721 L
.94019 .04704 L
.94133 .0469 L
.94238 .0468 L
.94337 .04673 L
.94443 .04668 L
.94561 .04665 L
.94667 .04665 L
.94793 .04667 L
.94909 .04673 L
.95036 .04681 L
.9517 .04694 L
.95396 .04722 L
.95644 .04763 L
.96137 .0487 L
.96666 .05019 L
.97619 .05352 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo0011Ool5
000]Ool3000_Ool2000`Ool3000^Ool00`00Oomoo`0?Ool004=oo`03001oogoo02eoo`03001oogoo
035oo`03001oogoo02ioo`03001oogoo02aoo`03001oo`00011oo`00@goo00<007ooOol0;Woo00<0
07ooOol0;goo00<007ooOol0;Goo1000;goo00<007ooOol03Woo0013Ool00`00Oomoo`0^Ool00`00
Oomoo`0`Ool00`00Oomoo`0/Ool00`00Ool0000^Ool2000AOol004=oo`03001oogoo02eoo`03001o
o`0002moo`03001oo`0002moo`8002ioo`03001oogoo011oo`00@Woo0P00<7oo00<007ooOol0;goo
00<007ooOol0;goo00<007ooOol0;7oo0`0047oo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo000=Oooo0004000:Ool001=oo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00moo`004goo00<007oo
Ool0ogoo1Goo000COol00`00Oomoo`3oOol5Ool001=oo`03001oogoo0?moo`Eoo`004goo00<007oo
Ool04goo2@00j7oo000COol00`00Oomoo`0AOol20009Ool00`00Oomoo`3UOol001=oo`03001oogoo
00aoo`D000aoo`03001oogoo0>Aoo`004goo0P002goo0P004Woo0P00i7oo000COol=000FOol00`00
Oomoo`3QOol001=oo`03001oogoo025oo`03001oogoo0>1oo`004goo00<007ooOol08Woo00<007oo
Ool0ggoo000COol00`00Oomoo`0ROol00`00Oomoo`3OOol001=oo`03001oogoo02=oo`03001oogoo
0<5oo`T001Aoo`004goo00<007ooOol097oo00<007ooOol0_goo00<007ooOol01goo00<007ooOol0
4Goo000COol2000VOol00`00Oomoo`2kOol3000;Ool2000AOol001=oo`03001oogoo02Eoo`03001o
ogoo0;Yoo`03001oogoo01moo`004goo00<007ooOol09Woo00<007ooOol0^Goo00<007ooOol07goo
000COol00`00Oomoo`0WOol00`00Oomoo`2gOol00`00Oomoo`0POol001=oo`03001oogoo02Moo`03
001oogoo0;Ioo`03001oogoo025oo`004goo00<007ooOol0:7oo00<007ooOol0]7oo00<007ooOol0
8Woo000COol00`00Oomoo`0XOol00`00Oomoo`2cOol00`00Oomoo`0SOol001=oo`03001oogoo02Uo
o`03001oogoo0;5oo`03001oogoo02Aoo`004goo0P00:Woo00<007ooOol0/Goo00<007ooOol097oo
000COol00`00Oomoo`0ZOol00`00Oomoo`2_Ool00`00Oomoo`0UOol001=oo`03001oogoo02Yoo`03
001oogoo0:moo`03001oogoo02Eoo`004goo00<007ooOol0:goo00<007ooOol0[Goo00<007ooOol0
9Woo000COol00`00Oomoo`0[Ool00`00Oomoo`2]Ool00`00Oomoo`0VOol001=oo`03001oogoo02ao
o`03001oogoo0:]oo`03001oogoo02Moo`004goo00<007ooOol0;7oo00<007ooOol0Zgoo00<007oo
Ool09goo000COol00`00Oomoo`0]Ool00`00Oomoo`2YOol00`00Oomoo`0XOol001=oo`8002ioo`03
001oogoo0:Uoo`03001oogoo02Qoo`004goo00<007ooOol0;Woo00<007ooOol0Ygoo00<007ooOol0
:Goo000COol00`00Oomoo`0^Ool00`00Oomoo`2WOol00`00Oomoo`0YOol001=oo`03001oogoo02io
o`03001oogoo0:Ioo`03001oogoo02Yoo`004goo00<007ooOol0;goo00<007ooOol0YGoo00<007oo
Ool0:Woo000COol00`00Oomoo`0_Ool00`00Oomoo`2TOol00`00Oomoo`0[Ool000]oo`8000Ioo`03
001oogoo031oo`03001oogoo0:=oo`03001oogoo02]oo`003Goo00<007ooOol00goo00<007ooOol0
<7oo00<007ooOol0XWoo00<007ooOol0;7oo000<Ool00`00Oomoo`04Ool2000bOol00`00Oomoo`2Q
Ool00`00Oomoo`0/Ool000eoo`03001oogoo00=oo`03001oogoo035oo`03001oogoo0:1oo`03001o
ogoo02eoo`002goo00<007oo00001Goo00<007ooOol0<Goo00<007ooOol0X7oo00<007ooOol0;Goo
000<Ool00`00Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`2NOol00`00Oomoo`0^Ool001=oo`03
001oogoo039oo`03001oogoo09ioo`03001oogoo02ioo`004goo00<007ooOol0<Woo00<007ooOol0
WGoo00<007ooOol0;goo000COol00`00Oomoo`0bOol00`00Oomoo`2MOol00`00Oomoo`0_Ool001=o
o`03001oogoo03=oo`03001oogoo09aoo`03001oogoo02moo`004goo0P00=7oo00<007ooOol0Vgoo
00<007ooOol0<7oo000COol00`00Oomoo`0cOol00`00Oomoo`2KOol00`00Oomoo`0`Ool001=oo`03
001oogoo03Aoo`03001oogoo09Uoo`03001oogoo035oo`004goo00<007ooOol0=7oo00<007ooOol0
VGoo00<007ooOol0<Goo000COol00`00Oomoo`0dOol00`00Oomoo`2IOol00`00Oomoo`0aOol001=o
o`03001oogoo03Eoo`03001oogoo09Moo`03001oogoo039oo`004goo00<007ooOol0=Goo00<007oo
Ool0Ugoo00<007ooOol0<Woo000COol2000fOol00`00Oomoo`2FOol00`00Oomoo`0cOol001=oo`03
001oogoo03Eoo`03001oogoo09Ioo`03001oogoo03=oo`004goo00<007ooOol0=Woo00<007ooOol0
UGoo00<007ooOol0<goo000COol00`00Oomoo`0fOol00`00Oomoo`2DOol00`00Oomoo`0dOol001=o
o`03001oogoo03Ioo`03001oogoo09Aoo`03001oogoo03Aoo`004goo00<007ooOol0=goo00<007oo
Ool0TWoo00<007ooOol0=Goo000COol00`00Oomoo`0gOol00`00Oomoo`2BOol00`00Oomoo`0eOol0
01=oo`03001oogoo03Moo`03001oogoo099oo`03001oogoo03Eoo`004goo0P00>Goo00<007ooOol0
T7oo00<007ooOol0=Woo000COol00`00Oomoo`0hOol00`00Oomoo`2@Ool00`00Oomoo`0fOol001=o
o`03001oogoo03Qoo`03001oogoo08moo`03001oogoo03Moo`004goo00<007ooOol0>7oo00<007oo
Ool0Sgoo00<007ooOol0=goo000COol00`00Oomoo`0iOol00`00Oomoo`2>Ool00`00Oomoo`0gOol0
01=oo`03001oogoo03Uoo`03001oogoo08eoo`03001oogoo03Qoo`004goo00<007ooOol0>Goo00<0
07ooOol0SGoo00<007ooOol0>7oo000COol00`00Oomoo`0jOol00`00Oomoo`2;Ool00`00Oomoo`0i
Ool001=oo`8003]oo`03001oogoo08]oo`03001oogoo03Uoo`004goo00<007ooOol0>Woo00<007oo
Ool0Rgoo00<007ooOol0>Goo000COol00`00Oomoo`0kOol00`00Oomoo`29Ool00`00Oomoo`0jOol0
01=oo`03001oogoo03]oo`03001oogoo08Uoo`03001oogoo03Yoo`004goo00<007ooOol0>goo00<0
07ooOol0R7oo00<007ooOol0>goo000COol00`00Oomoo`0lOol00`00Oomoo`27Ool00`00Oomoo`0k
Ool000aoo`<000Aoo`03001oogoo03aoo`03001oogoo08Moo`03001oogoo03]oo`003Goo00<007oo
Ool00goo00<007ooOol0?Goo00<007ooOol0QGoo00<007ooOol0?7oo000;Ool40004Ool2000nOol0
0`00Oomoo`25Ool00`00Oomoo`0lOol000]oo`03001oo`0000Eoo`03001oogoo03eoo`03001oogoo
08Aoo`03001oogoo03eoo`0037oo0P001Goo00<007ooOol0?Woo00<007ooOol0Pgoo00<007ooOol0
?Goo000=Ool00`00Oomoo`03Ool00`00Oomoo`0nOol00`00Oomoo`23Ool00`00Oomoo`0mOol001=o
o`03001oogoo03ioo`03001oogoo089oo`03001oogoo03ioo`004goo00<007ooOol0?goo00<007oo
Ool0PGoo00<007ooOol0?Woo000COol00`00Oomoo`0oOol00`00Oomoo`20Ool00`00Oomoo`0oOol0
01=oo`03001oogoo041oo`03001oogoo07moo`03001oogoo03moo`004goo0P00@Goo00<007ooOol0
Ogoo00<007ooOol0?goo000COol00`00Oomoo`10Ool00`00Oomoo`1nOol00`00Oomoo`10Ool001=o
o`03001oogoo045oo`03001oogoo07eoo`03001oogoo041oo`004goo00<007ooOol0@Goo00<007oo
Ool0O7oo00<007ooOol0@Goo000COol00`00Oomoo`12Ool00`00Oomoo`1kOol00`00Oomoo`11Ool0
01=oo`03001oogoo049oo`03001oogoo07Yoo`03001oogoo049oo`004goo00<007ooOol0@Woo00<0
07ooOol0NWoo00<007ooOol0@Woo000COol20014Ool00`00Oomoo`1hOol00`00Oomoo`13Ool001=o
o`03001oogoo04=oo`03001oogoo07Qoo`03001oogoo04=oo`004goo00<007ooOol0@goo00<007oo
Ool0Mgoo00<007ooOol0A7oo000COol00`00Oomoo`14Ool00`00Oomoo`1fOol00`00Oomoo`14Ool0
01=oo`03001oogoo04Aoo`03001oogoo07Eoo`03001oogoo04Eoo`004goo00<007ooOol0AGoo00<0
07ooOol0M7oo00<007ooOol0AGoo000COol00`00Oomoo`15Ool00`00Oomoo`1cOol00`00Oomoo`16
Ool001=oo`03001oogoo04Eoo`03001oogoo07=oo`03001oogoo04Ioo`004goo0P00Agoo00<007oo
Ool0LGoo00<007ooOol0Agoo000COol00`00Oomoo`16Ool00`00Oomoo`1aOol00`00Oomoo`17Ool0
01=oo`03001oogoo04Moo`03001oogoo06moo`03001oogoo04Qoo`004goo00<007ooOol0Agoo00<0
07ooOol0Kgoo00<007ooOol0B7oo000COol00`00Oomoo`18Ool00`00Oomoo`1]Ool00`00Oomoo`19
Ool001=oo`03001oogoo04Qoo`03001oogoo06eoo`03001oogoo04Uoo`004goo00<007ooOol0BGoo
00<007ooOol0Jgoo00<007ooOol0BWoo000COol00`00Oomoo`19Ool00`00Oomoo`1[Ool00`00Oomo
o`1:Ool001=oo`8004]oo`03001oogoo06Uoo`03001oogoo04]oo`004goo00<007ooOol0BWoo00<0
07ooOol0J7oo00<007ooOol0C7oo000COol00`00Oomoo`1;Ool00`00Oomoo`1WOol00`00Oomoo`1<
Ool001=oo`03001oogoo04]oo`03001oogoo06Ioo`03001oogoo04eoo`004goo00<007ooOol0C7oo
00<007ooOol0I7oo00<007ooOol0CWoo000COol00`00Oomoo`1<Ool00`00Oomoo`1SOol00`00Oomo
o`1?Ool000aoo`03001oogoo00Aoo`03001oogoo04eoo`03001oogoo069oo`03001oogoo04moo`00
2goo00<007oo00001Goo00<007ooOol0CWoo00<007ooOol0H7oo00<007ooOol0D7oo000=Ool00`00
Oomoo`03Ool2001?Ool00`00Oomoo`1OOol00`00Oomoo`1AOol000]oo`8000Ioo`03001oogoo04mo
o`03001oogoo05ioo`03001oogoo055oo`002goo00<007ooOol01Goo00<007ooOol0D7oo00<007oo
Ool0G7oo00<007ooOol0DWoo000;Ool30005Ool00`00Oomoo`1@Ool00`00Oomoo`1KOol00`00Oomo
o`1COol001=oo`03001oogoo055oo`03001oogoo05Uoo`03001oogoo05Aoo`004goo00<007ooOol0
DWoo0P00FGoo00<007ooOol0E7oo000COol00`00Oomoo`1DOol00`00Oomoo`1EOol00`00Oomoo`1E
Ool001=oo`03001oogoo05Eoo`03001oogoo05=oo`03001oogoo05Ioo`004goo0P00Egoo0P00DWoo
00<007ooOol0Egoo000COol00`00Oomoo`1HOol00`00Oomoo`1?Ool00`00Oomoo`1GOol001=oo`03
001oogoo05Uoo`03001oogoo04eoo`03001oogoo05Qoo`004goo00<007ooOol0FWoo0P00C7oo00<0
07ooOol0FGoo000COol00`00Oomoo`1LOol00`00Oomoo`18Ool00`00Oomoo`1JOol001=oo`03001o
ogoo05eoo`8004Qoo`03001oogoo05Yoo`004goo00<007ooOol0Ggoo0P00AGoo00<007ooOol0Fgoo
000COol00`00Oomoo`1QOol00`00Oomoo`11Ool00`00Oomoo`1LOol001=oo`8006=oo`80041oo`03
001oogoo05eoo`004goo00<007ooOol0I7oo00<007ooOol0?Goo00<007ooOol0GGoo000COol00`00
Oomoo`1UOol00`00Oomoo`0kOol00`00Oomoo`1NOol001=oo`03001oogoo06Ioo`8003Yoo`03001o
ogoo05moo`004goo00<007ooOol0J7oo00<007ooOol0=Woo00<007ooOol0H7oo000COol00`00Oomo
o`1YOol00`00Oomoo`0dOol00`00Oomoo`1QOol001=oo`03001oogoo06Yoo`03001oogoo039oo`03
001oogoo069oo`004goo0P00K7oo0P00<Goo00<007ooOol0Hgoo000COol00`00Oomoo`1]Ool00`00
Oomoo`0]Ool00`00Oomoo`1TOol001=oo`03001oogoo06ioo`03001oogoo02]oo`03001oogoo06Eo
o`004goo00<007ooOol0Kgoo00<007ooOol0:Goo00<007ooOol0IWoo000COol00`00Oomoo`1`Ool0
0`00Oomoo`0WOol00`00Oomoo`1WOol001=oo`03001oogoo075oo`03001oogoo02Eoo`03001oogoo
06Qoo`004goo00<007ooOol0LWoo00<007ooOol08goo00<007ooOol0JGoo000COol00`00Oomoo`1c
Ool2000ROol00`00Oomoo`1ZOol001=oo`8007Ioo`03001oogoo01ioo`03001oogoo06]oo`004goo
00<007ooOol0MWoo00<007ooOol077oo00<007ooOol0K7oo000COol00`00Oomoo`1gOol00`00Oomo
o`0JOol00`00Oomoo`1]Ool001=oo`03001oogoo07Qoo`03001oogoo01Qoo`03001oogoo06ioo`00
4goo00<007ooOol0NGoo0P005goo00<007ooOol0Kgoo000COol00`00Oomoo`1kOol2000DOol00`00
Oomoo`1`Ool000]oo`8000Ioo`03001oogoo07eoo`80011oo`8007=oo`002goo00<007oo00001Goo
00<007ooOol0Ogoo0P0037oo0P00MGoo000;Ool00`00Ool00005Ool20022Ool<001gOol000]oo`80
00Ioo`03001oogoo0?moo`Eoo`002goo00<007ooOol01Goo00<007ooOol0ogoo1Goo000<Ool20005
Ool00`00Oomoo`3oOol5Ool001=oo`03001oogoo0?moo`Eoo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-0.39098, 1.68708, 0.0203531, 
  0.0255961}}]
}, Open  ]],

Cell[TextData["Here is a plot of the tension in the cable."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[Reaction[3, s] /. sol], {T, 0, 5}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 -0.282829 0.00205025 [
[.21429 .01221 -3 -9 ]
[.21429 .01221 3 0 ]
[.40476 .01221 -3 -9 ]
[.40476 .01221 3 0 ]
[.59524 .01221 -3 -9 ]
[.59524 .01221 3 0 ]
[.78571 .01221 -3 -9 ]
[.78571 .01221 3 0 ]
[.97619 .01221 -3 -9 ]
[.97619 .01221 3 0 ]
[.01131 .12722 -18 -4.5 ]
[.01131 .12722 0 4.5 ]
[.01131 .22973 -18 -4.5 ]
[.01131 .22973 0 4.5 ]
[.01131 .33224 -18 -4.5 ]
[.01131 .33224 0 4.5 ]
[.01131 .43476 -18 -4.5 ]
[.01131 .43476 0 4.5 ]
[.01131 .53727 -18 -4.5 ]
[.01131 .53727 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .02471 m
.21429 .03096 L
s
[(1)] .21429 .01221 0 1 Mshowa
.40476 .02471 m
.40476 .03096 L
s
[(2)] .40476 .01221 0 1 Mshowa
.59524 .02471 m
.59524 .03096 L
s
[(3)] .59524 .01221 0 1 Mshowa
.78571 .02471 m
.78571 .03096 L
s
[(4)] .78571 .01221 0 1 Mshowa
.97619 .02471 m
.97619 .03096 L
s
[(5)] .97619 .01221 0 1 Mshowa
.125 Mabswid
.0619 .02471 m
.0619 .02846 L
s
.1 .02471 m
.1 .02846 L
s
.1381 .02471 m
.1381 .02846 L
s
.17619 .02471 m
.17619 .02846 L
s
.25238 .02471 m
.25238 .02846 L
s
.29048 .02471 m
.29048 .02846 L
s
.32857 .02471 m
.32857 .02846 L
s
.36667 .02471 m
.36667 .02846 L
s
.44286 .02471 m
.44286 .02846 L
s
.48095 .02471 m
.48095 .02846 L
s
.51905 .02471 m
.51905 .02846 L
s
.55714 .02471 m
.55714 .02846 L
s
.63333 .02471 m
.63333 .02846 L
s
.67143 .02471 m
.67143 .02846 L
s
.70952 .02471 m
.70952 .02846 L
s
.74762 .02471 m
.74762 .02846 L
s
.82381 .02471 m
.82381 .02846 L
s
.8619 .02471 m
.8619 .02846 L
s
.9 .02471 m
.9 .02846 L
s
.9381 .02471 m
.9381 .02846 L
s
.25 Mabswid
0 .02471 m
1 .02471 L
s
.02381 .12722 m
.03006 .12722 L
s
[(200)] .01131 .12722 1 0 Mshowa
.02381 .22973 m
.03006 .22973 L
s
[(250)] .01131 .22973 1 0 Mshowa
.02381 .33224 m
.03006 .33224 L
s
[(300)] .01131 .33224 1 0 Mshowa
.02381 .43476 m
.03006 .43476 L
s
[(350)] .01131 .43476 1 0 Mshowa
.02381 .53727 m
.03006 .53727 L
s
[(400)] .01131 .53727 1 0 Mshowa
.125 Mabswid
.02381 .04521 m
.02756 .04521 L
s
.02381 .06571 m
.02756 .06571 L
s
.02381 .08622 m
.02756 .08622 L
s
.02381 .10672 m
.02756 .10672 L
s
.02381 .14772 m
.02756 .14772 L
s
.02381 .16823 m
.02756 .16823 L
s
.02381 .18873 m
.02756 .18873 L
s
.02381 .20923 m
.02756 .20923 L
s
.02381 .25023 m
.02756 .25023 L
s
.02381 .27074 m
.02756 .27074 L
s
.02381 .29124 m
.02756 .29124 L
s
.02381 .31174 m
.02756 .31174 L
s
.02381 .35275 m
.02756 .35275 L
s
.02381 .37325 m
.02756 .37325 L
s
.02381 .39375 m
.02756 .39375 L
s
.02381 .41425 m
.02756 .41425 L
s
.02381 .45526 m
.02756 .45526 L
s
.02381 .47576 m
.02756 .47576 L
s
.02381 .49626 m
.02756 .49626 L
s
.02381 .51677 m
.02756 .51677 L
s
.02381 .00421 m
.02756 .00421 L
s
.02381 .55777 m
.02756 .55777 L
s
.02381 .57827 m
.02756 .57827 L
s
.02381 .59878 m
.02756 .59878 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .0148 L
.02605 .01502 L
.02729 .01544 L
.02846 .01601 L
.03053 .01743 L
.03279 .01958 L
.03527 .02269 L
.0379 .02688 L
.04262 .03687 L
.04749 .05082 L
.05205 .06774 L
.05706 .09125 L
.06244 .12332 L
.07373 .21804 L
.08445 .3435 L
.08947 .40727 L
.09419 .46176 L
.09681 .48651 L
.09819 .49731 L
.09964 .50687 L
.10087 .51322 L
.10152 .51594 L
.10221 .51836 L
.10344 .52134 L
.10458 .52255 L
.10522 .52258 L
.1059 .52212 L
.10713 .52004 L
.10845 .51598 L
.1092 .51287 L
.1099 .50947 L
.11233 .4944 L
.11494 .47321 L
.12439 .37549 L
.13391 .28197 L
.13855 .24606 L
.14277 .21969 L
.1474 .19739 L
.14994 .1879 L
.15234 .18065 L
.15496 .17453 L
.15737 .17047 L
.15863 .16893 L
.16001 .16768 L
.16071 .16722 L
.16146 .16686 L
.16217 .16664 L
.16281 .16654 L
.16411 .16664 L
Mistroke
.16484 .16686 L
.1655 .16717 L
.16678 .16804 L
.16799 .16921 L
.16941 .17099 L
.17071 .17301 L
.17364 .17897 L
.17602 .18523 L
.17864 .19359 L
.18391 .21533 L
.18917 .24381 L
.19414 .27735 L
.20346 .35766 L
.21362 .46465 L
.21918 .52272 L
.2219 .54793 L
.22439 .56785 L
.22657 .58219 L
.22896 .59392 L
.2302 .59823 L
.23136 .60106 L
.23258 .60284 L
.23388 .60332 L
.23458 .60295 L
.23523 .60224 L
.23595 .60105 L
.2367 .59935 L
.23797 .59543 L
.23936 .58968 L
.24193 .5755 L
.24434 .55865 L
.26277 .39072 L
.26777 .35243 L
.27321 .31932 L
.27569 .30735 L
.27834 .29686 L
.2806 .28974 L
.28182 .28661 L
.2831 .28383 L
.28424 .28181 L
.2855 .28008 L
.28664 .27896 L
.2877 .27829 L
.28895 .27798 L
.2901 .27813 L
.29142 .27883 L
.29266 .27999 L
.29375 .28141 L
.2949 .28332 L
.29697 .28776 L
Mistroke
.2992 .294 L
.30165 .30253 L
.31244 .35745 L
.3227 .42133 L
.32716 .44498 L
.32961 .45529 L
.33191 .46275 L
.33322 .46588 L
.33391 .46718 L
.33464 .46829 L
.33593 .46959 L
.33712 .46996 L
.33831 .46957 L
.33943 .46852 L
.34065 .46658 L
.34195 .46362 L
.34321 .45995 L
.34455 .45519 L
.34695 .44459 L
.35238 .41274 L
.36225 .34109 L
.3719 .27482 L
.38075 .2287 L
.38532 .21149 L
.39013 .1983 L
.39263 .1934 L
.39495 .19003 L
.39629 .1886 L
.39751 .18762 L
.39818 .18721 L
.39891 .18686 L
.3996 .18664 L
.40023 .18652 L
.40129 .18649 L
.40242 .18671 L
.40349 .18716 L
.40446 .18776 L
.40561 .18871 L
.40685 .19003 L
.40912 .1932 L
.41148 .19755 L
.414 .20336 L
.41852 .21671 L
.43855 .30972 L
.44403 .33671 L
.44703 .3492 L
.44982 .35864 L
.45221 .36456 L
.45289 .36586 L
.45354 .36691 L
Mistroke
.45476 .36837 L
.45541 .36887 L
.45611 .3692 L
.45735 .36922 L
.45805 .36892 L
.45869 .36841 L
.45941 .36762 L
.46017 .36649 L
.46146 .36397 L
.46283 .36039 L
.46531 .35175 L
.46825 .33805 L
.47091 .32287 L
.48113 .24992 L
.49045 .18032 L
.50031 .11889 L
.50509 .0954 L
.51033 .07453 L
.5151 .05998 L
.51955 .0501 L
.52084 .0479 L
.52225 .04584 L
.52348 .04432 L
.5248 .04301 L
.52598 .04209 L
.52729 .04137 L
.52848 .04097 L
.52959 .04083 L
.53091 .04095 L
.53157 .04114 L
.5323 .04144 L
.53358 .0422 L
.53478 .04319 L
.53619 .0447 L
.53748 .0464 L
.54036 .05143 L
.54267 .05667 L
.54521 .06371 L
.55034 .08232 L
.55509 .10515 L
.55954 .13177 L
.56956 .21133 L
.58033 .32236 L
.58524 .37549 L
.59046 .4265 L
.59346 .45055 L
.59619 .46767 L
.5975 .47411 L
.59892 .47968 L
.59958 .4817 L
Mistroke
.60027 .48348 L
.6015 .48577 L
.60275 .48694 L
.60389 .48693 L
.60521 .48576 L
.60646 .48356 L
.60761 .48058 L
.60868 .4771 L
.61109 .46694 L
.61619 .43733 L
.6216 .39958 L
.63099 .33541 L
.63592 .30722 L
.6411 .28299 L
.64566 .26626 L
.65065 .25252 L
.65284 .24784 L
.65518 .24368 L
.65718 .24075 L
.65939 .23817 L
.66198 .23593 L
.6634 .23505 L
.66409 .2347 L
.66473 .23442 L
.66597 .23401 L
.6671 .23378 L
.66832 .23368 L
.66901 .23369 L
.66965 .23375 L
.67097 .23398 L
.67221 .23434 L
.67357 .23489 L
.67504 .23567 L
.67802 .23785 L
.68077 .24051 L
.68545 .24649 L
.69058 .25509 L
.70093 .27897 L
.71118 .3111 L
.7205 .34688 L
.74144 .44112 L
.75074 .48321 L
.76059 .52213 L
.76574 .53812 L
.76847 .54492 L
.7714 .55071 L
.77278 .55282 L
.77409 .55446 L
.77527 .55561 L
.77655 .5565 L
Mistroke
.77777 .55699 L
.77906 .55708 L
.78028 .55679 L
.78138 .55622 L
.78258 .55524 L
.78371 .55401 L
.78494 .55228 L
.78626 .54998 L
.78895 .54385 L
.79141 .53673 L
.79615 .51905 L
.80063 .49826 L
.81073 .44238 L
.82145 .38186 L
.83092 .33826 L
.83352 .32885 L
.83631 .3201 L
.83873 .31372 L
.84137 .30811 L
.8438 .30417 L
.84496 .30271 L
.84605 .30157 L
.8473 .30058 L
.84843 .29996 L
.84966 .29957 L
.85035 .29948 L
.85098 .29948 L
.85203 .29966 L
.85302 .30001 L
.8541 .30061 L
.85526 .30152 L
.85763 .30415 L
.85979 .30739 L
.86457 .3173 L
.86967 .33123 L
.87882 .36176 L
.88408 .37958 L
.88963 .39597 L
.89192 .40152 L
.89437 .40637 L
.89577 .40862 L
.89705 .41033 L
.89834 .41171 L
.89956 .41269 L
.90081 .41328 L
.90144 .41343 L
.90213 .41349 L
.90336 .41334 L
.9045 .41291 L
.9052 .41251 L
Mistroke
.90586 .41204 L
.90709 .41091 L
.90842 .40928 L
.90988 .40705 L
.91565 .39458 L
.92102 .37887 L
.9412 .31277 L
.97619 .2228 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000[Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00AGoo1@00;goo0`00;goo0P00<Woo0`00<7oo00<007ooOol01Goo0017Ool00`00
Oomoo`0_Ool00`00Oomoo`0aOol00`00Oomoo`0`Ool00`00Oomoo`0^Ool00`00Ool00006Ool004Mo
o`03001oogoo031oo`03001oogoo02moo`03001oogoo02moo`@0035oo`03001oogoo00Aoo`00Agoo
00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol0;Woo00<007oo0000<7oo0P001goo0017Ool0
0`00Oomoo`0_Ool00`00Ool0000_Ool00`00Ool0000aOol2000`Ool00`00Oomoo`06Ool001Eoo`03
001oogoo02ioo`80039oo`03001oogoo02moo`03001oogoo035oo`03001oogoo02ioo`<000Ioo`00
5Goo0P00ogoo17oo000EOol00`00Oomoo`3oOol3Ool001Eoo`03001oogoo0?moo`=oo`005Goo0`00
ogoo0goo000EOol00`00Ool0003oOol3Ool000ioool000d000005Goo00D007ooOomoo`0000Eoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Eoo`00
5Goo00D007ooOomoo`0002eoo`03001oogoo031oo`03001oogoo031oo`03001oogoo02moo`03001o
ogoo031oo`03001oogoo00Eoo`005Goo00<007ooOol00Woo00<007ooOol0oGoo000EOol00`00Oomo
o`02Ool00`00Oomoo`3mOol001Eoo`03001oogoo009oo`03001oogoo07eoo`@007aoo`005Goo0P00
17oo00<007ooOol0Ngoo00D007ooOomoo`0007aoo`005Goo00<007ooOol00goo00<007ooOol0Ngoo
00<007ooOol00Woo00<007ooOol0NGoo000EOol00`00Oomoo`03Ool00`00Oomoo`1kOol00`00Oomo
o`02Ool00`00Oomoo`1iOol001Eoo`03001oogoo00=oo`03001oogoo07Yoo`03001oogoo00Aoo`03
001oogoo07Qoo`005Goo00<007ooOol017oo00<007ooOol0NGoo00<007ooOol017oo00<007ooOol0
N7oo000EOol20005Ool00`00Oomoo`1hOol00`00Oomoo`06Ool00`00Oomoo`1gOol001Eoo`03001o
ogoo00Aoo`03001oogoo07Qoo`03001oogoo00Ioo`03001oogoo07Moo`005Goo00<007ooOol017oo
00<007ooOol0Mgoo00<007ooOol01goo00<007ooOol0Mgoo000EOol00`00Oomoo`05Ool00`00Oomo
o`1fOol00`00Oomoo`08Ool00`00Oomoo`1fOol001Eoo`03001oogoo00Eoo`03001oogoo07Ioo`03
001oogoo00Qoo`03001oogoo07Ioo`005Goo00<007ooOol01Goo00<007ooOol0MGoo00<007ooOol0
2Goo00<007ooOol0MWoo000EOol20007Ool00`00Oomoo`1dOol00`00Oomoo`09Ool00`00Oomoo`1f
Ool001Eoo`03001oogoo00Ioo`03001oogoo07Aoo`03001oogoo00Uoo`03001oogoo07Ioo`005Goo
00<007ooOol01Woo00<007ooOol0M7oo00<007ooOol02Goo00<007ooOol0MWoo000EOol00`00Oomo
o`06Ool00`00Oomoo`1dOol00`00Oomoo`0:Ool00`00Oomoo`1eOol001Eoo`03001oogoo00Ioo`03
001oogoo07Aoo`03001oogoo00Yoo`03001oogoo07Eoo`005Goo0P001goo00<007ooOol0Lgoo00<0
07ooOol02goo00<007ooOol0MGoo000EOol00`00Oomoo`07Ool00`00Oomoo`1bOol00`00Oomoo`0;
Ool00`00Oomoo`1eOol001Eoo`03001oogoo00Moo`03001oogoo079oo`03001oogoo00]oo`03001o
ogoo07Eoo`005Goo00<007ooOol01goo00<007ooOol0LWoo00<007ooOol02goo00<007ooOol0MGoo
0004Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`1bOol0
0`00Oomoo`0<Ool00`00Oomoo`1dOol000Aoo`03001oogoo009oo`03001oo`00009oo`03001oo`00
00Aoo`03001oogoo00Moo`03001oogoo079oo`03001oogoo00aoo`03001oogoo07Aoo`001Goo00L0
07ooOomoo`00Ool00002Ool00`00Ool00004Ool20008Ool00`00Oomoo`1aOol00`00Oomoo`0=Ool0
0`00Oomoo`1dOol000Eoo`07001oogooOol007oo00000Woo00<007oo000017oo00<007ooOol01goo
00<007ooOol0LGoo00<007ooOol03Goo00<007ooOol0M7oo0004Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00004Ool00`00Oomoo`07Ool00`00Oomoo`1aOol00`00Oomoo`0=Ool00`00Oomo
o`1dOol000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Qoo`03
001oogoo071oo`03001oogoo00eoo`03001oogoo07Aoo`005Goo00<007ooOol027oo00<007ooOol0
L7oo00<007ooOol03Goo00<007ooOol0M7oo000EOol20009Ool00`00Oomoo`1`Ool00`00Oomoo`0>
Ool00`00Oomoo`1cOol001Eoo`03001oogoo00Qoo`03001oogoo06moo`03001oogoo00moo`03001o
ogoo07=oo`005Goo00<007ooOol027oo00<007ooOol0Kgoo00<007ooOol03goo00<007ooOol0Lgoo
000EOol00`00Oomoo`08Ool00`00Oomoo`1_Ool00`00Oomoo`0?Ool00`00Oomoo`1cOol001Eoo`03
001oogoo00Qoo`03001oogoo06moo`03001oogoo00moo`03001oogoo07=oo`005Goo0P002Goo00<0
07ooOol05Woo0`00EWoo00<007ooOol03goo00<007ooOol0Lgoo000EOol00`00Oomoo`08Ool00`00
Oomoo`0EOol200000goo0000001EOol00`00Oomoo`0?Ool00`00Oomoo`1cOol001Eoo`03001oogoo
00Uoo`03001oogoo01Aoo`05001oogooOol0001DOol00`00Oomoo`0AOol00`00Oomoo`1bOol001Eo
o`03001oogoo00Uoo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo055oo`03001oogoo015o
o`03001oogoo079oo`005Goo00<007ooOol02Goo00<007ooOol04goo00<007ooOol00goo00<007oo
Ool0DGoo00<007ooOol04Goo00<007ooOol0LWoo000EOol00`00Oomoo`09Ool00`00Oomoo`0BOol0
0`00Oomoo`04Ool00`00Oomoo`0hOol3000FOol00`00Oomoo`0AOol00`00Oomoo`1bOol001Eoo`80
00Yoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo03Qoo`04001oo`00000EOol00`00Oomo
o`0AOol00`00Oomoo`1bOol001Eoo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo00Eoo`03
001oogoo03Ioo`05001oogooOol0000DOol00`00Oomoo`0BOol00`00Oomoo`1bOol001Eoo`03001o
ogoo00Uoo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo03Eoo`03001oogoo00=oo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo079oo`005Goo00<007ooOol02Goo00<007ooOol04Woo
00<007ooOol01Goo00<007ooOol0=Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol04goo
00<007ooOol0LGoo000EOol00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomo
o`0dOol00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`0COol00`00Oomoo`1aOol001Eoo`80
00]oo`03001oogoo011oo`03001oogoo00Moo`03001oogoo03=oo`03001oogoo00Eoo`03001oogoo
011oo`03001oogoo01=oo`03001oogoo075oo`005Goo00<007ooOol02Woo00<007ooOol047oo00<0
07ooOol01goo00<007ooOol0<goo00<007ooOol01Woo00<007ooOol03goo00<007ooOol04goo00<0
07ooOol0LGoo000EOol00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0c
Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`0DOol00`00Oomoo`1aOol001Eoo`03001o
ogoo00Yoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo03=oo`03001oogoo00Ioo`03001o
ogoo00ioo`03001oogoo01Aoo`03001oogoo075oo`0017oo0`000goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol02Woo00<007ooOol03goo00<007ooOol027oo00<007ooOol0<Woo00<007oo
Ool01goo00<007ooOol03Woo00<007ooOol057oo00<007ooOol0JGoo00<007ooOol01Goo0004Ool0
0`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool0
0`00Oomoo`09Ool00`00Oomoo`0aOol00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`0DOol0
0`00Oomoo`1YOol00`00Oomoo`05Ool000Eoo`03001oogoo00=oo`06001oogoo001oo`0017oo0P00
2goo00<007ooOol03goo00<007ooOol02Goo00<007ooOol0<Goo00<007ooOol027oo00<007ooOol0
3Goo00<007ooOol05Goo00<007ooOol0Igoo00<007ooOol01Woo0005Ool01000Oomoogoo0P000goo
00<007oo000017oo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol02Woo00<007ooOol0<Goo
00<007ooOol027oo00<007ooOol03Goo00<007ooOol05Goo00<007ooOol05Goo1000CWoo00<007oo
Ool01Woo0004Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`0:Ool0
0`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`0`Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool0
0`00Oomoo`0FOol00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`1:Ool00`00Oomoo`07Ool0
00Eoo`04001oogooOol30003Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00
Oomoo`0;Ool00`00Oomoo`0_Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00
Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`19Ool00`00Oomoo`07Ool001Eoo`03001oogoo00]o
o`03001oogoo00eoo`03001oogoo00]oo`03001oogoo02moo`03001oogoo00Yoo`03001oogoo00]o
o`03001oogoo01Ioo`03001oogoo019oo`03001oogoo00Ioo`03001oogoo04Qoo`03001oogoo00Mo
o`005Goo0P0037oo00<007ooOol03Goo00<007ooOol02goo00<007ooOol0;goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol01Woo00<007ooOol0Agoo
00<007ooOol027oo000EOol00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomo
o`0^Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`0BOol00`00Oomo
o`07Ool00`00Oomoo`16Ool00`00Oomoo`08Ool001Eoo`03001oogoo00]oo`03001oogoo00eoo`03
001oogoo00]oo`03001oogoo02ioo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo01Ioo`03
001oogoo015oo`03001oogoo00Qoo`03001oogoo04Ioo`03001oogoo00Qoo`005Goo00<007ooOol0
2goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol0;Woo00<007ooOol02goo00<007ooOol0
2goo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol027oo00<007ooOol0AGoo00<007ooOol0
2Goo000EOol00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0]Ool00`00
Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Oomoo`0@Ool00`00Oomoo`0:Ool00`00
Oomoo`14Ool00`00Oomoo`09Ool001Eoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00eo
o`03001oogoo02aoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo00mo
o`03001oogoo00Yoo`03001oogoo04=oo`03001oogoo00Yoo`005Goo0P0037oo00<007ooOol037oo
00<007ooOol03Goo00<007ooOol0;7oo00<007ooOol03Goo00<007ooOol02Goo00<007ooOol067oo
00<007ooOol03goo00<007ooOol02goo00<007ooOol0@Woo00<007ooOol02Woo000EOol00`00Oomo
o`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0/Ool00`00Oomoo`0=Ool00`00Oomo
o`09Ool00`00Oomoo`0HOol00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`12Ool00`00Oomo
o`0:Ool001Eoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo01Eoo`<0
01Aoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo00ioo`03001oogoo
00eoo`03001oogoo041oo`03001oogoo00]oo`005Goo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol03Goo00<007ooOol05Goo00@007ooOol001=oo`03001oogoo00ioo`03001oogoo00Qoo`03
001oogoo01Qoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo041oo`03001oogoo00]oo`00
5Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol03Goo00<007ooOol057oo00D007ooOomo
o`0001=oo`03001oogoo00ioo`03001oogoo00Qoo`03001oogoo01Qoo`03001oogoo00ioo`03001o
ogoo00ioo`03001oogoo03moo`03001oogoo00]oo`005Goo0P003Goo00<007ooOol02goo00<007oo
Ool03Woo00<007ooOol04goo00D007ooOomoo`0001=oo`03001oogoo00ioo`03001oogoo00Qoo`03
001oogoo01Qoo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo03ioo`03001oogoo00aoo`00
5Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol03Woo00<007ooOol04goo00<007ooOol0
0Woo00<007ooOol03goo00<007ooOol03goo00<007ooOol027oo00<007ooOol067oo00<007ooOol0
3Goo00<007ooOol03goo00<007ooOol0?Woo00<007ooOol037oo000EOol00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00
Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0HOol00`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00
Oomoo`0ROol2000HOol00`00Oomoo`0=Ool001Eoo`03001oogoo00aoo`03001oogoo00]oo`03001o
ogoo00ioo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo011oo`03001o
ogoo00Moo`03001oogoo01Qoo`03001oogoo00eoo`03001oogoo011oo`03001oogoo025oo`800003
Ool007oo01Ioo`03001oogoo00eoo`005Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
3Woo00<007ooOol04Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol047oo00<007ooOol0
1Woo00<007ooOol06Woo00<007ooOol037oo00<007ooOol04Goo00<007ooOol087oo00D007ooOomo
o`0001Ioo`03001oogoo00eoo`005Goo00<007ooOol037oo00<007ooOol02Woo00<007ooOol03goo
00<007ooOol04Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol047oo00<007ooOol01Woo
00<007ooOol06Woo00<007ooOol037oo00<007ooOol04Goo00<007ooOol07goo00<007ooOol00Woo
00<007ooOol04goo00<007ooOol03Woo000EOol2000=Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool0
0`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool0
0`00Oomoo`0JOol00`00Oomoo`0;Ool00`00Oomoo`0BOol00`00Oomoo`0OOol00`00Oomoo`03Ool0
0`00Oomoo`0BOol00`00Oomoo`0>Ool001Eoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo
00moo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo00eoo`03001oogoo015oo`03001oogoo
00Eoo`03001oogoo01Yoo`03001oogoo00]oo`03001oogoo019oo`03001oogoo01ioo`03001oogoo
00Aoo`03001oogoo019oo`03001oogoo00ioo`005Goo00<007ooOol037oo00<007ooOol02Woo00<0
07ooOol047oo00<007ooOol047oo00<007ooOol01Woo00<007ooOol03Goo00<007ooOol04Goo00<0
07ooOol01Goo00<007ooOol06Woo00<007ooOol02goo00<007ooOol04goo00<007ooOol07Goo00<0
07ooOol017oo00<007ooOol04Goo00<007ooOol03goo0004Ool20004Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00
Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00
Oomoo`0;Ool00`00Oomoo`0COol00`00Oomoo`0LOol00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00
Oomoo`0?Ool000Ioo`06001oogoo001oo`000Woo00<007oo000017oo00<007ooOol03Goo00<007oo
Ool02Goo00<007ooOol047oo00<007ooOol047oo00<007ooOol01Woo00<007ooOol037oo00<007oo
Ool04Woo00<007ooOol01Goo00<007ooOol06Woo00<007ooOol02Woo00<007ooOol057oo00<007oo
Ool077oo00<007ooOol01Woo00<007ooOol047oo00<007ooOol03goo0005Ool01`00Oomoogoo001o
o`00009oo`03001oo`0000Aoo`8000ioo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo011o
o`03001oogoo00Moo`03001oogoo00]oo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo01]o
o`03001oogoo00Yoo`03001oogoo01Aoo`03001oogoo01aoo`03001oogoo00Moo`03001oogoo00io
o`03001oogoo011oo`001Woo00H007ooOol007oo0002Ool00`00Ool00004Ool00`00Oomoo`0=Ool0
0`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool0
0`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`0KOol00`00Oomoo`0:Ool00`00Oomoo`0DOol0
0`00Oomoo`0LOol00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool000Aoo`03001oo`00
009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo
011oo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo01=oo`03001oogoo
00=oo`03001oogoo01]oo`03001oogoo00Yoo`03001oogoo01Eoo`03001oogoo01]oo`03001oogoo
00Moo`03001oogoo00ioo`03001oogoo011oo`001Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol03Goo00<007ooOol02Goo00<007ooOol047oo00<007ooOol03goo00<0
07ooOol027oo00<007ooOol02goo00<007ooOol04goo00<007ooOol00goo00<007ooOol06goo00<0
07ooOol02Woo00<007ooOol05Goo00<007ooOol06goo00<007ooOol027oo00<007ooOol037oo00<0
07ooOol04Goo000EOol00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`0>
Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`0COol00`00Oomoo`02Ool00`00Oomoo`0L
Ool00`00Oomoo`0:Ool00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`09Ool00`00Oomoo`0<
Ool00`00Oomoo`0AOol001Eoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo015oo`03001o
ogoo00ioo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo01=oo`03001oogoo009oo`03001o
ogoo01eoo`03001oogoo00Uoo`03001oogoo01Eoo`03001oogoo01Yoo`03001oogoo00Uoo`03001o
ogoo00]oo`03001oogoo019oo`005Goo0P003Woo00<007ooOol027oo00<007ooOol04Woo00<007oo
Ool03Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol057oo00<007ooOol00Woo00<007oo
Ool07Goo00<007ooOol027oo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol02Goo00<007oo
Ool02goo00<007ooOol04Woo000EOol00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`0BOol0
0`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0EOol01@00Oomoogoo0000
7goo00<007ooOol027oo00<007ooOol05goo00<007ooOol06Goo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol04Woo000EOol00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00
Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomoo`02000OOol0
0`00Oomoo`08Ool00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`09Ool0
0`00Oomoo`0COol001Eoo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo019oo`03001oogoo
00eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo01Ioo`03001oo`00021oo`03001oogoo
00Qoo`03001oogoo01Moo`03001oogoo01Qoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo
01=oo`005Goo00<007ooOol03Goo00<007ooOol027oo00<007ooOol04Woo00<007ooOol03Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol05Woo0`0087oo00<007ooOol027oo00<007ooOol0
5goo00<007ooOol067oo00<007ooOol037oo00<007ooOol027oo00<007ooOol04goo000EOol2000>
Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0iOol00`00Oomoo`08Ool00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0<
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol001Eoo`03001oogoo00ioo`03001oogoo00Moo`03001o
ogoo019oo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo03Yoo`03001o
ogoo00Qoo`03001oogoo01Qoo`03001oogoo01Ioo`03001oogoo00ioo`03001oogoo00Ioo`03001o
ogoo01Aoo`005Goo00<007ooOol03Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol03Goo
00<007ooOol02goo00<007ooOol01goo00<007ooOol0>Woo00<007ooOol027oo00<007ooOol067oo
00<007ooOol05Woo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol057oo000EOol00`00Oomo
o`0>Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`07Ool00`00Oomoo`0jOol00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomo
o`0>Ool00`00Oomoo`06Ool00`00Oomoo`0DOol001Eoo`03001oogoo00ioo`03001oogoo00Moo`03
001oogoo01=oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo03Yoo`03
001oogoo00Moo`03001oogoo01Yoo`03001oogoo01Eoo`03001oogoo00ioo`03001oogoo00Eoo`03
001oogoo01Eoo`005Goo0P003goo00<007ooOol01goo00<007ooOol04goo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol01goo00<007ooOol0>goo00<007ooOol01Woo00<007ooOol06Woo00<0
07ooOol057oo00<007ooOol047oo00<007ooOol017oo00<007ooOol05Goo000EOol00`00Oomoo`0>
Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`07
Ool00`00Oomoo`0kOol00`00Oomoo`06Ool00`00Oomoo`0JOol00`00Oomoo`0DOol00`00Oomoo`0@
Ool00`00Oomoo`04Ool00`00Oomoo`0EOol001Eoo`03001oogoo00ioo`03001oogoo00Ioo`03001o
ogoo01Aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo03aoo`03001o
ogoo00Ioo`03001oogoo01Yoo`03001oogoo01Aoo`03001oogoo015oo`03001oogoo00=oo`03001o
ogoo01Eoo`005Goo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol057oo00<007ooOol02goo
00<007ooOol037oo00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo00<007ooOol06goo
00<007ooOol04goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol05Woo000EOol00`00Oomo
o`0>Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomo
o`05Ool00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`0COol00`00Oomo
o`0AOol20003Ool00`00Oomoo`0FOol001Eoo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo
01Aoo`03001oogoo00Yoo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo03aoo`03001oogoo
00Eoo`03001oogoo01aoo`03001oogoo019oo`03001oogoo01=oo`@001Uoo`005Goo0P003goo00<0
07ooOol01Woo00<007ooOol057oo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol01Goo00<0
07ooOol0?Goo00<007ooOol017oo00<007ooOol077oo00<007ooOol04Woo00<007ooOol057oo0P00
6Woo000EOol00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00
Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`0mOol00`00Oomoo`04Ool00`00Oomoo`0MOol00`00
Oomoo`0AOol00`00Oomoo`0`Ool001Eoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo01Ao
o`03001oogoo00Yoo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo03eoo`03001oogoo00Ao
o`03001oogoo01eoo`03001oogoo015oo`03001oogoo031oo`0017oo0P0017oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol03goo00<007ooOol017oo00<007ooOol05Goo00<007ooOol02Woo
00<007ooOol03Woo00<007ooOol01Goo00<007ooOol0?Goo00<007ooOol017oo00<007ooOol07Goo
00<007ooOol04Goo00<007ooOol0<7oo0006Ool01P00Oomoo`00Ool0009oo`03001oo`0000Aoo`03
001oogoo00moo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo00moo`03
001oogoo00=oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo01ioo`03001oogoo015oo`03
001oogoo031oo`001Goo00<007ooOol00goo00H007ooOol007oo0004Ool2000@Ool00`00Oomoo`04
Ool00`00Oomoo`0EOol00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0n
Ool00`00Oomoo`03Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0aOol000Ioo`03001o
ogoo008000=oo`03001oo`0000Aoo`03001oogoo00moo`03001oogoo00Aoo`03001oogoo01Eoo`03
001oogoo00Yoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo01moo`03001oogoo00moo`03001oogoo035oo`0017oo00<007oo00000Woo00<007ooOol0
0Woo00<007oo000017oo00<007ooOol03goo00<007ooOol017oo00<007ooOol05Woo00<007ooOol0
2Goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol00goo00<007ooOol0
7goo00<007ooOol03goo00<007ooOol0<Goo0005Ool01000Oomoogoo0`000goo00<007ooOol00goo
00<007ooOol03goo00<007ooOol017oo00<007ooOol05Woo00<007ooOol027oo00<007ooOol04Goo
00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol00goo00<007ooOol07goo00<007ooOol03goo
00<007ooOol0<Goo000EOol00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0FOol00`00Oomo
o`08Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomo
o`0OOol00`00Oomoo`0?Ool00`00Oomoo`0aOol001Eoo`03001oogoo011oo`03001oogoo00=oo`03
001oogoo01Ioo`03001oogoo00Qoo`03001oogoo015oo`05001oogooOol00011Ool00`00Oomoo`02
Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool00`00Oomoo`0bOol001Eoo`80015oo`03001oogoo00=o
o`03001oogoo01Ioo`03001oogoo00Qoo`03001oogoo015oo`05001oogooOol00011Ool00`00Oomo
o`02Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool00`00Oomoo`0bOol001Eoo`03001oogoo011oo`03
001oogoo009oo`03001oogoo01Moo`03001oogoo00Qoo`03001oogoo015oo`05001oogooOol00011
Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`0=Ool00`00Oomoo`0bOol001Eoo`03001o
ogoo011oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo00Qoo`03001oogoo019oo`03001o
o`0004=oo`05001oogooOol0000SOol00`00Oomoo`0=Ool00`00Oomoo`0bOol001Eoo`03001oogoo
011oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo00Qoo`03001oogoo019oo`<004=oo`05
001oogooOol0000SOol00`00Oomoo`0=Ool00`00Oomoo`0bOol001Eoo`03001oogoo011oo`03001o
ogoo009oo`03001oogoo01Moo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo049oo`05001o
ogooOol0000SOol00`00Oomoo`0<Ool00`00Oomoo`0cOol001Eoo`80015oo`03001oogoo009oo`03
001oogoo01Moo`03001oogoo00Moo`03001oogoo05Uoo`04001oogoo000UOol00`00Oomoo`0;Ool0
0`00Oomoo`0cOol001Eoo`03001oogoo011oo`03001oogoo009oo`03001oogoo01Moo`03001oogoo
00Moo`03001oogoo05Yoo`03001oo`0002Eoo`03001oogoo00]oo`03001oogoo03=oo`005Goo00<0
07ooOol047oo00<007ooOol00Woo00<007ooOol067oo00<007ooOol01Woo00<007ooOol0FWoo00<0
07oo00009Goo00<007ooOol02goo00<007ooOol0<goo000EOol00`00Oomoo`0@Ool01@00Oomoogoo
00006goo00<007ooOol01Woo00<007ooOol0FWoo0P009Woo00<007ooOol02goo00<007ooOol0<goo
000EOol00`00Oomoo`0@Ool01@00Oomoogoo00006goo00<007ooOol01Woo00<007ooOol0Pgoo00<0
07ooOol02Goo00<007ooOol0=7oo000EOol00`00Oomoo`0AOol01000Oomoo`006goo00<007ooOol0
1Woo00<007ooOol0Pgoo00<007ooOol02Goo00<007ooOol0=7oo000EOol2000BOol01000Oomoo`00
6goo00<007ooOol01Woo00<007ooOol0Pgoo00<007ooOol02Goo00<007ooOol0=7oo000EOol00`00
Oomoo`0AOol01000Oomoo`006goo00<007ooOol01Woo00<007ooOol0Pgoo00<007ooOol02Goo00<0
07ooOol0=7oo000EOol00`00Oomoo`0AOol01000Oomoo`006goo00<007ooOol01Woo00<007ooOol0
Q7oo00<007ooOol027oo00<007ooOol0=7oo000EOol00`00Oomoo`0AOol01000Oomoo`006goo00<0
07ooOol01Goo00<007ooOol0QGoo00<007ooOol01goo00<007ooOol0=Goo000EOol00`00Oomoo`0A
Ool01000Oomoo`0077oo00<007ooOol017oo00<007ooOol0QGoo00<007ooOol01goo00<007ooOol0
=Goo000EOol2000BOol00`00Ool0000MOol00`00Oomoo`04Ool00`00Oomoo`25Ool00`00Oomoo`07
Ool00`00Oomoo`0eOol001Eoo`03001oogoo019oo`8001eoo`03001oogoo00Aoo`03001oogoo08Io
o`03001oogoo00Ioo`03001oogoo03Eoo`005Goo00<007ooOol04Woo0P007Goo00<007ooOol017oo
00<007ooOol0QWoo00<007ooOol01Woo00<007ooOol0=Goo000EOol00`00Oomoo`0aOol00`00Oomo
o`04Ool00`00Oomoo`26Ool00`00Oomoo`05Ool00`00Oomoo`0fOol000Eoo`<0009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo035oo`03001oogoo00Aoo`03001oogoo08Ioo`03001oogoo
00Eoo`03001oogoo03Ioo`001Woo00H007ooOol007oo0002Ool00`00Ool00004Ool00`00Oomoo`0a
Ool00`00Oomoo`04Ool00`00Oomoo`27Ool00`00Oomoo`04Ool00`00Oomoo`0fOol000Aoo`@00004
Ool007oo0002Ool00`00Ool00004Ool2000cOol00`00Oomoo`03Ool00`00Oomoo`27Ool00`00Oomo
o`03Ool00`00Oomoo`0gOol000Aoo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03
001oogoo039oo`03001oogoo009oo`03001oogoo08Qoo`03001oogoo00=oo`03001oogoo03Moo`00
1Goo0P000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol0<Woo00<007ooOol00Woo00<0
07ooOol0RGoo00<007ooOol00Woo00<007ooOol0=goo0006Ool01@00Oomoogoo000017oo00<007oo
Ool00goo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol0RWoo00D007ooOomoo`0003Uoo`00
5Goo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol0RWoo0P0000=oo`00Ool0>Goo000EOol2
000cOol00`00Oomoo`02Ool00`00Oomoo`2;Ool2000kOol001Eoo`03001oogoo039oo`03001oogoo
009oo`03001oogoo0<Qoo`005Goo00<007ooOol0<Woo00<007ooOol00Woo00<007ooOol0b7oo000E
Ool00`00Oomoo`0bOol00`00Oomoo`02Ool00`00Oomoo`38Ool001Eoo`03001oogoo039oo`03001o
ogoo009oo`03001oogoo0<Qoo`005Goo0P00<goo00<007ooOol00Woo00<007ooOol0b7oo000EOol0
0`00Oomoo`0cOol01@00Oomoogoo0000bWoo000EOol00`00Oomoo`0cOol01000Oomoo`00bgoo000E
Ool00`00Oomoo`0cOol01000Oomoo`00bgoo000EOol00`00Oomoo`0cOol01000Oomoo`00bgoo000E
Ool00`00Oomoo`0cOol01000Oomoo`00bgoo000EOol2000eOol2003<Ool001Eoo`03001oogoo03Ao
o`800<aoo`005Goo00<007ooOol0ogoo0goo000EOol00`00Oomoo`3oOol3Ool001Eoo`03001oogoo
0?moo`=oo`005Goo00<007ooOol0ogoo0goo003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {173, 0}} -> {-0.420904, 124.79, 0.0197364, 
  1.83359}}]
}, Open  ]],

Cell[TextData[
"The following input will generate a sequence of 20 graphics which can be \
animated to show the dynamic response of the model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Do[Show[graph /. \((sol /. T \[Rule] i)\)], {i, 0, 5, .25}]\)], "Input",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D", "Input"],
  " Package."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{480, 684},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 113, 3, 105, "Title",
  PageBreakAbove->True],
Cell[1847, 56, 106, 2, 54, "Subtitle"],
Cell[1956, 60, 123, 3, 48, "Subsubtitle",
  PageBreakAbove->False],
Cell[2082, 65, 45834, 1649, 269, 27255, 1415, "GraphicsData", 
"PostScript", "Graphics"],
Cell[47919, 1716, 128, 3, 48, "Subsubtitle",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[48084, 1724, 110, 3, 53, "Section",
  PageBreakAbove->True],
Cell[48197, 1729, 441, 18, 166, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[48675, 1752, 111, 3, 33, "Section",
  PageBreakAbove->True],
Cell[48789, 1757, 1256, 21, 318, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[50082, 1783, 116, 3, 33, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[50223, 1790, 91, 2, 47, "Subsection"],
Cell[50317, 1794, 278, 12, 34, "Text"],
Cell[50598, 1808, 84, 2, 25, "Input"],
Cell[50685, 1812, 200, 4, 52, "Text"],
Cell[50888, 1818, 255, 8, 145, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51180, 1831, 86, 2, 31, "Subsection"],
Cell[51269, 1835, 327, 6, 71, "Text"],
Cell[51599, 1843, 205, 5, 45, "Input"],
Cell[51807, 1850, 82, 2, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51926, 1857, 91, 2, 31, "Subsection"],
Cell[52020, 1861, 653, 13, 148, "Text"],
Cell[52676, 1876, 173, 4, 65, "Input"],
Cell[52852, 1882, 280, 9, 54, "Text"],
Cell[53135, 1893, 177, 4, 65, "Input"],
Cell[53315, 1899, 1252, 36, 171, "Text"],
Cell[54570, 1937, 342, 7, 145, "Input"],
Cell[54915, 1946, 553, 15, 91, "Text"],
Cell[55471, 1963, 159, 3, 45, "Input"],
Cell[55633, 1968, 301, 9, 53, "Text"],
Cell[55937, 1979, 169, 4, 65, "Input"],
Cell[56109, 1985, 87, 2, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[56233, 1992, 85, 2, 31, "Subsection"],
Cell[56321, 1996, 270, 5, 71, "Text"],
Cell[56594, 2003, 94, 2, 25, "Input"],
Cell[56691, 2007, 74, 2, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[56802, 2014, 88, 2, 31, "Subsection"],
Cell[56893, 2018, 173, 4, 52, "Text"],
Cell[57069, 2024, 116, 2, 25, "Input"],
Cell[57188, 2028, 191, 5, 52, "Text"],
Cell[57382, 2035, 101, 2, 25, "Input"],
Cell[57486, 2039, 1124, 26, 208, "Text"],

Cell[CellGroupData[{
Cell[58635, 2069, 99, 2, 25, "Input"],
Cell[58737, 2073, 2203, 38, 257, "Output"]
}, Open  ]],
Cell[60955, 2114, 254, 8, 53, "Text"],

Cell[CellGroupData[{
Cell[61234, 2126, 88, 2, 25, "Input"],
Cell[61325, 2130, 54, 1, 29, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[61440, 2138, 109, 3, 33, "Section",
  PageBreakAbove->True],
Cell[61552, 2143, 152, 4, 33, "Text"],
Cell[61707, 2149, 1146, 20, 345, "Input"],
Cell[62856, 2171, 177, 4, 52, "Text"],
Cell[63036, 2177, 113, 3, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[63186, 2185, 109, 3, 33, "Section",
  PageBreakAbove->True],
Cell[63298, 2190, 481, 16, 74, "Text"],

Cell[CellGroupData[{
Cell[63804, 2210, 113, 2, 25, "Input"],
Cell[63920, 2214, 59, 1, 29, "Output"]
}, Open  ]],
Cell[63994, 2218, 643, 18, 93, "Text"],

Cell[CellGroupData[{
Cell[64662, 2240, 159, 4, 45, "Input"],
Cell[64824, 2246, 70, 1, 29, "Output"]
}, Open  ]],
Cell[64909, 2250, 201, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[65135, 2262, 100, 2, 25, "Input"],
Cell[65238, 2266, 14679, 456, 182, 4868, 329, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[79932, 2725, 117, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[80074, 2731, 113, 2, 25, "Input"],
Cell[80190, 2735, 31694, 850, 182, 8196, 554, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[111899, 3588, 201, 4, 52, "Text"],
Cell[112103, 3594, 142, 4, 25, "Input"],
Cell[112248, 3600, 143, 6, 34, "Text"],
Cell[112394, 3608, 69, 2, 25, "Input"]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

