(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    142425,       5779]*)
(*NotebookOutlinePosition[    171530,       6708]*)
(*  CellTagsIndexPosition[    164204,       6477]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Mech3D", "Subtitle",
  GeneratedCell->True,
  CellTags->"Mech3D"],

Cell[TextData[{
  StyleBox["Absolute", "Input"],
  " is a setting for the ",
  StyleBox["Magnitude", "Input"],
  " option for ",
  StyleBox["Force", "Input"],
  " and ",
  StyleBox["Moment", "Input"],
  ".  ",
  StyleBox["Magnitude->", "Input"],
  StyleBox["Absolute", "Input"],
  " causes the magnitude of the applied load to be equal to the magnitude \
specified in the ",
  StyleBox["Force", "Input"],
  " or ",
  StyleBox["Moment", "Input"],
  " object."
}], "Text",
  GeneratedCell->True,
  CellTags->"Absolute"],

Cell[TextData[{
  StyleBox["Acceleration", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->Acceleration", "Input"],
  " causes such functions to seek a solution for the location, velocity, and \
acceleration of the current mechanism.  ",
  StyleBox["Acceleration[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the global acceleration vector, ",
  Cell[BoxData[
      \(TraditionalForm
      \`{x\&\[DoubleDot], y\&\[DoubleDot], z\&\[DoubleDot]}\)]],
  ", of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Acceleration"],

Cell[TextData[{
  StyleBox["AccelerationTerms[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the part of the right hand-term of the current acceleration \
constraint expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"AccelerationTerms"],

Cell[TextData[{
  StyleBox["AddLoads", "Input"],
  " is an option for ",
  StyleBox["SetLoads", "Input"],
  " that specifies whether the supplied loads are to replace the existing \
load vector or be added to the existing load vector.  The default setting is \
",
  StyleBox["AddLoads->", "Input"],
  StyleBox["False", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"AddLoads"],

Cell[TextData[{
  StyleBox["Alpha[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the angular acceleration of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Alpha", "Input"],
  " accepts the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  CellTags->"Alpha"],

Cell[TextData[{
  StyleBox["Angle", "Input"],
  " is an option for ",
  StyleBox["Mech", "Input"],
  " graphics functions that specifies the range of the revolution angle of \
revolved objects.  ",
  StyleBox["Angle->{", "Input"],
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " revolves the object from a to ",
  StyleBox["b",
    FontSlant->"Italic"],
  " radians.  The default setting is ",
  StyleBox["Angle->{", "Input"],
  "0, ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  StyleBox["}", "Input"],
  "."
}], "Text",
  CellTags->"Angle"],

Cell[TextData[{
  StyleBox["Angular", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SetSymbols", "Input"],
  " that causes all subsequently built models to represent angular velocity \
and acceleration explicitly in their coordinates."
}], "Text",
  GeneratedCell->True,
  CellTags->"Angular"],

Cell[TextData[{
  StyleBox["Applied", "Input"],
  " is the default setting for the ",
  StyleBox["Type", "Input"],
  " option for ",
  StyleBox["Loads", "Input"],
  ".  Specifying ",
  StyleBox["Type->", "Input"],
  StyleBox["Applied", "Input"],
  " causes ",
  StyleBox["Loads", "Input"],
  " to return the total external load applied to a body."
}], "Text",
  GeneratedCell->True,
  CellTags->"Applied"],

Cell[TextData[{
  StyleBox["ArcLength[", "Input"],
  StyleBox["spline",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a one-dimensional cubic  ",
  StyleBox["SplineFunction", "Input"],
  " object approximately representing the arc length of the given spline.  ",
  StyleBox["spline",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["SplineFunction", "Input"],
  " object such as is returned by ",
  StyleBox["SplineFit", "Input"],
  "."
}], "Text",
  CellTags->"ArcLength"],

Cell[TextData[{
  StyleBox["Arrow[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["len",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a graphics object representing an arrow of length ",
  StyleBox["len",
    FontSlant->"Italic"],
  " emanating from the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and pointing in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Reverse->True", "Input"],
  " causes the arrow to terminate at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and point in the opposite direction.  ",
  StyleBox["HeadSize->", "Input"],
  "number specifies the width of the head of the arrow.  ",
  StyleBox["Magnitude->Relative", "Input"],
  " causes the length of the arrow to be equal to ",
  StyleBox["len",
    FontSlant->"Italic"],
  " times the length of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Arrow"],

Cell[TextData[{
  " ",
  StyleBox["Bar[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["facets",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a bar of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " spanning the length of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with the specified number of ",
  StyleBox["facets",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Bar", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " option."
}], "Text",
  CellTags->"Bar"],

Cell[TextData[{
  StyleBox["Body[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is used to define points and properties on a ",
  StyleBox["Mech", "Input"],
  " body.  ",
  StyleBox["Body", "Input"],
  " returns a ",
  StyleBox["SysBody", "Input"],
  " data object containing information to be passed to ",
  StyleBox["SetBodies", "Input"],
  ".  The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " must be a positive integer specifying an index number for the body that \
is used to reference the body in other ",
  StyleBox["Mech", "Input"],
  " functions.  ",
  StyleBox["Body", "Input"],
  " accepts the ",
  StyleBox["PointList", "Input"],
  ", ",
  StyleBox["InitialGuess", "Input"],
  ", ",
  StyleBox["Mass", "Input"],
  ", ",
  StyleBox["Inertia", "Input"],
  ", and ",
  StyleBox["Centroid", "Input"],
  " options.  The default setting for all options is ",
  StyleBox["Automatic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Body"],

Cell[TextData[{
  StyleBox["BodyEnergy[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the kinetic energy possessed by body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"BodyEnergy"],

Cell[TextData[{
  StyleBox["Box[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " generates a box with two opposing corners located at local points ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  The sides of the box are aligned with the local axes of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Box", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"Box"],

Cell[TextData[{
  StyleBox["BuildMech", "Input"],
  " is an option for ",
  StyleBox["SetConstraints", "Input"],
  " that specifies which parts of the mathematical mechanism model will be \
built immediately.  The default setting is ",
  StyleBox["BuildMech->", "Input"],
  StyleBox["Location", "Input"],
  ".  ",
  StyleBox["BuildMech[", "Input"],
  "level",
  StyleBox["]", "Input"],
  " is used to force a build of the mechanism equations to the specified \
level at any time. level can be ",
  StyleBox["None", "Input"],
  ", ",
  StyleBox["Location", "Input"],
  ", ",
  StyleBox["Velocity", "Input"],
  ", ",
  StyleBox["Acceleration", "Input"],
  ", ",
  StyleBox["Static", "Input"],
  ", ",
  StyleBox["Kinematic", "Input"],
  ", or ",
  StyleBox["Dynamic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"BuildMech"],

Cell[TextData[{
  StyleBox["CamPlot[", "Input"],
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["min",
    FontSlant->"Italic"],
  ", ",
  StyleBox["max",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns a ",
  StyleBox["SysPlot", "Input"],
  " object representing the cam profile, a space curve, that is defined by \
the locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["CamPlot[", "Input"],
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["min",
    FontSlant->"Italic"],
  ", ",
  StyleBox["max",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["min",
    FontSlant->"Italic"],
  ", ",
  StyleBox["max",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns a ",
  StyleBox["SysPlot", "Input"],
  " object representing a cam surface profile.  The coordinates of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"CamPlot"],

Cell[TextData[{
  StyleBox["CamToCam1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["gamma",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["delta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " models two cam profiles that work against each other.  The locus of ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " defines the first cam surface as a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " while the locus of ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " defines the second cam surface as a function of the symbols ",
  StyleBox["gamma",
    FontSlant->"Italic"],
  " and ",
  StyleBox["delta",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " & ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " must be defined as parametric functions of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["gamma",
    FontSlant->"Italic"],
  ", & ",
  StyleBox["delta",
    FontSlant->"Italic"],
  ").  ",
  StyleBox["CamToCam1", "Input"],
  " enforces that the surfaces of the two cam profiles lie tangent to each \
other.  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToCam1"],

Cell[TextData[{
  StyleBox["CamToPlane1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a cam surface with a planar follower.  The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ").  ",
  StyleBox["CamToPlane1", "Input"],
  " enforces that the cam surface profile lies tangent to a plane specified \
by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToPlane1"],

Cell[TextData[{
  StyleBox["CamToPoint1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a cam surface with a point follower.  The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ").  ",
  StyleBox["CamToPoint1", "Input"],
  " enforces that ",
  StyleBox["point",
    FontSlant->"Italic"],
  " lies on the surface of the cam profile.  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToPoint1"],

Cell[TextData[{
  StyleBox["CamToSphere1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a cam surface with a spherical follower.  The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ").  ",
  StyleBox["CamToSphere1", "Input"],
  " enforces that the surface of the spatial cam profile lies in tangent \
contact with a sphere of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"CamToSphere1"],

Cell[TextData[{
  StyleBox["Centrifugal[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the vector of centrifugal forces associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Centrifugal"],

Cell[TextData[{
  StyleBox["Centroid", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that specifies the location vector of a body's centroid, in the body's \
local coordinates.  The default setting is ",
  StyleBox["Centroid->", "Input"],
  StyleBox["Automatic", "Input"],
  ".  ",
  StyleBox["Centroid[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a point object corresponding to the centroid of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Centroid"],

Cell[TextData[{
  StyleBox["CheckRules", "Input"],
  " is an option for ",
  StyleBox["SolveMech", "Input"],
  " that determines whether solution rules passed into ",
  StyleBox["SolveMech", "Input"],
  " are assumed to be correct, or are checked against the constraints to see \
if they constitute a valid solution.  The default setting is ",
  StyleBox["CheckRules->", "Input"],
  StyleBox["True", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"CheckRules"],

Cell[TextData[{
  StyleBox["CheckSystem[", "Input"],
  StyleBox["]", "Input"],
  " checks the current model for undefined variables or inconsistent \
constraint sets.  ",
  StyleBox["CheckSystem", "Input"],
  " returns ",
  StyleBox["True", "Input"],
  " if all is well, ",
  StyleBox["False", "Input"],
  " and an error message otherwise."
}], "Text",
  GeneratedCell->True,
  CellTags->"CheckSystem"],

Cell[TextData[{
  StyleBox["ClearMech[", "Input"],
  StyleBox["]", "Input"],
  " clears the entire ",
  StyleBox["Mech", "Input"],
  " database and resets all internal variables to their initial states."
}], "Text",
  GeneratedCell->True,
  CellTags->"ClearMech"],

Cell[TextData[{
  StyleBox["ClearParameters[", "Input"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " deletes the rules from the current parameters list that are associated \
with the ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"ClearParameters"],

Cell[TextData[{
  StyleBox["Closed", "Input"],
  " is a setting for the ",
  StyleBox["EndConditions", "Input"],
  " option for ",
  StyleBox["SplineFit", "Input"],
  " that specifies that the slope and curvature of the spline at the  two \
ends shall be equal."
}], "Text",
  GeneratedCell->True,
  CellTags->"Closed"],

Cell[TextData[{
  StyleBox["CompositeInertia[{", "Input"],
  StyleBox["centroid1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mass1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertia1",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ..., ",
  StyleBox["{", "Input"],
  StyleBox["centroidn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["massn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertian",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns the list ",
  StyleBox["{", "Input"],
  StyleBox["centroid",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mass",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertia",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " of the inertia properties of a composite body  made up of the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " specified subcomponents.  Arguments to ",
  StyleBox["CompositeInertia", "Input"],
  " can have the form ",
  StyleBox["{", "Input"],
  StyleBox["centroidn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["massn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertian",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rotationn",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " to specify subcomponents that are rotated relative to the resulting \
composite body."
}], "Text",
  CellTags->"CompositeInertia"],

Cell[TextData[{
  StyleBox["ConstantVelocity4[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a constant velocity joint.  The origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to be coincident with the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the relative spin of the two axes is constrained to be equal.  The \
relative spin of the axes is determined by the angle between the reference \
directions of each axis, and the cross product of the two axes.  Constrains 4 \
DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"ConstantVelocity4"],

Cell[TextData[{
  StyleBox["Constraint[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["equation",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{{", "Input"],
  StyleBox["extravar",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "..",
  StyleBox["}]", "Input"],
  " returns a constraint object that contains a user-defined constraint \
equation(s).  ",
  StyleBox["equation",
    FontSlant->"Italic"],
  " can be a single equation or a list of equations, each of which must have \
the head ",
  StyleBox["Equal", "Input"],
  ".  The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "'s are an optional list of the body numbers of those bodies that are \
constrained by ",
  StyleBox["equation",
    FontSlant->"Italic"],
  "'s.  ",
  StyleBox["{", "Input"],
  StyleBox["extravar",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " (or ",
  StyleBox["{{", "Input"],
  StyleBox["extravar",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "..",
  StyleBox["}", "Input"],
  " ) is an optional list of symbols that appear in the model (and their \
associated initial guesses), that are added to the model's dependent variable \
list and solved for."
}], "Text",
  CellTags->"Constraint"],

Cell[TextData[{
  StyleBox["ConstraintCorrection", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  ". With ",
  StyleBox["ConstraintCorrection->", "Input"],
  StyleBox["True", "Input"],
  ", each body's location and velocity are corrected at each integration step \
so as to be consistent with the constraints."
}], "Text",
  GeneratedCell->True,
  CellTags->"ConstraintCorrection"],

Cell[TextData[{
  StyleBox["Constraints[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the list of constraint expressions that were generated by \
constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ".  The expressions returned are assumed to be set equal to zero to satisfy \
the constraint."
}], "Text",
  GeneratedCell->True,
  CellTags->"Constraints"],

Cell[TextData[{
  StyleBox["Coordinates", "Input"],
  " is an option for ",
  StyleBox["Reaction", "Input"],
  " that specifies whether the force and moment vectors returned are to be in \
",
  StyleBox["Global", "Input"],
  " or ",
  StyleBox["Local", "Input"],
  " coordinates.  The default setting is ",
  StyleBox["Coordinates->Global", "Input"],
  "."
}], "Text",
  CellTags->"Coordinates"],

Cell[TextData[{
  StyleBox["Corrector", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ". The ",
  StyleBox["Corrector", "Input"],
  " method uses an Adams-Moulton predictor-corrector integration algorithm."
}], "Text",
  GeneratedCell->True,
  CellTags->"Corrector"],

Cell[TextData[{
  StyleBox["CoupleSystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetCouple", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"CoupleSystem"],

Cell[TextData[{
  StyleBox["Cross[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the cross product of the direction vectors of the two ",
  StyleBox["Mech", "Input"],
  " vector objects."
}], "Text",
  GeneratedCell->True,
  CellTags->"Cross"],

Cell[TextData[{
  StyleBox["Cubic", "Input"],
  " is the default setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ".  ",
  StyleBox["Cubic", "Input"],
  " specifies a cubic approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Cubic"],

Cell[TextData[{
  StyleBox["CurveToCam1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["gamma",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["delta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " constrains the space curve defined by ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " to lie tangent to the spatial surface defined by ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  "  (",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " must be defined as parametric functions of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["gamma",
    FontSlant->"Italic"],
  ", & ",
  StyleBox["delta",
    FontSlant->"Italic"],
  ").  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"CurveToCam1"],

Cell[TextData[{
  StyleBox["CurveToCylinder1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the space curve defined by ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " to lie in tangent contact with a cylinder of specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". Constrains 1 DOF."
}], "Text",
  CellTags->"CurveToCylinder1"],

Cell[TextData[{
  StyleBox["CurveToPlane1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the space curve defined by ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " to lie tangent to a plane specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"CurveToPlane1"],

Cell[TextData[{
  StyleBox["CurveToPoint2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the space curve defined by ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". Constrains 2 DOF."
}], "Text",
  CellTags->"CurveToPoint2"],

Cell[TextData[{
  StyleBox["CutOff", "Input"],
  " is an option for ",
  StyleBox["Force", "Input"],
  " and ",
  StyleBox["Moment", "Input"],
  " that specifies a cutoff value for the magnitude of an applied load.  If ",
  
  StyleBox["CutOff", "Input"],
  " is nonzero, The magnitude of the load drops to one half of the specified \
magnitude when the length of the direction vector of the load is equal to ",
  StyleBox["CutOff", "Input"],
  ", and the magnitude of the load drops to zero when the length of the \
direction vector is zero."
}], "Text",
  CellTags->"CutOff"],

Cell[TextData[{
  StyleBox["Cylindrical4[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to be parallel and coincident.  Constrains 4 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Cylindrical4"],

Cell[TextData[{
  StyleBox["CylindricalToXYZ[{", "Input"],
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["angle",
    FontSlant->"Italic"],
  ", ",
  StyleBox["altitude",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " converts the given point from cylindrical to Cartesian coordinates and \
returns ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["CylindricalToXYZ", "Input"],
  " Accepts the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"CylindricalToXYZ"],

Cell[TextData[{
  StyleBox["D2DistanceDT2[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the second time derivative of the absolute distance between the \
two points."
}], "Text",
  GeneratedCell->True,
  CellTags->"D2DistanceDT2"],

Cell[TextData[{
  StyleBox["DDistanceDT[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the time derivative of the absolute distance between the two \
points."
}], "Text",
  GeneratedCell->True,
  CellTags->"DDistanceDT"],

Cell[TextData[{
  StyleBox["Diagnostics", "Input"],
  " is an element of the ",
  StyleBox["MakeRules", "Input"],
  " option setting for ",
  StyleBox["SolveFree", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Diagnostics"],

Cell[TextData[{
  StyleBox["DirectedDistance1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", measured in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"DirectedDistance1"],

Cell[TextData[{
  StyleBox["DirectedPosition3[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus a vector that is parallel to ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units long.  Constrains 3 DOF."
}], "Text",
  CellTags->"DirectedPosition3"],

Cell[TextData[{
  StyleBox["Direction[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the direction vector of a ",
  StyleBox["Mech", "Input"],
  " vector object in global coordinates."
}], "Text",
  CellTags->"Direction"],

Cell[TextData[{
  StyleBox["Distance[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the absolute distance between the two points."
}], "Text",
  GeneratedCell->True,
  CellTags->"Distance"],

Cell[TextData[{
  StyleBox["Dynamic", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->", "Input"],
  StyleBox["Dynamic", "Input"],
  " causes such functions to seek a solution for the location, velocity, \
acceleration, and dynamic loading of the current mechanism.  ",
  StyleBox["Dynamic", "Input"],
  " is also a setting for the ",
  StyleBox["Type", "Input"],
  " option for ",
  StyleBox["Loads", "Input"],
  ".  Specifying ",
  StyleBox["Type->", "Input"],
  StyleBox["Dynamic", "Input"],
  " causes ",
  StyleBox["Loads", "Input"],
  " to return the total inertial load on a body."
}], "Text",
  GeneratedCell->True,
  CellTags->"Dynamic"],

Cell[TextData[{
  StyleBox["Edge[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " generates n-1 lines passing from each local point to the next on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate, ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " or ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["Edge[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts1",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts2",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ...",
  StyleBox["]", "Input"],
  " generates several sequences of lines."
}], "Text",
  GeneratedCell->True,
  CellTags->"Edge"],

Cell[TextData[{
  StyleBox["EndConditions", "Input"],
  " is an option for ",
  StyleBox["SplineFit", "Input"],
  " that is used to specify the end conditions of the spline.  ",
  StyleBox["EndConditions", "Input"],
  " can be either ",
  StyleBox["Natural", "Input"],
  ", ",
  StyleBox["Closed", "Input"],
  ", or a list of two vectors, specifying the tangency direction at the \
beginning and end of the spline, respectively."
}], "Text",
  GeneratedCell->True,
  CellTags->"EndConditions"],

Cell[TextData[{
  StyleBox["Ends", "Input"],
  " is an option for ",
  StyleBox["Bar", "Input"],
  " that specifies whether or not the ends of the bar are to be closed.  The \
default setting is ",
  StyleBox["Ends->", "Input"],
  StyleBox["True", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Ends"],

Cell[TextData[{
  StyleBox["Euler", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SetSymbols", "Input"],
  " that causes all subsequently built models to use Euler parameters and \
their derivatives to represent angular orientation and velocity."
}], "Text",
  CellTags->"Euler"],

Cell[TextData[{
  StyleBox["EulerParameters[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the ",
  "Euler",
  " parameters associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " {",
  StyleBox["eo",
    FontSlant->"Italic"],
  ", e",
  StyleBox["i",
    FontSlant->"Italic"],
  ", e",
  StyleBox["j",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ek",
    FontSlant->"Italic"],
  "}."
}], "Text",
  CellTags->"EulerParameters"],

Cell[TextData[{
  StyleBox["Extrude[{", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ...,",
  StyleBox["pointn",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " extrudes the sequence of n-1 lines between the given points ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Extrude", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " & ",
  StyleBox["Magnitude", "Input"],
  " options."
}], "Text",
  CellTags->"Extrude"],

Cell[TextData[{
  StyleBox["Faces", "Input"],
  " is an option for ",
  StyleBox["Mech", "Input"],
  " graphics functions that specifies whether faces of polygons should be \
drawn.  The default setting is ",
  StyleBox["Faces->", "Input"],
  StyleBox["True", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Faces"],

Cell[TextData[{
  StyleBox["Facet[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " generates a filled polygon with vertices at each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate, ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " or ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ". ",
  StyleBox["Facet[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts1",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnts2",
    FontSlant->"Italic"],
  "..",
  StyleBox["}", "Input"],
  ", ...",
  StyleBox["]", "Input"],
  " generates several polygons."
}], "Text",
  GeneratedCell->True,
  CellTags->"Facet"],

Cell[TextData[{
  StyleBox["FindSwitchTime[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["snum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " seeks the point in time at which the the two constraints in ",
  StyleBox["TimeSwitch", "Input"],
  " number ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " separated by switch time number ",
  StyleBox["snum",
    FontSlant->"Italic"],
  " are both satisfied.  ",
  StyleBox["FindSwitchTime[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["snum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["TangentConstraint->True]", "Input"],
  " finds the switch point when the two constraints in question approach each \
other tangentially.  ",
  StyleBox["FindSwitchTime", "Input"],
  " also accepts the ",
  StyleBox["RequiredEquations", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"FindSwitchTime"],

Cell[TextData[{
  StyleBox["FindTime[", "Input"],
  StyleBox["eqn",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " seeks the solution to the current model that satisfies the given equation \
",
  StyleBox["eqn",
    FontSlant->"Italic"],
  " with time treated as a dependent variable. The equation must have the \
head ",
  StyleBox["Equal", "Input"],
  ".  ",
  StyleBox["FindTime", "Input"],
  " accepts the ",
  StyleBox["Solution", "Input"],
  " option to specify what level of solution is needed."
}], "Text",
  GeneratedCell->True,
  CellTags->"FindTime"],

Cell[TextData[{
  StyleBox["FitDegree", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  " that specifies the degree of polynomial that is used to approximate each \
section of the integrand at each time step.  Valid settings for ",
  StyleBox["FitDegree", "Input"],
  " are ",
  StyleBox["Linear", "Input"],
  ", ",
  StyleBox["Quadratic", "Input"],
  ", ",
  StyleBox["Cubic", "Input"],
  ", and ",
  StyleBox["Quartic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"FitDegree"],

Cell[TextData[{
  StyleBox["Force[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mag",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a ",
  StyleBox["Mech", "Input"],
  " load object that applies a force to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " along the specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Force", "Input"],
  " accepts the ",
  StyleBox["Magnitude", "Input"],
  " and ",
  StyleBox["CutOff", "Input"],
  " options."
}], "Text",
  GeneratedCell->True,
  CellTags->"Force"],

Cell[TextData[{
  StyleBox["Free", "Input"],
  " is a setting for the ",
  StyleBox["Time", "Input"],
  " option for ",
  StyleBox["SetCouple", "Input"],
  " that is used to omit the time specification so that time becomes a \
dependent variable.  If ",
  StyleBox["SetCouple", "Input"],
  " is passed ",
  StyleBox["Time->Free", "Input"],
  " instead of ",
  StyleBox["Time->", "Input"],
  StyleBox["number",
    FontSlant->"Italic"],
  ", time is considered to be a dependent variable to be solved for."
}], "Text",
  GeneratedCell->True,
  CellTags->"Free"],

Cell[TextData[{
  StyleBox["FreeSystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetFree", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"FreeSystem"],

Cell[TextData[{
  StyleBox["FunctionOfTime", "Input"],
  " is an option for several ",
  StyleBox["Mech", "Input"],
  " functions that causes returned ",
  StyleBox["InterpolatingFunction", "Input"],
  " objects to be explicitly functions of the current time variable."
}], "Text",
  GeneratedCell->True,
  CellTags->"FunctionOfTime"],

Cell[TextData[{
  StyleBox["Generalized[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the list of generalized forces, or Lagrange multipliers (Lmb1, ",
  StyleBox["Lmb2", "Input"],
  ", ...) associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " in the current model.  ",
  StyleBox["Generalized", "Input"],
  " is also an element of the ",
  StyleBox["MakeRules", "Input"],
  " option setting.  Specifying ",
  StyleBox["MakeRules->", "Input"],
  StyleBox["{", "Input"],
  "..., ",
  StyleBox["Generalized", "Input"],
  ", ...",
  StyleBox["}", "Input"],
  " causes the generalized forces to be included in the interpolated rules \
returned."
}], "Text",
  GeneratedCell->True,
  CellTags->"Generalized"],

Cell[TextData[{
  StyleBox["Global", "Input"],
  " is a setting for the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"Global"],

Cell[TextData[{
  StyleBox["Gravity[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["G",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a list of ",
  StyleBox["Mech", "Input"],
  " load objects that apply a force of magnitude ",
  StyleBox["mass\[Times]G",
    FontSlant->"Italic"],
  " in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " to the centroid of each body in the current model."
}], "Text",
  CellTags->"Gravity"],

Cell[TextData[{
  StyleBox["GyroFilter[", "Input"],
  StyleBox["{", "Input"],
  "Ixx, Iyy, Izz, Ixy, Iyz, Izx",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " returns a new set of inertia properties that have zero inertia in the \
direction of ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ".  The vector ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " must be a principal axis of the inertia properties, and the two principal \
moments not associated with ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " must be equal."
}], "Text",
  GeneratedCell->True,
  CellTags->"GyroFilter"],

Cell[TextData[{
  StyleBox["GyroMoment[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vec",
    FontSlant->"Italic"],
  ", omega",
  StyleBox["]", "Input"],
  " applies a moment to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " to simulate the gyroscopic effects of the axially symmetric body spinning \
with angular speed omega, about an axis originating from the centroid of the \
body, parallel to ",
  StyleBox["vec",
    FontSlant->"Italic"],
  ".  The constant angular velocity omega is relative to the local reference \
frame of ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["GyroMoment", "Input"],
  " accepts the ",
  StyleBox["Inertia", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"GyroMoment"],

Cell[TextData[{
  StyleBox["HeadSize", "Input"],
  " is an option for ",
  StyleBox["Arrow", "Input"],
  " that specifies the width of the arrowhead."
}], "Text",
  GeneratedCell->True,
  CellTags->"HeadSize"],

Cell[TextData[{
  StyleBox["IMatrix", "Input"],
  " returns the 3D identity matrix."
}], "Text",
  CellTags->"IMatrix"],

Cell[TextData[{
  StyleBox["IncludedAngle[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the positive angle between the global direction vectors of the \
two ",
  StyleBox["Mech", "Input"],
  " vector objects."
}], "Text",
  GeneratedCell->True,
  CellTags->"IncludedAngle"],

Cell[TextData[{
  StyleBox["Inertia", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that specifies the centroidal rotational inertia of a body.  The inertia \
is given as a list of six expressions corresponding to {",
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontSlant->"Italic"],
  "} for the body.  The inertia matrix is then of the form: {{",
  StyleBox["Ixx,Ixy,Izx",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["Ixy,Iyy,Iyz",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["Izx,Iyz,Izz",
    FontSlant->"Italic"],
  "}}.  The default setting is ",
  StyleBox["Inertia", "Input"],
  " ->",
  StyleBox["Automatic", "Input"],
  ".  ",
  StyleBox["Inertia[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the inertia matrix of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Inertia"],

Cell[TextData[{
  StyleBox["InitialCondition", "Input"],
  " is an option for ",
  StyleBox["Mech", "Input"],
  " functions that specifies initial conditions to be used in subsequent \
solutions.  ",
  StyleBox["InitialCondition", "Input"],
  " should specify rules giving the values of current system dependent \
variables, or current parameters, or time.  The default, ",
  StyleBox["InitialCondition->Automatic", "Input"],
  ", takes the initial conditions from the current default initial guess, ",
  StyleBox["LastSolve[]", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"InitialCondition"],

Cell[TextData[{
  StyleBox["InitialGuess", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " and other ",
  StyleBox["Mech", "Input"],
  " functions.  With ",
  StyleBox["Body", "Input"],
  ", ",
  StyleBox["InitialGuess", "Input"],
  " specifies the initial guesses that are used for a body's location \
coordinates.  The default setting is ",
  StyleBox["InitialGuess->Automatic", "Input"],
  ".  Guesses are given as a nested list of numbers of the form ",
  StyleBox["InitialGuess", "Input"],
  " -> ",
  StyleBox["{{", "Input"],
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["Eo",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Ei",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Ej",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Ek",
    FontSlant->"Italic"],
  StyleBox["}}", "Input"],
  "."
}], "Text",
  CellTags->"InitialGuess"],

Cell[TextData[{
  StyleBox["IntersectionPoint[", "Input"],
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the point of intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and a plane that is normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " in global coordinates.  ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is typically a ",
  StyleBox["Plane", "Input"],
  " object."
}], "Text",
  CellTags->"IntersectionPoint"],

Cell[TextData[{
  StyleBox["Jacobian[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the submatrix of the current Jacobian associated with constraint \
",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " and body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Jacobian"],

Cell[TextData[{
  StyleBox["KillMech[]", "Input"],
  " completely removes the ",
  StyleBox["Mech", "Input"],
  " packages from the current Mathematica session.  All of the symbols in the \
Mech3D` contexts are removed, as well as the contexts themselves."
}], "Text",
  CellTags->"KillMech"],

Cell[TextData[{
  StyleBox["Kinematic", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->", "Input"],
  StyleBox["Kinematic", "Input"],
  " causes such functions to seek a solution for the location, velocity, and \
velocity- dependent loading of the current model."
}], "Text",
  GeneratedCell->True,
  CellTags->"Kinematic"],

Cell[TextData[{
  StyleBox["LambdaGuess", "Input"],
  " is an option for ",
  StyleBox["SetLoads", "Input"],
  " that specifies the initial guesses for the Lagrange multipliers.  ",
  StyleBox["LambdaGuess", "Input"],
  " can be set to a number that specifies the same guess for all Lagrange \
multipliers, or a list of numbers that specify guesses for each.  The default \
setting is ",
  StyleBox["LambdaGuess->", "Input"],
  StyleBox["Automatic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"LambdaGuess"],

Cell[TextData[{
  StyleBox["LastSolve[", "Input"],
  StyleBox["]", "Input"],
  " returns the last solution rule returned by ",
  StyleBox["SolveMech", "Input"],
  ".  The values returned by ",
  StyleBox["LastSolve[", "Input"],
  StyleBox["]", "Input"],
  " are used as the initial guesses at the next invocation of ",
  StyleBox["SolveMech", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"LastSolve"],

Cell[TextData[{
  StyleBox["LeadScrew5[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", pitch, ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a lead screw.  The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to be parallel and coincident with ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the axial translation of the two axes is controlled per the pitch \
and relative rotation of the two parts of the screw.  The relative angular \
orientation of the two parts is determined by the angle between the reference \
directions of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 5 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"LeadScrew5"],

Cell[TextData[{
  StyleBox["Line[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is a ",
  StyleBox["Mech", "Input"],
  " data object that specifies two local points on body bnum that define a \
line.  The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be point numbers (positive integers) referencing points that were \
defined with ",
  StyleBox["SetBodies", "Input"],
  " or they can be coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y, z}\)]],
  " of points in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Line[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " uses two ",
  StyleBox["Mech", "Input"],
  " point objects to define the line."
}], "Text",
  CellTags->"Line"],

Cell[TextData[{
  StyleBox["Linear", "Input"],
  " is a setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ". ",
  StyleBox["Linear", "Input"],
  " specifies a linear approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Linear"],

Cell[TextData[{
  StyleBox["LineOnCylinder3[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". Constrains 3 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"LineOnCylinder3"],

Cell[TextData[{
  StyleBox["LineToCircle1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to pass through the perimeter of a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ".  The axis of the circle is specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and the center of the circle lies at the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"LineToCircle1"],

Cell[TextData[{
  StyleBox["LineToLine1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the minimum, (orthogonal), distance between the two axes to be \
equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units.  ",
  StyleBox["LineToLine1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the two axes to intersect. Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"LineToLine1"],

Cell[TextData[{
  StyleBox["LineToPlane2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie parallel to a plane that is normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from the plane in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 2 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"LineToPlane2"],

Cell[TextData[{
  StyleBox["Load[", "Input"],
  StyleBox["sym",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mag",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a ",
  StyleBox["Mech", "Input"],
  " load object that applies a load of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " directly to coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Load"],

Cell[TextData[{
  StyleBox["Loads[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the total external load applied to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["Type->", "Input"],
  StyleBox["Reaction", "Input"],
  " option may be specified to return the total reaction force applied by all \
constraints to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Type->", "Input"],
  StyleBox["Dynamic", "Input"],
  " returns the total inertial load on the body."
}], "Text",
  GeneratedCell->True,
  CellTags->"Loads"],

Cell[TextData[{
  StyleBox["Local", "Input"],
  " is a setting for the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"Local"],

Cell[TextData[{
  StyleBox["LocalAxes[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a graphics object placing local xy or xyz axes of specified ",
  StyleBox["size",
    FontSlant->"Italic"],
  " at the origin of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["LocalAxes[{", "Input"],
  StyleBox["bnum1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " places axes on several bodies.  ",
  StyleBox["LocalAxes[All", "Input"],
  ", ",
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " places axes on all bodies in the current model."
}], "Text",
  GeneratedCell->True,
  CellTags->"LocalAxes"],

Cell[TextData[{
  StyleBox["Location", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->Location", "Input"],
  " causes such functions to seek a solution for the location of the current \
mechanism.  ",
  StyleBox["Location[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the global coordinates, ",
  StyleBox["{", "Input"],
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " or ",
  StyleBox["{", "Input"],
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Location"],

Cell[TextData[{
  StyleBox["LockMech[", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds a solution to the mechanism equations at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and then embeds the numerical values of the dependent variables into the \
mechanism equations so that they cannot be changed until a new system is \
built with ",
  StyleBox["SetConstraints", "Input"],
  ".  ",
  StyleBox["LockMech", "Input"],
  " accepts the ",
  StyleBox["Solution", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"LockMech"],

Cell[TextData[{
  StyleBox["LocusPlot[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{{", "Input"],
  StyleBox["rules1",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["rules2",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ..., ",
  StyleBox["{", "Input"],
  StyleBox["rulesn",
    FontSlant->"Italic"],
  StyleBox["}}]", "Input"],
  " returns a graphics primitive representing the locus of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " as it moves through successive locations specified by the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"LocusPlot"],

Cell[TextData[{
  StyleBox["Magnitude[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the length of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Magnitude", "Input"],
  " is also an option for ",
  StyleBox["Force", "Input"],
  " and ",
  StyleBox["Moment", "Input"],
  ".  Setting ",
  StyleBox["Magnitude->Relative", "Input"],
  " causes the magnitude of the applied load to be equal to the length of the \
load vector times the given magnitude.  The default setting is ",
  StyleBox["Magnitude->Absolute", "Input"],
  "."
}], "Text",
  CellTags->"Magnitude"],

Cell[TextData[{
  StyleBox["MakeRules", "Input"],
  " is an option to several ",
  StyleBox["Mech", "Input"],
  " functions that is used to specify which dependent variables to generate ",
  
  StyleBox["InterpolatingFunction", "Input"],
  "'s for.  The default: ",
  StyleBox["MakeRules->{Parameters, Location, Generalized}", "Input"],
  " will generate rules for the location coordinates, (",
  StyleBox["X2", "Input"],
  ", ",
  StyleBox["Y3", "Input"],
  ", ...), and the generalized forces, (",
  StyleBox["Lmb1", "Input"],
  ", ",
  StyleBox["Lmb2", "Input"],
  ", ...), if they are present, and also any system parameters.  Settings for \
",
  StyleBox["MakeRules", "Input"],
  " may be any subset of: ",
  StyleBox[
  "{Parameters, Location, Velocity, Acceleration, Generalized}", "Input"],
  "."
}], "Text",
  CellTags->"MakeRules"],

Cell[TextData[{
  StyleBox["Mass", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that specifies the mass of a body.  The default setting is ",
  StyleBox["Mass->", "Input"],
  StyleBox["Automatic", "Input"],
  ".  ",
  StyleBox["Mass[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the mass of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Mass"],

Cell[TextData[{
  StyleBox["MassMatrix[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the submatrix of the current system mass matrix associated with \
body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"MassMatrix"],

Cell[TextData[{
  StyleBox["MaxError", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  " that is used to specify the maximum allowable estimated error in any \
dependent variable in a single time step.  The default setting is ",
  StyleBox["MaxError->", "Input"],
  "0.0001."
}], "Text",
  GeneratedCell->True,
  CellTags->"MaxError"],

Cell[TextData[{
  StyleBox["Mech", "Input"],
  " is the symbol name for all Mechanical Systems Pack general messages."
}], "Text",
  GeneratedCell->True,
  CellTags->"Mech"],

Cell[TextData[{
  StyleBox["MechPrimitive", "Input"],
  " is the head of the ",
  StyleBox["Graphics", "Input"],
  " primitive generating functions that are returned by some ",
  StyleBox["Mech", "Input"],
  " graphics functions.  ",
  StyleBox["MechPrimitive", "Input"],
  " functions will evaluate to a list of Mathematica graphics primitives when \
all of the ",
  StyleBox["Mech", "Input"],
  " system symbols on which they depend are replaced by numbers."
}], "Text",
  GeneratedCell->True,
  CellTags->"MechPrimitive"],

Cell[TextData[{
  StyleBox["Moment[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mag",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a load object that applies a moment of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Moment", "Input"],
  " accepts the ",
  StyleBox["Magnitude", "Input"],
  " and ",
  StyleBox["CutOff", "Input"],
  " options."
}], "Text",
  CellTags->"Moment"],

Cell[TextData[{
  StyleBox["Natural", "Input"],
  " is a setting for the ",
  StyleBox["EndConditions", "Input"],
  " option for ",
  StyleBox["SplineFit", "Input"],
  " that specifies that the curvature of the spline shall be zero at the \
ends."
}], "Text",
  GeneratedCell->True,
  CellTags->"Natural"],

Cell[TextData[{
  StyleBox["Omega[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the angular velocity of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Omega"],

Cell[TextData[{
  StyleBox["OriginLock3[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " locks the position of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to that of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".  The local origins of the two bodies are coincident.  If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is located relative to the global origin.  Constrains 3 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"OriginLock3"],

Cell[TextData[{
  StyleBox["Orthogonal1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be orthogonal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Orthogonal1"],

Cell[TextData[{
  StyleBox["OrthogonalGears5[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", teeth1, ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", teeth2, ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a pair of gears on orthogonal axes, such as a bevel gear set.  The \
axes of the two gears, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", are constrained to be orthogonal and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the origins of these two axes are constrained to be \
adjacent.  The rotational positions of the two gears are related as per their \
respective tooth counts, teeth1 & teeth2.  Negating teeth1 or teeth2 reverses \
the relative direction of rotation of the gears.  Constrains 5 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"OrthogonalGears5"],

Cell[TextData[{
  StyleBox["OrthoRevolute4[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and to be orthogonal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Further, the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie directly adjacent to the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 4 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"OrthoRevolute4"],

Cell[TextData[{
  StyleBox["Parallel2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the vectors to be parallel.  Constrains 2 DOF."
}], "Text",
  CellTags->"Parallel2"],

Cell[TextData[{
  StyleBox["ParallelAxis[", "Input"],
  StyleBox["vec",
    FontSlant->"Italic"],
  ", ",
  StyleBox["mass",
    FontSlant->"Italic"],
  ", ",
  StyleBox["inertia",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " uses the parallel axes theorem to transform the inertia properties of a \
body into or out of a centroidal reference frame.  Assuming that the given \
inertia properties are centroidal, ",
  StyleBox["ParallelAxis", "Input"],
  " returns the inertia properties relative to a noncentroidal reference \
frame in which ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " is the vector from the origin of the noncentroidal frame to the centroid \
of the body."
}], "Text",
  GeneratedCell->True,
  CellTags->"ParallelAxis"],

Cell[TextData[{
  StyleBox["ParallelGears4[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a gear set.  ",
  StyleBox["Constraint", "Input"],
  " is identical to ",
  StyleBox["ParallelGears5", "Input"],
  " except that the heads of the two axes are not constrained to be adjacent. \
 Thus, the two gears can slide on their axes, relative to each other.  \
Constrains 4 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"ParallelGears4"],

Cell[TextData[{
  StyleBox["ParallelGears5[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a gear set.  The axes of the two gears, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " are constrained to be parallel and rad1+rad2 units apart, and the heads \
of the two axes are constrained to be adjacent.  The rotational positions of \
the gears are related as per their respective radii. Constrains 5 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"ParallelGears5"],

Cell[TextData[{
  StyleBox["Parameterize[", "Input"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " takes the given symbols (each of which must have a numeric value defined) \
unsets them and puts them in the parameters list with a current value equal \
to their previously defined value."
}], "Text",
  GeneratedCell->True,
  CellTags->"Parameterize"],

Cell[TextData[{
  StyleBox["Parameters[", "Input"],
  StyleBox["]", "Input"],
  " returns the current ",
  StyleBox["Mech", "Input"],
  " parameters list.  ",
  StyleBox["Parameters", "Input"],
  " is also an element of the setting for the ",
  StyleBox["MakeRules", "Input"],
  " option.  ",
  StyleBox["MakeRules->", "Input"],
  StyleBox["{Parameters", "Input"],
  ", ...",
  StyleBox["}", "Input"],
  " causes the current parameters to be included in the returned rules.  ",
  StyleBox["Parameters", "Input"],
  " is also an option for ",
  StyleBox["SplineFit", "Input"],
  " that specifies the value of the spline parameter at each knot point."
}], "Text",
  GeneratedCell->True,
  CellTags->"Parameters"],

Cell[TextData[{
  "ParaRevolute[cnum, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from, and parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Further, the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie directly adjacent to the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 4 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"ParaRevolute4"],

Cell[TextData[{
  StyleBox["PathSystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetPath", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"PathSystem"],

Cell[TextData[{
  StyleBox["Plane[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt3",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is a data object that specifies three local points on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " that define a plane.  The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be point numbers (positive integers) referencing points that were \
defined with ",
  StyleBox["SetBodies", "Input"],
  " or they can be coordinates ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " of points in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Plane[", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point3",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " uses three ",
  StyleBox["Mech", "Input"],
  " point objects to define the plane."
}], "Text",
  CellTags->"Plane"],

Cell[TextData[{
  StyleBox["PlaneToCircle1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains a plane that is normal to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie tangent to a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", centered at the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", with normal vector in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"PlaneToCircle1"],

Cell[TextData[{
  StyleBox["PlaneToPlane3[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and constrains the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 3 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"PlaneToPlane3"],

Cell[TextData[{
  StyleBox["Point[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is a ",
  StyleBox["Mech", "Input"],
  " data object that specifies a point on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a point number (positive integer) referencing a point that was \
defined with ",
  StyleBox["SetBodies", "Input"],
  " or it can be the coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y, z}\)]],
  " of a point in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Point"],

Cell[TextData[{
  StyleBox["PointAtIntersection3[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie at the intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and a plane that is specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 3 DOF."
}], "Text",
  CellTags->"PointAtIntersection3"],

Cell[TextData[{
  StyleBox["PointLabel[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " labels ",
  StyleBox["Point[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  ", just to the right of the local point.  ",
  StyleBox["PointLabel[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["All]", "Input"],
  " labels all of the points on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " that were defined with a body object."
}], "Text",
  GeneratedCell->True,
  CellTags->"PointLabel"],

Cell[TextData[{
  StyleBox["PointList", "Input"],
  " is an option for ",
  StyleBox["Body", "Input"],
  " that is used to specify a list of local point coordinates on a body.  ",
  StyleBox["PointList->{{", "Input"],
  StyleBox["x1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y1",
    FontSlant->"Italic"],
  ", z1",
  StyleBox["}", "Input"],
  ", ..., ",
  StyleBox["{", "Input"],
  StyleBox["xn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["yn",
    FontSlant->"Italic"],
  ", zn",
  StyleBox["}}", "Input"],
  " specifies ",
  StyleBox["n",
    FontSlant->"Italic"],
  " points on the body that are referenced by their point numbers 1 through ",
  
  StyleBox["n",
    FontSlant->"Italic"],
  ".  The specified list replaces any points that are currently defined on \
the body.  ",
  StyleBox["PointList->{}", "Input"],
  " removes all points currently on the body. The default setting ",
  StyleBox["Automatic", "Input"],
  " leaves points that were previously defined unchanged.  ",
  StyleBox["PointList[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the local coordinates of point ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"PointList"],

Cell[TextData[{
  StyleBox["PointOnCircle2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the perimeter of a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " about the specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The center of the circle lies at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  Constrains 2 DOF."
}], "Text",
  CellTags->"PointOnCircle2"],

Cell[TextData[{
  StyleBox["PointOnCone1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a cone of half angle ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ".  The axis of the cone is specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and the vertex of the cone lies at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"PointOnCone1"],

Cell[TextData[{
  StyleBox["PointOnCylinder1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a cylinder of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ".  The axis of the cylinder is specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  CellTags->"PointOnCylinder1"],

Cell[TextData[{
  StyleBox["PointOnLine2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a spatial slider in which ",
  StyleBox["point",
    FontSlant->"Italic"],
  " is constrained to lie on ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  Constrains 2 DOF."
}], "Text",
  CellTags->"PointOnLine2"],

Cell[TextData[{
  StyleBox["PointOnPlane1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie within a plane specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " is typically a ",
  StyleBox["Plane", "Input"],
  " object.  Constrains 1 DOF."
}], "Text",
  CellTags->"PointOnPlane1"],

Cell[TextData[{
  StyleBox["PointOnPlanes2[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the intersection of two planes specified by their axes.  \
Constrains 2 DOF."
}], "Text",
  CellTags->"PointOnPlanes2"],

Cell[TextData[{
  StyleBox["PointOnTorus1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["majrad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["minrad",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a torus of major radius ",
  StyleBox["majrad",
    FontSlant->"Italic"],
  " and minor radius ",
  StyleBox["minrad",
    FontSlant->"Italic"],
  " that has its major axis specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  The center of the torus is at the origin of the axis.  Constrains 1 \
DOF."
}], "Text",
  CellTags->"PointOnTorus1"],

Cell[TextData[{
  StyleBox["PointToLineDistance[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the shortest distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"PointToLineDistance"],

Cell[TextData[{
  StyleBox["PointToLocal[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the local coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " in the coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"PointToLocal"],

Cell[TextData[{
  StyleBox["PointToPlaneDistance[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the shortest distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to a plane.  The plane's normal is specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"PointToPlaneDistance"],

Cell[TextData[{
  StyleBox["Predictor", "Input"],
  " is a setting for the ",
  StyleBox["Method", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ". The ",
  StyleBox["Predictor", "Input"],
  " method uses an Adams-Bashforth predictor integration algorithm."
}], "Text",
  GeneratedCell->True,
  CellTags->"Predictor"],

Cell[TextData[{
  StyleBox["PrincipalAxes[{", "Input"],
  "Ixx, Iyy, Izz, Ixy, Iyz, Izx",
  StyleBox["}]", "Input"],
  " returns the list ",
  StyleBox["{{", "Input"],
  "I1, I2, I3",
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis3",
    FontSlant->"Italic"],
  StyleBox["}}", "Input"],
  ", where I1-I3 are the principal moments of inertia and ",
  StyleBox["axis1-axis3",
    FontSlant->"Italic"],
  " are the corresponding principal axes of the body represented by the given \
inertia properties."
}], "Text",
  GeneratedCell->True,
  CellTags->"PrincipalAxes"],

Cell[TextData[{
  StyleBox["ProjectedAngle[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the counterclockwise angle measured from the direction of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " to the direction of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", as projected on a plane that is orthogonal to ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"ProjectedAngle"],

Cell[TextData[{
  StyleBox["ProjectedAngle1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the angle of the projection of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", relative to the projection of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", to be equal to ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ", when the two vectors are projected onto a plane that is normal to ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  ".  The sense of the angle is determined by the right-hand rule, relative \
to ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"ProjectedAngle1"],

Cell[TextData[{
  StyleBox["ProjectOnLine[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " projects ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " onto ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " and returns the vector component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is in the direction of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["ProjectOnLine[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " orthogonally projected onto ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"ProjectOnLine"],

Cell[TextData[{
  StyleBox["ProjectOnPlane[", "Input"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " projects ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " onto a plane that is normal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " and returns the vector component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is orthogonal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["ProjectOnPlane[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " orthogonally projected onto a plane that is normal to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"ProjectOnPlane"],

Cell[TextData[{
  StyleBox["Quadratic", "Input"],
  " is a setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ".  ",
  StyleBox["Quadratic", "Input"],
  " specifies a quadratic approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Quadratic"],

Cell[TextData[{
  StyleBox["Quartic", "Input"],
  " is a setting for the ",
  StyleBox["FitDegree", "Input"],
  " option for ",
  StyleBox["SolveFree", "Input"],
  ".  ",
  StyleBox["Quartic", "Input"],
  " specifies a quartic approximation of each section of the integrand."
}], "Text",
  GeneratedCell->True,
  CellTags->"Quartic"],

Cell[TextData[{
  StyleBox["RackAndPinion4[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is identical to ",
  StyleBox["RackAndPinion5", "Input"],
  " except that the heads of the two axes are not constrained to be adjacent. \
 Thus, the pinion is free to slide on its axis, relative to the rack.  \
Constrains 4 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RackAndPinion4"],

Cell[TextData[{
  StyleBox["RackAndPinion5[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a rack and pinion gear set.  ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " represents the rotational axis of the pinion, and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " represents the rack.  ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is parallel to the cut of the teeth of the rack, and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and its reference direction lie in the plane of the rack.  ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units away from, and parallel to, ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the origins of the two axes are constrained to be adjacent.  The \
rotational orientation of the pinion is related to that of the rack as per \
the pinion radius.  The symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " is used as the pinion rotation variable.  Constrains 5 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RackAndPinion5"],

Cell[TextData[{
  StyleBox["Reaction[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the reaction loads applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", calculated about ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Loads", "Input"],
  " are returned in the format: ",
  StyleBox["{", "Input"],
  "force, moment",
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["Reaction", "Input"],
  " accepts the option ",
  StyleBox["Coordinates->Local", "Input"],
  " to return the load vectors in local coordinates, relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Reaction", "Input"],
  " is also a setting for the ",
  StyleBox["Type", "Input"],
  " option for ",
  StyleBox["Loads", "Input"],
  "."
}], "Text",
  CellTags->"Reaction"],

Cell[TextData[{
  StyleBox["ReferenceDirection[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the reference direction associated with ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  This is a vector that is not parallel to the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"ReferenceDirection"],

Cell[TextData[{
  StyleBox["Relative", "Input"],
  " is a setting for the ",
  StyleBox["Magnitude", "Input"],
  " option for ",
  StyleBox["Force", "Input"],
  " and ",
  StyleBox["Moment", "Input"],
  ".  ",
  StyleBox["Magnitude->", "Input"],
  StyleBox["Relative", "Input"],
  " causes the magnitude of the applied load to be equal to the specified \
magnitude times the length of the vector used to specify the direction of the \
load."
}], "Text",
  GeneratedCell->True,
  CellTags->"Relative"],

Cell[TextData[{
  StyleBox["RelativeAngle1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " , ",
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the angle between ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeAngle1"],

Cell[TextData[{
  StyleBox["RelativeDistance1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a connecting link.  The absolute distance from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is constrained to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeDistance1"],

Cell[TextData[{
  StyleBox["RelativeVelocity[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the velocity of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", in global coordinates."
}], "Text",
  CellTags->"RelativeVelocity"],

Cell[TextData[{
  StyleBox["RelativeX1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeX1"],

Cell[TextData[{
  StyleBox["RelativeY1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeY1"],

Cell[TextData[{
  StyleBox["RelativeZ1[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  Constrains 1 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RelativeZ1"],

Cell[TextData[{
  StyleBox["RequiredEquations", "Input"],
  " is an option for ",
  StyleBox["FindSwitchTime", "Input"],
  " that specifies which equations, of a constraint that restrains more than \
one DOF, are to be retained in seeking the switch time.  ",
  StyleBox["RequiredEquations", "Input"],
  " should be a two element list; the first element applies to the first set \
of equations of the ",
  StyleBox["TimeSwitch", "Input"],
  " pair,  the second element applies to the second set.  Allowable values \
for each element are: an integer or list of integers, 1 through the number of \
DOF's in the constraint, ",
  StyleBox["All", "Input"],
  ", or ",
  StyleBox["Sum", "Input"],
  ".  The default setting is ",
  StyleBox["RequiredEquations->", "Input"],
  StyleBox["{All", "Input"],
  ", ",
  StyleBox["Sum}", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"RequiredEquations"],

Cell[TextData[{
  StyleBox["Revolute5[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and constrains the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be coincident with the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  Constrains 5 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Revolute5"],

Cell[TextData[{
  StyleBox["Revolve[{", "Input"],
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["pointn",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["facets",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " revolves the sequence of n-1 lines between the specified ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  " about ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", using ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " segments.  ",
  StyleBox["Revolve", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " & ",
  StyleBox["Angle", "Input"],
  " options."
}], "Text",
  CellTags->"Revolve"],

Cell[TextData[{
  StyleBox["Rotation[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the list ",
  StyleBox["{", "Input"],
  StyleBox["ang",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " specifying the angle and axis of rotation associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Rotation"],

Cell[TextData[{
  StyleBox["RotationLock3[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " locks the angular orientation of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to that of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".  The angular orientation of ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is identical to that of ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".  If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is oriented relative to the global coordinate system.  Constrains 3 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"RotationLock3"],

Cell[TextData[{
  StyleBox["RotationMatrix[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the rotation matrix associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"RotationMatrix"],

Cell[TextData[{
  StyleBox["SaveMech[", "Input"],
  "\"file\"",
  StyleBox["]", "Input"],
  " saves the entire state of the current ",
  StyleBox["Mech", "Input"],
  " system in file such that it can be restored with ",
  StyleBox["Get[", "Input"],
  "\"file\"",
  StyleBox["]", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SaveMech"],

Cell[TextData[{
  StyleBox["SensitivitySystem", "Input"],
  " is the head of the data object returned by ",
  StyleBox["SetSensitivity", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SensitivitySystem"],

Cell[TextData[{
  StyleBox["SetBodies[", "Input"],
  StyleBox["bodies",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " incorporates the local coordinates, initial guesses, and inertia \
properties provided by the ",
  StyleBox["bodies",
    FontSlant->"Italic"],
  " into the current mechanism model.  ",
  StyleBox["bodies",
    FontSlant->"Italic"],
  " must be a list or sequence of ",
  StyleBox["SysBody", "Input"],
  " data objects that are built by the ",
  StyleBox["Body", "Input"],
  " function."
}], "Text",
  CellTags->"SetBodies"],

Cell[TextData[{
  StyleBox["SetConstraints[", "Input"],
  StyleBox["constraints",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the mathematical mechanism model represented by the constraints.  \
The constraints must be a list or sequence of ",
  StyleBox["SysCon", "Input"],
  " data objects that are returned by any of the standard ",
  StyleBox["Mech", "Input"],
  " constraint functions.  The ",
  StyleBox["SetGuess", "Input"],
  " option is used to specify that the initial guesses shall be reset to the \
defaults, regardless of whether or not they must be.  The ",
  StyleBox["BuildMech", "Input"],
  " option determines which system equations are built immediately."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetConstraints"],

Cell[TextData[{
  StyleBox["SetCouple[", "Input"],
  StyleBox["sym",
    FontSlant->"Italic"],
  ", ",
  StyleBox["eq",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Time->", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds a ",
  StyleBox["CoupleSystem", "Input"],
  " in which the value of the symbol ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " is sought that satisfies the equation ",
  StyleBox["eq",
    FontSlant->"Italic"],
  " at time = ",
  StyleBox["t",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetCouple"],

Cell[TextData[{
  StyleBox["SetFree[", "Input"],
  StyleBox["dropcon",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the mathematical equations required to find equilibrium conditions \
of the current model.  The ",
  StyleBox["dropcon",
    FontSlant->"Italic"],
  " argument is used to specify the constraint number(s) that are dropped to \
make the system underconstrained.  The ",
  StyleBox["Solution", "Input"],
  " option specifies whether to seek ",
  StyleBox["Static", "Input"],
  ", ",
  StyleBox["Kinematic", "Input"],
  ", or ",
  StyleBox["Dynamic", "Input"],
  " equilibrium."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetFree"],

Cell[TextData[{
  StyleBox["SetGuess[", "Input"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " sets the current values of the system initial guesses.  Guesses are given \
as a sequence or list of rules, specifying the new values of the variables \
that are to have their current guesses changed.  ",
  StyleBox["SetGuess[]", "Input"],
  " restores all of the initial guesses to their default values as specified \
with ",
  StyleBox["SetBodies", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetGuess"],

Cell[TextData[{
  StyleBox["SetLoads[", "Input"],
  StyleBox["loads",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " prepares the applied load vector and incorporates the given loads into \
the current model.  Each load must have the head ",
  StyleBox["SysLoad", "Input"],
  ".  ",
  StyleBox["SysLoad", "Input"],
  " objects are returned by all of the ",
  StyleBox["Mech", "Input"],
  " forcing functions.  The ",
  StyleBox["AddLoads", "Input"],
  " option is used to specify whether the loads are to be added to or replace \
the current load vector.  The ",
  StyleBox["LambdaGuess", "Input"],
  " option specifies the default initial guess for the Lagrange multipliers."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetLoads"],

Cell[TextData[{
  StyleBox["SetParameters[", "Input"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " adds a sequence or list of rules to the current parameters list and \
returns the entire ",
  StyleBox["Parameters", "Input"],
  " list.  Each of the ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " must be of the form ",
  StyleBox["Symbol->", "Input"],
  StyleBox["number",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetParameters"],

Cell[TextData[{
  StyleBox["SetPath[", "Input"],
  StyleBox["constraints",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the differential equations necessary to find the time domain \
motion of a fully constrained nonholonomic system.  ",
  StyleBox["Kinematic", "Input"],
  " constraints in the current model are replaced with the given velocity \
dependent ",
  StyleBox["constraints",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SetPath", "Input"],
  " accepts the ",
  StyleBox["InitialCondition", "Input"],
  " option to specify the initial location of each body in the model.  ",
  StyleBox["SetPath", "Input"],
  " returns a ",
  StyleBox["PathSystem", "Input"],
  " object that is solved with ",
  StyleBox["SolvePath", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SetPath"],

Cell[TextData[{
  StyleBox["SetSensitivity[", "Input"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " builds the equations necessary to find the sensitivity of the current \
model to changes in the values of ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SetSensitivity", "Input"],
  " returns a ",
  StyleBox["SensitivitySystem", "Input"],
  " object that is solved with ",
  StyleBox["SolveSensitivity", "Input"],
  "."
}], "Text",
  CellTags->"SetSensitivity"],

Cell[TextData[{
  StyleBox["SetSymbols[", "Input"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is used with the ",
  StyleBox["SymbolBasis", "Input"],
  " option to specify the basis for the symbols that ",
  StyleBox["Mech", "Input"],
  " creates.  The ",
  StyleBox["Method", "Input"],
  " option is used to specify whether angular or Euler coordinates are used \
to represent the angular orientation and velocity of a mechanism body.  \
Settings for ",
  StyleBox["Method", "Input"],
  " are ",
  StyleBox["Angular", "Input"],
  " and ",
  StyleBox["Euler", "Input"],
  "."
}], "Text",
  CellTags->"SetSymbols"],

Cell[TextData[{
  StyleBox["SkewSym[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the skew-symmetric matrix associated with ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ": ",
  StyleBox["SkewSym[{", "Input"],
  StyleBox["a1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["a2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["a3",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns ",
  StyleBox["{{", "Input"],
  "0, -",
  StyleBox["a3",
    FontSlant->"Italic"],
  ", ",
  StyleBox["a2",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["a3",
    FontSlant->"Italic"],
  ", 0, -",
  StyleBox["a1",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["{", "Input"],
  "-",
  StyleBox["a2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["a1",
    FontSlant->"Italic"],
  ", 0",
  StyleBox["}}", "Input"]
}], "Text",
  CellTags->"SkewSym"],

Cell[TextData[{
  StyleBox["Solution", "Input"],
  " is an option for certain ",
  StyleBox["Mech", "Input"],
  " functions that specifies the level of solution sought.  Valid settings \
for ",
  StyleBox["Solution", "Input"],
  " are ",
  StyleBox["Location", "Input"],
  ", ",
  StyleBox["Velocity", "Input"],
  ", ",
  StyleBox["Acceleration", "Input"],
  ", ",
  StyleBox["Static", "Input"],
  ", ",
  StyleBox["Kinematic", "Input"],
  ", and ",
  StyleBox["Dynamic", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Solution"],

Cell[TextData[{
  StyleBox["SolveCouple[", "Input"],
  StyleBox["cpsys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " solves the coupled system built by ",
  StyleBox["SetCouple", "Input"],
  ".  The ",
  StyleBox["cpsys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["CoupleSystem", "Input"],
  ".  ",
  StyleBox["SolveCouple", "Input"],
  " returns a list of rules representing the solution to the ",
  StyleBox["CoupleSystem", "Input"],
  " object."
}], "Text",
  GeneratedCell->True,
  CellTags->"SolveCouple"],

Cell[TextData[{
  StyleBox["SolveFree[", "Input"],
  StyleBox["freesys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds the solution to a free system built by ",
  StyleBox["SetFree", "Input"],
  ".  The specified object ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["FreeSystem", "Input"],
  ".  ",
  StyleBox["SolveFree", "Input"],
  " returns a list of rules representing the solution to the ",
  StyleBox["FreeSystem", "Input"],
  " object.  ",
  StyleBox["SolveFree[", "Input"],
  StyleBox["freesys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " integrates the equations of motion in the ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " and returns the time domain free response."
}], "Text",
  GeneratedCell->True,
  CellTags->"SolveFree"],

Cell[TextData[{
  StyleBox["SolveMech[", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " attempts to find a location solution to the current model at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SolveMech", "Input"],
  " returns a list of rules containing the global coordinates of each body.  \
",
  StyleBox["SolveMech[{", "Input"],
  StyleBox["t1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["t2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["tn",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " returns a nested list of solution rules containing solution points at all \
of the ",
  StyleBox["ti",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["SolveMech", "Input"],
  " accepts the ",
  StyleBox["Solution", "Input"],
  " option to determine what order of solution to seek.  ",
  StyleBox["Interpolation->True", "Input"],
  " causes ",
  StyleBox["SolveMech", "Input"],
  " to interpolate the solution rules returned."
}], "Text",
  CellTags->"SolveMech"],

Cell[TextData[{
  StyleBox["SolvePath[", "Input"],
  StyleBox["pathsys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds the solution to the nonholonomic system built by ",
  StyleBox["SetPath", "Input"],
  ".  The ",
  StyleBox["pathsys",
    FontSlant->"Italic"],
  " object must have the head ",
  StyleBox["PathSystem", "Input"],
  ".  ",
  StyleBox["SolvePath", "Input"],
  " integrates the equations of motion from the initial time to ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"SolvePath"],

Cell[TextData[{
  StyleBox["SolveSensitivity[", "Input"],
  StyleBox["senssys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " finds the solution to the sensitivity system built by ",
  StyleBox["SetSensitivity", "Input"],
  ".  The ",
  StyleBox["senssys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["SensitivitySystem", "Input"],
  ".  ",
  StyleBox["SolveSensitivity", "Input"],
  " returns a list of rules representing the solution to the ",
  StyleBox["SensitivitySystem", "Input"],
  " object."
}], "Text",
  GeneratedCell->True,
  CellTags->"SolveSensitivity"],

Cell[TextData[{
  StyleBox["Sphere[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["facets",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a sphere of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", centered at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " divisions along either circumference.  The axis of revolution of the \
sphere points in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Sphere", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " & ",
  StyleBox["Angle", "Input"],
  " options."
}], "Text",
  CellTags->"Sphere"],

Cell[TextData[{
  StyleBox["Spherical3[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["point2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be coincident with ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  Constrains 3 DOF."
}], "Text",
  CellTags->"Spherical3"],

Cell[TextData[{
  StyleBox["SphericalToXYZ[{", "Input"],
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["baseangle",
    FontSlant->"Italic"],
  ", ",
  StyleBox["altitudeangle",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " converts the given point from spherical to Cartesian coordinates and \
returns ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["SphericalToXYZ", "Input"],
  " Accepts the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  GeneratedCell->True,
  CellTags->"SphericalToXYZ"],

Cell[TextData[{
  StyleBox["SplineFit[", "Input"],
  StyleBox["data",
    FontSlant->"Italic"],
  ", ",
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a ",
  StyleBox["SplineFunction", "Input"],
  " object representing the data as a cubic spline."
}], "Text",
  GeneratedCell->True,
  CellTags->"SplineFit"],

Cell[TextData[{
  StyleBox["SplineFunction[", "Input"],
  StyleBox["range",
    FontSlant->"Italic"],
  ", ",
  StyleBox["intdata",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " represents a spline created by ",
  StyleBox["SplineFit", "Input"],
  ". The ",
  StyleBox["SplineFunction", "Input"],
  " accepts an argument within ",
  StyleBox["range",
    FontSlant->"Italic"],
  " for evaluation at some point along the spline."
}], "Text",
  CellTags->"SplineFunction"],

Cell[TextData[{
  StyleBox["StageSwitch[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["test1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["const1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["test2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["const2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["]", "Input"],
  " can be used in place of a single constraint supplied to ",
  StyleBox["SetConstraints", "Input"],
  ".  ",
  StyleBox["StageSwitch", "Input"],
  " evaluates each of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " in turn, and applies the consti corresponding to the first ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " that returns ",
  StyleBox["True", "Input"],
  ".  ",
  StyleBox["StageSwitch[", "Input"],
  StyleBox["test1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["load1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["test2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["load2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["]", "Input"],
  " can be used in place of a load supplied to ",
  StyleBox["SetLoads", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"StageSwitch"],

Cell[TextData[{
  StyleBox["Static", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->", "Input"],
  StyleBox["Static", "Input"],
  " causes such functions to seek a solution for the location and static \
loading of the current mechanism."
}], "Text",
  GeneratedCell->True,
  CellTags->"Static"],

Cell[TextData[{
  StyleBox["Step[", "Input"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " represents a step function.  ",
  StyleBox["Step[", "Input"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns 1 if ",
  StyleBox["num",
    FontSlant->"Italic"],
  " >= 0 and returns 0 if ",
  StyleBox["num",
    FontSlant->"Italic"],
  " < 0, otherwise ",
  StyleBox["Step[", "Input"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is returned unevaluated.  All derivatives of ",
  StyleBox["Step", "Input"],
  " are equal to zero."
}], "Text",
  CellTags->"Step"],

Cell[TextData[{
  StyleBox["StepMech[", "Input"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " steps the constraint equations through one iteration of the \
Newton-Rhapson solution block with time set to ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", regardless of any convergence criteria."
}], "Text",
  GeneratedCell->True,
  CellTags->"StepMech"],

Cell[TextData[{
  StyleBox["StepSize", "Input"],
  " is an option for ",
  StyleBox["SolveFree", "Input"],
  " that sets the constant time step size used by the numerical integration \
algorithm."
}], "Text",
  GeneratedCell->True,
  CellTags->"StepSize"],

Cell[TextData[{
  StyleBox["SymbolBasis", "Input"],
  " is an option for ",
  StyleBox["SetSymbols", "Input"],
  ".  ",
  StyleBox["SymbolBasis", "Input"],
  " is given as a nested list of strings that specifies the basis for the \
symbol names that will be hard coded into the model."
}], "Text",
  GeneratedCell->True,
  CellTags->"SymbolBasis"],

Cell[TextData[{
  StyleBox["SysBody", "Input"],
  " is the head of a system body object returned by the ",
  StyleBox["Body", "Input"],
  " function."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysBody"],

Cell[TextData[{
  StyleBox["SysCon", "Input"],
  " is the head of a system constraint object returned by all ",
  StyleBox["Mech", "Input"],
  " constraint functions."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysCon"],

Cell[TextData[{
  StyleBox["SysLoad", "Input"],
  " is the head of a system load object returned by all ",
  StyleBox["Mech", "Input"],
  " load functions."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysLoad"],

Cell[TextData[{
  StyleBox["SysPlot", "Input"],
  " is used by ",
  StyleBox["CamPlot", "Input"],
  " to carry a plot object that  evaluates to a ",
  StyleBox["Graphics", "Input"],
  " object when numerical values are available for the coordinates of the cam \
body."
}], "Text",
  GeneratedCell->True,
  CellTags->"SysPlot"],

Cell[TextData[{
  StyleBox["TangentConstraint", "Input"],
  " is an option for ",
  StyleBox["FindSwitchTime", "Input"],
  " that specifies whether or not the constraint pair in question comes into \
conjunction tangentially.  The default setting is ",
  StyleBox["TangentConstraint->", "Input"],
  StyleBox["False", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"TangentConstraint"],

Cell[TextData[{
  StyleBox["Time", "Input"],
  " is an option for ",
  StyleBox["SetCouple", "Input"],
  " that is used to specify the value of time.  ",
  StyleBox["Time->", "Input"],
  StyleBox["Free", "Input"],
  " specifies that time is a dependent variable.  The default setting is ",
  StyleBox["Time->", "Input"],
  StyleBox["None", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Time"],

Cell[TextData[{
  StyleBox["TimeInterpolate[", "Input"],
  StyleBox["expr",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["rules1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rules2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " returns an ",
  StyleBox["InterpolatingFunction", "Input"],
  " object representing ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " as a function of time.  Each of the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  " must be a list of rules containing numerical replacements for all of the \
subexpressions in ",
  StyleBox["expr",
    FontSlant->"Italic"],
  ", as well as a rule for the value of time, ",
  StyleBox["T", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"TimeInterpolate"],

Cell[TextData[{
  StyleBox["TimeSwitch[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["con0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["time1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["con1",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["timen",
    FontSlant->"Italic"],
  ", ",
  StyleBox["conn",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " can be used in place of a single constraint supplied to ",
  StyleBox["SetConstraints", "Input"],
  ".  ",
  StyleBox["TimeSwitch", "Input"],
  " applies ",
  StyleBox["coni",
    FontSlant->"Italic"],
  " if ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " < ",
  StyleBox["T", "Input"],
  " < time(i+1).  The first and last constraints are applied when ",
  StyleBox["T", "Input"],
  " < ",
  StyleBox["time1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["T", "Input"],
  " > ",
  StyleBox["timen",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["TimeSwitch[", "Input"],
  StyleBox["load0",
    FontSlant->"Italic"],
  ", ",
  StyleBox["time1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["load1",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["timen",
    FontSlant->"Italic"],
  ", ",
  StyleBox["loadn",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " can be used in place of a single forcing function supplied to ",
  StyleBox["SetLoads", "Input"],
  ".  ",
  StyleBox["TimeSwitch", "Input"],
  " applies loadi if ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " < ",
  StyleBox["T", "Input"],
  " < time(i+1).  The first and last loadi are applied when ",
  StyleBox["T", "Input"],
  " < ",
  StyleBox["time1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["T", "Input"],
  " > ",
  StyleBox["timen",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"TimeSwitch"],

Cell[TextData[{
  StyleBox["Torus[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["majrad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["minrad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["facets",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a torus of specified major and minor radii, centered at the \
origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with its major axis in the direction of ",
  StyleBox["axis.",
    FontSlant->"Italic"],
  "  The torus will have ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " segments around its major and minor circumference.  ",
  StyleBox["Torus", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " & ",
  StyleBox["Angle", "Input"],
  " options."
}], "Text",
  CellTags->"Torus"],

Cell[TextData[{
  StyleBox["Translate5[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " constrains the two axes to be parallel and coincident, and constrains the \
projections of the reference directions of the two axes to be parallel.  \
Constrains 5 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"Translate5"],

Cell[TextData[{
  StyleBox["TwoPulleys4[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is identical to ",
  StyleBox["TwoPulleys5", "Input"],
  " except that the heads of the two axes are not constrained to be adjacent. \
 Thus, the two pulleys are free to slide on their axes, relative to each \
other.  Constrains 4 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"TwoPulleys4"],

Cell[TextData[{
  StyleBox["TwoPulleys5[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ", ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " models a pair of pulleys and a belt.  The axes of the two pulleys, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", are constrained to be parallel and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the origins of these two axes are constrained to be \
adjacent.  The rotational positions of the two pulleys are related as per \
their respective radii.  Constrains 5 DOF."
}], "Text",
  GeneratedCell->True,
  CellTags->"TwoPulleys5"],

Cell[TextData[{
  StyleBox["Type", "Input"],
  " is an option for ",
  StyleBox["Loads", "Input"],
  " that specifies whether ",
  StyleBox["Applied", "Input"],
  ", ",
  StyleBox["Reaction", "Input"],
  ", or ",
  StyleBox["Dynamic", "Input"],
  " loads are returned.  The default setting is ",
  StyleBox["Type->", "Input"],
  StyleBox["Applied", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Type"],

Cell[TextData[{
  StyleBox["Unit[", "Input"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns a unit vector pointed in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Unit"],

Cell[TextData[{
  StyleBox["Vector[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " is a ",
  StyleBox["Mech", "Input"],
  " data object that represents a vector in the local coordinate system of \
body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a vector, ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " or ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ", in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", or it can be a point number (positive integer) referencing a coordinate \
that was defined with ",
  StyleBox["SetBodies", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Vector"],

Cell[TextData[{
  StyleBox["Velocity", "Input"],
  " is a setting for the ",
  StyleBox["Solution", "Input"],
  " option for certain ",
  StyleBox["Mech", "Input"],
  " functions.  Setting ",
  StyleBox["Solution->Velocity", "Input"],
  " causes such functions to seek a solution for the location and velocity of \
the current mechanism.  ",
  StyleBox["Velocity[", "Input"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the global velocity vector, ",
  Cell[BoxData[
      \(TraditionalForm\`{x\&., y\&.}\)]],
  ", of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Velocity"],

Cell[TextData[{
  StyleBox["VelocityTerms[", "Input"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " returns the part of the right-hand term of the current velocity \
constraint expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"VelocityTerms"],

Cell[TextData[{
  StyleBox["Vertex[", "Input"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{", "Input"],
  StyleBox["pnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", ..., ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  StyleBox["]", "Input"],
  " generates point graphics primitives at each of the ",
  StyleBox["pntn",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate, ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  " or ",
  StyleBox["{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  "."
}], "Text",
  GeneratedCell->True,
  CellTags->"Vertex"],

Cell[TextData[{
  StyleBox["Virtual", "Input"],
  " is an option for ",
  StyleBox["SetConstraints", "Input"],
  " that causes a ",
  StyleBox["Jacobian", "Input"],
  " matrix based on virtual displacements to be generated, rather than a ",
  StyleBox["Jacobian", "Input"],
  " based on an Euler transformation.  The default setting is ",
  StyleBox["Virtual->True", "Input"],
  "."
}], "Text",
  CellTags->"Virtual"],

Cell[TextData[{
  " ",
  StyleBox["Wheel[", "Input"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", ",
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox["]", "Input"],
  " generates a circular disk with n facets.  The axis of the disk is defined \
by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  ",
  StyleBox["Wheel", "Input"],
  " accepts the ",
  StyleBox["Faces", "Input"],
  " and ",
  StyleBox["Angle", "Input"],
  " options."
}], "Text",
  CellTags->"Wheel"],

Cell[TextData[{
  StyleBox["XYZ", "Input"],
  " is a setting for the ",
  StyleBox["Coordinates", "Input"],
  " option that is used with coordinate conversion functions to specify the \
right handed ",
  StyleBox["x-y-z",
    FontSlant->"Italic"],
  " coordinate system."
}], "Text",
  CellTags->"XYZ"],

Cell[TextData[{
  StyleBox["XYZToCylindrical[{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " converts the given point from Cartesian to cylindrical coordinates and \
returns ",
  StyleBox["{", "Input"],
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["angle",
    FontSlant->"Italic"],
  ", ",
  StyleBox["altitude",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["XYZToCylindrical", "Input"],
  " Accepts the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  CellTags->"XYZToCylindrical"],

Cell[TextData[{
  StyleBox["XYZToSpherical[{", "Input"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}]", "Input"],
  " converts the given point from Cartesian to spherical coordinates and \
returns ",
  StyleBox["{", "Input"],
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["baseangle",
    FontSlant->"Italic"],
  ", ",
  StyleBox["altitudeangle",
    FontSlant->"Italic"],
  StyleBox["}", "Input"],
  ".  ",
  StyleBox["XYZToSpherical", "Input"],
  " Accepts the ",
  StyleBox["Coordinates", "Input"],
  " option."
}], "Text",
  CellTags->"XYZToSpherical"],

Cell[TextData[{
  StyleBox["YZX", "Input"],
  " is a setting for the ",
  StyleBox["Coordinates", "Input"],
  " option that is used with coordinate conversion functions to specify the \
right handed ",
  StyleBox["y-z-x",
    FontSlant->"Italic"],
  " coordinate system."
}], "Text",
  CellTags->"YZX"],

Cell[TextData[{
  StyleBox["ZXY", "Input"],
  " is a setting for the ",
  StyleBox["Coordinates", "Input"],
  " option that is used with coordinate conversion functions to specify the \
right handed ",
  StyleBox["z-x-y",
    FontSlant->"Italic"],
  " coordinate system."
}], "Text",
  CellTags->"ZXY"],

Cell[TextData[{
  StyleBox["$MechPostIterate", "Input"],
  " is a function that is applied to the iteration counter at each iteration \
of ",
  StyleBox["Mech", "Input"],
  "'s iterative solution block."
}], "Text",
  CellTags->"$MechPostIterate"],

Cell[TextData[{
  StyleBox["$MechPreSolve", "Input"],
  " is applied to the numeric value of the time variable before each run of \
the location solution block."
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechPreSolve"],

Cell[TextData[{
  StyleBox["$MechPrimeRules", "Input"],
  " returns a list of replacement rules for all of the current ",
  StyleBox["Mech", "Input"],
  " dependent variables to convert them to explicit functions of time with \
the ",
  StyleBox["Derivative", "Input"],
  " operator replacing ",
  StyleBox["Mech", "Input"],
  "'s symbolic derivatives.  ",
  StyleBox["$MechPrimeRules", "Input"],
  " is of the form ",
  StyleBox["{X2->X2[T]", "Input"],
  ", ..., ",
  StyleBox["Y3d->Y3'[T]", "Input"],
  ", ...",
  StyleBox["}", "Input"]
}], "Text",
  CellTags->"$MechPrimeRules"],

Cell[TextData[{
  StyleBox["$MechProcessFunction", "Input"],
  " a function that is applied to ",
  StyleBox["Mech", "Input"],
  "'s internal lists of modeling equations as they are generated. ",
  StyleBox["$MechProcessFunction", "Input"],
  " is initially set equal to ",
  StyleBox["Chop", "Input"],
  "."
}], "Text",
  CellTags->"$MechProcessFunction"],

Cell[TextData[{
  StyleBox["$MechTimeRules", "Input"],
  " returns a list of replacement rules for all of the current ",
  StyleBox["Mech", "Input"],
  " dependent variables to convert them to explicit functions of time.  ",
  StyleBox["$MechTimeRules", "Input"],
  " is of the form ",
  StyleBox["{X2->", "Input"],
  StyleBox["X2", "Input"],
  StyleBox["[T]", "Input"],
  ", ..., ",
  StyleBox["Y3d->", "Input"],
  StyleBox["Y3d", "Input"],
  StyleBox["[T]", "Input"],
  ", ...",
  StyleBox["}", "Input"]
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechTimeRules"],

Cell[TextData[{
  StyleBox["$MechUseEulerMassTerm", "Input"],
  " determines whether a term is retained in the mass matrix that corrects \
the Lagrange multipliers associated with Euler generalized constraints.  ",
  StyleBox["Default", "Input"],
  " is ",
  StyleBox["False", "Input"],
  " because the values of these terms have no physical meaning."
}], "Text",
  CellTags->"$MechUseEulerMassTerm"],

Cell[TextData[{
  StyleBox["$MechVariables", "Input"],
  " returns a list of the names of all of the user variables that are present \
in the current model.  Changes in the values of these variables affect the \
model."
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechVariables"],

Cell[TextData[{
  StyleBox["$MechVersion", "Input"],
  " returns the version number of the ",
  StyleBox["Mech", "Input"],
  " packages."
}], "Text",
  GeneratedCell->True,
  CellTags->"$MechVersion"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowSize->{436, 609},
WindowMargins->{{256, Automatic}, {Automatic, 16}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Mech3D"->{
    Cell[1731, 51, 71, 2, 54, "Subtitle",
      CellTags->"Mech3D"]},
  "Absolute"->{
    Cell[1805, 55, 517, 19, 74, "Text",
      CellTags->"Absolute"]},
  "Acceleration"->{
    Cell[2325, 76, 729, 23, 94, "Text",
      CellTags->"Acceleration"]},
  "AccelerationTerms"->{
    Cell[3057, 101, 375, 12, 53, "Text",
      CellTags->"AccelerationTerms"]},
  "AddLoads"->{
    Cell[3435, 115, 393, 12, 73, "Text",
      CellTags->"AddLoads"]},
  "Alpha"->{
    Cell[3831, 129, 350, 14, 54, "Text",
      CellTags->"Alpha"]},
  "Angle"->{
    Cell[4184, 145, 629, 24, 74, "Text",
      CellTags->"Angle"]},
  "Angular"->{
    Cell[4816, 171, 346, 10, 72, "Text",
      CellTags->"Angular"]},
  "Applied"->{
    Cell[5165, 183, 405, 14, 73, "Text",
      CellTags->"Applied"]},
  "ArcLength"->{
    Cell[5573, 199, 497, 16, 73, "Text",
      CellTags->"ArcLength"]},
  "Arrow"->{
    Cell[6073, 217, 983, 34, 133, "Text",
      CellTags->"Arrow"]},
  "Bar"->{
    Cell[7059, 253, 595, 27, 54, "Text",
      CellTags->"Bar"]},
  "Body"->{
    Cell[7657, 282, 1063, 39, 134, "Text",
      CellTags->"Body"]},
  "BodyEnergy"->{
    Cell[8723, 323, 286, 11, 34, "Text",
      CellTags->"BodyEnergy"]},
  "Box"->{
    Cell[9012, 336, 780, 32, 73, "Text",
      CellTags->"Box"]},
  "BuildMech"->{
    Cell[9795, 370, 841, 30, 113, "Text",
      CellTags->"BuildMech"]},
  "CamPlot"->{
    Cell[10639, 402, 1370, 60, 112, "Text",
      CellTags->"CamPlot"]},
  "CamToCam1"->{
    Cell[12012, 464, 1963, 83, 170, "Text",
      CellTags->"CamToCam1"]},
  "CamToPlane1"->{
    Cell[13978, 549, 1284, 53, 70, "Text",
      CellTags->"CamToPlane1"]},
  "CamToPoint1"->{
    Cell[15265, 604, 1261, 52, 70, "Text",
      CellTags->"CamToPoint1"]},
  "CamToSphere1"->{
    Cell[16529, 658, 1422, 59, 70, "Text",
      CellTags->"CamToSphere1"]},
  "Centrifugal"->{
    Cell[17954, 719, 305, 11, 70, "Text",
      CellTags->"Centrifugal"]},
  "Centroid"->{
    Cell[18262, 732, 585, 19, 70, "Text",
      CellTags->"Centroid"]},
  "CheckRules"->{
    Cell[18850, 753, 476, 13, 70, "Text",
      CellTags->"CheckRules"]},
  "CheckSystem"->{
    Cell[19329, 768, 402, 13, 73, "Text",
      CellTags->"CheckSystem"]},
  "ClearMech"->{
    Cell[19734, 783, 263, 8, 53, "Text",
      CellTags->"ClearMech"]},
  "ClearParameters"->{
    Cell[20000, 793, 316, 11, 53, "Text",
      CellTags->"ClearParameters"]},
  "Closed"->{
    Cell[20319, 806, 319, 10, 53, "Text",
      CellTags->"Closed"]},
  "CompositeInertia"->{
    Cell[20641, 818, 1335, 55, 132, "Text",
      CellTags->"CompositeInertia"]},
  "ConstantVelocity4"->{
    Cell[21979, 875, 962, 34, 110, "Text",
      CellTags->"ConstantVelocity4"]},
  "Constraint"->{
    Cell[22944, 911, 1507, 59, 151, "Text",
      CellTags->"Constraint"]},
  "ConstraintCorrection"->{
    Cell[24454, 972, 404, 11, 70, "Text",
      CellTags->"ConstraintCorrection"]},
  "Constraints"->{
    Cell[24861, 985, 413, 13, 70, "Text",
      CellTags->"Constraints"]},
  "Coordinates"->{
    Cell[25277, 1000, 395, 13, 70, "Text",
      CellTags->"Coordinates"]},
  "Corrector"->{
    Cell[25675, 1015, 343, 11, 70, "Text",
      CellTags->"Corrector"]},
  "CoupleSystem"->{
    Cell[26021, 1028, 205, 7, 70, "Text",
      CellTags->"CoupleSystem"]},
  "Cross"->{
    Cell[26229, 1037, 351, 13, 70, "Text",
      CellTags->"Cross"]},
  "Cubic"->{
    Cell[26583, 1052, 335, 11, 70, "Text",
      CellTags->"Cubic"]},
  "CurveToCam1"->{
    Cell[26921, 1065, 1321, 58, 70, "Text",
      CellTags->"CurveToCam1"]},
  "CurveToCylinder1"->{
    Cell[28245, 1125, 946, 39, 91, "Text",
      CellTags->"CurveToCylinder1"]},
  "CurveToPlane1"->{
    Cell[29194, 1166, 834, 34, 72, "Text",
      CellTags->"CurveToPlane1"]},
  "CurveToPoint2"->{
    Cell[30031, 1202, 783, 33, 72, "Text",
      CellTags->"CurveToPoint2"]},
  "CutOff"->{
    Cell[30817, 1237, 577, 15, 112, "Text",
      CellTags->"CutOff"]},
  "Cylindrical4"->{
    Cell[31397, 1254, 471, 20, 53, "Text",
      CellTags->"Cylindrical4"]},
  "CylindricalToXYZ"->{
    Cell[31871, 1276, 710, 30, 74, "Text",
      CellTags->"CylindricalToXYZ"]},
  "D2DistanceDT2"->{
    Cell[32584, 1308, 337, 12, 53, "Text",
      CellTags->"D2DistanceDT2"]},
  "DDistanceDT"->{
    Cell[32924, 1322, 326, 12, 53, "Text",
      CellTags->"DDistanceDT"]},
  "Diagnostics"->{
    Cell[33253, 1336, 241, 9, 34, "Text",
      CellTags->"Diagnostics"]},
  "DirectedDistance1"->{
    Cell[33497, 1347, 695, 31, 72, "Text",
      CellTags->"DirectedDistance1"]},
  "DirectedPosition3"->{
    Cell[34195, 1380, 738, 31, 70, "Text",
      CellTags->"DirectedPosition3"]},
  "Direction"->{
    Cell[34936, 1413, 272, 9, 70, "Text",
      CellTags->"Direction"]},
  "Distance"->{
    Cell[35211, 1424, 295, 11, 70, "Text",
      CellTags->"Distance"]},
  "Dynamic"->{
    Cell[35509, 1437, 773, 24, 70, "Text",
      CellTags->"Dynamic"]},
  "Edge"->{
    Cell[36285, 1463, 1377, 62, 70, "Text",
      CellTags->"Edge"]},
  "EndConditions"->{
    Cell[37665, 1527, 493, 14, 70, "Text",
      CellTags->"EndConditions"]},
  "Ends"->{
    Cell[38161, 1543, 318, 11, 70, "Text",
      CellTags->"Ends"]},
  "Euler"->{
    Cell[38482, 1556, 332, 9, 70, "Text",
      CellTags->"Euler"]},
  "EulerParameters"->{
    Cell[38817, 1567, 495, 24, 70, "Text",
      CellTags->"EulerParameters"]},
  "Extrude"->{
    Cell[39315, 1593, 744, 32, 70, "Text",
      CellTags->"Extrude"]},
  "Faces"->{
    Cell[40062, 1627, 331, 11, 70, "Text",
      CellTags->"Faces"]},
  "Facet"->{
    Cell[40396, 1640, 1415, 65, 70, "Text",
      CellTags->"Facet"]},
  "FindSwitchTime"->{
    Cell[41814, 1707, 990, 36, 70, "Text",
      CellTags->"FindSwitchTime"]},
  "FindTime"->{
    Cell[42807, 1745, 570, 19, 70, "Text",
      CellTags->"FindTime"]},
  "FitDegree"->{
    Cell[43380, 1766, 519, 18, 93, "Text",
      CellTags->"FitDegree"]},
  "Force"->{
    Cell[43902, 1786, 700, 31, 74, "Text",
      CellTags->"Force"]},
  "Free"->{
    Cell[44605, 1819, 560, 18, 93, "Text",
      CellTags->"Free"]},
  "FreeSystem"->{
    Cell[45168, 1839, 199, 7, 34, "Text",
      CellTags->"FreeSystem"]},
  "FunctionOfTime"->{
    Cell[45370, 1848, 334, 9, 73, "Text",
      CellTags->"FunctionOfTime"]},
  "Generalized"->{
    Cell[45707, 1859, 779, 25, 113, "Text",
      CellTags->"Generalized"]},
  "Global"->{
    Cell[46489, 1886, 180, 7, 34, "Text",
      CellTags->"Global"]},
  "Gravity"->{
    Cell[46672, 1895, 496, 18, 72, "Text",
      CellTags->"Gravity"]},
  "GyroFilter"->{
    Cell[47171, 1915, 1251, 55, 94, "Text",
      CellTags->"GyroFilter"]},
  "GyroMoment"->{
    Cell[48425, 1972, 793, 28, 70, "Text",
      CellTags->"GyroMoment"]},
  "HeadSize"->{
    Cell[49221, 2002, 209, 7, 70, "Text",
      CellTags->"HeadSize"]},
  "IMatrix"->{
    Cell[49433, 2011, 119, 4, 70, "Text",
      CellTags->"IMatrix"]},
  "IncludedAngle"->{
    Cell[49555, 2017, 382, 14, 70, "Text",
      CellTags->"IncludedAngle"]},
  "Inertia"->{
    Cell[49940, 2033, 898, 31, 112, "Text",
      CellTags->"Inertia"]},
  "InitialCondition"->{
    Cell[50841, 2066, 611, 15, 113, "Text",
      CellTags->"InitialCondition"]},
  "InitialGuess"->{
    Cell[51455, 2083, 1021, 42, 114, "Text",
      CellTags->"InitialGuess"]},
  "IntersectionPoint"->{
    Cell[52479, 2127, 544, 21, 74, "Text",
      CellTags->"IntersectionPoint"]},
  "Jacobian"->{
    Cell[53026, 2150, 403, 17, 53, "Text",
      CellTags->"Jacobian"]},
  "KillMech"->{
    Cell[53432, 2169, 292, 7, 72, "Text",
      CellTags->"KillMech"]},
  "Kinematic"->{
    Cell[53727, 2178, 451, 13, 73, "Text",
      CellTags->"Kinematic"]},
  "LambdaGuess"->{
    Cell[54181, 2193, 527, 14, 93, "Text",
      CellTags->"LambdaGuess"]},
  "LastSolve"->{
    Cell[54711, 2209, 418, 13, 70, "Text",
      CellTags->"LastSolve"]},
  "LeadScrew5"->{
    Cell[55132, 2224, 1069, 40, 70, "Text",
      CellTags->"LeadScrew5"]},
  "Line"->{
    Cell[56204, 2266, 1002, 38, 70, "Text",
      CellTags->"Line"]},
  "Linear"->{
    Cell[57209, 2306, 328, 11, 70, "Text",
      CellTags->"Linear"]},
  "LineOnCylinder3"->{
    Cell[57540, 2319, 638, 29, 70, "Text",
      CellTags->"LineOnCylinder3"]},
  "LineToCircle1"->{
    Cell[58181, 2350, 739, 29, 70, "Text",
      CellTags->"LineToCircle1"]},
  "LineToLine1"->{
    Cell[58923, 2381, 775, 32, 70, "Text",
      CellTags->"LineToLine1"]},
  "LineToPlane2"->{
    Cell[59701, 2415, 691, 29, 70, "Text",
      CellTags->"LineToPlane2"]},
  "Load"->{
    Cell[60395, 2446, 444, 19, 70, "Text",
      CellTags->"Load"]},
  "Loads"->{
    Cell[60842, 2467, 620, 21, 70, "Text",
      CellTags->"Loads"]},
  "Local"->{
    Cell[61465, 2490, 178, 7, 34, "Text",
      CellTags->"Local"]},
  "LocalAxes"->{
    Cell[61646, 2499, 898, 36, 93, "Text",
      CellTags->"LocalAxes"]},
  "Location"->{
    Cell[62547, 2537, 920, 38, 94, "Text",
      CellTags->"Location"]},
  "LockMech"->{
    Cell[63470, 2577, 591, 19, 93, "Text",
      CellTags->"LockMech"]},
  "LocusPlot"->{
    Cell[64064, 2598, 711, 28, 72, "Text",
      CellTags->"LocusPlot"]},
  "Magnitude"->{
    Cell[64778, 2628, 637, 21, 93, "Text",
      CellTags->"Magnitude"]},
  "MakeRules"->{
    Cell[65418, 2651, 841, 25, 154, "Text",
      CellTags->"MakeRules"]},
  "Mass"->{
    Cell[66262, 2678, 476, 18, 70, "Text",
      CellTags->"Mass"]},
  "MassMatrix"->{
    Cell[66741, 2698, 320, 12, 70, "Text",
      CellTags->"MassMatrix"]},
  "MaxError"->{
    Cell[67064, 2712, 356, 10, 70, "Text",
      CellTags->"MaxError"]},
  "Mech"->{
    Cell[67423, 2724, 173, 5, 70, "Text",
      CellTags->"Mech"]},
  "MechPrimitive"->{
    Cell[67599, 2731, 524, 14, 70, "Text",
      CellTags->"MechPrimitive"]},
  "Moment"->{
    Cell[68126, 2747, 650, 28, 70, "Text",
      CellTags->"Moment"]},
  "Natural"->{
    Cell[68779, 2777, 305, 10, 70, "Text",
      CellTags->"Natural"]},
  "Omega"->{
    Cell[69087, 2789, 268, 11, 70, "Text",
      CellTags->"Omega"]},
  "OriginLock3"->{
    Cell[69358, 2802, 683, 26, 70, "Text",
      CellTags->"OriginLock3"]},
  "Orthogonal1"->{
    Cell[70044, 2830, 463, 20, 53, "Text",
      CellTags->"Orthogonal1"]},
  "OrthogonalGears5"->{
    Cell[70510, 2852, 1132, 38, 148, "Text",
      CellTags->"OrthogonalGears5"]},
  "OrthoRevolute4"->{
    Cell[71645, 2892, 835, 35, 72, "Text",
      CellTags->"OrthoRevolute4"]},
  "Parallel2"->{
    Cell[72483, 2929, 333, 13, 53, "Text",
      CellTags->"Parallel2"]},
  "ParallelAxis"->{
    Cell[72819, 2944, 755, 23, 130, "Text",
      CellTags->"ParallelAxis"]},
  "ParallelGears4"->{
    Cell[73577, 2969, 911, 37, 92, "Text",
      CellTags->"ParallelGears4"]},
  "ParallelGears5"->{
    Cell[74491, 3008, 1001, 39, 110, "Text",
      CellTags->"ParallelGears5"]},
  "Parameterize"->{
    Cell[75495, 3049, 384, 10, 70, "Text",
      CellTags->"Parameterize"]},
  "Parameters"->{
    Cell[75882, 3061, 710, 21, 70, "Text",
      CellTags->"Parameters"]},
  "ParaRevolute4"->{
    Cell[76595, 3084, 705, 29, 70, "Text",
      CellTags->"ParaRevolute4"]},
  "PathSystem"->{
    Cell[77303, 3115, 199, 7, 70, "Text",
      CellTags->"PathSystem"]},
  "Plane"->{
    Cell[77505, 3124, 1267, 52, 70, "Text",
      CellTags->"Plane"]},
  "PlaneToCircle1"->{
    Cell[78775, 3178, 727, 29, 70, "Text",
      CellTags->"PlaneToCircle1"]},
  "PlaneToPlane3"->{
    Cell[79505, 3209, 809, 35, 70, "Text",
      CellTags->"PlaneToPlane3"]},
  "Point"->{
    Cell[80317, 3246, 719, 27, 70, "Text",
      CellTags->"Point"]},
  "PointAtIntersection3"->{
    Cell[81039, 3275, 600, 25, 70, "Text",
      CellTags->"PointAtIntersection3"]},
  "PointLabel"->{
    Cell[81642, 3302, 698, 28, 70, "Text",
      CellTags->"PointLabel"]},
  "PointList"->{
    Cell[82343, 3332, 1347, 50, 70, "Text",
      CellTags->"PointList"]},
  "PointOnCircle2"->{
    Cell[83693, 3384, 685, 28, 70, "Text",
      CellTags->"PointOnCircle2"]},
  "PointOnCone1"->{
    Cell[84381, 3414, 701, 28, 70, "Text",
      CellTags->"PointOnCone1"]},
  "PointOnCylinder1"->{
    Cell[85085, 3444, 612, 25, 70, "Text",
      CellTags->"PointOnCylinder1"]},
  "PointOnLine2"->{
    Cell[85700, 3471, 459, 19, 70, "Text",
      CellTags->"PointOnLine2"]},
  "PointOnPlane1"->{
    Cell[86162, 3492, 562, 24, 70, "Text",
      CellTags->"PointOnPlane1"]},
  "PointOnPlanes2"->{
    Cell[86727, 3518, 486, 20, 70, "Text",
      CellTags->"PointOnPlanes2"]},
  "PointOnTorus1"->{
    Cell[87216, 3540, 792, 32, 70, "Text",
      CellTags->"PointOnTorus1"]},
  "PointToLineDistance"->{
    Cell[88011, 3574, 381, 16, 70, "Text",
      CellTags->"PointToLineDistance"]},
  "PointToLocal"->{
    Cell[88395, 3592, 395, 16, 70, "Text",
      CellTags->"PointToLocal"]},
  "PointToPlaneDistance"->{
    Cell[88793, 3610, 428, 16, 70, "Text",
      CellTags->"PointToPlaneDistance"]},
  "Predictor"->{
    Cell[89224, 3628, 335, 11, 70, "Text",
      CellTags->"Predictor"]},
  "PrincipalAxes"->{
    Cell[89562, 3641, 702, 26, 70, "Text",
      CellTags->"PrincipalAxes"]},
  "ProjectedAngle"->{
    Cell[90267, 3669, 610, 23, 70, "Text",
      CellTags->"ProjectedAngle"]},
  "ProjectedAngle1"->{
    Cell[90880, 3694, 942, 36, 70, "Text",
      CellTags->"ProjectedAngle1"]},
  "ProjectOnLine"->{
    Cell[91825, 3732, 862, 36, 70, "Text",
      CellTags->"ProjectOnLine"]},
  "ProjectOnPlane"->{
    Cell[92690, 3770, 911, 36, 70, "Text",
      CellTags->"ProjectOnPlane"]},
  "Quadratic"->{
    Cell[93604, 3808, 341, 11, 54, "Text",
      CellTags->"Quadratic"]},
  "Quartic"->{
    Cell[93948, 3821, 333, 11, 53, "Text",
      CellTags->"Quartic"]},
  "RackAndPinion4"->{
    Cell[94284, 3834, 795, 32, 92, "Text",
      CellTags->"RackAndPinion4"]},
  "RackAndPinion5"->{
    Cell[95082, 3868, 1504, 54, 167, "Text",
      CellTags->"RackAndPinion5"]},
  "Reaction"->{
    Cell[96589, 3924, 1027, 41, 114, "Text",
      CellTags->"Reaction"]},
  "ReferenceDirection"->{
    Cell[97619, 3967, 417, 14, 53, "Text",
      CellTags->"ReferenceDirection"]},
  "Relative"->{
    Cell[98039, 3983, 500, 16, 92, "Text",
      CellTags->"Relative"]},
  "RelativeAngle1"->{
    Cell[98542, 4001, 590, 26, 53, "Text",
      CellTags->"RelativeAngle1"]},
  "RelativeDistance1"->{
    Cell[99135, 4029, 632, 26, 72, "Text",
      CellTags->"RelativeDistance1"]},
  "RelativeVelocity"->{
    Cell[99770, 4057, 402, 16, 53, "Text",
      CellTags->"RelativeVelocity"]},
  "RelativeX1"->{
    Cell[100175, 4075, 701, 32, 53, "Text",
      CellTags->"RelativeX1"]},
  "RelativeY1"->{
    Cell[100879, 4109, 701, 32, 53, "Text",
      CellTags->"RelativeY1"]},
  "RelativeZ1"->{
    Cell[101583, 4143, 701, 32, 53, "Text",
      CellTags->"RelativeZ1"]},
  "RequiredEquations"->{
    Cell[102287, 4177, 906, 24, 172, "Text",
      CellTags->"RequiredEquations"]},
  "Revolute5"->{
    Cell[103196, 4203, 620, 26, 72, "Text",
      CellTags->"Revolute5"]},
  "Revolve"->{
    Cell[103819, 4231, 788, 35, 74, "Text",
      CellTags->"Revolve"]},
  "Rotation"->{
    Cell[104610, 4268, 450, 18, 53, "Text",
      CellTags->"Rotation"]},
  "RotationLock3"->{
    Cell[105063, 4288, 816, 32, 91, "Text",
      CellTags->"RotationLock3"]},
  "RotationMatrix"->{
    Cell[105882, 4322, 275, 10, 53, "Text",
      CellTags->"RotationMatrix"]},
  "SaveMech"->{
    Cell[106160, 4334, 353, 13, 54, "Text",
      CellTags->"SaveMech"]},
  "SensitivitySystem"->{
    Cell[106516, 4349, 220, 7, 54, "Text",
      CellTags->"SensitivitySystem"]},
  "SetBodies"->{
    Cell[106739, 4358, 552, 18, 93, "Text",
      CellTags->"SetBodies"]},
  "SetConstraints"->{
    Cell[107294, 4378, 757, 18, 134, "Text",
      CellTags->"SetConstraints"]},
  "SetCouple"->{
    Cell[108054, 4398, 602, 26, 53, "Text",
      CellTags->"SetCouple"]},
  "SetFree"->{
    Cell[108659, 4426, 722, 24, 112, "Text",
      CellTags->"SetFree"]},
  "SetGuess"->{
    Cell[109384, 4452, 551, 15, 93, "Text",
      CellTags->"SetGuess"]},
  "SetLoads"->{
    Cell[109938, 4469, 744, 20, 133, "Text",
      CellTags->"SetLoads"]},
  "SetParameters"->{
    Cell[110685, 4491, 506, 18, 74, "Text",
      CellTags->"SetParameters"]},
  "SetPath"->{
    Cell[111194, 4511, 821, 25, 133, "Text",
      CellTags->"SetPath"]},
  "SetSensitivity"->{
    Cell[112018, 4538, 520, 17, 94, "Text",
      CellTags->"SetSensitivity"]},
  "SetSymbols"->{
    Cell[112541, 4557, 649, 21, 113, "Text",
      CellTags->"SetSymbols"]},
  "SkewSym"->{
    Cell[113193, 4580, 974, 47, 54, "Text",
      CellTags->"SkewSym"]},
  "Solution"->{
    Cell[114170, 4629, 546, 22, 74, "Text",
      CellTags->"Solution"]},
  "SolveCouple"->{
    Cell[114719, 4653, 599, 22, 74, "Text",
      CellTags->"SolveCouple"]},
  "SolveFree"->{
    Cell[115321, 4677, 987, 36, 113, "Text",
      CellTags->"SolveFree"]},
  "SolveMech"->{
    Cell[116311, 4715, 1037, 36, 134, "Text",
      CellTags->"SolveMech"]},
  "SolvePath"->{
    Cell[117351, 4753, 683, 26, 93, "Text",
      CellTags->"SolvePath"]},
  "SolveSensitivity"->{
    Cell[118037, 4781, 652, 22, 94, "Text",
      CellTags->"SolveSensitivity"]},
  "Sphere"->{
    Cell[118692, 4805, 777, 32, 92, "Text",
      CellTags->"Sphere"]},
  "Spherical3"->{
    Cell[119472, 4839, 436, 19, 53, "Text",
      CellTags->"Spherical3"]},
  "SphericalToXYZ"->{
    Cell[119911, 4860, 711, 30, 74, "Text",
      CellTags->"SphericalToXYZ"]},
  "SplineFit"->{
    Cell[120625, 4892, 348, 13, 53, "Text",
      CellTags->"SplineFit"]},
  "SplineFunction"->{
    Cell[120976, 4907, 480, 17, 73, "Text",
      CellTags->"SplineFunction"]},
  "StageSwitch"->{
    Cell[121459, 4926, 1177, 50, 113, "Text",
      CellTags->"StageSwitch"]},
  "Static"->{
    Cell[122639, 4978, 422, 13, 73, "Text",
      CellTags->"Static"]},
  "Step"->{
    Cell[123064, 4993, 647, 25, 74, "Text",
      CellTags->"Step"]},
  "StepMech"->{
    Cell[123714, 5020, 380, 12, 72, "Text",
      CellTags->"StepMech"]},
  "StepSize"->{
    Cell[124097, 5034, 255, 8, 53, "Text",
      CellTags->"StepSize"]},
  "SymbolBasis"->{
    Cell[124355, 5044, 347, 10, 72, "Text",
      CellTags->"SymbolBasis"]},
  "SysBody"->{
    Cell[124705, 5056, 208, 7, 34, "Text",
      CellTags->"SysBody"]},
  "SysCon"->{
    Cell[124916, 5065, 224, 7, 53, "Text",
      CellTags->"SysCon"]},
  "SysLoad"->{
    Cell[125143, 5074, 214, 7, 34, "Text",
      CellTags->"SysLoad"]},
  "SysPlot"->{
    Cell[125360, 5083, 326, 10, 73, "Text",
      CellTags->"SysPlot"]},
  "TangentConstraint"->{
    Cell[125689, 5095, 400, 11, 73, "Text",
      CellTags->"TangentConstraint"]},
  "Time"->{
    Cell[126092, 5108, 410, 13, 74, "Text",
      CellTags->"Time"]},
  "TimeInterpolate"->{
    Cell[126505, 5123, 818, 31, 93, "Text",
      CellTags->"TimeInterpolate"]},
  "TimeSwitch"->{
    Cell[127326, 5156, 1823, 81, 154, "Text",
      CellTags->"TimeSwitch"]},
  "Torus"->{
    Cell[129152, 5239, 809, 32, 92, "Text",
      CellTags->"Torus"]},
  "Translate5"->{
    Cell[129964, 5273, 465, 16, 72, "Text",
      CellTags->"Translate5"]},
  "TwoPulleys4"->{
    Cell[130432, 5291, 903, 38, 92, "Text",
      CellTags->"TwoPulleys4"]},
  "TwoPulleys5"->{
    Cell[131338, 5331, 1122, 45, 110, "Text",
      CellTags->"TwoPulleys5"]},
  "Type"->{
    Cell[132463, 5378, 419, 16, 54, "Text",
      CellTags->"Type"]},
  "Unit"->{
    Cell[132885, 5396, 260, 10, 34, "Text",
      CellTags->"Unit"]},
  "Vector"->{
    Cell[133148, 5408, 1065, 45, 93, "Text",
      CellTags->"Vector"]},
  "Velocity"->{
    Cell[134216, 5455, 648, 22, 93, "Text",
      CellTags->"Velocity"]},
  "VelocityTerms"->{
    Cell[134867, 5479, 363, 12, 53, "Text",
      CellTags->"VelocityTerms"]},
  "Vertex"->{
    Cell[135233, 5493, 1037, 47, 73, "Text",
      CellTags->"Vertex"]},
  "Virtual"->{
    Cell[136273, 5542, 417, 12, 74, "Text",
      CellTags->"Virtual"]},
  "Wheel"->{
    Cell[136693, 5556, 533, 24, 54, "Text",
      CellTags->"Wheel"]},
  "XYZ"->{
    Cell[137229, 5582, 302, 10, 53, "Text",
      CellTags->"XYZ"]},
  "XYZToCylindrical"->{
    Cell[137534, 5594, 687, 29, 74, "Text",
      CellTags->"XYZToCylindrical"]},
  "XYZToSpherical"->{
    Cell[138224, 5625, 688, 29, 74, "Text",
      CellTags->"XYZToSpherical"]},
  "YZX"->{
    Cell[138915, 5656, 302, 10, 53, "Text",
      CellTags->"YZX"]},
  "ZXY"->{
    Cell[139220, 5668, 302, 10, 53, "Text",
      CellTags->"ZXY"]},
  "$MechPostIterate"->{
    Cell[139525, 5680, 247, 7, 54, "Text",
      CellTags->"$MechPostIterate"]},
  "$MechPreSolve"->{
    Cell[139775, 5689, 225, 6, 53, "Text",
      CellTags->"$MechPreSolve"]},
  "$MechPrimeRules"->{
    Cell[140003, 5697, 581, 18, 94, "Text",
      CellTags->"$MechPrimeRules"]},
  "$MechProcessFunction"->{
    Cell[140587, 5717, 356, 10, 74, "Text",
      CellTags->"$MechProcessFunction"]},
  "$MechTimeRules"->{
    Cell[140946, 5729, 570, 18, 74, "Text",
      CellTags->"$MechTimeRules"]},
  "$MechUseEulerMassTerm"->{
    Cell[141519, 5749, 400, 9, 92, "Text",
      CellTags->"$MechUseEulerMassTerm"]},
  "$MechVariables"->{
    Cell[141922, 5760, 284, 7, 72, "Text",
      CellTags->"$MechVariables"]},
  "$MechVersion"->{
    Cell[142209, 5769, 200, 7, 34, "Text",
      CellTags->"$MechVersion"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Mech3D", 143024, 5795},
  {"Absolute", 143110, 5798},
  {"Acceleration", 143200, 5801},
  {"AccelerationTerms", 143299, 5804},
  {"AddLoads", 143395, 5807},
  {"Alpha", 143479, 5810},
  {"Angle", 143560, 5813},
  {"Angular", 143643, 5816},
  {"Applied", 143728, 5819},
  {"ArcLength", 143815, 5822},
  {"Arrow", 143900, 5825},
  {"Bar", 143980, 5828},
  {"Body", 144058, 5831},
  {"BodyEnergy", 144145, 5834},
  {"Box", 144229, 5837},
  {"BuildMech", 144312, 5840},
  {"CamPlot", 144400, 5843},
  {"CamToCam1", 144490, 5846},
  {"CamToPlane1", 144584, 5849},
  {"CamToPoint1", 144679, 5852},
  {"CamToSphere1", 144775, 5855},
  {"Centrifugal", 144871, 5858},
  {"Centroid", 144962, 5861},
  {"CheckRules", 145052, 5864},
  {"CheckSystem", 145145, 5867},
  {"ClearMech", 145237, 5870},
  {"ClearParameters", 145332, 5873},
  {"Closed", 145425, 5876},
  {"CompositeInertia", 145519, 5879},
  {"ConstantVelocity4", 145626, 5882},
  {"Constraint", 145726, 5885},
  {"ConstraintCorrection", 145830, 5888},
  {"Constraints", 145933, 5891},
  {"Coordinates", 146027, 5894},
  {"Corrector", 146120, 5897},
  {"CoupleSystem", 146214, 5900},
  {"Cross", 146303, 5903},
  {"Cubic", 146386, 5906},
  {"CurveToCam1", 146475, 5909},
  {"CurveToCylinder1", 146576, 5912},
  {"CurveToPlane1", 146678, 5915},
  {"CurveToPoint2", 146777, 5918},
  {"CutOff", 146869, 5921},
  {"Cylindrical4", 146961, 5924},
  {"CylindricalToXYZ", 147062, 5927},
  {"D2DistanceDT2", 147164, 5930},
  {"DDistanceDT", 147261, 5933},
  {"Diagnostics", 147356, 5936},
  {"DirectedDistance1", 147456, 5939},
  {"DirectedPosition3", 147563, 5942},
  {"Direction", 147662, 5945},
  {"Distance", 147751, 5948},
  {"Dynamic", 147839, 5951},
  {"Edge", 147923, 5954},
  {"EndConditions", 148014, 5957},
  {"Ends", 148104, 5960},
  {"Euler", 148186, 5963},
  {"EulerParameters", 148278, 5966},
  {"Extrude", 148373, 5969},
  {"Faces", 148458, 5972},
  {"Facet", 148541, 5975},
  {"FindSwitchTime", 148634, 5978},
  {"FindTime", 148729, 5981},
  {"FitDegree", 148819, 5984},
  {"Force", 148906, 5987},
  {"Free", 148988, 5990},
  {"FreeSystem", 149075, 5993},
  {"FunctionOfTime", 149171, 5996},
  {"Generalized", 149268, 5999},
  {"Global", 149359, 6002},
  {"Gravity", 149444, 6005},
  {"GyroFilter", 149534, 6008},
  {"GyroMoment", 149628, 6011},
  {"HeadSize", 149719, 6014},
  {"IMatrix", 149806, 6017},
  {"IncludedAngle", 149898, 6020},
  {"Inertia", 149991, 6023},
  {"InitialCondition", 150088, 6026},
  {"InitialGuess", 150190, 6029},
  {"IntersectionPoint", 150294, 6032},
  {"Jacobian", 150392, 6035},
  {"KillMech", 150481, 6038},
  {"Kinematic", 150570, 6041},
  {"LambdaGuess", 150663, 6044},
  {"LastSolve", 150756, 6047},
  {"LeadScrew5", 150848, 6050},
  {"Line", 150936, 6053},
  {"Linear", 151020, 6056},
  {"LineOnCylinder3", 151114, 6059},
  {"LineToCircle1", 151215, 6062},
  {"LineToLine1", 151312, 6065},
  {"LineToPlane2", 151408, 6068},
  {"Load", 151497, 6071},
  {"Loads", 151579, 6074},
  {"Local", 151662, 6077},
  {"LocalAxes", 151748, 6080},
  {"Location", 151838, 6083},
  {"LockMech", 151927, 6086},
  {"LocusPlot", 152017, 6089},
  {"Magnitude", 152108, 6092},
  {"MakeRules", 152199, 6095},
  {"Mass", 152286, 6098},
  {"MassMatrix", 152373, 6101},
  {"MaxError", 152464, 6104},
  {"Mech", 152549, 6107},
  {"MechPrimitive", 152638, 6110},
  {"Moment", 152730, 6113},
  {"Natural", 152816, 6116},
  {"Omega", 152901, 6119},
  {"OriginLock3", 152990, 6122},
  {"Orthogonal1", 153085, 6125},
  {"OrthogonalGears5", 153185, 6128},
  {"OrthoRevolute4", 153290, 6131},
  {"Parallel2", 153386, 6134},
  {"ParallelAxis", 153480, 6137},
  {"ParallelGears4", 153580, 6140},
  {"ParallelGears5", 153681, 6143},
  {"Parameterize", 153782, 6146},
  {"Parameters", 153877, 6149},
  {"ParaRevolute4", 153973, 6152},
  {"PathSystem", 154069, 6155},
  {"Plane", 154156, 6158},
  {"PlaneToCircle1", 154249, 6161},
  {"PlaneToPlane3", 154349, 6164},
  {"Point", 154440, 6167},
  {"PointAtIntersection3", 154538, 6170},
  {"PointLabel", 154641, 6173},
  {"PointList", 154733, 6176},
  {"PointOnCircle2", 154830, 6179},
  {"PointOnCone1", 154929, 6182},
  {"PointOnCylinder1", 155030, 6185},
  {"PointOnLine2", 155131, 6188},
  {"PointOnPlane1", 155229, 6191},
  {"PointOnPlanes2", 155329, 6194},
  {"PointOnTorus1", 155429, 6197},
  {"PointToLineDistance", 155534, 6200},
  {"PointToLocal", 155638, 6203},
  {"PointToPlaneDistance", 155743, 6206},
  {"Predictor", 155845, 6209},
  {"PrincipalAxes", 155940, 6212},
  {"ProjectedAngle", 156040, 6215},
  {"ProjectedAngle1", 156142, 6218},
  {"ProjectOnLine", 156243, 6221},
  {"ProjectOnPlane", 156343, 6224},
  {"Quadratic", 156439, 6227},
  {"Quartic", 156528, 6230},
  {"RackAndPinion4", 156622, 6233},
  {"RackAndPinion5", 156723, 6236},
  {"Reaction", 156820, 6239},
  {"ReferenceDirection", 156921, 6242},
  {"Relative", 157020, 6245},
  {"RelativeAngle1", 157115, 6248},
  {"RelativeDistance1", 157219, 6251},
  {"RelativeVelocity", 157325, 6254},
  {"RelativeX1", 157424, 6257},
  {"RelativeY1", 157518, 6260},
  {"RelativeZ1", 157612, 6263},
  {"RequiredEquations", 157713, 6266},
  {"Revolute5", 157814, 6269},
  {"Revolve", 157904, 6272},
  {"Rotation", 157993, 6275},
  {"RotationLock3", 158088, 6278},
  {"RotationMatrix", 158189, 6281},
  {"SaveMech", 158285, 6284},
  {"SensitivitySystem", 158384, 6287},
  {"SetBodies", 158483, 6290},
  {"SetConstraints", 158580, 6293},
  {"SetCouple", 158678, 6296},
  {"SetFree", 158768, 6299},
  {"SetGuess", 158858, 6302},
  {"SetLoads", 158948, 6305},
  {"SetParameters", 159044, 6308},
  {"SetPath", 159138, 6311},
  {"SetSensitivity", 159234, 6314},
  {"SetSymbols", 159332, 6317},
  {"SkewSym", 159424, 6320},
  {"Solution", 159513, 6323},
  {"SolveCouple", 159606, 6326},
  {"SolveFree", 159700, 6329},
  {"SolveMech", 159793, 6332},
  {"SolvePath", 159887, 6335},
  {"SolveSensitivity", 159986, 6338},
  {"Sphere", 160082, 6341},
  {"Spherical3", 160172, 6344},
  {"SphericalToXYZ", 160270, 6347},
  {"SplineFit", 160367, 6350},
  {"SplineFunction", 160464, 6353},
  {"StageSwitch", 160563, 6356},
  {"Static", 160656, 6359},
  {"Step", 160740, 6362},
  {"StepMech", 160826, 6365},
  {"StepSize", 160916, 6368},
  {"SymbolBasis", 161008, 6371},
  {"SysBody", 161100, 6374},
  {"SysCon", 161186, 6377},
  {"SysLoad", 161272, 6380},
  {"SysPlot", 161359, 6383},
  {"TangentConstraint", 161457, 6386},
  {"Time", 161552, 6389},
  {"TimeInterpolate", 161645, 6392},
  {"TimeSwitch", 161744, 6395},
  {"Torus", 161835, 6398},
  {"Translate5", 161924, 6401},
  {"TwoPulleys4", 162019, 6404},
  {"TwoPulleys5", 162115, 6407},
  {"Type", 162206, 6410},
  {"Unit", 162288, 6413},
  {"Vector", 162372, 6416},
  {"Velocity", 162461, 6419},
  {"VelocityTerms", 162556, 6422},
  {"Vertex", 162649, 6425},
  {"Virtual", 162737, 6428},
  {"Wheel", 162823, 6431},
  {"XYZ", 162905, 6434},
  {"XYZToCylindrical", 162998, 6437},
  {"XYZToSpherical", 163102, 6440},
  {"YZX", 163193, 6443},
  {"ZXY", 163273, 6446},
  {"$MechPostIterate", 163366, 6449},
  {"$MechPreSolve", 163468, 6452},
  {"$MechPrimeRules", 163569, 6455},
  {"$MechProcessFunction", 163678, 6458},
  {"$MechTimeRules", 163786, 6461},
  {"$MechUseEulerMassTerm", 163895, 6464},
  {"$MechVariables", 164003, 6467},
  {"$MechVersion", 164102, 6470}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 71, 2, 54, "Subtitle",
  CellTags->"Mech3D"],
Cell[1805, 55, 517, 19, 74, "Text",
  CellTags->"Absolute"],
Cell[2325, 76, 729, 23, 94, "Text",
  CellTags->"Acceleration"],
Cell[3057, 101, 375, 12, 53, "Text",
  CellTags->"AccelerationTerms"],
Cell[3435, 115, 393, 12, 73, "Text",
  CellTags->"AddLoads"],
Cell[3831, 129, 350, 14, 54, "Text",
  CellTags->"Alpha"],
Cell[4184, 145, 629, 24, 74, "Text",
  CellTags->"Angle"],
Cell[4816, 171, 346, 10, 72, "Text",
  CellTags->"Angular"],
Cell[5165, 183, 405, 14, 73, "Text",
  CellTags->"Applied"],
Cell[5573, 199, 497, 16, 73, "Text",
  CellTags->"ArcLength"],
Cell[6073, 217, 983, 34, 133, "Text",
  CellTags->"Arrow"],
Cell[7059, 253, 595, 27, 54, "Text",
  CellTags->"Bar"],
Cell[7657, 282, 1063, 39, 134, "Text",
  CellTags->"Body"],
Cell[8723, 323, 286, 11, 34, "Text",
  CellTags->"BodyEnergy"],
Cell[9012, 336, 780, 32, 73, "Text",
  CellTags->"Box"],
Cell[9795, 370, 841, 30, 113, "Text",
  CellTags->"BuildMech"],
Cell[10639, 402, 1370, 60, 112, "Text",
  CellTags->"CamPlot"],
Cell[12012, 464, 1963, 83, 170, "Text",
  CellTags->"CamToCam1"],
Cell[13978, 549, 1284, 53, 70, "Text",
  CellTags->"CamToPlane1"],
Cell[15265, 604, 1261, 52, 70, "Text",
  CellTags->"CamToPoint1"],
Cell[16529, 658, 1422, 59, 70, "Text",
  CellTags->"CamToSphere1"],
Cell[17954, 719, 305, 11, 70, "Text",
  CellTags->"Centrifugal"],
Cell[18262, 732, 585, 19, 70, "Text",
  CellTags->"Centroid"],
Cell[18850, 753, 476, 13, 70, "Text",
  CellTags->"CheckRules"],
Cell[19329, 768, 402, 13, 73, "Text",
  CellTags->"CheckSystem"],
Cell[19734, 783, 263, 8, 53, "Text",
  CellTags->"ClearMech"],
Cell[20000, 793, 316, 11, 53, "Text",
  CellTags->"ClearParameters"],
Cell[20319, 806, 319, 10, 53, "Text",
  CellTags->"Closed"],
Cell[20641, 818, 1335, 55, 132, "Text",
  CellTags->"CompositeInertia"],
Cell[21979, 875, 962, 34, 110, "Text",
  CellTags->"ConstantVelocity4"],
Cell[22944, 911, 1507, 59, 151, "Text",
  CellTags->"Constraint"],
Cell[24454, 972, 404, 11, 70, "Text",
  CellTags->"ConstraintCorrection"],
Cell[24861, 985, 413, 13, 70, "Text",
  CellTags->"Constraints"],
Cell[25277, 1000, 395, 13, 70, "Text",
  CellTags->"Coordinates"],
Cell[25675, 1015, 343, 11, 70, "Text",
  CellTags->"Corrector"],
Cell[26021, 1028, 205, 7, 70, "Text",
  CellTags->"CoupleSystem"],
Cell[26229, 1037, 351, 13, 70, "Text",
  CellTags->"Cross"],
Cell[26583, 1052, 335, 11, 70, "Text",
  CellTags->"Cubic"],
Cell[26921, 1065, 1321, 58, 70, "Text",
  CellTags->"CurveToCam1"],
Cell[28245, 1125, 946, 39, 91, "Text",
  CellTags->"CurveToCylinder1"],
Cell[29194, 1166, 834, 34, 72, "Text",
  CellTags->"CurveToPlane1"],
Cell[30031, 1202, 783, 33, 72, "Text",
  CellTags->"CurveToPoint2"],
Cell[30817, 1237, 577, 15, 112, "Text",
  CellTags->"CutOff"],
Cell[31397, 1254, 471, 20, 53, "Text",
  CellTags->"Cylindrical4"],
Cell[31871, 1276, 710, 30, 74, "Text",
  CellTags->"CylindricalToXYZ"],
Cell[32584, 1308, 337, 12, 53, "Text",
  CellTags->"D2DistanceDT2"],
Cell[32924, 1322, 326, 12, 53, "Text",
  CellTags->"DDistanceDT"],
Cell[33253, 1336, 241, 9, 34, "Text",
  CellTags->"Diagnostics"],
Cell[33497, 1347, 695, 31, 72, "Text",
  CellTags->"DirectedDistance1"],
Cell[34195, 1380, 738, 31, 70, "Text",
  CellTags->"DirectedPosition3"],
Cell[34936, 1413, 272, 9, 70, "Text",
  CellTags->"Direction"],
Cell[35211, 1424, 295, 11, 70, "Text",
  CellTags->"Distance"],
Cell[35509, 1437, 773, 24, 70, "Text",
  CellTags->"Dynamic"],
Cell[36285, 1463, 1377, 62, 70, "Text",
  CellTags->"Edge"],
Cell[37665, 1527, 493, 14, 70, "Text",
  CellTags->"EndConditions"],
Cell[38161, 1543, 318, 11, 70, "Text",
  CellTags->"Ends"],
Cell[38482, 1556, 332, 9, 70, "Text",
  CellTags->"Euler"],
Cell[38817, 1567, 495, 24, 70, "Text",
  CellTags->"EulerParameters"],
Cell[39315, 1593, 744, 32, 70, "Text",
  CellTags->"Extrude"],
Cell[40062, 1627, 331, 11, 70, "Text",
  CellTags->"Faces"],
Cell[40396, 1640, 1415, 65, 70, "Text",
  CellTags->"Facet"],
Cell[41814, 1707, 990, 36, 70, "Text",
  CellTags->"FindSwitchTime"],
Cell[42807, 1745, 570, 19, 70, "Text",
  CellTags->"FindTime"],
Cell[43380, 1766, 519, 18, 93, "Text",
  CellTags->"FitDegree"],
Cell[43902, 1786, 700, 31, 74, "Text",
  CellTags->"Force"],
Cell[44605, 1819, 560, 18, 93, "Text",
  CellTags->"Free"],
Cell[45168, 1839, 199, 7, 34, "Text",
  CellTags->"FreeSystem"],
Cell[45370, 1848, 334, 9, 73, "Text",
  CellTags->"FunctionOfTime"],
Cell[45707, 1859, 779, 25, 113, "Text",
  CellTags->"Generalized"],
Cell[46489, 1886, 180, 7, 34, "Text",
  CellTags->"Global"],
Cell[46672, 1895, 496, 18, 72, "Text",
  CellTags->"Gravity"],
Cell[47171, 1915, 1251, 55, 94, "Text",
  CellTags->"GyroFilter"],
Cell[48425, 1972, 793, 28, 70, "Text",
  CellTags->"GyroMoment"],
Cell[49221, 2002, 209, 7, 70, "Text",
  CellTags->"HeadSize"],
Cell[49433, 2011, 119, 4, 70, "Text",
  CellTags->"IMatrix"],
Cell[49555, 2017, 382, 14, 70, "Text",
  CellTags->"IncludedAngle"],
Cell[49940, 2033, 898, 31, 112, "Text",
  CellTags->"Inertia"],
Cell[50841, 2066, 611, 15, 113, "Text",
  CellTags->"InitialCondition"],
Cell[51455, 2083, 1021, 42, 114, "Text",
  CellTags->"InitialGuess"],
Cell[52479, 2127, 544, 21, 74, "Text",
  CellTags->"IntersectionPoint"],
Cell[53026, 2150, 403, 17, 53, "Text",
  CellTags->"Jacobian"],
Cell[53432, 2169, 292, 7, 72, "Text",
  CellTags->"KillMech"],
Cell[53727, 2178, 451, 13, 73, "Text",
  CellTags->"Kinematic"],
Cell[54181, 2193, 527, 14, 93, "Text",
  CellTags->"LambdaGuess"],
Cell[54711, 2209, 418, 13, 70, "Text",
  CellTags->"LastSolve"],
Cell[55132, 2224, 1069, 40, 70, "Text",
  CellTags->"LeadScrew5"],
Cell[56204, 2266, 1002, 38, 70, "Text",
  CellTags->"Line"],
Cell[57209, 2306, 328, 11, 70, "Text",
  CellTags->"Linear"],
Cell[57540, 2319, 638, 29, 70, "Text",
  CellTags->"LineOnCylinder3"],
Cell[58181, 2350, 739, 29, 70, "Text",
  CellTags->"LineToCircle1"],
Cell[58923, 2381, 775, 32, 70, "Text",
  CellTags->"LineToLine1"],
Cell[59701, 2415, 691, 29, 70, "Text",
  CellTags->"LineToPlane2"],
Cell[60395, 2446, 444, 19, 70, "Text",
  CellTags->"Load"],
Cell[60842, 2467, 620, 21, 70, "Text",
  CellTags->"Loads"],
Cell[61465, 2490, 178, 7, 34, "Text",
  CellTags->"Local"],
Cell[61646, 2499, 898, 36, 93, "Text",
  CellTags->"LocalAxes"],
Cell[62547, 2537, 920, 38, 94, "Text",
  CellTags->"Location"],
Cell[63470, 2577, 591, 19, 93, "Text",
  CellTags->"LockMech"],
Cell[64064, 2598, 711, 28, 72, "Text",
  CellTags->"LocusPlot"],
Cell[64778, 2628, 637, 21, 93, "Text",
  CellTags->"Magnitude"],
Cell[65418, 2651, 841, 25, 154, "Text",
  CellTags->"MakeRules"],
Cell[66262, 2678, 476, 18, 70, "Text",
  CellTags->"Mass"],
Cell[66741, 2698, 320, 12, 70, "Text",
  CellTags->"MassMatrix"],
Cell[67064, 2712, 356, 10, 70, "Text",
  CellTags->"MaxError"],
Cell[67423, 2724, 173, 5, 70, "Text",
  CellTags->"Mech"],
Cell[67599, 2731, 524, 14, 70, "Text",
  CellTags->"MechPrimitive"],
Cell[68126, 2747, 650, 28, 70, "Text",
  CellTags->"Moment"],
Cell[68779, 2777, 305, 10, 70, "Text",
  CellTags->"Natural"],
Cell[69087, 2789, 268, 11, 70, "Text",
  CellTags->"Omega"],
Cell[69358, 2802, 683, 26, 70, "Text",
  CellTags->"OriginLock3"],
Cell[70044, 2830, 463, 20, 53, "Text",
  CellTags->"Orthogonal1"],
Cell[70510, 2852, 1132, 38, 148, "Text",
  CellTags->"OrthogonalGears5"],
Cell[71645, 2892, 835, 35, 72, "Text",
  CellTags->"OrthoRevolute4"],
Cell[72483, 2929, 333, 13, 53, "Text",
  CellTags->"Parallel2"],
Cell[72819, 2944, 755, 23, 130, "Text",
  CellTags->"ParallelAxis"],
Cell[73577, 2969, 911, 37, 92, "Text",
  CellTags->"ParallelGears4"],
Cell[74491, 3008, 1001, 39, 110, "Text",
  CellTags->"ParallelGears5"],
Cell[75495, 3049, 384, 10, 70, "Text",
  CellTags->"Parameterize"],
Cell[75882, 3061, 710, 21, 70, "Text",
  CellTags->"Parameters"],
Cell[76595, 3084, 705, 29, 70, "Text",
  CellTags->"ParaRevolute4"],
Cell[77303, 3115, 199, 7, 70, "Text",
  CellTags->"PathSystem"],
Cell[77505, 3124, 1267, 52, 70, "Text",
  CellTags->"Plane"],
Cell[78775, 3178, 727, 29, 70, "Text",
  CellTags->"PlaneToCircle1"],
Cell[79505, 3209, 809, 35, 70, "Text",
  CellTags->"PlaneToPlane3"],
Cell[80317, 3246, 719, 27, 70, "Text",
  CellTags->"Point"],
Cell[81039, 3275, 600, 25, 70, "Text",
  CellTags->"PointAtIntersection3"],
Cell[81642, 3302, 698, 28, 70, "Text",
  CellTags->"PointLabel"],
Cell[82343, 3332, 1347, 50, 70, "Text",
  CellTags->"PointList"],
Cell[83693, 3384, 685, 28, 70, "Text",
  CellTags->"PointOnCircle2"],
Cell[84381, 3414, 701, 28, 70, "Text",
  CellTags->"PointOnCone1"],
Cell[85085, 3444, 612, 25, 70, "Text",
  CellTags->"PointOnCylinder1"],
Cell[85700, 3471, 459, 19, 70, "Text",
  CellTags->"PointOnLine2"],
Cell[86162, 3492, 562, 24, 70, "Text",
  CellTags->"PointOnPlane1"],
Cell[86727, 3518, 486, 20, 70, "Text",
  CellTags->"PointOnPlanes2"],
Cell[87216, 3540, 792, 32, 70, "Text",
  CellTags->"PointOnTorus1"],
Cell[88011, 3574, 381, 16, 70, "Text",
  CellTags->"PointToLineDistance"],
Cell[88395, 3592, 395, 16, 70, "Text",
  CellTags->"PointToLocal"],
Cell[88793, 3610, 428, 16, 70, "Text",
  CellTags->"PointToPlaneDistance"],
Cell[89224, 3628, 335, 11, 70, "Text",
  CellTags->"Predictor"],
Cell[89562, 3641, 702, 26, 70, "Text",
  CellTags->"PrincipalAxes"],
Cell[90267, 3669, 610, 23, 70, "Text",
  CellTags->"ProjectedAngle"],
Cell[90880, 3694, 942, 36, 70, "Text",
  CellTags->"ProjectedAngle1"],
Cell[91825, 3732, 862, 36, 70, "Text",
  CellTags->"ProjectOnLine"],
Cell[92690, 3770, 911, 36, 70, "Text",
  CellTags->"ProjectOnPlane"],
Cell[93604, 3808, 341, 11, 54, "Text",
  CellTags->"Quadratic"],
Cell[93948, 3821, 333, 11, 53, "Text",
  CellTags->"Quartic"],
Cell[94284, 3834, 795, 32, 92, "Text",
  CellTags->"RackAndPinion4"],
Cell[95082, 3868, 1504, 54, 167, "Text",
  CellTags->"RackAndPinion5"],
Cell[96589, 3924, 1027, 41, 114, "Text",
  CellTags->"Reaction"],
Cell[97619, 3967, 417, 14, 53, "Text",
  CellTags->"ReferenceDirection"],
Cell[98039, 3983, 500, 16, 92, "Text",
  CellTags->"Relative"],
Cell[98542, 4001, 590, 26, 53, "Text",
  CellTags->"RelativeAngle1"],
Cell[99135, 4029, 632, 26, 72, "Text",
  CellTags->"RelativeDistance1"],
Cell[99770, 4057, 402, 16, 53, "Text",
  CellTags->"RelativeVelocity"],
Cell[100175, 4075, 701, 32, 53, "Text",
  CellTags->"RelativeX1"],
Cell[100879, 4109, 701, 32, 53, "Text",
  CellTags->"RelativeY1"],
Cell[101583, 4143, 701, 32, 53, "Text",
  CellTags->"RelativeZ1"],
Cell[102287, 4177, 906, 24, 172, "Text",
  CellTags->"RequiredEquations"],
Cell[103196, 4203, 620, 26, 72, "Text",
  CellTags->"Revolute5"],
Cell[103819, 4231, 788, 35, 74, "Text",
  CellTags->"Revolve"],
Cell[104610, 4268, 450, 18, 53, "Text",
  CellTags->"Rotation"],
Cell[105063, 4288, 816, 32, 91, "Text",
  CellTags->"RotationLock3"],
Cell[105882, 4322, 275, 10, 53, "Text",
  CellTags->"RotationMatrix"],
Cell[106160, 4334, 353, 13, 54, "Text",
  CellTags->"SaveMech"],
Cell[106516, 4349, 220, 7, 54, "Text",
  CellTags->"SensitivitySystem"],
Cell[106739, 4358, 552, 18, 93, "Text",
  CellTags->"SetBodies"],
Cell[107294, 4378, 757, 18, 134, "Text",
  CellTags->"SetConstraints"],
Cell[108054, 4398, 602, 26, 53, "Text",
  CellTags->"SetCouple"],
Cell[108659, 4426, 722, 24, 112, "Text",
  CellTags->"SetFree"],
Cell[109384, 4452, 551, 15, 93, "Text",
  CellTags->"SetGuess"],
Cell[109938, 4469, 744, 20, 133, "Text",
  CellTags->"SetLoads"],
Cell[110685, 4491, 506, 18, 74, "Text",
  CellTags->"SetParameters"],
Cell[111194, 4511, 821, 25, 133, "Text",
  CellTags->"SetPath"],
Cell[112018, 4538, 520, 17, 94, "Text",
  CellTags->"SetSensitivity"],
Cell[112541, 4557, 649, 21, 113, "Text",
  CellTags->"SetSymbols"],
Cell[113193, 4580, 974, 47, 54, "Text",
  CellTags->"SkewSym"],
Cell[114170, 4629, 546, 22, 74, "Text",
  CellTags->"Solution"],
Cell[114719, 4653, 599, 22, 74, "Text",
  CellTags->"SolveCouple"],
Cell[115321, 4677, 987, 36, 113, "Text",
  CellTags->"SolveFree"],
Cell[116311, 4715, 1037, 36, 134, "Text",
  CellTags->"SolveMech"],
Cell[117351, 4753, 683, 26, 93, "Text",
  CellTags->"SolvePath"],
Cell[118037, 4781, 652, 22, 94, "Text",
  CellTags->"SolveSensitivity"],
Cell[118692, 4805, 777, 32, 92, "Text",
  CellTags->"Sphere"],
Cell[119472, 4839, 436, 19, 53, "Text",
  CellTags->"Spherical3"],
Cell[119911, 4860, 711, 30, 74, "Text",
  CellTags->"SphericalToXYZ"],
Cell[120625, 4892, 348, 13, 53, "Text",
  CellTags->"SplineFit"],
Cell[120976, 4907, 480, 17, 73, "Text",
  CellTags->"SplineFunction"],
Cell[121459, 4926, 1177, 50, 113, "Text",
  CellTags->"StageSwitch"],
Cell[122639, 4978, 422, 13, 73, "Text",
  CellTags->"Static"],
Cell[123064, 4993, 647, 25, 74, "Text",
  CellTags->"Step"],
Cell[123714, 5020, 380, 12, 72, "Text",
  CellTags->"StepMech"],
Cell[124097, 5034, 255, 8, 53, "Text",
  CellTags->"StepSize"],
Cell[124355, 5044, 347, 10, 72, "Text",
  CellTags->"SymbolBasis"],
Cell[124705, 5056, 208, 7, 34, "Text",
  CellTags->"SysBody"],
Cell[124916, 5065, 224, 7, 53, "Text",
  CellTags->"SysCon"],
Cell[125143, 5074, 214, 7, 34, "Text",
  CellTags->"SysLoad"],
Cell[125360, 5083, 326, 10, 73, "Text",
  CellTags->"SysPlot"],
Cell[125689, 5095, 400, 11, 73, "Text",
  CellTags->"TangentConstraint"],
Cell[126092, 5108, 410, 13, 74, "Text",
  CellTags->"Time"],
Cell[126505, 5123, 818, 31, 93, "Text",
  CellTags->"TimeInterpolate"],
Cell[127326, 5156, 1823, 81, 154, "Text",
  CellTags->"TimeSwitch"],
Cell[129152, 5239, 809, 32, 92, "Text",
  CellTags->"Torus"],
Cell[129964, 5273, 465, 16, 72, "Text",
  CellTags->"Translate5"],
Cell[130432, 5291, 903, 38, 92, "Text",
  CellTags->"TwoPulleys4"],
Cell[131338, 5331, 1122, 45, 110, "Text",
  CellTags->"TwoPulleys5"],
Cell[132463, 5378, 419, 16, 54, "Text",
  CellTags->"Type"],
Cell[132885, 5396, 260, 10, 34, "Text",
  CellTags->"Unit"],
Cell[133148, 5408, 1065, 45, 93, "Text",
  CellTags->"Vector"],
Cell[134216, 5455, 648, 22, 93, "Text",
  CellTags->"Velocity"],
Cell[134867, 5479, 363, 12, 53, "Text",
  CellTags->"VelocityTerms"],
Cell[135233, 5493, 1037, 47, 73, "Text",
  CellTags->"Vertex"],
Cell[136273, 5542, 417, 12, 74, "Text",
  CellTags->"Virtual"],
Cell[136693, 5556, 533, 24, 54, "Text",
  CellTags->"Wheel"],
Cell[137229, 5582, 302, 10, 53, "Text",
  CellTags->"XYZ"],
Cell[137534, 5594, 687, 29, 74, "Text",
  CellTags->"XYZToCylindrical"],
Cell[138224, 5625, 688, 29, 74, "Text",
  CellTags->"XYZToSpherical"],
Cell[138915, 5656, 302, 10, 53, "Text",
  CellTags->"YZX"],
Cell[139220, 5668, 302, 10, 53, "Text",
  CellTags->"ZXY"],
Cell[139525, 5680, 247, 7, 54, "Text",
  CellTags->"$MechPostIterate"],
Cell[139775, 5689, 225, 6, 53, "Text",
  CellTags->"$MechPreSolve"],
Cell[140003, 5697, 581, 18, 94, "Text",
  CellTags->"$MechPrimeRules"],
Cell[140587, 5717, 356, 10, 74, "Text",
  CellTags->"$MechProcessFunction"],
Cell[140946, 5729, 570, 18, 74, "Text",
  CellTags->"$MechTimeRules"],
Cell[141519, 5749, 400, 9, 92, "Text",
  CellTags->"$MechUseEulerMassTerm"],
Cell[141922, 5760, 284, 7, 72, "Text",
  CellTags->"$MechVariables"],
Cell[142209, 5769, 200, 7, 34, "Text",
  CellTags->"$MechVersion"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

