(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    447955,      16159]*)
(*NotebookOutlinePosition[    448899,      16191]*)
(*  CellTagsIndexPosition[    448855,      16187]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "Generalized Coordinate Modeling in ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"]
}], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The Generalized Coordinate Package for ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " is an extension package that allows some or all of the bodies in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model to be represented by generalized coordinates. The primary utility \
of this technique is to increase the performance of multi-body models by \
reducing the total number of symbolic coordinates used.\n\nStandard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " models are made up of one or more independent bodies, each of which are \
represented by three, four, or seven Cartesian and Euler coordinates. While \
this representation is very general, and allows bodies to be interconnected \
in an unrestricted manner, it inevitably causes many more symbolic \
coordinates to be included in the model than are required to represent its \
motion.\n\nFor example, a 3D body which is attached to the ground with a \
revolute joint (a ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint in ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") would normally be represented by seven coordinates. While all these \
coordinates are necessary to completely define the location and orientation \
of the body, we are really concerned with only one of them; the single \
coordinate representing rotation about the revolute axis. The other \
coordinates may be just excess baggage, conveying trivial, constant \
information that we do not need. The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " Generalized Coordinate Package allows such a body to be represented by a \
single coordinate, supplied by the user.\n\nNote that there are pros and cons \
to using generalized coordinates. Some information, such as constraint \
reaction forces, are lost when a constraint is eliminated from the model with \
generalized coordinates. This notebook contains general guidelines to help \
determine when to use generalized coordinates, and when to use ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s standard representation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Installation and Loading"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section covers the installation of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " Generalized Coordinate Package on various computer systems and loading \
the packages into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["File Locations"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " Generalized Coordinate Package is contained in three standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package files. These files should be placed in the same directory as the \
rest of the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " files. Exact file locations will vary on different computer systems, but \
all will have names and locations similar to the following:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
MathematicaFolder/AddOns/Applications/Mech/GenCrd2D.m
                                           GenCrd3D.m
                                           GenCrdCommon.m\
\>", "Special3",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell["A typical UNIX installation.", "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell["\<\
With the package files so placed, no other installation steps are required.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Loading the Packages", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The Generalized Coordinate packages are loaded into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the same manner as a standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package; with a ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement. The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages may be loaded before loading ",
  StyleBox["GenCrd2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" or ",
    FontFamily->"Times"],
  StyleBox["GenCrd3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", otherwise they will be autoloaded.",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Needs[\"Mech`GenCrd3D`\"]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " loads all necessary components of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages that are not already loaded, and then loads the Generalized \
Coordinate packages."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Loading the Generalized Coordinate packages."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["GenCrd2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`GenCrd2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Like the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages, the Generalized Coordinate packages are not intended to be \
loaded twice. Thus, it is recommended that ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " be used to load the packages because ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will not read a package if it has already been read.\n\nThe ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command will remove all ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages from a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, including the Generalized Coordinate packages."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " standard and auxiliary packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "After executing ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " nothing remains of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " session except whatever definitions the user had made in the ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context, and a few undefined symbols that ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " creates in the ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context. The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages can be reloaded with ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " after executing ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Generalized Coordinate Constraints"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "The generalized coordinate constraints are not, in fact, constraints at \
all. Each generalized coordinate constraint is named like a standard \
constraint, takes approximately the same arguments as a standard constraint, \
returns a ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint object that is passed to ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and generally appears in a mechanism model in exactly the same way as \
the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraints. The difference between them is best illustrated by an \
example.\n\nConsider a standard ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model containing a ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint that models a translational joint between body 2 and the \
ground. The presence of the constraint object causes ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to do two things: three degrees of freedom (the symbols ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") are added to the model to represent body 2, and two degrees of freedom \
are removed from the model by the two constraint equations in the constraint. \
The net effect, then, is to add one degree of freedom to the model that must \
be constrained by some other constraint. If the ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is replaced with a ",
  StyleBox["GenTranslate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does only one thing: one degree of freedom is added to the model by \
adding a single symbol to the dependent variable list. The name of the symbol \
is specified in the ",
  StyleBox["GenTranslate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint object.\n\nBody 2, which was represented by three symbols, is \
now represented by only one. All of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s other constraint, load, output, and graphics functions can recognize \
and access body 2 just as if it were a standard body; the only difference is \
that the symbolic representation of all geometry on the body is a function of \
just one symbol, not three.\n\nNote that generalized coordinate constraints \
cannot be used within the multistage constraint objects, ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is simply because including them in a multistage constraint would \
have no effect on the model; the generalized coordinate constraints contain \
no constraint equations, so there is nothing to switch on and off."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"There are only two 2D generalized coordinate constraints. The wide variety \
of standard 2D constraints cannot be meaningfully converted to generalized \
constraints; only constraints which attach exactly two bodies together such \
that only one degree of freedom remains between them are generally useful.\n\n\
The arguments given to the generalized coordinate constraints are of the same \
form as the arguments given to the standard constraints. However, each of \
these constraints requires an additional argument to specify the name of, and \
an initial guess for, the new symbol that represents the added degree of \
freedom."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenRevolute2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by a single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of rotational freedom.  The origins of the two axes \
are constrained to be coincident, and the counterclockwise angle from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["GenTranslate2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by a single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of translational freedom. The two axes are \
constrained to be colinear, and the distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The 2D generalized coordinate constraints."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Note that there is a clear distinction between a master and slave bodies. \
The slave body is the one that will be represented by the single new \
generalized coordinate. Thus, the slave body cannot be the ground body. The \
master body may be the ground body, another body represented by standard \
coordinates, or another body represented by generalized coordinates that was \
created with another generalized constraint. The master-slave relationship \
cannot be circular; the master-slave chain must originate from the ground, or \
from a standard body. Also, a slave body cannot be a slave to more than one \
master body.\n\nAnother restriction on the arguments to generalized \
coordinate constraints is that the axis objects, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", must each be defined entirely on a single body. While standard \
constraints allow axis objects to span multiple bodies (such as a line \
originating on one body and ending on another) generalized coordinate \
constraints do not."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The following example shows a standard constraint and a generalized \
coordinate constraint that could be used to perform exactly the same function \
in a model. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are two functionally equivalent constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Needs["\<Mech`GenCrd2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(body2 = 2; \)\), 
    \(Translate2[2, \n\tLine[body2, {0, 0}, {0, 1}], \n\t
      Line[ground, {0, 1}, {0, 2}]]\), 
    \(GenTranslate2[2, \n\tLine[body2, {0, 0}, {0, 1}], \n\t
      Line[ground, {0, 1}, {0, 2}], {newsym, 0.0}]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["Translate2", "<>"]\)], "Output"],

Cell[BoxData[
    \(SysCon["GenTranslate2", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"There are only four 3D generalized coordinate constraints. The wide variety \
of standard 3D constraints cannot be meaningfully converted to generalized \
constraints; only constraints which attach exactly two bodies together such \
that only one or two degrees of freedom remain between them are generally \
useful.\n\nThe arguments given to the generalized coordinate constraints are \
of the same form as the arguments given to the standard constraints. However, \
each of these constraints requires additional arguments to specify the names \
of, and an initial guesses for, the new symbol or symbols that represent the \
added degrees of freedom."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenCylindrical4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body represented by \
two generalized coordinates ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of rotational freedom and one degree of \
translational freedom. The two axes are constrained to be colinear and the \
distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", is represented by ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". The angle from the projection of the reference direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the right-hand sense, is represented by ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["GenOrthoRevolute4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body represented by \
two generalized coordinates ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with two degrees of rotational freedom.  The origins of the two axes \
are constrained to be coincident, and the axes are constrained to be \
orthogonal.  The symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " represents the angle between ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and the reference direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " represents the angle between ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and the reference direction of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["GenRevolute5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body represented by a \
single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of rotational freedom. The two axes are constrained \
to be parallel and their origins are constrained to be coincident. The angle \
from the projection of the reference direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the right-hand sense, is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["GenTranslate5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body represented by a \
single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of translational freedom.  The two axes are \
constrained to be colinear, and the distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".  The projections of the reference directions of the two axes are \
constrained to be parallel."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The 3D generalized coordinate constraints."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Note that there is a clear distinction between a master and slave bodies. \
The slave body is the one that will be represented by the single new \
generalized coordinate. Thus, the slave body cannot be the ground body. The \
master body may be the ground body, another body represented by standard \
coordinates, or another body represented by generalized coordinates that was \
created with another generalized constraint. The master-slave relationship \
cannot be circular; the master-slave chain must eventually lead back to the \
ground, or to a standard body.\n\nAnother restriction on the arguments to \
generalized coordinate constraints is that the axis objects, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", must each be defined entirely on a single body. While standard \
constraints allow axis objects to span multiple bodies (such as a line \
originating on one body and ending on another) generalized coordinate \
constraints do not."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The following example shows a standard constraint and a generalized \
coordinate constraint that could be used to perform exactly the same function \
in a model. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are two functionally equivalent constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Needs["\<Mech`GenCrd3D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(body2 = 2; \)\), 
    \(Revolute5[2, \n\tLine[body2, {0, 0, 0}, {0, 1, 0}], \n\t
      Line[ground, {0, 1, 1}, {0, 2, 1}]]\), 
    \(GenRevolute5[2, \n\tLine[body2, {0, 0, 0}, {0, 1, 0}], \n\t
      Line[ground, {0, 1, 1}, {0, 2, 1}], {newsym, 0.0}]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["Revolute5", "<>"]\)], "Output"],

Cell[BoxData[
    \(SysCon["GenRevolute5", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["User-Defined Generalized Constraint"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If the selection of predefined generalized coordinate constraints is not \
sufficient, the ",
  StyleBox["GenConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function can be used to create constraints with any number of generalized \
coordinates representing any geometric relationship between two bodies that \
can be written algebraically."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenConstraint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, rotation, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object which introduces a slave body represented by \
generalized coordinates into the model. A point on the slave body, ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", is constrained to be coincident with a point on the master, ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". The angular orientation of the slave with respect to the master is \
specified by ",
  StyleBox["rotation",
    FontSlant->"Italic"],
  ". ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", are generalized coordinate symbols and their associated initial guesses \
which are added to the model."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The user-defined generalized coordinate constraint."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["rotation",
    FontSlant->"Italic"],
  " is a counterclockwise angle. In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["rotation",
    FontSlant->"Italic"],
  " is specified in the ",
  StyleBox["{",
    FontFamily->"Courier"],
  StyleBox["ang, axis",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier"],
  " format, and it can be a single rotation or a sequence of rotations of the \
form used by ",
  StyleBox["RotationLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nThe trick to creating a valid constraint with ",
  StyleBox["GenConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is to make the ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  " and ",
  StyleBox["rotation",
    FontSlant->"Italic"],
  " arguments symbolic functions of the generalized coordinate symbols ",
  StyleBox["symi",
    FontSlant->"Italic"],
  ". For example, the following constraint object would introduce a slave \
body that is constrained so that its origin lies on a parabola in the ",
  StyleBox["Y-Z",
    FontSlant->"Italic"],
  " plane, and its rotation is about the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis only. The position of the body along the parabola is represented by \
",
  StyleBox["tau",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the rotation angle of the body about the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis is represented by ",
  StyleBox["phi",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a ",
  StyleBox["GenConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " example."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
GenConstraint[1, Point[body2, {0, 0, 0}],
                 Point[ground, {0, tau, tau^2}],
                 {phi, {0, 0, 1}},
                 {tau, 0.0}, {phi, 0.0}] \
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["GenConstraint", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["KillMech[]", "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Four-Bar Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of generalized coordinate constraints in a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model, a 2D model of a simple four-bar mechanism is developed. The model \
consists of three moving bars and one stationary bar, the ground. This same \
model is also used in Section 8.3 and Chapter 9 of the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " manual, so it is presented very briefly here."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This loads the Generalized Coordinate packages and defines some useful \
constants."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`GenCrd2D`\>"]\), 
    \(Off[General::"\<spell1\>"]\), 
    \(\(X = {1, 0}; \)\), 
    \(\(Y = {0, 1}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the four-bar mechanism, shown with the locus of a moving point. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.20833  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.5 0.208333 0.333333 0.208333 [ 
[(-2)] .08333 0 0 2 Msboxa 
[(-1)] .29167 0 0 2 Msboxa 
[(0)] .5 0 0 2 Msboxa 
[(1)] .70833 0 0 2 Msboxa 
[(2)] .91667 0 0 2 Msboxa 
[(-1)] -0.0125 .125 1 0 Msboxa 
[(0)] -0.0125 .33333 1 0 Msboxa 
[(1)] -0.0125 .54167 1 0 Msboxa 
[(2)] -0.0125 .75 1 0 Msboxa 
[(3)] -0.0125 .95833 1 0 Msboxa 
[(4)] -0.0125 1.16667 1 0 Msboxa 
[ -0.001 -0.001 0 0 ] 
[ 1.001 1.20933 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.08333 0 m 
.08333 .00625 L 
s 
P 
[(-2)] .08333 0 0 2 Mshowa 
p 
.002 w 
.29167 0 m 
.29167 .00625 L 
s 
P 
[(-1)] .29167 0 0 2 Mshowa 
p 
.002 w 
.5 0 m 
.5 .00625 L 
s 
P 
[(0)] .5 0 0 2 Mshowa 
p 
.002 w 
.70833 0 m 
.70833 .00625 L 
s 
P 
[(1)] .70833 0 0 2 Mshowa 
p 
.002 w 
.91667 0 m 
.91667 .00625 L 
s 
P 
[(2)] .91667 0 0 2 Mshowa 
p 
.001 w 
.125 0 m 
.125 .00375 L 
s 
P 
p 
.001 w 
.16667 0 m 
.16667 .00375 L 
s 
P 
p 
.001 w 
.20833 0 m 
.20833 .00375 L 
s 
P 
p 
.001 w 
.25 0 m 
.25 .00375 L 
s 
P 
p 
.001 w 
.33333 0 m 
.33333 .00375 L 
s 
P 
p 
.001 w 
.375 0 m 
.375 .00375 L 
s 
P 
p 
.001 w 
.41667 0 m 
.41667 .00375 L 
s 
P 
p 
.001 w 
.45833 0 m 
.45833 .00375 L 
s 
P 
p 
.001 w 
.54167 0 m 
.54167 .00375 L 
s 
P 
p 
.001 w 
.58333 0 m 
.58333 .00375 L 
s 
P 
p 
.001 w 
.625 0 m 
.625 .00375 L 
s 
P 
p 
.001 w 
.66667 0 m 
.66667 .00375 L 
s 
P 
p 
.001 w 
.75 0 m 
.75 .00375 L 
s 
P 
p 
.001 w 
.79167 0 m 
.79167 .00375 L 
s 
P 
p 
.001 w 
.83333 0 m 
.83333 .00375 L 
s 
P 
p 
.001 w 
.875 0 m 
.875 .00375 L 
s 
P 
p 
.001 w 
.04167 0 m 
.04167 .00375 L 
s 
P 
p 
.001 w 
.95833 0 m 
.95833 .00375 L 
s 
P 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 .125 m 
.00625 .125 L 
s 
P 
[(-1)] -0.0125 .125 1 0 Mshowa 
p 
.002 w 
0 .33333 m 
.00625 .33333 L 
s 
P 
[(0)] -0.0125 .33333 1 0 Mshowa 
p 
.002 w 
0 .54167 m 
.00625 .54167 L 
s 
P 
[(1)] -0.0125 .54167 1 0 Mshowa 
p 
.002 w 
0 .75 m 
.00625 .75 L 
s 
P 
[(2)] -0.0125 .75 1 0 Mshowa 
p 
.002 w 
0 .95833 m 
.00625 .95833 L 
s 
P 
[(3)] -0.0125 .95833 1 0 Mshowa 
p 
.002 w 
0 1.16667 m 
.00625 1.16667 L 
s 
P 
[(4)] -0.0125 1.16667 1 0 Mshowa 
p 
.001 w 
0 .16667 m 
.00375 .16667 L 
s 
P 
p 
.001 w 
0 .20833 m 
.00375 .20833 L 
s 
P 
p 
.001 w 
0 .25 m 
.00375 .25 L 
s 
P 
p 
.001 w 
0 .29167 m 
.00375 .29167 L 
s 
P 
p 
.001 w 
0 .375 m 
.00375 .375 L 
s 
P 
p 
.001 w 
0 .41667 m 
.00375 .41667 L 
s 
P 
p 
.001 w 
0 .45833 m 
.00375 .45833 L 
s 
P 
p 
.001 w 
0 .5 m 
.00375 .5 L 
s 
P 
p 
.001 w 
0 .58333 m 
.00375 .58333 L 
s 
P 
p 
.001 w 
0 .625 m 
.00375 .625 L 
s 
P 
p 
.001 w 
0 .66667 m 
.00375 .66667 L 
s 
P 
p 
.001 w 
0 .70833 m 
.00375 .70833 L 
s 
P 
p 
.001 w 
0 .79167 m 
.00375 .79167 L 
s 
P 
p 
.001 w 
0 .83333 m 
.00375 .83333 L 
s 
P 
p 
.001 w 
0 .875 m 
.00375 .875 L 
s 
P 
p 
.001 w 
0 .91667 m 
.00375 .91667 L 
s 
P 
p 
.001 w 
0 1 m 
.00375 1 L 
s 
P 
p 
.001 w 
0 1.04167 m 
.00375 1.04167 L 
s 
P 
p 
.001 w 
0 1.08333 m 
.00375 1.08333 L 
s 
P 
p 
.001 w 
0 1.125 m 
.00375 1.125 L 
s 
P 
p 
.001 w 
0 .08333 m 
.00375 .08333 L 
s 
P 
p 
.001 w 
0 .04167 m 
.00375 .04167 L 
s 
P 
p 
.001 w 
0 0 m 
.00375 0 L 
s 
P 
p 
.001 w 
0 1.20833 m 
.00375 1.20833 L 
s 
P 
p 
.002 w 
0 0 m 
0 1.20833 L 
s 
P 
P 
p 
p 
.002 w 
.08333 1.20208 m 
.08333 1.20833 L 
s 
P 
p 
.002 w 
.29167 1.20208 m 
.29167 1.20833 L 
s 
P 
p 
.002 w 
.5 1.20208 m 
.5 1.20833 L 
s 
P 
p 
.002 w 
.70833 1.20208 m 
.70833 1.20833 L 
s 
P 
p 
.002 w 
.91667 1.20208 m 
.91667 1.20833 L 
s 
P 
p 
.001 w 
.125 1.20458 m 
.125 1.20833 L 
s 
P 
p 
.001 w 
.16667 1.20458 m 
.16667 1.20833 L 
s 
P 
p 
.001 w 
.20833 1.20458 m 
.20833 1.20833 L 
s 
P 
p 
.001 w 
.25 1.20458 m 
.25 1.20833 L 
s 
P 
p 
.001 w 
.33333 1.20458 m 
.33333 1.20833 L 
s 
P 
p 
.001 w 
.375 1.20458 m 
.375 1.20833 L 
s 
P 
p 
.001 w 
.41667 1.20458 m 
.41667 1.20833 L 
s 
P 
p 
.001 w 
.45833 1.20458 m 
.45833 1.20833 L 
s 
P 
p 
.001 w 
.54167 1.20458 m 
.54167 1.20833 L 
s 
P 
p 
.001 w 
.58333 1.20458 m 
.58333 1.20833 L 
s 
P 
p 
.001 w 
.625 1.20458 m 
.625 1.20833 L 
s 
P 
p 
.001 w 
.66667 1.20458 m 
.66667 1.20833 L 
s 
P 
p 
.001 w 
.75 1.20458 m 
.75 1.20833 L 
s 
P 
p 
.001 w 
.79167 1.20458 m 
.79167 1.20833 L 
s 
P 
p 
.001 w 
.83333 1.20458 m 
.83333 1.20833 L 
s 
P 
p 
.001 w 
.875 1.20458 m 
.875 1.20833 L 
s 
P 
p 
.001 w 
.04167 1.20458 m 
.04167 1.20833 L 
s 
P 
p 
.001 w 
.95833 1.20458 m 
.95833 1.20833 L 
s 
P 
p 
.002 w 
0 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
.99375 .125 m 
1 .125 L 
s 
P 
p 
.002 w 
.99375 .33333 m 
1 .33333 L 
s 
P 
p 
.002 w 
.99375 .54167 m 
1 .54167 L 
s 
P 
p 
.002 w 
.99375 .75 m 
1 .75 L 
s 
P 
p 
.002 w 
.99375 .95833 m 
1 .95833 L 
s 
P 
p 
.002 w 
.99375 1.16667 m 
1 1.16667 L 
s 
P 
p 
.001 w 
.99625 .16667 m 
1 .16667 L 
s 
P 
p 
.001 w 
.99625 .20833 m 
1 .20833 L 
s 
P 
p 
.001 w 
.99625 .25 m 
1 .25 L 
s 
P 
p 
.001 w 
.99625 .29167 m 
1 .29167 L 
s 
P 
p 
.001 w 
.99625 .375 m 
1 .375 L 
s 
P 
p 
.001 w 
.99625 .41667 m 
1 .41667 L 
s 
P 
p 
.001 w 
.99625 .45833 m 
1 .45833 L 
s 
P 
p 
.001 w 
.99625 .5 m 
1 .5 L 
s 
P 
p 
.001 w 
.99625 .58333 m 
1 .58333 L 
s 
P 
p 
.001 w 
.99625 .625 m 
1 .625 L 
s 
P 
p 
.001 w 
.99625 .66667 m 
1 .66667 L 
s 
P 
p 
.001 w 
.99625 .70833 m 
1 .70833 L 
s 
P 
p 
.001 w 
.99625 .79167 m 
1 .79167 L 
s 
P 
p 
.001 w 
.99625 .83333 m 
1 .83333 L 
s 
P 
p 
.001 w 
.99625 .875 m 
1 .875 L 
s 
P 
p 
.001 w 
.99625 .91667 m 
1 .91667 L 
s 
P 
p 
.001 w 
.99625 1 m 
1 1 L 
s 
P 
p 
.001 w 
.99625 1.04167 m 
1 1.04167 L 
s 
P 
p 
.001 w 
.99625 1.08333 m 
1 1.08333 L 
s 
P 
p 
.001 w 
.99625 1.125 m 
1 1.125 L 
s 
P 
p 
.001 w 
.99625 .08333 m 
1 .08333 L 
s 
P 
p 
.001 w 
.99625 .04167 m 
1 .04167 L 
s 
P 
p 
.001 w 
.99625 0 m 
1 0 L 
s 
P 
p 
.001 w 
.99625 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
1 0 m 
1 1.20833 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 1.20833 L 
0 1.20833 L 
closepath 
clip 
newpath 
p 
p 
p 
.025 w 
.08333 .95833 Mdot 
.015 w 
.29167 .02083 m 
.5 .33333 L 
.70833 .02083 L 
.08333 .02083 L 
.08333 .95833 L 
s 
P 
p 
1 0 0 r 
p 
.015 w 
.55208 .24312 m 
.70833 .33333 L 
s 
.70833 .33333 m 
.55208 .42354 L 
s 
P 
.015 w 
newpath 
.5 .33333 .10417 0 365.73 arc 
s 
P 
p 
0 0 1 r 
p 
.015 w 
.08333 .95833 m 
.70833 .95833 L 
s 
P 
P 
p 
p 
.025 w 
.70833 .33333 Mdot 
.70833 .95833 Mdot 
.91667 .75 Mdot 
P 
0 1 0 r 
p 
.70833 .33333 m 
.70833 .95833 L 
.91667 .75 L 
F 
P 
P 
P 
.004 w 
.91667 .75 m 
.91104 .81206 L 
.8952 .86278 L 
.87212 .89517 L 
.84594 .9026 L 
.82031 .87992 L 
.79638 .8262 L 
.77265 .74866 L 
.7489 .66256 L 
.72906 .58351 L 
.7183 .5204 L 
.71923 .47588 L 
.73138 .44978 L 
.75254 .44118 L 
.77988 .44904 L 
.81056 .47222 L 
.84186 .50939 L 
.871 .55879 L 
.89504 .61796 L 
.91104 .68331 L 
.91667 .75 L 
s 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{220, 266},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L00012Q000`40O003h00Og7oo003LOol00=ao
o`00g7oo000OOol3000WOol5000UOol00`00Oomoo`0UOol5000WOol3000BOol001moo`03001oogoo
02Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001oogoo02Moo`03001oogoo019oo`006Woo0`00
0goo00<007ooOol08Woo0`000goo00<007ooOol097oo00<007oo0000:7oo00<007ooOol0:7oo00<0
07ooOol04Goo000POol00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Ool0000XOol00`00Oomoo`0X
Ool00`00Oomoo`0AOol001moo`03001oo`0002Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001o
ogoo02Moo`03001oo`00019oo`0087oo00<007ooOol09goo0P009goo00<007ooOol09Woo0P00:Woo
00<007ooOol04Goo003LOol00=aoo`00g7oo003LOol00=aoo`00g7oo003LOol00=aoo`003Gooc@00
0Woo000=Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool10001
Ool1Ool000eoo`03001oogoo00ioo`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo02Qoo`03
001oogoo02Moo`03001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=
Ool00`00Oomoo`0=Oon3000iOol10001Ool1Ool000eoo`03001oogoo00eooh<003Uoo`40005oo`5o
o`003Goo00<007ooOol03GooP`00>Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000YOol4001>
Ool4000jOol10001Ool1Ool000eoo`03001oogoo00eoo`<002Yoo`<004ioo`<003]oo`40005oo`5o
o`003Goo0P003Woo0`00:Woo1000C7oo1000>goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000[
Ool4001:Ool4000lOol10001Ool1Ool000eoo`03001oogoo00eoo`<002aoo`<004Yoo`<003eoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00;7oo1000B7oo1000?Goo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3000]Ool40016Ool4000nOol10001Ool1Ool000eoo`03001oogoo00eoo`<002ioo`<0
04Ioo`<003moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00;Woo1000A7oo1000?goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3000_Ool40012Ool40010Ool10001Ool1Ool000eoo`03001oogoo
00eoo`<0031oo`<0049oo`<0045oo`40005oo`5oo`003Goo0P003Woo0`00<7oo1000@7oo1000@Goo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000aOol4000nOol40012Ool10001Ool1Ool000eoo`03
001oogoo00eoo`<0039oo`<003ioo`<004=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00<Woo
1000?7oo1000@goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000cOol3000kOol40014Ool10001
Ool1Ool000eoo`03001oogoo00eoo`<003=oo`@003Yoo`<004Eoo`40005oo`5oo`001Woo1@000Woo
00<007ooOol03Goo0`00=7oo1000>7oo1000AGoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool3000eOol3000gOol40016Ool10001Ool1Ool0009oo`<000=oo`03001oogoo009oo`80
00ioo`<003Eoo`@003Ioo`<004Ioo`80009oo`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00
=Woo1000=7oo1000Agoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3000gOol3
000cOol40018Ool10001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<003Moo`@0039oo`<004Uo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00>7oo1000<7oo1000BGoo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3000iOol3000_Ool4001:Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003Uo
o`@002ioo`<004]oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00>Woo1000;7oo1000Bgoo0@00
0Goo0Goo000=Ool00`00Oomoo`0=Ool3000kOol3000[Ool4001<Ool10001Ool1Ool000eoo`8000io
o`<003]oo`@002Yoo`<004eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?7oo1000:7oo1000
CGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000mOol3000WOol4001>Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<003eoo`@002Eoo`@004moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
?Woo100097oo0`00D7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol3000SOol4001@Ool1
0001Ool1Ool000eoo`03001oogoo00eoo`<003moo`@0025oo`@0055oo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00@7oo100087oo0`00DWoo0@000Goo0Goo000=Ool2000>Ool30011Ool3000OOol4
001BOol10001Ool1Ool000eoo`03001oogoo00eoo`<0045oo`@001eoo`@005=oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00@Woo100077oo0`00E7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0013Ool30009Ool8O00:Ool4001DOol10001Ool1Ool000eoo`03001oogoo00eoo`<004=oo`@000=o
oa5l00Eoo`@005Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00A7oo100000=oog`0O0004W`0
0goo0`00EWoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30015Ool20009O006Ool:O003001FOol1
0001Ool1Ool000eoo`03001oogoo00eoo`<004Eoo`03001l07`000Al00ioo`Ml0003001oogoo05Eo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00AGoo1W`04Goo1g`0EWoo0@000Goo0Goo000=Ool2
000>Ool30014Ool5O0000`00Oomoo`0AOol00`00O01l0005O01DOol10001Ool1Ool000eoo`03001o
ogoo00eoo`<004=oo`Al00@0015oo`<000Ql059oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
@Woo17`00Woo0`004Goo0`0000=oog`0O0001W`0DGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0011Ool4O003Ool4000?Ool40002Ool9O01?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0041o
o`Al00Eoo`@000eoo`@000Aoo`Yl04eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?goo17`0
1goo0`003Goo0`001Woo2W`0C7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol4O007Ool4
000;Ool40007Ool4O0000gooO01l0004O01:Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003mo
o`=l00Uoo`@000Uoo`@000Uoo`Al009oo`Il04Qoo`40005oo`5oo`003Goo0P003Woo0`00?Woo17`0
2Woo0`002Goo0`002goo0g`00goo1W`0Agoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000nOol3
O00;Ool40007Ool4000;Ool4O004Ool6O015Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003io
o`=l00aoo`@000Eoo`@000eoo`=l00Ioo`Il04=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
?Woo0g`03Goo0`001Goo0`003Woo0g`01goo1W`0@Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
000mOol4O00=Ool40003Ool4000>Ool3O009Ool6O010Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<003eoo`=l00moo`@00003Ool00000008000moo`=l00]oo`Il03ioo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00?Goo0g`047oo0`0000Aoo`000000011oo`=l00aoo`Ml03aoo`40005oo`5oo`00
27oo00<007ooOol00Woo00<007ooOol03Goo0`00?Goo0g`047oo1`0047oo0g`03Woo1W`0>goo0@00
0Goo0Goo0007Ool00`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00AOol5000AOol3O00@Ool3
O00200000g`0Oomoo`0gOol10001Ool1Ool000Moo`03001oo`0000=oo`8000ioo`<003eoo`=l019o
o`<0019oo`=l015oo`03O0000000008003Qoo`80009oo`001goo00<007oo00000goo00<007ooOol0
3Goo0`00?Goo0g`04Woo0`004Woo0g`047oo0W`00P0000<3h000Ool0>7oo0@000Goo0Goo0007Ool0
0`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00WOol3O00>Ool5O0000`000n1oo`0iOol10001
Ool1Ool000Qoo`03001oogoo009oo`03001oogoo00eoo`<003eoo`=l02Moo`=l00aoo`Il009oo`83
h3Uoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?Goo17`09Woo0g`02Woo1g`00goo0P?P>Goo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000nOol3O00VOol3O008Ool7O005Ool30n0hOol10001
Ool1Ool000eoo`03001oogoo00eoo`<003ioo`=l02Ioo`=l00Moo`Il00Moo`<3h3Qoo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00?Woo0g`09Goo17`01Goo1W`02Goo10?P=goo0@000Goo0Goo000=
Ool2000>Ool3000nOol4O00TOol3O004Ool6O00;Ool40n0gOol10001Ool1Ool000eoo`03001oogoo
00eoo`<003moo`=l02=oo`Al009oo`Ml00aoo`D3h3Ioo`40005oo`5oo`003Goo00<007ooOol03Goo
0`00?goo17`08Woo0g`00Woo1W`03Woo1@?P=Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000o
Ool4O00QOol:O00@Ool60n0eOol10001Ool1Ool000eoo`03001oogoo00eoo`<0041oo`Al01ioo`Yl
019oo`H3h3Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@Goo1G`077oo2G`04goo1`?P=7oo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30012Ool4O00JOol9O00EOol70n0dOol10001Ool1Ool0
00eoo`03001oogoo00eoo`<004=oo`Al01Qoo`Ql01Moo`P3h3=oo`40005oo`5oo`003Goo00<007oo
Ool03Goo0`00A7oo1G`05Goo1g`06Goo20?P<goo0@000Goo0Goo000=Ool2000>Ool30014Ool7O00B
Ool6O00KOol90n0bOol10001Ool1Ool000eoo`03001oogoo00eoo`<004Ioo`Il00ioo`Ql01aoo`T3
h39oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00B7oo27`027oo27`07Woo2P?P<Goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool30019OolFO00OOol:0n0aOol10001Ool1Ool000eoo`03001oogoo
00eoo`<004Yooa5l02=oo`/3h31oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Cgoo2W`09Goo
1`?P1@00;goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol40n0300050n03000/Ool10001
Ool1Ool000eoo`03001oogoo00eoo`<007ioo`@3h0030003h0?P00D3h0=oo`8002Yoo`40005oo`5o
o`003Goo0P003Woo0`00OWoo0`?P00<000?P0n001`?P17oo00<007ooOol09goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001nOol30n000`000n03h0070n05Ool00`00Oomoo`0VOol10001Ool1Ool0
00eoo`03001oogoo00eoo`<007ioo`<3h0030003h0?P00P3h0Eoo`8002Ioo`40005oo`5oo`003Goo
00<007ooOol03Goo0`00OWoo0P?P00<000?P0n002@?P1goo00<007ooOol08goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00:0n07Ool00`00Oomoo`0ROol10001Ool1Ool0
00eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00X3h0Moo`03001oogoo029oo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00OWoo0P?P00<000?P0n002`?P1goo00<007ooOol08Goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00;0n08Ool00`00Oomoo`0POol10001
Ool1Ool000eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00`3h0Qoo`03001oogoo01moo`40
005oo`5oo`003Goo0P003Woo0`00OWoo0P?P00<000?P0n0030?P27oo00<007ooOol07goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00=0n08Ool00`00Oomoo`0NOol10001
Ool1Ool000eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00d3h0Uoo`03001oogoo01eoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo0P?P00<000?P0n003P?P2Goo00<007ooOol077oo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00>0n09Ool00`00Oomoo`0L
Ool10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00l3h0Uoo`03001oogoo
01]oo`40005oo`5oo`001Woo1@000Woo00<007ooOol03Goo0`00OWoo0P?P00<000?P0n003`?P2Goo
00<007ooOol06goo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3001nOol20n00
0`000n03h00@0n09Ool00`00Oomoo`0JOol10001Ool1Ool000Qoo`03001oogoo009oo`8000ioo`<0
07ioo`<3h0030003h0?P00l3h0Yoo`03001oogoo01Qoo`80009oo`0027oo00<007ooOol00Woo00<0
07ooOol03Goo0`00OWoo0`?P00<000?P0n0040?P2Goo00<007ooOol06Goo0@000Goo0Goo0008Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool3001nOol30n000`000n03h00@0n0:Ool00`00Oomoo`0HOol1
0001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<007ioo`<3h0030003h0?P0143h0Uoo`03001o
ogoo01Qoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo0`?P00<000?P0n004@?P2Woo00<0
07ooOol05goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol30n000`000n03h00B0n09Ool0
0`00Oomoo`0GOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`@3h0030003h0?P0143h0Yo
o`03001oogoo01Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo10?P00<000?P0n004P?P
2Goo00<007ooOol05Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol40n000`000n03h00B
0n0:Ool00`00Oomoo`0EOol10001Ool1Ool000eoo`8000ioo`<007ioo`@3h0030003h0?P01<3h0Uo
o`03001oogoo01Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo10?P00<000?P0n004`?P
2Goo00<007ooOol05Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol40n000`000n03h00D
0n09Ool00`00Oomoo`0DOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`D3h0030003h0?P
01<3h0Uoo`03001oogoo01Aoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo1@?P00<000?P
0n0050?P2Goo00<007ooOol04goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol50n000`00
0n03h00D0n09Ool00`00Oomoo`0COol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`D3h003
0003h0?P01D3h0Uoo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo1P?P
00<000?P0n0050?P2Goo00<007ooOol04Woo0@000Goo0Goo000=Ool2000>Ool3001nOol60n000`00
0n03h00E0n08Ool00`00Oomoo`0BOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`H3h003
0003h0?P01D3h0Qoo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo1P?P
00<000?P0n005P?P27oo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol7
0n000`000n03h00E0n08Ool00`00Oomoo`0AOol10001Ool1Ool000eoo`03001oogoo00eoo`<007io
o`L3h0030003h0?P01H3h0Moo`03001oogoo015oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
OWoo1`?P00<000?P0n005P?P1goo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
001nOol70n000`000n03h00G0n07Ool00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<007ioo`P3h0030003h0?P01H3h0Moo`03001oogoo011oo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo20?P00<000?P0n005`?P1Woo00<007ooOol047oo0@000Goo0Goo000=Ool2000>Ool3
001nOol80n000`000n03h00G0n06Ool00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<007ioo`T3h0030003h0?P01L3h0Ioo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo2@?P00<000?P0n005`?P1Woo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001nOol90n000`000n03h00H0n05Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001o
ogoo00eoo`<007ioo`T3h0030003h0?P01P3h0Eoo`03001oogoo00moo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00OWoo2P?P00<000?P0n0060?P17oo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001nOol:0n000`000n03h00H0n04Ool00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<007ioo`X3h0030003h0?P01T3h0=oo`03001oogoo00moo`40005oo`5oo`00
3Goo0P003Woo0`00OWoo2`?P00<000?P0n0060?P0goo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001nOol;0n000`000n03h00I0n02Ool00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<007ioo`/3h0030003h0?P01T3h09oo`03001oogoo00moo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo30?P00<000?P0n006@?P0Woo00<007ooOol03Woo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOol<0n000`000n03h00I0n02Ool00`00Oomoo`0>Ool10001Ool1
Ool000eoo`03001oogoo00eoo`<007ioo``3h0030003h0?P01X3h003Ool007oo00moo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00OWoo30?P00<000?P0n006P?P00=oo`00Ool03goo0@000Goo0Goo
0007Ool30003Ool00`00Oomoo`0=Ool3001nOol=0n000`000n03h00J0n000`00Oomoo`0>Ool10001
Ool1Ool000Moo`03001oogoo00=oo`03001oogoo00eoo`<007ioo`d3h0030003h0?P01X3h003001o
ogoo00ioo`40005oo`5oo`0027oo00<007ooOol00Woo0P003Woo0`00OWoo3@?P00<000?P0n006P?P
0P003Woo0P000Woo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3001nOol>0n000`000n03h00H
0n03000?Ool10001Ool1Ool000Moo`03001oo`0000=oo`03001oogoo00eoo`<007ioo`h3h0030003
h0?P01L3h003Ool00000011oo`40005oo`5oo`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00
OWoo3P?P00<000?P0n005P?P0goo00<007ooOol03Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
001nOol?0n000`000n03h00D0n04Ool00`00Oomoo`0>Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<007ioo`l3h0030003h0?P01<3h0Eoo`03001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo3`?P00<000?P0n004P?P1Goo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001nOol?0n000`000n03h00A0n06Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`8000io
o`<007iooa03h0030003h0?P00l3h0Moo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo40?P00<000?P0n003P?P27oo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001nOol@0n000`000n03h00=0n09Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001o
ogoo00eoo`<007iooa43h0030003h0?P00/3h0Yoo`03001oogoo00moo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00OWoo4@?P00<000?P0n002P?P2goo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001nOolA0n000`000n03h0090n0<Ool00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<007iooa83h0030003h0?P00L3h0aoo`03001oogoo011oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo4P?P00<000?P0n001P?P3Goo00<007ooOol047oo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOolB0n000`000n03h0050n0>Ool00`00Oomoo`0@Ool10001Ool1
Ool000eoo`8000ioo`<007iooa<3h0030003h0?P00<3h0moo`03001oogoo011oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo4`?P00<000?P0n000P?P3goo00<007ooOol04Goo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOolD0n000`000n03h00@Ool00`00Oomoo`0AOol10001Ool1Ool0
00eoo`03001oogoo00eoo`<007iooa@3h0030003h7oo011oo`03001oogoo015oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo5@?P00<007ooOol03goo00<007ooOol04Goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001nOolD0n000goo001oo`0?Ool00`00Oomoo`0BOol10001Ool1Ool000eo
o`03001oogoo00eoo`<007iooa<3h0=oo`03001oogoo00eoo`03001oogoo019oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo4P?P17oo00<007ooOol037oo00<007ooOol04goo0@000Goo0Goo
000=Ool2000>Ool3001nOolA0n06Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol10001Ool1Ool000eo
o`03001oogoo00eoo`<007iooa03h0Moo`03001oogoo00Uoo`03001oogoo01Eoo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo3`?P2Goo00<007ooOol027oo00<007ooOol05Goo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOol>0n0;Ool00`00Oomoo`06Ool00`00Oomoo`0FOol10001Ool1
Ool000eoo`03001oogoo00eoo`<007ioo`d3h0eoo`03001oogoo00=oo`8001Uoo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo30?P3goo00<007ooOol00P006goo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3001nOol;0n0AOol2000MOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`X3
h35oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo2@?P<Woo0@000Goo0Goo000=Ool2000>
Ool3001nOol80n0cOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`L3h3Aoo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00OWoo1P?P=Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001n
Ool50n0fOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`@3h3Moo`40005oo`5oo`003Goo
00<007ooOol03Goo0`00OWoo0`?P>7oo0@000Goo0Goo0007Ool20004Ool00`00Oomoo`0=Ool3001n
Ool20n0iOol10001Ool1Ool000Uoo`05001oogooOol0000?Oon001l00`000n007`0iOol10001Ool1
Ool000Qoo`03001oogoo009oo`8000eoo`0300007`0O07d07`@003Qoo`80009oo`002Goo00D007oo
Oomoo`0000ioo`0300007`0O07d07`@003Uoo`40005oo`5oo`001goo00<007oo00000goo00<007oo
Ool03Goo0P00OWoo0P00>Woo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`39Ool10001
Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=
Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007oo
Ool0bGoo0@000Goo0Goo000=Ool2003:Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5o
o`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03
001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39
Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo0P00bWoo0@000Goo0Goo000=
Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007oo
Ool0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40
005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool0
00eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo0P00bWoo0@000Goo0Goo000=Ool00`00Oomoo`39
Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo
0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo
00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`800<Yoo`40
005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool0
00eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00
Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`0027oo0`000Woo00<007oo
Ool0bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo0007Ool40002Ool20039
Ool20002Ool000Moo`03001oo`0000=oo`03001oogoo0<Uoo`40005oo`5oo`0027oo0P000goo00<0
07ooOol0bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo000=Ool00`00Oomo
o`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@00
0Goo0Goo000=Ool00`00Oomoo`0>Ool00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0XOol0
0`00Oomoo`0WOol00`00Oomoo`0>Ool10001Ool1Ool000eoold0009oo`00\
\>"],
  ImageRangeCache->{{{0, 219}, {265, 0}} -> {-2.71851, -2.02306, 0.0235014, 
  0.0235014}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Four body objects are required for the four-bar model. Each bar is \
attached to another bar at its local origin and at a point at the other end \
of the bar on the local ",
  StyleBox["X",
    FontSlant->"Italic"],
  " or ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axis."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground (body 1) uses two points.\nP0 is the attachment point of the \
drive bar.\nP1 is the attachment point of the driven bar."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The drive bar (body2) uses two points.\nP0 is the rotational axis of the \
drive bar.\nP1 is the attachment point of the center bar."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The driven bar (body3) uses two points.\nP0 is the rotational axis of the \
driven bar.\nP1 is the attachment point of the center bar."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The center bar (body 4) uses three points.\nP0 is the attachment point of \
the drive bar.\nP1 is the attachment point of the driven bar.\nP2 is an \
offset point used for tracking a point locus."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the body objects for the four-bar model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bd[1] = Body[ground = 1, PointList \[Rule] {{\(-2\), 3}}]; \)\), 
    \(\(bd[2] = Body[drivebar = 2, PointList \[Rule] {{1, 0}}]; \)\), 
    \(bd[3] = 
      Body[drivenbar = 3, PointList \[Rule] {{3, 0}}, \n\t\t
        InitialGuess \[Rule] {{\(-2\), 3}, 0}]; \n
    bd[4] = Body[centerbar = 4, PointList \[Rule] {{0, 3}, {1, 2}}, \n\t\t
        InitialGuess \[Rule] {{1, 0}, 0}]; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The body properties are incorporated into the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[drivebar], bd[drivenbar], bd[centerbar]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Five constraints, one of which is a driving constraint, are used to model \
the four-bar mechanism. These constraints are simply standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraints which will be replaced with generalized coordinate \
constraints shortly."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used as a driving constraint to rotate the drive bar."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Four ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints model the four pivot points in the four-bar mechanism."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the four-bar."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[1] = RotationLock1[1, drivebar, 2\ N[\[Pi]]\ T]; \)\), 
    \(cs[2] = Revolute2[2, \n\t\tPoint[drivebar, 0], Point[ground, 0]]; \n
    cs[3] = Revolute2[3, \n\t\tPoint[centerbar, 0], Point[drivebar, 1]]; \n
    cs[4] = Revolute2[4, \n\t\tPoint[drivenbar, 1], Point[centerbar, 1]]; \n
    cs[5] = Revolute2[5, \n\t\tPoint[drivenbar, 0], Point[ground, 1]]; \)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The constraints are incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 5]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run-Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because of the presence of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the driving constraint ",
  StyleBox["cs[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the model can be run through its intended range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the angle of rotation of the drive bar in revolutions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.3`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 1.88495559215387586`\), ",", 
        \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
        \(Th3 \[Rule] 0.231291243186026607`\), ",", 
        \(X4 \[Rule] \(-0.309016994374947362`\)\), ",", 
        \(Y4 \[Rule] 0.951056516295153642`\), ",", 
        \(Th4 \[Rule] \(-0.422136359279569184`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the four-bar model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.20833  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.5 0.208333 0.333333 0.208333 [ 
[(-2)] .08333 0 0 2 Msboxa 
[(-1)] .29167 0 0 2 Msboxa 
[(0)] .5 0 0 2 Msboxa 
[(1)] .70833 0 0 2 Msboxa 
[(2)] .91667 0 0 2 Msboxa 
[(-1)] -0.0125 .125 1 0 Msboxa 
[(0)] -0.0125 .33333 1 0 Msboxa 
[(1)] -0.0125 .54167 1 0 Msboxa 
[(2)] -0.0125 .75 1 0 Msboxa 
[(3)] -0.0125 .95833 1 0 Msboxa 
[(4)] -0.0125 1.16667 1 0 Msboxa 
[ -0.001 -0.001 0 0 ] 
[ 1.001 1.20933 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.08333 0 m 
.08333 .00625 L 
s 
P 
[(-2)] .08333 0 0 2 Mshowa 
p 
.002 w 
.29167 0 m 
.29167 .00625 L 
s 
P 
[(-1)] .29167 0 0 2 Mshowa 
p 
.002 w 
.5 0 m 
.5 .00625 L 
s 
P 
[(0)] .5 0 0 2 Mshowa 
p 
.002 w 
.70833 0 m 
.70833 .00625 L 
s 
P 
[(1)] .70833 0 0 2 Mshowa 
p 
.002 w 
.91667 0 m 
.91667 .00625 L 
s 
P 
[(2)] .91667 0 0 2 Mshowa 
p 
.001 w 
.125 0 m 
.125 .00375 L 
s 
P 
p 
.001 w 
.16667 0 m 
.16667 .00375 L 
s 
P 
p 
.001 w 
.20833 0 m 
.20833 .00375 L 
s 
P 
p 
.001 w 
.25 0 m 
.25 .00375 L 
s 
P 
p 
.001 w 
.33333 0 m 
.33333 .00375 L 
s 
P 
p 
.001 w 
.375 0 m 
.375 .00375 L 
s 
P 
p 
.001 w 
.41667 0 m 
.41667 .00375 L 
s 
P 
p 
.001 w 
.45833 0 m 
.45833 .00375 L 
s 
P 
p 
.001 w 
.54167 0 m 
.54167 .00375 L 
s 
P 
p 
.001 w 
.58333 0 m 
.58333 .00375 L 
s 
P 
p 
.001 w 
.625 0 m 
.625 .00375 L 
s 
P 
p 
.001 w 
.66667 0 m 
.66667 .00375 L 
s 
P 
p 
.001 w 
.75 0 m 
.75 .00375 L 
s 
P 
p 
.001 w 
.79167 0 m 
.79167 .00375 L 
s 
P 
p 
.001 w 
.83333 0 m 
.83333 .00375 L 
s 
P 
p 
.001 w 
.875 0 m 
.875 .00375 L 
s 
P 
p 
.001 w 
.04167 0 m 
.04167 .00375 L 
s 
P 
p 
.001 w 
.95833 0 m 
.95833 .00375 L 
s 
P 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 .125 m 
.00625 .125 L 
s 
P 
[(-1)] -0.0125 .125 1 0 Mshowa 
p 
.002 w 
0 .33333 m 
.00625 .33333 L 
s 
P 
[(0)] -0.0125 .33333 1 0 Mshowa 
p 
.002 w 
0 .54167 m 
.00625 .54167 L 
s 
P 
[(1)] -0.0125 .54167 1 0 Mshowa 
p 
.002 w 
0 .75 m 
.00625 .75 L 
s 
P 
[(2)] -0.0125 .75 1 0 Mshowa 
p 
.002 w 
0 .95833 m 
.00625 .95833 L 
s 
P 
[(3)] -0.0125 .95833 1 0 Mshowa 
p 
.002 w 
0 1.16667 m 
.00625 1.16667 L 
s 
P 
[(4)] -0.0125 1.16667 1 0 Mshowa 
p 
.001 w 
0 .16667 m 
.00375 .16667 L 
s 
P 
p 
.001 w 
0 .20833 m 
.00375 .20833 L 
s 
P 
p 
.001 w 
0 .25 m 
.00375 .25 L 
s 
P 
p 
.001 w 
0 .29167 m 
.00375 .29167 L 
s 
P 
p 
.001 w 
0 .375 m 
.00375 .375 L 
s 
P 
p 
.001 w 
0 .41667 m 
.00375 .41667 L 
s 
P 
p 
.001 w 
0 .45833 m 
.00375 .45833 L 
s 
P 
p 
.001 w 
0 .5 m 
.00375 .5 L 
s 
P 
p 
.001 w 
0 .58333 m 
.00375 .58333 L 
s 
P 
p 
.001 w 
0 .625 m 
.00375 .625 L 
s 
P 
p 
.001 w 
0 .66667 m 
.00375 .66667 L 
s 
P 
p 
.001 w 
0 .70833 m 
.00375 .70833 L 
s 
P 
p 
.001 w 
0 .79167 m 
.00375 .79167 L 
s 
P 
p 
.001 w 
0 .83333 m 
.00375 .83333 L 
s 
P 
p 
.001 w 
0 .875 m 
.00375 .875 L 
s 
P 
p 
.001 w 
0 .91667 m 
.00375 .91667 L 
s 
P 
p 
.001 w 
0 1 m 
.00375 1 L 
s 
P 
p 
.001 w 
0 1.04167 m 
.00375 1.04167 L 
s 
P 
p 
.001 w 
0 1.08333 m 
.00375 1.08333 L 
s 
P 
p 
.001 w 
0 1.125 m 
.00375 1.125 L 
s 
P 
p 
.001 w 
0 .08333 m 
.00375 .08333 L 
s 
P 
p 
.001 w 
0 .04167 m 
.00375 .04167 L 
s 
P 
p 
.001 w 
0 0 m 
.00375 0 L 
s 
P 
p 
.001 w 
0 1.20833 m 
.00375 1.20833 L 
s 
P 
p 
.002 w 
0 0 m 
0 1.20833 L 
s 
P 
P 
p 
p 
.002 w 
.08333 1.20208 m 
.08333 1.20833 L 
s 
P 
p 
.002 w 
.29167 1.20208 m 
.29167 1.20833 L 
s 
P 
p 
.002 w 
.5 1.20208 m 
.5 1.20833 L 
s 
P 
p 
.002 w 
.70833 1.20208 m 
.70833 1.20833 L 
s 
P 
p 
.002 w 
.91667 1.20208 m 
.91667 1.20833 L 
s 
P 
p 
.001 w 
.125 1.20458 m 
.125 1.20833 L 
s 
P 
p 
.001 w 
.16667 1.20458 m 
.16667 1.20833 L 
s 
P 
p 
.001 w 
.20833 1.20458 m 
.20833 1.20833 L 
s 
P 
p 
.001 w 
.25 1.20458 m 
.25 1.20833 L 
s 
P 
p 
.001 w 
.33333 1.20458 m 
.33333 1.20833 L 
s 
P 
p 
.001 w 
.375 1.20458 m 
.375 1.20833 L 
s 
P 
p 
.001 w 
.41667 1.20458 m 
.41667 1.20833 L 
s 
P 
p 
.001 w 
.45833 1.20458 m 
.45833 1.20833 L 
s 
P 
p 
.001 w 
.54167 1.20458 m 
.54167 1.20833 L 
s 
P 
p 
.001 w 
.58333 1.20458 m 
.58333 1.20833 L 
s 
P 
p 
.001 w 
.625 1.20458 m 
.625 1.20833 L 
s 
P 
p 
.001 w 
.66667 1.20458 m 
.66667 1.20833 L 
s 
P 
p 
.001 w 
.75 1.20458 m 
.75 1.20833 L 
s 
P 
p 
.001 w 
.79167 1.20458 m 
.79167 1.20833 L 
s 
P 
p 
.001 w 
.83333 1.20458 m 
.83333 1.20833 L 
s 
P 
p 
.001 w 
.875 1.20458 m 
.875 1.20833 L 
s 
P 
p 
.001 w 
.04167 1.20458 m 
.04167 1.20833 L 
s 
P 
p 
.001 w 
.95833 1.20458 m 
.95833 1.20833 L 
s 
P 
p 
.002 w 
0 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
.99375 .125 m 
1 .125 L 
s 
P 
p 
.002 w 
.99375 .33333 m 
1 .33333 L 
s 
P 
p 
.002 w 
.99375 .54167 m 
1 .54167 L 
s 
P 
p 
.002 w 
.99375 .75 m 
1 .75 L 
s 
P 
p 
.002 w 
.99375 .95833 m 
1 .95833 L 
s 
P 
p 
.002 w 
.99375 1.16667 m 
1 1.16667 L 
s 
P 
p 
.001 w 
.99625 .16667 m 
1 .16667 L 
s 
P 
p 
.001 w 
.99625 .20833 m 
1 .20833 L 
s 
P 
p 
.001 w 
.99625 .25 m 
1 .25 L 
s 
P 
p 
.001 w 
.99625 .29167 m 
1 .29167 L 
s 
P 
p 
.001 w 
.99625 .375 m 
1 .375 L 
s 
P 
p 
.001 w 
.99625 .41667 m 
1 .41667 L 
s 
P 
p 
.001 w 
.99625 .45833 m 
1 .45833 L 
s 
P 
p 
.001 w 
.99625 .5 m 
1 .5 L 
s 
P 
p 
.001 w 
.99625 .58333 m 
1 .58333 L 
s 
P 
p 
.001 w 
.99625 .625 m 
1 .625 L 
s 
P 
p 
.001 w 
.99625 .66667 m 
1 .66667 L 
s 
P 
p 
.001 w 
.99625 .70833 m 
1 .70833 L 
s 
P 
p 
.001 w 
.99625 .79167 m 
1 .79167 L 
s 
P 
p 
.001 w 
.99625 .83333 m 
1 .83333 L 
s 
P 
p 
.001 w 
.99625 .875 m 
1 .875 L 
s 
P 
p 
.001 w 
.99625 .91667 m 
1 .91667 L 
s 
P 
p 
.001 w 
.99625 1 m 
1 1 L 
s 
P 
p 
.001 w 
.99625 1.04167 m 
1 1.04167 L 
s 
P 
p 
.001 w 
.99625 1.08333 m 
1 1.08333 L 
s 
P 
p 
.001 w 
.99625 1.125 m 
1 1.125 L 
s 
P 
p 
.001 w 
.99625 .08333 m 
1 .08333 L 
s 
P 
p 
.001 w 
.99625 .04167 m 
1 .04167 L 
s 
P 
p 
.001 w 
.99625 0 m 
1 0 L 
s 
P 
p 
.001 w 
.99625 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
1 0 m 
1 1.20833 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 1.20833 L 
0 1.20833 L 
closepath 
clip 
newpath 
p 
p 
p 
.025 w 
.08333 .95833 Mdot 
.015 w 
.29167 .02083 m 
.5 .33333 L 
.70833 .02083 L 
.08333 .02083 L 
.08333 .95833 L 
s 
P 
p 
1 0 0 r 
p 
.015 w 
.5697 .41074 m 
.43562 .53147 L 
s 
.43562 .53147 m 
.39811 .35499 L 
s 
P 
.015 w 
newpath 
.5 .33333 .10417 0 365.73 arc 
s 
P 
p 
0 0 1 r 
p 
.015 w 
.08333 .95833 m 
.69169 1.1016 L 
s 
P 
P 
p 
p 
.025 w 
.43562 .53147 Mdot 
.69169 1.1016 Mdot 
.79638 .8262 Mdot 
P 
0 1 0 r 
p 
.43562 .53147 m 
.69169 1.1016 L 
.79638 .8262 L 
F 
P 
P 
P 
.004 w 
.91667 .75 m 
.91104 .81206 L 
.8952 .86278 L 
.87212 .89517 L 
.84594 .9026 L 
.82031 .87992 L 
.79638 .8262 L 
.77265 .74866 L 
.7489 .66256 L 
.72906 .58351 L 
.7183 .5204 L 
.71923 .47588 L 
.73138 .44978 L 
.75254 .44118 L 
.77988 .44904 L 
.81056 .47222 L 
.84186 .50939 L 
.871 .55879 L 
.89504 .61796 L 
.91104 .68331 L 
.91667 .75 L 
s 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{220, 266},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L00012Q000`40O003h00Og7oo003LOol00=ao
o`00g7oo000OOol3000WOol5000UOol00`00Oomoo`0UOol5000WOol3000BOol001moo`03001oogoo
02Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001oogoo02Moo`03001oogoo019oo`006Woo0`00
0goo00<007ooOol08Woo0`000goo00<007ooOol097oo00<007oo0000:7oo00<007ooOol0:7oo00<0
07ooOol04Goo000POol00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Ool0000XOol00`00Oomoo`0X
Ool00`00Oomoo`0AOol001moo`03001oo`0002Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001o
ogoo02Moo`03001oo`00019oo`0087oo00<007ooOol09goo0P009goo00<007ooOol09Woo0P00:Woo
00<007ooOol04Goo003LOol00=aoo`00g7oo003LOol00=aoo`00g7oo003LOol00=aoo`003Gooc@00
0Woo000=Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool10001
Ool1Ool000eoo`03001oogoo00ioo`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo02Qoo`03
001oogoo02Moo`03001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=
Ool00`00Oomoo`0=Oon3000iOol10001Ool1Ool000eoo`03001oogoo00eooh<003Uoo`40005oo`5o
o`003Goo00<007ooOol03GooP`00>Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000YOol4001>
Ool4000jOol10001Ool1Ool000eoo`03001oogoo00eoo`<002Yoo`<004ioo`<003]oo`40005oo`5o
o`003Goo0P003Woo0`00:Woo1000C7oo1000>goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000[
Ool4001:Ool4000lOol10001Ool1Ool000eoo`03001oogoo00eoo`<002aoo`<004Yoo`<003eoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00;7oo1000B7oo1000?Goo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3000]Ool40016Ool4000nOol10001Ool1Ool000eoo`03001oogoo00eoo`<002ioo`<0
04Ioo`<003moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00;Woo1000A7oo1000?goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3000_Ool40012Ool40010Ool10001Ool1Ool000eoo`03001oogoo
00eoo`<0031oo`<0049oo`<0045oo`40005oo`5oo`003Goo0P003Woo0`00<7oo1000@7oo1000@Goo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000aOol4000nOol40012Ool10001Ool1Ool000eoo`03
001oogoo00eoo`<0039oo`<003ioo`<004=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00<Woo
1000?7oo1000@goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000cOol3000kOol40014Ool10001
Ool1Ool000eoo`03001oogoo00eoo`<003=oo`@003Yoo`<004Eoo`40005oo`5oo`001Woo1@000Woo
00<007ooOol03Goo0`00=7oo1000>7oo1000AGoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool3000eOol3000gOol40016Ool10001Ool1Ool0009oo`<000=oo`03001oogoo009oo`80
00ioo`<003Eoo`@003Ioo`<004Ioo`80009oo`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00
=Woo1000=7oo1000Agoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3000gOol3
000cOol40018Ool10001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<003Moo`@0039oo`<004Uo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00>7oo1000<7oo1000BGoo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3000iOol3000_Ool4001:Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003Uo
o`@002ioo`<004]oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00>Woo1000;7oo1000Bgoo0@00
0Goo0Goo000=Ool00`00Oomoo`0=Ool3000kOol3000[Ool4001<Ool10001Ool1Ool000eoo`8000io
o`<003]oo`@002Yoo`<004eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?7oo1000:7oo1000
CGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000mOol3000WOol4001>Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<003eoo`@002Eoo`@004moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
?Woo100097oo0`00D7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol3000SOol4001@Ool1
0001Ool1Ool000eoo`03001oogoo00eoo`<003moo`@0025oo`@0055oo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00@7oo100087oo0`00DWoo0@000Goo0Goo000=Ool2000>Ool30011Ool3000OOol4
001BOol10001Ool1Ool000eoo`03001oogoo00eoo`<0045oo`@001eoo`@005=oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00@Woo100077oo0`00E7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0013Ool30009Ool8O00:Ool4001DOol10001Ool1Ool000eoo`03001oogoo00eoo`<004=oo`@000=o
oa5l00Eoo`@005Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00A7oo100000=oog`0O0004W`0
0goo0`00EWoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30015Ool20009O006Ool9O004001FOol1
0001Ool1Ool000eoo`03001oogoo00eoo`<004Eoo`03001l07`000Al00ioo`Ml0003001oogoo05Eo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00AGoo1W`04Goo1G`0F7oo0@000Goo0Goo000=Ool2
000>Ool30014Ool5O0000`00Oomoo`0AOol00`00O01l0002O01GOol10001Ool1Ool000eoo`03001o
ogoo00eoo`<004=oo`Al00@0015oo`<000Al05Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
@Woo17`00Woo0`004Goo0`0000=oog`0O0000W`0EGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0011Ool4O003Ool4000?Ool40002Ool4O01DOol10001Ool1Ool000eoo`03001oogoo00eoo`<0041o
o`Al00Eoo`@000eoo`@000Aoo`Al05=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?goo17`0
1goo0`003Goo0`001Woo1G`0DGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol4O007Ool4
000;Ool40007Ool4O01AOol10001Ool1Ool000eoo`03001oogoo00eoo`<003moo`=l00Uoo`@000Uo
o`@000Uoo`Al051oo`40005oo`5oo`003Goo0P003Woo0`00?Woo17`02Woo0`002Goo0`002goo0g`0
D7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000nOol3O00;Ool40007Ool4000;Ool4O01?Ool1
0001Ool1Ool000eoo`03001oogoo00eoo`<003ioo`=l00aoo`@000Eoo`@000eoo`=l04moo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00?Woo0g`03Goo0`001Goo0`003Woo0g`0Cgoo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3000mOol4O00=Ool40003Ool4000>Ool3O01?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<003eoo`=l00moo`@00003Ool00000008000moo`=l04moo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00?Goo0g`047oo0`0000Aoo`000000011oo`=l04moo`40005oo`5oo`00
27oo00<007ooOol00Woo00<007ooOol03Goo0`00?Goo0g`047oo1`0047oo0g`0Cgoo0@000Goo0Goo
0007Ool00`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00AOol5000AOol3O01?Ool10001Ool1
Ool000Moo`03001oo`0000=oo`8000ioo`<003eoo`=l019oo`<0019oo`=l04ioo`80009oo`001goo
00<007oo00000goo00<007ooOol03Goo0`00?Goo0g`04Woo0`004Woo0g`0Cgoo0@000Goo0Goo0007
Ool00`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00WOol3O01?Ool10001Ool1Ool000Qoo`03
001oogoo009oo`03001oogoo00eoo`<003eoo`=l02Moo`=l04moo`40005oo`5oo`003Goo00<007oo
Ool03Goo0`00?Goo17`09Woo0g`0Cgoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000mOol4O00V
Ool3O01?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003eoo`Al02Ioo`=l04moo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00?Woo0g`09Goo17`0Cgoo0@000Goo0Goo000=Ool2000>Ool3000n
Ool4O00TOol3O01@Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003ioo`Al02=oo`Al051oo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00?Woo1G`08Woo0g`0DGoo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3000nOol5O00QOol4O01AOol10001Ool1Ool000eoo`03001oogoo00eoo`<003moo`El
01ioo`El059oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?goo1g`077oo1G`0DWoo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3000oOol7O00JOol5O01DOol10001Ool1Ool000eoo`03001oogoo
00eoo`<003moo`Ql01Qoo`El05Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@7oo0g`000=o
og`0O0000g`05Goo1W`0EGoo0@000Goo0Goo000=Ool2000>Ool30010Ool3O0000gooO01l0005O00B
Ool5O01GOol10001Ool1Ool000eoo`03001oogoo00eoo`<0041oo`=l00=oo`Il00ioo`Il05Uoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00@7oo0g`01Goo27`027oo1g`0FWoo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool30010Ool4O005OolFO01JOol10001Ool1Ool000eoo`03001oogoo00eoo`<0
045oo`=l00Iooa=l05aoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@Goo0g`02goo3G`0:Goo
1@00;goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30011Ool3O00COol4O00WOol30005Ool3000/
Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0045oo`Al015oo`Al02Qoo`03001oogoo00Qoo`80
02Yoo`40005oo`5oo`003Goo0P003Woo0`00@Woo0g`047oo17`0:7oo00<007ooOol02goo00<007oo
Ool09goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30012Ool3O00?Ool4O00YOol00`00Oomoo`0<
Ool00`00Oomoo`0VOol10001Ool1Ool000eoo`03001oogoo00eoo`<0049oo`=l00eoo`El02Yoo`03
001oogoo00eoo`8002Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@Woo0g`037oo1G`0:Woo
00<007ooOol047oo00<007ooOol08goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30012Ool4O00:
Ool4O00/Ool00`00Oomoo`0AOol00`00Oomoo`0ROol10001Ool1Ool000eoo`03001oogoo00eoo`<0
04=oo`=l00Uoo`Al02eoo`03001oogoo015oo`03001oogoo029oo`40005oo`5oo`003Goo00<007oo
Ool03Goo0`00@goo0g`027oo17`0;Woo00<007ooOol04Woo00<007ooOol08Goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool30013Ool3O007Ool4O00_Ool00`00Oomoo`0COol00`00Oomoo`0POol10001
Ool1Ool000eoo`03001oogoo00eoo`<004=oo`Al00Eoo`Al031oo`03001oogoo01Aoo`03001oogoo
01moo`40005oo`5oo`003Goo0P003Woo0`00A7oo0g`017oo17`0<Goo00<007ooOol057oo00<007oo
Ool07goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30014Ool3O003Ool4O00bOol00`00Oomoo`0E
Ool00`00Oomoo`0NOol10001Ool1Ool000eoo`03001oogoo00eoo`<004Aoo`=l009oo`Al03=oo`03
001oogoo01Ioo`03001oogoo01eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00A7oo0g`000=o
og`0O0000W`0=7oo00<007ooOol05goo00<007ooOol077oo0@000Goo0Goo000=Ool00`00Oomoo`0=
Ool30014Ool7O00eOol00`00Oomoo`0GOol00`00Oomoo`0LOol10001Ool1Ool000eoo`03001oogoo
00eoo`<004Eoo`8000=l03Ioo`03001oogoo01Qoo`03001oogoo01]oo`40005oo`5oo`001Woo1@00
0Woo00<007ooOol03Goo0`00A7oo100000=l07ooOol0=Goo00<007ooOol067oo00<007ooOol06goo
0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool30014Ool300000`?POomoo`0fOol0
0`00Oomoo`0IOol00`00Oomoo`0JOol10001Ool1Ool000Qoo`03001oogoo009oo`8000ioo`<004Eo
o`800083h3Qoo`03001oogoo01Uoo`03001oogoo01Qoo`80009oo`0027oo00<007ooOol00Woo00<0
07ooOol03Goo0`00B7oo0P?P=goo00<007ooOol06Goo00<007ooOol06Goo0@000Goo0Goo0008Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool30018Ool30n0fOol00`00Oomoo`0JOol00`00Oomoo`0HOol1
0001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<004Uoo`@3h3Aoo`03001oogoo01Yoo`03001o
ogoo01Qoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00BGoo1@?P<goo00<007ooOol06goo00<0
07ooOol05goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001:Ool50n0bOol00`00Oomoo`0KOol0
0`00Oomoo`0GOol10001Ool1Ool000eoo`03001oogoo00eoo`<004Yoo`H3h39oo`03001oogoo01]o
o`03001oogoo01Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Bgoo1`?P<7oo00<007ooOol0
6goo00<007ooOol05Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001;Ool80n0_Ool00`00Oomo
o`0LOol00`00Oomoo`0EOol10001Ool1Ool000eoo`8000ioo`<004]oo`T3h2ioo`03001oogoo01ao
o`03001oogoo01Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00C7oo2@?P;Goo00<007ooOol0
77oo00<007ooOol05Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001<Ool;0n0[Ool00`00Oomo
o`0MOol00`00Oomoo`0DOol10001Ool1Ool000eoo`03001oogoo00eoo`<004eoo`/3h2]oo`03001o
ogoo01aoo`03001oogoo01Aoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00CGoo30?P:Woo00<0
07ooOol07Goo00<007ooOol04goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001>Ool<0n0YOol0
0`00Oomoo`0MOol00`00Oomoo`0COol10001Ool1Ool000eoo`03001oogoo00eoo`<004ioo`d3h2Qo
o`03001oogoo01ioo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Cgoo3P?P
9goo00<007ooOol07Goo00<007ooOol04Woo0@000Goo0Goo000=Ool2000>Ool3001?Ool?0n0VOol0
0`00Oomoo`0MOol00`00Oomoo`0BOol10001Ool1Ool000eoo`03001oogoo00eoo`<004mooa03h2Eo
o`03001oogoo01eoo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00D7oo40?P
97oo00<007ooOol07Woo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001@OolB
0n0SOol00`00Oomoo`0MOol00`00Oomoo`0AOol10001Ool1Ool000eoo`03001oogoo00eoo`<0055o
oa83h29oo`03001oogoo01eoo`03001oogoo015oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
DGoo4`?P8Goo00<007ooOol07Goo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
001BOolC0n0POol00`00Oomoo`0NOol00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<0059ooaD3h1moo`03001oogoo01eoo`03001oogoo011oo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00Dgoo5@?P7Woo00<007ooOol07Goo00<007ooOol047oo0@000Goo0Goo000=Ool2000>Ool3
001COolF0n0MOol00`00Oomoo`0MOol00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<005=ooaL3h1eoo`03001oogoo01eoo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00E7oo5`?P77oo00<007ooOol07Goo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001DOolI0n0JOol00`00Oomoo`0MOol00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001o
ogoo00eoo`<005EooaT3h1Uoo`03001oogoo01eoo`03001oogoo00moo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00EGoo6P?P6Goo00<007ooOol077oo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001FOolJ0n0HOol00`00Oomoo`0LOol00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<005Iooa`3h1Ioo`03001oogoo01aoo`03001oogoo00moo`40005oo`5oo`00
3Goo0P003Woo0`00Egoo70?P5Woo00<007ooOol06goo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001GOolM0n0EOol00`00Oomoo`0KOol00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<005Qooad3h1Aoo`03001oogoo01]oo`03001oogoo00moo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00F7oo7`?P4goo00<007ooOol06goo00<007ooOol03Woo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001HOolP0n0BOol00`00Oomoo`0KOol00`00Oomoo`0>Ool10001Ool1
Ool000eoo`03001oogoo00eoo`<005Uoob03h15oo`03001oogoo01]oo`03001oogoo00ioo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00FGoo8@?P47oo00<007ooOol06goo00<007ooOol03Woo0@00
0Goo0Goo0007Ool30003Ool00`00Oomoo`0=Ool3001JOolR0n0?Ool00`00Oomoo`0JOol00`00Oomo
o`0>Ool10001Ool1Ool000Moo`03001oogoo00=oo`03001oogoo00eoo`<005Yoob<3h0ioo`03001o
ogoo01Yoo`03001oogoo00ioo`40005oo`5oo`0027oo00<007ooOol00Woo0P003Woo0`00Fgoo8`?P
3Goo00<007ooOol06Woo00<007ooOol03Goo0P000Woo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool3001KOolT0n0=Ool00`00Oomoo`0IOol00`00Oomoo`0>Ool10001Ool1Ool000Moo`03001oo`00
00=oo`03001oogoo00eoo`<005aoob@3h0aoo`03001oogoo01Uoo`03001oogoo00ioo`40005oo`5o
o`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00G7oo9P?P2Woo00<007ooOol06Goo00<007oo
Ool03Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001LOolW0n0:Ool00`00Oomoo`0HOol00`00
Oomoo`0>Ool10001Ool1Ool000eoo`03001oogoo00eoo`<005eoobL3h0Uoo`03001oogoo01Qoo`03
001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00GGoo:0?P27oo00<007ooOol05goo
00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001NOolY0n06Ool00`00Oomoo`0G
Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`8000ioo`<005ioobX3h0Ioo`03001oogoo01Ioo`03
001oogoo00moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Ggoo:P?P1Goo00<007ooOol05Woo
00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001OOol[0n04Ool00`00Oomoo`0F
Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0061oob`3h0=oo`03001oogoo
01Eoo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00H7oo;@?P0Woo00<007oo
Ool05Goo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001POol^0n000goo001o
o`0FOol00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0065oobh3h08001Eoo`03
001oogoo011oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00HGoo;`?P0P0057oo00<007ooOol0
47oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001ROol^0n02000DOol00`00Oomoo`0@Ool10001
Ool1Ool000eoo`8000ioo`<0069oobh3h08001Aoo`03001oogoo011oo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00Hgoo;0?P0Woo00<007ooOol04Goo00<007ooOol04Goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001SOol/0n03Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol10001Ool1Ool000eo
o`03001oogoo00eoo`<006Aoob/3h0=oo`03001oogoo011oo`03001oogoo015oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00I7oo:P?P1Goo00<007ooOol03goo00<007ooOol04Goo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001UOolY0n05Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol10001Ool1
Ool000eoo`03001oogoo00eoo`<006EoobP3h0Moo`03001oogoo00eoo`03001oogoo019oo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00IGoo:0?P1goo00<007ooOol037oo00<007ooOol04goo0@00
0Goo0Goo000=Ool2000>Ool3001VOolW0n08Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol10001Ool1
Ool000eoo`03001oogoo00eoo`<006IoobH3h0Uoo`03001oogoo00Uoo`03001oogoo01Eoo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00Igoo9@?P2Woo00<007ooOol027oo00<007ooOol05Goo0@00
0Goo0Goo000=Ool00`00Oomoo`0=Ool3001WOolT0n0<Ool00`00Oomoo`06Ool00`00Oomoo`0FOol1
0001Ool1Ool000eoo`03001oogoo00eoo`<006Qoob<3h0eoo`03001oogoo00=oo`8001Uoo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00J7oo8`?P3Woo00<007ooOol00P006goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001YOolQ0n0@Ool2000MOol10001Ool1Ool000eoo`03001oogoo00eoo`<0
06Uoob43h2moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00JGoo80?P<7oo0@000Goo0Goo000=
Ool2000>Ool3001ZOolO0n0`Ool10001Ool1Ool000eoo`03001oogoo00eoo`<006Yooal3h31oo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00Jgoo7@?P<Goo0@000Goo0Goo000=Ool00`00Oomoo`0=
Ool3001[OolM0n0aOol10001Ool1Ool000eoo`03001oogoo00eoo`<006aooa/3h39oo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00K7oo6`?P<Woo0@000Goo0Goo0007Ool20004Ool00`00Oomoo`0=
Ool3001]OolJ0n0bOol10001Ool1Ool000Uoo`05001oogooOol0000?Ool401m/OolI0n0cOol10001
Ool1Ool000Qoo`03001oogoo009oo`8000eoo`0300007`0O00H07fQooaT3h39oo`80009oo`002Goo
00D007ooOomoo`0000ioo`0300007`0O00X07fEooaL3h3Aoo`40005oo`5oo`001goo00<007oo0000
0goo00<007ooOol03Goo0P000Woo300OHGoo5`?P=7oo0@000Goo0Goo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0EOol=01mMOolF0n0dOol10001Ool1Ool000eoo`03001oogoo01Uoo`d07eUooaD3h3Eo
o`40005oo`5oo`003Goo00<007ooOol07Goo3@0OEWoo50?P=Goo0@000Goo0Goo000=Ool00`00Oomo
o`0ROol=01mAOolD0n0eOol10001Ool1Ool000eoo`03001oogoo02Ioo`d07diooa83h3Ioo`40005o
o`5oo`003Goo00<007ooOol0:Woo3@0OBWoo4P?P=Woo0@000Goo0Goo000=Ool2000`Ool<01m7Ool@
0n0gOol10001Ool1Ool000eoo`03001oogoo03=oo`d07d9ooa03h3Moo`40005oo`5oo`003Goo00<0
07ooOol0=goo3@0O?Woo40?P=goo0@000Goo0Goo000=Ool00`00Oomoo`0kOol=01lkOol>0n0hOol1
0001Ool1Ool000eoo`03001oogoo041oo``07cMoo`h3h3Qoo`40005oo`5oo`003Goo00<007ooOol0
A7oo3@0O<goo30?P>Goo0@000Goo0Goo000=Ool00`00Oomoo`18Ool=01l_Ool<0n0iOol10001Ool1
Ool000eoo`03001oogoo04aoo`d07baoo`/3h3Uoo`40005oo`5oo`003Goo0P00DWoo3@0O9goo2P?P
>Woo0@000Goo0Goo000=Ool00`00Oomoo`1EOol=01lTOol90n0jOol10001Ool1Ool000eoo`03001o
ogoo05Uoo`d07b1oo`P3h3]oo`40005oo`5oo`003Goo00<007ooOol0GWoo300O77oo20?P>goo0@00
0Goo0Goo000=Ool00`00Oomoo`1ROol=01lHOol70n0kOol10001Ool1Ool000eoo`03001oogoo06Io
o`d07aAoo`H3h3aoo`40005oo`5oo`003Goo00<007ooOol0JWoo3@0O4Goo1@?P?7oo0@000Goo0Goo
000=Ool00`00Oomoo`1_Ool=01l<Ool40n0mOol10001Ool1Ool000eoo`03001oogoo07=oo`d07`Uo
o`<3h3eoo`40005oo`5oo`003Goo0P00N7oo3@0O1Goo0`?P?Goo0@000Goo0Goo000=Ool00`00Oomo
o`1lOol<01l2Ool00`?POomoo`0lOol10001Ool1Ool000eoo`03001oogoo081oo`T07`030003h00O
03eoo`40005oo`5oo`003Goo00<007ooOol0Q7oo100O1000?Goo0@000Goo0Goo000=Ool00`00Oomo
o`28Ool4000mOol10001Ool1Ool000eoo`03001oogoo08Uoo`8003ioo`40005oo`5oo`003Goo00<0
07ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`800<Yoo`40005o
o`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eo
o`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomo
o`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`0027oo0`000Woo00<007ooOol0
bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo0007Ool40002Ool20039Ool2
0002Ool000Moo`03001oo`0000=oo`03001oogoo0<Uoo`40005oo`5oo`0027oo0P000goo00<007oo
Ool0bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo000=Ool00`00Oomoo`39
Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo
0Goo000=Ool00`00Oomoo`0>Ool00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0XOol00`00
Oomoo`0WOol00`00Oomoo`0>Ool10001Ool1Ool000eoold0009oo`00\
\>"],
  ImageRangeCache->{{{0, 219}, {265, 0}} -> {-2.71851, -2.02306, 0.0235014, 
  0.0235014}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Generalized Coordinate Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now one of the standard constraints is replaced with a generalized \
coordinate constraint. Constraint 2, the revolute joint at the drive bar \
origin, is replaced first, and body 2 becomes a slave to the ground body, \
represented by the single coordinate ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the new constraint."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[2] = 
      GenRevolute2[2, Axis[drivebar, 0, X], 
        Axis[ground, 0, X], {alpha, 0.0}]; \)\), 
    \(SetConstraints[Array[cs, 5]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The modified model is run again at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.3`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X3 \[Rule] \(-2.`\)\), ",", 
        \(Y3 \[Rule] 3.`\), ",", \(Th3 \[Rule] 0.231291243186026607`\), ",", 
        \(X4 \[Rule] \(-0.309016994374947362`\)\), ",", 
        \(Y4 \[Rule] 0.951056516295153642`\), ",", 
        \(Th4 \[Rule] \(-0.422136359279569184`\)\), ",", 
        \(alpha \[Rule] 1.88495559215387586`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that the symbols ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are no longer included in the solution rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The location of body 2 is represented entirely by ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which has the same numerical value as ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " used to have. The numerical value of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would be different from ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " if the direction vectors of the two axes in the ",
  StyleBox["GenRevolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint were not identical (",
  StyleBox["X",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["X",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ").\n\nTwo more of the ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints can also be replaced, but not the fourth one. This is because \
each generalized coordinate constraint creates a slave body, and a slave body \
can be a slave to only one master body. Thus, there is no way to use four \
generalized coordinate constraints in a model with only three bodies. Any \
three of the four revolute constraints can be replaced, but not all of them."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are two more new constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[3] = 
      GenRevolute2[3, Axis[centerbar, 0, X], 
        Axis[drivebar, 1, X], {beta, 0.0}]; \)\), 
    \(\(cs[4] = 
      GenRevolute2[4, Axis[drivenbar, 1, X], 
        Axis[centerbar, 1, X], {gamma, 0.0}]; \)\), 
    \(SetConstraints[Array[cs, 5]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The modified model is run again at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.3`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(alpha \[Rule] 1.88495559215387586`\),
         ",", \(beta \[Rule] \(-2.30709195143344514`\)\), ",", 
        \(gamma \[Rule] 0.653427602465595747`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Now all of the Cartesian coordinates have been replaced with the \
generalized coordinates ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". A quick degree of freedom count shows that this all makes sense: the \
three generalized coordinate constraints each add one degree of freedom to \
the model, while the two standard constraints ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain a total of three degrees of freedom.\n\nThe physical meaning of \
the new coordinates is quite clear: ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the angle between the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis of the ground and the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the drive bar, ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the angle between the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axes of the drive and center bars, and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the angle between the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axes of the center and driven bars."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Output and Graphics Functions"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now that we have a solution in terms of the generalized coordinates, all \
of the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output and graphics functions allow it to be used in the same manner as a \
solution in Cartesian coordinates. For example, the location of a point is \
still found with the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function and the rotation angle of a body is found with ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The symbolic expressions returned by these functions reflect the new \
coordinate system being used, but the numerical results are equivalent. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the Cartesian coordinates of point 2 on the center bar."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Location[centerbar, 2]\), 
    \(% /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({Cos[alpha] + Cos[alpha + beta] - 2\ Sin[alpha + beta], 
      2\ Cos[alpha + beta] + Sin[alpha] + Sin[alpha + beta]}\)], "Output"],

Cell[BoxData[
    \({1.42261915427221996`, 2.36577777813382628`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the global rotation angle of the driven bar. Note that it is \
numerically equal to the ",
  StyleBox["Th3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " coordinate from the first set of solution rules."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Rotation[drivenbar]\), 
    \(% /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(alpha + beta + gamma\)], "Output"],

Cell[BoxData[
    \(0.231291243186026473`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The location of point 2 on the center bar is a function of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", but not ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is because of the master-slave relationship of the generalized \
coordinate bodies; the center bar is a slave to the drive bar, which is a \
slave to the ground. Thus, the location of any point on the driven bar is a \
function of all three generalized coordinates, and the location of any point \
on the drive bar is a function of only ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics functions also operate without regard to the use of generalized \
coordinates. The following graphics object will generate the same image with \
any of the three constraint formulations used previously."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the graphics object representing the four-bar model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
graph := Graphics[{
  Thickness[.015], PointSize[.025],
(* Ground    *)
  {Point[{-2, 3}], 
   Line[{{-1, -1.5}, {0, 0}, {1, -1.5}, {-2, -1.5},
         {-2, 3}}]},
(* Drive Bar *)
  {RGBColor[1, 0, 0],
   Tangent[{0, 0}, .5, Point[drivebar, 1], 0],
   Wheel[Point[drivebar, 0], 0.5, Faces->False]},
(* Driven Bar*)
  {RGBColor[0, 0, 1], Edge[drivenbar, {0, 1}]},
(* Center Bar*)
  {Vertex[centerbar, {0, 1, 2}],
   RGBColor[0, 1, 0],
   Facet[centerbar, {0, 1, 2}]}},
  Frame->True,
  PlotRange->{{-2.4, 2.4}, {-1.6, 4.2}}, 
  AspectRatio->Automatic]; \
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This shows the graphic at T = 0.45."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{graph /. SolveMech[0.45]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.20833 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.208333 0.333333 0.208333 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.29167 -0.0125 -6 -9 ]
[.29167 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.70833 -0.0125 -3 -9 ]
[.70833 -0.0125 3 0 ]
[.91667 -0.0125 -3 -9 ]
[.91667 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .54167 -6 -4.5 ]
[-0.0125 .54167 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .95833 -6 -4.5 ]
[-0.0125 .95833 0 4.5 ]
[-0.0125 1.16667 -6 -4.5 ]
[-0.0125 1.16667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1.20833 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1.20833 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08333 0 m
.08333 .00625 L
s
[(-2)] .08333 -0.0125 0 1 Mshowa
.29167 0 m
.29167 .00625 L
s
[(-1)] .29167 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.70833 0 m
.70833 .00625 L
s
[(1)] .70833 -0.0125 0 1 Mshowa
.91667 0 m
.91667 .00625 L
s
[(2)] .91667 -0.0125 0 1 Mshowa
.125 Mabswid
.125 0 m
.125 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.20833 0 m
.20833 .00375 L
s
.25 0 m
.25 .00375 L
s
.33333 0 m
.33333 .00375 L
s
.375 0 m
.375 .00375 L
s
.41667 0 m
.41667 .00375 L
s
.45833 0 m
.45833 .00375 L
s
.54167 0 m
.54167 .00375 L
s
.58333 0 m
.58333 .00375 L
s
.625 0 m
.625 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.75 0 m
.75 .00375 L
s
.79167 0 m
.79167 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.875 0 m
.875 .00375 L
s
.04167 0 m
.04167 .00375 L
s
.95833 0 m
.95833 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-1)] -0.0125 .125 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(0)] -0.0125 .33333 1 0 Mshowa
0 .54167 m
.00625 .54167 L
s
[(1)] -0.0125 .54167 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .95833 m
.00625 .95833 L
s
[(3)] -0.0125 .95833 1 0 Mshowa
0 1.16667 m
.00625 1.16667 L
s
[(4)] -0.0125 1.16667 1 0 Mshowa
.125 Mabswid
0 .16667 m
.00375 .16667 L
s
0 .20833 m
.00375 .20833 L
s
0 .25 m
.00375 .25 L
s
0 .29167 m
.00375 .29167 L
s
0 .375 m
.00375 .375 L
s
0 .41667 m
.00375 .41667 L
s
0 .45833 m
.00375 .45833 L
s
0 .5 m
.00375 .5 L
s
0 .58333 m
.00375 .58333 L
s
0 .625 m
.00375 .625 L
s
0 .66667 m
.00375 .66667 L
s
0 .70833 m
.00375 .70833 L
s
0 .79167 m
.00375 .79167 L
s
0 .83333 m
.00375 .83333 L
s
0 .875 m
.00375 .875 L
s
0 .91667 m
.00375 .91667 L
s
0 1 m
.00375 1 L
s
0 1.04167 m
.00375 1.04167 L
s
0 1.08333 m
.00375 1.08333 L
s
0 1.125 m
.00375 1.125 L
s
0 .08333 m
.00375 .08333 L
s
0 .04167 m
.00375 .04167 L
s
0 0 m
.00375 0 L
s
.25 Mabswid
0 0 m
0 1.20833 L
s
.08333 1.20208 m
.08333 1.20833 L
s
.29167 1.20208 m
.29167 1.20833 L
s
.5 1.20208 m
.5 1.20833 L
s
.70833 1.20208 m
.70833 1.20833 L
s
.91667 1.20208 m
.91667 1.20833 L
s
.125 Mabswid
.125 1.20458 m
.125 1.20833 L
s
.16667 1.20458 m
.16667 1.20833 L
s
.20833 1.20458 m
.20833 1.20833 L
s
.25 1.20458 m
.25 1.20833 L
s
.33333 1.20458 m
.33333 1.20833 L
s
.375 1.20458 m
.375 1.20833 L
s
.41667 1.20458 m
.41667 1.20833 L
s
.45833 1.20458 m
.45833 1.20833 L
s
.54167 1.20458 m
.54167 1.20833 L
s
.58333 1.20458 m
.58333 1.20833 L
s
.625 1.20458 m
.625 1.20833 L
s
.66667 1.20458 m
.66667 1.20833 L
s
.75 1.20458 m
.75 1.20833 L
s
.79167 1.20458 m
.79167 1.20833 L
s
.83333 1.20458 m
.83333 1.20833 L
s
.875 1.20458 m
.875 1.20833 L
s
.04167 1.20458 m
.04167 1.20833 L
s
.95833 1.20458 m
.95833 1.20833 L
s
.25 Mabswid
0 1.20833 m
1 1.20833 L
s
.99375 .125 m
1 .125 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .54167 m
1 .54167 L
s
.99375 .75 m
1 .75 L
s
.99375 .95833 m
1 .95833 L
s
.99375 1.16667 m
1 1.16667 L
s
.125 Mabswid
.99625 .16667 m
1 .16667 L
s
.99625 .20833 m
1 .20833 L
s
.99625 .25 m
1 .25 L
s
.99625 .29167 m
1 .29167 L
s
.99625 .375 m
1 .375 L
s
.99625 .41667 m
1 .41667 L
s
.99625 .45833 m
1 .45833 L
s
.99625 .5 m
1 .5 L
s
.99625 .58333 m
1 .58333 L
s
.99625 .625 m
1 .625 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .70833 m
1 .70833 L
s
.99625 .79167 m
1 .79167 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .875 m
1 .875 L
s
.99625 .91667 m
1 .91667 L
s
.99625 1 m
1 1 L
s
.99625 1.04167 m
1 1.04167 L
s
.99625 1.08333 m
1 1.08333 L
s
.99625 1.125 m
1 1.125 L
s
.99625 .08333 m
1 .08333 L
s
.99625 .04167 m
1 .04167 L
s
.99625 0 m
1 0 L
s
.25 Mabswid
1 0 m
1 1.20833 L
s
0 0 m
1 0 L
1 1.20833 L
0 1.20833 L
closepath
clip
newpath
.025 w
.08333 .95833 Mdot
.015 w
.29167 .02083 m
.5 .33333 L
.70833 .02083 L
.08333 .02083 L
.08333 .95833 L
s
1 0 0 r
.47834 .43522 m
.30186 .39771 L
s
.30186 .39771 m
.42259 .26363 L
s
newpath
.5 .33333 .10417 162 522 arc
s
0 0 1 r
.08333 .95833 m
.70302 .87698 L
s
0 g
.025 w
.30186 .39771 Mdot
.70302 .87698 Mdot
.72906 .58351 Mdot
0 1 0 r
.30186 .39771 m
.70302 .87698 L
.72906 .58351 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{237, 286},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003]00017Q000`40O003h00OkGoo003]Ool00>eo
o`00kGoo003]Ool0029oo`<002Yoo`D002Qoo`03001oogoo02Uoo`D002Yoo`<001=oo`008Woo00<0
07ooOol0;7oo00<007ooOol09goo00<007oo0000;7oo00<007ooOol0:Woo00<007ooOol04goo000M
Ool30003Ool00`00Oomoo`0UOol30003Ool00`00Oomoo`0WOol00`00Ool0000/Ool00`00Oomoo`0[
Ool00`00Oomoo`0BOol002=oo`03001oogoo02]oo`03001oogoo02Moo`03001oo`0002aoo`03001o
ogoo02]oo`03001oogoo019oo`008Woo00<007oo0000;7oo00<007ooOol09goo00<007oo0000;7oo
00<007ooOol0:Woo00<007oo00004goo000SOol00`00Oomoo`0ZOol2000ZOol00`00Oomoo`0ZOol2
000]Ool00`00Oomoo`0BOol00>eoo`00kGoo003]Ool00>eoo`003WoogP000Goo000>Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool10001Ool000ioo`03001oogoo
011oo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo
00moo`40005oo`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`0?Oon=000nOol10001
Ool000ioo`03001oogoo00moohd003ioo`40005oo`003Woo00<007ooOol03gooS@00?Woo0@000Goo
000>Ool00`00Oomoo`0?Ool3000/Ool4001EOol4000oOol10001Ool000ioo`03001oogoo00moo`<0
02eoo`<005Eoo`<0041oo`40005oo`003Woo00<007ooOol03goo0`00;Goo1000Dgoo1000@7oo0@00
0Goo000>Ool2000@Ool3000^Ool4001AOol40011Ool10001Ool000ioo`03001oogoo00moo`<002mo
o`<0055oo`<0049oo`40005oo`003Woo00<007ooOol03goo0`00;goo1000Cgoo1000@Woo0@000Goo
000>Ool00`00Oomoo`0?Ool3000`Ool4001=Ool40013Ool10001Ool000ioo`03001oogoo00moo`<0
035oo`<004eoo`<004Aoo`40005oo`003Woo00<007ooOol03goo0`00<Goo1000Bgoo1000A7oo0@00
0Goo000>Ool00`00Oomoo`0?Ool3000bOol40019Ool40015Ool10001Ool000ioo`03001oogoo00mo
o`<003=oo`<004Uoo`<004Ioo`40005oo`003Woo00<007ooOol03goo0`00<goo1000Agoo1000AWoo
0@000Goo000>Ool2000@Ool3000dOol40015Ool40017Ool10001Ool000ioo`03001oogoo00moo`<0
03Eoo`<004Eoo`<004Qoo`40005oo`003Woo00<007ooOol03goo0`00=Goo1000@goo1000B7oo0@00
0Goo000>Ool00`00Oomoo`0?Ool3000fOol40011Ool40019Ool10001Ool000ioo`03001oogoo00mo
o`<003Moo`<0045oo`<004Yoo`40005oo`003Woo00<007ooOol03goo0`00=goo1000?goo1000BWoo
0@000Goo000>Ool00`00Oomoo`0?Ool3000hOol4000mOol4001;Ool10001Ool000Moo`D0009oo`03
001oogoo00moo`<003Uoo`<003eoo`<004aoo`40005oo`002Goo00<007ooOol00Woo00<007ooOol0
3goo0`00>Goo1000>goo1000C7oo0@000Goo0003Ool30003Ool00`00Oomoo`02Ool3000?Ool3000j
Ool4000iOol4001<Ool20001Ool000Uoo`03001oogoo009oo`03001oogoo00moo`<003]oo`<003Uo
o`<004ioo`40005oo`002Goo00<007ooOol00Woo00<007ooOol03goo0`00>goo1000=goo1000CWoo
0@000Goo0008Ool20004Ool00`00Oomoo`0?Ool3000lOol4000eOol4001?Ool10001Ool000ioo`03
001oogoo00moo`<003eoo`<003Eoo`<0051oo`40005oo`003Woo00<007ooOol03goo0`00?Goo1000
<goo1000D7oo0@000Goo000>Ool00`00Oomoo`0?Ool3000nOol4000aOol4001AOol10001Ool000io
o`03001oogoo00moo`<003moo`<0035oo`<0059oo`40005oo`003Woo00<007ooOol03goo0`00?goo
1000;goo1000DWoo0@000Goo000>Ool2000@Ool30010Ool4000]Ool4001COol10001Ool000ioo`03
001oogoo00moo`<0045oo`<002eoo`<005Aoo`40005oo`003Woo00<007ooOol03goo0`00@Goo1000
:goo1000E7oo0@000Goo000>Ool00`00Oomoo`0?Ool30012Ool4000YOol4001EOol10001Ool000io
o`03001oogoo00moo`<004=oo`<002Uoo`<005Ioo`40005oo`003Woo00<007ooOol03goo0`00@goo
10009goo1000EWoo0@000Goo000>Ool00`00Oomoo`0?Ool30014Ool4000UOol4001GOol10001Ool0
00ioo`03001oogoo00moo`<004Eoo`<002Eoo`<005Qoo`40005oo`003Woo00<007ooOol03goo0`00
AGoo10008goo1000F7oo0@000Goo000>Ool2000@Ool30016Ool4000QOol4001IOol10001Ool000io
o`03001oogoo00moo`<004Moo`<0025oo`<005Yoo`40005oo`003Woo00<007ooOol03goo0`00Agoo
10007goo1000FWoo0@000Goo000>Ool00`00Oomoo`0?Ool30018Ool4000MOol4001KOol10001Ool0
00ioo`03001oogoo00moo`<004Uoo`<000Qoo`al00Uoo`<005aoo`40005oo`003Woo00<007ooOol0
3goo0`00BGoo10001Goo47`01Woo1000G7oo0@000Goo000>Ool00`00Oomoo`0?Ool3001:Ool40002
OolFO0000goo00000002001MOol10001Ool000ioo`03001oogoo00moo`<004]oo`<000Ml00Yoo`Ml
0004Ool00000001NOol10001Ool000ioo`03001oogoo00moo`<004]oo`Ql00ioo`Ml008005ioo`40
005oo`003Woo00<007ooOol03goo0`00BWoo1g`04goo1W`0GWoo0@000Goo000>Ool2000@Ool30019
Ool6O0000`00Oomoo`0COol7O01LOol10001Ool000ioo`03001oogoo00moo`<004Qoo`El00@001=o
o`8000Il05aoo`40005oo`003Woo00<007ooOol03goo0`00Agoo17`00goo10004Goo10000Woo17`0
Fgoo0@000Goo000>Ool00`00Oomoo`0?Ool30017Ool4O004Ool3000AOol30003Ool4O01KOol10001
Ool000ioo`03001oogoo00moo`<004Ioo`Al00Eoo`@000moo`@000Aoo`El05Uoo`40005oo`003Woo
00<007ooOol03goo0`00AGoo1G`01Woo10003Goo10001Woo17`0FGoo0@000Goo000>Ool00`00Oomo
o`0?Ool30014Ool5O008Ool3000=Ool30008Ool4O01HOol10001Ool000ioo`03001oogoo00moo`<0
04Aoo`Al00Uoo`@000]oo`@000Uoo`=l05Qoo`40005oo`003Woo00<007ooOol03goo0`00@goo17`0
2goo10002Goo10002Woo17`0Egoo0@000Goo000>Ool2000@Ool30012Ool5O00<Ool30009Ool3000<
Ool3O01GOol10001Ool000ioo`03001oogoo00moo`<0045oo`El00eoo`@000Moo`@000aoo`Al05Io
o`40005oo`003Woo00<007ooOol03goo0`00@7oo1W`03Woo10001Goo10003Woo0g`0EWoo0@000Goo
000>Ool00`00Oomoo`0?Ool3000oOol7O00?Ool30005Ool3000?Ool3O01FOol10001Ool000ioo`03
001oogoo00moo`<003ioo`Ql00moo`@000=oo`@000moo`=l05Ioo`40005oo`003Woo00<007ooOol0
3goo0`00?Goo17`000Aoog`0O01l015oo`@00003Ool000000080011oo`Al05Eoo`40005oo`003Woo
00<007ooOol03goo0`00?7oo17`00Woo0g`04Woo0`0000Aoo`000000019oo`=l05Eoo`40005oo`00
2Goo00<007ooOol00Woo00<007ooOol03goo0`00>goo17`00goo0g`04Woo1`004Woo0g`0EGoo0@00
0Goo0008Ool00`00Ool00003Ool00`00Oomoo`0?Ool3000kOol3O004Ool3O00COol5000COol3O01E
Ool10001Ool000Qoo`03001oo`0000=oo`<000moo`<003Yoo`=l00Eoo`=l01Aoo`<001Aoo`=l05Ao
o`80005oo`0027oo00<007oo00000goo00<007ooOol03goo0`00>Goo17`01Goo0g`057oo0`0057oo
0g`0EGoo0@000Goo0008Ool00`00Ool00003Ool00`00Oomoo`0?Ool3000hOol4O006Ool3O00[Ool3
O01EOol10001Ool000Uoo`03001oogoo009oo`03001oogoo00moo`<003Moo`Al00Moo`=l02Yoo`Al
05Eoo`40005oo`003Woo00<007ooOol03goo0`00=Woo17`027oo0g`0:Woo0g`0EWoo0@000Goo000>
Ool00`00Oomoo`0?Ool3000eOol4O009Ool3O00ZOol3O01FOol10001Ool000ioo`03001oogoo00mo
o`<003Aoo`Al00Yoo`Al02Uoo`=l05Ioo`40005oo`003Woo00<007ooOol03goo0`00<goo17`037oo
0g`0:7oo17`0EWoo0@000Goo000>Ool00`00Oomoo`0?Ool3000bOol4O00=Ool4O00WOol3O01GOol1
0001Ool000ioo`80011oo`<0035oo`Al00moo`=l02Ioo`Al05Moo`40005oo`003Woo00<007ooOol0
3goo0`00<7oo17`047oo17`09Goo0g`0F7oo0@000Goo000>Ool00`00Oomoo`0?Ool3000_Ool4O00B
Ool3O00TOol4O01HOol10001Ool000ioo`03001oogoo00moo`<002ioo`Al01=oo`Al02=oo`=l05Uo
o`40005oo`003Woo00<007ooOol03goo0`00;Goo0P000W`05Goo0g`08Woo17`0FGoo0@000Goo000>
Ool00`00Oomoo`0?Ool3000/Ool40005O00AOol4O00POol4O01JOol10001Ool000ioo`03001oogoo
00moo`<002aoo`<00083h0Ql00eoo`Al01moo`El05Yoo`40005oo`003Woo00<007ooOol03goo0`00
;Goo0P0000Aoo`?P0n03h0]l00Uoo`El01aoo`Al05aoo`40005oo`003Woo00<007ooOol03goo0`00
<Goo10?P3G`01Woo1W`06Woo17`0G7oo0@000Goo000>Ool2000@Ool3000bOol60n000gooO01l000;
O003Ool5O00HOol5O01MOol10001Ool000ioo`03001oogoo00moo`<003=oo`L3h0Aooa5l01Eoo`Ml
05eoo`40005oo`003Woo00<007ooOol03goo0`00=7oo20?P1Woo4G`03goo1g`0Ggoo0@000Goo000>
Ool00`00Oomoo`0?Ool3000dOol;0n07Ool@O008Ool9O01QOol10001Ool000ioo`03001oogoo00mo
o`<003Eoo``3h0YooaYl06=oo`40005oo`003Woo00<007ooOol03goo0`00=Woo3@?P37oo57`0IGoo
0@000Goo000>Ool00`00Oomoo`0?Ool3000gOol>0n0>Ool<O01YOol10001Ool000ioo`03001oogoo
00moo`<003Qooa03h81oo`40005oo`003Woo00<007ooOol03goo0`00>Goo4@?POWoo0@000Goo000>
Ool00`00Oomoo`0?Ool3000iOolC0n1lOol10001Ool000ioo`80011oo`<003YooaD3h7Uoo`40005o
o`003Woo00<007ooOol03goo0`00>goo5P?PMgoo0@000Goo000>Ool00`00Oomoo`0?Ool3000lOolG
0n1eOol10001Ool000ioo`03001oogoo00moo`<003eooaP3h7=oo`40005oo`003Woo00<007ooOol0
3goo0`00?Woo6P?PL7oo0@000Goo000>Ool00`00Oomoo`0?Ool3000nOolL0n1^Ool10001Ool000io
o`03001oogoo00moo`<003mooad3h6aoo`40005oo`003Woo00<007ooOol03goo0`00@7oo7`?PJGoo
0@000Goo000>Ool00`00Oomoo`0?Ool30011OolP0n1WOol10001Ool000ioo`80011oo`<0049oob43
h6Eoo`40005oo`003Woo00<007ooOol03goo0`00@goo8`?PHWoo0@000Goo000>Ool00`00Oomoo`0?
Ool30013OolU0n1POol10001Ool000ioo`03001oogoo00moo`<004AoobH3h5ioo`40005oo`003Woo
00<007ooOol03goo0`00AGoo9`?PG7oo0@000Goo000>Ool00`00Oomoo`0?Ool30016OolY0n1IOol1
0001Ool000ioo`03001oogoo00moo`<004MoobX3h5Moo`40005oo`001goo1@000Woo00<007ooOol0
3goo0`00B7oo:`?PEGoo0@000Goo0009Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool30019Ool]0n1B
Ool10001Ool000Uoo`03001oogoo009oo`<000moo`<004Uoobl3h4moo`80005oo`002Goo00<007oo
Ool00Woo00<007ooOol03goo0`00BWoo<0?PCWoo0@000Goo0009Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool3001;Oola0n1<Ool10001Ool000Qoo`8000Aoo`03001oogoo00moo`<004aooc<3h4Uoo`40
005oo`003Woo00<007ooOol03goo0`00CGoo=0?PAgoo0@000Goo000>Ool00`00Oomoo`0?Ool3001>
Oole0n15Ool10001Ool000ioo`03001oogoo00moo`<004ioocP3h49oo`40005oo`003Woo00<007oo
Ool03goo0`00Cgoo>@?P@7oo0@000Goo000>Ool00`00Oomoo`0?Ool3001@Oolj0n0nOol10001Ool0
00ioo`80011oo`<0055ooc/3h003001oogoo03Uoo`40005oo`003Woo00<007ooOol03goo0`00DWoo
>P?P0P00>Woo0@000Goo000>Ool00`00Oomoo`0?Ool3001COoli0n02000jOol10001Ool000ioo`03
001oogoo00moo`<005=oocT3h003001oogoo03Uoo`40005oo`003Woo00<007ooOol03goo0`00E7oo
>0?P?7oo0@000Goo000>Ool00`00Oomoo`0?Ool3001EOolg0n0lOol10001Ool000ioo`03001oogoo
00moo`<005IoocH3h3aoo`40005oo`003Woo00<007ooOol03goo0`00Egoo=@?P?7oo0@000Goo000>
Ool00`00Oomoo`0?Ool3001HOold0n0lOol10001Ool000ioo`80011oo`<005Qooc@3h3aoo`40005o
o`003Woo00<007ooOol03goo0`00FGoo<`?P?7oo0@000Goo000>Ool00`00Oomoo`0?Ool3001JOolb
0n0lOol10001Ool000ioo`03001oogoo00moo`<005]ooc43h3aoo`40005oo`003Woo00<007ooOol0
3goo0`00G7oo;`?P?Goo0@000Goo000>Ool00`00Oomoo`0?Ool3001MOol^0n0mOol10001Ool000io
o`03001oogoo00moo`<005ioobd3h3eoo`40005oo`003Woo00<007ooOol03goo0`00GWoo;@?P?Goo
0@000Goo000>Ool00`00Oomoo`0?Ool3001OOol/0n0mOol10001Ool000ioo`03001oogoo00moo`<0
061oob/3h3eoo`40005oo`003Woo0P0047oo0`00HGoo:P?P?Goo0@000Goo000>Ool00`00Oomoo`0?
Ool3001ROolY0n0mOol10001Ool000ioo`03001oogoo00moo`<006=oobP3h3eoo`40005oo`003Woo
00<007ooOol03goo0`00Hgoo:0?P?Goo0@000Goo000>Ool00`00Oomoo`0?Ool3001TOolW0n0mOol1
0001Ool000ioo`03001oogoo00moo`<006EoobH3h3eoo`40005oo`003Woo00<007ooOol03goo0`00
IWoo9@?P?Goo0@000Goo000>Ool00`00Oomoo`0?Ool3001WOolS0n0nOol10001Ool000ioo`03001o
ogoo00moo`<006Qoob83h3ioo`40005oo`003Woo0P0047oo0`00J7oo8P?P?Woo0@000Goo000>Ool0
0`00Oomoo`0?Ool3001YOolQ0n0nOol10001Ool000ioo`03001oogoo00moo`<006Yoob03h3ioo`40
005oo`003Woo00<007ooOol03goo0`00Jgoo7`?P?Woo0@000Goo000>Ool00`00Oomoo`0?Ool3001/
OolN0n0nOol10001Ool000ioo`03001oogoo00moo`<006eooad3h3ioo`40005oo`003Woo00<007oo
Ool03goo0`00KGoo7@?P?Woo0@000Goo0008Ool30003Ool00`00Oomoo`0?Ool3001^OolL0n0nOol1
0001Ool000Qoo`03001oogoo00=oo`03001oogoo00moo`<006mooa/3h3ioo`40005oo`002Goo00<0
07ooOol00Woo0`003goo0`00L7oo6P?P?Goo0P000Goo0009Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool3001aOolI0n0nOol10001Ool000Qoo`03001oo`0000=oo`03001oogoo00moo`<0079ooaL3h3mo
o`40005oo`002Goo00<007ooOol00Woo00<007ooOol03goo0`00Lgoo5P?P?goo0@000Goo000>Ool0
0`00Oomoo`0?Ool3001cOolF0n0oOol10001Ool000ioo`03001oogoo00moo`<007AooaD3h3moo`40
005oo`003Woo00<007ooOol03goo0`00MGoo50?P?goo0@000Goo000>Ool00`00Oomoo`0?Ool3001f
OolC0n0oOol10001Ool000ioo`03001oogoo00moo`<007Mooa83h3moo`40005oo`003Woo0P0047oo
0`00N7oo4@?P?goo0@000Goo000>Ool00`00Oomoo`0?Ool3001hOolA0n0oOol10001Ool000ioo`03
001oogoo00moo`<007Uooa03h3moo`40005oo`003Woo00<007ooOol03goo0`00NWoo3`?P?goo0@00
0Goo000>Ool00`00Oomoo`0?Ool3001kOol>0n0oOol10001Ool000ioo`03001oogoo00moo`<007ao
o`d3h3moo`40005oo`003Woo00<007ooOol03goo0`00OGoo2`?P@7oo0@000Goo000>Ool00`00Oomo
o`0?Ool3001mOol;0n10Ool10001Ool000ioo`03001oogoo00moo`<007ioo`X3h41oo`40005oo`00
3Woo00<007ooOol03goo0`00Ogoo2@?P@7oo0@000Goo000>Ool2000@Ool30020Ool80n10Ool10001
Ool000ioo`03001oogoo00moo`<0085oo`L3h41oo`40005oo`003Woo00<007ooOol03goo0`00PWoo
1P?P@7oo0@000Goo000>Ool00`00Oomoo`0?Ool30022Ool60n10Ool10001Ool000ioo`03001oogoo
00moo`<008=oo`D3h41oo`40005oo`003Woo00<007ooOol03goo0`00Q7oo10?P@7oo0@000Goo000>
Ool00`00Oomoo`0?Ool30025Ool30n10Ool10001Ool000ioo`03001oogoo00moo`<008Ioo`83h41o
o`40005oo`003Woo00<007ooOol03goo0`00Q7oo00D07`000003h00O03moo`40005oo`003Woo0P00
47oo0`00O7oo200O100000<07gooOol0?Goo0@000Goo000>Ool00`00Oomoo`0?Ool3001eOol?01l4
00000`0OOomoo`0mOol10001Ool000ioo`03001oogoo00moo`<006eooaL07`03Ool00000045oo`40
005oo`003Woo00<007ooOol03goo0`00IGoo5`0OC7oo0@000Goo000>Ool00`00Oomoo`0?Ool3001N
OolG01mCOol10001Ool000ioo`03001oogoo00moo`<005IooaL07e]oo`40005oo`003Woo00<007oo
Ool03goo0`00CWoo5`0OHgoo0@000Goo000>Ool00`00Oomoo`0?Ool30017OolG01mZOol10001Ool0
00ioo`03001oogoo00moo`<003mooaL07g9oo`40005oo`003Woo0P0047oo0`00>7oo5P0ONWoo0@00
0Goo000>Ool00`00Oomoo`0?Ool3000`OolG01n1Ool10001Ool000ioo`03001oogoo00moo`<002Qo
oaL07hUoo`40005oo`003Woo00<007ooOol03goo0`008Goo5`0OT7oo0@000Goo000>Ool00`00Oomo
o`0?Ool3000IOolG01nHOol10001Ool000ioo`03001oogoo00moo`<0015ooaL07j1oo`40005oo`00
3Woo00<007ooOol03goo0`002Woo5`0OYgoo0@000Goo0008Ool20004Ool00`00Oomoo`0?Ool30002
OolG01n_Ool10001Ool000Yoo`05001oogooOol0000@Ool00`0001l07`0B01ngOol10001Ool000Uo
o`03001oogoo009oo`<000eoo`8000d07keoo`80005oo`002Woo00D007ooOomoo`0000moo`8000D0
7lIoo`40005oo`0027oo00<007oo00000goo00<007ooOol03Woo0P00bWoo0@000Goo0009Ool00`00
Oomoo`02Ool00`00Oomoo`3JOol10001Ool000ioo`03001oogoo0=Yoo`40005oo`003Woo00<007oo
Ool0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`03001oogoo0=Yoo`40005oo`00
3Woo00<007ooOol0fWoo0@000Goo000>Ool2003KOol10001Ool000ioo`03001oogoo0=Yoo`40005o
o`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`03001oogoo
0=Yoo`40005oo`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000io
o`03001oogoo0=Yoo`40005oo`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol1
0001Ool000ioo`800=]oo`40005oo`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3J
Ool10001Ool000ioo`03001oogoo0=Yoo`40005oo`003Woo00<007ooOol0fWoo0@000Goo000>Ool0
0`00Oomoo`3JOol10001Ool000ioo`03001oogoo0=Yoo`40005oo`003Woo00<007ooOol0fWoo0@00
0Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`800=]oo`40005oo`003Woo00<007ooOol0fWoo
0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`03001oogoo0=Yoo`40005oo`003Woo00<0
07ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`03001oogoo0=Yoo`40005o
o`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`800=]oo`40
005oo`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`03001o
ogoo0=Yoo`40005oo`003Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool0
00ioo`03001oogoo0=Yoo`40005oo`002Goo0`000Woo00<007ooOol0fWoo0@000Goo000:Ool01@00
Oomoogoo0000g7oo0@000Goo0008Ool40002Ool3003IOol20001Ool000Qoo`03001oo`0000=oo`03
001oogoo0=Yoo`40005oo`002Goo0P000goo00<007ooOol0fWoo0@000Goo000:Ool01@00Oomoogoo
0000g7oo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`03001oogoo0=Yoo`40005oo`00
3Woo00<007ooOol0fWoo0@000Goo000>Ool00`00Oomoo`3JOol10001Ool000ioo`03001oogoo011o
o`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo00mo
o`40005oo`003WoogP000Goo003]Ool00>eoo`00kGoo0000\
\>"],
  ImageRangeCache->{{{0, 236}, {285, 0}} -> {-2.72053, -1.9212, 0.0217088, 
  0.0217088}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes all of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Space-Crank Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of generalized coordinate constraints in a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model, a 3D model of a spatial slider-crank mechanism is developed. The \
model consists of three moving bodies; a slider, crank, and connecting rod. A \
geometrically similar model is presented in Section 3.2 of the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " manual. The model presented here differs in that it uses a separate body \
to represent the connecting rod, instead of simply replacing it with a \
relative-distance constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This loads the Generalized Coordinate packages and defines some useful \
constants."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`GenCrd3D`\>"]\), 
    \(Off[General::"\<spell1\>"]\), 
    \(\(X = {1, 0, 0}; \)\), 
    \(\(Y = {0, 1, 0}; \)\), 
    \(\(Z = {0, 0, 1}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the complete space-crank graphic. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!  
%%Creator: Mathematica  
%%AspectRatio: .83498   
MathPictureStart  
%% Graphics3D  
/Courier findfont 10  scalefont  setfont  
% Scaling calculations  
-0.0177149 0.992893 -0.0316522 0.992893 [  
[ 0 0 0 0 ]  
[ 1 .83498 0 0 ]  
] MathScale  
% Start of Graphics  
1 setlinecap  
1 setlinejoin  
newpath  
[ ] 0 setdash  
0 g  
0 0 m  
1 0 L  
1 .83498 L  
0 .83498 L  
closepath  
clip  
newpath  
p  
.002 w  
.67169 .36171 m  
.68339 .81015 L  
s  
.68339 .81015 m  
.97518 .70072 L  
s  
.97518 .70072 m  
.94115 .1703 L  
s  
.94115 .1703 m  
.67169 .36171 L  
s  
.05344 .26268 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.02482 .75387 L  
s  
.02482 .75387 m  
.05344 .26268 L  
s  
.67169 .36171 m  
.68339 .81015 L  
s  
.68339 .81015 m  
.02482 .75387 L  
s  
.02482 .75387 m  
.05344 .26268 L  
s  
.05344 .26268 m  
.67169 .36171 L  
s  
.94115 .1703 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.97518 .70072 L  
s  
.97518 .70072 m  
.94115 .1703 L  
s  
P  
p  
.008 w  
.69732 .39447 m  
.70802 .75843 L  
s  
P  
p  
.002 w  
.75376 .47515 m .7838 .39367 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.74515 .56635 m .75376 .47515 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.7838 .39367 m .75376 .47515 L .73819 .47292 L p  
.761 .71 .804 r  
F P  
s  
P  
p  
.002 w  
.75376 .47515 m .74515 .56635 L .7295 .56435 L p  
.785 .634 .694 r  
F P  
s  
P  
p  
.002 w  
.7295 .56435 m .73819 .47292 L .75376 .47515 L p  
.785 .634 .694 r  
F P  
s  
P  
p  
.002 w  
.73819 .47292 m .76808 .39119 L .7838 .39367 L p  
.761 .71 .804 r  
F P  
s  
P  
p  
.002 w  
.76006 .64706 m .74515 .56635 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.73819 .47292 m .76808 .39119 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.74515 .56635 m .76006 .64706 L .74414 .64524 L p  
.785 .531 .553 r  
F P  
s  
P  
p  
.002 w  
.74414 .64524 m .7295 .56435 L .74515 .56635 L p  
.785 .531 .553 r  
F P  
s  
P  
p  
.002 w  
.7295 .56435 m .73819 .47292 L p  
.79168 .5407 L .291 .2 .577 r  
F P  
s  
P  
p  
.8421 .60457 m .81306 .5942 L .79168 .5407 L .291 .2 .577 r  
F  
P  
p  
.81306 .5942 m .7295 .56435 L .79168 .5407 L .291 .2 .577 r  
F  
P  
p  
.83102 .624 m .7295 .56435 L .8421 .60457 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.82317 .63779 m .83908 .65079 L p  
.82295 .63817 L .556 .521 .772 r  
F P  
s  
P  
p  
.79136 .6007 m .77466 .61645 L .7295 .56435 L .291 .2 .577 r  
F  
P  
p  
.81674 .61561 m .79987 .6225 L .79136 .6007 L .291 .2 .577 r  
F  
P  
p  
.79987 .6225 m .79392 .62492 L .79136 .6007 L .291 .2 .577 r  
F  
P  
p  
.79392 .62492 m .74414 .64524 L .77466 .61645 L .291 .2 .577 r  
F  
P  
p  
.79392 .62492 m .77466 .61645 L .79136 .6007 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.83959 .64786 m .83908 .65079 L .82317 .63779 L p  
0 .336 .815 r  
F P  
s  
P  
p  
.81688 .62746 m .80311 .63083 L .81674 .61561 L .291 .2 .577 r  
F  
P  
p  
.80311 .63083 m .74414 .64524 L .79987 .6225 L .291 .2 .577 r  
F  
P  
p  
.80311 .63083 m .79987 .6225 L .81674 .61561 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.74414 .64524 m .73584 .59938 L p  
.77466 .61645 L .291 .2 .577 r  
F P  
s  
P  
p  
.81659 .64934 m .74414 .64524 L .81688 .62746 L .291 .2 .577 r  
F  
P  
p  
.81713 .64839 m .81688 .62746 L .83102 .624 L .291 .2 .577 r  
F  
P  
p  
.81659 .64934 m .81688 .62746 L .81713 .64839 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.79628 .69766 m .76006 .64706 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.83207 .66062 m .82264 .67165 L .81735 .66731 L p  
.683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.73584 .59938 m .7295 .56435 L p  
.77466 .61645 L .291 .2 .577 r  
F P  
s  
P  
p  
.83207 .66062 m .81735 .66731 L .81713 .64901 L .683 .512 .648 r  
F  
P  
p  
.83959 .64786 m .82317 .63779 L .83188 .64162 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.83203 .64169 m .83959 .64786 L p  
.83188 .64162 L 0 .336 .815 r  
F P  
s  
P  
p  
.002 w  
.81713 .64839 m .83207 .66062 L p  
.81713 .64901 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.83908 .65079 m .83207 .66062 L .81713 .64839 L p  
.556 .521 .772 r  
F P  
s  
P  
p  
.83908 .65079 m .81713 .64839 L .82295 .63817 L .556 .521 .772 r  
F  
P  
p  
.002 w  
.83585 .65124 m .83959 .64786 L .83203 .64169 L p  
.785 .445 .412 r  
F P  
s  
P  
p  
.002 w  
.83959 .64786 m .83908 .65079 L p  
.82355 .66893 L .748 .959 .661 r  
F P  
s  
P  
p  
.002 w  
.82264 .67165 m .81999 .67407 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.82788 .66271 m .83959 .64786 L .82355 .66893 L .748 .959 .661 r  
F  
P  
p  
.002 w  
.81735 .66731 m .82264 .67165 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.002 w  
.76006 .64706 m .79628 .69766 L .77996 .69593 L p  
.716 .298 .252 r  
F P  
s  
P  
p  
.002 w  
.77996 .69593 m .74414 .64524 L .76006 .64706 L p  
.716 .298 .252 r  
F P  
s  
P  
p  
.002 w  
.77996 .69593 m .74414 .64524 L p  
.83639 .65046 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.83207 .66062 m .82264 .67165 L .81999 .67407 L p  
.748 .959 .661 r  
F P  
s  
P  
p  
.82152 .67186 m .83207 .66062 L .81999 .67407 L .748 .959 .661 r  
F  
P  
p  
.81533 .68077 m .77996 .69593 L .83639 .65046 L .291 .2 .577 r  
F  
P  
p  
.81999 .67407 m .81622 .6775 L .81983 .67366 L .784 .448 .419 r  
F  
P  
p  
.002 w  
.81973 .67341 m .81622 .6775 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.002 w  
.83908 .65079 m .83207 .66062 L p  
.81622 .6775 L .748 .959 .661 r  
F P  
s  
P  
p  
.002 w  
.83319 .65365 m .83959 .64786 L p  
.81622 .6775 L .748 .959 .661 r  
F P  
s  
P  
p  
.88027 .65294 m .81533 .68077 L .83639 .65046 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.81999 .67407 m .81622 .6775 L p  
.82152 .67186 L .748 .959 .661 r  
F P  
s  
P  
p  
.81622 .6775 m .82788 .66271 L .82355 .66893 L .748 .959 .661 r  
F  
P  
p  
.84789 .63391 m .83552 .65041 L .83102 .624 L .291 .2 .577 r  
F  
P  
p  
.88027 .65294 m .83639 .65046 L .84789 .63391 L .291 .2 .577 r  
F  
P  
p  
.83639 .65046 m .83552 .65041 L .84789 .63391 L .291 .2 .577 r  
F  
P  
p  
.83552 .65041 m .81659 .64934 L .82746 .63025 L .291 .2 .577 r  
F  
P  
p  
.83552 .65041 m .82746 .63025 L .83102 .624 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.32291 .27727 m .45723 .29939 L .45704 .36613 L p  
.788 .589 .632 r  
F P  
s  
P  
p  
.39943 .32159 m .45704 .36613 L .43092 .3337 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.37648 .31276 m .39876 .32752 L p  
.39943 .32159 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.39876 .32752 m .45704 .36613 L p  
.39943 .32159 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.40728 .31295 m .39943 .32159 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39943 .32159 m .40728 .31295 L .43416 .33495 L p  
.683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.32291 .27727 m .37648 .31276 L p  
.39943 .32159 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.41255 .30254 m .40728 .31295 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.40003 .31632 m .40557 .31022 L .3997 .31925 L .89 .969 .83 r  
F  
P  
p  
.40557 .31022 m .41255 .30254 L .40723 .30946 L .89 .969 .83 r  
F  
P  
p  
.40557 .31022 m .40723 .30946 L .3997 .31925 L .89 .969 .83 r  
F  
P  
p  
.32291 .27727 m .39943 .32159 L .39989 .31749 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.43416 .33495 m .40728 .31295 L p  
.43564 .33514 L .556 .521 .772 r  
F P  
s  
P  
p  
.002 w  
.40728 .31295 m .41255 .30254 L .45558 .33766 L p  
.556 .521 .772 r  
F P  
s  
P  
p  
.45723 .29939 m .47554 .34133 L .46664 .35326 L .173 .096 .522 r  
F  
P  
p  
.002 w  
.45708 .35031 m .45723 .29939 L p  
.46664 .35326 L .173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.47849 .34809 m .4753 .35078 L p  
.47554 .34133 L .173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.4753 .35078 m .47081 .35455 L p  
.47554 .34133 L .173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.47081 .35455 m .45704 .36613 L p  
.46664 .35326 L .173 .096 .522 r  
F P  
s  
P  
p  
.47554 .34133 m .47081 .35455 L .46664 .35326 L .173 .096 .522 r  
F  
P  
p  
.83188 .64162 m .4806 .35756 L .83203 .64169 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.45704 .36613 m .45708 .35031 L p  
.46664 .35326 L .173 .096 .522 r  
F P  
s  
P  
p  
.43303 .33481 m .47081 .35455 L .46322 .34613 L .481 .626 .915 r  
F  
P  
p  
.43416 .33495 m .46322 .34613 L .45558 .33766 L .481 .626 .915 r  
F  
P  
p  
.43303 .33481 m .46322 .34613 L .43416 .33495 L .481 .626 .915 r  
F  
P  
p  
.4357 .33514 m .40728 .31295 L .45558 .33766 L .556 .521 .772 r  
F  
P  
p  
.002 w  
.45704 .36613 m .47081 .35455 L p  
.43303 .33481 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.45723 .29939 m .47849 .28027 L .47849 .34809 L p  
.173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.34206 .25731 m .32291 .27727 L .45723 .29939 L p  
.584 .802 .982 r  
F P  
s  
P  
p  
.002 w  
.45723 .29939 m .47849 .28027 L .34206 .25731 L p  
.584 .802 .982 r  
F P  
s  
P  
p  
.002 w  
.47849 .34809 m .47849 .28027 L p  
.43517 .29479 L .789 .589 .63 r  
F P  
s  
P  
p  
.49093 .37839 m .43564 .33514 L .49082 .37823 L .556 .521 .772 r  
F  
P  
p  
.43564 .33514 m .40728 .31295 L .4357 .33514 L .556 .521 .772 r  
F  
P  
p  
.43564 .33514 m .4357 .33514 L .82317 .63779 L .556 .521 .772 r  
F  
P  
p  
.43092 .3337 m .43167 .33463 L .43303 .33481 L .481 .626 .915 r  
F  
P  
p  
.43167 .33463 m .45704 .36613 L .43303 .33481 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.41077 .29792 m .41255 .30254 L p  
.40003 .31632 L .89 .969 .83 r  
F P  
s  
P  
p  
.32291 .27727 m .39989 .31749 L .40045 .31257 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.45704 .36613 m .32146 .34526 L .32291 .27727 L p  
.788 .589 .632 r  
F P  
s  
P  
p  
.39017 .32717 m .40045 .31257 L .40003 .31632 L .89 .969 .83 r  
F  
P  
p  
.40045 .31257 m .41077 .29792 L .40003 .31632 L .89 .969 .83 r  
F  
P  
p  
.40045 .31257 m .43303 .33481 L .45558 .33766 L .481 .626 .915 r  
F  
P  
p  
.39989 .31749 m .43303 .33481 L .40045 .31257 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.43416 .33495 m .47485 .36825 L p  
.39943 .32159 L .683 .512 .648 r  
F P  
s  
P  
p  
.47454 .38035 m .39943 .32159 L .47485 .36825 L .683 .512 .648 r  
F  
P  
p  
.002 w  
.47081 .35455 m .47849 .34809 L p  
.45558 .33766 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.45558 .33766 m .82317 .63779 L p  
.4357 .33514 L .556 .521 .772 r  
F P  
s  
P  
p  
.002 w  
.81713 .64839 m .43416 .33495 L p  
.82295 .63817 L .556 .521 .772 r  
F P  
s  
P  
p  
.82295 .63817 m .43416 .33495 L .43564 .33514 L .556 .521 .772 r  
F  
P  
p  
.39989 .31749 m .39943 .32159 L .43092 .3337 L .481 .626 .915 r  
F  
P  
p  
.39017 .32717 m .40003 .31632 L .3997 .31925 L .89 .969 .83 r  
F  
P  
p  
.002 w  
.39804 .32312 m .39017 .32717 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39943 .32159 m .39804 .32312 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39804 .32312 m .39943 .32159 L p  
.81713 .64839 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.81735 .66731 m .39804 .32312 L p  
.81713 .64901 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.81622 .6775 m .39017 .32717 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.002 w  
.39017 .32717 m .39804 .32312 L .81735 .66731 L p  
.784 .448 .419 r  
F P  
s  
P  
p  
.81742 .6675 m .39017 .32717 L .81735 .66731 L .784 .448 .419 r  
F  
P  
p  
.81713 .64901 m .39804 .32312 L .81713 .64839 L .683 .512 .648 r  
F  
P  
p  
.32291 .27727 m .34557 .28758 L .34077 .32642 L .481 .626 .915 r  
F  
P  
p  
.34557 .28758 m .40045 .31257 L .38881 .31527 L .481 .626 .915 r  
F  
P  
p  
.34557 .28758 m .38881 .31527 L .34077 .32642 L .481 .626 .915 r  
F  
P  
p  
.39017 .32717 m .39121 .32509 L .39147 .32531 L .89 .969 .83 r  
F  
P  
p  
.002 w  
.36269 .32987 m .34077 .32642 L p  
.38436 .3163 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.47485 .36825 m .81713 .64839 L p  
.47454 .38035 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.8166 .67472 m .82363 .66482 L .42755 .34008 L p  
.553 .52 .773 r  
F P  
s  
P  
p  
.40045 .31257 m .3912 .3168 L .38881 .31527 L .481 .626 .915 r  
F  
P  
p  
.39121 .32509 m .40289 .30189 L .39147 .32531 L .89 .969 .83 r  
F  
P  
p  
.002 w  
.40289 .30189 m .41077 .29792 L p  
.39147 .32531 L .89 .969 .83 r  
F P  
s  
P  
p  
.40045 .31257 m .45558 .33766 L .41899 .33459 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.39353 .31218 m .40289 .30189 L p  
.39017 .32717 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39017 .32717 m .38826 .32267 L .39353 .31218 L p  
.89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.38826 .32267 m .44949 .373 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.002 w  
.44949 .373 m .8166 .67472 L p  
.42951 .34302 L .553 .52 .773 r  
F P  
s  
P  
p  
.42951 .34302 m .42173 .33635 L .44949 .373 L .553 .52 .773 r  
F  
P  
p  
.40045 .31257 m .41899 .33459 L .3912 .3168 L .481 .626 .915 r  
F  
P  
p  
.8166 .67472 m .42755 .34008 L .42173 .33635 L .553 .52 .773 r  
F  
P  
p  
.002 w  
.3912 .3168 m .38826 .32267 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.4806 .35756 m .4695 .34858 L .48062 .35757 L 0 .336 .815 r  
F  
P  
p  
.4695 .34858 m .46171 .34228 L .46947 .34855 L 0 .336 .815 r  
F  
P  
p  
.4695 .34858 m .46947 .34855 L .48062 .35757 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.47849 .34809 m .46702 .34629 L p  
.45558 .33766 L .481 .626 .915 r  
F P  
s  
P  
p  
.46452 .3388 m .45826 .33817 L .46981 .34673 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.82317 .63779 m .47355 .35234 L p  
.83188 .64162 L 0 .336 .815 r  
F P  
s  
P  
p  
.002 w  
.47355 .35234 m .45558 .33766 L p  
.47223 .35111 L 0 .336 .815 r  
F P  
s  
P  
p  
.83188 .64162 m .47355 .35234 L .47223 .35111 L 0 .336 .815 r  
F  
P  
p  
.46171 .34228 m .46183 .34238 L .48062 .35757 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.46702 .34629 m .46981 .34673 L p  
.46659 .34588 L .789 .589 .63 r  
F P  
s  
P  
p  
.45826 .33817 m .46659 .34588 L .46981 .34673 L .789 .589 .63 r  
F  
P  
p  
.48062 .35757 m .46943 .34852 L .48584 .35918 L 0 .336 .815 r  
F  
P  
p  
.46943 .34852 m .41255 .30254 L .45625 .33631 L 0 .336 .815 r  
F  
P  
p  
.4695 .34858 m .45558 .33766 L .45446 .33642 L 0 .336 .815 r  
F  
P  
p  
.47223 .35111 m .45558 .33766 L .4695 .34858 L 0 .336 .815 r  
F  
P  
p  
.45558 .33766 m .45595 .33794 L .44075 .33642 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.46702 .34629 m .42755 .34008 L p  
.44075 .33642 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.38826 .32267 m .39017 .32717 L .47849 .39979 L p  
0 .319 .803 r  
F P  
s  
P  
p  
.002 w  
.47849 .39979 m .81622 .6775 L p  
.45416 .37731 L 0 .319 .803 r  
F P  
s  
P  
p  
.45416 .37731 m .38826 .32267 L .47849 .39979 L 0 .319 .803 r  
F  
P  
p  
.44075 .33642 m .42755 .34008 L .41734 .33446 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.40289 .30189 m .39353 .31218 L .42755 .34008 L p  
.683 .511 .647 r  
F P  
s  
P  
p  
.002 w  
.42755 .34008 m .39353 .31218 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.46171 .34228 m .41255 .30254 L .46183 .34238 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.45558 .33766 m .41255 .30254 L p  
.45446 .33642 L 0 .336 .815 r  
F P  
s  
P  
p  
.43933 .32416 m .42705 .33505 L .45826 .33817 L .789 .589 .63 r  
F  
P  
p  
.4447 .32561 m .45826 .33817 L .46452 .3388 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.46981 .34673 m .47849 .34809 L p  
.46456 .33096 L .789 .589 .63 r  
F P  
s  
P  
p  
.43517 .29479 m .45814 .32923 L .46456 .33096 L .789 .589 .63 r  
F  
P  
p  
.45814 .32923 m .46981 .34673 L .46456 .33096 L .789 .589 .63 r  
F  
P  
p  
.48584 .35918 m .41255 .30254 L .4447 .32561 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.41255 .30254 m .41077 .29792 L .4447 .32561 L p  
0 .336 .815 r  
F P  
s  
P  
p  
.83188 .64162 m .47223 .35111 L .4695 .34858 L 0 .336 .815 r  
F  
P  
p  
.46943 .34852 m .45625 .33631 L .48584 .35918 L 0 .336 .815 r  
F  
P  
p  
.82295 .63817 m .49093 .37839 L .82317 .63779 L .556 .521 .772 r  
F  
P  
p  
.49093 .37839 m .49082 .37823 L .82317 .63779 L .556 .521 .772 r  
F  
P  
p  
.4806 .35756 m .48062 .35757 L .83203 .64169 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.48584 .35918 m .83203 .64169 L p  
.48062 .35757 L 0 .336 .815 r  
F P  
s  
P  
p  
.002 w  
.83203 .64169 m .4447 .32561 L p  
.83585 .65124 L .785 .445 .412 r  
F P  
s  
P  
p  
.002 w  
.4447 .32561 m .41077 .29792 L p  
.44379 .32536 L .785 .445 .412 r  
F P  
s  
P  
p  
.44316 .32519 m .41077 .29792 L .42561 .32047 L .785 .445 .412 r  
F  
P  
p  
.002 w  
.41077 .29792 m .40289 .30189 L .42561 .32047 L p  
.785 .445 .412 r  
F P  
s  
P  
p  
.43933 .32416 m .45826 .33817 L .4447 .32561 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.83319 .65365 m .83585 .65124 L p  
.44379 .32536 L .785 .445 .412 r  
F P  
s  
P  
p  
.44316 .32519 m .44379 .32536 L .41077 .29792 L .785 .445 .412 r  
F  
P  
p  
.83319 .65365 m .44379 .32536 L .44316 .32519 L .785 .445 .412 r  
F  
P  
p  
.002 w  
.47849 .28027 m .34206 .25731 L .3413 .29777 L p  
.789 .589 .63 r  
F P  
s  
P  
p  
.002 w  
.3413 .29777 m .34077 .32642 L p  
.38842 .31045 L .789 .589 .63 r  
F P  
s  
P  
p  
.42561 .32047 m .42705 .33505 L .43933 .32416 L .789 .589 .63 r  
F  
P  
p  
.42572 .32159 m .40289 .30189 L .42755 .34008 L .683 .511 .647 r  
F  
P  
p  
.002 w  
.42755 .34008 m .46702 .34629 L p  
.42711 .33558 L .789 .589 .63 r  
F P  
s  
P  
p  
.424 .33474 m .42755 .34008 L .42711 .33558 L .789 .589 .63 r  
F  
P  
p  
.45595 .33794 m .46702 .34629 L .44075 .33642 L .481 .626 .915 r  
F  
P  
p  
.424 .33474 m .46702 .34629 L .46659 .34588 L .789 .589 .63 r  
F  
P  
p  
.45826 .33817 m .424 .33474 L .46659 .34588 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.82363 .66482 m .83319 .65365 L .42561 .32047 L p  
.683 .511 .647 r  
F P  
s  
P  
p  
.002 w  
.42561 .32047 m .40289 .30189 L p  
.42572 .32159 L .683 .511 .647 r  
F P  
s  
P  
p  
.82363 .66482 m .42561 .32047 L .42572 .32159 L .683 .511 .647 r  
F  
P  
p  
.48175 .36991 m .42572 .32159 L .42755 .34008 L .683 .511 .647 r  
F  
P  
p  
.42346 .29871 m .3413 .29777 L .38842 .31045 L .789 .589 .63 r  
F  
P  
p  
.47849 .28027 m .42235 .28743 L .42346 .29871 L .789 .589 .63 r  
F  
P  
p  
.42235 .28743 m .3413 .29777 L .42346 .29871 L .789 .589 .63 r  
F  
P  
p  
.4107 .30299 m .43933 .32416 L .4447 .32561 L .789 .589 .63 r  
F  
P  
p  
.83585 .65124 m .4447 .32561 L .44379 .32536 L .785 .445 .412 r  
F  
P  
p  
.42492 .31351 m .42561 .32047 L .43933 .32416 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.42561 .32047 m .83319 .65365 L p  
.44316 .32519 L .785 .445 .412 r  
F P  
s  
P  
p  
.002 w  
.39353 .31218 m .3912 .3168 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.4107 .30299 m .38356 .31208 L .42705 .33505 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.81622 .6775 m .8166 .67472 L .44949 .373 L p  
0 .319 .803 r  
F P  
s  
P  
p  
.002 w  
.44949 .373 m .38826 .32267 L p  
.45416 .37731 L 0 .319 .803 r  
F P  
s  
P  
p  
.81622 .6775 m .44949 .373 L .45416 .37731 L 0 .319 .803 r  
F  
P  
p  
.41834 .33418 m .41899 .33459 L .4084 .33371 L .481 .626 .915 r  
F  
P  
p  
.41834 .33418 m .4084 .33371 L .36269 .32987 L .481 .626 .915 r  
F  
P  
p  
.3912 .3168 m .41834 .33418 L .36269 .32987 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.42755 .34008 m .36269 .32987 L p  
.41734 .33446 L .481 .626 .915 r  
F P  
s  
P  
p  
.424 .33474 m .40616 .33296 L .42755 .34008 L .789 .589 .63 r  
F  
P  
p  
.38797 .31829 m .36269 .32987 L .38436 .3163 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.34077 .32642 m .41105 .33748 L p  
.40616 .33296 L .789 .589 .63 r  
F P  
s  
P  
p  
.002 w  
.41105 .33748 m .42755 .34008 L p  
.40616 .33296 L .789 .589 .63 r  
F P  
s  
P  
p  
.38881 .31527 m .38797 .31829 L .38436 .3163 L .481 .626 .915 r  
F  
P  
p  
.3912 .3168 m .38797 .31829 L .38881 .31527 L .481 .626 .915 r  
F  
P  
p  
.38356 .31208 m .34077 .32642 L .40616 .33296 L .789 .589 .63 r  
F  
P  
p  
.38356 .31208 m .40616 .33296 L .42705 .33505 L .789 .589 .63 r  
F  
P  
p  
.4107 .30299 m .42705 .33505 L .42492 .31351 L .789 .589 .63 r  
F  
P  
p  
.43517 .29479 m .41774 .30063 L .46452 .3388 L .789 .589 .63 r  
F  
P  
p  
.41774 .30063 m .4107 .30299 L .4447 .32561 L .789 .589 .63 r  
F  
P  
p  
.41774 .30063 m .4447 .32561 L .46452 .3388 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.42755 .34008 m .82363 .66482 L p  
.48175 .36991 L .683 .511 .647 r  
F P  
s  
P  
p  
.83102 .624 m .81688 .62746 L .81674 .61561 L .291 .2 .577 r  
F  
P  
p  
.88027 .65294 m .83102 .624 L .8421 .60457 L .291 .2 .577 r  
F  
P  
p  
.008 w  
.3973 .29852 m  
.42113 .30241 L  
s  
P  
p  
.008 w  
.42113 .30241 m  
.43532 .30473 L  
s  
P  
p  
.008 w  
.43532 .30473 m  
.44888 .30694 L  
s  
P  
p  
.008 w  
.44888 .30694 m  
.48067 .31213 L  
s  
P  
p  
.008 w  
.48067 .31213 m  
.49912 .31514 L  
s  
P  
p  
.008 w  
.49912 .31514 m  
.75347 .35666 L  
s  
P  
p  
.008 w  
.58716 .35543 m  
.72318 .37705 L  
s  
P  
p  
.008 w  
.47849 .33815 m  
.58716 .35543 L  
s  
P  
p  
.008 w  
.10888 .30305 m  
.24902 .32482 L  
s  
P  
p  
.008 w  
.24902 .32482 m  
.32165 .3361 L  
s  
P  
p  
.008 w  
.48952 .36218 m  
.69732 .39447 L  
s  
P  
p  
.002 w  
.7838 .39367 m .82922 .34103 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.008 w  
.7188 .38001 m  
.73637 .36817 L  
s  
P  
p  
.008 w  
.69732 .39447 m  
.7188 .38001 L  
s  
P  
p  
.002 w  
.82922 .34103 m .7838 .39367 L .76808 .39119 L p  
.684 .784 .926 r  
F P  
s  
P  
p  
.002 w  
.76808 .39119 m .81317 .33834 L .82922 .34103 L p  
.684 .784 .926 r  
F P  
s  
P  
p  
.002 w  
.76808 .39119 m .81317 .33834 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.008 w  
.73637 .36817 m  
.81197 .31727 L  
s  
P  
p  
.008 w  
.70802 .75843 m  
.8401 .70485 L  
s  
P  
p  
.008 w  
.8344 .30217 m  
.90769 .25282 L  
s  
P  
p  
.008 w  
.81197 .31727 m  
.8344 .30217 L  
s  
P  
p  
.002 w  
.34077 .32642 m .32146 .34526 L .32291 .27727 L p  
.481 .626 .915 r  
F P  
s  
P  
p  
.008 w  
.12518 .28199 m  
.3203 .313 L  
s  
P  
p  
.008 w  
.34338 .28972 m  
.3973 .29852 L  
s  
P  
p  
.002 w  
.34206 .25731 m .32291 .27727 L .32146 .34526 L p  
.092 .025 .48 r  
F P  
s  
P  
p  
.008 w  
.3203 .313 m  
.32214 .3133 L  
s  
P  
p  
.002 w  
.32146 .34526 m .34077 .32642 L .34206 .25731 L p  
.092 .025 .48 r  
F P  
s  
P  
p  
.008 w  
.14434 .25723 m  
.34338 .28972 L  
s  
P  
p  
.008 w  
.2432 .12945 m  
.10888 .30305 L  
s  
P  
p  
.002 w  
.82922 .34103 m .87989 .33275 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.87989 .33275 m .82922 .34103 L .81317 .33834 L p  
.26 .723 .95 r  
F P  
s  
P  
p  
.002 w  
.81317 .33834 m .8634 .32993 L .87989 .33275 L p  
.26 .723 .95 r  
F P  
s  
P  
p  
.002 w  
.81317 .33834 m .8634 .32993 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.89742 .65492 m .84638 .7023 L .79628 .69766 L p  
.297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.79628 .69766 m .84638 .7023 L .8296 .70052 L p  
0 .527 .718 r  
F P  
s  
P  
p  
.002 w  
.8296 .70052 m .77996 .69593 L .79628 .69766 L p  
0 .527 .718 r  
F P  
s  
P  
p  
.002 w  
.88027 .65294 m .8296 .70052 L .77996 .69593 L p  
.291 .2 .577 r  
F P  
s  
P  
p  
.008 w  
.65191 .49173 m  
.67062 .49431 L  
s  
P  
p  
.008 w  
.67062 .49431 m  
.69855 .49816 L  
s  
P  
p  
.008 w  
.69855 .49816 m  
.74087 .504 L  
s  
P  
p  
.008 w  
.74087 .504 m  
.77547 .50878 L  
s  
P  
p  
.008 w  
.77547 .50878 m  
.82119 .51509 L  
s  
P  
p  
.002 w  
.87989 .33275 m .92231 .37563 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.92231 .37563 m .87989 .33275 L .8634 .32993 L p  
.668 .175 .07 r  
F P  
s  
P  
p  
.002 w  
.8634 .32993 m .90539 .37284 L .92231 .37563 L p  
.668 .175 .07 r  
F P  
s  
P  
p  
.002 w  
.8634 .32993 m .90539 .37284 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.82363 .66482 m .83319 .65365 L p  
.81622 .6775 L .748 .959 .661 r  
F P  
s  
P  
p  
.002 w  
.81622 .6775 m .8166 .67472 L .82363 .66482 L p  
.748 .959 .661 r  
F P  
s  
P  
p  
.5 0 0 r  
.03 w  
.82788 .66271 Mdot  
P  
p  
.008 w  
.90769 .25282 m  
.91445 .36768 L  
s  
P  
p  
.008 w  
.90769 .25282 m  
.2432 .12945 L  
s  
P  
p  
.002 w  
.84638 .7023 m .89742 .65492 L .88027 .65294 L p  
.656 .821 .962 r  
F P  
s  
P  
p  
.002 w  
.88027 .65294 m .8296 .70052 L .84638 .7023 L p  
.656 .821 .962 r  
F P  
s  
P  
p  
.008 w  
.8401 .70485 m  
.84638 .7023 L  
s  
P  
p  
.008 w  
.84638 .7023 m  
.93209 .66753 L  
s  
P  
p  
.002 w  
.92231 .37563 m .94287 .46156 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.94287 .46156 m .92231 .37563 L .90539 .37284 L p  
.796 .517 .515 r  
F P  
s  
P  
p  
.002 w  
.90539 .37284 m .92564 .45897 L .94287 .46156 L p  
.796 .517 .515 r  
F P  
s  
P  
p  
.002 w  
.90539 .37284 m .92564 .45897 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.94287 .46156 m .93369 .56573 L .89742 .65492 L p  
.297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.89742 .65492 m .93369 .56573 L .91637 .56345 L p  
.769 .734 .82 r  
F P  
s  
P  
p  
.008 w  
.92706 .58203 m  
.93209 .66753 L  
s  
P  
p  
.002 w  
.91637 .56345 m .88027 .65294 L .89742 .65492 L p  
.769 .734 .82 r  
F P  
s  
P  
p  
.002 w  
.92564 .45897 m .91637 .56345 L .88027 .65294 L p  
.291 .2 .577 r  
F P  
s  
P  
p  
.008 w  
.92214 .49843 m  
.92604 .56472 L  
s  
P  
p  
.002 w  
.93369 .56573 m .94287 .46156 L .92564 .45897 L p  
.798 .644 .69 r  
F P  
s  
P  
p  
.002 w  
.92564 .45897 m .91637 .56345 L .93369 .56573 L p  
.798 .644 .69 r  
F P  
s  
P  
p  
.002 w  
.05344 .26268 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.02482 .75387 L  
s  
.02482 .75387 m  
.05344 .26268 L  
s  
.94115 .1703 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.97518 .70072 L  
s  
.97518 .70072 m  
.94115 .1703 L  
s  
P  
p  
P  
% End of Graphics  
MathPictureEnd  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 235},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000ja000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000mOol3003JOol003aoo`80
009oo`D00=Eoo`00?7oo0P001goo1@00d7oo000kOol00`00Ool0000<Ool5003;Ool003Yoo`04001o
ogoo000AOol50036Ool003Yoo`04001oogoo000FOol50031Ool003Uoo`05001oogooOol0000KOol5
002lOol003Qoo`03001oogoo009oo`03001oogoo01ioo`D00;Moo`00>7oo00<007ooOol00Woo00<0
07ooOol08goo1@00/Woo000gOol00`00Oomoo`03Ool00`00Oomoo`0XOol5002]Ool003Ioo`03001o
ogoo00Aoo`03001oogoo02eoo`@00:Uoo`00=Goo00<007ooOol01Goo00<007ooOol0<Goo1@00Y7oo
000eOol00`00Oomoo`05Ool00`00Oomoo`0fOol5002OOol003Aoo`03001oogoo00Ioo`03001oogoo
03]oo`D009Yoo`00<goo00<007ooOol01Woo00<007ooOol0@Goo1@00UGoo000cOol00`00Oomoo`06
Ool00`00Oomoo`16Ool5002@Ool0039oo`03001oogoo00Moo`03001oogoo04]oo`D008]oo`00<Goo
00<007ooOol027oo00<007ooOol0D7oo1@00QWoo000aOol00`00Oomoo`08Ool00`00Oomoo`1EOol5
0021Ool0031oo`03001oogoo00Uoo`03001oogoo05Yoo`D007aoo`00;goo00<007ooOol02Woo00<0
07ooOol0Ggoo1@00Mgoo000_Ool00`00Oomoo`0:Ool00`00Oomoo`1TOol5001bOol002ioo`03001o
ogoo00]oo`03001oogoo06Uoo`D006eoo`00;Goo00<007ooOol037oo00<007ooOol0KWoo1@00J7oo
000]Ool00`00Oomoo`0<Ool00`00Oomoo`1cOol5001SOol002aoo`03001oogoo00eoo`03001oogoo
07Qoo`D005ioo`00:goo00<007ooOol03Woo00<007ooOol0OGoo1@00FGoo000ZOol00`00Oomoo`0?
Ool00`00Oomoo`22Ool5001DOol002Yoo`03001oogoo00moo`03001oogoo08Moo`D004moo`00:Goo
00<007ooOol047oo00<007ooOol017oo0P00QWoo1@00BWoo000XOol00`00Oomoo`0AOol00`00Oomo
o`04Ool70026Ool50015Ool002Qoo`03001oogoo015oo`03001oogoo00=oo`d008Ioo`@0045oo`00
9goo00<007ooOol04Woo00<007ooOol00goo0P001Woo2`00Q7oo1@00?7oo000VOol00`00Oomoo`0C
Ool00`00Oomoo`02Ool2000<Ool;0024Ool5000gOol002Ioo`03001oogoo01=oo`04001oogooOol3
000BOol;0023Ool5000bOol002Eoo`03001oogoo01Aoo`03001oogoo00<001Qoo`/008=oo`D002eo
o`0097oo00<007ooOol05Goo00<007oo00000P007goo2`00PWoo1@00:7oo000TOol00`00Oomoo`0E
Ool01000Ool000009Goo2`00PWoo1@008goo000SOol00`00Oomoo`0FOol3000/Ool;0021Ool5000N
Ool0029oo`03001oogoo01Moo`<0035oo`/0085oo`D001Uoo`008Woo00<007ooOol05Woo0`00>7oo
2`00P7oo1@0057oo000QOol00`00Oomoo`0FOol3000nOol;0020Ool3000AOol0021oo`03001oogoo
01Moo`8004Eoo`/007Yoo`<0015oo`007goo00<007ooOol05goo0`00BWoo2`00M7oo00@007ooOol0
015oo`007goo00<007ooOol05Woo1000D7oo2`00KGoo00D007ooOomoo`00015oo`007Woo00<007oo
Ool05Woo0`0000=oo`00Ool0E7oo2`00IWoo0P0017oo00<007ooOol03goo000MOol00`00Oomoo`0G
Ool20002Ool00`00Oomoo`1IOol:001POol00`00Oomoo`04Ool00`00Oomoo`0?Ool001eoo`03001o
ogoo01Ioo`8000=oo`03001oogoo05ioo`/005Qoo`8000Moo`03001oogoo00moo`0077oo00<007oo
Ool05Woo0`000goo00<007ooOol0Hgoo2`00DWoo00<007ooOol01goo00<007ooOol03goo000KOol0
0`00Oomoo`0FOol30004Ool00`00Oomoo`1YOol;001;Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool0
01]oo`03001oogoo01Eoo`<000Eoo`03001oogoo06ioo`/004Aoo`8000aoo`03001oogoo00ioo`00
6Woo00<007ooOol05Woo0P001Woo00<007ooOol0M7oo2`00?Goo00<007ooOol037oo00<007ooOol0
3Woo000IOol00`00Oomoo`0FOol20007Ool00`00Oomoo`1iOol;000fOol2000?Ool00`00Oomoo`0>
Ool001Uoo`03001oogoo01Eoo`<000Moo`03001oogoo07moo`/002moo`03001oogoo00moo`03001o
ogoo00ioo`0067oo00<007ooOol05Goo0`0027oo00<007ooOol0Q7oo2`00:Goo00<007ooOol047oo
00<007ooOol03Woo000GOol00`00Oomoo`0EOol30009Ool00`00Oomoo`2:Ool;000QOol2000COol0
0`00Oomoo`0>Ool001Moo`03001oogoo01Eoo`8000Yoo`03001oogoo08moo`/001]oo`03001oogoo
01=oo`03001oogoo00ioo`005Woo00<007ooOol05Goo0P002goo00<007ooOol0UGoo2`004goo0P00
5Woo00<007ooOol03Woo000EOol00`00Oomoo`0EOol3000;Ool00`00Oomoo`2JOol;000=Ool00`00
Oomoo`0FOol00`00Oomoo`0>Ool001Aoo`03001oogoo01Eoo`<000aoo`03001oogoo0:1oo`/000Eo
o`8001Uoo`03001oogoo00ioo`0057oo00<007ooOol057oo0`003Goo00<007ooOol0YGoo2`006goo
00<007ooOol03Woo000COol00`00Oomoo`0EOol2000>Ool00`00Oomoo`2[Ool;000EOol00`00Oomo
o`0>Ool0019oo`03001oogoo01Eoo`8000moo`03001oogoo0:aoo`80009oo`/0011oo`03001oogoo
00ioo`004Woo00<007ooOol057oo0`003goo00<007ooOol0Zgoo00<007ooOol027oo2`002Woo00<0
07ooOol03Woo000AOol00`00Oomoo`0DOol3000@Ool00`00Oomoo`2YOol2000@Ool70009Ool00`00
Oomoo`0>Ool0011oo`03001oogoo01Aoo`<0015oo`03001oogoo0:Qoo`03001oogoo019oo`D000Uo
o`03001oogoo00ioo`0047oo00<007ooOol057oo200037oo00<007ooOol08Woo1000PGoo00<007oo
Ool04Woo1P002Woo00<007ooOol03Goo000?Ool4000COol?0006Ool00`00Oomoo`0QOol20003IU@6
001iOol2000COol40002Ool2000:Ool00`00Oomoo`0=Ool000moo`04001oogooOol6000<Ool30007
Ool=000ROol00`0020l00009IU@6001bOol00`00Oomoo`0BOol40003Ool2000:Ool00`00Oomoo`0=
Ool000moo`03001oogoo00Moo`H000Eoo`<000ioo``001]oo`8000883`03001VE6ID00eVE0L006Uo
o`8001=oo`@000Eoo`8000Yoo`03001oogoo00eoo`003goo00<007ooOol03Goo1`0057oo3P004goo
00<000P?20l00PP?00<006IDIU@056ID1P00HWoo00<007ooOol04Woo10001Woo0P002Woo00<007oo
Ool03Goo000?Ool00`00Oomoo`0AOol8000?Ool00`00Oomoo`04Ool=000<Ool00`0020l83`0320l0
0`00IUAVE00JIU@6001KOol00`00Oomoo`0BOol30008Ool2000:Ool00`00Oomoo`0=Ool000moo`03
001oogoo011oo`<000Ioo`H000Uoo`03001oogoo00]oo``000Ioo`0300083`P?00<83`03001VE6ID
021VE0@005Eoo`8001=oo`@000Uoo`8000Yoo`03001oogoo00eoo`003goo00<007ooOol03goo2@00
1goo1`000Woo00<007ooOol04Goo3@001@P?00<006IDIU@08fID00<007ooOol0DWoo00<007ooOol0
4Woo10002Woo0P002Woo00<007ooOol03Goo000?Ool00`00Oomoo`0>OolA0007Ool6000FOol=000U
IU@00`00Oomoo`1@Ool2000COol4000<Ool2000:Ool00`00Oomoo`0=Ool000moo`03001oogoo00io
o`8000Qoo`h0009oo`04001oogooOol6000FOol>000NIU@00`00Oomoo`1?Ool00`00Oomoo`0BOol4
000=Ool2000:Ool00`00Oomoo`0=Ool000ioo`03001oogoo00ioo`80011oo`h000Eoo`H0011oo`03
00083`P?00883a4001IVE003001oogoo04ioo`03001oogoo015oo`@000moo`8000Yoo`03001oogoo
00eoo`003Woo00<007ooOol037oo10005goo3P0017oo1P002Woo00<000P?20l00PP?00<006IDIU@0
1VID3`003fID00<007ooOol0C7oo0P004goo100047oo0P002Woo00<007ooOol03Goo000>Ool00`00
Oomoo`0<Ool7000FOol00`00Oomoo`02Ool>0003Ool70003Ool00`0020l83`0220l2000>IU@;000<
IU@00`00Oomoo`1;Ool00`00Oomoo`0AOol4000BOol2000:Ool00`00Oomoo`0=Ool000ioo`03001o
ogoo00eoo``0011oo`03001oogoo00Uoo`h000=oo`@000@83`8001EVE0T000MVE003001oogoo04Uo
o`80019oo`D001=oo`8000Yoo`03001oogoo00eoo`003Woo00<007ooOol04goo30002Woo00<007oo
Ool047oo3P0010P?0P006FID3@00BWoo00<007ooOol04Goo10005Goo0P002Woo00<007ooOol03Goo
000>Ool00`00Oomoo`0IOol;0005Ool00`00Oomoo`0GOol7000420l00`00IUAVE00LIU@?0013Ool0
0`00Oomoo`0@Ool4000HOol20009Ool00`00Oomoo`0=Ool000ioo`03001oogoo01moo`/001moo`03
00083`P?00883`03001VE6ID02AVE0d003]oo`80019oo`@001Uoo`8000Uoo`03001oogoo00eoo`00
3Woo00<007ooOol097oo30006Goo00<000P?20l00PP?00<006IDIU@096ID00<007ooOol00goo3@00
=7oo00<007ooOol047oo10006goo0P002Woo00<007ooOol037oo000>Ool00`00Oomoo`0YOol<000D
Ool00`0020l83`0220l00`00IUAVE00FIU@00`00ILeVE00;IU@00`00Oomoo`0:Ool=000[Ool2000B
Ool4000LOol2000:Ool00`00Oomoo`0<Ool000ioo`03001oogoo02Uoo`03001oogoo00Aoo``000eo
o`0300083`P?00883`03001VE6ID01IVE003EQ@00000009Uc@UVE003001oogoo011oo`d002Aoo`03
001oogoo011oo`@001ioo`8000Yoo`03001oogoo00aoo`003Woo00<007ooOol0:Goo00<007ooOol0
2Goo3P001Woo00D000P?20l83`0000AVE0H000mVE0=F5004001UcFG=ILd7IU@2000HOol=000KOol2
000BOol4000?Ool5000;Ool2000:Ool00`00Oomoo`0<Ool000ioo`03001oogoo02Uoo`03001oogoo
011oo`h000883`03001VE6ID00UVE0L000QVE0AF5005001UcFG=ILd00004IU@200000goo00000004
000HOol=000DOol00`00Oomoo`0AOol3000:Ool700049=840008Ool2000:Ool00`00Oomoo`0<Ool0
00ioo`03001oogoo02Uoo`03001oogoo01Moo`L0000320l006ID015VE0L0009VE0EF5005001UcFG=
ILd00003IU@800000goo00000004000IOol=000<Ool00`00Oomoo`0@Ool40007Ool4000<9=801000
E:9DXP001goo0P002Woo00<007ooOol037oo000>Ool00`00Oomoo`0YOol00`00Oomoo`0MOol2000F
IU@200000dHH000000020005EQ@01@00ILeUcFG=00000fID3@0000=oo`0000001@0067oo3@0017oo
0P004Woo10001goo00<002CB9=803bCB00@005BRE:8000Ioo`8000Yoo`03001oogoo00aoo`003Woo
00<007ooOol0:Goo00<007ooOol07Goo10005FID0P000dHH00=F5000EQ@015HD0P0000=UcFID0000
0VID00<007ooOol017oo2`000goo1P006Goo3@003goo100027oo00<002CB9=804BCB00@005BRE:80
00Eoo`8000Yoo`03001oogoo00aoo`003Woo00<007ooOol0:Goo00<007ooOol08Goo1P0046ID0`00
0dHH0P001EHD00@006G=ILeUc@8000aoo`/000=oo`H001Uoo`d000Qoo`@000Qoo`03000TdRCB01<T
dP04001DXUBR0004Ool2000:Ool00`00Oomoo`0<Ool000ioo`03001oogoo02Uoo`03001oogoo02Mo
o`H000]VE0030001F@0000A66003001F55HD00=F5005001UcFG=ILd0000AOol<0003Ool6000COol0
0`00Oomoo`04Ool@000:Ool00`009=8TdP0D9=801000E:9DXP000goo0P002Woo00<007ooOol037oo
000=Ool00`00Oomoo`0ZOol00`00Oomoo`0]Ool70005IU@30004AQP00`00EQAF5003EQ@01@00ILeU
cFG=00005Woo3@000Woo1P0037oo00<007ooOol02goo2@002Woo00<002CB9=805RCB00@005BRE:80
009oo`8000Yoo`03001oogoo00aoo`003Goo00<007ooOol0:Woo00<007ooOol0=7oo1P0000=VE000
00000dHH0P001EHD00D006G=ILeUc@0001]oo`d0009oo`H000Aoo`80019oo`@000Yoo`03000TdRCB
01PTdP05001DXUBR001oo`02000:Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Yoo`03001oogoo
03Yoo`@000=66003EQ@005HD00AF50800003ILd0000000H001]oo`d00003Ool000000080019oo`@0
00]oo`03000TdRCB01XTdP03001DXUBR00<000Yoo`03001oogoo00aoo`003Goo00<007ooOol0:Woo
00<007ooOol0?Goo0`000dHH0P001EHD00<006G=000030006goo3P003goo10002goo00<002CB9=80
72CB00<005BRE:800P002Woo00<007ooOol037oo000=Ool00`00Oomoo`0YOol00`00Oomoo`0oOol0
0`000ET00004AQP00`00EQAF5003EQ@01@00ILeUcFG=00000goo3@006goo3@001goo100037oo00<0
02CB9=807RCB00<005BRE:800P002Goo00<007ooOol037oo000=Ool00`00Oomoo`0YOol00`00Oomo
o`10Ool00`000ET00004AQP00`00EQAF5003EQ@01@00ILeUcFG=000027oo3@006Goo00<007ooOol0
400037oo00<002CB9=8082CB10002Goo00<007ooOol037oo000=Ool00`00Oomoo`0YOol00`00Oomo
o`12Ool00`000EU66003AQP00`00EQAF5003EQ@20002ILd00`00Oomoo`0<Ool=000BOol00`00Oomo
o`06Ool8000=Ool00`009=8TdP0Q9=800`00IQ0000020009Ool00`00Oomoo`0;Ool000eoo`03001o
ogoo02Uoo`03001oogoo04=oo`<000966003EQ@0000000EF5003001UcFG=0080019oo`d000aoo`03
001oogoo00Qoo`D000ioo`03000TdRCB024TdP05001V46H@IQ000009Ool00`00Oomoo`0;Ool000eo
o`03001oogoo02Uoo`03001oogoo04Aoo`030001F@0000966003EQA6600000EF5005001UcFG=ILd0
000HOol=0005Ool00`00Oomoo`07Ool4000?Ool00`009=8TdP0S9=801000IQ1V40002Goo00<007oo
Ool02goo000=Ool00`00Oomoo`0YOol00`00Oomoo`15Ool00`000ET00004AQP00`00EQAF5003EQ@0
1@00ILeUcFG=00007Goo3@0027oo0`0047oo00<002CB9=8092CB00D006H@IQ1V400000Qoo`03001o
ogoo00]oo`003Goo00<007ooOol0:Goo00<007ooOol0AWoo00<0005I0ET014HH00<005HDEQ@00eHD
00D006G=ILeUc@0002=ooa00011oo`03000TdRCB02DTdP05001V46H@IQ000008Ool00`00Oomoo`0;
Ool000eoo`03001oogoo02Uoo`03001oogoo04Qoo`030ET004HH00=66003001F55HD00=F5080009U
c@03001oogoo02Eoo`X0015oo`03000TdRCB02DTdP05001V46H@IQ000008Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02Uoo`03001oogoo04Uoo`030ET0000000=6608000EF5003001UcFG=008002Eo
o`03001oogoo00Aoo`80015oo`03000TdRCB02HTdP05001V46H@IQ000008Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02Uoo`03001oogoo04Yoo`030001F@0000966003EQA6600000EF5005001UcFG=
ILd0000TOol00`00Oomoo`04Ool2000AOol00`009=8TdP0W9=801@00IQ1V46H@00001goo00<007oo
Ool02goo000=Ool00`00Oomoo`0YOol00`00Oomoo`1;Ool00`000ET00002AQP00eHDAQP00005EQ@0
1@00ILeUcFG=00008goo00<007ooOol017oo0P004Goo00<002CB9=809bCB00D006H@IQ1V400000Mo
o`03001oogoo00]oo`003Goo00<007ooOol0:Goo00<007ooOol0C7oo0P0000<1FDHHAQP00THH00<0
05HDEQ@00eHD00D006G=ILeUc@00029oo`03001oogoo00Aoo`80011oo`03000TdRCB02PTdP05001V
46H@IQ000007Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Uoo`03001oogoo04ioo`8000A66080
00AF5080009Uc@80021oo`03001oogoo00Aoo`80011oo`03000TdRCB02PTdP05001V46H@IQ000007
Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Uoo`03001oogoo04moo`<000A66003001F55HD00=F
5005001UcFG=ILd0000OOol00`00Oomoo`04Ool2000@Ool00`009=8TdP0X9=800`00IQ1V4002IQ00
0`00Oomoo`04Ool00`00Oomoo`0;Ool000aoo`03001oogoo02Yoo`03001oogoo051oo`030001F@00
00A66003001F55HD00=F5005001UcFG=ILd0000NOol00`00Oomoo`04Ool2000?Ool00`009=8TdP0Z
9=801@00IQ1V46H@00001Woo00<007ooOol02goo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1AOol3
0002AQP00eHDAQP00005EQ@01@00ILeUcFG=00007Goo00<007ooOol017oo0P003goo00<002CB9=80
:RCB00D006H@IQ1V400000Ioo`03001oogoo00]oo`0037oo00<007ooOol0:Woo00<007ooOol0Dgoo
00L0005IAQQ665HDAQP00005EQ@01@00ILeUcFG=000077oo00<007ooOol017oo0P003goo00<002CB
9=80:RCB00D006H@IQ1V400000Ioo`03001oogoo00]oo`0037oo00<007ooOol0:Woo00<007ooOol0
E7oo0P0014HH0P0015HD0P000VG=0P006Woo00<007ooOol017oo0P003Woo00<002CB9=80:bCB00<0
06H@IQ000VH@00<007ooOol00goo00<007ooOol02goo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1E
Ool30004AQP00`00EQAF5003EQ@01@00ILeUcFG=00006Goo00<007ooOol017oo0P003Woo00<002CB
9=80;2CB00D006H@IQ1V400000Eoo`03001oogoo00]oo`0037oo00<007ooOol0:Woo00<007ooOol0
EWoo00<0005I000014HH00<005HDEQ@00eHD00D006G=ILeUc@0001Qoo`03001oogoo00Aoo`8000eo
o`03000TdRCB02dTdP05001V46H@IQ000006Ool00`00Oomoo`0:Ool000aoo`03001oogoo02Yoo`03
001oogoo05Moo`8000030EU664HH00966003001F55HD00=F5005001UcFG=ILd0000HOol00`00Oomo
o`03Ool2000=Ool00`009=8TdP0]9=801@00IQ1V46H@00001Woo00<007ooOol02Woo000<Ool00`00
Oomoo`0ZOol00`00Oomoo`1IOol20002AQP00eHDAQP00005EQ@20002ILd2000FOol00`00Oomoo`03
Ool2000=Ool00`009=8TdP0]9=800`00IQ1V4002IQ000`00Oomoo`03Ool00`00Oomoo`0:Ool000ao
o`03001oogoo02Yoo`03001oogoo05Yoo`<00003AQP004HH008000EF5005001UcFG=ILd0000EOol0
0`00Oomoo`03Ool2000<Ool00`009=8TdP0^9=800`00IQ1V4002IQ000`00Oomoo`03Ool00`00Oomo
o`0:Ool000aoo`03001oogoo02Yoo`03001oogoo05]oo`030001F@0000A66003001F55HD00=F5005
001UcFG=ILd0000DOol00`00Oomoo`03Ool2000<Ool00`009=8TdP0_9=801@00IQ1V46H@00001Goo
00<007ooOol02Woo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1LOol30004AQP00`00EQAF5003EQ@0
1@00ILeUcFG=00004goo00<007ooOol00goo0P0037oo00<002CB9=80;bCB00<006H@IQ000VH@1Goo
00<007ooOol02Woo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1NOol00`000EU66003AQP00`00EQAF
5003EQ@01000ILeUcFG=0P004Goo00<007ooOol00goo0P002goo00<002CB9=80<2CB0`000VH@00<0
07ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1OOol20004AQP20004
EQ@20003ILd00`00Oomoo`0>Ool00`00Oomoo`03Ool2000;Ool00`009=8TdP0`9=800`00IYIVUP03
0004Ool00`00Oomoo`0:Ool000aoo`03001oogoo02Yoo`03001oogoo061oo`<00005AQP004HHAQP0
0005EQ@01@00ILeUcFG=00003goo00<007ooOol00goo0P002goo00<002CB9=80<2CB00<006JFIYH0
0VJF00<007ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0YOol00`00Oomoo`1ROol30004
AQP00`00EQAF5003EQ@01@00ILeUcFG=00003Woo00<007ooOol00goo0P002Woo00<002CB9=80<BCB
00<006JFIYH00VJF00<007ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0YOol00`00Oomo
o`1TOol20004AQP00`00EQAF5003EQ@01@00ILeUcFG=00003Goo00<007ooOol00goo0P002Woo00<0
02CB9=80<BCB00<006JFIYH00VJF00<007ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0Y
Ool00`00Oomoo`1UOol00`000EU66003AQP00`00EQAF5003EQ@01000ILeUcFG=0P002goo00<007oo
Ool00goo0P002Woo00<002CB9=80<BCB00<006JFIYH00VJF00<007ooOol00Woo00<007ooOol02Woo
000;Ool00`00Oomoo`0ZOol00`00Oomoo`1VOol20004AQP20004EQ@20003ILd00`00Oomoo`08Ool0
0`00Oomoo`03Ool2000:Ool00`009=8TdP0a9=800`00IYIVUP02IYH00`00Oomoo`02Ool00`00Oomo
o`0:Ool000]oo`03001oogoo02Yoo`03001oogoo06Moo`<000A66003001F55HD00=F5005001UcFG=
ILd00009Ool00`00Oomoo`03Ool2000:Ool00`009=8TdP0a9=800`00IYIVUP02IYH00`00Oomoo`02
Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Yoo`03001oogoo06Qoo`<00005AQP004HHAQP00005
EQ@01`00ILeUcFG=001oo`0000Ioo`03001oogoo00=oo`8000Yoo`03000TdRCB030TdP03001VUVJF
00=VUP03001oogoo009oo`03001oogoo00Yoo`002goo00<007ooOol0:Woo00<007ooOol0JWoo0P00
14HH00<005HDEQ@00eHD00@006G=ILeUc@T000Eoo`8000Uoo`03000TdRCB034TdP03001VUVJF009V
UP03001oogoo00=oo`03001oogoo00Yoo`002goo00<007ooOol0:Woo00<007ooOol0Jgoo0P0014HH
0P0015HD0P000fG=3P002Goo00<002CB9=80<BCB00<006JFIYH00VJF00<007ooOol00goo00<007oo
Ool02Woo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1/Ool30004AQP00`00EQAF5003EQ@01@00ILeU
cFG=00000goo3P0017oo00<002CB9=80<2CB0P0016JF00<007ooOol017oo00<007ooOol02Goo000;
Ool00`00Oomoo`0ZOol00`00Oomoo`1]Ool30004AQP00`00EQAF5003EQ@01@00ILeUcFG=00000goo
00<007ooOol00goo3P00<BCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo000;Ool0
0`00Oomoo`0ZOol00`00Oomoo`1_Ool20004AQP00`00EQAF5003EQ@01@00ILeUcFG=00000Woo00<0
07ooOol00goo0P001Goo3`00:BCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo000;
Ool00`00Oomoo`0ZOol00`00Oomoo`1`Ool010000EU660000THH00<005HDEQ@00eHD00@006G=ILeU
c@<000Eoo`8000Uoo`03000TdP0000l0028TdP03001VUVJF009VUP03001oogoo00Aoo`03001oogoo
00Uoo`002goo00<007ooOol0:Woo00<007ooOol0LGoo0P0014HH0P0015HD0P000fG=00<007ooOol0
0goo0P002Goo00<002CB9=8022CB3P006bCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol0
2Goo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1bOol30004AQP00`00EQAF5003EQ@01@00ILeUcFG=
00001Goo0P0027oo00<002CB9=803bCB1`006bCB00<006JFIYH00VJF00<007ooOol017oo00<007oo
Ool02Goo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1dOol20004AQP00`00EQAF5003EQ@01@00ILeU
cFG=000017oo0P001goo00<002CB9=80<RCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol0
2Goo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1eOol20004AQP00`00EQAF5003EQ@01000ILeUcFG=
0P000Woo0P001goo00<002CB9=80<RCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo
000;Ool00`00Oomoo`0ZOol00`00Oomoo`1fOol00`000EU66003AQP20004EQ@00`00ILeUc@02ILd0
1000Ool000001goo00<002CB9=80<RCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo
000;Ool00`00Oomoo`0ZOol00`00Oomoo`1gOol200000dHH00166002AQP00`00EQAF5002EQ@20003
ILd30007Ool00`009=8TdP0b9=800`00IYIVUP02IYH00`00Oomoo`04Ool00`00Oomoo`09Ool000]o
o`03001oogoo02Yoo`03001oogoo07Uoo`8000A66003001F55HD00=F5004001UcFG=ILd20007Ool0
0`009=8TdP0b9=800`00IYIVUP02IYH00`00Oomoo`04Ool00`00Oomoo`09Ool000]oo`03001oogoo
02Yoo`03001oogoo07Yoo`8000A66003001F55HD00=F5004001UcFG=ILd20006Ool00`009=8TdP0a
9=800`00IYIVUP03IYH00`00Oomoo`04Ool00`00Oomoo`09Ool000Yoo`03001oogoo02]oo`03001o
ogoo07]oo`8000A66003001F55HD00=F5003001UcFG=009Uc@03001oogoo00=oo`03000TdRCB034T
dP03001VUVJF009VUP03001oogoo00Eoo`03001oogoo00Uoo`002Woo00<007ooOol0:goo00<007oo
Ool0O7oo0P0014HH0P0015HD0P000fG=00<007ooOol00Woo00<002CB9=80<BCB00<006JFIYH00VJF
00<007ooOol01Goo00<007ooOol02Goo000:Ool00`00Oomoo`0[Ool00`00Oomoo`1mOol20005AQP0
0`00EQAF5003EQ@01@00ILeUcFG=00000goo00<002CB9=80<BCB00<006JFIYH00VJF00<007ooOol0
1Goo00<007ooOol02Goo000:Ool00`00Oomoo`0[Ool00`00Oomoo`1oOol200001FG=AQQ664HH0000
1EHD00L006G=ILeUc@00Ool0000d9=800`00IYIVUP02IYH00`00Oomoo`05Ool00`00Oomoo`09Ool0
00Yoo`03001oogoo02]oo`03001oogoo081oo`8000A66003001F55HD00=F5004001UcFG=ILd2000d
9=800`00IYIVUP02IYH00`00Oomoo`06Ool00`00Oomoo`08Ool000Yoo`03001oogoo02]oo`03001o
ogoo085oo`030001FDHH00=6608000AF5003001UcFG=009Uc@03000TdRCB034TdP03001VUVJF009V
UP03001oogoo00Ioo`03001oogoo00Qoo`002Woo00<007ooOol0:goo00<007ooOol0PWoo0P001DHH
00<005HDEQ@00UHD0P000fG=00<002CB9=80<2CB0`000VJF00<007ooOol01Woo00<007ooOol027oo
000:Ool00`00Oomoo`0[Ool00`00Oomoo`22Ool01000Ool0000014HH00<005HDEQ@00eHD00D006G=
ILeUc@00034TdP03001RnP0000<000Qoo`03001oogoo00Qoo`002Woo00<007ooOol0:Woo00<007oo
Ool0Pgoo00<007ooOol00P0014HH00<005HDEQ@00eHD00@006G=ILeUc@8002hTdP03001RnV;j0080
0003H_X007oo00Moo`03001oogoo00Qoo`002Woo00<007ooOol0:Woo00<007ooOol0Pgoo00@007oo
Oomoo`8000A66003001F55HD00=F5003001UcFG=009Uc@03000TdRCB02/TdP03001RnV;j009RnP03
001oogoo00Moo`03001oogoo00Qoo`002Woo00<007ooOol0:Woo00<007ooOol0Pgoo00<007ooOol0
0Woo00<0005IAQP00dHH0P0015HD00<006G=ILd00VG=00<002CB9=80:BCB00<006;jH_X00f;j00<0
07ooOol01goo00<007ooOol027oo000:Ool00`00Oomoo`0ZOol00`00Oomoo`23Ool00`00Oomoo`04
Ool00`00AQQ66003AQP00`00EQAF5002EQ@20003ILd00`009=8TdP0X9=800`00H_YRnP02H_X00`00
Oomoo`08Ool00`00Oomoo`08Ool000Yoo`03001oogoo02Yoo`03001oogoo08=oo`03001oogoo00Ao
o`<000A66003001F55HD00=F5005001UcFG=ILd0000Y9=801000H_YRnV;j0P002Woo00<007ooOol0
27oo000:Ool00`00Oomoo`0ZOol00`00Oomoo`23Ool00`00Oomoo`04Ool40004AQP00`00EQAF5003
EQ@01000ILeUcFG=0P009RCB00<006;jH_X00V;j0`002Goo00<007ooOol027oo000:Ool00`00Oomo
o`0ZOol00`00Oomoo`24Ool00`00Oomoo`03Ool200000goo00000004AQP00`00EQAF5003EQ@00`00
ILeUc@02ILd00`009=8TdP0S9=800`00H_YRnP02H_X30009Ool00`00Oomoo`08Ool000Yoo`03001o
ogoo02Yoo`03001oogoo08Aoo`03001oogoo00=oo`8000=oo`03001664HH0096608000AF5003001U
cFG=009Uc@03000TdRCB024TdP03001RnV;j009RnP04001oo`000009Ool00`00Oomoo`08Ool000Yo
o`03001oogoo02Yoo`03001oogoo08Aoo`03001oogoo00=oo`8000Aoo`03001664HH00=66003001F
55HD009F508000=Uc@03000TdRCB020TdP03001RnV;j009RnP04001oo`000009Ool00`00Oomoo`08
Ool000Uoo`03001oogoo02]oo`03001oogoo08Aoo`03001oogoo00=oo`8000Eoo`8000A66003001F
55HD00=F5004001UcFG=ILd2000P9=800`00H_YRnP02H_X01000Ool000002Goo00<007ooOol027oo
0009Ool00`00Oomoo`0[Ool00`00Oomoo`24Ool00`00Oomoo`03Ool20006Ool20004AQP00`00EQAF
5003EQ@00`00ILeUc@02ILd00`009=8TdP0L9=800`00H_YRnP02H_X00`00Oomoo`020009Ool00`00
Oomoo`08Ool000Uoo`03001oogoo02]oo`03001oogoo08Aoo`03001oogoo00=oo`8000Moo`8000A6
608000AF5003001UcFG=009Uc@03000TdRCB01/TdP03001RnV;j009RnP03001oogoo008000Uoo`03
001oogoo00Qoo`002Goo00<007ooOol0:goo00<007ooOol0Q7oo00<007ooOol00goo0P0027oo0P00
1DHH00<005HDEQ@00UHD0P000fG=00<002CB9=806BCB00<006;jH_X00V;j00@007ooOomoo`8000Uo
o`03001oogoo00Qoo`002Goo00<007ooOol0:goo1@00PWoo00<007ooOol00goo0P002Goo0`0014HH
00<005HDEQ@00eHD00@006G=ILeUc@8001TTdP03001RnV;j009RnP04001oogooOol2000:Ool00`00
Oomoo`07Ool000Uoo`03001oogoo02Yoo`03001oogoo00=oo`T007Uoo`03001oogoo00=oo`8000Uo
o`04000TdP000004AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0F9=801@00H_YRnV;j
000017oo0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0XOol2000?Ool9001`Ool00`00Oomo
o`03Ool20009Ool00`009=8TdP020004AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0D
9=800`00H_YRnP02H_X00`00Oomoo`02Ool2000:Ool00`00Oomoo`07Ool000Uoo`03001oogoo02Mo
o`03001oogoo01Qoo`T006Moo`03001oogoo00=oo`8000Uoo`03000TdRCB008TdP030EU664HH0096
608000AF5003001UcFG=009Uc@03000TdRCB01<TdP03001RnV;j009RnP03001oogoo009oo`8000Yo
o`03001oogoo00Moo`002Goo00<007ooOol09Woo00<007ooOol08Woo2@00GWoo00<007ooOol00goo
0P002Goo00<002CB9=800bCB00<004HHAQP00dHH00<005HDEQ@00UHD0P000fG=00<002CB9=804BCB
00<006;jH_X00V;j00<007ooOol00goo0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0UOol0
0`00Oomoo`0/Ool9001EOol00`00Oomoo`03Ool20009Ool200059=820004AQP00`00EQAF5003EQ@0
1000ILeUcFG=0P004BCB00<006;jH_X00V;j00<007ooOol00goo0P002Woo00<007ooOol01goo0009
Ool00`00Oomoo`0TOol00`00Oomoo`0fOol:001;Ool00`00Oomoo`03Ool2000:Ool00`009=8TdP04
9=820004AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0>9=801@00H_YRnV;j00001Woo
0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0ROol20013Ool90012Ool00`00Oomoo`04Ool2
0009Ool00`009=8TdP069=800`00AQQ66002AQP20004EQ@00`00ILeUc@02ILd00`009=8TdP0<9=80
0`00H_YRnP02H_X00`00Oomoo`04Ool2000:Ool00`00Oomoo`07Ool000Uoo`03001oogoo025oo`03
001oogoo04aoo`T003Uoo`03001oogoo00Aoo`8000Uoo`<000LTdP03001664HH00=66003001F55HD
009F5003001UcFG=009Uc@hTdP05001RnV;jH_X00007Ool2000:Ool00`00Oomoo`07Ool000Uoo`03
001oogoo021oo`03001oogoo05Ioo`T0031oo`03001oogoo00Aoo`8000Yoo`03000TdRCB00LTdP03
001664HH00=66003001F55HD009F5080009Uc@dTdP03001RnV;j009RnP03001oogoo00Eoo`8000Yo
o`03001oogoo00Moo`002Goo00<007ooOol07goo00<007ooOol0H7oo2@009goo00<007ooOol017oo
0P002Woo00<002CB9=8022CB0P0014HH00<005HDEQ@00eHD00<006G=000032CB0P000f;j27oo0P00
2Woo00<007ooOol01goo0009Ool00`00Oomoo`0MOol2001/Ool9000NOol00`00Oomoo`04Ool2000;
Ool00`009=8TdP089=820004AQP01`00EQAF55HD?01F500000`TdP03001CGU=N00<000Qoo`8000Yo
o`03001oogoo00Moo`002Goo00<007ooOol077oo00<007ooOol0MGoo2@005Goo00<007ooOol017oo
0P0037oo00<002CB9=802BCB00<004HHAQP00THH00<003`0?0000c`02bCB00<005=NDeh00U=N00<0
07ooOol01goo0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0KOol00`00Oomoo`1oOol9000<
Ool00`00Oomoo`04Ool2000<Ool00`009=8TdP0:9=800`00AQQ66002AQP5?00:9=800`00DeiCGP02
Deh00`00Oomoo`08Ool2000:Ool00`00Oomoo`07Ool000Qoo`03001oogoo01]oo`03001oogoo08Uo
o`T000=oo`03001oogoo00Aoo`8000eoo`03000TdRCB00XTdP03001664HH00Ll00PTdP03001CGU=N
009CGP03001oogoo00Uoo`8000Yoo`03001oogoo00Moo`0027oo00<007ooOol06Goo0P00UGoo2@00
00=oo`0000003Woo00<002CB9=802RCB0P0000=663`0?0000c`022CB00<005=NDeh00U=N00<007oo
Ool027oo1@002Goo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00`00Oomoo`2HOol00`00Oomo
o`03Ool90008Ool00`009=8TdP0<9=800`00?00l0003?0079=800`00DeiCGP02Deh00`00Oomoo`07
Ool7000:Ool00`00Oomoo`06Ool000Qoo`03001oogoo01Moo`03001oogoo09Uoo`03001oogoo00Ao
o`8000Ioo`X000hTdP03000TdS`000LTdP8000ACGP03001oogoo00Eoo`H000ioo`03001oogoo00Io
o`0027oo00<007ooOol05Woo00<007ooOol0VWoo00<007ooOol017oo0P003goo2P003RCB00<005=N
Deh00U=N0P001Goo1`0047oo00<007ooOol01Woo0008Ool00`00Oomoo`0EOol00`00Oomoo`2KOol0
0`00Oomoo`04Ool2000@Ool00`009=8TdP069=8900049=800`00DeiCGP02Deh00`00Oomoo`03Ool6
000COol00`00Oomoo`06Ool000Qoo`03001oogoo01=oo`8009ioo`03001oogoo00Aoo`80015oo`03
000TdRCB00hTdPT000=oo`H001Ioo`03001oogoo00Ioo`0027oo00<007ooOol04Woo00<007ooOol0
WWoo00<007ooOol017oo0P004Woo00<002CB9=800RCB00<002CB9=802RCB00<005=NDeh00U=N00<0
07oo000020005Woo00<007ooOol01Woo0008Ool00`00Oomoo`0AOol00`00Oomoo`2OOol00`00Oomo
o`04Ool2000BOol010009=8TdUTX3BCB00<005=NDeh00U=N1`001Goo2@003Goo00<007ooOol01Woo
0008Ool00`00Oomoo`0@Ool00`00Oomoo`2POol00`00Oomoo`04Ool2000COol700089=801000DeiC
GU=N1P004Goo2@0017oo00<007ooOol01Woo0008Ool00`00Oomoo`0>Ool2002SOol00`00Oomoo`04
Ool2000JOol@000LOol50008Ool000Qoo`03001oogoo00eoo`03001oogoo0:=oo`03001oogoo00Ao
o`80029oo`D0021oo`8000Yoo`0027oo00<007ooOol037oo00<007ooOol0Y7oo00<007ooOol017oo
0P007goo1P007goo0`0037oo0008Ool00`00Oomoo`0;Ool00`00Oomoo`2UOol00`00Oomoo`04Ool2
000MOol6000NOol3000?Ool000Qoo`03001oogoo00Uoo`800:Qoo`03001oogoo00Aoo`8001Yoo`H0
01moo`80019oo`0027oo00<007ooOol027oo00<007ooOol0Z7oo00<007ooOol017oo0P0067oo1P00
7Woo0`0057oo0008Ool00`00Oomoo`07Ool00`00Oomoo`2YOol00`00Oomoo`04Ool2000EOol6000N
Ool3000GOol000Moo`03001oogoo00Moo`03001oogoo0:Yoo`03001oogoo00Aoo`8001=oo`H001io
o`8001Yoo`001goo00<007ooOol01Woo00<007ooOol0Zgoo00<007ooOol017oo0P0047oo1P007Woo
0`0077oo0007Ool00`00Oomoo`04Ool2002^Ool00`00Oomoo`04Ool2000>Ool6000MOol3000OOol0
00Moo`03001oogoo00=oo`03001oogoo0:ioo`03001oogoo00Aoo`8000]oo`H001ioo`80029oo`00
1goo00<007ooOol00Woo00<007ooOol0/7oo00<007ooOol00goo0P002Goo1P007Goo0`0097oo0007
Ool01@00Oomoogoo0000/goo00<007ooOol00goo0P001Woo1P007Goo0`009goo0007Ool01000Ool0
0000]7oo00<007ooOol00goo0P0017oo1P007Goo0P00:Woo0007Ool2002fOol00`00Oomoo`03Ool2
00000goo00000004000MOol3000/Ool000Moo`H00;9oo`03001oogoo00=oo`L001eoo`8002moo`00
3Goo3000YWoo00<007ooOol00goo10007Goo0`00<Goo000IOol;002KOol00`00Oomoo`03Ool2000L
Ool3000dOol002Aoo``008moo`03001oogoo01moo`8003Moo`00<7oo2`00Q7oo00<007ooOol077oo
0`00>Goo000kOol<001hOol00`00Oomoo`0IOol3000lOol004Moo`/006eoo`03001oogoo01Moo`80
03moo`00DWoo3000HGoo00<007ooOol057oo0`00@Goo001NOol;001FOol00`00Oomoo`0AOol30014
Ool006Uoo``004Yoo`03001oogoo00moo`8004Moo`00MGoo2`00?goo00<007ooOol037oo0`00BGoo
0020Ool<000cOol00`00Oomoo`09Ool3001<Ool008aoo`/002Qoo`03001oogoo00Moo`8004moo`00
Ugoo300077oo00<007ooOol017oo0`00DGoo002SOol;000AOol01000Oomoogoo0`00E7oo002^Ool<
0005Ool01000Ool00000Egoo002jOol7001IOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {234, 0}} -> {0.0164822, 0.0318746, 0.00359387,
   0.00359387}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four body objects are defined for the space-crank model. Note the use of the \
zeroth point to avoid having to define {0, 0, 0}."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground (body 1) has one point defined in its body object.\nP1 is a point \
to locate the rotational axis of the crank."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The crank (body 2) has one point defined in its body object. \nP1 is the \
attachment point of the connecting rod. The center of the crank is at the \
local origin."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The connecting rod (body 3) has one point defined in its body object.\nP1 is \
the attachment point of the connecting rod to the slider, while the \
connecting rod is attached to the crank at P0."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider (body 4) has no points in its body object, only an initial guess, \
because only the local origin P0 is used."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the body objects for the space-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bd[1] = Body[ground = 1, PointList \[Rule] {{0, 10, 12}}]; \)\), 
    \(\(bd[2] = 
      Body[crank = 2, PointList \[Rule] {{0, 8, 0}}, 
        InitialGuess \[Rule] {{0, 10, 12}, {1, 0, 0, 0}}]; \)\), 
    \(\(bd[3] = 
      Body[conrod = 3, PointList \[Rule] {{30, 0, 0}}, 
        InitialGuess \[Rule] {{0, 18, 12}, {1, 0, 0, 0}}]; \)\), 
    \(\(bd[4] = 
      Body[slider = 4, \n\t\t
        InitialGuess \[Rule] {{20, 0, 0}, {1, 0, 0, 0}}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The body properties are incorporated into the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[crank], bd[conrod], bd[slider]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Five constraints, one of which is a driving constraint, are used to model \
the space-crank mechanism. These constraints are simply standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraints which will be replaced with generalized coordinate \
constraints shortly."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the angular relationship between a line on the \
ground body and a line on the crank. This driving constraint is used to \
rotate the crank."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of the crank to be coincident with its pivot \
axis on the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the crank and the connecting rod models a ball joint."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An ",
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the slider and the connecting rod models a universal \
joint. This is used instead of a ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint so as to constrain the spin of the connecting rod about its \
own longitudinal axis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the slider and the ground allows translation of the \
slider."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the space-crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[1] = 
      ProjectedAngle1[1, Vector[crank, Y], Vector[ground, Y], 
        Vector[ground, X], 2\ N[\[Pi]]\ T]; \)\), 
    \(cs[2] = Revolute5[2, \n\t\tAxis[crank, 0, X], Axis[ground, 1, X]]; \n
    \(cs[3] = Spherical3[3, Point[crank, 1], Point[conrod, 0]]; \)\), 
    \(cs[4] = 
      OrthoRevolute4[4, \n\t\tAxis[conrod, 1, Y], Axis[slider, 0, Z]]; \n
    cs[5] = Translate5[5, \n\t\tAxis[slider, 0, X, Y], 
        Axis[ground, 0, X, Y]]; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The constraints are incorporated into the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 5]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run-Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The model can now be run through its range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the angle of rotation of the crank in revolutions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 10.`\), ",", \(Z2 \[Rule] 11.9999999999999996`\), ",", 
        \(Eo2 \[Rule] 0.987688340595137859`\), ",", 
        \(Ei2 \[Rule] 0.156434465040230863`\), ",", \(Ej2 \[Rule] 0.`\), ",", 
        \(Ek2 \[Rule] 0.`\), ",", \(X3 \[Rule] 0.`\), ",", 
        \(Y3 \[Rule] 17.6084521303612291`\), ",", 
        \(Z3 \[Rule] 14.4721359549995787`\), ",", 
        \(Eo3 \[Rule] 0.903943892415714245`\), ",", 
        \(Ei3 \[Rule] 0.0893987074414874172`\), ",", 
        \(Ej3 \[Rule] 0.232451273519890388`\), ",", 
        \(Ek3 \[Rule] \(-0.347648839939247711`\)\), ",", 
        \(X4 \[Rule] 19.5064013716727089`\), ",", \(Y4 \[Rule] 0.`\), ",", 
        \(Z4 \[Rule] 0.`\), ",", \(Eo4 \[Rule] 1.`\), ",", 
        \(Ei4 \[Rule] 0.`\), ",", \(Ej4 \[Rule] 0.`\), ",", 
        \(Ek4 \[Rule] 0.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the slider-crank model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92637 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0241794 0.967178 0.0106302 0.967178 [
[ 0 0 0 0 ]
[ 1 .92637 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .92637 L
0 .92637 L
closepath
clip
newpath
p
.002 w
.07818 .27571 m
.02418 .6791 L
s
.02418 .6791 m
.31663 .90219 L
s
.31663 .90219 m
.33538 .52595 L
s
.33538 .52595 m
.07818 .27571 L
s
.72798 .02418 m
.92505 .33469 L
s
.92505 .33469 m
.97582 .73229 L
s
.97582 .73229 m
.75953 .44787 L
s
.75953 .44787 m
.72798 .02418 L
s
.07818 .27571 m
.02418 .6791 L
s
.02418 .6791 m
.75953 .44787 L
s
.75953 .44787 m
.72798 .02418 L
s
.72798 .02418 m
.07818 .27571 L
s
.33538 .52595 m
.92505 .33469 L
s
.92505 .33469 m
.97582 .73229 L
s
.97582 .73229 m
.31663 .90219 L
s
.31663 .90219 m
.33538 .52595 L
s
P
p
.002 w
.31608 .60705 m .33424 .69428 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.002 w
.27795 .52876 m .31608 .60705 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.002 w
.33424 .69428 m .31608 .60705 L .33087 .60245 L p
.612 .483 .681 r
F P
s
P
p
.008 w
.32164 .60532 m
.32525 .53682 L
s
P
p
.002 w
.31608 .60705 m .27795 .52876 L .29279 .52391 L p
.644 .595 .785 r
F P
s
P
p
.008 w
.09416 .31455 m
.24365 .45834 L
s
P
p
.002 w
.29279 .52391 m .33087 .60245 L .31608 .60705 L p
.644 .595 .785 r
F P
s
P
p
.002 w
.33087 .60245 m .34918 .68988 L .33424 .69428 L p
.612 .483 .681 r
F P
s
P
p
.002 w
.33087 .60245 m .3452 .67087 L p
.29814 .66255 L .94 .685 .525 r
F P
s
P
p
.29814 .66255 m .3452 .67087 L .33739 .68356 L .94 .685 .525 r
F
P
p
.002 w
.33424 .69428 m .32791 .77097 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.002 w
.31748 .71591 m .31218 .73289 L p
.31732 .71617 L .903 .92 .529 r
F P
s
P
p
.002 w
.32791 .77097 m .33424 .69428 L .34918 .68988 L p
.557 .336 .535 r
F P
s
P
p
.002 w
.3318 .73537 m .32393 .73232 L .32654 .724 L p
.656 .594 .773 r
F P
s
P
p
.002 w
.32654 .724 m .32393 .73232 L p
.32637 .72385 L .816 .769 .808 r
F P
s
P
p
.002 w
.34918 .68988 m .34319 .76668 L .32791 .77097 L p
.557 .336 .535 r
F P
s
P
p
.002 w
.31218 .73289 m .30825 .73866 L .31315 .72294 L p
.903 .92 .529 r
F P
s
P
p
.002 w
.34918 .68988 m .34522 .74068 L p
.31102 .71014 L .94 .685 .525 r
F P
s
P
p
.19723 .60853 m .3036 .66547 L .31102 .71014 L .94 .685 .525 r
F
P
p
.3036 .66547 m .34918 .68988 L .31102 .71014 L .94 .685 .525 r
F
P
p
.31218 .73289 m .31315 .72294 L .31732 .71617 L .903 .92 .529 r
F
P
p
.002 w
.31315 .72294 m .30825 .73866 L p
.31325 .72355 L .378 .304 .647 r
F P
s
P
p
.002 w
.32393 .73232 m .31218 .73289 L .31748 .71591 L p
.816 .769 .808 r
F P
s
P
p
.32393 .73232 m .31748 .71591 L .32637 .72385 L .816 .769 .808 r
F
P
p
.002 w
.34522 .74068 m .34319 .76668 L p
.32286 .74465 L .94 .685 .525 r
F P
s
P
p
.002 w
.32393 .73232 m .31218 .73289 L p
.32566 .74175 L .731 .346 .322 r
F P
s
P
p
.32895 .73834 m .32393 .73232 L .32566 .74175 L .731 .346 .322 r
F
P
p
.33526 .73178 m .34522 .74068 L .32286 .74465 L .94 .685 .525 r
F
P
p
.002 w
.33665 .73725 m .32393 .73232 L p
.33923 .75066 L .731 .346 .322 r
F P
s
P
p
.002 w
.31218 .73289 m .30825 .73866 L p
.3231 .74441 L .731 .346 .322 r
F P
s
P
p
.33923 .75066 m .32566 .74175 L .3231 .74441 L .731 .346 .322 r
F
P
p
.32566 .74175 m .31218 .73289 L .3231 .74441 L .731 .346 .322 r
F
P
p
.32137 .74621 m .32286 .74465 L .34319 .76668 L .94 .685 .525 r
F
P
p
.002 w
.30825 .73866 m .31454 .7463 L p
.3203 .74732 L .731 .346 .322 r
F P
s
P
p
.002 w
.32791 .77097 m .29704 .81793 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.32137 .74621 m .34319 .76668 L .3296 .77005 L .94 .685 .525 r
F
P
p
.31945 .7482 m .3296 .77005 L .28865 .78021 L .94 .685 .525 r
F
P
p
.32137 .74621 m .3296 .77005 L .31945 .7482 L .94 .685 .525 r
F
P
p
.33923 .75066 m .3231 .74441 L .3203 .74732 L .731 .346 .322 r
F
P
p
.3231 .74441 m .30825 .73866 L .3203 .74732 L .731 .346 .322 r
F
P
p
.31588 .73941 m .31541 .73658 L .32286 .74465 L .94 .685 .525 r
F
P
p
.002 w
.31454 .7463 m .32742 .75129 L .33923 .75066 L p
.731 .346 .322 r
F P
s
P
p
.002 w
.31454 .7463 m .31945 .7482 L p
.31626 .74133 L .655 .594 .774 r
F P
s
P
p
.002 w
.30825 .73866 m .31454 .7463 L .31617 .74112 L p
.378 .304 .647 r
F P
s
P
p
.30825 .73866 m .31617 .74112 L .31325 .72355 L .378 .304 .647 r
F
P
p
.31634 .74149 m .32286 .74465 L .32137 .74621 L .94 .685 .525 r
F
P
p
.002 w
.31617 .74112 m .31454 .7463 L p
.31626 .74133 L .655 .594 .774 r
F P
s
P
p
.30708 .73281 m .3151 .73883 L .31634 .74149 L .94 .685 .525 r
F
P
p
.3151 .73883 m .32286 .74465 L .31634 .74149 L .94 .685 .525 r
F
P
p
.19723 .60853 m .33526 .73178 L .32286 .74465 L .94 .685 .525 r
F
P
p
.002 w
.3452 .67087 m .34918 .68988 L p
.33739 .68356 L .94 .685 .525 r
F P
s
P
p
.002 w
.39998 .22455 m .42904 .25872 L .56483 .209 L p
.668 .735 .9 r
F P
s
P
p
.002 w
.31748 .71591 m .44964 .29251 L p
.32637 .72385 L .816 .769 .808 r
F P
s
P
p
.002 w
.42767 .31405 m .42809 .29688 L p
.43686 .30504 L .531 .306 .518 r
F P
s
P
p
.002 w
.44016 .31551 m .44195 .30977 L p
.44012 .31576 L .903 .92 .529 r
F P
s
P
p
.31732 .71617 m .44195 .30977 L .44291 .30762 L .903 .92 .529 r
F
P
p
.32637 .72385 m .44964 .29251 L .45141 .29077 L .816 .769 .808 r
F
P
p
.002 w
.44964 .29251 m .31748 .71591 L p
.44295 .30754 L .903 .92 .529 r
F P
s
P
p
.31732 .71617 m .44291 .30762 L .31748 .71591 L .903 .92 .529 r
F
P
p
.42904 .25872 m .46364 .26106 L .43686 .30504 L .531 .306 .518 r
F
P
p
.46364 .26106 m .44964 .29251 L .43686 .30504 L .531 .306 .518 r
F
P
p
.44291 .30762 m .44295 .30754 L .31748 .71591 L .903 .92 .529 r
F
P
p
.002 w
.31315 .72294 m .44016 .31551 L p
.31732 .71617 L .903 .92 .529 r
F P
s
P
p
.31732 .71617 m .44016 .31551 L .44012 .31576 L .903 .92 .529 r
F
P
p
.46364 .26106 m .48055 .2622 L .46769 .27481 L .531 .306 .518 r
F
P
p
.45504 .28038 m .46769 .27481 L .44964 .29251 L .531 .306 .518 r
F
P
p
.46364 .26106 m .46769 .27481 L .45504 .28038 L .531 .306 .518 r
F
P
p
.002 w
.33665 .73725 m .3318 .73537 L p
.46842 .27449 L .656 .594 .773 r
F P
s
P
p
.33665 .73725 m .46842 .27449 L .46885 .2743 L .656 .594 .773 r
F
P
p
.002 w
.32654 .724 m .46769 .27481 L p
.3318 .73537 L .656 .594 .773 r
F P
s
P
p
.002 w
.56483 .209 m .56524 .2319 L p
.49794 .24515 L .531 .306 .518 r
F P
s
P
p
.002 w
.34301 .74482 m .33665 .73725 L .48566 .26691 L p
.386 .311 .649 r
F P
s
P
p
.46774 .25109 m .51691 .22654 L .49794 .24515 L .531 .306 .518 r
F
P
p
.002 w
.49308 .27346 m .47702 .32391 L p
.48597 .26719 L .386 .311 .649 r
F P
s
P
p
.002 w
.47702 .32391 m .34301 .74482 L p
.46504 .33711 L .386 .311 .649 r
F P
s
P
p
.46504 .33711 m .48597 .26719 L .47702 .32391 L .386 .311 .649 r
F
P
p
.34301 .74482 m .48566 .26691 L .48597 .26719 L .386 .311 .649 r
F
P
p
.002 w
.33923 .75066 m .34301 .74482 L .33665 .73725 L p
.731 .346 .322 r
F P
s
P
p
.002 w
.33923 .75066 m .34301 .74482 L .47702 .32391 L p
.888 .911 .507 r
F P
s
P
p
.002 w
.47702 .32391 m .49308 .27346 L p
.47739 .32214 L .888 .911 .507 r
F P
s
P
p
.33923 .75066 m .47702 .32391 L .47739 .32214 L .888 .911 .507 r
F
P
p
.32637 .72385 m .45141 .29077 L .32654 .724 L .816 .769 .808 r
F
P
p
.42904 .25872 m .46774 .25109 L .47932 .26131 L .531 .306 .518 r
F
P
p
.002 w
.42904 .25872 m .4625 .24646 L p
.46774 .25109 L .531 .306 .518 r
F P
s
P
p
.002 w
.4625 .24646 m .51691 .22654 L p
.46774 .25109 L .531 .306 .518 r
F P
s
P
p
.002 w
.48566 .26691 m .33665 .73725 L p
.46885 .2743 L .656 .594 .773 r
F P
s
P
p
.33923 .75066 m .32895 .73834 L .32566 .74175 L .731 .346 .322 r
F
P
p
.002 w
.32742 .75129 m .33923 .75066 L .48549 .29077 L p
.818 .772 .81 r
F P
s
P
p
.49752 .26335 m .51295 .26382 L .51241 .26436 L .531 .306 .518 r
F
P
p
.49424 .26313 m .49756 .26325 L .49752 .26335 L .531 .306 .518 r
F
P
p
.49756 .26325 m .51295 .26382 L .49752 .26335 L .531 .306 .518 r
F
P
p
.42904 .25872 m .49637 .2622 L .49424 .26313 L .531 .306 .518 r
F
P
p
.49637 .2622 m .56586 .26579 L .49424 .26313 L .531 .306 .518 r
F
P
p
.47932 .26131 m .50178 .25362 L .49637 .2622 L .531 .306 .518 r
F
P
p
.46774 .25109 m .54053 .23676 L .47932 .26131 L .531 .306 .518 r
F
P
p
.54053 .23676 m .56524 .2319 L .53491 .24228 L .531 .306 .518 r
F
P
p
.54053 .23676 m .53491 .24228 L .47932 .26131 L .531 .306 .518 r
F
P
p
.002 w
.46726 .30866 m .32742 .75129 L p
.48004 .30423 L .818 .772 .81 r
F P
s
P
p
.48004 .30423 m .4842 .29204 L .47618 .29991 L .818 .772 .81 r
F
P
p
.48004 .30423 m .47618 .29991 L .46726 .30866 L .818 .772 .81 r
F
P
p
.45141 .29077 m .45145 .29074 L .32654 .724 L .816 .769 .808 r
F
P
p
.3318 .73537 m .46769 .27481 L .46842 .27449 L .656 .594 .773 r
F
P
p
.002 w
.46769 .27481 m .32654 .724 L p
.45145 .29074 L .816 .769 .808 r
F P
s
P
p
.45933 .28774 m .47368 .29811 L .44143 .30928 L .531 .306 .518 r
F
P
p
.48055 .2622 m .47368 .29811 L .45933 .28774 L .531 .306 .518 r
F
P
p
.002 w
.48549 .29077 m .33923 .75066 L p
.49275 .27423 L .888 .911 .507 r
F P
s
P
p
.32742 .75129 m .48549 .29077 L .4842 .29204 L .818 .772 .81 r
F
P
p
.33923 .75066 m .49308 .27346 L .49275 .27423 L .888 .911 .507 r
F
P
p
.48055 .2622 m .5615 .26768 L .47368 .29811 L .531 .306 .518 r
F
P
p
.4535 .28353 m .46664 .23802 L .45352 .28354 L .816 .769 .808 r
F
P
p
.4535 .28353 m .45352 .28354 L .45145 .29074 L .816 .769 .808 r
F
P
p
.45141 .29077 m .4535 .28353 L .45145 .29074 L .816 .769 .808 r
F
P
p
.5615 .26768 m .54413 .27523 L .42767 .31405 L .531 .306 .518 r
F
P
p
.44195 .30977 m .54413 .27523 L .44371 .3114 L .531 .306 .518 r
F
P
p
.4422 .30921 m .54413 .27523 L .44195 .30977 L .531 .306 .518 r
F
P
p
.31315 .72294 m .44824 .31562 L .44376 .31145 L .378 .304 .647 r
F
P
p
.002 w
.44195 .30977 m .44016 .31551 L p
.44376 .31145 L .378 .304 .647 r
F P
s
P
p
.002 w
.44016 .31551 m .31315 .72294 L p
.44376 .31145 L .378 .304 .647 r
F P
s
P
p
.002 w
.44072 .31253 m .42759 .3172 L p
.44074 .31247 L .531 .306 .518 r
F P
s
P
p
.54413 .27523 m .44072 .31253 L .44074 .31247 L .531 .306 .518 r
F
P
p
.002 w
.5379 .27795 m .44072 .31253 L p
.54413 .27523 L .531 .306 .518 r
F P
s
P
p
.48055 .2622 m .44143 .30928 L .43686 .30504 L .531 .306 .518 r
F
P
p
.43686 .30504 m .44143 .30928 L .42767 .31405 L .531 .306 .518 r
F
P
p
.44291 .30762 m .46322 .24157 L .44295 .30754 L .903 .92 .529 r
F
P
p
.44157 .30942 m .44195 .30977 L .42759 .3172 L .531 .306 .518 r
F
P
p
.44195 .30977 m .44371 .3114 L .44075 .31246 L .531 .306 .518 r
F
P
p
.44195 .30977 m .44075 .31246 L .42759 .3172 L .531 .306 .518 r
F
P
p
.44157 .30942 m .4422 .30921 L .44195 .30977 L .531 .306 .518 r
F
P
p
.44295 .30754 m .46322 .24157 L .44964 .29251 L .903 .92 .529 r
F
P
p
.002 w
.46664 .23802 m .4789 .23913 L .46769 .27481 L p
.816 .769 .808 r
F P
s
P
p
.45145 .29074 m .46664 .23802 L .46769 .27481 L .816 .769 .808 r
F
P
p
.002 w
.46322 .24157 m .46664 .23802 L .44964 .29251 L p
.903 .92 .529 r
F P
s
P
p
.002 w
.44195 .30977 m .46322 .24157 L p
.44291 .30762 L .903 .92 .529 r
F P
s
P
p
.002 w
.44964 .29251 m .46664 .23802 L p
.45141 .29077 L .816 .769 .808 r
F P
s
P
p
.002 w
.47075 .24775 m .46322 .24157 L .44195 .30977 L p
.378 .304 .647 r
F P
s
P
p
.45464 .29916 m .4451 .30994 L .46979 .2953 L .664 .74 .907 r
F
P
p
.46979 .2953 m .4451 .30994 L .47618 .29991 L .664 .74 .907 r
F
P
p
.002 w
.44376 .31145 m .47618 .29991 L p
.4451 .30994 L .664 .74 .907 r
F P
s
P
p
.44376 .31145 m .47075 .24775 L .44195 .30977 L .378 .304 .647 r
F
P
p
.44824 .31562 m .45313 .30086 L .44376 .31145 L .378 .304 .647 r
F
P
p
.45313 .30086 m .47075 .24775 L .44376 .31145 L .378 .304 .647 r
F
P
p
.45319 .3008 m .47075 .24775 L .45313 .30086 L .378 .304 .647 r
F
P
p
.002 w
.4492 .31651 m .45464 .29916 L p
.44827 .31565 L .378 .304 .647 r
F P
s
P
p
.002 w
.45464 .29916 m .47075 .24775 L p
.45319 .3008 L .378 .304 .647 r
F P
s
P
p
.44827 .31565 m .45464 .29916 L .45319 .3008 L .378 .304 .647 r
F
P
p
.002 w
.4789 .23913 m .49284 .24423 L .48566 .26691 L p
.656 .594 .773 r
F P
s
P
p
.002 w
.48339 .25761 m .48487 .25292 L p
.48334 .25737 L .655 .594 .774 r
F P
s
P
p
.46885 .2743 m .4789 .23913 L .48566 .26691 L .656 .594 .773 r
F
P
p
.47029 .29517 m .48339 .25761 L .48334 .25737 L .655 .594 .774 r
F
P
p
.002 w
.47163 .29483 m .48339 .25761 L p
.47029 .29517 L .655 .594 .774 r
F P
s
P
p
.47029 .29517 m .48487 .25292 L .47027 .29518 L .655 .594 .774 r
F
P
p
.45965 .29788 m .48487 .25292 L .45464 .29916 L .655 .594 .774 r
F
P
p
.46979 .2953 m .47618 .29991 L .47123 .29493 L .664 .74 .907 r
F
P
p
.46532 .30951 m .47027 .29518 L .4492 .31651 L .655 .594 .774 r
F
P
p
.47027 .29518 m .48487 .25292 L .45965 .29788 L .655 .594 .774 r
F
P
p
.47027 .29518 m .45965 .29788 L .4492 .31651 L .655 .594 .774 r
F
P
p
.47123 .29493 m .47618 .29991 L .47163 .29483 L .664 .74 .907 r
F
P
p
.50178 .25362 m .49842 .26129 L .49637 .2622 L .531 .306 .518 r
F
P
p
.002 w
.56524 .2319 m .56586 .26579 L p
.49637 .2622 L .531 .306 .518 r
F P
s
P
p
.002 w
.49284 .24423 m .50043 .25038 L .49308 .27346 L p
.386 .311 .649 r
F P
s
P
p
.48597 .26719 m .49284 .24423 L .49308 .27346 L .386 .311 .649 r
F
P
p
.002 w
.48566 .26691 m .49284 .24423 L p
.48597 .26719 L .386 .311 .649 r
F P
s
P
p
.002 w
.49719 .254 m .48487 .25292 L .47163 .29483 L p
.818 .772 .81 r
F P
s
P
p
.002 w
.47163 .29483 m .46726 .30866 L p
.47362 .29705 L .818 .772 .81 r
F P
s
P
p
.47362 .29705 m .49719 .254 L .47163 .29483 L .818 .772 .81 r
F
P
p
.002 w
.46769 .27481 m .4789 .23913 L p
.46842 .27449 L .656 .594 .773 r
F P
s
P
p
.46885 .2743 m .46842 .27449 L .4789 .23913 L .656 .594 .773 r
F
P
p
.002 w
.48487 .25292 m .47075 .24775 L .45464 .29916 L p
.655 .594 .774 r
F P
s
P
p
.4842 .29204 m .49719 .254 L .47362 .29705 L .818 .772 .81 r
F
P
p
.47618 .29991 m .47362 .29705 L .46726 .30866 L .818 .772 .81 r
F
P
p
.4842 .29204 m .47362 .29705 L .47618 .29991 L .818 .772 .81 r
F
P
p
.002 w
.50043 .25038 m .49719 .254 L .48549 .29077 L p
.888 .911 .507 r
F P
s
P
p
.49275 .27423 m .50043 .25038 L .48549 .29077 L .888 .911 .507 r
F
P
p
.002 w
.48549 .29077 m .49719 .254 L p
.4842 .29204 L .818 .772 .81 r
F P
s
P
p
.45659 .278 m .50957 .28803 L .5243 .27179 L .664 .74 .907 r
F
P
p
.44706 .27888 m .45892 .28061 L .45659 .278 L .664 .74 .907 r
F
P
p
.45892 .28061 m .50957 .28803 L .45659 .278 L .664 .74 .907 r
F
P
p
.45892 .28061 m .48246 .29768 L .4852 .28446 L .664 .74 .907 r
F
P
p
.44706 .27888 m .46668 .2893 L .45892 .28061 L .664 .74 .907 r
F
P
p
.46668 .2893 m .48246 .29768 L .45892 .28061 L .664 .74 .907 r
F
P
p
.002 w
.47618 .29991 m .48246 .29768 L p
.47533 .29389 L .664 .74 .907 r
F P
s
P
p
.46668 .2893 m .47163 .29483 L .47533 .29389 L .664 .74 .907 r
F
P
p
.47163 .29483 m .47618 .29991 L .47533 .29389 L .664 .74 .907 r
F
P
p
.46263 .29013 m .46979 .2953 L .46443 .2881 L .664 .74 .907 r
F
P
p
.46979 .2953 m .47123 .29493 L .46443 .2881 L .664 .74 .907 r
F
P
p
.002 w
.45464 .29916 m .4492 .31651 L p
.45965 .29788 L .655 .594 .774 r
F P
s
P
p
.46534 .3095 m .47029 .29517 L .46532 .30951 L .655 .594 .774 r
F
P
p
.47029 .29517 m .47027 .29518 L .46532 .30951 L .655 .594 .774 r
F
P
p
.46443 .2881 m .47123 .29493 L .46668 .2893 L .664 .74 .907 r
F
P
p
.47123 .29493 m .47163 .29483 L .46668 .2893 L .664 .74 .907 r
F
P
p
.44706 .27888 m .46263 .29013 L .46443 .2881 L .664 .74 .907 r
F
P
p
.44706 .27888 m .44267 .30221 L .45464 .29916 L .664 .74 .907 r
F
P
p
.46263 .29013 m .45464 .29916 L .46979 .2953 L .664 .74 .907 r
F
P
p
.44706 .27888 m .45464 .29916 L .46263 .29013 L .664 .74 .907 r
F
P
p
.002 w
.42759 .3172 m .42767 .31405 L p
.44157 .30942 L .531 .306 .518 r
F P
s
P
p
.44267 .30221 m .44072 .31253 L .4451 .30994 L .664 .74 .907 r
F
P
p
.44267 .30221 m .4451 .30994 L .45464 .29916 L .664 .74 .907 r
F
P
p
.002 w
.44072 .31253 m .44376 .31145 L p
.4451 .30994 L .664 .74 .907 r
F P
s
P
p
.44827 .31565 m .45319 .3008 L .44824 .31562 L .378 .304 .647 r
F
P
p
.45319 .3008 m .45313 .30086 L .44824 .31562 L .378 .304 .647 r
F
P
p
.002 w
.46726 .30866 m .47163 .29483 L p
.46534 .3095 L .655 .594 .774 r
F P
s
P
p
.46534 .3095 m .47163 .29483 L .47029 .29517 L .655 .594 .774 r
F
P
p
.51241 .26436 m .56586 .26579 L .5615 .26768 L .531 .306 .518 r
F
P
p
.51295 .26382 m .56586 .26579 L .51241 .26436 L .531 .306 .518 r
F
P
p
.002 w
.48246 .29768 m .50957 .28803 L p
.4852 .28446 L .664 .74 .907 r
F P
s
P
p
.5615 .26768 m .5659 .26798 L .54413 .27523 L .531 .306 .518 r
F
P
p
.002 w
.5659 .26798 m .5379 .27795 L p
.54413 .27523 L .531 .306 .518 r
F P
s
P
p
.002 w
.50957 .28803 m .5659 .26798 L p
.5243 .27179 L .664 .74 .907 r
F P
s
P
p
.002 w
.49308 .27346 m .50043 .25038 L p
.49275 .27423 L .888 .911 .507 r
F P
s
P
p
.50178 .25362 m .56524 .2319 L .49842 .26129 L .531 .306 .518 r
F
P
p
.002 w
.51691 .22654 m .56483 .209 L p
.49794 .24515 L .531 .306 .518 r
F P
s
P
p
.002 w
.56586 .26579 m .5659 .26798 L p
.5615 .26768 L .531 .306 .518 r
F P
s
P
p
.002 w
.32742 .75129 m .46726 .30866 L p
.31626 .74133 L .655 .594 .774 r
F P
s
P
p
.31626 .74133 m .46726 .30866 L .46534 .3095 L .655 .594 .774 r
F
P
p
.31325 .72355 m .44827 .31565 L .31315 .72294 L .378 .304 .647 r
F
P
p
.44827 .31565 m .44824 .31562 L .31315 .72294 L .378 .304 .647 r
F
P
p
.31626 .74133 m .46534 .3095 L .31617 .74112 L .655 .594 .774 r
F
P
p
.46534 .3095 m .46532 .30951 L .31617 .74112 L .655 .594 .774 r
F
P
p
.002 w
.4492 .31651 m .31617 .74112 L p
.46532 .30951 L .655 .594 .774 r
F P
s
P
p
.002 w
.39998 .22455 m .42904 .25872 L .42759 .3172 L p
.964 .688 .46 r
F P
s
P
p
.002 w
.42759 .3172 m .39797 .28338 L .39998 .22455 L p
.964 .688 .46 r
F P
s
P
p
.002 w
.39797 .28338 m .42759 .3172 L .44072 .31253 L p
.664 .74 .907 r
F P
s
P
p
.002 w
.42809 .29688 m .42904 .25872 L p
.43686 .30504 L .531 .306 .518 r
F P
s
P
p
.39797 .28338 m .44072 .31253 L .44706 .27888 L .664 .74 .907 r
F
P
p
.002 w
.31617 .74112 m .4492 .31651 L p
.31325 .72355 L .378 .304 .647 r
F P
s
P
p
.31325 .72355 m .4492 .31651 L .44827 .31565 L .378 .304 .647 r
F
P
p
.14443 .58026 m .32137 .74621 L .28865 .78021 L .94 .685 .525 r
F
P
p
.002 w
.31945 .7482 m .32742 .75129 L p
.31626 .74133 L .655 .594 .774 r
F P
s
P
p
.002 w
.29704 .81793 m .32791 .77097 L .34319 .76668 L p
.385 0 .174 r
F P
s
P
p
.002 w
.34319 .76668 m .31275 .81362 L .29704 .81793 L p
.385 0 .174 r
F P
s
P
p
.002 w
.34319 .76668 m .31275 .81362 L p
.28865 .78021 L .94 .685 .525 r
F P
s
P
p
.30708 .73281 m .30902 .72965 L .31541 .73658 L .94 .685 .525 r
F
P
p
.30708 .73281 m .31541 .73658 L .31588 .73941 L .94 .685 .525 r
F
P
p
.14443 .58026 m .19723 .60853 L .30902 .72965 L .94 .685 .525 r
F
P
p
.14443 .58026 m .30902 .72965 L .30708 .73281 L .94 .685 .525 r
F
P
p
.19723 .60853 m .2716 .60515 L .29814 .66255 L .94 .685 .525 r
F
P
p
.2716 .60515 m .33087 .60245 L .29814 .66255 L .94 .685 .525 r
F
P
p
.14443 .58026 m .16883 .58316 L .19723 .60853 L .94 .685 .525 r
F
P
p
.16883 .58316 m .33087 .60245 L .19723 .60853 L .94 .685 .525 r
F
P
p
.002 w
.29279 .52391 m .33087 .60245 L p
.14443 .58026 L .94 .685 .525 r
F P
s
P
p
.008 w
.61954 .44176 m
.89789 .35186 L
s
P
p
.008 w
.44829 .49707 m
.61954 .44176 L
s
P
p
.008 w
.41886 .50658 m
.44829 .49707 L
s
P
p
.008 w
.33971 .53215 m
.37631 .52032 L
s
P
p
.008 w
.32525 .53682 m
.33971 .53215 L
s
P
p
.008 w
.26115 .47517 m
.32525 .53682 L
s
P
p
.002 w
.22796 .47744 m .27795 .52876 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.002 w
.27795 .52876 m .22796 .47744 L .24303 .47232 L p
.663 .725 .895 r
F P
s
P
p
.002 w
.24303 .47232 m .29279 .52391 L .27795 .52876 L p
.663 .725 .895 r
F P
s
P
p
.002 w
.24303 .47232 m .29279 .52391 L p
.14443 .58026 L .94 .685 .525 r
F P
s
P
p
.008 w
.24365 .45834 m
.26115 .47517 L
s
P
p
.002 w
.17748 .46754 m .22796 .47744 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.002 w
.22796 .47744 m .17748 .46754 L .19293 .46222 L p
.586 .9 .985 r
F P
s
P
p
.002 w
.19293 .46222 m .24303 .47232 L .22796 .47744 L p
.586 .9 .985 r
F P
s
P
p
.002 w
.19293 .46222 m .24303 .47232 L p
.14443 .58026 L .94 .685 .525 r
F P
s
P
p
.008 w
.16822 .38579 m
.41104 .2983 L
s
P
p
.002 w
.29704 .81793 m .2475 .81983 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.002 w
.2475 .81983 m .29704 .81793 L .31275 .81362 L p
.39 .847 .891 r
F P
s
P
p
.008 w
.31049 .81741 m
.31066 .8142 L
s
P
p
.002 w
.31275 .81362 m .26362 .81538 L .2475 .81983 L p
.39 .847 .891 r
F P
s
P
p
.008 w
.3077 .87044 m
.31049 .81741 L
s
P
p
.002 w
.31275 .81362 m .26362 .81538 L p
.14443 .58026 L .94 .685 .525 r
F P
s
P
p
.008 w
.24271 .82001 m
.3077 .87044 L
s
P
p
.002 w
.12818 .58555 m .1401 .50578 L .17748 .46754 L p
.938 .685 .528 r
F P
s
P
p
.002 w
.17748 .46754 m .1401 .50578 L .15598 .50039 L p
.205 0 0 r
F P
s
P
p
.002 w
.15598 .50039 m .19293 .46222 L .17748 .46754 L p
.205 0 0 r
F P
s
P
p
.002 w
.14443 .58026 m .15598 .50039 L .19293 .46222 L p
.94 .685 .525 r
F P
s
P
p
.008 w
.89789 .35186 m
.71883 .07802 L
s
P
p
.008 w
.12968 .34871 m
.396 .25023 L
s
P
p
.008 w
.09416 .31455 m
.04894 .66963 L
s
P
p
.008 w
.09416 .31455 m
.3635 .21257 L
s
P
p
.002 w
.2475 .81983 m .19192 .77162 L p
.12818 .58555 L .938 .685 .528 r
F P
s
P
p
.002 w
.19192 .77162 m .2475 .81983 L .26362 .81538 L p
.641 .751 .928 r
F P
s
P
p
.002 w
.26362 .81538 m .20832 .7669 L .19192 .77162 L p
.641 .751 .928 r
F P
s
P
p
.002 w
.26362 .81538 m .20832 .7669 L p
.14443 .58026 L .94 .685 .525 r
F P
s
P
p
.002 w
.1401 .50578 m .12818 .58555 L .14443 .58026 L p
.517 .277 .49 r
F P
s
P
p
.002 w
.14443 .58026 m .15598 .50039 L .1401 .50578 L p
.517 .277 .49 r
F P
s
P
p
.002 w
.56483 .209 m .53735 .17316 L .39998 .22455 L p
.668 .735 .9 r
F P
s
P
p
.002 w
.53735 .17316 m .39998 .22455 L .39797 .28338 L p
.524 .296 .511 r
F P
s
P
p
.008 w
.396 .25023 m
.43556 .2356 L
s
P
p
.008 w
.43556 .2356 m
.43663 .2352 L
s
P
p
.002 w
.4789 .23913 m .46664 .23802 L p
.49719 .254 L .671 .177 .066 r
F P
s
P
p
.002 w
.49284 .24423 m .4789 .23913 L p
.49719 .254 L .671 .177 .066 r
F P
s
P
p
.002 w
.49719 .254 m .50043 .25038 L .49284 .24423 L p
.671 .177 .066 r
F P
s
P
p
.002 w
.53792 .23247 m .5659 .26798 L .56483 .209 L p
.974 .684 .411 r
F P
s
P
p
.008 w
.56808 .24172 m
.77672 .16655 L
s
P
p
.008 w
.56544 .24267 m
.56808 .24172 L
s
P
p
.002 w
.56483 .209 m .53735 .17316 L .53792 .23247 L p
.974 .684 .411 r
F P
s
P
p
.008 w
.50407 .15934 m
.71883 .07802 L
s
P
p
.002 w
.46664 .23802 m .46322 .24157 L p
.49719 .254 L .671 .177 .066 r
F P
s
P
p
.002 w
.19192 .77162 m .14726 .68461 L .12818 .58555 L p
.938 .685 .528 r
F P
s
P
p
.002 w
.14726 .68461 m .19192 .77162 L .20832 .7669 L p
.63 .597 .797 r
F P
s
P
p
.008 w
.19958 .78653 m
.24271 .82001 L
s
P
p
.002 w
.46322 .24157 m .47075 .24775 L p
.49719 .254 L .671 .177 .066 r
F P
s
P
p
.002 w
.12818 .58555 m .14726 .68461 L .1637 .67958 L p
.594 .465 .675 r
F P
s
P
p
.002 w
.1637 .67958 m .14443 .58026 L .12818 .58555 L p
.594 .465 .675 r
F P
s
P
p
.002 w
.20832 .7669 m .1637 .67958 L .14726 .68461 L p
.63 .597 .797 r
F P
s
P
p
.002 w
.20832 .7669 m .1637 .67958 L .14443 .58026 L p
.94 .685 .525 r
F P
s
P
p
.008 w
.16115 .75671 m
.19958 .78653 L
s
P
p
.008 w
.04894 .66963 m
.16115 .75671 L
s
P
p
.002 w
.47075 .24775 m .48487 .25292 L .49719 .254 L p
.671 .177 .066 r
F P
s
P
p
.002 w
.5659 .26798 m .53792 .23247 L .39797 .28338 L p
.664 .74 .907 r
F P
s
P
p
.002 w
.39797 .28338 m .53792 .23247 L .53735 .17316 L p
.524 .296 .511 r
F P
s
P
p
.008 w
.43663 .2352 m
.53481 .1989 L
s
P
p
.008 w
.40325 .19751 m
.50407 .15934 L
s
P
p
.008 w
.53481 .1989 m
.74665 .12056 L
s
P
p
.008 w
.3635 .21257 m
.40325 .19751 L
s
P
p
.002 w
.72798 .02418 m
.92505 .33469 L
s
.92505 .33469 m
.97582 .73229 L
s
.97582 .73229 m
.75953 .44787 L
s
.75953 .44787 m
.72798 .02418 L
s
.07818 .27571 m
.02418 .6791 L
s
.02418 .6791 m
.75953 .44787 L
s
.75953 .44787 m
.72798 .02418 L
s
.72798 .02418 m
.07818 .27571 L
s
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{321, 297},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000510001:A000`40O003h00Oogoo@Woo003oOom2
Ool00?mood9oo`00ogoo@Woo003oOom2Ool00?mood9oo`00ogoo@Woo003oOom2Ool00>Moo`8005Qo
o`00iGoo0P0000=oo`000000Egoo003ROol30003Ool2001GOol00>1oo`8000Ioo`03001oo`0005Io
o`00gGoo0`0027oo00@007ooOol005Eoo`00fWoo0`002goo00@007ooOol005Eoo`00f7oo0P003Woo
00D007ooOomoo`0005Aoo`00eGoo0`004Goo00@007ooOol005Aoo`00dgoo0P0057oo00D007ooOomo
o`0005=oo`00d7oo0`005Woo00<007ooOol00Woo00<007ooOol0D7oo003>Ool2000IOol00`00Oomo
o`02Ool00`00Oomoo`1@Ool00<]oo`<001]oo`03001oogoo00=oo`03001oogoo04moo`00bGoo0P00
7Woo00<007ooOol017oo00<007ooOol0CWoo0036Ool3000POol00`00Oomoo`04Ool00`00Oomoo`1>
Ool00<=oo`<002=oo`03001oogoo00Eoo`03001oogoo04eoo`00`Goo0P009Woo00<007ooOol01Woo
00<007ooOol0C7oo002nOol3000TOol01@00Oomoogoo000027oo00<007ooOol0C7oo002lOol2000T
Ool50002Ool00`00Oomoo`07Ool00`00Oomoo`1;Ool00;Uoo`<002Aoo`L0009oo`03001oogoo00Mo
o`03001oogoo04]oo`00]goo0P0097oo1P000goo0P0000=oo`00Ool02Goo00<007ooOol0BWoo002d
Ool3000TOol60006Ool00`00Ool0000;Ool00`00Oomoo`19Ool00;9oo`8002Aoo`H000Uoo`800003
Ool007oo00Uoo`03001oogoo04Uoo`00[goo0`008goo1`0037oo0`002goo00<007ooOol0B7oo002/
Ool3000TOol6000@Ool2000<Ool00`00Oomoo`17Ool00:Yoo`8002Aoo`H001=oo`8000aoo`03001o
ogoo04Moo`00Ygoo0`008goo1`005Woo0P0037oo00<007ooOol0AWoo002UOol2000TOol6000IOol2
000=Ool00`00Oomoo`15Ool00:9oo`<002=oo`H001aoo`<000aoo`03001oogoo04Eoo`00X7oo0P00
97oo1P007Woo00@007oo000000aoo`03001oogoo04Aoo`00WGoo0`008goo1P008Goo00@007ooOol0
00aoo`03001oogoo04Aoo`00Vgoo0P008goo1`008goo00<007ooOol00P0037oo00<007ooOol0@goo
002HOol3000SOol6000VOol6000<Ool00`00Oomoo`12Ool009Eoo`<002=oo`H002Qoo`L000aoo`03
001oogoo049oo`00Tgoo0P0097oo1P009goo1P000goo0P0037oo00<007ooOol0@Goo002@Ool3000S
Ool6000WOol80005Ool2000<Ool00`00Oomoo`10Ool008ioo`8002=oo`L002Moo`H000Aoo`03001o
ogoo00=oo`03001oogoo00Yoo`03001oogoo041oo`00Rgoo0`008goo1P009goo1P001goo00<007oo
Ool00goo0P0037oo00<007ooOol0?goo0029Ool2000SOol6000WOol70009Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Oomoo`0nOol008Ioo`<0029oo`L002Moo`H000aoo`03001oogoo00Aoo`80
00aoo`03001oogoo03ioo`00Q7oo0P008goo1P009goo1P003goo00<007ooOol01Goo0P0037oo00<0
07ooOol0?Goo0021Ool3000ROol6000WOol7000AOol00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00
Oomoo`0mOol007ioo`<002=oo`H002Moo`H001Aoo`03001oogoo00Ioo`8000aoo`03001oogoo03ao
o`00O7oo0P008goo1P009goo1P005goo00<007ooOol01goo0P0037oo00<007ooOol0>goo001iOol3
000SOol6000VOol7000IOol00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`0kOol007Moo`80
02=oo`H002Ioo`L001aoo`03001oogoo00Qoo`8000aoo`03001oogoo03Yoo`00M7oo0`008goo1P00
9Woo1P007goo00<007ooOol02Goo0P0037oo00<007ooOol0>Goo001bOol2000SOol6000VOol6000R
Ool00`00Oomoo`07Ool5000;Ool00`00Oomoo`0iOol006moo`<002=oo`H002Eoo`L002Aoo`03001o
ogoo00Aoo`P000aoo`03001oogoo03Qoo`00KGoo0P008goo1P004Woo0P004Woo1P00:7oo00@007oo
Oomoo`H000=oo`8000aoo`03001oogoo03Moo`00JWoo0`008goo1P004Goo0`0000=1<00000003Woo
1P00:goo1`001goo00<007ooOol02Woo00<007ooOol0=goo001WOol3000SOol6000BOol20004@C00
0`00OZd0000:Ool7000[Ool70009Ool2000<Ool00`00Oomoo`0fOol006Eoo`8002Aoo`H0015oo`<0
00I1<003001n[@0000Qoo`H002]oo`L000eoo`8000]oo`03001oogoo03Ioo`00HWoo0`008goo1P00
4Goo0`002D4`00@007j]OZd000Aoo`H002]oo`L00003Ool007oo00ioo`03001oogoo00Yoo`03001o
ogoo03Eoo`00H7oo0P0097oo1P004Goo0P00344`00@007j]OZen[@P002]oo`H000Aoo`03001oogoo
00eoo`8000aoo`03001oogoo03Aoo`00GGoo0`008goo1P004Goo0`003T4`00<007j]OZd01P00:goo
1P001goo00<007ooOol03Woo0P002goo00<007ooOol0=7oo001KOol2000TOol6000@Ool3000A@C07
000ZOol70009Ool00`00Oomoo`0?Ool00`00Oomoo`0:Ool00`00Oomoo`0cOol005Qoo`<002=oo`H0
015oo`800151<0L000=n[@03001oogoo02Aoo`L000aoo`03001oogoo00moo`8000aoo`03001oogoo
039oo`00EWoo0P008goo1`0047oo0`004D4`1P001Wj]00<007ooOol08Goo1`003goo00<007ooOol0
47oo0P002goo00<007ooOol0<Woo001COol3000ROol6000AOol3000A@C060003@C000`00OZen[@04
OZd00`00Oomoo`0NOol6000BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0aOol0051o
o`<0025oo`L0019oo`800151<0L000E1<003001n[Gj]00En[@03001oogoo01Yoo`H001Eoo`03001o
ogoo015oo`8000aoo`03001oogoo031oo`00CWoo0P008Goo1`004Woo0`004D4`1P00244`00<007j]
OZd01Gj]00<007ooOol05goo1`005goo00<007ooOol04Woo0P002goo00<007ooOol0<7oo001;Ool3
000QOol6000BOol3000A@C06000;@C000`00OZen[@05OZd00`00Oomoo`0DOol7000JOol00`00Oomo
o`0COol00`00Oomoo`0:Ool00`00Oomoo`0_Ool004Uoo`80025oo`H001=oo`800151<0L000e1<003
001n[Gj]00En[@03001oogoo019oo`H001ioo`03001oogoo019oo`8000]oo`03001oogoo02moo`00
AWoo0`008Goo1P004Woo0`004D4`1P00444`00<007j]OZd01Gj]00<007ooOol03goo1P008Goo00<0
07ooOol04goo0P002goo00<007ooOol0;Woo0014Ool2000QOol6000COol2000A@C06000C@C000`00
OZen[@05OZd00`00Oomoo`0<Ool7000SOol00`00Oomoo`0DOol00`00Oomoo`0:Ool00`00Oomoo`0]
Ool0045oo`<0021oo`L001Eoo`030011<44`00e1<0L001E1<003001n[Gj]00En[@03001oogoo00Uo
o`L002Ioo`03001oogoo01Aoo`8000]oo`03001oogoo02eoo`00?goo0P008Goo1P0067oo00<0044`
@C002d4`1P00644`00<007j]OZd01Gj]00<007ooOol01Woo1`00:Goo00<007ooOol05Goo0P002goo
00<007ooOol0;7oo000lOol3000POol6000KOol00`00@C11<008@C06000J@C020007OZd00`00Oomo
o`04Ool6000/Ool00`00Oomoo`0FOol00`00Oomoo`0:Ool00`00Oomoo`0[Ool003Uoo`<0025oo`H0
01eoo`030011<44`00E1<0L001U1<0<0009Fo@03001n[Gj]00An[@04001oogooOol6000_Ool00`00
Oomoo`0FOol2000;Ool00`00Oomoo`0[Ool003Moo`80025oo`H0021oo`030011<44`0091<0L001U1
<0<000IFo@03001n[Gj]00An[@L0035oo`03001oogoo01Moo`8000]oo`03001oogoo02Yoo`00=7oo
0`0087oo1`008Woo00<0044`00001@006d4`0P002EKm00<007j]OZd00Wj]1P00=7oo00<007ooOol0
67oo00<007ooOol02Woo00<007ooOol0:Goo000bOol2000QOol6000SOol7000K@C03000<E_d01000
OZen[Gj]0`00=goo00<007ooOol067oo0P002goo00<007ooOol0:Goo000_Ool3000POol6000SOol7
000K@C03000@E_d00`00OZen[@02OZd00`00Oomoo`0eOol00`00Oomoo`0IOol2000;Ool00`00Oomo
o`0XOol002eoo`80025oo`H002=oo`H00003Ool0044`01Q1<0<001AFo@05001n[Gj]OZd0000gOol0
0`00Oomoo`0JOol00`00Oomoo`09Ool00`00Oomoo`0XOol002Yoo`<0021oo`H002=oo`H000=oo`03
0011<44`01E1<0<001QFo@04001n[Gj]000gOol00`00Oomoo`0JOol2000;Ool00`00Oomoo`0WOol0
02Qoo`80021oo`L0029oo`L000Eoo`030011<44`01=1<08001aFo@03001n[@0003Qoo`03001oogoo
01Yoo`8000]oo`03001oogoo02Ioo`009Goo0`0087oo1P008goo1P0027oo00<0044`@C00444`0`00
7UKm00<007j]0000>7oo00<007ooOol06goo00<007ooOol02Goo00<007ooOol09Woo000ROol3000P
Ool6000SOol6000;Ool00`00@C11<00=@C03000RE_d2000hOol00`00Oomoo`0KOol2000;Ool00`00
Oomoo`0UOol0021oo`80021oo`L0029oo`L000eoo`030011<44`00Y1<0<002IFo@03001oogoo03Io
o`03001oogoo01aoo`8000]oo`03001oogoo02Aoo`007Goo0`0087oo1P008goo1P0047oo00<0044`
@C001d4`0`009UKm0P00>Woo00<007ooOol07Goo00<007ooOol02Goo00<007ooOol097oo000KOol2
000POol6000SOol6000COol00`00@C11<005@C02000VE_d3000lOol00`00Oomoo`0MOol2000;Ool0
0`00Oomoo`0SOol001Uoo`80021oo`H0029oo`L001Eoo`030011<44`0091<0<002IFo@8003moo`03
001oogoo01ioo`8000]oo`03001oogoo029oo`006Goo0P007Goo1P008goo1P0067oo00<0044`0000
0P001UKm1D4`6eKm0`00@Goo00<007ooOol07goo00<007ooOol02Goo00<007ooOol08Woo000IOol0
0`00Ool0000IOol7000ROol6000KOol2000VE_d30014Ool00`00Oomoo`0OOol2000;Ool00`00Oomo
o`0QOol001Uoo`04001oogoo000FOol6000ROol7000NOol00`00E_eFo@0RE_d20017Ool00`00Oomo
o`0POol2000:Ool00`00Oomoo`0QOol001Qoo`03001oogoo009oo`03001oogoo011oo`H002=oo`H0
029oo`03001FoEKm011Fo@03DWQFoEKm00]Fo@<004Uoo`03001oogoo025oo`03001oogoo00Uoo`03
001oogoo021oo`0067oo00<007ooOol00goo00<007ooOol03Goo1P008Woo1P009Goo00<005KmE_d0
6eKm0`00C7oo00<007ooOol08Goo0P002goo00<007ooOol07goo000HOol00`00Oomoo`04Ool00`00
Oomoo`09Ool6000ROol7000XOol2000BE_d00`00E_eFo@03E_d3001?Ool00`00Oomoo`0ROol00`00
Oomoo`09Ool00`00Oomoo`0OOol001Qoo`03001oogoo00Eoo`03001oogoo00Eoo`L0029oo`H002Uo
o`D000aFo@03001BN59h009BN003001[6@0000<0059oo`03001oogoo029oo`8000]oo`03001oogoo
01ioo`0067oo00<007ooOol01Woo00<007ooOol00Woo1P008Woo1P00:Goo200035Km00D0059hDWQB
N00000A[6@03001oogoo059oo`03001oogoo029oo`8000]oo`03001oogoo01eoo`0067oo00<007oo
Ool01goo1`008goo1P00:Goo1P0017oo00<005KmE_d025Km00<0059hDWP00U9h00<006/IJaT00V/I
00<007ooOol0DWoo00<007ooOol08goo00<007ooOol02Goo00<007ooOol07Goo000HOol00`00Oomo
o`06Ool6000ROol6000YOol60008Ool00`00E_eFo@06E_d00c4d001BN003DWP01000JaU[6F/I0P00
E7oo00<007ooOol08goo0P002goo00<007ooOol077oo000GOol00`00Oomoo`04Ool7000QOol7000X
Ool7000:Ool00`00E_eFo@03E_d300000c4d001BN003DWP01@00JaU[6F/I0000EGoo00<007ooOol0
97oo0P002goo00<007ooOol06goo000GOol00`00Oomoo`03Ool50003Ool00`00Oomoo`0LOol6000X
Ool7000>Ool00`00E_eFo@030002<C@00`00DWQBN003DWP4JaT00`00Oomoo`1COol00`00Oomoo`0U
Ool00`00Oomoo`09Ool00`00Oomoo`0KOol001Moo`03001oogoo00=oo`@000Eoo`03001oogoo01Qo
o`H002Uoo`H0019oo`80009oo`04000a=34d0004DWP01000JaU[6F/I0P00EGoo00<007ooOol09Goo
0P002goo00<007ooOol06Woo000GOol00`00Oomoo`03Ool50005Ool00`00Oomoo`0DOol7000XOol6
000HOol01@00<C@a=34d0000159h00D006/IJaU[6@0005Ioo`03001oogoo02Ioo`8000Yoo`03001o
ogoo01Yoo`005goo00<007ooOol00goo0P0000Aoo`00000000Eoo`03001oogoo015oo`H002Qoo`L0
01Yoo`04000a=34d0005DWP4JaT00`00Oomoo`1DOol00`00Oomoo`0WOol00`00Oomoo`09Ool00`00
Oomoo`0IOol001Moo`03001oogoo00=oo`80009oo`<000Eoo`03001oogoo00eoo`H002Qoo`L001eo
o`04000a=34d<C@4DWP01000JaU[6F/I0P00EWoo00<007ooOol09goo0P002goo00<007ooOol067oo
000GOol00`00Oomoo`03Ool20003Ool30005Ool00`00Oomoo`09Ool7000WOol7000OOol01@00<C@a
=34d0000159h00D006/IJaU[6@0005Moo`03001oogoo02Qoo`8000Yoo`03001oogoo01Qoo`005Woo
00<007ooOol017oo0P0017oo0`001Goo00<007ooOol01Woo1P00:7oo1P008Woo00@0034d<C@000EB
N0A[6@03001oogoo05Eoo`03001oogoo02Uoo`03001oogoo00Qoo`8001Uoo`005Woo00<007ooOol0
17oo0P001Goo0`001Goo00<007ooOol00Woo1P00:7oo1P009Goo00@0034d<C@a=0ABN004001[6F/I
JaT2001GOol00`00Oomoo`0YOol20006Ool300000goo001oo`0HOol001Ioo`03001oogoo00=oo`80
00Moo`<000Eoo`P002Moo`L002Moo`04000a=34d0004DWP01@00JaU[6F/I0000F7oo00<007ooOol0
:Woo0P000Woo0`0017oo00<007ooOol05goo000FOol00`00Oomoo`03Ool20008Ool30003Ool6000W
Ool7000YOol01@00<C@a=34d0000159h00D006/IJaU[6@0005Qoo`03001oogoo02]oo`<000Moo`03
001oogoo01Moo`005Woo00<007ooOol00goo0P002Goo200000=oo`00Ool097oo1`00;7oo00@0034d
<C@a=0ABN004001[6F/IJaT2001IOol00`00Oomoo`0WOol50009Ool00`00Oomoo`0FOol001Ioo`03
001oogoo00=oo`8000Yoo`D000Aoo`03001oogoo021oo`H002moo`04000a=34d0004DWP01@00JaU[
6F/I0000FWoo00<007ooOol097oo0`0017oo0P0027oo00<007ooOol05Woo000FOol00`00Oomoo`03
Ool2000;Ool40005Ool00`00Oomoo`0LOol6000aOol01@00<C@a=34d0000159h00D006/IJaU[6@00
05Yoo`03001oogoo025oo`<000Eoo`@000Qoo`03001oogoo01Ioo`005Goo00<007ooOol017oo0P00
3Goo0`001Goo00<007ooOol067oo1`00<goo00@0034d<C@a=0ABN004001[6F/IJaT2001JOol00`00
Oomoo`0NOol30005Ool70008Ool00`00Oomoo`0FOol001Eoo`03001oogoo00Aoo`8000ioo`<000Eo
o`03001oogoo01Aoo`L003Ioo`04000a=34d0004DWP01@00JaU[6F/I0000Fgoo00<007ooOol06goo
0`001Goo1P0037oo00<007ooOol05Woo000EOol00`00Oomoo`04Ool2000?Ool30005Ool00`00Oomo
o`0@Ool7000hOol01@00<C@a=34d0000159h00D006/IJaU[6@0005]oo`03001oogoo01Qoo`<000Eo
o`H000moo`03001oogoo01Ioo`005Goo00<007ooOol00goo0P004Goo0`001Goo00<007ooOol03Goo
1P00>goo00@0034d<C@a=0ABN004001[6F/IJaT2001KOol00`00Oomoo`0EOol30005Ool6000BOol0
0`00Oomoo`0FOol001Eoo`03001oogoo00=oo`80019oo`<000Eoo`03001oogoo00Uoo`H003ioo`04
000a=34d0004DWP01000JaU[6F/I0P00Fgoo00<007ooOol04Woo0`001Goo1P005Goo00<007ooOol0
5Woo000EOol00`00Oomoo`03Ool2000COol30005Ool00`00Oomoo`05Ool7000oOol01@00<C@a=34d
0000159h00D006/IJaU[6@0005aoo`03001oogoo00moo`<000Eoo`H001Uoo`03001oogoo01Eoo`00
5Goo00<007ooOol00goo0P0057oo0`001Goo00@007ooOomoo`L0049oo`04000a=34d<C@4DWP01000
JaU[6F/I0P00G7oo00<007ooOol037oo0`001Goo1P0077oo00<007ooOol05Goo000DOol00`00Oomo
o`04Ool2000EOol30005Ool70015Ool01000<C@a=000159h00@006/IJaU[6@8005aoo`03001oogoo
00Uoo`<000Eoo`H001moo`03001oogoo01Eoo`0057oo00<007ooOol017oo0P005Woo0`000Woo1P00
B7oo00@0034d<C@000ABN005001[6F/IJaT0001MOol00`00Oomoo`06Ool30005Ool6000ROol00`00
Oomoo`0EOol001Aoo`03001oogoo00Aoo`8001Moo`T004Qoo`04000a=34d<C@4DWP01000JaU[6F/I
0P00GGoo00<007ooOol00Woo10001Goo1P009Goo00<007ooOol05Goo000DOol00`00Oomoo`03Ool2
000HOol50004Ool00`00Oomoo`15Ool01000<C@a=000159h00@006/IJaU[6@8005ioo`@000Ioo`H0
02Qoo`03001oogoo01Eoo`0057oo00<007ooOol00goo0P006Goo10001Goo00<007ooOol0A7oo00@0
034d<C@000ABN005001[6F/IJaT0001MOol30006Ool6000[Ool00`00Oomoo`0EOol001Aoo`03001o
ogoo00=oo`8001]oo`<000Eoo`03001oogoo049oo`05000a=34d<C@00003DWP01000JaU[6F/I0P00
FWoo0`000Woo00@007ooOomoo`H002moo`03001oogoo01Aoo`0057oo00<007ooOol00goo0P0077oo
0`001Goo00<007ooOol0@Goo00@0034d<C@000ABN004001[6F/IJaT2001GOol30005Ool7000bOol0
0`00Oomoo`0DOol001Aoo`03001oogoo00=oo`8001eoo`<000Eoo`03001oogoo041oo`04000a=34d
0004DWP01@00JaU[6F/I0000EGoo0`001Goo1`00=Goo00<007ooOol057oo000COol00`00Oomoo`04
Ool2000NOol30005Ool00`00Oomoo`0nOol01@00<C@a=34d00000e9h00@006/IJaU[6@80059oo`<0
00Eoo`L003Qoo`03001oogoo01Aoo`004goo00<007ooOol017oo0P007goo0`001Goo00<007ooOol0
?Goo00@0034d<C@000ABN004001[6F/IJaT2001?Ool30005Ool60003Ool00`00Oomoo`0fOol00`00
Oomoo`0DOol001=oo`03001oogoo00Aoo`80021oo`<000Eoo`03001oogoo03aoo`04000a=34d0004
DWP01@00JaU[6F/I0000CGoo0`001Goo1P001Woo00<007ooOol0=Woo00<007ooOol057oo000COol0
0`00Oomoo`03Ool2000ROol30005Ool00`00Oomoo`0jOol01@00<C@a=34d0000159h00D006/IJaU[
6@0004Yoo`<000Eoo`H000Uoo`03001oogoo03Ioo`03001oogoo01Aoo`004goo00<007ooOol00goo
0P008goo0`001Goo00<007ooOol0>Goo00@0034d<C@000ABN004001[6F/IJaT20017Ool30005Ool6
000<Ool00`00Oomoo`0fOol00`00Oomoo`0DOol001=oo`03001oogoo00=oo`8002Aoo`<000Eoo`03
001oogoo03Qoo`04000a=34d0004DWP01@00JaU[6F/I0000AGoo0`001Goo1P003goo00<007ooOol0
=goo00<007ooOol04goo000COol00`00Oomoo`03Ool2000UOol40004Ool00`00Oomoo`0gOol01000
<C@a=000159h00D006/IJaU[6@00049oo`<000Eoo`H0019oo`03001oogoo03Moo`03001oogoo01=o
o`004Woo00<007ooOol017oo0P009Woo100017oo00<007ooOol0=Goo00@0034d<C@000ABN004001[
6F/IJaT2000oOol30005Ool6000EOol00`00Oomoo`0gOol00`00Oomoo`0COol0019oo`03001oogoo
00Aoo`8002Qoo`<000Aoo`03001oogoo03Aoo`04000a=34d0004DWP01@00JaU[6F/I0000?Goo0`00
1Goo1P0067oo00<007ooOol0=goo00<007ooOol04goo000BOol00`00Oomoo`04Ool2000YOol30004
Ool00`00Oomoo`0cOol01000<C@a=000159h00D006/IJaU[6@0003Yoo`<000Eoo`H001aoo`03001o
ogoo03Ioo`03001oogoo01=oo`004Woo00<007ooOol00goo0P00:goo0`0017oo00<007ooOol0<Goo
00@0034d<C@000ABN004001[6F/IJaT2000gOol30005Ool6000OOol00`00Oomoo`0fOol00`00Oomo
o`0COol0019oo`03001oogoo00=oo`8002aoo`<000Aoo`03001oogoo031oo`04000a=34d0004DWP0
1@00JaU[6F/I0000=Goo0`001Goo1P008Woo00<007ooOol0=Woo00<007ooOol04goo000BOol00`00
Oomoo`03Ool2000]Ool30004Ool00`00Oomoo`0_Ool01000<C@a=000159h00D006/IJaU[6@00039o
o`<000Aoo`L002Eoo`03001oogoo03Moo`03001oogoo019oo`004Woo00<007ooOol00goo0P00;Woo
0`0017oo00<007ooOol0;Goo00D0034d<C@a=00000=BN004001[6F/IJaT2000_Ool30004Ool7000X
Ool00`00Oomoo`0gOol00`00Oomoo`0BOol0015oo`03001oogoo00Aoo`8002moo`<000Aoo`03001o
ogoo02aoo`04000a=34d0004DWP01@00JaU[6F/I0000;Goo0`0017oo1`00:goo00<007ooOol0=goo
00<007ooOol04Woo000AOol00`00Oomoo`04Ool2000`Ool30004Ool00`00Oomoo`0[Ool01000<C@a
=000159h00D006/IJaU[6@0002Yoo`<000Aoo`H002ioo`8003Uoo`03001oogoo019oo`004Goo00<0
07ooOol017oo0P00<Goo0`0017oo00<007ooOol0:Goo00D0034d<C@a=00000=BN004001[6F/IJaT2
000WOol30004Ool6000^Ool30002Ool00`00Oomoo`0fOol00`00Oomoo`0BOol0015oo`03001oogoo
00Aoo`80039oo`<000Aoo`03001oogoo02Qoo`04000a=34d0004DWP01000JaU[6F/I0P0097oo0`00
0goo1`00;Goo10001Woo00<007ooOol0=Goo00<007ooOol04Woo000AOol00`00Oomoo`03Ool2000d
Ool30004Ool00`00Oomoo`0WOol01000<C@a=000159h00D006/IJaU[6@00029oo`<000=oo`L002eo
o`<000Yoo`03001oogoo03Eoo`03001oogoo019oo`004Goo00<007ooOol00goo0P008goo10003Woo
0`0017oo00<007ooOol09Woo00@0034d<C@000=BN004001[6F/IJaT2000OOol30003Ool6000^Ool3
000>Ool00`00Oomoo`0dOol00`00Oomoo`0BOol0015oo`03001oogoo00=oo`80025oo`<000=j/0D0
00Yoo`<000Aoo`8002Eoo`04000a=34d0004DWP01000JaU[6F/I0P0077oo0`000goo1P00;Woo0`00
4Woo00<007ooOol0=7oo00<007ooOol04Goo000@Ool00`00Oomoo`04Ool2000OOol200000aP0001j
/008N[060005Ool30005Ool00`00Oomoo`0ROol01000<C@a=000159h00D006/IJaU[6@0001Yoo`<0
009oo`L002ioo`<001Ioo`03001oogoo03=oo`03001oogoo015oo`0047oo00<007ooOol017oo0P00
7Woo00@001P06000011j/0<000=oo`<000Eoo`03001oogoo025oo`04000a=34d0004DWP00`00JaU[
6@02000GOol30002Ool7000]Ool4000IOol00`00Oomoo`0cOol00`00Oomoo`0AOol0011oo`03001o
ogoo00Aoo`8001eoo`04000H01P0000DN[001000Oomoogoo0`001Goo00<007ooOol07goo00@0034d
<C@000ABN004001[6F/IJaT2000DOol30002Ool6000^Ool3000NOol00`00Oomoo`0bOol00`00Oomo
o`0AOol0011oo`03001oogoo00Aoo`8001aoo`04000H01P0000FN[001000Oomoogoo0`001Goo00<0
07ooOol07Woo00@0034d<C@000ABN005001[6F/IJaT0000BOol30002Ool6000^Ool3000ROol00`00
Oomoo`0aOol00`00Oomoo`0AOol0011oo`03001oogoo00=oo`8001aoo`04000H01P0000HN[001000
Oomoogoo0`001Goo00<007ooOol07Goo00@0034d<C@000ABN003001[6F/I008000ioo`@00003Ool0
000000D002ioo`<002Ioo`03001oogoo031oo`03001oogoo015oo`0047oo00<007ooOol00goo0P00
6goo00D001P0600H000001Uj/004001oogooOol30005Ool00`00Oomoo`0KOol01@00<C@a=34d0000
0e9h00@006/IJaU[6@8000]oo`<0009oo`L002eoo`@002Yoo`03001oogoo02moo`03001oogoo015o
o`0047oo00<007ooOol00goo0P006Woo00D001P0600H000001]j/004001oogooOol30005Ool00`00
Oomoo`0JOol01000<C@a=000159h00D006/IJaU[6@0000Uoo`<0009oo`H002ioo`<002ioo`03001o
ogoo031oo`03001oogoo011oo`003goo00<007ooOol017oo0P006Woo00@001P0600001ej/004001o
ogooOol30005Ool00`00Oomoo`0IOol01000<C@a=000159h00D006/IJaU[6@0000Ioo`<0009oo`H0
02ioo`<0039oo`03001oogoo02moo`03001oogoo011oo`003goo00<007ooOol017oo0P006Goo00@0
01P0600001mj/004001oogooOol30005Ool00`00Oomoo`0GOol01@00<C@a=34d00000e9h00@006/I
JaU[6@8000=oo`<00003Ool0000000D002ioo`<003Ioo`03001oogoo02ioo`03001oogoo011oo`00
3goo00<007ooOol017oo0P0067oo00@001P06000025j/004001oogooOol30005Ool00`00Oomoo`0F
Ool01000<C@a=000159h00H006/IJaU[6@00Ool300000goo00000005000^Ool3000jOol00`00Oomo
o`0]Ool00`00Oomoo`0@Ool000moo`03001oogoo00Aoo`8001Moo`04000H0000000RN[000`00Oomo
o`02Ool30005Ool00`00Oomoo`0EOol01000<C@a=000159h00@006/IJaU[6@800003Ool0000000D0
02eoo`@003eoo`03001oogoo02eoo`03001oogoo011oo`003goo00<007ooOol017oo0P005Woo0`00
00=13`00N[008WZ`00<007ooOol00Woo0`001Goo00<007ooOol057oo00@0034d<C@000=BN004001[
6F/IJaT8000]Ool30012Ool00`00Oomoo`0/Ool00`00Oomoo`0@Ool000moo`03001oogoo00=oo`80
01Ioo`8000=13`03001j/7Z`029j/003001oogoo009oo`@000Aoo`03001oogoo019oo`04000a=34d
0004DWP01000JaU[6F/I1@00;Goo0`00AWoo00<007ooOol0:goo00<007ooOol047oo000?Ool00`00
Oomoo`03Ool2000FOol00`00@@m13`02@@l00`00N[1j/00SN[000`00Oomoo`02Ool40004Ool00`00
Oomoo`0AOol01000<C@a=000159h00@006/IJaU[6@8002eoo`<004Yoo`03001oogoo02Yoo`03001o
ogoo011oo`003Woo00<007ooOol017oo0P005Woo00D0044?@@m13`0002Mj/003001oogoo00=oo`<0
00Aoo`03001oogoo011oo`04000a=34d0003DWP01000JaU[6F/I0P00:goo0`00CWoo00<007ooOol0
:Woo00<007ooOol03goo000>Ool00`00Oomoo`04Ool2000FOol01@00@@m13d4?0000:7Z`00<007oo
Ool00goo0`0017oo00<007ooOol037oo0`000S4d00<0059hDWP00U9h00D006/IJaU[6@0002Qoo`@0
055oo`03001oogoo02Yoo`03001oogoo00moo`003Woo00<007ooOol017oo0P005Goo00<0044?@@l0
0T4?00<007Z`N[009gZ`00<007ooOol00goo0`0017oo00<007ooOol027oo0`000Woo00@0034d<C@0
00ABN005001[6F/IJaT0000UOol3001FOol00`00Oomoo`0YOol00`00Oomoo`0?Ool000ioo`03001o
ogoo00Aoo`8001Eoo`0300113d4?00913`03001j/7Z`02Qj/003001oogoo00=oo`<000Aoo`03001o
ogoo00Aoo`<0009oo`D00003<C@0059h009BN004001[6F/IJaT2000ROol3001JOol00`00Oomoo`0X
Ool00`00Oomoo`0?Ool000ioo`03001oogoo00Aoo`8001Eoo`0300113d4?00913`03001j/7Z`02Uj
/003001oogoo00=oo`<000Aoo`03001oogoo00<0009oo`L00003<C@0059h00=BN005001[6F/IJaT0
000POol3001NOol00`00Oomoo`0WOol00`00Oomoo`0?Ool000ioo`03001oogoo00=oo`8001Ioo`03
00113d4?00913`03001j/7Z`02Mj/003001j/00000Ioo`<000Aoo`80009oo`L00005Ool0034d<C@0
0004DWP01@00JaU[6F/I000077oo1000HGoo00<007ooOol09goo00<007ooOol03goo000>Ool00`00
Oomoo`03Ool2000FOol01@00@@m13d4?0000;GZ`00<007ooOol017oo0`000goo200017oo00@0034d
<C@000=BN004001[6F/IJaT2000IOol3001VOol00`00Oomoo`0VOol00`00Oomoo`0?Ool000eoo`03
001oogoo00Aoo`8001Ioo`0500113d4?@@l0000]N[000`00Oomoo`05Ool:0006Ool01@00<C@a=34d
00000e9h00D006/IJaU[6@0001Moo`<006Yoo`03001oogoo02Ioo`03001oogoo00ioo`003Goo00<0
07ooOol017oo0P005Goo00<0044?@@l00T4?00<007Z`N[00;7Z`00<007ooOol01Goo1P002Goo00@0
034d<C@000ABN005001[6F/IJaT0000DOol3001^Ool00`00Oomoo`0UOol00`00Oomoo`0>Ool000eo
o`03001oogoo00Aoo`8001Eoo`0300113d4?00913`03001j/7Z`02aj/003001oogoo00Eoo`80009o
o`03001oogoo00Qoo`04000a=34d0004DWP00`00JaU[6@02000AOol3001bOol00`00Oomoo`0TOol0
0`00Oomoo`0>Ool000eoo`03001oogoo00Aoo`8001Eoo`0300113d4?00913`03001j/7Z`02ej/003
001oogoo00Aoo`80009oo`03001oogoo00Qoo`04000a=34d0003DWP01000JaU[6F/I0P003Goo1000
MGoo00<007ooOol097oo00<007ooOol03Woo000=Ool00`00Oomoo`04Ool2000EOol00`00@@m13`02
@@l00`00N[1j/00]N[000`00Oomoo`04Ool20002Ool00`00Oomoo`07Ool01000<C@a=000159h00D0
06/IJaU[6@0000]oo`<007Yoo`03001oogoo02=oo`03001oogoo00ioo`003Goo00<007ooOol017oo
0P005Goo00<0044?@@l00T4?00<007Z`N[00;WZ`00<007ooOol00goo0P000Woo00<007ooOol01goo
00@0034d<C@000ABN003001[6F/I008000Qoo`<007ioo`03001oogoo029oo`03001oogoo00ioo`00
3Goo00<007ooOol00goo0P005Woo00D0044?@@m13`00035j/003001oogoo00=oo`80009oo`03001o
ogoo00Moo`04000a=34d0003DWP01000JaU[6F/I0P001Goo0`00PWoo00<007ooOol08Goo00<007oo
Ool03Woo000<Ool00`00Oomoo`04Ool2000FOol01@00@@m13d4?0000<WZ`00<007ooOol00Woo0P00
0Woo00<007ooOol01Woo00@0034d<C@000ABN005001[6F/IJaT00002Ool40025Ool00`00Oomoo`0R
Ool00`00Oomoo`0=Ool000aoo`03001oogoo00Aoo`8001Eoo`0300113d4?00913`03001j/7Z`031j
/003001oogoo009oo`800003Ool007oo00Qoo`04000a=34d0004DWP01000JaU[6F/I0`00RWoo00<0
07ooOol08Goo00<007ooOol03Goo000<Ool00`00Oomoo`04Ool2000EOol00`00@@m13`02@@l00`00
N[1j/00aN[001000Oomoogoo0P0000=oo`00Ool027oo00@0034d<C@000=BN003001[6@0000<008eo
o`03001oogoo021oo`03001oogoo00eoo`0037oo00<007ooOol017oo0P005Goo00<0044?@@l00T4?
00<007Z`N[00<GZ`00@007ooOomoo`800003Ool007oo00Moo`04000a=34d0003DWP30002JaT00`00
Oomoo`2=Ool00`00Oomoo`0OOol00`00Oomoo`0=Ool000aoo`03001oogoo00Aoo`8001Eoo`030011
3d4?00913`03001j/7Z`039j/003001oogoo00800003Ool007oo00Moo`03000a=34d00@00003DWP0
06/I009[6@03001oogoo08ioo`03001oogoo01ioo`03001oogoo00eoo`0037oo00<007ooOol017oo
0P005Goo00D0044?@@m13`0003Ej/003001oogoo00800003Ool007oo00Moo`@000=BN004001[6F/I
JaT2002@Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool000aoo`03001oogoo00=oo`8001Ioo`050011
3d4?@@l0000fN[001P00Ool00000Ool000Eoo`<0008a=003001BN59h009BN005001[6F/IJaT0002B
Ool00`00Oomoo`0MOol00`00Oomoo`0=Ool000]oo`03001oogoo00Aoo`8001Eoo`0300113d4?0091
3`03001j/7Z`03Aj/006001oo`00001oo`000Woo0`000Woo00@0034d<C@000ABN005001[6F/IJaT0
002COol00`00Oomoo`0LOol00`00Oomoo`0=Ool000]oo`03001oogoo00Aoo`8001Eoo`0400113d4?
@@l2000gN[03000017oo000000001Goo00@0034d<C@000=BN004001[6F/IJaT2002DOol00`00Oomo
o`0LOol00`00Oomoo`0<Ool000]oo`03001oogoo00Aoo`8001Eoo`0600113`00001=e@00=gZ`1@00
1goo00@0034d<C@000=BN005001[6F/IJaT0002EOol00`00Oomoo`0LOol00`00Oomoo`0<Ool000]o
o`03001oogoo00Aoo`8001Eoo`8000==e@03001j/7Z`039j/0<00005N[000000Ool00006Ool01000
<C@a=000159h00D006/IJaU[6@0009Ioo`03001oogoo01]oo`03001oogoo00aoo`002goo00<007oo
Ool017oo0P005Goo00<004gECMD00dgE00<007Z`N[00;WZ`0`0017Z`0P0000=oo`00Ool01Goo00@0
034d<C@000=BN004001[6F/IJaT2002GOol00`00Oomoo`0JOol00`00Oomoo`0<Ool000]oo`03001o
ogoo00Aoo`8001Eoo`03001=eDgE00==e@03001j/7Z`02]j/0<000Qj/003001oo`0000Ioo`04000a
=34d0003DWP01@00JaU[6F/I0000VGoo00<007ooOol06Goo00<007ooOol037oo000;Ool00`00Oomo
o`04Ool2000FOol00`00CME=e@02CMD00`00N[1j/00XN[03000;N[000`00Ool00005Ool01000<C@a
=000159h00D006/IJaU[6@0009Yoo`03001oogoo01Qoo`03001oogoo00aoo`002goo00<007ooOol0
0goo0P005goo00<004gECMD00TgE00<007Z`N[0097Z`10003gZ`0P001Goo00@0034d<C@000ABN003
001[6F/I008009Yoo`03001oogoo01Qoo`03001oogoo00aoo`002Woo00<007ooOol017oo0P005goo
00<004gECMD00TgE00<007Z`N[008GZ`0`004gZ`0P001Goo00@0034d<C@000=BN005001[6F/IJaT0
002LOol00`00Oomoo`0HOol00`00Oomoo`0;Ool000Yoo`03001oogoo00Aoo`8001Moo`03001=eDgE
009=e@03001j/7Z`01ij/0<001Ij/08000Aoo`04000a=34d0004DWP01@00JaU[6F/I0000WGoo00<0
07ooOol05goo00<007ooOol02goo000:Ool00`00Oomoo`04Ool2000GOol00`00CME=e@03CMD00`00
N[1j/00JN[03000IN[020004Ool01000<C@a=000159h00<006/IJaT00P00WWoo00<007ooOol05Woo
00<007ooOol02goo000:Ool00`00Oomoo`04Ool2000HOol00`00CME=e@02CMD00`00N[1j/00FN[04
000MN[000`00Oomoo`02Ool01000<C@a=0000e9h00D006/IJaU[6@0009moo`03001oogoo01Ioo`03
001oogoo00]oo`002Woo00<007ooOol017oo0P0067oo00<004gECMD00TgE00<007Z`N[004gZ`0`00
8GZ`00D007ooOomoo`00008a=003001BN59h009BN005001[6F/IJaT0002POol00`00Oomoo`0EOol0
0`00Oomoo`0;Ool000Yoo`03001oogoo00Aoo`8001Qoo`03001=eDgE009=e@03001j/7Z`011j/0<0
02Aj/005001oogooOol00002<C@00`00DWQBN002DWP00`00JaU[6@02002QOol00`00Oomoo`0DOol0
0`00Oomoo`0;Ool000Yoo`03001oogoo00=oo`8001Uoo`03001=eDgE009=e@03001j/7Z`00ej/0<0
02Mj/005001oogooOol00002<C@01@00DWQBN59h00000f/I0P00XWoo00<007ooOol04goo00<007oo
Ool02goo0009Ool00`00Oomoo`04Ool2000IOol00`00CME=e@03CMD00`00N[1j/009N[03000[N[00
1000Oomoo`000S4d00D0059hDWQBN00000=[6@03001oogoo0:9oo`03001oogoo019oo`03001oogoo
00]oo`002Goo00<007ooOol017oo0P006Woo00<004gECMD00TgE00<007Z`N[001GZ`1000;WZ`00<0
07oo00000S4d00<0059hDWP00U9h00<006/IJaT00P00Y7oo00<007ooOol04goo00<007ooOol02Woo
0009Ool00`00Oomoo`04Ool2000JOol00`00CME=e@02CMD00`00N[1j/002N[03000bN[000`00Ool0
0002<C@01@00DWQBN59h00000f/I0P00YGoo00<007ooOol04Woo00<007ooOol02Woo0009Ool00`00
Oomoo`04Ool2000JOol00`00CME=e@02CMD00`00N[000002000eN[000`00Ool00002<C@01@00DWQB
N59h00000f/I00<007ooOol0YGoo00<007ooOol04Goo00<007ooOol02Woo0009Ool00`00Oomoo`04
Ool2000JOol01000CME=eDgE0`00>7Z`0P000S4d00<0059hDWP00U9h00D006/IJaU[6@000:Qoo`03
001oogoo011oo`03001oogoo00Yoo`002Goo00<007ooOol017oo0P006Woo10000TgE00<007Z`N[00
=gZ`00@0034d<C@000=BN004001[6F/IJaT2002XOol00`00Oomoo`0@Ool00`00Oomoo`0:Ool000Uo
o`03001oogoo00Aoo`8001Moo`@000E=e@03001j/7Z`03Mj/004000a=34d0003DWP01@00JaU[6F/I
0000ZWoo00<007ooOol03goo00<007ooOol02Woo0008Ool00`00Oomoo`04Ool2000EOol30004Ool0
0`00CME=e@02CMD00`00N[1j/00fN[001000<C@a=000159h00D006/IJaU[6@000:]oo`03001oogoo
00ioo`03001oogoo00Yoo`0027oo00<007ooOol017oo0P004Woo0`001goo00<004gECMD00TgE00<0
07Z`N[00=WZ`00@0034d<C@000=BN004001[6F/IJaT2002/Ool00`00Oomoo`0>Ool00`00Oomoo`09
Ool000Qoo`03001oogoo00Aoo`8000moo`<000Yoo`03001=eDgE009=e@03001j/7Z`03Ij/004000a
=34d0003DWP01@00JaU[6F/I0000[Woo00<007ooOol03Goo00<007ooOol02Goo0008Ool00`00Oomo
o`04Ool2000;Ool4000=Ool00`00CME=e@02CMD00`00N[1j/00eN[001000<C@a=000159h00D006/I
JaU[6@000:ioo`03001oogoo00eoo`03001oogoo00Uoo`0027oo00<007ooOol017oo0P0027oo0`00
4Goo00<004gECMD00dgE00<007Z`N[00=7Z`00@0034d<C@000ABN003001[6F/I00800:moo`03001o
ogoo00aoo`03001oogoo00Uoo`0027oo00<007ooOol017oo0P001Goo0`005Goo00<004gECMD00TgE
00<007Z`N[00=7Z`00@0034d<C@000=BN005001[6F/IJaT0002aOol00`00Oomoo`0;Ool00`00Oomo
o`09Ool000Qoo`03001oogoo00Aoo`80009oo`<001Qoo`03001=eDgE009=e@03001j/7Z`03Aj/08a
=003001BN59h009BN005001[6F/IJaT0002bOol00`00Oomoo`0:Ool00`00Oomoo`09Ool000Moo`03
001oogoo00Aoo`D001]oo`03001=eDgE009=e@03001j/7Z`03=j/004000a=34d0004DWP00`00JaU[
6@02002bOol00`00Oomoo`0:Ool00`00Oomoo`09Ool000Moo`03001oogoo009oo`L001]oo`03001=
eDgE009=e@03001j/7Z`03=j/004000a=34d0003DWP01@00JaU[6F/I0000]7oo00<007ooOol02Goo
00<007ooOol02Goo0007Ool00`00Ool000020004Ool4000JOol00`00CME=e@03CMD00`00N[1j/00b
N[03<C@01@00DWQBN59h00000f/I00<007ooOol0/goo00<007ooOol02Goo00<007ooOol027oo0007
Ool20009Ool3000JOol00`00CME=e@02CMD00`00N[1j/00aN[001000<C@a=000159h00<006/IJaT0
0P00]Woo00<007ooOol027oo00<007ooOol027oo0008Ool00`00Oomoo`08Ool3000IOol00`00CME=
e@03000cN[001000<C@a=0000e9h00D006/IJaU[6@000;Qoo`03001oogoo00Moo`03001oogoo00Qo
o`002Goo0P002Goo10005goo0`000U9i00<007Z`N[00<GZ`0c4d00D0059hDWQBN00000=[6@03001o
ogoo0;Ioo`03001oogoo00Moo`03001oogoo00Qoo`002goo00<007ooOol01goo10005Woo00<0059i
DWT00e9i00<007Z`N[00;gZ`00@0034d<C@000ABN003001[6F/I00800;Uoo`03001oogoo00Ioo`03
001oogoo00Qoo`0037oo00<007ooOol027oo0`005Woo00<0059iDWT00U9i00<007Z`N[00;gZ`00@0
034d<C@000=BN005001[6F/IJaT0002kOol00`00Oomoo`05Ool00`00Oomoo`08Ool000eoo`8000Uo
o`@001Aoo`03001BNE9i00=BN@03001j/7Z`02ij/0<a=005001BN59hDWP00003JaT00`00Oomoo`2j
Ool00`00Oomoo`04Ool00`00Oomoo`08Ool000moo`03001oogoo00Moo`@001Aoo`03001BNE9i009B
N@03001j/7Z`02ej/004000a=34d0004DWP00`00JaU[6@02002lOol00`00Oomoo`05Ool00`00Oomo
o`07Ool0011oo`03001oogoo00Qoo`<001=oo`03001BNE9i00=BN@03001j/7Z`02aj/004000a=34d
0003DWP01@00JaU[6F/I0000_Woo00<007ooOol017oo00<007ooOol01goo000AOol20009Ool3000C
Ool00`00DWUBN@02DWT00`00N[1j/00/N[03<C@01@00DWQBN59h00000f/I00<007ooOol0_Goo00<0
07ooOol00goo00<007ooOol01goo000COol00`00Oomoo`07Ool4000AOol00`00DWUBN@03DWT00`00
N[1j/00[N[02<C@00`00DWQBN002DWP00`00JaU[6@020030Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool001Aoo`03001oogoo00Moo`@0015oo`03001BNE9i009BN@03001j/7Z`02Yj/004000a=34d0003
DWP01000JaU[6F/I0P00`Goo00D007ooOomoo`0000Uoo`005Goo0P002Goo0`0047oo00<0059iDWT0
0e9i00<007Z`N[00:GZ`0c4d00D0059hDWQBN00000=[6@03001oogoo0<1oo`05001oogooOol00009
Ool001Moo`03001oogoo00Moo`@000moo`03001BNE9i009BN@03001j/7Z`02Uj/08a=003001BN59h
009BN005001[6F/IJaT00033Ool01000Oomoo`002Goo000HOol00`00Oomoo`07Ool4000>Ool00`00
DWUBN@03DWT00`00N[1j/00WN[001000<C@a=0000e9h00@006/IJaU[6@800<Aoo`03001oo`0000Uo
o`006Goo00<007ooOol027oo0`003Woo00<0059iDWT00U9i00<007Z`N[009gZ`0c4d00D0059hDWQB
N00000=[6@03001oogoo0<Aoo`03001oo`0000Qoo`006Woo0P002Goo0`003Goo00<0059iDWT00e9i
00<007Z`N[009WZ`0c4d00D0059hDWQBN00000=[6@03001oogoo0<Aoo`03001oo`0000Qoo`0077oo
00<007ooOol01goo100037oo00<0059iDWT00U9i00<007Z`N[009gZ`00<a=000DWP00e9h00<006/I
JaT00P00agoo0P0027oo000MOol00`00Oomoo`07Ool4000;Ool00`00DWUBN@03DWT00`00N[1j/00T
N[001000N[0a=0000e9h00D006/IJaU[6@000<Qoo`8000Qoo`007Woo0P002Goo0`002goo00<0059i
DWT00U9i00<007Z`N[009GZ`0S4d00D0059hDWQBN00000=[6@03001oogoo0<9oo`@000Yoo`0087oo
00<007ooOol01goo10002Goo00<0059iDWT00e9i00<007Z`N[009GZ`00<0059hDWP00U9h00<006/I
JaT00P00`7oo10003Woo000QOol00`00Oomoo`07Ool40009Ool00`00DWUBN@02DWT00`00N[1j/00U
N[001@00DWQBN59h00000f/I0P00_7oo10004Woo000ROol20009Ool30008Ool00`00DWUBN@03DWT0
0`00N[1j/00TN[04DWP01000JaU[6F/I0P00^7oo10005Woo000TOol00`00Oomoo`07Ool30008Ool0
0`00DWUBN@02DWT00`00N[1j/00UN[03DWP01P00JaU[6@00N[000;Aoo`@001Yoo`009Goo00<007oo
Ool01goo10001Woo00<0059iDWT00e9i00<007Z`N[0097Z`00<0059h00000V/I0P0000=j/000Ool0
/7oo0`007Woo000VOol00`00Oomoo`07Ool40006Ool00`00DWUBN@02DWT00`00N[1j/00UN[040002
N[000`00Oomoo`2/Ool4000QOol002Moo`8000Uoo`<000Eoo`03001BNE9i00=BN@03001j/7Z`02Yj
/003001oogoo0:Qoo`@002Eoo`00:Goo00<007ooOol01goo100017oo00<0059iDWT00U9i00<007Z`
N[00:WZ`00<007ooOol0Y7oo1000:Goo000ZOol00`00Oomoo`07Ool40003Ool00`00DWUBN@03DWT0
0`00N[1j/00YN[000`00Oomoo`2POol4000]Ool002]oo`8000Uoo`<000=oo`03001BNE9i009BN@03
001j/7Z`02Uj/003001oogoo09aoo`@0035oo`00;Goo00<007ooOol01goo0`000Woo00@0059iDWUB
N@<002Uj/003001oogoo09Yoo`<003Eoo`00;Woo00<007ooOol01goo100000Aoo`00000000=C7@03
001j/7Z`02Ij/003001oogoo09Ioo`@003Qoo`00;goo0P0027oo100000=oo`00Dad015<M00<007Z`
N[0097Z`00<007ooOol0Tgoo1000?7oo000aOol00`00Oomoo`07Ool300000goo001C7@04Dad2000T
N[000`00Oomoo`2?Ool40010Ool0039oo`03001oogoo00Moo`H000EC7@03001j/7Z`021j/003001o
ogoo08aoo`@004Aoo`00<goo0P0027oo100000=oo`00Dad015<M00<007Z`N[007WZ`00<007ooOol0
RGoo1000B7oo000eOol00`00Oomoo`07Ool300000goo001C7@04Dad00`00N[1j/00MN[000`00Oomo
o`26Ool3001<Ool003Ioo`03001oogoo00Moo`<00003Ool005<M00AC7@03001j/7Z`01]j/003001o
ogoo08=oo`@004moo`00=goo00<007ooOol01goo1@001E<M0P006gZ`00<007ooOol0Ogoo1000Dgoo
000hOol20008Ool60005Dad00`00N[1j/00GN[000`00Oomoo`1lOol4001GOol003Yoo`03001oogoo
00Moo`<00003Ool005<M00AC7@03001j/7Z`01Ej/08007Yoo`@005]oo`00>goo00<007ooOol01goo
0`0000=oo`00Dad015<M00<007Z`N[0057Z`0P00MWoo1000Ggoo000lOol20008Ool300000goo001C
7@04Dad00`00N[1j/00BN[000`00Ool0001cOol3001SOol003ioo`03001oogoo00Ioo`<00003Ool0
05<M00AC7@80019j/080071oo`@006Ioo`00?goo00<007ooOol01Woo1P001E<M00<007Z`N[001gZ`
200000=oo`00Ool0Jgoo1000JWoo0010Ool20007Ool400000goo001C7@02Dad;0004<g`30002Ool0
0`00Oomoo`1VOol4001^Ool0049oo`03001oogoo00Ioo`<00003Ool0000001000006Ool00000001o
o`00I7oo1000LWoo0013Ool00`00Oomoo`06Ool3000COol20002Ool00`00Oomoo`1NOol4001fOol0
04Aoo`8000Moo`@0015oo`80009oo`03001oogoo05Yoo`@007Yoo`00AWoo00<007ooOol01Goo1000
47oo0P000Woo00<007ooOol0Egoo0`00OWoo0017Ool00`00Oomoo`06Ool3000?Ool20002Ool00`00
Oomoo`1COol40021Ool004Qoo`03001oogoo00Ioo`@000eoo`80009oo`03001oogoo04moo`@008Eo
o`00BGoo0P001goo100037oo0P000Woo00<007ooOol0Bgoo1000RGoo001;Ool00`00Oomoo`06Ool3
000;Ool20002Ool00`00Oomoo`17Ool4002=Ool004aoo`03001oogoo00Ioo`<000Yoo`80009oo`03
001oogoo04=oo`@0095oo`00CGoo0P001goo100027oo0P000Woo00<007ooOol0@7oo0`00UGoo001?
Ool00`00Oomoo`05Ool40007Ool20002Ool00`00Oomoo`0lOol4002HOol0051oo`03001oogoo00Io
o`<000Ioo`80009oo`03001oogoo03Qoo`@009aoo`00DGoo0P001goo100017oo0P000Woo00<007oo
Ool0=7oo1000X7oo001COol00`00Oomoo`05Ool40003Ool20002Ool00`00Oomoo`0`Ool4002TOol0
05Aoo`03001oogoo00Ioo`<0009oo`80009oo`03001oogoo02aoo`@00:Qoo`00EGoo00<007ooOol0
1Woo1P000Woo00<007ooOol0:Goo0`00[7oo001FOol20007Ool50002Ool00`00Oomoo`0UOol4002_
Ool005Qoo`03001oogoo00Ioo`<00003Ool007oo02=oo`@00;=oo`00FGoo00<007ooOol01Goo0P00
0Woo00<007ooOol07Woo1000]goo001JOol20009Ool00`00Oomoo`0JOol4002kOol005aoo`03001o
ogoo00Ioo`03001oogoo01Ioo`@00;moo`00GGoo00<007ooOol01Goo00<007ooOol04goo0`00`goo
001NOol20005Ool00`00Oomoo`0?Ool40036Ool0061oo`03001oogoo009oo`03001oogoo00]oo`@0
0<Yoo`00HGoo00D007ooOomoo`0000Uoo`@00<ioo`00HWoo0P0000=oo`00Ool017oo1000dWoo001T
Ool200000goo00000002003FOol006Eoo`800=Yoo`00ogoo@Woo003oOom2Ool00?mood9oo`00ogoo
@Woo003oOom2Ool00?mood9oo`00ogoo@Woo0000\
\>"],
  ImageRangeCache->{{{0, 320}, {296, 0}} -> {-0.0257708, -0.0109957, 
  0.00323587, 0.00323587}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Generalized Coordinate Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now one of the standard constraints is replaced with a generalized \
coordinate constraint. Constraint 2, the revolute joint that models the \
rotational axis of the crank, is replaced first, and body 2 becomes a slave \
to the ground body, represented by the single coordinate ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Note that the arguments to the ",
  StyleBox["GenRevolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are exactly the same as the arguments to the ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, with the addition of the new symbol ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and its initial guess."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the new constraint."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[2] = 
      GenRevolute5[2, Axis[crank, 0, X], Axis[ground, 1, X], {alpha, 0.0}]; 
    \)\), 
    \(SetConstraints[Array[cs, 5]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The modified model is run again at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X3 \[Rule] 0.`\), ",", 
        \(Y3 \[Rule] 17.6084521303612291`\), ",", 
        \(Z3 \[Rule] 14.4721359549995787`\), ",", 
        \(Eo3 \[Rule] 0.903943892415714245`\), ",", 
        \(Ei3 \[Rule] 0.0893987074414874172`\), ",", 
        \(Ej3 \[Rule] 0.232451273519890388`\), ",", 
        \(Ek3 \[Rule] \(-0.347648839939247666`\)\), ",", 
        \(X4 \[Rule] 19.5064013716727053`\), ",", \(Y4 \[Rule] 0.`\), ",", 
        \(Z4 \[Rule] 0.`\), ",", \(Eo4 \[Rule] 1.`\), ",", 
        \(Ei4 \[Rule] 0.`\), ",", \(Ej4 \[Rule] 0.`\), ",", 
        \(Ek4 \[Rule] 0.`\), ",", \(alpha \[Rule] 0.314159265358979311`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that all of the symbols associated with body 2 are no longer included \
in the solution rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The location of body 2 is represented entirely by ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is the rotation angle of the crank in full revolutions. The \
definition (and hence the numerical value) of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is dependent on the relative reference directions of the two axis objects \
passed to ",
  StyleBox["GenRevolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Since the reference directions were not explicitly specified in the axis \
objects, default reference directions were assumed by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " (the local ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axes of each body, in this case).\n\nOnly two more of the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraints in this model can be replaced with generalized coordinate \
constraints. This is because each generalized coordinate constraint creates a \
slave body, and a slave body can be a slave to only one master body. Thus, \
there is no way to use more than three generalized coordinate constraints in \
a model with only three bodies."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are two more new constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[4] = 
      GenOrthoRevolute4[4, Axis[conrod, 1, Y], 
        Axis[slider, 0, Z], {beta, \(-1.0\)}, {gamma, 1.0}]; \)\), 
    \(\(cs[5] = 
      GenTranslate5[5, Axis[slider, 0, X, Y], 
        Axis[ground, 0, X, Y], {delta, 20.0}]; \)\), 
    \(SetConstraints[Array[cs, 5]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The modified model is run again at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        \(alpha \[Rule] 0.314159265358979311`\), ",", 
        \(beta \[Rule] \(-0.836490846423524381`\)\), ",", 
        \(gamma \[Rule] 0.50339770459476929`\), ",", 
        \(delta \[Rule] 19.5064013716725561`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Now the 21 Cartesian and Euler coordinates have been replaced with the \
four generalized coordinates ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["delta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". A quick degree of freedom count shows that this all makes sense: the \
three generalized coordinate constraints add a total of four degrees of \
freedom to the model, while the two remaining standard constraints ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain a total of four degrees of freedom.\n\nThe physical meaning of \
the new coordinates is somewhat confusing: ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is simply the angle between the global ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axis and the local ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis of the crank, and ",
  StyleBox["delta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction distance from the global origin to the origin of the slider. ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are two angles that represent the rotation of the connecting rod with \
respect to the slider: ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the altitude angle, the angle between a horizontal plane and a vector \
down the axis of the connecting rod, and gamma is the azimuth angle, the \
rotation of the connecting rod axis about the global ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis.\n\nFinally, to reduce the mathematical model of the space-crank to \
absolute minimum size, constraint 1 (the ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint) must be reexamined. This constraint uses a rather complicated \
expression relating the directions of three vectors to specify the rotation \
of the crank, but it is known that the rotation of the crank can be directly \
specified by ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". While ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " attempts to simplify constraint expressions to some extent, the algebraic \
expression generated by constraint 1 is more complicated than it could be."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the expression that results from constraint 1."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints[1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-Cos[6.28318530717958623`\ T]\)\ Sin[alpha] + 
        Cos[alpha]\ Sin[6.28318530717958623`\ T]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Constraint 1 really just sets ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " equal to ",
  StyleBox["2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["\[Pi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which can be done more directly with the all-purpose constraint function \
",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a simplified functional replacement for constraint 1."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraint[1, alpha == 2.0  \[Pi]\ T]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["Constraint", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Output and Graphics Functions"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now that we have a solution in terms of generalized coordinates, all of \
the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output and graphics functions allow it to be used in the same manner as a \
solution in terms of Cartesian and Euler coordinates. For example, the \
location of a point is still found with the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function and the spatial orientation of a body is found with ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The symbolic expressions returned by these functions reflect the new \
coordinate system being used, but the numerical results are equivalent. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the Cartesian coordinates of a point at the center of the \
connecting rod."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Location[conrod, {15, 0, 0}]\), 
    \(% /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({delta + 15\ Cos[gamma]\ Sin[beta], 15\ Cos[beta]\ Cos[gamma], 
      15\ Sin[gamma]}\)], "Output"],

Cell[BoxData[
    \({9.75320068583630117`, 8.80422606518059147`, 7.23606797749979069`}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The location of the point on the connecting rod is a function of ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["delta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", but not ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is because of the master-slave relationship of the generalized \
coordinate bodies; the connecting rod is a slave to the slider, which is a \
slave to the ground. Thus, the location of any point on the connecting rod is \
a function of the generalized coordinates of the slider and the connecting \
rod, while the location of any point on the crank is a function of only ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the global rotation angle of the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(crrot = Rotation[crank]\), 
    \(crrot /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2\ ArcCos[1\/2\ \@\(2 + 2\ Cos[alpha]\)], {
        \(2\ Sin[alpha]\)\/\@\(\((2 - 2\ Cos[alpha])\)\ 
              \((2 + 2\ Cos[alpha])\)\), 0, 0}}\)], "Output"],

Cell[BoxData[
    \({0.314159265358978778`, {0.999999999999999467`, 0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The symbolic expression returned by ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is rather complicated, considering that the correct result is known to be \
",
  StyleBox["{alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["0}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is an unfortunate side effect of the general transformation that ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " uses to convert a rotation matrix to the single rotation angle and axis \
of rotation that it represents. The application of a couple of trig \
identities will reduce this expression back to the simpler form, but only in \
such trivial cases. In a more general case, such as the connecting rod, which \
has undergone two consecutive rotations relative to the ground, the symbolic \
expression for the angle and axis of rotation cannot be reduced \
significantly. \n\n",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics functions also operate without regard to the use of generalized \
coordinates. The following graphics object will generate the same image with \
any of the three constraint formulations used in the preceding example."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the graphics object representing the space-crank model."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
graph := Graphics3D[{
  {Thickness[.008],
   Line[{{-1,-5,0}, {-1,18, 0}, {35,18, 0}, {35,-5,0},
         {-1,-5,0}, {-1,-5,22}, {-1,18,22}, {-1,18,0}}],
   Line[{{-1, 1.8,0}, {35, 1.8,0}}],
   Line[{{-1,-1.8,0}, {35,-1.8,0}}]},
   Bar[Line[crank, 0, {-1,0,0}], 10.0, 12],
   Box[ slider, {{-4,-1.5,-2}, {4,1.5,2}} ],
   Bar[ Line[conrod, 0, 1], 1.0, 8 ]} ];\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This shows the graphic at T = 0.15."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{graph /. SolveMech[0.15]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92288 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.01683 -0.0141402 1.01683 [
[ 0 0 0 0 ]
[ 1 .92288 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.0568 .2641 m
0 .68731 L
s
0 .68731 m
.30881 .92288 L
s
.30881 .92288 m
.32838 .52832 L
s
.32838 .52832 m
.0568 .2641 L
s
.73861 0 m
.9467 .32787 L
s
.9467 .32787 m
1 .74483 L
s
1 .74483 m
.77161 .4445 L
s
.77161 .4445 m
.73861 0 L
s
.0568 .2641 m
0 .68731 L
s
0 .68731 m
.77161 .4445 L
s
.77161 .4445 m
.73861 0 L
s
.73861 0 m
.0568 .2641 L
s
.32838 .52832 m
.9467 .32787 L
s
.9467 .32787 m
1 .74483 L
s
1 .74483 m
.30881 .92288 L
s
.30881 .92288 m
.32838 .52832 L
s
0 0 m
1 0 L
1 .92288 L
0 .92288 L
closepath
clip
newpath
.5 Mabswid
.31226 .63009 m .32641 .72107 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.27587 .54448 m .31226 .63009 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.32641 .72107 m .31226 .63009 L .32779 .62532 L p .604 .459 .657 r
F P
0 g
s
.008 w
.31158 .62572 m
.3162 .53822 L
s
.5 Mabswid
.31226 .63009 m .27587 .54448 L .29141 .53944 L p .638 .573 .765 r
F P
0 g
s
.008 w
.31152 .62687 m
.31158 .62572 L
s
.5 Mabswid
.29141 .53944 m .32779 .62532 L .31226 .63009 L p .638 .573 .765 r
F P
0 g
s
.32779 .62532 m .34215 .71648 L .32641 .72107 L p .604 .459 .657 r
F P
0 g
s
.22503 .48357 m .27587 .54448 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.12787 .49358 m .17103 .46355 L .22503 .48357 L p .938 .685 .528 r
F P
0 g
s
.32779 .62532 m .33256 .6556 L p .24575 .58592 L .94 .685 .525 r
F P
0 g
s
.24426 .57449 m .32779 .62532 L .24575 .58592 L .94 .685 .525 r
F
.2487 .60845 m .33256 .6556 L .31625 .68654 L F
.19163 .54246 m .24575 .58592 L .2487 .60845 L F
.24575 .58592 m .33256 .6556 L .2487 .60845 L F
.31443 .79684 m .27737 .83769 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.26459 .79149 m .27225 .79826 L p .27522 .79887 L .696 .232 .147 r
F P
0 g
s
.32641 .72107 m .31443 .79684 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.31443 .79684 m .32641 .72107 L .34215 .71648 L p .539 .293 .491 r
F P
0 g
s
.34215 .71648 m .33055 .79235 L .31443 .79684 L p .539 .293 .491 r
F P
0 g
s
.27737 .83769 m .31443 .79684 L .33055 .79235 L p .299 0 .019 r
F P
0 g
s
.33055 .79235 m .29394 .83315 L .27737 .83769 L p .299 0 .019 r
F P
0 g
s
.33055 .79235 m .29394 .83315 L p .27847 .79742 L .94 .685 .525 r
F P
0 g
s
.32184 .7781 m .33055 .79235 L .27847 .79742 L .94 .685 .525 r
F
.27966 .7969 m .26459 .79149 L .27522 .79887 L .696 .232 .147 r
F
.26459 .79149 m .27225 .79826 L .27316 .79542 L p .422 .319 .632 r
F P
0 g
s
.27501 .76474 m .26786 .78702 L p .27482 .76511 L .88 .896 .476 r
F P
0 g
s
.28001 .78743 m .26786 .78702 L .27501 .76474 L p .833 .758 .779 r
F P
0 g
s
.28001 .78743 m .26786 .78702 L p .28318 .79533 L .696 .232 .147 r
F P
0 g
s
.29859 .80369 m .28706 .7936 L .28318 .79533 L .696 .232 .147 r
F
.28706 .7936 m .28001 .78743 L .28318 .79533 L F
.26786 .78702 m .26459 .79149 L .27031 .77365 L p .88 .896 .476 r
F P
0 g
s
.26786 .78702 m .27031 .77365 L .27482 .76511 L .88 .896 .476 r
F
.26786 .78702 m .26459 .79149 L p .29859 .80369 L .696 .232 .147 r
F P
0 g
s
.26459 .79149 m .27316 .79542 L .27041 .77436 L .422 .319 .632 r
F
.28001 .78743 m .27501 .76474 L .28418 .77349 L .833 .758 .779 r
F
.29159 .79158 m .28001 .78743 L .28442 .77373 L p .679 .586 .745 r
F P
0 g
s
.28442 .77373 m .28001 .78743 L p .28418 .77349 L .833 .758 .779 r
F P
0 g
s
.25703 .67208 m .32184 .7781 L .27124 .78072 L .94 .685 .525 r
F
.34215 .71648 m .33055 .79235 L p .15904 .51179 L F P
0 g
s
.14444 .48792 m .15377 .4987 L .15904 .51179 L .94 .685 .525 r
F
.15377 .4987 m .34215 .71648 L .15904 .51179 L F
.37704 .21696 m .40773 .25262 L .54938 .20073 L p .668 .735 .9 r
F P
0 g
s
.40589 .31391 m .40773 .25262 L p .44281 .25506 L .531 .306 .518 r
F P
0 g
s
.29069 .77972 m .32184 .7781 L .29945 .78808 L .94 .685 .525 r
F
.29396 .79243 m .28001 .78743 L p .29859 .80369 L .696 .232 .147 r
F P
0 g
s
.29069 .77972 m .29945 .78808 L .27847 .79742 L .94 .685 .525 r
F
.33256 .6556 m .34215 .71648 L p .31625 .68654 L F P
0 g
s
.29396 .79243 m .29159 .79158 L p .44495 .27832 L .679 .586 .745 r
F P
0 g
s
.44281 .25506 m .46319 .25648 L .43598 .28375 L .531 .306 .518 r
F
.29396 .79243 m .44495 .27832 L .4452 .27817 L .679 .586 .745 r
F
.44371 .27908 m .42986 .3221 L p .42566 .30001 L .833 .758 .779 r
F P
0 g
s
.42986 .3221 m .28442 .77373 L p .42147 .31407 L .833 .758 .779 r
F P
0 g
s
.42147 .31407 m .42566 .30001 L .42986 .3221 L .833 .758 .779 r
F
.44281 .25506 m .42761 .29215 L .40589 .31391 L .531 .306 .518 r
F
.41713 .30991 m .40589 .31391 L p .42761 .29215 L F P
0 g
s
.27124 .78072 m .29069 .77972 L .27847 .79742 L .94 .685 .525 r
F
.28442 .77373 m .44371 .27908 L p .29159 .79158 L .679 .586 .745 r
F P
0 g
s
.46319 .25648 m .44371 .27908 L .43598 .28375 L .531 .306 .518 r
F
.29159 .79158 m .44371 .27908 L .44495 .27832 L .679 .586 .745 r
F
.18062 .51502 m .32779 .62532 L .19163 .54246 L .94 .685 .525 r
F
.27587 .54448 m .22503 .48357 L .24077 .47825 L p .661 .695 .871 r
F P
0 g
s
.24077 .47825 m .29141 .53944 L .27587 .54448 L p .661 .695 .871 r
F P
0 g
s
.29141 .53944 m .32779 .62532 L p .14444 .48792 L .94 .685 .525 r
F P
0 g
s
.27501 .76474 m .41579 .32098 L .42087 .30858 L .88 .896 .476 r
F
.42322 .30284 m .42006 .31272 L p .42087 .30858 L F P
0 g
s
.42006 .31272 m .27501 .76474 L p .42087 .30858 L .88 .896 .476 r
F P
0 g
s
.43598 .28375 m .42322 .30284 L .42761 .29215 L .531 .306 .518 r
F
.44371 .27908 m .42322 .30284 L .43598 .28375 L F
.42942 .28772 m .43598 .28375 L .42761 .29215 L F
.28418 .77349 m .4256 .30008 L .28442 .77373 L .833 .758 .779 r
F
.30167 .79915 m .29396 .79243 L .46398 .26681 L p .429 .325 .635 r
F P
0 g
s
.44934 .25552 m .49365 .22115 L .46319 .25648 L .531 .306 .518 r
F
.30167 .79915 m .46398 .26681 L .46436 .2671 L .429 .325 .635 r
F
.46398 .26681 m .29396 .79243 L p .4452 .27817 L .679 .586 .745 r
F P
0 g
s
.40773 .25262 m .45019 .23707 L p .44281 .25506 L .531 .306 .518 r
F P
0 g
s
.47228 .2732 m .30167 .79915 L p .46436 .2671 L .429 .325 .635 r
F P
0 g
s
.46112 .30761 m .47228 .2732 L p .46132 .30667 L .862 .884 .451 r
F P
0 g
s
.4256 .30008 m .42566 .30001 L .28442 .77373 L .833 .758 .779 r
F
.42322 .30284 m .41713 .30991 L .42761 .29215 L .531 .306 .518 r
F
.27501 .76474 m .44577 .23258 L p .28418 .77349 L .833 .758 .779 r
F P
0 g
s
.44371 .27908 m .47166 .27473 L .41713 .30991 L .531 .306 .518 r
F
.29859 .80369 m .30167 .79915 L .29396 .79243 L p .696 .232 .147 r
F P
0 g
s
.29859 .80369 m .47228 .2732 L .47184 .27428 L .862 .884 .451 r
F
.47166 .27473 m .47111 .2761 L .41713 .30991 L .531 .306 .518 r
F
.47111 .2761 m .46498 .29131 L .41713 .30991 L F
.46319 .25648 m .4846 .24263 L .48282 .24706 L F
.46319 .25648 m .5199 .22925 L .47919 .2576 L F
.5199 .22925 m .54956 .21501 L .51325 .23699 L F
.5199 .22925 m .51325 .23699 L .47919 .2576 L F
.27847 .79742 m .29394 .83315 L .27964 .81152 L .94 .685 .525 r
F
.27465 .79913 m .27964 .81152 L .27217 .80023 L F
.27847 .79742 m .27964 .81152 L .27465 .79913 L F
.28755 .79973 m .27966 .7969 L .27729 .79795 L .696 .232 .147 r
F
.28755 .79973 m .27729 .79795 L .27522 .79887 L F
.29859 .80369 m .28755 .79973 L .27522 .79887 L F
.46362 .2947 m .29859 .80369 L p .47184 .27428 L .862 .884 .451 r
F P
0 g
s
.51636 .27458 m .46528 .29276 L p .53156 .26543 L .531 .306 .518 r
F P
0 g
s
.46528 .29276 m .41713 .30991 L p .46731 .29041 L .531 .306 .518 r
F P
0 g
s
.53156 .26543 m .46528 .29276 L .46731 .29041 L .531 .306 .518 r
F
.42087 .30858 m .46425 .29313 L p .44599 .28344 L .664 .74 .907 r
F P
0 g
s
.49365 .22115 m .54938 .20073 L p .46319 .25648 L .531 .306 .518 r
F P
0 g
s
.46319 .25648 m .47919 .2576 L .44371 .27908 L .531 .306 .518 r
F
.47919 .2576 m .53779 .26168 L .44371 .27908 L F
.53779 .26168 m .55015 .26254 L .53156 .26543 L F
.53779 .26168 m .53156 .26543 L .44371 .27908 L F
.27031 .77365 m .26459 .79149 L p .27041 .77436 L .422 .319 .632 r
F P
0 g
s
.26914 .77588 m .27847 .79742 L .26637 .78112 L .94 .685 .525 r
F
.27225 .79826 m .28638 .80334 L .29859 .80369 L p .696 .232 .147 r
F P
0 g
s
.27225 .79826 m .27465 .79913 L p .27321 .79553 L .678 .586 .746 r
F P
0 g
s
.27316 .79542 m .27225 .79826 L p .27321 .79553 L .678 .586 .746 r
F P
0 g
s
.27737 .83769 m .22281 .82908 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.27847 .79742 m .27217 .80023 L .20354 .69645 L .94 .685 .525 r
F
.27321 .79553 m .44025 .32036 L .27316 .79542 L .678 .586 .746 r
F
.44599 .25294 m .49365 .22115 L .44934 .25552 L .531 .306 .518 r
F
.45019 .23707 m .49365 .22115 L p .44281 .25506 L F P
0 g
s
.45786 .23513 m .47259 .24019 L .46398 .26681 L p .679 .586 .745 r
F P
0 g
s
.4452 .27817 m .45786 .23513 L .46398 .26681 L .679 .586 .745 r
F
.45356 .28248 m .46715 .24384 L .45356 .28248 L .678 .586 .746 r
F
.46436 .2671 m .47259 .24019 L .47228 .2732 L .429 .325 .635 r
F
.46398 .26681 m .47259 .24019 L p .46436 .2671 L F P
0 g
s
.46715 .24384 m .45471 .28234 L p .4724 .26008 L .835 .76 .78 r
F P
0 g
s
.45907 .28664 m .4724 .26008 L .45471 .28234 L .835 .76 .78 r
F
.44599 .28344 m .46425 .29313 L .4645 .29199 L .664 .74 .907 r
F
.47259 .24019 m .48148 .24485 L .47228 .2732 L p .429 .325 .635 r
F P
0 g
s
.46374 .29125 m .47928 .24638 L .45907 .28664 L .835 .76 .78 r
F
.44599 .28344 m .4645 .29199 L .45471 .28234 L .664 .74 .907 r
F
.46362 .2947 m .4645 .29199 L p .46183 .29679 L .835 .76 .78 r
F P
0 g
s
.4645 .29199 m .47928 .24638 L p .46374 .29125 L .835 .76 .78 r
F P
0 g
s
.46183 .29679 m .4645 .29199 L .46374 .29125 L .835 .76 .78 r
F
.48148 .24485 m .47928 .24638 L .46362 .2947 L p .862 .884 .451 r
F P
0 g
s
.47184 .27428 m .48148 .24485 L .46362 .2947 L .862 .884 .451 r
F
.47383 .2744 m .48545 .28335 L .46498 .29131 L .531 .306 .518 r
F
.47383 .2744 m .46498 .29131 L .47111 .2761 L F
.47166 .27473 m .47383 .2744 L .47111 .2761 L F
.47383 .2744 m .53156 .26543 L .48545 .28335 L F
.47228 .2732 m .48148 .24485 L p .47184 .27428 L .862 .884 .451 r
F P
0 g
s
.55015 .26254 m .51636 .27458 L p .53156 .26543 L .531 .306 .518 r
F P
0 g
s
.46926 .26995 m .4645 .29199 L .55015 .26254 L .664 .74 .907 r
F
.46425 .29313 m .46528 .29276 L p .4645 .29199 L F P
0 g
s
.46528 .29276 m .55015 .26254 L p .4645 .29199 L .664 .74 .907 r
F P
0 g
s
.45471 .28234 m .4645 .29199 L .46691 .2808 L .664 .74 .907 r
F
.46183 .29679 m .46374 .29125 L .44295 .31874 L .835 .76 .78 r
F
.46374 .29125 m .45907 .28664 L .44295 .31874 L F
.45471 .28234 m .44295 .31874 L p .45907 .28664 L F P
0 g
s
.41713 .30991 m .42087 .30858 L p .41535 .30402 L .664 .74 .907 r
F P
0 g
s
.37704 .21696 m .40773 .25262 L .40589 .31391 L p .963 .688 .465 r
F P
0 g
s
.40589 .31391 m .37459 .27861 L .37704 .21696 L p .963 .688 .465 r
F P
0 g
s
.38356 .27779 m .41307 .30603 L .41535 .30402 L .664 .74 .907 r
F
.41307 .30603 m .41713 .30991 L .41535 .30402 L F
.42278 .29892 m .44337 .23404 L .42276 .299 L .88 .896 .476 r
F
.44281 .25506 m .44599 .25294 L .44934 .25552 L .531 .306 .518 r
F
.4256 .30008 m .44577 .23258 L .42566 .30001 L .833 .758 .779 r
F
.44337 .23404 m .44577 .23258 L .42322 .30284 L p .88 .896 .476 r
F P
0 g
s
.38356 .27779 m .42087 .30858 L .42774 .27375 L .664 .74 .907 r
F
.41579 .32098 m .44337 .23404 L .42322 .30284 L .88 .896 .476 r
F
.44281 .25506 m .43598 .28375 L .42942 .28772 L .531 .306 .518 r
F
.4144 .32436 m .44337 .23404 L p .41573 .32112 L .88 .896 .476 r
F P
0 g
s
.44577 .23258 m .45786 .23513 L .44371 .27908 L p .833 .758 .779 r
F P
0 g
s
.42566 .30001 m .44577 .23258 L .44371 .27908 L .833 .758 .779 r
F
.45221 .23871 m .44337 .23404 L .42312 .29717 L p .422 .319 .632 r
F P
0 g
s
.41573 .32112 m .42278 .29892 L .41579 .32098 L .88 .896 .476 r
F
.42278 .29892 m .42276 .299 L .41579 .32098 L F
.43628 .28557 m .45221 .23871 L .42312 .29717 L .422 .319 .632 r
F
.43748 .28451 m .42087 .30858 L .44599 .28344 L .664 .74 .907 r
F
.43748 .28451 m .45221 .23871 L p .43632 .28553 L .422 .319 .632 r
F P
0 g
s
.42312 .29717 m .42087 .30858 L .43748 .28451 L .664 .74 .907 r
F
.27482 .76511 m .41573 .32112 L .27501 .76474 L .88 .896 .476 r
F
.41573 .32112 m .41579 .32098 L .27501 .76474 L F
.27031 .77365 m .4144 .32436 L p .27482 .76511 L F P
0 g
s
.27482 .76511 m .4144 .32436 L .41573 .32112 L .88 .896 .476 r
F
.27041 .77436 m .43632 .28553 L .27031 .77365 L .422 .319 .632 r
F
.43632 .28553 m .45221 .23871 L .43628 .28557 L F
.43632 .28553 m .43628 .28557 L .27031 .77365 L F
.44371 .27908 m .45786 .23513 L p .44495 .27832 L .679 .586 .745 r
F P
0 g
s
.4452 .27817 m .44495 .27832 L .45786 .23513 L .679 .586 .745 r
F
.46715 .24384 m .45221 .23871 L .42252 .33103 L p .678 .586 .746 r
F P
0 g
s
.44023 .32037 m .46715 .24384 L .42252 .33103 L .678 .586 .746 r
F
.44484 .27801 m .44599 .28344 L .45218 .27984 L .664 .74 .907 r
F
.42774 .27375 m .44143 .28102 L .44484 .27801 L F
.44143 .28102 m .44599 .28344 L .44484 .27801 L F
.42532 .28604 m .42312 .29717 L .43748 .28451 L F
.27316 .79542 m .43748 .28451 L p .27041 .77436 L .422 .319 .632 r
F P
0 g
s
.27041 .77436 m .43748 .28451 L .43632 .28553 L .422 .319 .632 r
F
.42312 .29717 m .27031 .77365 L p .43628 .28557 L F P
0 g
s
.45471 .28234 m .46715 .24384 L p .45356 .28248 L .678 .586 .746 r
F P
0 g
s
.44445 .27222 m .45218 .27984 L .46926 .26995 L .664 .74 .907 r
F
.42774 .27375 m .45218 .27984 L .44445 .27222 L F
.44599 .28344 m .46691 .2808 L .46926 .26995 L F
.44025 .32036 m .45356 .28248 L .44023 .32037 L .678 .586 .746 r
F
.45356 .28248 m .45356 .28248 L .44023 .32037 L F
.44025 .32036 m .44023 .32037 L .27316 .79542 L F
.47928 .24638 m .47255 .24497 L p .4724 .26008 L .835 .76 .78 r
F P
0 g
s
.47255 .24497 m .46715 .24384 L p .4724 .26008 L .835 .76 .78 r
F P
0 g
s
.44295 .31874 m .28638 .80334 L p .46183 .29679 L .835 .76 .78 r
F P
0 g
s
.42774 .27375 m .42532 .28604 L .44599 .28344 L .664 .74 .907 r
F
.28638 .80334 m .45471 .28234 L p .27321 .79553 L .678 .586 .746 r
F P
0 g
s
.27321 .79553 m .45471 .28234 L .45356 .28248 L .678 .586 .746 r
F
.27465 .79913 m .28638 .80334 L p .27321 .79553 L F P
0 g
s
.28638 .80334 m .29859 .80369 L .46362 .2947 L p .835 .76 .78 r
F P
0 g
s
.28638 .80334 m .46362 .2947 L .46183 .29679 L .835 .76 .78 r
F
.29859 .80369 m .30167 .79915 L .46112 .30761 L p .862 .884 .451 r
F P
0 g
s
.29859 .80369 m .46112 .30761 L .46132 .30667 L .862 .884 .451 r
F
.54938 .20073 m .54956 .21501 L p .48282 .24706 L .531 .306 .518 r
F P
0 g
s
.4846 .24263 m .54938 .20073 L .48282 .24706 L .531 .306 .518 r
F
.54956 .21501 m .55015 .26254 L p .47919 .2576 L F P
0 g
s
.42252 .33103 m .27316 .79542 L p .44023 .32037 L .678 .586 .746 r
F P
0 g
s
.37459 .27861 m .40589 .31391 L .41713 .30991 L p .664 .74 .907 r
F P
0 g
s
.37459 .27861 m .41713 .30991 L .38356 .27779 L .664 .74 .907 r
F
.14444 .48792 m .25703 .67208 L .27124 .78072 L .94 .685 .525 r
F
.25677 .7473 m .26914 .77588 L .20354 .69645 L F
.26914 .77588 m .26637 .78112 L .20354 .69645 L F
.20354 .69645 m .27419 .80328 L .2398 .82437 L F
.29394 .83315 m .27775 .83053 L p .27419 .80328 L F P
0 g
s
.27775 .83053 m .2398 .82437 L p .27419 .80328 L .94 .685 .525 r
F P
0 g
s
.14444 .48792 m .25677 .7473 L .20354 .69645 L .94 .685 .525 r
F
.19163 .54246 m .24426 .57449 L .24575 .58592 L F
.14444 .48792 m .18062 .51502 L .19163 .54246 L F
0 g
.008 w
.29771 .88824 m
.30104 .82524 L
s
.07361 .30489 m
.07622 .3074 L
s
.07622 .3074 m
.08518 .31602 L
s
.62841 .43732 m
.91703 .34405 L
s
.33137 .53332 m
.34924 .52754 L
s
.42484 .50311 m
.62841 .43732 L
s
.39452 .51291 m
.42484 .50311 L
s
.3162 .53822 m
.33137 .53332 L
s
.5 Mabswid
.22503 .48357 m .17103 .46355 L .18715 .458 L p .631 .87 .987 r
F P
0 g
s
.18715 .458 m .24077 .47825 L .22503 .48357 L p .631 .87 .987 r
F P
0 g
s
.24077 .47825 m .29141 .53944 L p .14444 .48792 L .94 .685 .525 r
F P
0 g
s
.008 w
.28092 .50428 m
.3162 .53822 L
s
.23619 .46126 m
.28092 .50428 L
s
.5 Mabswid
.14444 .48792 m .18715 .458 L .24077 .47825 L p .94 .685 .525 r
F P
0 g
s
.008 w
.15136 .37967 m
.36864 .30134 L
s
.36864 .30134 m
.38842 .29421 L
s
.5 Mabswid
.17103 .46355 m .12787 .49358 L .14444 .48792 L p .043 0 0 r
F P
0 g
s
.14444 .48792 m .18715 .458 L .17103 .46355 L p .043 0 0 r
F P
0 g
s
.008 w
.08518 .31602 m
.21022 .43629 L
s
.21022 .43629 m
.23619 .46126 L
s
.26939 .86626 m
.29771 .88824 L
s
.5 Mabswid
.22281 .82908 m .27737 .83769 L .29394 .83315 L p .513 .882 .977 r
F P
0 g
s
.29394 .83315 m .2398 .82437 L .22281 .82908 L p .513 .882 .977 r
F P
0 g
s
.008 w
.91703 .34405 m
.72904 .05655 L
s
.26645 .28319 m
.37267 .24389 L
s
.11089 .34075 m
.26645 .28319 L
s
.07361 .30489 m
.02605 .67742 L
s
.21073 .25293 m
.33834 .20458 L
s
.07361 .30489 m
.21073 .25293 L
s
.5 Mabswid
.12278 .67232 m .10921 .56992 L .12787 .49358 L p .938 .685 .528 r
F P
0 g
s
.16529 .76879 m .12278 .67232 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.22281 .82908 m .16529 .76879 L p .12787 .49358 L .938 .685 .528 r
F P
0 g
s
.12787 .49358 m .10921 .56992 L .12619 .56433 L p .488 .217 .429 r
F P
0 g
s
.12619 .56433 m .14444 .48792 L .12787 .49358 L p .488 .217 .429 r
F P
0 g
s
.14001 .66697 m .12619 .56433 L .14444 .48792 L p .94 .685 .525 r
F P
0 g
s
.18252 .76377 m .14001 .66697 L p .14444 .48792 L .94 .685 .525 r
F P
0 g
s
.2398 .82437 m .18252 .76377 L p .14444 .48792 L .94 .685 .525 r
F P
0 g
s
.16529 .76879 m .22281 .82908 L .2398 .82437 L p .643 .715 .9 r
F P
0 g
s
.008 w
.22114 .82882 m
.2266 .83306 L
s
.2266 .83306 m
.26939 .86626 L
s
.5 Mabswid
.2398 .82437 m .18252 .76377 L .16529 .76879 L p .643 .715 .9 r
F P
0 g
s
.54938 .20073 m .52032 .16333 L .37704 .21696 L p .668 .735 .9 r
F P
0 g
s
.52032 .16333 m .37704 .21696 L .37459 .27861 L p .524 .296 .511 r
F P
0 g
s
.008 w
.37267 .24389 m
.41726 .22739 L
s
.5 Mabswid
.45786 .23513 m .44577 .23258 L p .47928 .24638 L .505 0 0 r
F P
0 g
s
.47259 .24019 m .45786 .23513 L p .47928 .24638 L .505 0 0 r
F P
0 g
s
.47928 .24638 m .48148 .24485 L .47259 .24019 L p .505 0 0 r
F P
0 g
s
.52054 .22549 m .55015 .26254 L .54938 .20073 L p .973 .684 .418 r
F P
0 g
s
.008 w
.55264 .235 m
.78982 .1495 L
s
.54982 .23602 m
.55264 .235 L
s
.5 Mabswid
.54938 .20073 m .52032 .16333 L .52054 .22549 L p .973 .684 .418 r
F P
0 g
s
.008 w
.48492 .14904 m
.72904 .05655 L
s
.5 Mabswid
.44577 .23258 m .44337 .23404 L p .47928 .24638 L .505 0 0 r
F P
0 g
s
.10921 .56992 m .12278 .67232 L .14001 .66697 L p .584 .436 .647 r
F P
0 g
s
.14001 .66697 m .12619 .56433 L .10921 .56992 L p .584 .436 .647 r
F P
0 g
s
.44337 .23404 m .45221 .23871 L p .47928 .24638 L .505 0 0 r
F P
0 g
s
.45221 .23871 m .46715 .24384 L .47928 .24638 L p .505 0 0 r
F P
0 g
s
.55015 .26254 m .52054 .22549 L .37459 .27861 L p .664 .74 .907 r
F P
0 g
s
.37459 .27861 m .52054 .22549 L .52032 .16333 L p .524 .296 .511 r
F P
0 g
s
.008 w
.41726 .22739 m
.51744 .19032 L
s
.37887 .18923 m
.48492 .14904 L
s
.51744 .19032 m
.75825 .10122 L
s
.33834 .20458 m
.37887 .18923 L
s
.5 Mabswid
.12278 .67232 m .16529 .76879 L .18252 .76377 L p .625 .571 .774 r
F P
0 g
s
.008 w
.17647 .79415 m
.22114 .82882 L
s
.5 Mabswid
.18252 .76377 m .14001 .66697 L .12278 .67232 L p .625 .571 .774 r
F P
0 g
s
.008 w
.02605 .67742 m
.17647 .79415 L
s
.25 Mabswid
.73861 0 m
.9467 .32787 L
s
.9467 .32787 m
1 .74483 L
s
1 .74483 m
.77161 .4445 L
s
.77161 .4445 m
.73861 0 L
s
.0568 .2641 m
0 .68731 L
s
0 .68731 m
.77161 .4445 L
s
.77161 .4445 m
.73861 0 L
s
.73861 0 m
.0568 .2641 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{270, 250},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000nQ000`40O003h00Oogoo3goo0035Ool2
0017Ool00<=oo`800003Ool0000004Ioo`00`7oo0`000goo0P00AWoo002mOol30006Ool00`00Ool0
0015Ool00;]oo`8000Uoo`04001oogoo0014Ool00;Qoo`<000]oo`04001oogoo0014Ool00;Ioo`80
00ioo`05001oogooOol00013Ool00;=oo`<0015oo`04001oogoo0013Ool00;5oo`8001Aoo`05001o
ogooOol00012Ool00:ioo`<001Ioo`03001oogoo009oo`03001oogoo03moo`00Zgoo0`006Goo00<0
07ooOol00Woo00<007ooOol0?goo002YOol2000LOol00`00Oomoo`03Ool00`00Oomoo`0nOol00:Io
o`<001ioo`03001oogoo00Aoo`03001oogoo03eoo`00Y7oo0P008Goo00<007ooOol017oo00<007oo
Ool0?Goo002QOol3000POol01000Oomoo`001goo00<007ooOol0?7oo002OOol2000POol500000goo
001oo`07Ool00`00Oomoo`0kOol009aoo`<0021oo`L00003Ool007oo00Moo`03001oogoo03]oo`00
VGoo0`0087oo1P000goo0`002Goo00<007ooOol0>Woo002GOol2000POol70006Ool20009Ool00`00
Oomoo`0jOol009Aoo`<0021oo`H000Uoo`8000Yoo`03001oogoo03Uoo`00TWoo0P0087oo1P003Goo
0P002Woo00<007ooOol0>7oo002?Ool3000OOol7000@Ool00`00Oomoo`08Ool00`00Oomoo`0hOol0
08eoo`80021oo`H001=oo`8000Yoo`03001oogoo03Moo`00RWoo0`007goo1P005Woo0P002goo00<0
07ooOol0=Woo0027Ool3000POol6000HOol3000:Ool00`00Oomoo`0fOol008Eoo`80021oo`H001]o
o`04001oo`00000:Ool00`00Oomoo`0eOol0089oo`<001moo`L001eoo`04001oogoo000;Ool00`00
Oomoo`0dOol0081oo`80021oo`H0021oo`D000Yoo`03001oogoo03Aoo`00OGoo0`007goo1P008Goo
20002Woo00<007ooOol0<goo001jOol3000OOol7000POol60004Ool00`00Oomoo`08Ool00`00Oomo
o`0cOol007Qoo`80021oo`H0021oo`L00003Ool007oo00=oo`8000Yoo`03001oogoo039oo`00MGoo
0`007goo1P008Goo1P0017oo00<007ooOol00goo0P002Woo00<007ooOol0<Goo001cOol2000POol6
000POol60007Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0aOol0071oo`<001moo`H0
021oo`L000Uoo`03001oogoo00Aoo`8000Yoo`03001oogoo031oo`00KWoo0P007goo1`0087oo1P00
3Goo00<007ooOol017oo0P002Woo00<007ooOol0;goo001[Ool3000OOol6000POol6000@Ool00`00
Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0_Ool006Qoo`<001moo`H0021oo`L0019oo`03001o
ogoo00Eoo`8000Yoo`03001oogoo02ioo`00IWoo0P007goo1`0087oo1P005Goo00<007ooOol01Woo
0P002Woo00<007ooOol0;Goo001SOol3000OOol6000POol6000HOol00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`0]Ool0065oo`8001moo`H0021oo`L001Yoo`03001oogoo00Moo`8000Yoo`03
001oogoo02aoo`00GWoo0`007Woo1`0087oo1P007Goo00<007ooOol01Goo1@002Goo00<007ooOol0
;7oo001LOol2000OOol6000POol6000POol00`00Oomoo`02Ool8000:Ool00`00Oomoo`0[Ool005Uo
o`<001ioo`H0021oo`L0029oo`03001oogoo00H000=oo`8000Yoo`03001oogoo02Yoo`00EWoo0`00
7Woo1`0087oo1P009Goo1P001goo00<007ooOol027oo00<007ooOol0:Woo001DOol2000OOol6000?
Ool2000?Ool6000UOol70009Ool2000:Ool00`00Oomoo`0YOol0055oo`<001ioo`H000moo`<00003
@C00000000]oo`L002Aoo`L000eoo`8000Yoo`03001oogoo02Qoo`00Cgoo0P007goo1P003goo0P00
144`00<007j]000027oo1P009Goo1P000Woo00<007ooOol037oo00<007ooOol027oo00<007ooOol0
:7oo001<Ool3000NOol6000?Ool30006@C000`00OZd00005Ool6000UOol60006Ool00`00Oomoo`0;
Ool2000:Ool00`00Oomoo`0WOol004Uoo`<001ioo`L000ioo`<000U1<005001n[Gj]001oo`07000T
Ool70008Ool00`00Oomoo`0<Ool2000:Ool00`00Oomoo`0VOol004Moo`8001moo`H000moo`8000a1
<003001n[Gj]00H002Aoo`L000]oo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo02Ioo`00
A7oo0`007Woo1P003goo0`003T4`1P0097oo1`003Woo00<007ooOol03Goo0P002Woo00<007ooOol0
9Goo0012Ool2000NOol7000>Ool3000>@C070002OZd00`00Oomoo`0OOol6000AOol00`00Oomoo`0>
Ool20009Ool00`00Oomoo`0UOol003moo`<001ioo`H000ioo`<000m1<0H000En[@03001oogoo01ao
o`H001Aoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo02Aoo`00?Goo0P007Woo1P003goo
0P003d4`1P000d4`00<007j]OZd00gj]00<007ooOol067oo1`005Woo00<007ooOol03goo0P002Woo
00<007ooOol08goo000jOol3000NOol6000>Ool3000>@C070005@C000`00OZen[@04OZd00`00Oomo
o`0DOol7000IOol00`00Oomoo`0@Ool20009Ool00`00Oomoo`0SOol003Moo`<001ioo`H000ioo`<0
00i1<0L000Q1<003001n[Gj]00An[@03001oogoo015oo`L001aoo`03001oogoo015oo`03001oogoo
00Qoo`03001oogoo029oo`00=Goo0P007goo1P003Woo0P003d4`1P002d4`00<007j]OZd017j]00<0
07ooOol03goo1P007goo00<007ooOol04Goo0P002Woo00<007ooOol08Goo000bOol3000NOol6000>
Ool3000>@C06000>@C000`00OZen[@04OZd00`00Oomoo`0<Ool6000ROol00`00Oomoo`0BOol20009
Ool00`00Oomoo`0QOol0031oo`8001ioo`L000ioo`8000i1<0L00111<003001n[Gj]00An[@03001o
ogoo00Uoo`L002Aoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo021oo`00;Goo0`007Woo
1P004Goo00<0044`@C002d4`1P004d4`00<007j]OZd017j]00<007ooOol01Woo1`009goo00<007oo
Ool04goo0P002Woo00<007ooOol07goo000[Ool2000NOol6000DOol00`00@C11<008@C06000F@C00
0`00OZen[@04OZd00`00Oomoo`04Ool6000[Ool00`00Oomoo`0COol20009Ool00`00Oomoo`0OOol0
02Qoo`<001eoo`L001Ioo`030011<44`00E1<0L001M1<08000In[@04001oogooOol6000^Ool00`00
Oomoo`0DOol00`00Oomoo`08Ool00`00Oomoo`0NOol002Eoo`<001eoo`L001Uoo`030011<44`0091
<0L001M1<0<0009Fo@03001n[Gj]00=n[@P0031oo`03001oogoo01Aoo`8000Uoo`03001oogoo01io
o`008goo0P007Woo1P0077oo00<0044`00001P005d4`0`001UKm00@007j]OZen[@H003=oo`03001o
ogoo01Eoo`8000Uoo`03001oogoo01eoo`0087oo0`007Goo1P007Woo1`00644`0P002EKm00@007j]
OZen[@<003Ioo`03001oogoo01Ioo`03001oogoo00Qoo`03001oogoo01aoo`007Woo0P007Goo1`00
7Goo1`00644`0`0035Km00D007j]OZen[@0003Moo`03001oogoo01Ioo`8000Uoo`03001oogoo01ao
o`006goo0`007Goo1P007Woo1`005d4`0`0045Km00@007j]OZd003Moo`03001oogoo01Moo`03001o
ogoo00Qoo`03001oogoo01]oo`006Goo0P007Goo1P007Woo1P000Woo00<0044`@C004d4`0`0055Km
00<007j]0000=goo00<007ooOol05goo0P002Woo00<007ooOol06Woo000FOol3000LOol7000MOol7
0004Ool00`00@C11<00@@C03000GE_d00`00OZd0000gOol00`00Oomoo`0HOol20009Ool00`00Oomo
o`0JOol001=oo`<001eoo`H001ioo`H000Moo`030011<44`00e1<0<001]Fo@8003Moo`03001oogoo
01Uoo`03001oogoo00Qoo`03001oogoo01Uoo`004Goo0P007Goo1P007Woo1P002Woo00<0044`@C00
2T4`0`007eKm00<007ooOol0=Goo00<007ooOol06Goo0P002Woo00<007ooOol067oo000?Ool2000L
Ool7000NOol6000<Ool00`00@C11<008@C02000OE_d2000iOol00`00Oomoo`0JOol20009Ool00`00
Oomoo`0HOol000moo`8001Yoo`H001ioo`H000moo`030011<44`00E1<0<001iFo@<003]oo`03001o
ogoo01]oo`03001oogoo00Qoo`03001oogoo01Moo`003goo00<007oo00005Woo1P007Woo1`004Goo
00<0044`@C000T4`0`007eKm0`00?Woo00<007ooOol06Woo0P002Goo00<007ooOol05goo000?Ool0
1000Oomoo`004Woo1`007Woo1P0057oo00<0044`00000P001EKm1D4`5UKm0`00@7oo00<007ooOol0
6goo0P002Goo00<007ooOol05Woo000>Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool6000NOol6000G
Ool200000g[>E_eFo@0<E_d01000E_eFEeIG3EKm0`00@goo00<007ooOol077oo00<007ooOol027oo
00<007ooOol05Goo000>Ool00`00Oomoo`03Ool00`00Oomoo`09Ool6000NOol7000JOol00`00E_eF
o@0:E_d00`00E_eFo@02E_d3EUL00`00E_eFo@07E_d30015Ool00`00Oomoo`0LOol20009Ool00`00
Oomoo`0EOol000ioo`03001oogoo00Aoo`03001oogoo00Ioo`H001ioo`H001ioo`03001FoEKm00aF
o@06001FEeIGEUMFo@001UKm0`00B7oo00<007ooOol07Goo0P002Goo00<007ooOol057oo000>Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool6000NOol6000ROol2000;E_d00cED001FE`02EUL00`00JaQ[
6003E_d2001;Ool00`00Oomoo`0NOol00`00Oomoo`08Ool00`00Oomoo`0COol000ioo`03001oogoo
00Ioo`P001eoo`L0029oo`D000MFo@04001FoCED=E@4EUL00`00JaQ[6003001=Ool00`00Oomoo`0N
Ool20009Ool00`00Oomoo`0COol000ioo`03001oogoo00Eoo`H001ioo`H002=oo`L000=Fo@05001F
oEKmE_d00002=E@01000EUMFEeIG0P000V/H0P00CWoo00<007ooOol07goo0P002Goo00<007ooOol0
4Woo000>Ool00`00Oomoo`02Ool7000MOol6000SOol60004Ool01@00E_eFoEKm@C000UKm00@003ED
=E@000=FE`06001[66/H001_SP00CWoo00<007ooOol087oo00<007ooOol027oo00<007ooOol04Goo
000>Ool01000Oomoogoo1@000goo00<007ooOol067oo1P008Woo1`001goo00H005KmE_eFoD4`0003
=E@4EUL01@00JaQ[66/HKhh0Cgoo00<007ooOol087oo0P002Goo00<007ooOol04Goo000=Ool00`00
Oomoo`02Ool40005Ool00`00Oomoo`0DOol6000SOol6000;Ool00`00E_eFo@020002=E@00`00EUMF
E`02EUL00`00JaQ[6002001?Ool00`00Oomoo`0QOol20009Ool00`00Oomoo`0@Ool000eoo`03001o
ogoo009oo`D000Eoo`03001oogoo011oo`L0029oo`H000moo`800005Ool003ED=E@00003EUL20000
16/H001_SP00Cgoo00<007ooOol08Woo00<007ooOol01goo00<007ooOol047oo000=Ool00`00Oomo
o`02Ool2000017oo000000001Goo00<007ooOol03Goo1P008Woo1`004goo00@003ED=E@eE0AFE`05
001[66/HJaP0001@Ool00`00Oomoo`0ROol20009Ool00`00Oomoo`0?Ool000eoo`03001oogoo009o
o`80009oo`<000Eoo`03001oogoo00Uoo`H0029oo`L001Ioo`04000eE3ED0004EUL01@00JaQ[6000
Khh0DGoo00<007ooOol08Woo00<007ooOol027oo00<007ooOol03Woo000=Ool00`00Oomoo`02Ool2
0003Ool30005Ool00`00Oomoo`06Ool6000QOol7000IOol00`00=E@eE004EUL2000016/H001_SP00
DGoo00<007ooOol08Woo0P002Goo00<007ooOol03Woo000=Ool00`00Oomoo`02Ool20004Ool30005
Ool00`00Oomoo`02Ool6000ROol6000KOol01000=E@eE3ED15IG00D006/HJaQ[6000059oo`03001o
ogoo02=oo`8000Qoo`8000moo`003Goo00<007ooOol00Woo0P001Goo0`001Goo20008Goo1P007Woo
00@003ED=E@000AFE`05001[66/H001_SP1BOol00`00Oomoo`0TOol00`00Oomoo`03Ool300000goo
001oo`0>Ool000aoo`03001oogoo00=oo`8000Ioo`<000=oo`H0025oo`L0021oo`04000eE3ED0003
EUL2000016/H001_SP00DWoo00<007ooOol097oo0P0000Aoo`00000000Aoo`03001oogoo00eoo`00
37oo00<007ooOol00Woo0P0027oo200000=oo`00Ool07Woo1`008Woo00@003ED=E@000AFE`05001[
66/HJaP0001COol00`00Oomoo`0TOol30007Ool00`00Oomoo`0=Ool000aoo`03001oogoo009oo`80
00Uoo`D000Aoo`03001oogoo01Uoo`L002Eoo`04000eE3ED0004EUL01@00JaQ[6000Khh0Dgoo00<0
07ooOol08Goo1`001goo00<007ooOol037oo000<Ool00`00Oomoo`02Ool2000:Ool40005Ool00`00
Oomoo`0EOol7000XOol01000=E@eE00015IG00<006/HJaP00P00Dgoo00<007ooOol07Woo2@0027oo
00<007ooOol037oo000<Ool00`00Oomoo`02Ool2000;Ool40005Ool00`00Oomoo`0BOol6000[Ool0
0`00=E@00004EUL01@00JaQ[66/H0000E7oo00<007ooOol06goo2@002goo00<007ooOol037oo000<
Ool00`00Oomoo`02Ool2000=Ool30005Ool00`00Oomoo`0>Ool6000]Ool01000=E@eE00015IG00D0
06/HJaP006n>05Aoo`03001oogoo01Moo`X000ioo`03001oogoo00aoo`0037oo00<007ooOol00Woo
0P003Woo0`001Goo00<007ooOol02Woo1`00;goo00@003ED=E@000AFE`03001[66/H008005Aoo`03
001oogoo01Aoo`X0015oo`03001oogoo00aoo`0037oo00<007ooOol00Woo0P003goo0`001Goo00<0
07ooOol01Woo1`00<Woo00<003ED000015IG00D006/HJaQ[600005Eoo`03001oogoo015oo`X001Ao
o`03001oogoo00aoo`002goo00<007ooOol00goo0P0047oo0`001Goo00<007ooOol00Woo1`00=7oo
00@003ED=E@000AFE`05001[66/H001_SP1EOol00`00Oomoo`0>Ool:000GOol00`00Oomoo`0<Ool0
00]oo`03001oogoo009oo`80019oo`<000Eoo`03001oo`0000D003Moo`04000eE3ED0004EUL00`00
JaQ[6002001EOol00`00Oomoo`0;Ool:000JOol00`00Oomoo`0<Ool000]oo`03001oogoo009oo`80
01=oo`<000=oo`H003Yoo`03000eE00000AFE`05001[66/HJaP0001GOol00`00Oomoo`07Ool:000N
Ool00`00Oomoo`0;Ool000]oo`03001oogoo009oo`8001Aoo`T003]oo`04000eE3ED0004EUL01@00
JaQ[6000Khh0Egoo00<007ooOol017oo2P008Goo00<007ooOol02goo000;Ool00`00Oomoo`02Ool2
000EOol50003Ool00`00Oomoo`0hOol01000=E@eE00015IG00<006/HJaP00P00Egoo00@007ooOomo
o`X002Aoo`03001oogoo00]oo`002goo00<007ooOol00Woo0P005Woo0`001Goo00<007ooOol0=goo
00@003ED=E@000=FE`80009[6003001oogoo05Ioo`/002Moo`03001oogoo00]oo`002goo00<007oo
Ool00Woo0P005goo0`001Goo00<007ooOol0=Goo00@003ED=E@000AFE`05001[66/H001_SP1FOol:
000ZOol00`00Oomoo`0;Ool000]oo`03001oogoo009oo`8001Qoo`<000Eoo`03001oogoo03Aoo`04
000eE3ED0004EUL00`00JaQ[6002001COol300000goo00000004000]Ool00`00Oomoo`0;Ool000Yo
o`03001oogoo00=oo`8001Uoo`<000Eoo`03001oogoo03=oo`04000eE3ED0003EUL20002JaP00fn>
001oo`1?Ool300000goo00000004000`Ool00`00Oomoo`0;Ool000Yoo`03001oogoo00=oo`8001Yo
o`<000Eoo`03001oogoo035oo`04000eE3ED0004EUL01@00JaQ[6000Khh0CWoo0`0000=oo`000000
1P00<Woo00<007ooOol02Woo000:Ool00`00Oomoo`02Ool2000LOol40004Ool00`00Oomoo`0`Ool0
1000=E@eE00015IG00<006/HJaP00P00BWoo100000=oo`0000001@000goo00<007ooOol0<7oo00<0
07ooOol02Woo000:Ool00`00Oomoo`02Ool2000MOol40004Ool00`00Oomoo`0_Ool01000=E@eE000
0eIG0P0000A[6000Khh004Moo`<0009oo`L000Ioo`03001oogoo031oo`03001oogoo00Yoo`002Woo
00<007ooOol00Woo0P007goo0`0017oo00<007ooOol0;Goo00@003ED=E@000AFE`05001[66/H001_
SP15Ool30002Ool70009Ool00`00Oomoo`0`Ool00`00Oomoo`0:Ool000Yoo`03001oogoo009oo`80
021oo`<000Aoo`03001oogoo02aoo`04000eE3ED0004EUL00`00JaQ[60020012Ool30002Ool7000<
Ool00`00Oomoo`0`Ool00`00Oomoo`0:Ool000Yoo`03001oogoo009oo`80025oo`<000Aoo`03001o
ogoo02]oo`04000eE3ED0003EUL2000016/H001_SP00?goo0`000Woo1`003goo00<007ooOol0<7oo
00<007ooOol02Woo0009Ool00`00Oomoo`03Ool2000ROol30004Ool00`00Oomoo`0YOol01000=E@e
E00015IG00D006/HJaP006n>03eoo`<0009oo`L001=oo`03001oogoo02moo`03001oogoo00Yoo`00
2Goo00<007ooOol00goo0P008goo0`0017oo00<007ooOol0:7oo00@003ED=E@000AFE`03001[66/H
008003Yoo`<0009oo`L001Ioo`03001oogoo02moo`03001oogoo00Yoo`002Goo00<007ooOol00goo
0P0097oo0`0017oo00<007ooOol09goo00@003ED=E@000=FE`800004JaP006n>000gOol30002Ool7
000IOol00`00Oomoo`0`Ool00`00Oomoo`09Ool000Uoo`03001oogoo009oo`8002Ioo`<000Aoo`03
001oogoo02Eoo`04000eE3ED0004EUL01@00JaQ[6000Khh0=Goo0`000Woo1`0077oo00<007ooOol0
<7oo00<007ooOol02Goo0009Ool00`00Oomoo`02Ool2000WOol30004Ool00`00Oomoo`0TOol01000
=E@eE00015IG00<006/HJaP00P00<Woo0`000Woo1`007goo00<007ooOol0<7oo00<007ooOol02Goo
0009Ool00`00Oomoo`02Ool2000XOol30004Ool00`00Oomoo`0SOol01000=E@eE0000eIG0P0000A[
6000Khh002moo`<0009oo`L0029oo`03001oogoo031oo`03001oogoo00Uoo`002Goo00<007ooOol0
0Woo0P00:Goo0`0017oo00<007ooOol08Woo00<003ED000015IG00D006/HJaP006n>02eoo`<0009o
o`L002Aoo`80039oo`03001oogoo00Uoo`002Goo00<007ooOol00Woo0P00:Woo0`0017oo00<007oo
Ool087oo00@003ED=E@000AFE`03001[66/H008002Yoo`<0009oo`H002Eoo`<0009oo`03001oogoo
02moo`03001oogoo00Uoo`0027oo00<007ooOol00goo0P00:goo0`0017oo00<007ooOol07goo00@0
03ED=E@000AFE`03001[66/H008002Moo`<0009oo`H002Eoo`<000Ioo`03001oogoo02ioo`03001o
ogoo00Uoo`0027oo00<007ooOol00goo0P00;7oo0`0017oo00<007ooOol07Woo00<003ED000015IG
00D006/HJaP006n>02Aoo`@00003Ool0000000D002Eoo`<000Uoo`03001oogoo02moo`03001oogoo
00Qoo`0027oo00<007ooOol00goo0P008Woo0P002Goo0`0017oo00<007ooOol077oo00@003ED=E@0
00AFE`03001[66/H0080025oo`<0009oo`L002Aoo`@000eoo`03001oogoo02ioo`03001oogoo00Qo
o`0027oo00<007ooOol00Woo0P008Goo0P000WZ`0P0027oo0`0017oo0P0077oo00@003ED=E@000AF
E`03001[66/H008001ioo`<0009oo`H002Eoo`<0019oo`03001oogoo02eoo`03001oogoo00Qoo`00
27oo00<007ooOol00Woo0P007goo0P001WZ`0P001goo0`001Goo00<007ooOol06Goo00<003ED0000
15IG00D006/HJaP006n>01aoo`<0009oo`H002Eoo`<001Ioo`03001oogoo02aoo`03001oogoo00Qo
o`0027oo00<007ooOol00Woo0P007Goo0`002GZ`0`001Goo0`001Goo00<007ooOol05goo00@003ED
=E@000AFE`03001[66/H008001Uoo`<00003Ool0000000D002Eoo`<001Uoo`03001oogoo02aoo`03
001oogoo00Qoo`0027oo00<007ooOol00Woo0P0077oo0P003WZ`0P0017oo0`001Goo00<007ooOol0
5Woo00@003ED=E@000AFE`03001[66/H008001Ioo`<00003Ool0000000D002Eoo`<001eoo`03001o
ogoo02]oo`03001oogoo00Qoo`001goo00<007ooOol00goo0P006Woo0`004GZ`0P000goo0`001Goo
00<007ooOol05Goo00@003ED000000=FE`05001[66/H001_SP0DOol300000goo00000004000VOol3
000QOol00`00Oomoo`0ZOol00`00Oomoo`08Ool000Moo`03001oogoo00=oo`8001Uoo`8001Ej/080
009oo`<000Eoo`03001oogoo01=oo`04000eE3ED0004EUL00`00JaQ[6002000AOol300000goo0000
0004000VOol3000UOol00`00Oomoo`0YOol00`00Oomoo`08Ool000Moo`03001oogoo00=oo`8001Mo
o`<001Qj/003001oogoo00<000Eoo`03001oogoo019oo`04000eE3ED0004EUL00`00JaQ[6002000>
Ool:000UOol4000XOol00`00Oomoo`0ZOol00`00Oomoo`07Ool000Moo`03001oogoo00=oo`8001Io
o`8001]j/003001oogoo00<000Eoo`03001oogoo015oo`04000eE0000003EUL01@00JaQ[6000Khh0
37oo2P009Goo0`00;Goo00<007ooOol0:Goo00<007ooOol01goo0007Ool00`00Oomoo`02Ool2000E
Ool3000MN[000`00Oomoo`030005Ool00`00Oomoo`0?Ool01000=E@eE00015IG00<006/HJaP00P00
2Goo2@009Woo0`00<Goo00<007ooOol0:7oo00<007ooOol01goo0007Ool00`00Oomoo`02Ool2000D
Ool20002?<dMN[001000Oomoogoo0`001Goo00<007ooOol03Woo00@003ED=E@000AFE`03001[66/H
008000Ioo`T002Ioo`<003Eoo`03001oogoo02Moo`03001oogoo00Moo`001goo00<007ooOol00Woo
0P0057oo0cc=00<007Z`N[0077Z`00@007ooOomoo`<000Eoo`03001oogoo00eoo`04000eE3ED0003
EUL01@00JaQ[6000Khh017oo2@009Woo0`00>7oo00<007ooOol09goo00<007ooOol01goo0007Ool0
0`00Oomoo`02Ool2000COol01@00?<dlcCc=00007gZ`00@007ooOomoo`<000Eoo`03001oogoo00]o
o`04000eE3ED0004EUL00`00JaQ[600<000VOol3000lOol00`00Oomoo`0VOol00`00Oomoo`07Ool0
00Ioo`03001oogoo00=oo`8001=oo`05000lcCc=?<d0000PN[001000Oomoogoo0`001Goo00<007oo
Ool02Woo00@003ED=E@000AFE`03001[66/H00800003Ool0000000@002Ioo`<0041oo`03001oogoo
02Eoo`03001oogoo00Moo`001Woo00<007ooOol00goo0P004goo00D003c=?<dlc@00025j/004001o
ogooOol30005Ool00`00Oomoo`09Ool01000=E@eE0000eIG0P0000=[600000001@009Goo1000A7oo
00<007ooOol09Goo00<007ooOol01Woo0006Ool00`00Oomoo`03Ool2000COol01000?<dlc@008gZ`
00@007ooOomoo`<000Eoo`03001oogoo00Moo`04000eE3ED0004EUL00`00JaQ[6005000TOol30019
Ool00`00Oomoo`0TOol00`00Oomoo`06Ool000Ioo`03001oogoo00=oo`80019oo`05000lcCc=?<d0
000TN[001000Oomoogoo0`001Goo00<007ooOol01Woo00@003ED=E@000AFE`03001[66/H008002Ao
o`<004aoo`03001oogoo02Aoo`03001oogoo00Ioo`001Woo00<007ooOol00goo0P004Woo00D003c=
?<dlc@0002Ej/004001oogooOol40004Ool00`00Oomoo`04Ool20002=E@01000EUMFEeIG0P0000=[
6000Khh08Woo0`00D7oo00<007ooOol08goo00<007ooOol01Woo0006Ool00`00Oomoo`02Ool2000C
Ool01@00?<dlcCc=00009GZ`00<007ooOol00Woo100017oo00<007ooOol010000SED00<005IGEUL0
0UIG00<006/HJaP00P007goo0`00E7oo00<007ooOol08Woo00<007ooOol01Woo0006Ool00`00Oomo
o`02Ool2000COol01000?<dlc@009gZ`00<007ooOol00goo0`0017oo1P000SED00<005IGEUL00UIG
00<006/HJaP00P0077oo0`00F7oo00<007ooOol08Goo00<007ooOol01Woo0006Ool00`00Oomoo`02
Ool2000BOol01@00?<dlcCc=0000:7Z`00<007ooOol00goo0`000Woo1`000SED00@005IGEUMFE`80
0003JaP006n>01Yoo`<005]oo`03001oogoo025oo`03001oogoo00Ioo`001Goo00<007ooOol00goo
0P004Woo00D003c=?<dlc@0002Uj/003001oogoo00=oo`L0009oo`04000eE3ED0004EUL00`00JaQ[
6002000GOol3001OOol00`00Oomoo`0POol00`00Oomoo`06Ool000Eoo`03001oogoo00=oo`80019o
o`05000lcCc=?<d0000ZN[000`00Oomoo`03Ool50003Ool01000=E@eE00015IG00<006/HJaP00P00
4goo1000Hgoo00<007ooOol087oo00<007ooOol01Goo0005Ool00`00Oomoo`03Ool2000BOol01000
?<dlc@00:gZ`00<007ooOol00goo0P000Woo00D007ooOomoo`00008eE004001FEeIGEUL200000f/H
001_SP0AOol3001XOol00`00Oomoo`0OOol00`00Oomoo`05Ool000Eoo`03001oogoo00=oo`80015o
o`05000lcCc=?<d0000/N[000`00Oomoo`02Ool20002Ool01`00Oomoogoo000eE00000AFE`03001[
66/H008000ioo`<006]oo`03001oogoo01moo`03001oogoo00Eoo`001Goo00<007ooOol00goo0P00
4Goo00D003c=?<dlc@0002aj/003001oogoo009oo`80009oo`04001oogoo0002=E@00`00EUMFE`02
EUL00`00JaQ[6002000;Ool3001_Ool00`00Oomoo`0NOol00`00Oomoo`05Ool000Eoo`03001oogoo
009oo`80019oo`05000lcCc=?<d0000]N[001000Oomoogoo0P000Woo00@007ooOol0008eE003001F
EeIG009FE`04001[66/HKhh9Ool3001cOol00`00Oomoo`0MOol00`00Oomoo`05Ool000Eoo`03001o
ogoo009oo`80019oo`04000lcCc=000^N[001000Oomoogoo0P000Woo00H007ooOol003ED0004EUL0
0`00JaQ[60020006Ool3001gOol00`00Oomoo`0LOol00`00Oomoo`05Ool000Aoo`03001oogoo00=o
o`80015oo`05000lcCc=?<d0000_N[000`00Oomoo`020002Ool00`00Ool00002=E@00`00EUMFE`02
EUL00`00JaQ[60020003Ool3001jOol00`00Oomoo`0LOol00`00Oomoo`05Ool000Aoo`03001oogoo
00=oo`80015oo`03000lcCc=008002mj/003001oogoo0080009oo`03001oo`00008eE003001FEeIG
009FE`03001[66/H00D007ioo`03001oogoo01aoo`03001oogoo00Aoo`0017oo00<007ooOol00goo
0P004Goo0`0000=9]000N[00;WZ`00<007ooOol00P0000Ioo`00Oomoo`00=E@20003EUL00`00JaP0
00020023Ool00`00Oomoo`0KOol00`00Oomoo`04Ool000Aoo`03001oogoo00=oo`80015oo`050019
]4VdBK@0000`N[002000Ool00000Ool007oo0002=E@01000EUMFEeIG0`0000=[60000000Q7oo00<0
07ooOol06Woo00<007ooOol017oo0004Ool00`00Oomoo`03Ool2000AOol01@00BKA9]4Vd0000<7Z`
00P007oo000007oo001oo`000SED100000AFE`00JaQ[608008Eoo`03001oogoo01Uoo`03001oogoo
00Aoo`0017oo00<007ooOol00goo0P004Goo00<004VdBK@00TVd00<007Z`N[00;WZ`0`0000=oo`00
Ool010000eIG00<006/HJaP00P00QWoo00<007ooOol06Goo00<007ooOol017oo0004Ool00`00Oomo
o`02Ool2000COol01@00BKA9]4Vd0000<7Z`0P000Woo0`0000<eE000EUL00eIG00<006/HJaP00P00
Qgoo00<007ooOol067oo00<007ooOol017oo0004Ool00`00Oomoo`02Ool2000COol01@00BKA9]4Vd
0000<GZ`1@000SED00<005IGEUL00UIG00<006/HJaP00P00R7oo00<007ooOol05goo00<007ooOol0
17oo0003Ool00`00Oomoo`03Ool2000COol01@00BKA9]4Vd0000;GZ`1@000Woo0P000SED00D005IG
EUMFE`00009[608008Yoo`03001oogoo01Moo`03001oogoo00=oo`000goo00<007ooOol00goo0P00
4goo00D004VdBKA9]00002Yj/0<000Ej/003001oo`00008eE003001FE`00009FE`03001[66/H0080
08Yoo`03001oogoo01Moo`03001oogoo00=oo`000goo00<007ooOol00goo0P004goo00D004VdBKA9
]00002Mj/0<000Qj/003001oo`00008eE003001FEeIG009FE`03001[66/H008008]oo`03001oogoo
01Ioo`03001oogoo00=oo`000goo00<007ooOol00goo0P004goo00D004VdBKA9]00002Aj/0<000]j
/003001oo`00008eE005001FEeIGEUL00002JaP2002=Ool00`00Oomoo`0EOol00`00Oomoo`03Ool0
00=oo`03001oogoo00=oo`8001=oo`030019]4Vd0099]003001j/7Z`01ij/0<000mj/006000eE3ED
001FE`000UIG00<006/HJaP00P00SWoo00<007ooOol057oo00<007ooOol00goo0003Ool00`00Oomo
o`03Ool2000DOol01@00BKA9]4Vd00007GZ`0`004WZ`00@003ED=E@000AFE`03001[66/H008008io
o`03001oogoo01Aoo`03001oogoo00=oo`000goo00<007ooOol00goo0P0057oo00D004VdBKA9]000
01Yj/0<001Ej/004000eE3ED0003EUL00`00JaQ[6002002@Ool00`00Oomoo`0COol00`00Oomoo`03
Ool0009oo`03001oogoo00=oo`8001Eoo`050019]4VdBK@0000GN[03000GN[001P00=E@eE000EUL0
009FE`03001[66/H0080095oo`03001oogoo019oo`03001oogoo00=oo`000Woo00<007ooOol00goo
0P005Goo00D004VdBKA9]00001=j/0@001Yj/004000eE3ED0004EUL00`00JaQ[6002002BOol00`00
Oomoo`0BOol00`00Oomoo`02Ool0009oo`03001oogoo00=oo`8001Eoo`050019]4VdBK@0000@N[03
000NN[001000=E@eE0000eIG0P0000=[60000000U7oo00<007ooOol04Goo00<007ooOol00Woo0002
Ool00`00Oomoo`03Ool2000EOol00`00BKA9]002BK@00`00N[1j/00:N[03000PN[001000=E@eE000
15IG00<006/HJaP00P00U7oo00<007ooOol04Goo00<007ooOol00Woo0002Ool00`00Oomoo`03Ool2
000EOol00`00BKA9]002BK@00`00N[1j/007N[03000SN[001000=E@eE00015IG00<006/HJaP00P00
UGoo00<007ooOol047oo00<007ooOol00Woo0002Ool00`00Oomoo`03Ool2000FOol01@00BKA9]4Vd
00001WZ`0`009WZ`00@003ED=E@000=FE`800003JaP0000009Moo`03001oogoo00moo`03001oogoo
009oo`000Woo00<007ooOol00goo0P005Woo00D004VdBKA9]00000=j/0<002Uj/003000eE00000AF
E`03001[66/H008009Qoo`03001oogoo00ioo`03001oogoo009oo`000Woo00<007ooOol00goo0P00
5Woo00@004VdBKA9]0@002]j/004000eE3ED0004EUL00`00JaQ[6002002HOol00`00Oomoo`0>Ool0
0`00Oomoo`02Ool00003Ool007oo00Aoo`8001Moo`D002ij/004000eE3ED0003EUL200000f/H0000
002JOol00`00Oomoo`0>Ool00`00Oomoo`01Ool00003Ool007oo00Aoo`8001Eoo`<000=9]003001j
/7Z`02aj/003000eE00000AFE`03001[66/H008009]oo`03001oogoo00eoo`03001oogoo005oo`00
00=oo`00Ool017oo0P004Woo0`000Woo00<004VdBK@00TVd00<007Z`N[00:WZ`00@003ED=E@000AF
E`03001[66/H008009aoo`03001oogoo00aoo`03001oogoo005oo`0000=oo`00Ool017oo0P003goo
0`001Goo00<004VdBK@00TVd00<007Z`N[00:WZ`00@003ED=E@000AFE`04001[66/H002MOol00`00
Oomoo`0<Ool00`00Oomoo`01Ool00003Ool007oo00Aoo`8000aoo`<000Uoo`050019]4VdBK@0000/
N[001000=E@000000eIG00<006/HJaP00P00WWoo00<007ooOol02goo00<007ooOol00Goo00000goo
001oo`04Ool20009Ool3000<Ool01@00BKA9]4Vd0000:gZ`00@003ED=E@000AFE`03001[66/H0080
09moo`03001oogoo00Yoo`03001oogoo005oo`0000=oo`00Ool017oo0P001Woo0`003goo00<004Vd
00000P00:gZ`00<003ED=E@00P000eIG00@006/HJaP00:5oo`03001oogoo00Uoo`03001oogoo005o
o`0000=oo`00Ool017oo0P000Woo10004Woo0P000diH00<007Z`N[00:7Z`00@003ED=E@000=FE`03
001[66/H00800:5oo`03001oogoo00Uoo`03001oogoo005oo`0000<007ooOol00goo1@005Woo00<0
04iHCUP00TiH00<007Z`N[009gZ`00@003ED=E@000AFE`03001[66/H00800:9oo`03001oogoo00Uo
o`40005oo`5oo`0000<007ooOol00Woo1P005goo00<004iHCUP00TiH00<007Z`N[009WZ`00<003ED
=E@00P000eIG00@006/HJaP00:Aoo`03001oogoo00Qoo`40005oo`5oo`0000<007oo00000P000goo
10005Woo00<004iHCUP00TiH00<007Z`N[009WZ`00@003ED=E@000=FE`03001[66/H00800:Eoo`03
001oogoo00Moo`40005oo`5oo`000P0027oo0`005Woo00<004iHCUP00TiH00<007Z`N[0097Z`00@0
03ED=E@000AFE`03001[66/H00800:Ioo`03001oogoo00Ioo`40005oo`5oo`0000=oo`00Ool027oo
0`005Goo00<004iHCUP00TiH00<007Z`N[0097Z`00@003ED=E@000AFE`03001[66/H00800:Ioo`03
001oogoo00Ioo`40005oo`5oo`000Woo0P0027oo100057oo00<004iHCUP00TiH00<007Z`N[008gZ`
00@003ED=E@000=FE`03001[66/H00<00:Moo`03001oogoo00Eoo`40005oo`5oo`0017oo00<007oo
Ool01Woo10004goo00<004iHCUP00TiH00<007Z`N[008WZ`00@003ED=E@000AFE`03001[66/H00<0
0:Qoo`03001oogoo00Aoo`40005oo`5oo`001Goo00<007ooOol01goo0`004Woo00<004iHCUP00diH
00<007Z`N[008GZ`00@003ED=E@000AFE`06001[66/H001j/000ZGoo00<007ooOol017oo0@000Goo
0006Ool20008Ool4000AOol00`00CUQ>F002CUP00`00N[1j/00QN[001000=E@eE0000eIG00<006/H
JaP00P0000=j/0000000Z7oo00<007ooOol017oo0@000Goo0008Ool00`00Oomoo`06Ool4000@Ool0
0`00CUQ>F003CUP00`00N[1j/00ON[001000=E@eE00015IG00<006/HJaP00P000WZ`00<007ooOol0
Ygoo00<007ooOol00goo0@000Goo0009Ool00`00Oomoo`07Ool3000@Ool00`00CUQ>F002CUP00`00
N[1j/00ON[001000=E@eE00015IG00@006/HJaP000=j/003001oogoo0:Qoo`03001oogoo009oo`40
005oo`002Woo0P0027oo0`003goo00<004iHCUP00TiH00<007Z`N[007gZ`00@003ED=E@000=FE`03
001[66/H008000=j/003001oogoo0:Uoo`05001oogooOol00001Ool000aoo`03001oogoo00Ioo`@0
00eoo`03001>F4iH00=>F003001j/7Z`01ej/004000eE3ED0004EUL00`00JaQ[60020003N[000`00
Oomoo`2YOol01@00Oomoogoo00000Goo000=Ool00`00Oomoo`06Ool4000=Ool00`00CUQ>F002CUP0
0`00N[1j/00MN[001000=E@eE00015IG00D006/HJaQ_SP0000=j/003001oogoo0:Yoo`04001oogoo
0001Ool000ioo`8000Qoo`<000aoo`03001>F4iH00=>F003001j/7Z`01aj/004000eE3ED0003EUL0
0`00JaQ[60020003N[000`00Oomoo`2/Ool00`00Ool00001Ool0011oo`03001oogoo00Ioo`@000]o
o`03001>F4iH009>F003001j/7Z`01aj/004000eE000JaP3EUL00`00JaQ[60020003N[000`00Oomo
o`2]Ool10001Ool10000015oo`03001oogoo00Ioo`@000Yoo`03001>F4iH00=>F003001j/7Z`01Yj
/004000eE3ED0004EUL01@00JaQ[66n>00000gZ`00<007ooOol0[Goo0@000Goo0@00000BOol20008
Ool3000:Ool00`00CUQ>F002CUP00`00N[1j/00JN[001000=E@eE0000eIG00<006/HJaP00P0017Z`
00<007ooOol0[Woo0P00000DOol00`00Oomoo`06Ool40008Ool00`00CUQ>F003CUP00`00N[1j/00I
N[000`00=E@00004EUL00`00JaQ[60020004N[000`00Oomoo`2^Ool2000001Eoo`03001oogoo00Io
o`@000Moo`03001>F4iH00=>F003001j/7Z`01Qj/004000eE3ED0004EUL01@00JaQ[66n>00000gZ`
00<007ooOol0Zgoo10000Woo000FOol20008Ool30007Ool00`00CUQ>F003CUP00`00N[1j/00GN[00
1000=E@eE0000eIG00<006/HJaP00P0017Z`00<007ooOol0Ygoo10001Woo000HOol00`00Oomoo`06
Ool30006Ool00`00CUQ>F003CUP00`00N[1j/00GN[001000=E@eE0000eIG00<006/HJaP00P0017Z`
00<007ooOol0Xgoo10002Woo000IOol00`00Oomoo`06Ool40005Ool00`00CUQ>F003CUP00`00N[1j
/00EN[001000=E@eE00015IG00D006/HJaQ_SP0000Aj/003001oogoo09moo`@000ioo`006Woo0P00
1goo100017oo00<004iHCUP00TiH0P005gZ`00@003ED=E@000AFE`=[6003001j/7Z`00=j/003001o
ogoo09]oo`@0019oo`0077oo00<007ooOol01Woo0`0017oo00@004iH0000009Bg003001j/7Z`01Aj
/004000eE3ED0003EUL00`00JaQ[60020004N[000`00Oomoo`2HOol4000FOol001eoo`03001oogoo
00Ioo`@0009oo`8000EBg003001j/7Z`019j/004000eE3ED0004EUL01@00JaQ[66n>000017Z`00<0
07ooOol0U7oo10006Woo000NOol00`00Oomoo`06Ool40002Ool00`00D]aBg004D]`00`00N[1j/00A
N[001000=E@eE00015IG0f/H00<007Z`N[000gZ`00<007ooOol0TGoo0`007Woo000OOol20008Ool3
0002Ool00`00D]aBg004D]`00`00N[1j/00@N[001000=E@eE0000eIG00<006/HJaP00P001GZ`00<0
07ooOol0SGoo10008Goo000QOol00`00Oomoo`06Ool30002Ool00`00D]aBg003D]`00`00N[1j/00A
N[000cED001FE`03EUL01@00JaQ[66n>00001GZ`00<007ooOol0RGoo10009Goo000ROol00`00Oomo
o`06Ool400000goo001Bg004D]`00`00N[1j/00@N[000cED001FE`03EUL3JaP00`00N[1j/003N[00
0`00Oomoo`26Ool4000YOol002=oo`8000Moo`@00003Ool005;L00ABg003001j/7Z`00mj/003=E@0
05IG009FE`03001[66/H008000Ej/003001oogoo089oo`@002eoo`009Goo00<007ooOol01Woo0`00
00=oo`00D]`015;L00<007Z`N[003WZ`00<005IGEUL00UIG00D006/HJaQ_SP0000Ej/003001oogoo
07ioo`@0035oo`009Woo00<007ooOol01Woo0`0000=oo`00D]`015;L00<007Z`N[0037Z`0P0015IG
0f/H00<007Z`N[000gZ`00<007ooOol0Ngoo1000=Goo000WOol20007Ool40006D]`00`00N[1j/00<
N[020002EUL00`00JaQ[60020004N[000`00Oomoo`1hOol4000iOol002Uoo`03001oogoo00Eoo`@0
00IBg003001j/7Z`00ej/0H000Ej/003001oogoo07Eoo`<003eoo`00:Woo00<007ooOol01Woo0`00
1U;L00<007Z`N[005WZ`00<007ooOol0LWoo1000@7oo000[Ool20007Ool30005D]`00`00N[1j/00E
N[000`00Oomoo`1_Ool40014Ool002eoo`03001oogoo00Eoo`<000EBg003001j/7Z`01=j/08006eo
o`@004Qoo`00;Woo00<007ooOol01Goo100015;L00<007Z`N[004GZ`00<007oo0000JGoo1000C7oo
000_Ool20006Ool40004D]`00`00N[1j/00?N[001000Oomoo`00IGoo1000D7oo000aOol00`00Oomo
o`05Ool30002D]`7000:N[030002Ool00`00Oomoo`1OOol4001DOol0039oo`03001oogoo00Eoo`@0
00I3W`T0009j/08000=oo`03001oogoo05]oo`@005Qoo`00<goo0P001Woo0`0000=oo`0000001P00
1D>O1@000goo00<007ooOol0F7oo0`00G7oo000eOol00`00Oomoo`04Ool40007Ool60002Ool20003
Ool00`00Oomoo`1DOol4001OOol003Ioo`03001oogoo00Aoo`@000ioo`8000=oo`03001oogoo051o
o`@006=oo`00=goo00<007ooOol01Goo0`003Goo0P000goo00<007ooOol0C7oo1000Igoo000hOol2
0006Ool4000;Ool20003Ool00`00Oomoo`18Ool4001[Ool003Yoo`03001oogoo00Aoo`@000Yoo`80
00=oo`03001oogoo04Aoo`@006moo`00>goo00<007ooOol01Goo0`002Goo0P000goo00<007ooOol0
@7oo1000Lgoo000lOol20006Ool40007Ool20003Ool00`00Oomoo`0lOol4001gOol003ioo`03001o
ogoo00Aoo`@000Ioo`8000=oo`03001oogoo03Uoo`<007]oo`00?goo00<007ooOol01Goo0`001Goo
0P000goo00<007ooOol0=Goo1000OWoo0010Ool20006Ool40003Ool20003Ool00`00Oomoo`0aOol4
0022Ool0049oo`03001oogoo00Aoo`@0009oo`8000=oo`03001oogoo02eoo`@008Ioo`00@goo00<0
07ooOol01Goo0`0000=oo`0000000goo00<007ooOol0:Goo1000RWoo0014Ool20006Ool50003Ool0
0`00Oomoo`0UOol4002>Ool004Ioo`03001oogoo00Aoo`@0009oo`03001oogoo029oo`@0099oo`00
Agoo00<007ooOol01Goo0`0000=oo`00Ool07goo1000UWoo0018Ool20005Ool20002Ool00`00Oomo
o`0KOol3002JOol004Yoo`03001oogoo00Ioo`03001oogoo01Moo`@009eoo`00Bgoo00<007ooOol0
1Goo00<007ooOol04goo1000XGoo001<Ool20005Ool00`00Oomoo`0?Ool4002UOol004ioo`03001o
ogoo009oo`03001oogoo00]oo`@00:Uoo`00Cgoo00D007ooOomoo`0000Uoo`@00:eoo`00D7oo0P00
00=oo`00Ool017oo1000/Goo001BOol200000goo00000002002eOol005=oo`800;Uoo`00\
\>"],
  ImageRangeCache->{{{0, 269}, {249, 0}} -> {-4.91729*^-06, 0.0125393, 
  0.00365598, 0.00365598}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Loads and Reactions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[
"This section deals with issues related to applying loads to mechanisms \
modeled with generalized coordinates, and finding the reaction forces \
associated with those coordinates. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Applied Loads"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The Generalized Coordinate Package has almost no effect on the modeling of \
applied Loads. The standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load functions ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Gravity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are used to apply loads to a generalized coordinate slave body in exactly \
the same way as they are used with standard bodies. The one load function \
that is affected by the use of generalized coordinates is ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is used to apply a load directly to a specified coordinate.\n\n\
Since ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references the coordinates in a model directly by their symbolic name, it \
can be used to apply a load directly to a generalized coordinate. Conversely, \
",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cannot be used to apply a load directly to a Cartesian coordinate of a \
slave body because a slave body doesn't have any explicit Cartesian \
coordinates.\n\nFor example, suppose a model has two bodies, 2 and 3, and \
body 3 is a slave to body 2. The two bodies are joined by a revolute joint \
and the symbol ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " represents the rotation of the slave, relative to the master. The ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function may be used to apply a force in the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction to the slave , but the ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function may not."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
This loads the Generalized Coordinate Package and defines names for bodies 2 \
and 3.\
\>", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`GenCrd2D`\>"]\), 
    \(\(master = 2; \)\), 
    \(\(slave = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a load object that applies a 10 unit force to the slave body."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Force[slave, Axis[slave, 0, {1, 0}], 10]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Force", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This load object does not apply the 10 unit force to the slave body, \
because ",
  StyleBox["X3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not a coordinate in the model."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Load[X3, 10]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Load", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "However, the ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function can be used to apply a moment to the slave body because the \
generalized coordinate ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an angular coordinate. A load applied directly to ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " essentially applies a counterclockwise moment to the slave body, and a \
clockwise moment to the master."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a load object that applies a 10 unit moment to the slave, and an \
equal and opposite moment to the master."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Moment[slave, master, 10]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({SysLoad["Moment", "<>"], SysLoad["Moment", "<>"]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a simpler load object that applies the same 10 unit couple between \
the slave and master."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Load[alpha, 10]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Load", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "In general, the ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function should be used instead of ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " whenever possible because the resulting algebraic expressions that are \
added to the model can be much simpler. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraint Reactions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "While the use of generalized coordinates has little effect on the \
application of loads to a model, finding constraint reaction forces is \
another matter. When a constraint is eliminated from a model by using \
generalized coordinates, information regarding the reaction forces at the \
constraint is lost. This is one basic disadvantage of a reduced coordinate \
system; by algebraically eliminating coordinates from a model we lose \
information about those coordinates.\n\nThus, three restrictions are placed \
on models using generalized coordinates: the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function cannot be used to find the reaction forces applied by a \
generalized coordinate constraint to ",
  StyleBox["any",
    FontSlant->"Italic"],
  " body (because it is not really a constraint), the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function cannot be used to find the reaction forces applied by ",
  StyleBox["any",
    FontSlant->"Italic"],
  " constraint to a generalized coordinate slave body (because the body \
doesn't have Cartesian coordinates), and the ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function cannot be used to find the loads applied to a slave body (for \
the same reason).\n\nBoth the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions may still be used with generalized coordinates, but they must \
be used to access the coordinates directly."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, sym",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the generalized reaction applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The physical meaning of the returned scalar load is dependent on the \
nature of the generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".\n   \n",
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the total external generalized load applied to generalized \
coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, ",
    FontSlant->"Italic"],
  StyleBox["Type->Reaction]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the total generalized reaction load applied by all constraints to \
coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, ",
    FontSlant->"Italic"],
  StyleBox["Type->Dynamic]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the total generalized inertial load applied to coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Alternate usages of ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The physical meaning of the quantities returned by ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is quite clear, in the context of the simple generalized coordinate \
constraints provided by this package. If the generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " represents an angle in radians, then the loads on the coordinate are in \
consistent units of moment. If the coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " represents a distance, then the loads on the coordinate are in consistent \
units of force.\n\nHowever, if abstract user-defined generalized coordinate \
constraints are used, the generalized loads may have little physical meaning, \
just like the generalized loads associated with each constraint (",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...) sometimes have little physical meaning. The one meaning that always \
applies to a generalized load is this: a generalized load times a small \
variation in its associated generalized coordinate is equal to a small \
variation in work, in consistent energy units. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Slider-Crank Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions with generalized coordinates a planar model of a simple \
slider-crank is developed. This model uses only two bodies, the slider and \
crank, and it is modeled with two generalized coordinates, the rotation angle \
of the crank and the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " displacement of the slider."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This loads the Generalized Coordinate packages and defines some useful \
constants."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`GenCrd2D`\>"]\), 
    \(Off[General::"\<spell1\>"]\), 
    \(\(X = {1, 0}; \)\), 
    \(\(Y = {0, 1}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the slider-crank mechanism. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53488 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.267442 0.116279 0.267442 0.116279 [
[ 0 0 0 0 ]
[ 1 .53488 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .53488 L
0 .53488 L
closepath
clip
newpath
p
.01 w
.38372 .01163 m
.26744 .26744 L
.15116 .01163 L
.90698 .01163 L
.90698 .23837 L
.44186 .23837 L
s
p
1 0 0 r
.02 w
.26744 .26744 m
.26744 .26744 .05814 0 365.73 arc
F
p
.26744 .26744 m
.45559 .40414 L
s
P
P
p
0 1 0 r
.015 w
.45559 .40414 m
.83892 .26744 L
s
P
p
0 0 1 r
.78078 .23837 m
.89706 .23837 L
.89706 .29651 L
.78078 .29651 L
F
P
.02 w
.83892 .26744 Mdot
.26744 .26744 Mdot
p
p
p
/Courier findfont 8 scalefont setfont
[(x)] .36151 .33579 -0.33185 -1.25712 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .19909 .36151 -0.33185 -1.25712 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(2)] .26744 .26744 -0.33185 -1.25712 Mshowa
P
.002 w
.36151 .33579 m
.26744 .26744 L
.19909 .36151 L
s
.34953 .31271 m
.36151 .33579 L
.33586 .33153 L
s
.20336 .33586 m
.19909 .36151 L
.22217 .34953 L
s
P
p
p
/Courier findfont 8 scalefont setfont
[(x)] .9552 .26744 -1.5 -0.9 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .83892 .38372 -1.5 -0.9 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(3)] .83892 .26744 -1.5 -0.9 Mshowa
P
.002 w
.9552 .26744 m
.83892 .26744 L
.83892 .38372 L
s
.93194 .25581 m
.9552 .26744 L
.93194 .27907 L
s
.82729 .36047 m
.83892 .38372 L
.85055 .36047 L
s
P
p
p
/Courier findfont 8 scalefont setfont
[(x)] .9552 .26744 -1.5 -0.9 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .83892 .38372 -1.5 -0.9 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(3)] .83892 .26744 -1.5 -0.9 Mshowa
P
.002 w
.9552 .26744 m
.83892 .26744 L
.83892 .38372 L
s
.93194 .25581 m
.9552 .26744 L
.93194 .27907 L
s
.82729 .36047 m
.83892 .38372 L
.85055 .36047 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 150},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000UQ000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00:goo00<007ooOol0?Woo00<007ooOol0Zgoo000ZOooD000LOol002Yoom@001ao
o`00;7oo00<007ooOol0?7oo00<007ooOol0SWoo0P0077oo000/Ool2000lOol2002@Ool2000LOol0
02eoo`03001oogoo03Yoo`03001oogoo08moo`8001aoo`00;Goo00<007ooOol0>Goo0P00TGoo0P00
77oo000]Ool2000jOol00`00Oomoo`2@Ool2000LOol002ioo`03001oogoo03Qoo`03001oogoo091o
o`8001aoo`00;Woo0P00>7oo0P00TWoo0P0077oo000_Ool00`00Oomoo`0fOol00`00Oomoo`2AOol2
000LOol002moo`8003Ioo`8009=oo`8001aoo`00<7oo00<007ooOol0=7oo00<007ooOol0TWoo0P00
77oo000`Ool2000dOol2002DOol2000LOol0035oo`03001oogoo039oo`03001oogoo09=oo`8001ao
o`00<Goo0P00<Woo0P00UGoo0P0077oo000bOol00`00Oomoo`0`Ool00`00Oomoo`2DOol2000LOol0
039oo`03001oogoo02moo`8009Ioo`8001aoo`00<Woo0P00<7oo00<007ooOol0UGoo0P0077oo000c
Ool00`00Oomoo`0]Ool2002GOol2000LOol003=oo`8002ioo`03001oogoo09Ioo`8001aoo`00=7oo
00<007ooOol0:goo0P00V7oo0P0077oo000dOol2000/Ool00`00Oomoo`2GOol2000LOol003Eoo`03
001oogoo02Yoo`03001oogoo09Moo`8001aoo`00=Goo0P00:Woo0P00VGoo0P0077oo000fOol00`00
Oomoo`0XOol00`00Oomoo`2HOol2000LOol003Ioo`03001oogoo02Moo`8009Yoo`8001aoo`00=Woo
0P00:7oo00<007ooOol0VGoo0P0077oo000gOol00`00Oomoo`0UOol2002KOol2000LOol003Moo`80
02Ioo`03001oogoo09Yoo`8001aoo`00>7oo00<007ooOol08goo0P00W7oo0P0077oo000hOol2000T
Ool00`00Oomoo`2KOol2000LOol003Uoo`03001oogoo025oo`8009eoo`8001aoo`00>Goo0P008Woo
00<007ooOol0W7oo0P0077oo000jOol00`00Oomoo`0OOol2002NOol2000LOol003Yoo`80021oo`03
001oogoo09eoo`8001aoo`00>goo00<007ooOol07Goo0P00Wgoo0P0077oo000kOol00`00Oomoo`0M
Ool00`00Oomoo`2NOol2000LOol003]oo`8001ioo`03001oogoo09ioo`8001aoo`00?7oo00<007oo
Ool06goo0P00X7oo0P0077oo000lOol2000LOol00`00Oomoo`2OOol2000LOol003eoo`03001oogoo
01Uoo`800:5oo`8001aoo`00?Goo0P006Woo00<007ooOol0X7oo0P0077oo000nOol00`00Oomoo`0G
Ool2002ROol2000LOol003ioo`8001Qoo`03001oogoo0:5oo`8001aoo`00?goo00<007ooOol05Goo
0P00Xgoo0P0077oo000oOol2000FOol00`00Oomoo`2ROol2000LOol0041oo`03001oogoo01=oo`80
0:Aoo`8001aoo`00@7oo00<007ooOol04goo00<007ooOol0Xgoo0P0077oo0010Ool2000COol2002U
Ool2000LOol0045oo`03001oogoo015oo`03001oogoo0:Aoo`8001aoo`00@Goo0P004Woo00<007oo
Ool0Y7oo0P0077oo0012Ool00`00Oomoo`0?Ool2002VOol2000LOol0049oo`80011oo`03001oogoo
0:Eoo`8001aoo`00@goo00<007ooOol03Goo0P00Ygoo0P0077oo0013Ool2000>Ool00`00Oomoo`2V
Ool2000LOol004Aoo`03001oogoo00]oo`800:Qoo`8001aoo`00A7oo00<007ooO0002g`000<007oo
Ool0Ygoo0P0077oo0013Ool@O02YOol2000LOol0049ooa=l0:Moo`8001aoo`00@Goo5G`0YWoo0P00
77oo0010OolGO02UOol2000LOol003iooaYl0:Aoo`8001aoo`00?Woo6g`0Xgoo0P0077oo000nOolK
O00ROon3000LOol003eooael025ooel002407`<001aoo`00?7oo7g`0Ogoo8@0O7goo000lOolOO01o
OolQ01lOOol003aooaml07moob407amoo`00?7oo7g`0Ogoo8@0O2Goo0P0057oo000kOolPO01oOolQ
01l;Ool2000BOol003]oo`ml008000ml07moo`l07`8001007`eoo`80011oo`00>goo3W`010003W`0
Ogoo3P0O90003Woo000kOol>O005000=O01oOol>01l4000?01l=Ool2000@Ool003]oo`ml0080009l
0003001l07`000Yl07moo`l07`8001007`]oo`80019oo`00?7oo3G`000<007`0O0000g`000<007`0
O0002G`0Ogoo400O00<0000O01l00`002`0O2Goo0P001Woo0P0000=oo`00Ool02Goo000lOol<O000
0`00O01l00030002O0020009O01nOol00`?P01l07`0>01l00`0001l07`0201l00`0001l07`0901lC
Ool00`00Oomoo`09Ool003aoo`]l0004001l07`0O0020005O0000`00O01l0006O01kOol40n0@01l0
1@0001l07`0O0000300O4Woo00<007oo00002Woo000lOol;O0000`00O01l0003O0000`00O01l0003
O0000`00O01l0004O01jOol60n0@01l00`0001l07`0201l00`0001l07`0901lOOol003eoo`Ul0003
001l07`000Al0003001l07`000Al008000Al07Moo`T3h1007`0300007`0O00<000/07amoo`00?Goo
27`000<007`0O0000g`00`0027`000<007`0O0000W`0Lgoo30?P400O00<0000O01l03P0O7goo000n
Ool6O0000`00O01l000@O0000`00O01l0002O01_Ool<0n0COol00`00Oomoo`0]Ool003moo`El0003
001l07`0015l008000Al06]oo``3h1Eoo`03001oogoo02eoo`00?goo17`000<007`0O00057`000<0
07`0O0000W`0Igoo30?P67oo00<007ooOol0;Goo0011Ool00g`0001l000CO00017ooO01l07`00P00
17`0HWoo30?P6goo00<007ooOol0;Goo0011Ool00`00O01l000BO003Ool4O0000`00O01l0002O000
0`00Oomoo`1KOol<0n0NOol00`00Oomoo`0]Ool0045oo`03001oogoo011l00Moo`=l0005001l07`0
O000001JOol=0n0POol00`00Oomoo`0]Ool0041oo`03001oogoo009oo`al00]oo`=l0080009l0003
001l07oo05Eoo``3h2=oo`03001oogoo02eoo`00?goo00<007ooOol01Woo27`03Woo0g`000<007`0
00000W`0DWoo30?P9Woo00<007ooOol0;Goo000oOol00`00Oomoo`0MOol3O0000`00O0000002O01>
Ool<0n0YOol00`00Oomoo`0]Ool003ioo`03001oogoo01eoo`@00003O000000000Al04Uoo``3h2ao
o`03001oogoo02eoo`00>Goo00D007ooOomoo`0002Aoo`@000Al04Eoo`d3h2ioo`03001oogoo02eo
o`00>Goo00@007ooOol002Ioo`Ul045oo``3h35oo`03001oogoo02eoo`00>Goo00@007ooOol002Mo
o`Ul03eoo``3h3Aoo`03001oogoo02eoo`00>Goo00<007oo0000:Woo27`0>Goo30?P=goo00<007oo
Ool0;Goo000hOol00`00Ool00003Ool2000TOol200000goo001l0007O00dOol<0n0jOol00`00Oomo
o`0]Ool003Qoo`80009oo`8002Qoo`03001oogoo00Ql031oo`d3h3aoo`03001oogoo02eoo`00>7oo
1000:Goo00<007oo00000Woo2G`0;7oo30?P?goo00<007ooOol0;Goo000hOol2000aOol9O00XOol<
0n0oOol01000Oomoo`000goo00<007ooOol0:Goo001]Ool8O00TOol<0n12Ool01000Oomoo`000Woo
00<007ooOol0:Woo000gOol2000eOol9O00OOol<0n16Ool00`00Ool00002Ool00`00Oomoo`0ZOol0
03Qoo`03001oogoo03Eoo`Ql01aoo``3h4Qoo`05001oo`00Ool0000]Ool003Qoo`03001oogoo03Io
o`Ul01Moo``3h4aoo`<002ioo`00=goo00<007oo0000>7oo2G`04goo30?PCgoo0`00;Woo000gOol0
1000Ool00000>Goo27`03goo30?PDgoo00<007ooOol0;Goo001eOol9O00:Ool=0n1HOol2000[Ool0
07Moo`Ql00Moo``3h5aoo`03001oogoo02Uoo`00N7oo2G`00Woo30?PGgoo00<007ooOol0:Goo001i
Ool7O00<0n1QOol00`00Ool0000ZOol007]oo`=l00/3h6Aoo`04001oo`00000YOol007aoo`9l00T3
h9=oo`00OWoo00=l00?P0n000`?PUWoo001oOol20n000g`0Oomoo`2FOol0081oo`03O01oogoo09Mo
o`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003o
OolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003o
OolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol00?mooa]oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {149, 0}} -> {-2.3376, -2.30003, 0.0308726, 
  0.0308726}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two body objects are defined for the slider-crank model. Inertia properties \
are defined for each moving body so that the dynamic reaction forces can be \
calculated. No local point definitions are made in the body objects. All \
necessary point coordinates in this model are given explicitly in the \
constraint functions. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the body objects for the slider-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(bd[2] = Body[crank = 2, Mass \[Rule] 200.0, Inertia \[Rule] 450.0]; 
    \)\), 
    \(\(bd[3] = Body[slider = 3, Mass \[Rule] 25.0, Inertia \[Rule] 0.02]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The body properties are incorporated into the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[crank], bd[slider]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four constraints are used to model the slider-crank mechanism. Two \
generalized coordinate constraints are used along with two standard \
constraints."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["GenRevolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint defines the symbol ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as the angular coordinate of the crank."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the rotation of the crank."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["GenTranslate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint defines the symbol ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as the displacement coordinate of the slider."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the connecting rod between the crank and the slider."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the slider-crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[1] = 
      GenRevolute2[1, Axis[crank, 0, X], Axis[ground, 0, X], {alpha, 0.0}]; 
    \)\), 
    \(\(cs[2] = RotationLock1[2, crank, 2\ N[\[Pi]]\ T]; \)\), 
    \(\(cs[3] = 
      GenTranslate2[3, Axis[slider, 0, X], Axis[ground, 0, X], {beta, 5.0}]; 
    \)\), 
    \(\(cs[4] = 
      RelativeDistance1[4, Point[crank, {2, 0}], Point[slider, 0], 3.5]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The constraints are incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 4]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Loads"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A force that is a linear function of slider position is applied to the \
slider to simulate a simple spring. The spring has a spring constant of 10, \
and it is placed so that the spring force is zero when the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " displacement of the slider is three units. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a spring force applied to the slider."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1] = Load[beta, \(-10\)\ \((beta - 3)\)]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1 with the ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to cause the Lagrange multipliers to be calculated."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.1, Solution \[Rule] Static]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        \(alpha \[Rule] 0.628318530717958623`\), ",", 
        \(beta \[Rule] 4.91470412522850441`\), ",", 
        \(Lmb1 \[Rule] 33.5561585343974844`\), ",", 
        \(Lmb2 \[Rule] \(-2.90399713341312004`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Reactions"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because generalized coordinates were used in this model, Mech's ability to \
find constraint reaction forces is limited. Normally, ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " could be used to find the reaction force vector that the revolute joint \
applies to the crank, but with this model only the moment applied to the \
crank by constraint 2 can be found. Note that ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cannot directly find the moment applied to body 2, it can only find the \
generalized force associated with the symbol ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Since ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an angular coordinate, its associated load is a moment. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the moment applied to the crank by the driving constraint."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[2, alpha] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-33.5561585343974844`\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Of course constraint 4, the ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, applies an equal and opposite moment to the crank. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the moment applied to the crank by the connecting rod."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Reaction[4, alpha]\), 
    \(% /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-Lmb2\)\ 
      \((8\ Cos[alpha]\ Sin[alpha] - 
          4\ \((\(-beta\) + 2\ Cos[alpha])\)\ Sin[alpha])\)\)], "Output"],

Cell[BoxData[
    \(33.5561585343974844`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Constraint 4 also applies a reaction force to the slider. Again, the \
restraining force and torque that would be applied to the slider by a normal \
",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint cannot be found. Only the generalized force associated with ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be found, which is the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction force on the slider."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the force applied to the slider by the connecting rod."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[4, beta] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(19.1470412522850423`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here are the external loads applied to the coordinates ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Loads[All]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, \(-10\)\ \((\(-3\) + beta)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The Generalized Coordinate Package automatically converts the inertia \
terms into the proper coordinate system so that the dynamic reaction forces \
may be calculated. The ",
  StyleBox["Solution->Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to include the inertial loads and calculate the reaction forces."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of the torque required to drive the crank through a full \
cycle."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{alpha, Reaction[2, alpha]} /. 
        SolveMech[{0, 1}, 41, Solution \[Rule] Dynamic], 
      PlotJoined \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.151576 0.309017 8.20156e-005 [
[.17539 .29652 -3 -9 ]
[.17539 .29652 3 0 ]
[.32696 .29652 -3 -9 ]
[.32696 .29652 3 0 ]
[.47854 .29652 -3 -9 ]
[.47854 .29652 3 0 ]
[.63011 .29652 -3 -9 ]
[.63011 .29652 3 0 ]
[.78169 .29652 -3 -9 ]
[.78169 .29652 3 0 ]
[.93327 .29652 -3 -9 ]
[.93327 .29652 3 0 ]
[.01131 .06297 -30 -4.5 ]
[.01131 .06297 0 4.5 ]
[.01131 .14499 -30 -4.5 ]
[.01131 .14499 0 4.5 ]
[.01131 .227 -30 -4.5 ]
[.01131 .227 0 4.5 ]
[.01131 .39103 -24 -4.5 ]
[.01131 .39103 0 4.5 ]
[.01131 .47305 -24 -4.5 ]
[.01131 .47305 0 4.5 ]
[.01131 .55506 -24 -4.5 ]
[.01131 .55506 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.17539 .30902 m
.17539 .31527 L
s
[(1)] .17539 .29652 0 1 Mshowa
.32696 .30902 m
.32696 .31527 L
s
[(2)] .32696 .29652 0 1 Mshowa
.47854 .30902 m
.47854 .31527 L
s
[(3)] .47854 .29652 0 1 Mshowa
.63011 .30902 m
.63011 .31527 L
s
[(4)] .63011 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(5)] .78169 .29652 0 1 Mshowa
.93327 .30902 m
.93327 .31527 L
s
[(6)] .93327 .29652 0 1 Mshowa
.125 Mabswid
.05412 .30902 m
.05412 .31277 L
s
.08444 .30902 m
.08444 .31277 L
s
.11476 .30902 m
.11476 .31277 L
s
.14507 .30902 m
.14507 .31277 L
s
.2057 .30902 m
.2057 .31277 L
s
.23602 .30902 m
.23602 .31277 L
s
.26633 .30902 m
.26633 .31277 L
s
.29665 .30902 m
.29665 .31277 L
s
.35728 .30902 m
.35728 .31277 L
s
.38759 .30902 m
.38759 .31277 L
s
.41791 .30902 m
.41791 .31277 L
s
.44822 .30902 m
.44822 .31277 L
s
.50885 .30902 m
.50885 .31277 L
s
.53917 .30902 m
.53917 .31277 L
s
.56948 .30902 m
.56948 .31277 L
s
.5998 .30902 m
.5998 .31277 L
s
.66043 .30902 m
.66043 .31277 L
s
.69074 .30902 m
.69074 .31277 L
s
.72106 .30902 m
.72106 .31277 L
s
.75137 .30902 m
.75137 .31277 L
s
.81201 .30902 m
.81201 .31277 L
s
.84232 .30902 m
.84232 .31277 L
s
.87264 .30902 m
.87264 .31277 L
s
.90295 .30902 m
.90295 .31277 L
s
.96358 .30902 m
.96358 .31277 L
s
.9939 .30902 m
.9939 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .06297 m
.03006 .06297 L
s
[(-3000)] .01131 .06297 1 0 Mshowa
.02381 .14499 m
.03006 .14499 L
s
[(-2000)] .01131 .14499 1 0 Mshowa
.02381 .227 m
.03006 .227 L
s
[(-1000)] .01131 .227 1 0 Mshowa
.02381 .39103 m
.03006 .39103 L
s
[(1000)] .01131 .39103 1 0 Mshowa
.02381 .47305 m
.03006 .47305 L
s
[(2000)] .01131 .47305 1 0 Mshowa
.02381 .55506 m
.03006 .55506 L
s
[(3000)] .01131 .55506 1 0 Mshowa
.125 Mabswid
.02381 .07937 m
.02756 .07937 L
s
.02381 .09578 m
.02756 .09578 L
s
.02381 .11218 m
.02756 .11218 L
s
.02381 .12858 m
.02756 .12858 L
s
.02381 .16139 m
.02756 .16139 L
s
.02381 .17779 m
.02756 .17779 L
s
.02381 .1942 m
.02756 .1942 L
s
.02381 .2106 m
.02756 .2106 L
s
.02381 .2434 m
.02756 .2434 L
s
.02381 .25981 m
.02756 .25981 L
s
.02381 .27621 m
.02756 .27621 L
s
.02381 .29261 m
.02756 .29261 L
s
.02381 .32542 m
.02756 .32542 L
s
.02381 .34182 m
.02756 .34182 L
s
.02381 .35823 m
.02756 .35823 L
s
.02381 .37463 m
.02756 .37463 L
s
.02381 .40744 m
.02756 .40744 L
s
.02381 .42384 m
.02756 .42384 L
s
.02381 .44024 m
.02756 .44024 L
s
.02381 .45665 m
.02756 .45665 L
s
.02381 .48945 m
.02756 .48945 L
s
.02381 .50585 m
.02756 .50585 L
s
.02381 .52226 m
.02756 .52226 L
s
.02381 .53866 m
.02756 .53866 L
s
.02381 .04657 m
.02756 .04657 L
s
.02381 .03016 m
.02756 .03016 L
s
.02381 .01376 m
.02756 .01376 L
s
.02381 .57147 m
.02756 .57147 L
s
.02381 .58787 m
.02756 .58787 L
s
.02381 .60427 m
.02756 .60427 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.04762 .43006 L
.07143 .53043 L
.09524 .59226 L
.11905 .60332 L
.14286 .55984 L
.16667 .4689 L
.19048 .34918 L
.21429 .22803 L
.2381 .13357 L
.2619 .08377 L
.28571 .07954 L
.30952 .10743 L
.33333 .14944 L
.35714 .1917 L
.38095 .22721 L
.40476 .25433 L
.42857 .27411 L
.45238 .28853 L
.47619 .29958 L
.5 .30902 L
.52381 .31845 L
.54762 .3295 L
.57143 .34392 L
.59524 .36371 L
.61905 .39082 L
.64286 .42634 L
.66667 .4686 L
.69048 .51061 L
.71429 .53849 L
.7381 .53426 L
.7619 .48446 L
.78571 .39 L
.80952 .26886 L
.83333 .14913 L
.85714 .0582 L
.88095 .01472 L
.90476 .02577 L
.92857 .0876 L
.95238 .18797 L
.97619 .30902 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00
8Goo00<007ooOol0mGoo000QOol00`00Oomoo`3eOol0025oo`03001oogoo0?Eoo`008Goo0P00mWoo
000QOol00`00Oomoo`3EOol2000NOol0025oo`03001oogoo0=Aoo`03001oogoo00<001]oo`008Goo
00<007ooOol0e7oo00<007ooOol00goo0P006Goo000QOol2003DOol00`00Oomoo`05Ool00`00Oomo
o`0GOol0025oo`03001oogoo0==oo`03001oogoo00Ioo`03001oogoo01Ioo`008Goo00<007ooOol0
dWoo00<007ooOol01goo00<007ooOol05Woo000QOol00`00Oomoo`3BOol00`00Oomoo`07Ool00`00
Oomoo`0FOol0025oo`03001oogoo0=5oo`03001oogoo00Uoo`03001oogoo01Eoo`008Goo0P00dWoo
00<007ooOol02Goo00<007ooOol05Goo000QOol00`00Oomoo`3@Ool00`00Oomoo`0;Ool00`00Oomo
o`0DOol000]oo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
0=1oo`03001oogoo00]oo`03001oogoo01Aoo`003Goo00H007ooOol007oo0002Ool00`00Ool00002
Ool00`00Ool00004Ool00`00Oomoo`3?Ool00`00Oomoo`0<Ool00`00Oomoo`0DOol000Ioo`<000=o
o`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo000017oo0P00d7oo00<007ooOol0
3Goo00<007ooOol04goo000=Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oo`0000Ao
o`03001oogoo0<ioo`03001oogoo00ioo`03001oogoo01=oo`002goo00<007oo00000Woo00<007oo
00000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol0cWoo00<007ooOol03Woo00<007oo
Ool04goo000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`3>Ool00`00Oomoo`0?Ool00`00Oomoo`0BOol0025oo`8003ioo`<008ioo`03001oogoo
00moo`03001oogoo019oo`008Goo00<007ooOol0>Goo10000goo00<007ooOol0RWoo00<007ooOol0
4Goo00<007ooOol04Goo000QOol00`00Oomoo`0iOol00`00Oomoo`05Ool00`00Oomoo`29Ool00`00
Oomoo`0AOol00`00Oomoo`0AOol0025oo`03001oogoo03Qoo`03001oogoo00Moo`03001oogoo08Qo
o`03001oogoo015oo`03001oogoo015oo`008Goo0P00>Goo00<007ooOol01goo00<007ooOol0R7oo
00<007ooOol04Goo00<007ooOol04Goo000QOol00`00Oomoo`0gOol00`00Oomoo`09Ool00`00Oomo
o`26Ool00`00Oomoo`0COol00`00Oomoo`0@Ool0025oo`03001oogoo03Moo`03001oogoo00Yoo`03
001oogoo08Eoo`03001oogoo01=oo`03001oogoo011oo`008Goo00<007ooOol0=Woo00<007ooOol0
37oo00<007ooOol0Q7oo00<007ooOol04goo00<007ooOol047oo000QOol2000gOol00`00Oomoo`0=
Ool00`00Oomoo`23Ool00`00Oomoo`0COol00`00Oomoo`0@Ool0025oo`03001oogoo03Eoo`03001o
ogoo00ioo`03001oogoo089oo`03001oogoo01Eoo`03001oogoo00moo`008Goo00<007ooOol0=Goo
00<007ooOol03goo00<007ooOol0PGoo00<007ooOol05Goo00<007ooOol03goo000QOol00`00Oomo
o`0dOol00`00Oomoo`0@Ool00`00Oomoo`21Ool00`00Oomoo`0EOol00`00Oomoo`0?Ool0025oo`80
03Eoo`03001oogoo015oo`03001oogoo081oo`03001oogoo01Eoo`03001oogoo00moo`008Goo00<0
07ooOol0<goo00<007ooOol04Woo00<007ooOol0Ogoo00<007ooOol05goo00<007ooOol03Woo000Q
Ool00`00Oomoo`0cOol00`00Oomoo`0COol00`00Oomoo`1nOol00`00Oomoo`0GOol00`00Oomoo`0>
Ool000]oo`<000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03=o
o`03001oogoo01=oo`03001oogoo07ioo`03001oogoo01Moo`03001oogoo00ioo`002goo00<007oo
Ool00Woo00<007oo00000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol0<Woo00<007oo
Ool05Goo00<007ooOol0OGoo00<007ooOol05goo00<007ooOol03Woo0006Ool30003Ool01`00Oomo
ogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`8003=oo`03001oogoo01Eoo`03001o
ogoo07aoo`03001oogoo01Uoo`03001oogoo00eoo`0037oo00L007ooOomoo`00Ool00002Ool00`00
Ool00002Ool00`00Ool00004Ool00`00Oomoo`0bOol00`00Oomoo`0FOol00`00Oomoo`1kOol00`00
Oomoo`0IOol00`00Oomoo`0=Ool000]oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009o
o`03001oo`0000Aoo`03001oogoo039oo`03001oogoo01Moo`03001oogoo07Yoo`03001oogoo01Uo
o`03001oogoo00eoo`0037oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0<Goo00<007ooOol067oo00<007ooOol0NWoo00<007ooOol06Goo00<007oo
Ool03Goo000QOol2000bOol00`00Oomoo`0IOol00`00Oomoo`1hOol00`00Oomoo`0KOol00`00Oomo
o`0<Ool0025oo`03001oogoo035oo`03001oogoo01Uoo`03001oogoo07Qoo`03001oogoo01]oo`03
001oogoo00aoo`008Goo00<007ooOol0<Goo00<007ooOol06Woo00<007ooOol0Mgoo00<007ooOol0
6goo00<007ooOol037oo000QOol00`00Oomoo`0`Ool00`00Oomoo`0LOol00`00Oomoo`1fOol00`00
Oomoo`0KOol00`00Oomoo`0<Ool0025oo`80035oo`03001oogoo01aoo`03001oogoo07Ioo`03001o
ogoo01aoo`03001oogoo00]oo`008Goo00<007ooOol0<7oo00<007ooOol07Goo00<007ooOol0M7oo
00<007ooOol07Goo00<007ooOol02goo000QOol00`00Oomoo`0`Ool00`00Oomoo`0MOol00`00Oomo
o`1dOol00`00Oomoo`0MOol00`00Oomoo`0;Ool0025oo`03001oogoo02moo`03001oogoo01moo`03
001oogoo07=oo`03001oogoo01eoo`03001oogoo00]oo`008Goo0P00<7oo00<007ooOol087oo00<0
07ooOol0LWoo00<007ooOol07Goo00<007ooOol02goo000QOol00`00Oomoo`0_Ool00`00Oomoo`0P
Ool00`00Oomoo`1bOol00`00Oomoo`0NOol00`00Oomoo`0:Ool0025oo`03001oogoo02moo`03001o
ogoo025oo`03001oogoo071oo`03001oogoo01moo`03001oogoo00Yoo`008Goo00<007ooOol0;Woo
00<007ooOol08goo00<007ooOol0Kgoo00<007ooOol07goo00<007ooOol02Woo000QOol2000_Ool0
0`00Oomoo`0SOol00`00Oomoo`1_Ool00`00Oomoo`0OOol00`00Oomoo`0:Ool0025oo`03001oogoo
02ioo`03001oogoo02Aoo`03001oogoo06ioo`03001oogoo01moo`03001oogoo00Yoo`002Woo1@00
0Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0;Woo00<007ooOol0
9Goo00<007ooOol0KGoo00<007ooOol087oo00<007ooOol02Goo000<Ool01`00Oomoogoo001oo`00
009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo02eoo`03001oogoo02Ioo`03001oogoo
06aoo`03001oogoo025oo`03001oogoo00Uoo`001Woo0`000goo00L007ooOomoo`00Ool00002Ool0
0`00Ool00002Ool00`00Ool00004Ool2000^Ool00`00Oomoo`0WOol00`00Oomoo`1[Ool00`00Oomo
o`0QOol00`00Oomoo`09Ool000aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo
000017oo00<007ooOol0;Goo00<007ooOol0:7oo00<007ooOol0JWoo00<007ooOol08Goo00<007oo
Ool02Goo000<Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03001o
ogoo02eoo`03001oogoo02Uoo`03001oogoo06Uoo`03001oogoo025oo`03001oogoo00Uoo`002goo
0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0;Goo00<007oo
Ool0:Woo00<007ooOol0J7oo00<007ooOol08Woo00<007ooOol027oo000QOol2000]Ool00`00Oomo
o`0[Ool00`00Oomoo`1WOol00`00Oomoo`0SOol00`00Oomoo`08Ool0025oo`03001oogoo02aoo`03
001oogoo02aoo`03001oogoo06Ioo`03001oogoo02=oo`03001oogoo00Qoo`008Goo00<007ooOol0
;7oo00<007ooOol0;Goo00<007ooOol0IGoo00<007ooOol08goo00<007ooOol027oo000QOol00`00
Oomoo`0/Ool00`00Oomoo`0^Ool00`00Oomoo`1TOol00`00Oomoo`0SOol00`00Oomoo`08Ool0025o
o`03001oogoo02aoo`03001oogoo02moo`03001oogoo06=oo`03001oogoo02=oo`03001oogoo00Qo
o`008Goo0P00;7oo00<007ooOol0<Goo00<007ooOol0HGoo00<007ooOol09Goo00<007ooOol01goo
000QOol00`00Oomoo`0POol50006Ool00`00Oomoo`0JOol3000EOol2000<Ool2000UOol3000TOol0
0`00Oomoo`04Ool00`00Oomoo`0KOol20008Ool00`00Oomoo`07Ool0025oo`03001oogoo029oo`03
001oogoo00Ioo`03001oogoo01Yoo`03001oogoo01Moo`03001oogoo00]oo`03001oogoo02=oo`03
001oogoo029oo`03001oo`0000Eoo`03001oogoo01]oo`03001oo`0000Moo`03001oogoo00Moo`00
8Goo00<007ooOol08Woo00<007ooOol01Woo00<007ooOol06goo00<007ooOol05goo00<007ooOol0
2Goo00<007ooOol08Woo10009Goo00<007ooOol00goo00<007ooOol06goo00<007oo00001goo00<0
07ooOol01goo000QOol2000SOol00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`0HOol2000:
Ool00`00Oomoo`0QOol00`00Ool0000TOol20006Ool00`00Oomoo`0KOol20008Ool00`00Oomoo`07
Ool0025oo`03001oogoo029oo`03001oogoo00Eoo`03001oogoo01]oo`03001oo`0001]oo`03001o
ogoo00Eoo`03001oo`0002Aoo`8002Aoo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo00Qo
o`03001oogoo00Ioo`008Goo00<007ooOol08Goo0P001goo00<007ooOol077oo00<007ooOol06goo
0P001Woo00<007ooOol097oo00<007ooOol08Woo0`0017oo00<007ooOol07Goo0P0027oo00<007oo
Ool01Woo000QOol00`00Oomoo`0ZOol00`00Oomoo`0lOol00`00Oomoo`1FOol00`00Oomoo`0WOol0
0`00Oomoo`06Ool0025oo`8002]oo`03001oogoo03eoo`8005Ioo`03001oogoo02Moo`03001oogoo
00Ioo`008Goo00<007ooOol0:Woo00<007ooOol0?goo0P00E7oo00<007ooOol09goo00<007ooOol0
1Woo000QOol00`00Oomoo`0YOol00`00Oomoo`12Ool3001@Ool00`00Oomoo`0YOol00`00Oomoo`05
Ool0025oo`03001oogoo02Uoo`03001oogoo04Eoo`<004eoo`03001oogoo02Uoo`03001oogoo00Eo
o`006goooP00000QOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Ool00006Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool30005Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol01Goo0@000Goo0Goo000QOol00`00Oomoo`0SOol0
0`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`0TOol00`00Oomoo`07Ool2000JOol00`00Oomo
o`0SOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool0025oo`8002Uoo`03001oogoo
055oo`80049oo`03001oogoo039oo`008Goo0P00:Goo00<007ooOol0Dgoo0P00@7oo00<007ooOol0
<Woo000QOol2000YOol00`00Oomoo`1EOol2000nOol00`00Oomoo`0bOol0025oo`8002Uoo`03001o
ogoo05Moo`8003aoo`03001oogoo039oo`008Goo0P00:Goo00<007ooOol0FGoo00<007ooOol0>Goo
00<007ooOol0<Woo000QOol3000WOol00`00Oomoo`1KOol2000hOol00`00Oomoo`0cOol0025oo`03
001oo`0002Moo`03001oogoo05eoo`03001oogoo03Eoo`03001oogoo03=oo`008Goo00<007oo0000
9goo00<007ooOol0GWoo00<007ooOol0=7oo00<007ooOol0<goo000QOol00`00Ool0000WOol00`00
Oomoo`1OOol00`00Oomoo`0cOol00`00Oomoo`0cOol0025oo`<002Moo`03001oogoo061oo`8003=o
o`03001oogoo03=oo`008Goo00@007ooOol002Eoo`03001oogoo06=oo`03001oogoo02moo`03001o
ogoo03Aoo`008Goo00@007ooOol002Eoo`03001oogoo06Aoo`03001oogoo02ioo`03001oogoo03Ao
o`008Goo00@007ooOol002Eoo`03001oogoo06Eoo`03001oogoo02eoo`03001oogoo03Aoo`008Goo
00@007ooOol002Eoo`03001oogoo06Ioo`03001oogoo02aoo`03001oogoo03Aoo`008Goo0P0000=o
o`00Ool097oo00<007ooOol0Igoo00<007ooOol0:goo00<007ooOol0=7oo000QOol01000Oomoo`00
97oo00<007ooOol0J7oo00<007ooOol0:Woo00<007ooOol0=Goo000:Ool50002Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo00008goo00<007ooOol0JGoo00<007oo
Ool0:Goo00<007ooOol0=Goo000<Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001o
o`0000Aoo`05001oogooOol0000SOol00`00Oomoo`1ZOol00`00Oomoo`0XOol00`00Oomoo`0eOol0
00aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo000017oo0P000Woo00<007oo
Ool08Goo00<007ooOol0Jgoo00<007ooOol09goo00<007ooOol0=Goo000<Ool01`00Oomoogoo001o
o`00009oo`03001oo`00009oo`03001oo`0000Aoo`05001oogooOol0000SOol00`00Oomoo`1/Ool0
0`00Oomoo`0UOol00`00Oomoo`0fOol000aoo`07001oogooOol007oo00000Woo00<007oo00000Woo
00<007oo000017oo00D007ooOomoo`00029oo`03001oogoo06eoo`03001oogoo02Eoo`03001oogoo
03Ioo`002goo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol07goo00<007ooOol0KWoo00<007ooOol097oo00<007ooOol0=Woo000QOol20003
Ool00`00Oomoo`0OOol00`00Oomoo`1_Ool00`00Oomoo`0SOol00`00Oomoo`0fOol0025oo`03001o
ogoo009oo`03001oogoo01moo`03001oogoo06moo`03001oogoo029oo`03001oogoo03Moo`008Goo
00<007ooOol00Woo00<007ooOol07goo00<007ooOol0L7oo00<007ooOol08Goo00<007ooOol0=goo
000QOol00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`1bOol00`00Oomoo`0POol00`00Oomo
o`0gOol0025oo`8000Aoo`03001oogoo01eoo`03001oogoo079oo`03001oogoo021oo`03001oogoo
03Moo`008Goo00<007ooOol00goo00<007ooOol07Goo00<007ooOol0Lgoo00<007ooOol07Woo00<0
07ooOol0>7oo000QOol00`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`1dOol00`00Oomoo`0M
Ool00`00Oomoo`0hOol0025oo`03001oogoo00=oo`03001oogoo01eoo`03001oogoo07Aoo`03001o
ogoo01eoo`03001oogoo03Qoo`008Goo0P0017oo00<007ooOol077oo00<007ooOol0MWoo00<007oo
Ool077oo00<007ooOol0>7oo000QOol00`00Oomoo`04Ool00`00Oomoo`0KOol00`00Oomoo`1fOol0
0`00Oomoo`0KOol00`00Oomoo`0iOol0025oo`03001oogoo00Aoo`03001oogoo01]oo`03001oogoo
07Moo`03001oogoo01Yoo`03001oogoo03Uoo`008Goo00<007ooOol017oo00<007ooOol06goo00<0
07ooOol0N7oo00<007ooOol06Goo00<007ooOol0>Goo000QOol20005Ool00`00Oomoo`0KOol00`00
Oomoo`1hOol00`00Oomoo`0IOol00`00Oomoo`0iOol0025oo`03001oogoo00Eoo`03001oogoo01Uo
o`03001oogoo07Yoo`03001oogoo01Moo`03001oogoo03Yoo`002goo0`000goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol06Goo00<007ooOol0NWoo
00<007ooOol05goo00<007ooOol0>Woo000;Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00004Ool00`00Oomoo`05Ool00`00Oomoo`0IOol00`00Oomoo`1kOol00`00Oomo
o`0FOol00`00Oomoo`0jOol000aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo
000017oo0P001Woo00<007ooOol06Goo00<007ooOol0O7oo00<007ooOol05Goo00<007ooOol0>Woo
000<Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00Io
o`03001oogoo01Moo`03001oogoo07eoo`03001oogoo01Aoo`03001oogoo03]oo`002goo00<007oo
00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo000017oo00<007ooOol01Woo00<007oo
Ool05goo00<007ooOol0OWoo00<007ooOol04goo00<007ooOol0>goo000<Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0GOol0
0`00Oomoo`1nOol00`00Oomoo`0COol00`00Oomoo`0kOol0025oo`03001oogoo00Ioo`03001oogoo
01Moo`03001oogoo07moo`03001oogoo019oo`03001oogoo03]oo`008Goo0P0027oo00<007ooOol0
5Goo00<007ooOol0P7oo00<007ooOol04Goo00<007ooOol0?7oo000QOol00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`21Ool00`00Oomoo`0@Ool00`00Oomoo`0lOol0025oo`03001oogoo00Mo
o`03001oogoo01Eoo`03001oogoo085oo`03001oogoo00moo`03001oogoo03eoo`008Goo00<007oo
Ool01goo00<007ooOol05Goo00<007ooOol0PWoo00<007ooOol03Woo00<007ooOol0?Goo000QOol2
0009Ool00`00Oomoo`0COol00`00Oomoo`23Ool00`00Oomoo`0=Ool00`00Oomoo`0nOol0025oo`03
001oogoo00Qoo`03001oogoo01=oo`03001oogoo08Aoo`03001oogoo00aoo`03001oogoo03ioo`00
8Goo00<007ooOol027oo00<007ooOol04goo00<007ooOol0QGoo00<007ooOol02Woo00<007ooOol0
?goo000QOol00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`26Ool00`00Oomoo`09Ool00`00
Oomoo`0oOol0025oo`8000Yoo`03001oogoo015oo`03001oogoo08Qoo`03001oogoo00Moo`03001o
ogoo041oo`008Goo00<007ooOol02Goo00<007ooOol04Goo00<007ooOol0R7oo00<007ooOol01goo
00<007ooOol0@7oo000QOol00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`29Ool00`00Oomo
o`05Ool00`00Oomoo`11Ool0025oo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo08Yoo`03
001oogoo009oo`<004=oo`008Goo0P002goo00<007ooOol03goo00<007ooOol0S7oo1000AWoo000Q
Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool00`00Oomoo`3FOol000]oo`8000Aoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00moo`03001oogoo0=Io
o`003Goo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0;Ool0
0`00Oomoo`0>Ool00`00Oomoo`3FOol000aoo`07001oogooOol007oo00000Woo00<007oo00000Woo
00<007oo000017oo0P0037oo00<007ooOol03Goo00<007ooOol0egoo000=Ool01P00Oomoo`00Ool0
009oo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo
0=Moo`002goo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo000017oo00<0
07ooOol037oo00<007ooOol02goo00<007ooOol0f7oo000<Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`3H
Ool0025oo`8000ioo`03001oogoo00Uoo`03001oogoo0=Uoo`008Goo00<007ooOol03Goo00<007oo
Ool02Goo00<007ooOol0fGoo000QOol00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`3JOol0
025oo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo0=Yoo`008Goo00<007ooOol03Woo00<0
07ooOol01Woo00<007ooOol0fgoo000QOol2000@Ool00`00Oomoo`05Ool00`00Oomoo`3KOol0025o
o`03001oogoo00moo`8000Eoo`03001oogoo0=aoo`008Goo00<007ooOol04Goo0`000Woo00<007oo
Ool0g7oo000QOol00`00Oomoo`0DOol2003OOol0025oo`800?Ioo`008Goo00<007ooOol0mGoo000Q
Ool00`00Oomoo`3eOol0025oo`03001oogoo0?Eoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo
6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00001\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-0.865232, -4171.06, 0.0260912, 
  48.2201}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the graphics function that generates the image of the \
slider-crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
graph:=Graphics[
 {Thickness[.01],
  Line[{{1, -2.2}, {0, 0}, {-1, -2.2}, {5.5, -2.2},
    {5.5, -.25}, {1.5, -.25}}],
  {Thickness[.02], RGBColor[1, 0, 0],
   Disk[{0, 0}, .5], Edge[crank, {0, {2, 0}}]},
  {RGBColor[0, 1, 0], Thickness[.015],
   Edge[{Point[crank, {2, 0}], Point[slider, 0]}]},
  {RGBColor[0, 0, 1],
   Box[slider, {{-.5, -.25}, {.5, .25}}]},
  PointSize[.02],
  Point[Location[slider, 0]], Point[{0,0}],
  Thickness[.002], LocalAxes[{crank, slider}, 1]},
  AspectRatio->Automatic,
  PlotRange->{{-2.3,6.3},{-2.3,2.3}}]\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the slider-crank at T = 0.35."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[graph /. SolveMech[.35]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53488 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.267442 0.116279 0.267442 0.116279 [
[ 0 0 0 0 ]
[ 1 .53488 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .53488 L
0 .53488 L
closepath
clip
newpath
0 g
.01 w
.38372 .01163 m
.26744 .26744 L
.15116 .01163 L
.90698 .01163 L
.90698 .23837 L
.44186 .23837 L
s
1 0 0 r
.26744 .26744 m
.26744 .26744 .05814 0 365.73 arc
F
.02 w
.26744 .26744 m
.13075 .45559 L
s
0 1 0 r
.015 w
.13075 .45559 m
.49162 .26744 L
s
0 0 1 r
.43348 .23837 m
.54976 .23837 L
.54976 .29651 L
.43348 .29651 L
F
0 g
.02 w
.49162 .26744 Mdot
.26744 .26744 Mdot
gsave
.19909 .36151 -74.9284 -10.0067 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.17337 .19909 -74.9284 -10.0067 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.26744 .26744 -74.9284 -10.0067 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.002 w
.19909 .36151 m
.26744 .26744 L
.17337 .19909 L
s
.22217 .34953 m
.19909 .36151 L
.20336 .33586 L
s
.19902 .20336 m
.17337 .19909 L
.18535 .22217 L
s
gsave
.6079 .26744 -58.75 -4.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.49162 .38372 -58.75 -4.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.49162 .26744 -58.75 -4.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.6079 .26744 m
.49162 .26744 L
.49162 .38372 L
s
.58465 .25581 m
.6079 .26744 L
.58465 .27907 L
s
.48 .36047 m
.49162 .38372 L
.50325 .36047 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 150},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000UQ000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00:Woo00<007ooOol0?Woo00<007ooOol0Zgoo000YOooE000KOol002UoomD001]o
o`00:goo00<007ooOol0?7oo00<007ooOol0Sgoo0P006goo000[Ool2000lOol2002AOol2000KOol0
02aoo`03001oogoo03Yoo`03001oogoo091oo`8001]oo`00;7oo0P00>goo00<007ooOol0T7oo0P00
6goo000]Ool00`00Oomoo`0hOol2002BOol2000KOol002eoo`03001oogoo03Qoo`03001oogoo095o
o`8001]oo`00;Goo0P00>7oo0P00Tgoo0P006goo000^Ool00`00Oomoo`0fOol00`00Oomoo`2BOol2
000KOol002ioo`8003Ioo`8009Aoo`8001]oo`00;goo00<007ooOol0=7oo00<007ooOol0Tgoo0P00
6goo000_Ool2000dOol2002EOol2000KOol0031oo`03001oogoo039oo`03001oogoo09Aoo`8001]o
o`00<7oo0P00<Woo0P00UWoo0P006goo000aOol00`00Oomoo`0`Ool00`00Oomoo`2EOol2000KOol0
035oo`80035oo`03001oogoo09Eoo`8001]oo`00<Woo00<007ooOol0;Woo0P00Ugoo0P006goo000b
Ool2000_Ool00`00Oomoo`2FOol2000KOol003=oo`03001oogoo02aoo`8009Qoo`8001]oo`00<goo
0P00;Goo00<007ooOol0Ugoo0P006goo000dOol00`00Oomoo`0ZOol2002IOol2000KOol003Aoo`03
001oogoo02Yoo`03001oogoo09Qoo`8001]oo`00=7oo0P00:Woo0P00VWoo0P006goo000eOol00`00
Oomoo`0XOol00`00Oomoo`2IOol2000KOol003Eoo`8002Uoo`03001oogoo09Uoo`8001]oo`00=Woo
00<007ooOol09Woo0P00Vgoo0P006goo000fOol2000WOol00`00Oomoo`2JOol2000KOol003Moo`03
001oogoo02Aoo`8009aoo`8001]oo`00=goo0P009Goo00<007ooOol0Vgoo0P006goo000hOol00`00
Oomoo`0ROol2002MOol2000KOol003Qoo`8002=oo`03001oogoo09aoo`8001]oo`00>Goo00<007oo
Ool087oo0P00WWoo0P006goo000iOol2000QOol00`00Oomoo`2MOol2000KOol003Yoo`03001oogoo
01ioo`8009moo`8001]oo`00>Woo00<007ooOol07Woo00<007ooOol0WWoo0P006goo000jOol2000O
Ool00`00Oomoo`2NOol2000KOol003]oo`03001oogoo01aoo`800:1oo`8001]oo`00>goo0P007Goo
00<007ooOol0Wgoo0P006goo000lOol00`00Oomoo`0JOol2002QOol2000KOol003aoo`8001]oo`03
001oogoo0:1oo`8001]oo`00?Goo00<007ooOol067oo0P00XWoo0P006goo000mOol2000IOol00`00
Oomoo`2QOol2000KOol003ioo`03001oogoo01Ioo`800:=oo`8001]oo`00?Woo0P005goo00<007oo
Ool0XWoo0P006goo000oOol00`00Oomoo`0DOol2002TOol2000KOol003moo`8001Eoo`03001oogoo
0:=oo`8001]oo`00@7oo00<007ooOol04goo00<007ooOol0Xgoo0P006goo0010Ool2000COol2002U
Ool2000KOol0045oo`03001oogoo015oo`03001oogoo0:Aoo`8001]oo`009Woo0P006Goo00<007oo
Ool047oo0P00YWoo0P006goo000WOol00`00Oomoo`0GOol2000AOol00`00Oomoo`2UOol2000KOol0
02Moo`03001oogoo00Moo`@000eoo`03001oogoo00ioo`800:Moo`8001]oo`009Woo00<007oo0000
27oo0`0000=oo`0000000P002Goo0P003goo00<007ooOol0YWoo0P006goo000VOol01000Ool00000
27oo00<007oo00003Woo00<007ooOol037oo0P00Z7oo0P006goo000bOol01000Oomoo`003Goo0P00
3Goo00<007ooOol0Ygoo0P006goo000cOol00`00Oomoo`02000<Ool00`00Ooml000:O0000goo001o
o`2XOol2000KOol003=oo`03001oogoo009oo`03001oogoo00Qoo`ml0003001oogoo0:Moo`8001]o
o`00=7oo00<007ooOol00Woo00<007ooOol01Woo4g`0Ygoo0P006goo000jOol20004OolFO02VOol2
000KOol003aoo`03001oogoo01Ql0:Eoo`8001]oo`00?Goo00<007`0O0005g`0YGoo0P006goo000n
Ool2000HO02TOol2000KOol003eoo`=l0003001l07`001Il025ooh@001]oo`00?7oo1G`00P005g`0
7goo800OI@006goo000lOol7O0000`00O01l000DO00OOolP01n0Ool003aoo`Ql0003001l07`001=l
01moob007h1oo`00>goo2W`00P0057`07Woo800OP7oo000kOol<O0000`00O01l000AO00NOolP01l:
Ool2001dOol003]oo`el0003001l07`0011l01ioob007`aoo`80079oo`00>goo3W`00P0047`07Woo
3`0O0P003`0O3Woo0P00L7oo000kOol5O0030005O004000?O00NOol>01lT001^Ool003]oo`El0080
00Il00@000ml01ioo`h07`@000h07`ioo`80071oo`00>goo1g`000<007`0O00017`00P0047`07Woo
3`0O0P003`0O37oo0P00LWoo000kOol7O0000`00O01l0004O0000`00O01l000?O00NOol@01l00`00
01l07`0=01l:Ool2001dOol003]oo`El00<000El0003001l07`0011l01iooa007`0300007`0O00d0
7h1oo`00>goo37`000<007`0O00047`07goo400O00<0000O01l00P0O0`00200O5Goo0P0000=oo`00
Ool0IWoo000kOol<O0000`00O01l000@O00OOol@01l00`0001l07`0401l00`0001l07`0601lGOol0
0`00Oomoo`1VOol003aoo`Yl0003001l07`0015l01eoo`83h1007`0300007`0O00<07`0300007`0O
00L07aIoo`03001oo`0006Moo`00?Goo27`000<007`0O0004G`077oo10?P400O00<0000O01l0100O
00<0000O01l01P0OP7oo000nOol6O0000`00O01l000AO00KOol:0n0<Ool00`00Oomoo`02Ool30028
Ool003moo`El0003001l07`0015l01Uoo`X3h0ioo`03001oogoo08eoo`00?goo17`000<007`0O000
4G`067oo2P?P47oo00<007ooOol0SGoo0010Ool2O0000`00O01l000AO00HOol90n0BOol00`00Oomo
o`2=Ool003moo`9l0003001l07`0015l01Moo`T3h1Aoo`03001oogoo08eoo`00?Woo0g`000<007`0
O00047`05Woo2@?P5Woo00<007ooOol0SGoo000mOol3O0000`00O01l000>O00GOol90n0HOol00`00
Oomoo`2=Ool003eoo`9l0004001l07`0O004Ool8O00GOol:0n0IOol00`00Oomoo`2=Ool003aoo`=l
0003001l07`0029oo`X3h1]oo`03001oogoo08eoo`00>goo0g`000<007`0O0008Goo2P?P7Goo00<0
07ooOol0SGoo000iOol01@00Ooml07`000000g`07goo2P?P7goo00<007ooOol0SGoo000iOol01000
O01l00000g`07Woo2P?P8Goo00<007ooOol0SGoo000iOol01000O01l00000W`07Goo2P?P8goo00<0
07ooOol0SGoo000hOol017`0001l00000g`06goo2P?P9Goo00<007ooOol0SGoo000hOol00`00O000
0003O0000`00Oomoo`0GOol:0n0WOol00`00Oomoo`2=Ool003Moo`03O0000000009l008001Qoo`X3
h2Uoo`03001oogoo08eoo`00=Woo0W`010006Goo2@?P:goo00<007ooOol0SGoo000/Ool200000goo
001oo`04Ool3O0020002O00GOol90n0ZOol01000Oomoo`000Woo00<007ooOol0RWoo000^Ool00`00
Oomoo`04Ool6O00FOol90n0/Ool01P00Oomoo`00Ool008eoo`00;Goo00<007oo000017oo1W`05Goo
2@?P;goo00D007oo001oo`0008eoo`00<goo1W`057oo2P?P<7oo00@007oo000008ioo`00<Woo1g`0
4Woo2P?P<goo0`00SWoo000bOol6O00AOol:0n0eOol2002?Ool0035oo`Il011oo`X3h3Qoo`03001o
ogoo08eoo`00<7oo1W`03goo2P?PbWoo000`Ool6O00=Ool:0n3<Ool002moo`Il00aoo`X3h4=oo`80
08Uoo`00;Woo1W`02goo2P?PAWoo00<007ooOol0Qgoo000]Ool7O00:Ool90n18Ool00`00Oomoo`27
Ool002eoo`Il00Uoo`T3h4Uoo`03001oo`0008Qoo`00;7oo1W`027oo2@?PBgoo00@007oo000008Mo
o`00:goo1W`01goo2@?Pf7oo000ZOol7O005Ool:0n3IOol002Yoo`Il00Aoo`X3h=]oo`00:Goo1W`0
0goo2P?PgGoo000XOol6O002Ool:0n3OOol002Moo`Ml00X3h>5oo`009goo1G`02P?Phgoo000VOol4
O00:0n3UOol002Eoo`=l00X3h>Moo`009Goo00=l00?P0n0020?PjGoo000TOol00g`00n03h0070n3[
Ool002=oo`T3h>eoo`008Woo00=l00?P0n001@?Pkgoo000SOol00g`00n03h0020n3aOol002Aoo`<3
h?9oo`009Goo00=l07ooOol0lGoo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYo
o`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003o
OolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00001\
\>"],
  ImageRangeCache->{{{0, 280}, {149, 0}} -> {-2.32216, -2.30003, 0.0308726, 
  0.0308726}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Dynamic Modeling"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[
"This section covers topics related to generalized coordinate modeling of \
dynamic systems. Dynamic motion synthesis is often where generalized \
coordinates have their greatest payoff. Using a coordinate system that is \
closer to being a minimal and independent set can drastically reduce the size \
of the mass matrix and centrifugal force vector, resulting in reduced \
run-times for the numerical integration routine.\n\nThe reduced mass matrix, \
in terms of generalized coordinates, is often useful in its own right for \
certain types of analysis. Examples of various mass matrix manipulations are \
presented in this section, including the conversion of an open-loop mass \
matrix to end-point coordinates, and the reduction of a closed loop mass \
matrix to minimal coordinates. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Two-Link Manipulator Example"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "It is often useful to find the mass matrix of a model with respect to an \
alternative coordinate system. The Generalized Coordinate Package \
automatically generates the model's mass matrix in terms of the specified \
coordinates, and converting the mass matrix to another consistent coordinate \
system is a straight-forward process.\n\nAn open-loop two-link manipulator \
model is developed to demonstrate the conversion of a mass matrix from one \
coordinate system to another. The model has two moving bodies, link 1 and \
link 2, which are represented by two generalized coordinates, ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " coordinate represents the rotation angle of link 1 relative to the ground \
and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " represents the rotation of link2 relative to link 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This loads the Generalized Coordinate packages and defines some useful \
constants."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`GenCrd2D`\>"]\), 
    \(Off[General::"\<spell1\>"]\), 
    \(\(X = {1, 0}; \)\), 
    \(\(Y = {0, 1}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the two-link manipulator model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .72727 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.363636 0.0909091 0.0909091 0.0909091 [
[(-2)] .18182 0 0 2 Msboxa
[(0)] .36364 0 0 2 Msboxa
[(2)] .54545 0 0 2 Msboxa
[(4)] .72727 0 0 2 Msboxa
[(6)] .90909 0 0 2 Msboxa
[(-1)] -0.0125 0 1 0 Msboxa
[(0)] -0.0125 .09091 1 0 Msboxa
[(1)] -0.0125 .18182 1 0 Msboxa
[(2)] -0.0125 .27273 1 0 Msboxa
[(3)] -0.0125 .36364 1 0 Msboxa
[(4)] -0.0125 .45455 1 0 Msboxa
[(5)] -0.0125 .54545 1 0 Msboxa
[(6)] -0.0125 .63636 1 0 Msboxa
[(7)] -0.0125 .72727 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .72827 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(-2)] .18182 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(0)] .36364 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(2)] .54545 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(4)] .72727 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(6)] .90909 0 0 2 Mshowa
p
.001 w
.03636 0 m
.03636 .00375 L
s
P
p
.001 w
.07273 0 m
.07273 .00375 L
s
P
p
.001 w
.10909 0 m
.10909 .00375 L
s
P
p
.001 w
.14545 0 m
.14545 .00375 L
s
P
p
.001 w
.21818 0 m
.21818 .00375 L
s
P
p
.001 w
.25455 0 m
.25455 .00375 L
s
P
p
.001 w
.29091 0 m
.29091 .00375 L
s
P
p
.001 w
.32727 0 m
.32727 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43636 0 m
.43636 .00375 L
s
P
p
.001 w
.47273 0 m
.47273 .00375 L
s
P
p
.001 w
.50909 0 m
.50909 .00375 L
s
P
p
.001 w
.58182 0 m
.58182 .00375 L
s
P
p
.001 w
.61818 0 m
.61818 .00375 L
s
P
p
.001 w
.65455 0 m
.65455 .00375 L
s
P
p
.001 w
.69091 0 m
.69091 .00375 L
s
P
p
.001 w
.76364 0 m
.76364 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.83636 0 m
.83636 .00375 L
s
P
p
.001 w
.87273 0 m
.87273 .00375 L
s
P
p
.001 w
.94545 0 m
.94545 .00375 L
s
P
p
.001 w
.98182 0 m
.98182 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-1)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .09091 m
.00625 .09091 L
s
P
[(0)] -0.0125 .09091 1 0 Mshowa
p
.002 w
0 .18182 m
.00625 .18182 L
s
P
[(1)] -0.0125 .18182 1 0 Mshowa
p
.002 w
0 .27273 m
.00625 .27273 L
s
P
[(2)] -0.0125 .27273 1 0 Mshowa
p
.002 w
0 .36364 m
.00625 .36364 L
s
P
[(3)] -0.0125 .36364 1 0 Mshowa
p
.002 w
0 .45455 m
.00625 .45455 L
s
P
[(4)] -0.0125 .45455 1 0 Mshowa
p
.002 w
0 .54545 m
.00625 .54545 L
s
P
[(5)] -0.0125 .54545 1 0 Mshowa
p
.002 w
0 .63636 m
.00625 .63636 L
s
P
[(6)] -0.0125 .63636 1 0 Mshowa
p
.002 w
0 .72727 m
.00625 .72727 L
s
P
[(7)] -0.0125 .72727 1 0 Mshowa
p
.001 w
0 .01818 m
.00375 .01818 L
s
P
p
.001 w
0 .03636 m
.00375 .03636 L
s
P
p
.001 w
0 .05455 m
.00375 .05455 L
s
P
p
.001 w
0 .07273 m
.00375 .07273 L
s
P
p
.001 w
0 .10909 m
.00375 .10909 L
s
P
p
.001 w
0 .12727 m
.00375 .12727 L
s
P
p
.001 w
0 .14545 m
.00375 .14545 L
s
P
p
.001 w
0 .16364 m
.00375 .16364 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .21818 m
.00375 .21818 L
s
P
p
.001 w
0 .23636 m
.00375 .23636 L
s
P
p
.001 w
0 .25455 m
.00375 .25455 L
s
P
p
.001 w
0 .29091 m
.00375 .29091 L
s
P
p
.001 w
0 .30909 m
.00375 .30909 L
s
P
p
.001 w
0 .32727 m
.00375 .32727 L
s
P
p
.001 w
0 .34545 m
.00375 .34545 L
s
P
p
.001 w
0 .38182 m
.00375 .38182 L
s
P
p
.001 w
0 .4 m
.00375 .4 L
s
P
p
.001 w
0 .41818 m
.00375 .41818 L
s
P
p
.001 w
0 .43636 m
.00375 .43636 L
s
P
p
.001 w
0 .47273 m
.00375 .47273 L
s
P
p
.001 w
0 .49091 m
.00375 .49091 L
s
P
p
.001 w
0 .50909 m
.00375 .50909 L
s
P
p
.001 w
0 .52727 m
.00375 .52727 L
s
P
p
.001 w
0 .56364 m
.00375 .56364 L
s
P
p
.001 w
0 .58182 m
.00375 .58182 L
s
P
p
.001 w
0 .6 m
.00375 .6 L
s
P
p
.001 w
0 .61818 m
.00375 .61818 L
s
P
p
.001 w
0 .65455 m
.00375 .65455 L
s
P
p
.001 w
0 .67273 m
.00375 .67273 L
s
P
p
.001 w
0 .69091 m
.00375 .69091 L
s
P
p
.001 w
0 .70909 m
.00375 .70909 L
s
P
p
.002 w
0 0 m
0 .72727 L
s
P
P
p
p
.002 w
0 .72102 m
0 .72727 L
s
P
p
.002 w
.18182 .72102 m
.18182 .72727 L
s
P
p
.002 w
.36364 .72102 m
.36364 .72727 L
s
P
p
.002 w
.54545 .72102 m
.54545 .72727 L
s
P
p
.002 w
.72727 .72102 m
.72727 .72727 L
s
P
p
.002 w
.90909 .72102 m
.90909 .72727 L
s
P
p
.001 w
.03636 .72352 m
.03636 .72727 L
s
P
p
.001 w
.07273 .72352 m
.07273 .72727 L
s
P
p
.001 w
.10909 .72352 m
.10909 .72727 L
s
P
p
.001 w
.14545 .72352 m
.14545 .72727 L
s
P
p
.001 w
.21818 .72352 m
.21818 .72727 L
s
P
p
.001 w
.25455 .72352 m
.25455 .72727 L
s
P
p
.001 w
.29091 .72352 m
.29091 .72727 L
s
P
p
.001 w
.32727 .72352 m
.32727 .72727 L
s
P
p
.001 w
.4 .72352 m
.4 .72727 L
s
P
p
.001 w
.43636 .72352 m
.43636 .72727 L
s
P
p
.001 w
.47273 .72352 m
.47273 .72727 L
s
P
p
.001 w
.50909 .72352 m
.50909 .72727 L
s
P
p
.001 w
.58182 .72352 m
.58182 .72727 L
s
P
p
.001 w
.61818 .72352 m
.61818 .72727 L
s
P
p
.001 w
.65455 .72352 m
.65455 .72727 L
s
P
p
.001 w
.69091 .72352 m
.69091 .72727 L
s
P
p
.001 w
.76364 .72352 m
.76364 .72727 L
s
P
p
.001 w
.8 .72352 m
.8 .72727 L
s
P
p
.001 w
.83636 .72352 m
.83636 .72727 L
s
P
p
.001 w
.87273 .72352 m
.87273 .72727 L
s
P
p
.001 w
.94545 .72352 m
.94545 .72727 L
s
P
p
.001 w
.98182 .72352 m
.98182 .72727 L
s
P
p
.002 w
0 .72727 m
1 .72727 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .09091 m
1 .09091 L
s
P
p
.002 w
.99375 .18182 m
1 .18182 L
s
P
p
.002 w
.99375 .27273 m
1 .27273 L
s
P
p
.002 w
.99375 .36364 m
1 .36364 L
s
P
p
.002 w
.99375 .45455 m
1 .45455 L
s
P
p
.002 w
.99375 .54545 m
1 .54545 L
s
P
p
.002 w
.99375 .63636 m
1 .63636 L
s
P
p
.001 w
.99625 .01818 m
1 .01818 L
s
P
p
.001 w
.99625 .03636 m
1 .03636 L
s
P
p
.001 w
.99625 .05455 m
1 .05455 L
s
P
p
.001 w
.99625 .07273 m
1 .07273 L
s
P
p
.001 w
.99625 .10909 m
1 .10909 L
s
P
p
.001 w
.99625 .12727 m
1 .12727 L
s
P
p
.001 w
.99625 .14545 m
1 .14545 L
s
P
p
.001 w
.99625 .16364 m
1 .16364 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .21818 m
1 .21818 L
s
P
p
.001 w
.99625 .23636 m
1 .23636 L
s
P
p
.001 w
.99625 .25455 m
1 .25455 L
s
P
p
.001 w
.99625 .29091 m
1 .29091 L
s
P
p
.001 w
.99625 .30909 m
1 .30909 L
s
P
p
.001 w
.99625 .32727 m
1 .32727 L
s
P
p
.001 w
.99625 .34545 m
1 .34545 L
s
P
p
.001 w
.99625 .38182 m
1 .38182 L
s
P
p
.001 w
.99625 .4 m
1 .4 L
s
P
p
.001 w
.99625 .41818 m
1 .41818 L
s
P
p
.001 w
.99625 .43636 m
1 .43636 L
s
P
p
.001 w
.99625 .47273 m
1 .47273 L
s
P
p
.001 w
.99625 .49091 m
1 .49091 L
s
P
p
.001 w
.99625 .50909 m
1 .50909 L
s
P
p
.001 w
.99625 .52727 m
1 .52727 L
s
P
p
.001 w
.99625 .56364 m
1 .56364 L
s
P
p
.001 w
.99625 .58182 m
1 .58182 L
s
P
p
.001 w
.99625 .6 m
1 .6 L
s
P
p
.001 w
.99625 .61818 m
1 .61818 L
s
P
p
.001 w
.99625 .65455 m
1 .65455 L
s
P
p
.001 w
.99625 .67273 m
1 .67273 L
s
P
p
.001 w
.99625 .69091 m
1 .69091 L
s
P
p
.001 w
.99625 .70909 m
1 .70909 L
s
P
p
.002 w
1 0 m
1 .72727 L
s
P
P
p
P
0 0 m
1 0 L
1 .72727 L
0 .72727 L
closepath
clip
newpath
p
.36364 .09091 m
.45455 0 L
.27273 0 L
F
p
1 0 0 r
.34545 .1224 m
.38182 .05942 L
.8542 .33214 L
.81783 .39513 L
F
0 0 1 r
.81783 .33214 m
.8542 .39513 L
.38182 .66786 L
.34545 .60487 L
F
P
p
16 Mabswid
.36364 .63636 Mdot
.83601 .36364 Mdot
P
16 Mabswid
.36364 .09091 Mdot
p
p
.015 w
.13636 .63636 m
.31818 .63636 L
s
.29247 .61065 m
.31818 .63636 L
.29247 .66208 L
s
P
P
p
/Times-Bold findfont 16 scalefont setfont
[(F)] .22727 .54545 0 0 Mshowa
P
p
p
p
/Courier findfont 8 scalefont setfont
[(x)] .75728 .31818 -0.54904 -1.22942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .50892 .38473 -0.54904 -1.22942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(2)] .59983 .22727 -0.54904 -1.22942 Mshowa
P
.004 w
.75728 .31818 m
.59983 .22727 L
.50892 .38473 L
s
.73488 .28425 m
.75728 .31818 L
.7167 .31575 L
s
.51135 .34415 m
.50892 .38473 L
.54284 .36233 L
s
P
p
p
/Courier findfont 8 scalefont setfont
[(x)] .75728 .40909 -2.04904 -0.32942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .69073 .65746 -2.04904 -0.32942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(3)] .59983 .5 -2.04904 -0.32942 Mshowa
P
.004 w
.75728 .40909 m
.59983 .5 L
.69073 .65746 L
s
.7167 .41153 m
.75728 .40909 L
.73488 .44302 L
s
.65681 .63506 m
.69073 .65746 L
.6883 .61688 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 205},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000cA000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0015Ool3000XOol00`00Oomoo`0YOol3000[Ool3000YOol2000ROol0
04Eoo`03001oogoo02Moo`03001oo`0002Yoo`03001oogoo02aoo`03001oogoo02Qoo`03001oo`00
025oo`00@7oo0`000goo00<007ooOol09Woo00<007oo0000:goo00<007ooOol0:Goo1000:Goo00<0
07oo00008Goo0016Ool00`00Oomoo`0VOol00`00Ool0000[Ool00`00Oomoo`0YOol00`00Ool0000Z
Ool2000ROol004Eoo`03001oo`0002Moo`03001oo`0002Yoo`03001oo`0002]oo`8002Yoo`03001o
ogoo025oo`00AWoo00<007ooOol09goo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol0:Goo
0P008Goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000?Ool5
003oOol7Ool0015oo`03001oogoo0?moo`Moo`002goo0`000goo00<007ooOol00goon0002goo000A
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`02Ool/0005Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool01@00Oomoogoo00002goo
000AOol00`00Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`0EOolZ000HOol00`00Oomoo`0ZOol0
0`00Oomoo`0ZOol00`00Oomoo`0COol00`00Oomoo`09Ool0011oo`8000Eoo`03001oogoo04=oobP0
08Uoo`03001oogoo00Uoo`005goo00<007ooOol0A7oo9P00RWoo00<007ooOol02Goo000GOol20016
OolT002:Ool2000;Ool001Moo`03001oogoo04Ioob8008aoo`03001oogoo00Uoo`005goo00<007oo
Ool0Agoo8000SGoo00<007ooOol02Goo000GOol00`00Oomoo`18OolN002>Ool00`00Oomoo`09Ool0
01Moo`8004Yooa`008ioo`8000]oo`005goo00<007ooOol0BWoo6P00T7oo00<007ooOol02Goo000G
Ool00`00Oomoo`1;OolH002AOol00`00Oomoo`09Ool001Moo`03001oogoo04aooaH0099oo`03001o
ogoo00Uoo`005goo00<007ooOol0CGoo5000Tgoo00<007ooOol02Goo000GOol2001?OolB002COol2
000;Ool001Moo`03001oogoo04mooa0009Eoo`03001oogoo00Uoo`005goo00<007ooOol0D7oo2`00
0W`000<007ooOol0U7oo00<007ooOol02Goo000GOol00`00Oomoo`1AOol90005O02EOol00`00Oomo
o`09Ool001Moo`80059oo`/000El099oo`8000]oo`005goo00<007ooOol0DGoo2`001W`0TWoo00<0
07ooOol02Goo000GOol00`00Oomoo`1@Ool=0007O02@Ool00`00Oomoo`09Ool0015oo`03001oogoo
00=oo`03001oogoo051oo`d000Ul08ioo`03001oogoo00Uoo`0047oo00<007oo000017oo00<007oo
Ool0Cgoo3`002W`0S7oo00<007ooOol02Goo000@Ool00`00Ool00004Ool2001@Ool?000;O02:Ool2
000;Ool0011oo`03001oo`0000Aoo`03001oogoo04moo`l000el08Uoo`03001oogoo00Uoo`0047oo
00<007oo000017oo00<007ooOol0D7oo3@0047`0Qgoo00<007ooOol02Goo000AOol00`00Oomoo`03
Ool00`00Oomoo`1@Ool=000AO026Ool00`00Oomoo`09Ool001Moo`80059oo`/001Al08=oo`8000]o
o`005goo00<007ooOol0DGoo2`005W`0PWoo00<007ooOol02Goo000GOol00`00Oomoo`1COol7000J
O020Ool00`00Oomoo`09Ool001Moo`03001oogoo05=oo`9l00<001el07moo`03001oogoo00Uoo`00
5goo00<007ooOol0DWoo9G`0OGoo00<007ooOol02Goo000GOol2001EOolUO01jOol2000;Ool001Mo
o`03001oogoo05IoobAl07Yoo`03001oogoo00Uoo`005goo00<007ooOol0F7oo97`0N7oo00<007oo
Ool02Goo000GOol00`00Oomoo`1IOolUO01fOol00`00Oomoo`09Ool001Moo`8005aoobEl07=oo`80
00]oo`005goo00<007ooOol0GGoo97`0Lgoo00<007ooOol02Goo000GOol00`00Oomoo`1OOolTO01a
Ool00`00Oomoo`09Ool001Moo`03001oogoo061oobEl06moo`03001oogoo00Uoo`005goo00<007oo
Ool0HWoo9G`0KGoo00<007ooOol02Goo000GOol2001UOolTO01[Ool2000;Ool001Moo`03001oogoo
06IoobAl06Yoo`03001oogoo00Uoo`003goo1@000goo00<007ooOol0Igoo9G`0J7oo00<007ooOol0
2Goo000AOol00`00Oomoo`03Ool00`00Oomoo`1YOolTO01WOol00`00Oomoo`09Ool0015oo`03001o
ogoo00=oo`8006aoobAl06Aoo`8000]oo`004Goo00<007ooOol00goo00<007ooOol0KGoo97`0Hgoo
00<007ooOol02Goo000AOol00`00Oomoo`03Ool00`00Oomoo`1^OolUO01QOol00`00Oomoo`09Ool0
011oo`8000Eoo`03001oogoo071oobAl061oo`03001oogoo00Uoo`005goo00<007ooOol0LWoo97`0
GWoo00<007ooOol02Goo000GOol2001eOolTO01KOol2000;Ool001Moo`03001oogoo07EoobAl05]o
o`03001oogoo00Uoo`005goo00<007ooOol0Mgoo97`0FGoo00<007ooOol02Goo000GOol00`00Oomo
o`1iOolTO01GOol00`00Oomoo`09Ool001Moo`8007aoobAl05Aoo`8000]oo`005goo00<007ooOol0
O7oo97`0E7oo00<007ooOol02Goo000GOol00`00Oomoo`1nOolTO01BOol00`00Oomoo`09Ool001Mo
o`03001oogoo081ooa5l0003001l07`0011l051oo`03001oogoo00Uoo`005goo00<007ooOol0PWoo
3W`000@007`00000015l04moo`03001oogoo00Uoo`005goo0P00Q7oo3G`000@007`0O01l0080015l
04aoo`8000]oo`005goo00<007ooOol0QGoo2W`000<007`0O00017`00P004G`0Bgoo00<007ooOol0
2Goo000GOol00`00Oomoo`27Ool8O0000`00O00000020004O0000`00O01l000@O019Ool00`00Oomo
o`09Ool001Moo`03001oogoo08Uoo`El0003001l07`0008000Il0080015l04Qoo`03001oogoo00Uo
o`005goo0P00Rgoo17`000<007`0O0000W`000<007`0O0001G`00P004G`0AGoo0P002goo000GOol0
0`00Oomoo`2<Ool00g`0001l0004O0000`00O01l0007O002000AO014Ool00`00Oomoo`09Ool001Mo
o`03001oogoo08aoo`03001oog`0009l00<000]l0080015l049oo`03001oogoo00Uoo`0047oo0`00
17oo00<007ooOol0S7oo00@007ooOomooa5l0003001l07`000ml045oo`03001oogoo00Uoo`0047oo
00<007ooOol017oo00<007ooOol0Rgoo00<007ooOol00goo4G`00P004G`0?goo00<007ooOol02Goo
000AOol00`00Oomoo`03Ool2002<Ool00`00Oomoo`05OolAO002000AO00lOol2000;Ool0015oo`03
001oogoo00=oo`03001oogoo08Yoo`03001oogoo00Qooa5l0080011l03aoo`03001oogoo00Uoo`00
47oo00<007oo000017oo00<007ooOol0RWoo00<007ooOol02Woo4G`000<007`0O0003g`0>Woo00<0
07ooOol02Goo000AOol00`00Oomoo`03Ool00`00Oomoo`29Ool00`00Oomoo`0<OolAO0020008O000
0`00O01l0006O00hOol00`00Oomoo`09Ool001Moo`8008Yoo`03001oogoo00iooa5l008000Ml0003
001l07`000Ml03Eoo`8000]oo`005goo00<007ooOol0R7oo00<007ooOol04Goo4G`00P001G`000<0
07`0O00027`0=Goo00<007ooOol02Goo000GOol00`00Oomoo`27Ool00`00Oomoo`0DOolAO0020004
O0000`00O01l0009O00cOol00`00Oomoo`09Ool001Moo`03001oogoo08Moo`03001oogoo01Eooa9l
0005001l07`0O000000=O00aOol00`00Oomoo`09Ool001Moo`03001oogoo08Ioo`03001oogoo01Qo
oa5l0080009l0003001l07`000]l031oo`03001oogoo00Uoo`005goo0P00Qgoo00<007ooOol06Woo
4G`00P0000=l0000O0003G`0;Goo0P002goo000GOol00`00Oomoo`25Ool00`00Oomoo`0MOolAO002
000@O00/Ool00`00Oomoo`09Ool001Moo`03001oogoo08Eoo`03001oogoo01ioo`Ql00/0015l02Yo
o`03001oogoo00Uoo`005goo00<007ooOol0Q7oo00<007ooOol08Goo8g`0:Goo00<007ooOol02Goo
000GOol20024Ool00`00Oomoo`0TOolSO00VOol2000;Ool001Moo`03001oogoo08=oo`03001oogoo
02Ioob=l02Eoo`03001oogoo00Uoo`005goo00<007ooOol0PWoo00<007ooOol0:7oo2W`00P0000=l
0000O00057`097oo00<007ooOol02Goo000GOol00`00Oomoo`22Ool00`00Oomoo`0ZOol:O0000`00
O01l000:O00201l2O0030003O00TOol00`00Oomoo`09Ool001Moo`03001oogoo085oo`03001oogoo
02eoo`Ml0003001l000000Ul00@07`L002Eoo`03001oogoo00Uoo`005goo0P00O7oo00<007ooOol0
0goo00<007ooOol0;goo3g`0100O2`008Woo0P002goo000GOol00`00Oomoo`1kOol00`00Oomoo`02
Ool00`00Oomoo`0aOol=O00501l;000SOol00`00Oomoo`09Ool0011oo`8000Eoo`03001oogoo07]o
o`03001oogoo009oo`03001oogoo03=oo`Ul00H07`d0029oo`03001oogoo00Uoo`004Woo00<007oo
Ool00Woo00<007ooOol0Ngoo00D007ooOomoo`0003Qoo`El00P07`d0029oo`03001oogoo00Uoo`00
4Goo00<007ooOol00goo0P00O7oo00@007ooOol000Aoo`03001oogoo03Aoo`03O0007`0O00L07`l0
021oo`8000]oo`004Woo00<007ooOol00Woo00<007ooOol0Ngoo00@007ooOol000=oo`03001oogoo
03Eoo`X07`l0025oo`03001oogoo00Uoo`0047oo00<007oo000017oo00<007ooOol0Ngoo00<007oo
00000Woo0P00=Woo300O3`008Goo00<007ooOol02Goo000AOol00`00Oomoo`03Ool00`00Oomoo`1k
Ool01@00Ool007oo0000=Woo3`0O3@008Woo00<007ooOol02Goo000GOol00`00Oomoo`1kOol20000
0goo001oo`0dOolA01l=000ROol00`00Oomoo`09Ool001Moo`8007aoo`<003Eooa<07`/0029oo`80
00]oo`005goo00<007ooOol0Ngoo00<007ooOol0<goo5@0O2`008goo00<007ooOol02Goo000GOol0
0`00Oomoo`2_OolI01l700000`0OOomoo`0ROol00`00Oomoo`09Ool001Moo`03001oogoo07Yoo`80
035ooad07`<000<07bAoo`03001oogoo00Uoo`005goo0P00O7oo00<007ooOol0;Woo8`0O97oo0P00
2goo000GOol00`00Oomoo`1kOol00`00Oomoo`0/OolS01lWOol00`00Oomoo`09Ool001Moo`03001o
ogoo07Yoo`03001oo`0002]oob<07bUoo`03001oogoo00Uoo`005goo00<007ooOol0NWoo00@007oo
000002Qoo`P07`/000807`80000301l0000O00X07bYoo`03001oogoo00Uoo`005goo00<007ooOol0
YGoo4@0O0P001@0O00<0000O01l0200O;7oo00<007ooOol02Goo000GOol2002TOolA01l200000`0O
00007`0301l00`0001l0000701l]Ool2000;Ool001Moo`03001oogoo0:5ooa407`8000807`030000
7`0O00/07c1oo`03001oogoo00Uoo`005goo00<007ooOol0Wgoo4P0O00D0000O01l07`0000d07c5o
o`03001oogoo00Uoo`005goo00<007ooOol0WWoo4@0O0P00100O00<0000O01l02@0O<goo00<007oo
Ool02Goo000GOol2002MOolA01l2000501l00`0001l07`0801ldOol2000;Ool001Moo`03001oogoo
09Yooa407`8000L07`0300007`0O00L07cIoo`03001oogoo00Uoo`005goo00<007ooOol0V7oo4@0O
0P00200O00<0000O01l01P0O>7oo00<007ooOol02Goo000AOol30003Ool00`00Oomoo`2GOolA01l0
0`0001l07`0?01ljOol00`00Oomoo`09Ool0019oo`03001oogoo009oo`03001oogoo09Eooa407`80
01007caoo`03001oogoo00Uoo`0047oo10000goo0P00U7oo4@0O0P004@0O?7oo0P002goo000@Ool0
0`00Ool00004Ool00`00Oomoo`2AOolA01l2000A01loOol00`00Oomoo`09Ool0015oo`8000Aoo`03
001oogoo091ooa407`0300007`0O00l07d5oo`03001oogoo00Uoo`004Woo00<007ooOol00Woo00<0
07ooOol0SWoo4@0O0P004@0O@Woo00<007ooOol02Goo000GOol2002=OolA01l2000A01m3Ool2000;
Ool001Moo`03001oogoo08Yooa407`8001407dIoo`03001oogoo00Uoo`005goo00<007ooOol0RGoo
400O0P004@0OB7oo00<007ooOol02Goo000GOol00`00Oomoo`27OolA01l00`0001l07`0@01m9Ool0
0`00Oomoo`09Ool001Moo`03001oogoo08Eooa407`8001407d]oo`03001oogoo00Uoo`005goo0P00
Q7oo4@0O0P004@0OC7oo0P002goo000GOol00`00Oomoo`22Ool@01l2000A01m?Ool00`00Oomoo`09
Ool001Moo`03001oogoo081ooa407`0300007`0O01007e1oo`03001oogoo00Uoo`005goo00<007oo
Ool0OWoo500O00<0000O01l00`002P0ODWoo00<007ooOol02Goo000GOol2001mOolF01l00`0001l0
7`0201l00`0001l07`0601mCOol2000;Ool001Moo`03001oogoo07]ooaP07`0400007`0O000801mE
Ool00`00Oomoo`09Ool001Moo`03001oogoo07UooaX07`0500007`0O01l0000501mGOol00`00Oomo
o`09Ool001Moo`03001oogoo07Mooad07`@000<07eUoo`03001oogoo00Uoo`005goo00<007ooOol0
MGoo800O00@0000O01l07e]oo`03001oogoo00Uoo`005goo0P00<Goo1P00?Woo8@0O00<0000O01l0
Fgoo0P002goo000GOol00`00Oomoo`0bOol2000nOolT01l00`00Oomoo`1KOol00`00Oomoo`09Ool0
015oo`03001oogoo00=oo`03001oogoo039oo`8003aoob@07`9oo`03001oogoo05]oo`03001oogoo
00Uoo`0047oo00<007oo000017oo00<007ooOol0<Woo0P000Woo00<007ooOol0=Goo9@0O17oo00<0
07ooOol0FWoo00<007ooOol02Goo000BOol00`00Oomoo`02Ool2000cOol20002Ool00`00Oomoo`0d
OolT01l6Ool00`00Oomoo`1IOol2000;Ool0011oo`8000Eoo`03001oogoo039oo`D003Aoob@07`Uo
o`03001oogoo05Uoo`03001oogoo00Uoo`0047oo00<007ooOol017oo00<007ooOol0<Woo0P000Woo
00<007ooOol0<7oo900O37oo00<007ooOol0F7oo00<007ooOol02Goo000@Ool30004Ool00`00Oomo
o`0bOol20002Ool00`00Oomoo`0^OolU01l=Ool00`00Oomoo`1HOol00`00Oomoo`09Ool001Moo`03
001oogoo039oo`8000Aoo`03001oogoo02]oob@07a1oo`03001oogoo05Moo`03001oogoo00Uoo`00
5goo0P00<goo0P0017oo00<007ooOol0:Goo900O4Woo00<007ooOol0EWoo0P002goo000GOol00`00
Oomoo`0`Ool9000YOolU01lDOol00`00Oomoo`1FOol00`00Oomoo`09Ool001Moo`03001oogoo061o
obD07aMoo`03001oogoo05Eoo`03001oogoo00Uoo`005goo00<007ooOol0Ggoo900O6Goo00<007oo
Ool0EGoo00<007ooOol02Goo000GOol2001NOolT01lLOol00`00Oomoo`1COol2000;Ool001Moo`03
001oogoo05]oobD07aeoo`03001oogoo05Aoo`03001oogoo00Uoo`005goo00<007ooOol0FGoo9@0O
87oo00<007ooOol0Dgoo00<007ooOol02Goo000GOol00`00Oomoo`1HOolT01lSOol00`00Oomoo`1B
Ool00`00Oomoo`09Ool001Moo`03001oogoo05Ioob@07bEoo`03001oogoo059oo`03001oogoo00Uo
o`005goo0P00EGoo9@0O9goo00<007ooOol0D7oo0P002goo000GOol00`00Oomoo`1BOolU01lYOol0
0`00Oomoo`1AOol00`00Oomoo`09Ool001Moo`03001oogoo04Aoo`8000eoo`807`<001d07baoo`03
001oogoo051oo`03001oogoo00Uoo`005goo00<007ooOol0@goo100037oo1`006P0O;Woo00<007oo
Ool0Cgoo00<007ooOol02Goo000GOol20015Ool40009Ool;000F01l`Ool00`00Oomoo`02Ool00`00
Oomoo`19Ool2000;Ool001Moo`03001oogoo04Eoo`@000Qoo`/001@07c=oo`05001oogooOol0001<
Ool00`00Oomoo`09Ool001Moo`03001oogoo04Ioo`@000Ioo`d001407cEoo`05001oogooOol0001<
Ool00`00Oomoo`09Ool0011oo`8000Eoo`03001oogoo04Moo`D000Aoo`d001007cMoo`04001oogoo
001<Ool00`00Oomoo`09Ool0011oo`03001oo`0000Aoo`03001oogoo01eooc00009oo`l000d07cUo
o`04001oogoo001<Ool00`00Oomoo`09Ool0011oo`03001oo`0000Aoo`8001iooc00009oo`l000/0
7cIoo`03001oogoo00=oo`03001oo`0004]oo`8000]oo`0047oo0P001Goo00<007ooOol07Goo<000
0Woo3`002P0O>7oo0P0017oo00<007oo0000Bgoo00<007ooOol02Goo000@Ool00`00Oomoo`04Ool0
0`00Oomoo`17Ool50004Ool=000901llOol20002Ool00`00Ool0001;Ool00`00Oomoo`09Ool0015o
o`8000Aoo`03001oogoo04Ioo`@000Ioo`d000L07d1oo`800003Ool0000004]oo`03001oogoo00Uo
o`005goo0P00AWoo100027oo2`001P0OA7oo0`000Woo0P00AWoo0P002goo000GOol00`00Oomoo`14
Ool40009Ool;000501m7Ool01@00Oomoogoo0000Agoo00<007ooOol02Goo000GOol00`00Oomoo`13
Ool4000<Ool7000501m=Ool00`00Oomoo`15Ool00`00Oomoo`09Ool001Moo`03001oogoo04Aoo`80
00moo`<000=oo`807dioo`03001oo`0004Ioo`03001oogoo00Uoo`005goo00<007ooOol0Zgoo00@0
07oo000004Eoo`03001oogoo00Uoo`005goo0P00m7oo0P002goo000GOol00`00Oomoo`3dOol00`00
Oomoo`09Ool001Moo`03001oogoo0?Aoo`03001oogoo00Uoo`005goo00<007ooOol0m7oo00<007oo
Ool02Goo000GOol2003dOol2000;Ool001Moo`03001oogoo0?Aoo`03001oogoo00Uoo`005goo00<0
07ooOol0m7oo00<007ooOol02Goo000GOol00`00Oomoo`3dOol00`00Oomoo`09Ool001Moo`03001o
ogoo0?Aoo`03001oogoo00Uoo`005goo0P00m7oo0P002goo000GOol00`00Oomoo`3dOol00`00Oomo
o`09Ool0015oo`03001oogoo00=oo`03001oogoo0?Aoo`03001oogoo00Uoo`004Goo00<007ooOol0
0goo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0
:Woo00<007ooOol04goo00<007ooOol02Goo000AOol00`00Oomoo`03Oooh000;Ool0019oo`03001o
ogoo0?moo`Ioo`0047oo00<007oo0000ogoo27oo000@Ool3003oOol8Ool00?mooa]oo`00ogoo6goo
003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {204, 0}} -> {-5.02995, -1.80004, 0.0444447, 
  0.0444447}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Two body objects are used in the manipulator model. Each body object is \
used only to define inertia properties for the body, no local point \
definitions are made. Thus the ground (body 1) needs no body object because \
its inertia is immaterial. Note that the lengths of the links are left as \
parameters ",
  StyleBox["L1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["L2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", causing the resulting mass matrix to be completely general."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the body objects for the manipulator model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(link1 = 2; \)\), 
    \(\(link2 = 3; \)\), 
    \(bd[2] = 
      Body[link1, \n\t\tMass \[Rule] 1, Inertia \[Rule] 3, 
        Centroid \[Rule] {L1/2, 0}]; \n
    bd[3] = Body[link2, \n\t\tMass \[Rule] 1, Inertia \[Rule] 3, 
        Centroid \[Rule] {L2/2, 0}]; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The inertia properties are incorporated into the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[link1], bd[link2]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Four constraint objects are used to model the manipulator. Two constraints \
are generalized coordinate constraints which introduce the two degrees of \
freedom, ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the other two constraints simply constrain these two degrees of \
freedom."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["GenRevolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint sets up the relationship between link1 and the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["GenRevolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint sets up the relationship between link2 and link1."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Two ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects constrain ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to be equal to the parameters ",
  StyleBox["q1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["q2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["L1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " appears explicitly in constraint 3 to locate the tip of ",
  StyleBox["link1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where it is attached to ",
  StyleBox["link2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the manipulator."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[1] = 
      GenRevolute2[1, Axis[link1, 0, X], Axis[ground, 0, X], {alpha, 0}]; 
    \)\), 
    \(\(cs[2] = Constraint[2, alpha == q1]; \)\), 
    \(\(cs[3] = 
      GenRevolute2[3, Axis[link2, 0, X], Axis[link1, {L1, 0}, X], {beta, 0}]; 
    \)\), 
    \(\(cs[4] = Constraint[4, beta == q2]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The constraints are incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 4]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Mass Matrix"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The kinematics of this model are truly trivial. The entire constraint set \
is nothing more than a pair of expressions setting ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " equal to ",
  StyleBox["q1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["q2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". There is really no point in \"running\" the model at all, in the normal \
sense in which other ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " models are \"run\" because the configuration of the model can be \
specified directly by ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The usefulness of the model lies in the other definitions that have been \
made by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " for inertia properties and coordinate transformations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the constraint vector."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints[All]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({alpha - q1, beta - q2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the global location of the tip of link 2."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(link2tip = Location[link2, {L2, 0}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({L1\ Cos[alpha] + L2\ Cos[alpha + beta], 
      L1\ Sin[alpha] + L2\ Sin[alpha + beta]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the 2x2 system mass matrix."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(m = Simplify[MassMatrix[All]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{1\/4\ \((24 + 5\ L1\^2 + L2\^2 + 4\ L1\ L2\ Cos[beta])\), 
        1\/4\ \((12 + L2\^2 + 2\ L1\ L2\ Cos[beta])\)}, {
        1\/4\ \((12 + L2\^2 + 2\ L1\ L2\ Cos[beta])\), 3 + L2\^2\/4}}\)], 
  "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["End Point Mobility"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now we wish to find the ellipse of mobility of the end point of link 2. \
The ellipse of mobility of an equivalent two-link manipulator model was found \
in Section 10.3 of the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " manual. In that example, a one unit force was applied to the end point of \
link 2 while varying the direction of the force through 360 degrees, and the \
resulting free acceleration vector of the endpoint was found with the ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions.\n\nThis section presents a more elegant method of finding the \
ellipse of mobility directly from the mass matrix. The method presented in \
Section 10.3 is much more general than this one in that this method (as it is \
presented here) is restricted to finding the mobility of the end point at \
zero velocity, and is restricted to models that have the same total number of \
coordinates as the number of physical degrees of freedom of the end point.\n\n\
The basic trick here is to convert the mass matrix from the generalized \
(joint angle) coordinates to endpoint coordinates. The mass matrix ",
  StyleBox["m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", in the context of ",
  StyleBox["f=m.a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", transforms accelerations of the generalized coordinates ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which are the relative angular accelerations of each of the joints, into \
forces on the generalized coordinates ",
  StyleBox["f",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which are moments applied at the joints. We need to have a matrix ",
  StyleBox["P",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["P.F=A",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which transforms a force vector ",
  StyleBox["F",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applied to the endpoint into the linear acceleration vector ",
  StyleBox["A",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of the end point. First, we need a transformation matrix ",
  StyleBox["J",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " from generalized coordinates to endpoint coordinates such that ",
  StyleBox["A = J.a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Then ",
  StyleBox["P=J.Inverse[m].Transpose[J]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nThe matrix ",
  StyleBox["J",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the Jacobian of the global coordinates of the endpoint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the transformation matrix ",
  StyleBox["J",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(J = Outer[D, link2tip, {alpha, beta}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(-L1\)\ Sin[alpha] - L2\ Sin[alpha + beta], 
        \(-L2\)\ Sin[alpha + beta]}, {L1\ Cos[alpha] + L2\ Cos[alpha + beta], 
        L2\ Cos[alpha + beta]}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the inverse end point mass matrix ",
  StyleBox["P",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a rather large symbolic matrix."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(P = J.Inverse[m].Transpose[J]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "We can now find the acceleration of the endpoint that results from any \
force vector at any particular configuration simply by multiplying ",
  StyleBox["P",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " times the force vector."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the acceleration vector resulting from an applied force {0, 2}."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(config
       = {alpha \[Rule] \[Pi]\/6.0, beta \[Rule] \(2.0  \[Pi]\)\/3.0, 
        L1 \[Rule] 6.0, L2 \[Rule] 6.0}; \nP.{0, 2} /. config\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.2674119662719856`, 4.58181818181818023`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Now finding the ellipse of mobility is simply a matter of applying a unit \
force vector that revolves through a full circle and plotting the components \
of the resulting acceleration."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the ellipse of mobility."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[
      Evaluate[P.PolarToXY[{1, ang}] /. config], {ang, 0, 2\ \[Pi]}, 
      Epilog \[Rule] {Line[{{0, 0}, P.X /. config}]}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.262272 0.309017 0.115138 [
[.10659 .29652 -12 -9 ]
[.10659 .29652 12 0 ]
[.23773 .29652 -6 -9 ]
[.23773 .29652 6 0 ]
[.36886 .29652 -12 -9 ]
[.36886 .29652 12 0 ]
[.63114 .29652 -9 -9 ]
[.63114 .29652 9 0 ]
[.76227 .29652 -3 -9 ]
[.76227 .29652 3 0 ]
[.89341 .29652 -9 -9 ]
[.89341 .29652 9 0 ]
[.4875 .07874 -12 -4.5 ]
[.4875 .07874 0 4.5 ]
[.4875 .19388 -12 -4.5 ]
[.4875 .19388 0 4.5 ]
[.4875 .42415 -6 -4.5 ]
[.4875 .42415 0 4.5 ]
[.4875 .53929 -6 -4.5 ]
[.4875 .53929 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.10659 .30902 m
.10659 .31527 L
s
[(-1.5)] .10659 .29652 0 1 Mshowa
.23773 .30902 m
.23773 .31527 L
s
[(-1)] .23773 .29652 0 1 Mshowa
.36886 .30902 m
.36886 .31527 L
s
[(-0.5)] .36886 .29652 0 1 Mshowa
.63114 .30902 m
.63114 .31527 L
s
[(0.5)] .63114 .29652 0 1 Mshowa
.76227 .30902 m
.76227 .31527 L
s
[(1)] .76227 .29652 0 1 Mshowa
.89341 .30902 m
.89341 .31527 L
s
[(1.5)] .89341 .29652 0 1 Mshowa
.125 Mabswid
.13282 .30902 m
.13282 .31277 L
s
.15905 .30902 m
.15905 .31277 L
s
.18527 .30902 m
.18527 .31277 L
s
.2115 .30902 m
.2115 .31277 L
s
.26395 .30902 m
.26395 .31277 L
s
.29018 .30902 m
.29018 .31277 L
s
.31641 .30902 m
.31641 .31277 L
s
.34264 .30902 m
.34264 .31277 L
s
.39509 .30902 m
.39509 .31277 L
s
.42132 .30902 m
.42132 .31277 L
s
.44755 .30902 m
.44755 .31277 L
s
.47377 .30902 m
.47377 .31277 L
s
.52623 .30902 m
.52623 .31277 L
s
.55245 .30902 m
.55245 .31277 L
s
.57868 .30902 m
.57868 .31277 L
s
.60491 .30902 m
.60491 .31277 L
s
.65736 .30902 m
.65736 .31277 L
s
.68359 .30902 m
.68359 .31277 L
s
.70982 .30902 m
.70982 .31277 L
s
.73605 .30902 m
.73605 .31277 L
s
.7885 .30902 m
.7885 .31277 L
s
.81473 .30902 m
.81473 .31277 L
s
.84095 .30902 m
.84095 .31277 L
s
.86718 .30902 m
.86718 .31277 L
s
.08036 .30902 m
.08036 .31277 L
s
.05414 .30902 m
.05414 .31277 L
s
.02791 .30902 m
.02791 .31277 L
s
.00168 .30902 m
.00168 .31277 L
s
.91964 .30902 m
.91964 .31277 L
s
.94586 .30902 m
.94586 .31277 L
s
.97209 .30902 m
.97209 .31277 L
s
.99832 .30902 m
.99832 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .07874 m
.50625 .07874 L
s
[(-2)] .4875 .07874 1 0 Mshowa
.5 .19388 m
.50625 .19388 L
s
[(-1)] .4875 .19388 1 0 Mshowa
.5 .42415 m
.50625 .42415 L
s
[(1)] .4875 .42415 1 0 Mshowa
.5 .53929 m
.50625 .53929 L
s
[(2)] .4875 .53929 1 0 Mshowa
.125 Mabswid
.5 .10177 m
.50375 .10177 L
s
.5 .1248 m
.50375 .1248 L
s
.5 .14782 m
.50375 .14782 L
s
.5 .17085 m
.50375 .17085 L
s
.5 .21691 m
.50375 .21691 L
s
.5 .23993 m
.50375 .23993 L
s
.5 .26296 m
.50375 .26296 L
s
.5 .28599 m
.50375 .28599 L
s
.5 .33204 m
.50375 .33204 L
s
.5 .35507 m
.50375 .35507 L
s
.5 .3781 m
.50375 .3781 L
s
.5 .40113 m
.50375 .40113 L
s
.5 .44718 m
.50375 .44718 L
s
.5 .47021 m
.50375 .47021 L
s
.5 .49324 m
.50375 .49324 L
s
.5 .51627 m
.50375 .51627 L
s
.5 .05571 m
.50375 .05571 L
s
.5 .03269 m
.50375 .03269 L
s
.5 .00966 m
.50375 .00966 L
s
.5 .56232 m
.50375 .56232 L
s
.5 .58535 m
.50375 .58535 L
s
.5 .60838 m
.50375 .60838 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.87195 .43955 m
.90589 .47119 L
.9349 .50184 L
.95822 .53173 L
.96618 .54468 L
.96894 .54997 L
.97143 .55545 L
.97336 .56054 L
.9747 .565 L
.9752 .56711 L
.97558 .56905 L
.97588 .57101 L
.976 .57203 L
.97609 .57311 L
.97616 .57422 L
.97619 .57523 L
.97619 .5758 L
.97618 .57632 L
.97617 .57691 L
.97614 .57746 L
.97607 .57845 L
.97597 .57934 L
.97583 .5803 L
.97565 .5813 L
.97525 .58297 L
.97478 .58448 L
.97334 .58769 L
.97237 .58928 L
.97136 .59067 L
.96862 .59355 L
.96571 .59579 L
.96211 .59785 L
.95845 .59942 L
.95464 .60065 L
.95004 .60173 L
.94727 .60222 L
.94461 .60259 L
.94175 .60289 L
.93906 .60309 L
.93752 .60318 L
.9367 .60321 L
.93583 .60325 L
.93419 .60329 L
.93266 .60331 L
.93123 .60332 L
.92966 .60331 L
.92817 .60328 L
.92678 .60324 L
.92513 .60318 L
.92331 .6031 L
Mistroke
.91991 .60289 L
.9158 .60255 L
.91196 .60217 L
.90296 .60102 L
.88543 .59798 L
.84683 .58856 L
.79885 .57332 L
.68876 .52904 L
.56963 .47119 L
.45051 .40515 L
.32729 .32835 L
.22015 .25306 L
.12657 .17717 L
.08976 .14252 L
.06255 .11325 L
.04176 .08628 L
.03442 .07444 L
.02937 .06444 L
.0275 .05989 L
.02589 .05515 L
.02473 .05063 L
.0243 .04828 L
.02414 .04716 L
.02402 .04615 L
.02391 .04504 L
.02387 .04445 L
.02384 .04385 L
.02381 .04284 L
.02381 .04227 L
.02382 .04175 L
.02385 .04078 L
.0239 .03992 L
.024 .03893 L
.02412 .03802 L
.02429 .03706 L
.0245 .03606 L
.02497 .03432 L
.02562 .03252 L
.0265 .03064 L
.02839 .02769 L
.03091 .02491 L
.0335 .02279 L
.03678 .02075 L
.04085 .01888 L
.04332 .018 L
.04581 .01726 L
.04826 .01666 L
.05105 .0161 L
.05373 .01567 L
.05629 .01534 L
Mistroke
.05902 .01508 L
.06058 .01497 L
.06208 .01488 L
.06349 .01481 L
.06482 .01477 L
.06631 .01473 L
.06792 .01472 L
.06885 .01472 L
.06972 .01472 L
.07068 .01473 L
.0717 .01475 L
.07345 .0148 L
.0754 .01487 L
.07717 .01496 L
.0791 .01508 L
.08266 .01535 L
.0915 .01627 L
.1004 .01752 L
.11839 .02084 L
.15902 .03115 L
.20184 .04496 L
.30696 .08709 L
.42028 .14161 L
.54619 .21095 L
.66441 .28422 L
.77826 .36379 L
.86872 .43669 L
.87195 .43955 L
Mfstroke
.5 .30902 m
.87195 .43955 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00OS7oo00<007ooOol0
RWoo002<Ool00`00Oomoo`2:Ool008aoo`03001oogoo08Yoo`00S7oo0P00Rgoo002<Ool00`00Oomo
o`2:Ool000aooa<006eoo`03001oogoo08Yoo`002Woo0`004Woo1000JGoo00<007ooOol0RWoo0008
Ool2000IOol4001UOol00`00Oomoo`2:Ool000Moo`03001oogoo01eoo`@0065oo`03001oogoo08Yo
o`001goo00<007ooOol08Goo0`00GWoo00<007ooOol0RWoo0007Ool00`00Oomoo`0TOol3001KOol2
002;Ool000Ioo`03001oogoo02Qoo`<005Qoo`03001oogoo08Yoo`001Woo00<007ooOol0:goo0`00
EGoo00<007ooOol0RWoo0006Ool00`00Oomoo`0^Ool3001BOol00`00Oomoo`2:Ool000Ioo`03001o
ogoo035oo`80051oo`03001oogoo08Yoo`001Woo00<007ooOol0<goo0`00CGoo00<007ooOol0RWoo
0007Ool00`00Oomoo`0eOol2001;Ool2002;Ool000Moo`03001oogoo03Moo`8004Uoo`03001oogoo
08Yoo`001goo00<007ooOol0>Goo0`00AWoo00<007ooOol0RWoo0008Ool00`00Oomoo`0kOol20014
Ool00`00Oomoo`2:Ool000Qoo`03001oogoo03eoo`<0045oo`03001oogoo08Yoo`002Goo00<007oo
Ool0?goo0P00=goo0`001Goo00<007ooOol0RWoo0009Ool00`00Oomoo`11Ool2000eOol00`00Oomo
o`05Ool00`00Oomoo`2:Ool000Yoo`03001oogoo049oo`<002eoo`<000=oo`03001oogoo00Aoo`80
08]oo`002Woo00<007ooOol0AGoo0P00<Goo00<007ooOol017oo00<007ooOol0RWoo000;Ool00`00
Oomoo`16Ool3000]Ool00`00Ool00005Ool00`00Oomoo`2:Ool000aoo`03001oogoo04Qoo`8002ao
o`03001oogoo00Aoo`03001oogoo08Yoo`003Goo00<007ooOol0BGoo0P00<Goo00<007ooOol0RWoo
000>Ool00`00Oomoo`1:Ool2000_Ool00`00Oomoo`2:Ool000ioo`03001oogoo04aoo`8002eoo`80
08]oo`003goo00<007ooOol0CGoo0P00:goo00<007ooOol0RWoo000@Ool00`00Oomoo`1>Ool2000Y
Ool00`00Oomoo`2:Ool0015oo`03001oogoo04moo`8002Moo`03001oogoo08Yoo`004Woo00<007oo
Ool0D7oo0`0097oo00<007ooOol0RWoo000COol00`00Oomoo`1BOol2000ROol00`00Oomoo`2:Ool0
01Aoo`03001oogoo05=oo`80021oo`8008]oo`005Goo00<007ooOol0E7oo0P007Woo00<007ooOol0
RWoo000FOol00`00Oomoo`1EOol2000LOol00`00Oomoo`2:Ool001Moo`03001oogoo05Ioo`8001Yo
o`03001oogoo08Yoo`0067oo00<007ooOol0Egoo0P0067oo00<007ooOol0RWoo000IOol00`00Oomo
o`1HOol2000FOol00`00Oomoo`2:Ool001Yoo`03001oogoo05Uoo`8001Aoo`03001oogoo08Yoo`00
6goo00<007ooOol0FWoo0P004Woo0P00Rgoo000LOol00`00Oomoo`1KOol2000@Ool00`00Oomoo`2:
Ool001eoo`03001oogoo05aoo`03001oogoo00eoo`03001oogoo08Yoo`007Woo00<007ooOol0G7oo
0P003Goo00<007ooOol0RWoo000OOol00`00Oomoo`1MOol2000;Ool00`00Oomoo`2:Ool0021oo`03
001oogoo05ioo`8000Uoo`03001oogoo08Yoo`008Goo00<007ooOol0Ggoo00<007ooOol01Woo0P00
Rgoo000ROol00`00Oomoo`1OOol20006Ool00`00Oomoo`2:Ool002=oo`03001oogoo061oo`8000Ao
o`03001oogoo08Yoo`0097oo00<007ooOol0HGoo0P000Woo00<007ooOol0RWoo000UOol2001SOol0
0`00Ool0002<Ool002Moo`03001oogoo05Uoo`D000=oo`8008aoo`00:7oo00<007ooOol0FWoo00<0
07ooOol017oo0`00RWoo000YOol00`00Oomoo`1COol30003Ool00`00Oomoo`04Ool200000goo0000
0028Ool002Yoo`8005Uoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo08Eoo`00;7oo00<0
07ooOol0EWoo00<007ooOol017oo00<007ooOol00goo0P00QGoo000]Ool00`00Oomoo`1DOol20006
Ool00`00Oomoo`05Ool20023Ool002ioo`03001oogoo05]oo`03001oogoo00Moo`80085oo`00;goo
00<007ooOol0FWoo00<007ooOol02Goo00<007ooOol0OWoo000`Ool2001JOol2000;Ool2001nOol0
039oo`03001oogoo05Moo`03001oogoo00aoo`8007aoo`00<goo00<007ooOol0EWoo00<007ooOol0
3Woo00<007ooOol0NGoo000dOol00`00Oomoo`1EOol00`00Oomoo`0?Ool2001iOol003Eoo`8005Eo
o`03001oogoo015oo`8007Moo`00=goo00<007ooOol0DWoo00<007ooOol04goo0P00MGoo000hOol0
0`00Oomoo`1AOol00`00Oomoo`0EOol00`00Oomoo`1bOol003Uoo`03001oogoo051oo`8001Moo`80
079oo`00>Woo0P00D7oo00<007ooOol067oo0P00L7oo000lOol00`00Oomoo`1=Ool00`00Oomoo`0J
Ool00`00Oomoo`1]Ool003eoo`03001oogoo04aoo`03001oogoo01]oo`8006eoo`00?Woo0P00C7oo
00<007ooOol07Goo0P00Jgoo0010Ool00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`1XOol0
045oo`03001oogoo04Qoo`80025oo`8006Qoo`00@Woo0P00B7oo00<007ooOol08Woo0P00IWoo000H
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`0KOol5000MOol00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0KOol00`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomoo`03000LOol5000KOol5
0002Ool00`00Oomoo`02Ool00`00Oomoo`0HOol001Yoo`03001oogoo00Ioo`03001oo`0001ioo`<0
01aoo`03001oo`0000Moo`03001oo`0001aoo`03001oogoo01]oo`03001oo`0000Moo`<001eoo`03
001oogoo01eoo`03001oogoo00Ioo`03001oo`0001Uoo`0057oo0`000goo00<007ooOol027oo00<0
07ooOol05Woo0`000goo00@007ooOol001Ioo`<0009oo`03001oo`0000Uoo`03001oogoo01Yoo`03
001oogoo01]oo`03001oo`0000Uoo`8001aoo`03001oogoo01eoo`03001oogoo00Qoo`03001oogoo
01Moo`006Woo00<007ooOol01Woo0P007goo00@007ooOomoo`8001Uoo`03001oo`0000Moo`8001eo
o`03001oogoo01]oo`03001oo`0000Moo`80009oo`8001Yoo`03001oogoo01eoo`03001oogoo00Io
o`8001Yoo`006Woo00<007ooOol01Woo00<007ooOol07Woo00<007ooOol00goo00<007ooOol05Woo
00<007oo00001goo00<007ooOol077oo00<007ooOol06goo00<007oo00001goo00<007ooOol00goo
00<007ooOol05goo00<007ooOol07Goo00<007ooOol01Woo00<007ooOol06Goo000IOol20008Ool3
000MOol20006Ool00`00Oomoo`0FOol00`00Oomoo`06Ool3000LOol2000MOol00`00Oomoo`06Ool3
0004Ool2000FOol2000NOol20008Ool3000IOol004aoo`8003ioo`03001oogoo02ioo`03001oogoo
05Uoo`00CWoo00<007ooOol0>goo00<007ooOol0;goo00<007ooOol0F7oo001?Ool2000kOol00`00
Oomoo`0`Ool2001HOol0055oo`03001oogoo03Qoo`03001oogoo039oo`03001oogoo05Eoo`00DWoo
0P00>7oo00<007ooOol0<goo0P00EGoo003o000I0001Ool00003001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`05001oogooOol0
0002Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Ool000020002Ool00`00Oomoo`04Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool20007Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool10001Ool001eoo`03001oogoo029oo`03001oogoo015oo`8000moo`03001o
ogoo029oo`03001oogoo009oo`<001aoo`03001oogoo01=oo`8000eoo`03001oogoo029oo`03001o
ogoo01aoo`00F7oo00<007ooOol0<Goo00<007ooOol01Goo0P00<Woo00<007ooOol0CWoo001IOol2
000aOol00`00Oomoo`07Ool3000`Ool2001>Ool005]oo`03001oogoo02ioo`03001oogoo00Yoo`<0
02moo`03001oogoo04]oo`00G7oo0P00;Woo0P003Woo0`00;Goo0P00Bgoo001NOol00`00Oomoo`0[
Ool00`00Oomoo`0@Ool3000/Ool00`00Oomoo`18Ool005moo`8002]oo`03001oogoo01=oo`8002]o
o`03001oogoo04Moo`00HGoo0P00:Goo00<007ooOol05Goo0`00:Goo0P00Agoo001SOol00`00Oomo
o`0VOol00`00Oomoo`0HOol3000XOol00`00Oomoo`14Ool006Aoo`8002Ioo`03001oogoo01]oo`<0
02Ioo`8004Aoo`00IWoo00<007ooOol08goo00<007ooOol07Woo0`009Goo00<007ooOol0@Goo001W
Ool2000SOol2000ROol2000TOol00`00Oomoo`10Ool006Uoo`80025oo`03001oogoo02=oo`<0029o
o`80041oo`00Jgoo00<007ooOol07Woo00<007ooOol09Woo0`008Goo00<007ooOol0?Goo001/Ool2
000NOol00`00Oomoo`0YOol3000OOol00`00Oomoo`0lOol006ioo`03001oogoo01]oo`03001oogoo
02aoo`<001eoo`8003aoo`00Kgoo0P006goo00<007ooOol0;goo0P007Goo00<007ooOol0>Goo001a
Ool2000IOol2000bOol3000KOol00`00Oomoo`0hOol007=oo`03001oogoo01Ioo`03001oogoo03Ao
o`<001Uoo`03001oogoo03Moo`00M7oo0P005Woo00<007ooOol0=goo0`005goo0P00=goo001fOol0
0`00Oomoo`0COol00`00Oomoo`0jOol3000FOol00`00Oomoo`0dOol007Moo`8001=oo`03001oogoo
03eoo`<001Aoo`03001oogoo03=oo`00NGoo0P004Goo00<007ooOol0@7oo0P004goo00<007ooOol0
<Woo001kOol00`00Oomoo`0>Ool00`00Oomoo`12Ool3000AOol00`00Oomoo`0aOol007aoo`8000io
o`8004Ioo`<000moo`80035oo`00OWoo00<007ooOol02goo00<007ooOol0B7oo0`003Woo00<007oo
Ool0;Woo001oOol2000;Ool00`00Oomoo`1;Ool3000<Ool00`00Oomoo`0]Ool0085oo`8000Uoo`03
001oogoo04ioo`8000]oo`03001oogoo02aoo`00Pgoo1@0017oo00<007ooOol0D7oo0`002Goo0P00
;7oo0025Ool20005Ool00`00Oomoo`1COol30008Ool00`00Oomoo`0YOol008Eoo`04001oo`000003
Ool2001GOol30006Ool00`00Oomoo`0XOol008Eoo`05001oogooOol00002Ool00`00Oomoo`1IOol3
0004Ool00`00Oomoo`0WOol008Eoo`03001oogoo009oo`<005ioo`8000=oo`8002Moo`00Q7oo0P00
1Woo0P00Ggoo0`000Woo00<007ooOol097oo002<Ool01000Ool00000H7oo10009Goo002<Ool01000
Oomoogoo0P00HGoo0P0097oo002<Ool00`00Oomoo`03Ool2001QOol00`00Oomoo`0QOol008aoo`80
00Ioo`03001oogoo05moo`03001oogoo021oo`00S7oo00<007ooOol01Woo0P00H7oo00<007ooOol0
7goo002<Ool00`00Oomoo`08Ool2001OOol2000OOol008aoo`03001oogoo00Yoo`8005moo`03001o
ogoo01aoo`00S7oo00<007ooOol037oo0P00GWoo00<007ooOol06goo002<Ool00`00Oomoo`0>Ool2
001MOol00`00Oomoo`0JOol008aoo`80015oo`03001oogoo05]oo`03001oogoo01Uoo`00S7oo00<0
07ooOol04Goo0P00G7oo00<007ooOol067oo002<Ool00`00Oomoo`0COol2001KOol00`00Oomoo`0G
Ool008aoo`03001oogoo01Eoo`8005Yoo`03001oogoo01Ioo`00S7oo00<007ooOol05goo0P00FGoo
00<007ooOol05Goo002<Ool00`00Oomoo`0IOol2001GOol00`00Oomoo`0EOol008aoo`03001oogoo
01]oo`8005Ioo`03001oogoo01Aoo`00S7oo0P007Woo0P00EGoo00<007ooOol04goo002<Ool00`00
Oomoo`0OOol2001DOol00`00Oomoo`0BOol008aoo`03001oogoo025oo`8005=oo`03001oogoo015o
o`00S7oo00<007ooOol08goo0P00DWoo00<007ooOol047oo002<Ool00`00Oomoo`0UOol2001AOol0
0`00Oomoo`0?Ool008aoo`03001oogoo02Moo`80051oo`03001oogoo00ioo`00S7oo0P00:Woo0P00
CWoo00<007ooOol03Woo002<Ool00`00Oomoo`0[Ool2001=Ool00`00Oomoo`0=Ool008aoo`03001o
ogoo02eoo`8004aoo`03001oogoo00aoo`00S7oo00<007ooOol0;goo0P00Bgoo00<007ooOol02goo
0024Ool30005Ool00`00Oomoo`0aOol2001:Ool00`00Oomoo`0:Ool008Aoo`03001oogoo00Eoo`03
001oogoo03=oo`8004Qoo`03001oogoo00Yoo`00QGoo00<007ooOol017oo0P00=Woo0`00AWoo00<0
07ooOol02Goo0025Ool00`00Oomoo`04Ool00`00Oomoo`0hOol30013Ool00`00Oomoo`09Ool008Ao
o`03001oo`0000Eoo`03001oogoo03]oo`80049oo`03001oogoo00Qoo`00QGoo00<007ooOol017oo
00<007ooOol0?Goo0`00@7oo00<007ooOol01goo002<Ool00`00Oomoo`10Ool2000nOol00`00Oomo
o`07Ool008aoo`03001oogoo049oo`<003]oo`03001oogoo00Moo`00S7oo00<007ooOol0AGoo0P00
>Woo00<007ooOol01Woo002<Ool20018Ool3000gOol00`00Oomoo`06Ool008aoo`03001oogoo04Yo
o`<003Aoo`8000Moo`00S7oo00<007ooOol0CGoo0P00<goo00<007ooOol01Goo002<Ool00`00Oomo
o`1?Ool3000`Ool00`00Oomoo`05Ool008aoo`03001oogoo059oo`@002aoo`03001oogoo00Eoo`00
S7oo00<007ooOol0EWoo0`00:Goo00<007ooOol01Goo002<Ool2001JOol4000TOol20007Ool008ao
o`03001oogoo05eoo`<0025oo`03001oogoo00Ioo`00S7oo00<007ooOol0H7oo0`007Goo00<007oo
Ool01goo002<Ool00`00Oomoo`1SOol4000HOol20009Ool008aoo`03001oogoo06Moo`@0019oo`80
00]oo`00S7oo00<007ooOol0Jgoo4P003Goo002<Ool00`00Oomoo`2:Ool008aoo`8008]oo`00S7oo
00<007ooOol0RWoo002<Ool00`00Oomoo`2:Ool00001\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-1.90697, -2.68391, 0.0136212, 
  0.0310277}}]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Four-Bar Example"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another useful manipulation of the mass matrix is to find a minimal mass \
matrix for a model with a non-minimal coordinate system. While this can \
theoretically be done with or without generalized coordinates, it often \
becomes intractable when modeling in Cartesian coordinates because of the \
need to invert a large symbolic matrix.\n\nThe four-bar model that was \
developed previously in this notebook is used again here to demonstrate the \
formulation of a minimal mass matrix. In this case, the minimal mass matrix \
is a 1x1 matrix because the four-bar model has only one degree of freedom. \
Since the four-bar is modeled with three generalized coordinates ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the default mass matrix generated by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " is a 3x3 matrix; the task at hand is to reduce it to 1x1.\n\nSince the \
Generalized Coordinate Package was loaded into Mathematica in the last \
section, it does not need to be loaded again here. Note, however, that \
inertia properties are included in the body objects of this version of the \
four-bar."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This clears all data in the current ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ClearMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies and Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The entire four-bar model is redefined without explanation here, because its \
kinematics are completely documented in a previous section."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the body objects for the four-bar model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      bd[1] = Body[ground = 1, PointList \[Rule] {{\(-2\), 3}}], \n\t
      bd[2] = Body[drivebar = 2, PointList \[Rule] {{1, 0}}, \n\t\t\t
          Mass \[Rule] 5, Inertia \[Rule] 1], \n\t
      bd[3] = Body[drivenbar = 3, PointList \[Rule] {{3, 0}}, \n\t\t\t
          Mass \[Rule] 2, Inertia \[Rule] 4, 
          InitialGuess \[Rule] {{\(-2\), 3}, 0}], 
      bd[4] = Body[centerbar = 4, PointList \[Rule] {{0, 3}, {1, 2}}, \n\t\t\t
          Mass \[Rule] 3, Inertia \[Rule] 12, 
          InitialGuess \[Rule] {{1, 0}, 0}]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the generalized coordinate constraint objects."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs[1] = RotationLock1[1, drivebar, 2.0  \[Pi]\ T], \n\t
      cs[2] = GenRevolute2[2, Axis[drivebar, 0, X], \n\t\t\t
          Axis[ground, 0, X], {alpha, 0.0}], \n\t
      cs[3] = GenRevolute2[3, Axis[centerbar, 0, X], \n\t\t\t
          Axis[drivebar, 1, X], {beta, 0.0}], \n\t
      cs[4] = GenRevolute2[4, Axis[drivenbar, 1, X], \n\t\t\t
          Axis[centerbar, 1, X], {gamma, 0.0}], \n\t
      cs[5] = Revolute2[5, Point[drivenbar, 0], \n\t\t\tPoint[ground, 1]]]\)],
   "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Mass Matrix"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "We intend to transform the 3x3 system mass matrix ",
  StyleBox["M",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " into a 1x1 mass matrix ",
  StyleBox["m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " where ",
  StyleBox["f = m.alphadd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["f",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the generalized force in the direction of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is simply a counterclockwise moment applied to the drive bar. This \
transformation is of the form ",
  StyleBox["m = Transpose[J].M.J",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nThe necessary transformation matrix ",
  StyleBox["J",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converts motions in all three generalized coordinates into motions of the \
single coordinate ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This matrix ",
  StyleBox["J",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is created by inverting the part of the model's Jacobian associated with \
",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and multiplying it by the part associated with ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The resulting 2x1 matrix converts ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " only into ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", so it must be prepended with a 1 to convert ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " into all three coordinates.\n\nOnly the part of the Jacobian associated \
with constraint 5 is included in the calculation because the driving \
constraint (constraint 1) must be dropped for the model to have more than \
zero degrees of freedom, and the other 3 generalized coordinate constraints \
contribute no constraint equations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the 3x1 transformation matrix ",
  StyleBox["J",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(J = 
      Prepend[\(-Inverse[Jacobian[5, {beta, gamma}]].Jacobian[5, alpha]\), {
          1}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the 3x3 system mass matrix."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(M = Simplify[MassMatrix[All]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(-2\)\ 
          \((\(-29\) + 6\ Cos[beta + gamma] + 6\ Sin[beta] + 18\ Sin[gamma])
            \), 52 - 6\ Cos[beta + gamma] - 6\ Sin[beta] - 36\ Sin[gamma], 
        22 - 6\ Cos[beta + gamma] - 18\ Sin[gamma]}, {
        52 - 6\ Cos[beta + gamma] - 6\ Sin[beta] - 36\ Sin[gamma], 
        52 - 36\ Sin[gamma], 22 - 18\ Sin[gamma]}, {
        22 - 6\ Cos[beta + gamma] - 18\ Sin[gamma], 22 - 18\ Sin[gamma], 22}}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the 1x1 mass matrix in terms of the coordinate alpha."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(m = Transpose[J].M.J; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Since ",
  StyleBox["m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a 1x1 matrix it may as well be a scalar, and the acceleration that \
results from applying a moment to the drive bar is simply ",
  StyleBox["alphadd = f/m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Remember that ",
  StyleBox["m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is still a function of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and not just any set of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["gamma",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will do (unlike the two-link manipulator in which any values of the \
coordinates could be specified). ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be used to find a set of coordinates that represents a valid \
configuration of the four-bar model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["The 1x1 matrix m is converted to a scalar."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(m = m\[LeftDoubleBracket]1, 1\[RightDoubleBracket]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the configuration of the four-bar at 1/8 turn of the drive bar."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(config = SolveMech[1\/8]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 1\/8, alpha \[Rule] 0.785398163397448278`, 
      beta \[Rule] \(-0.855504454513781276`\), 
      gamma \[Rule] 0.305520531991373855`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the acceleration that results from a 10 unit moment applied to the \
drive bar."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(a = 10\/m /. config\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(2.16888423880179903`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Dynamic Motion"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The constrained dynamic motion profile of the four-bar can be found with \
the ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions, as described in Chapter 10 of the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " manual. In this example, the drive bar is given an initial angular \
velocity of 2 pi radians/second, a condition that is inherent in the \
definition of constraint 1. Constraint 1 is dropped from the model, and the \
free motion of the underconstrained system is found. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 to make initial conditions available to ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SolveMech[0, Solution \[Rule] Velocity]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that contains the dynamical equations of motion, with constraint 1 \
dropped."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(fsys = SetFree[1, Solution \[Rule] Dynamic]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(FreeSystem[Dynamic, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object ",
  StyleBox["fsys",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is integrated in the time domain from ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.0 to 2.0 with ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". All initial conditions for the integration are taken from the most \
recent solution returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the time domain solution."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = SolveFree[fsys, 1.0]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"alpha", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 1.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"beta", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 1.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"gamma", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 1.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of the angular velocity of the drive bar through \
approximately one full revolution of the drive bar."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[\[PartialD]\_T\((alpha /. sol)\)], {T, 0., 1.}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -2.74711 0.530808 [
[.21429 .42524 -9 -9 ]
[.21429 .42524 9 0 ]
[.40476 .42524 -9 -9 ]
[.40476 .42524 9 0 ]
[.59524 .42524 -9 -9 ]
[.59524 .42524 9 0 ]
[.78571 .42524 -9 -9 ]
[.78571 .42524 9 0 ]
[.97619 .42524 -3 -9 ]
[.97619 .42524 3 0 ]
[.01131 .01309 -18 -4.5 ]
[.01131 .01309 0 4.5 ]
[.01131 .11925 -18 -4.5 ]
[.01131 .11925 0 4.5 ]
[.01131 .22542 -18 -4.5 ]
[.01131 .22542 0 4.5 ]
[.01131 .33158 -18 -4.5 ]
[.01131 .33158 0 4.5 ]
[.01131 .5439 -18 -4.5 ]
[.01131 .5439 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .43774 m
.21429 .44399 L
s
[(0.2)] .21429 .42524 0 1 Mshowa
.40476 .43774 m
.40476 .44399 L
s
[(0.4)] .40476 .42524 0 1 Mshowa
.59524 .43774 m
.59524 .44399 L
s
[(0.6)] .59524 .42524 0 1 Mshowa
.78571 .43774 m
.78571 .44399 L
s
[(0.8)] .78571 .42524 0 1 Mshowa
.97619 .43774 m
.97619 .44399 L
s
[(1)] .97619 .42524 0 1 Mshowa
.125 Mabswid
.07143 .43774 m
.07143 .44149 L
s
.11905 .43774 m
.11905 .44149 L
s
.16667 .43774 m
.16667 .44149 L
s
.2619 .43774 m
.2619 .44149 L
s
.30952 .43774 m
.30952 .44149 L
s
.35714 .43774 m
.35714 .44149 L
s
.45238 .43774 m
.45238 .44149 L
s
.5 .43774 m
.5 .44149 L
s
.54762 .43774 m
.54762 .44149 L
s
.64286 .43774 m
.64286 .44149 L
s
.69048 .43774 m
.69048 .44149 L
s
.7381 .43774 m
.7381 .44149 L
s
.83333 .43774 m
.83333 .44149 L
s
.88095 .43774 m
.88095 .44149 L
s
.92857 .43774 m
.92857 .44149 L
s
.25 Mabswid
0 .43774 m
1 .43774 L
s
.02381 .01309 m
.03006 .01309 L
s
[(5.2)] .01131 .01309 1 0 Mshowa
.02381 .11925 m
.03006 .11925 L
s
[(5.4)] .01131 .11925 1 0 Mshowa
.02381 .22542 m
.03006 .22542 L
s
[(5.6)] .01131 .22542 1 0 Mshowa
.02381 .33158 m
.03006 .33158 L
s
[(5.8)] .01131 .33158 1 0 Mshowa
.02381 .5439 m
.03006 .5439 L
s
[(6.2)] .01131 .5439 1 0 Mshowa
.125 Mabswid
.02381 .03963 m
.02756 .03963 L
s
.02381 .06617 m
.02756 .06617 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .14579 m
.02756 .14579 L
s
.02381 .17233 m
.02756 .17233 L
s
.02381 .19887 m
.02756 .19887 L
s
.02381 .25196 m
.02756 .25196 L
s
.02381 .2785 m
.02756 .2785 L
s
.02381 .30504 m
.02756 .30504 L
s
.02381 .35812 m
.02756 .35812 L
s
.02381 .38466 m
.02756 .38466 L
s
.02381 .4112 m
.02756 .4112 L
s
.02381 .46428 m
.02756 .46428 L
s
.02381 .49082 m
.02756 .49082 L
s
.02381 .51736 m
.02756 .51736 L
s
.02381 .57044 m
.02756 .57044 L
s
.02381 .59698 m
.02756 .59698 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .58806 m
.02499 .58806 L
.02605 .58805 L
.02729 .58803 L
.02846 .588 L
.02954 .58796 L
.03053 .58792 L
.03279 .58781 L
.03506 .58767 L
.03756 .58747 L
.04262 .58696 L
.04755 .58631 L
.05285 .58544 L
.06244 .58341 L
.07373 .58018 L
.08445 .57615 L
.09419 .57155 L
.10458 .56543 L
.11497 .55788 L
.12439 .5496 L
.14277 .5284 L
.16202 .49783 L
.18284 .45359 L
.22384 .33249 L
.26333 .19248 L
.28319 .12686 L
.3013 .07638 L
.31065 .05504 L
.32081 .0368 L
.32639 .02868 L
.33155 .02297 L
.3341 .02069 L
.33648 .01864 L
.33898 .0171 L
.34031 .01644 L
.34173 .01585 L
.343 .01542 L
.34416 .01512 L
.34532 .0149 L
.34642 .01477 L
.3477 .01472 L
.34889 .01475 L
.35018 .01489 L
.35084 .01499 L
.35156 .01497 L
.35225 .01514 L
.3529 .01534 L
.35414 .01578 L
.35691 .01713 L
.3593 .01871 L
Mistroke
.36191 .02085 L
.36656 .02578 L
.37151 .03252 L
.38041 .04897 L
.39073 .07473 L
.40187 .11068 L
.42205 .19491 L
.4631 .41234 L
.47299 .46176 L
.48357 .51017 L
.49271 .54523 L
.50264 .57379 L
.50796 .58545 L
.51287 .59352 L
.51529 .59662 L
.51756 .599 L
.5187 .59999 L
.51993 .60049 L
.5206 .60094 L
.5213 .60138 L
.52254 .60204 L
.52366 .60251 L
.52472 .60286 L
.52593 .60314 L
.52703 .60328 L
.52808 .60332 L
.52904 .60327 L
.53009 .60311 L
.53121 .60285 L
.53233 .60247 L
.53354 .60193 L
.53467 .60047 L
.53571 .59982 L
.54067 .59576 L
.54546 .59028 L
.54789 .58693 L
.55056 .58183 L
.55973 .5653 L
.58048 .51624 L
.62065 .41725 L
.6391 .37863 L
.65931 .34459 L
.67932 .32009 L
.69024 .31061 L
.70041 .30418 L
.70545 .30187 L
.70811 .30086 L
.71092 .29996 L
.71338 .2993 L
.71468 .29901 L
Mistroke
.71608 .29874 L
.71854 .2984 L
.71966 .29827 L
.72085 .29815 L
.72208 .29807 L
.72323 .29802 L
.72393 .298 L
.72459 .29799 L
.72582 .298 L
.72701 .29804 L
.72809 .2981 L
.72929 .29819 L
.73055 .29832 L
.73161 .29845 L
.73274 .29867 L
.73478 .29904 L
.73943 .30018 L
.74472 .30198 L
.74961 .30417 L
.76068 .3106 L
.77044 .3181 L
.78081 .32776 L
.81858 .37465 L
.8588 .43827 L
.89751 .49799 L
.91717 .52433 L
.93867 .54782 L
.95811 .56428 L
.97619 .57549 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`005Goo00<007ooOol0ogoo0Woo0005Ool0
0`00Oomoo`02Ool01000Oomoogoo0`0017oo00<007ooOol0ogoo0Woo0004Ool00`00Ool00007Ool0
0`00Oomoo`04Ool00`00Oomoo`3oOol2Ool000Ioo`03001oogoo00Ioo`03001oogoo00=oo`800?mo
o`=oo`0017oo0P002Goo00<007ooOol00goo00<007ooOol0D7oo1P00Zgoo0004Ool00`00Oomoo`07
Ool00`00Ool00004Ool00`00Oomoo`1?Ool20005Ool00`00Oomoo`2XOol000Aoo`<000Qoo`03001o
ogoo00=oo`03001oogoo04ioo`03001oogoo00Ioo`800:Qoo`005Goo00<007ooOol0CGoo00<007oo
Ool027oo00<007ooOol0YWoo000EOol00`00Oomoo`1<Ool00`00Oomoo`0:Ool00`00Oomoo`2UOol0
01Eoo`03001oogoo04aoo`03001oogoo00Yoo`03001oogoo0:Eoo`005Goo0P00C7oo00<007ooOol0
37oo00<007ooOol0Y7oo000EOol00`00Oomoo`1;Ool00`00Oomoo`0<Ool00`00Oomoo`2TOol001Eo
o`03001oogoo04Yoo`03001oogoo00ioo`03001oogoo0:=oo`005Goo00<007ooOol0BWoo00<007oo
Ool03Woo00<007ooOol0Xgoo000EOol00`00Oomoo`19Ool00`00Oomoo`0?Ool00`00Oomoo`2SOol0
01Eoo`03001oogoo04Qoo`03001oogoo015oo`03001oogoo0:9oo`005Goo00<007ooOol0B7oo00<0
07ooOol04Goo00<007ooOol0XWoo000EOol20018Ool00`00Oomoo`0COol00`00Oomoo`2QOol001Eo
o`03001oogoo04Moo`03001oogoo01=oo`03001oogoo0:5oo`005Goo00<007ooOol0AWoo00<007oo
Ool05Goo00<007ooOol0X7oo000EOol00`00Oomoo`16Ool00`00Oomoo`0EOol00`00Oomoo`2POol0
01Eoo`03001oogoo04Ioo`03001oogoo01Ioo`03001oogoo09moo`005Goo00<007ooOol0AGoo00<0
07ooOol05goo00<007ooOol0Wgoo000EOol00`00Oomoo`15Ool00`00Oomoo`0GOol00`00Oomoo`2O
Ool001Eoo`8004Ioo`03001oogoo01Moo`03001oogoo09moo`005Goo00<007ooOol0A7oo00<007oo
Ool06Goo00<007ooOol0WWoo000EOol00`00Oomoo`14Ool00`00Oomoo`0IOol00`00Oomoo`2NOol0
01Eoo`03001oogoo04Aoo`03001oogoo01Uoo`03001oogoo09ioo`005Goo00<007ooOol0A7oo00<0
07ooOol06Woo00<007ooOol0WGoo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30003Ool00`00
Oomoo`13Ool00`00Oomoo`0KOol00`00Oomoo`2MOol000Aoo`03001oo`0000Uoo`03001oogoo009o
o`03001oogoo04=oo`03001oogoo01]oo`03001oogoo09eoo`001Woo00<007ooOol01Goo10000goo
0P00A7oo00<007ooOol06goo00<007ooOol0WGoo0004Ool20008Ool00`00Ool00004Ool00`00Oomo
o`12Ool00`00Oomoo`0MOol00`00Oomoo`2LOol000Aoo`03001oogoo00Qoo`8000Aoo`03001oogoo
049oo`03001oogoo01eoo`03001oogoo09aoo`0017oo0`002Goo00<007ooOol00Woo00<007ooOol0
@Woo00<007ooOol07Goo00<007ooOol0W7oo000EOol00`00Oomoo`11Ool00`00Oomoo`0NOol00`00
Oomoo`2LOol001Eoo`03001oogoo045oo`03001oogoo01moo`03001oogoo09]oo`005Goo00<007oo
Ool0@Goo00<007ooOol07goo00<007ooOol0Vgoo000EOol20011Ool00`00Oomoo`0POol00`00Oomo
o`2KOol001Eoo`03001oogoo041oo`03001oogoo021oo`03001oogoo09]oo`005Goo00<007ooOol0
@7oo00<007ooOol087oo00<007ooOol0Vgoo000EOol00`00Oomoo`0oOol00`00Oomoo`0ROol00`00
Oomoo`2JOol001Eoo`03001oogoo03moo`03001oogoo029oo`03001oogoo09Yoo`005Goo00<007oo
Ool0?goo00<007ooOol08Woo00<007ooOol0VWoo000EOol00`00Oomoo`0nOol00`00Oomoo`0SOol0
0`00Oomoo`2JOol001Eoo`8003moo`03001oogoo02Aoo`03001oogoo09Uoo`005Goo00<007ooOol0
?Woo00<007ooOol097oo00<007ooOol0VGoo000EOol00`00Oomoo`0mOol00`00Oomoo`0UOol00`00
Oomoo`2IOol001Eoo`03001oogoo03eoo`03001oogoo02Eoo`03001oogoo09Uoo`005Goo00<007oo
Ool0?Goo00<007ooOol09Woo00<007ooOol0V7oo000EOol00`00Oomoo`0lOol00`00Oomoo`0WOol0
0`00Oomoo`2HOol001Eoo`03001oogoo03aoo`03001oogoo02Moo`03001oogoo09Qoo`005Goo0P00
?Goo00<007ooOol09goo00<007ooOol0V7oo000EOol00`00Oomoo`0kOol00`00Oomoo`0XOol00`00
Oomoo`2HOol001Eoo`03001oogoo03]oo`03001oogoo02Uoo`03001oogoo09Moo`005Goo00<007oo
Ool0>goo00<007ooOol0:Goo00<007ooOol0Ugoo000EOol00`00Oomoo`0kOol00`00Oomoo`0YOol0
0`00Oomoo`2GOol000Eoo`03001oogoo009oo`04001oogooOol20005Ool00`00Oomoo`0jOol00`00
Oomoo`0ZOol00`00Oomoo`2GOol000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo03Yo
o`03001oogoo02Yoo`03001oogoo09Moo`001Woo00<007ooOol01Goo00<007oo000017oo0P00>goo
00<007ooOol0:goo00<007ooOol0UWoo0004Ool20008Ool20005Ool00`00Oomoo`0jOol00`00Oomo
o`0[Ool00`00Oomoo`2FOol000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo03Uoo`03
001oogoo02aoo`03001oogoo09Ioo`0017oo0`0027oo0P0017oo00<007ooOol0>Goo00<007ooOol0
;7oo00<007ooOol0UWoo000EOol00`00Oomoo`0iOol00`00Oomoo`0/Ool00`00Oomoo`2FOol001Eo
o`03001oogoo03Qoo`03001oogoo02eoo`03001oogoo09Ioo`005Goo00<007ooOol0>7oo00<007oo
Ool0;Woo00<007ooOol0UGoo000EOol2000iOol00`00Oomoo`0^Ool00`00Oomoo`2EOol001Eoo`03
001oogoo03Qoo`03001oogoo02ioo`03001oogoo09Eoo`005Goo00<007ooOol0=goo00<007ooOol0
;goo00<007ooOol0UGoo000EOol00`00Oomoo`0gOol00`00Oomoo`0_Ool00`00Oomoo`2EOol001Eo
o`03001oogoo03Moo`03001oogoo031oo`03001oogoo09Aoo`005Goo00<007ooOol0=goo00<007oo
Ool0<7oo00<007ooOol0U7oo000EOol00`00Oomoo`0fOol00`00Oomoo`0aOol00`00Oomoo`2DOol0
01Eoo`8003Moo`03001oogoo035oo`03001oogoo09Aoo`005Goo00<007ooOol0=Woo00<007ooOol0
<Goo00<007ooOol0U7oo000EOol00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`2COol001Eo
o`03001oogoo03Eoo`03001oogoo03=oo`03001oogoo09=oo`005Goo00<007ooOol0=Goo00<007oo
Ool0<goo00<007ooOol0Tgoo000EOol00`00Oomoo`0eOol00`00Oomoo`0cOol00`00Oomoo`2COol0
01Eoo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo04Aoo`T004Ioo`005Goo0P00=Goo00<0
07ooOol0=7oo00<007ooOol0@Woo0P002Goo0`00@goo000EOol00`00Oomoo`0dOol00`00Oomoo`0e
Ool00`00Oomoo`0oOol2000>Ool20011Ool001Eoo`03001oogoo03Aoo`03001oogoo03Eoo`03001o
ogoo03ioo`03001oogoo011oo`03001oogoo03ioo`005Goo00<007ooOol0<goo00<007ooOol0=Woo
00<007ooOol0?Goo00<007ooOol04Woo0P00?Woo000EOol00`00Oomoo`0cOol00`00Oomoo`0fOol0
0`00Oomoo`0lOol00`00Oomoo`0EOol00`00Oomoo`0kOol000Eoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo03=oo`03001oogoo03Ioo`03001oogoo03]oo`03001oogoo
01Moo`03001oogoo03Yoo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0<goo00<0
07ooOol0=goo00<007ooOol0>Goo00<007ooOol06Goo00<007ooOol0>Goo0006Ool00`00Oomoo`05
Ool00`00Ool00004Ool2000cOol00`00Oomoo`0hOol00`00Oomoo`0hOol00`00Oomoo`0KOol00`00
Oomoo`0hOol000Aoo`8000Uoo`03001oogoo00=oo`03001oogoo039oo`03001oogoo03Qoo`03001o
ogoo03Qoo`03001oogoo01aoo`03001oogoo03Moo`0017oo00<007ooOol01goo00<007oo000017oo
00<007ooOol0<Woo00<007ooOol0>7oo00<007ooOol0=goo00<007ooOol07Goo00<007ooOol0=goo
0004Ool30008Ool00`00Oomoo`03Ool00`00Oomoo`0aOol00`00Oomoo`0iOol00`00Oomoo`0fOol0
0`00Oomoo`0OOol00`00Oomoo`0fOol001Eoo`03001oogoo035oo`03001oogoo03Yoo`03001oogoo
03Aoo`03001oogoo025oo`03001oogoo03Eoo`005Goo00<007ooOol0<Goo00<007ooOol0>Woo00<0
07ooOol0<goo00<007ooOol08goo00<007ooOol0=7oo000EOol00`00Oomoo`0`Ool00`00Oomoo`0k
Ool00`00Oomoo`0cOol00`00Oomoo`0SOol00`00Oomoo`0dOol001Eoo`03001oogoo031oo`03001o
ogoo03]oo`03001oogoo039oo`03001oogoo02Eoo`03001oogoo03=oo`005Goo0P00<Goo00<007oo
Ool0>goo00<007ooOol0<Woo00<007ooOol09Woo00<007ooOol0<Woo000EOol00`00Oomoo`0_Ool0
0`00Oomoo`0mOol00`00Oomoo`0`Ool00`00Oomoo`0XOol00`00Oomoo`0aOol001Eoo`03001oogoo
02moo`03001oogoo03eoo`03001oogoo031oo`03001oogoo02Qoo`03001oogoo035oo`005Goo00<0
07ooOol0;goo00<007ooOol0?Goo00<007ooOol0;goo00<007ooOol0:Woo00<007ooOol0<7oo000E
Ool00`00Oomoo`0^Ool00`00Oomoo`0nOol00`00Oomoo`0_Ool00`00Oomoo`0[Ool00`00Oomoo`0_
Ool001Eoo`03001oogoo02ioo`03001oogoo03ioo`03001oogoo02ioo`03001oogoo02eoo`03001o
ogoo02ioo`005Goo00<007ooOol0;Woo00<007ooOol0?Woo00<007ooOol0;Goo00<007ooOol0;Woo
00<007ooOol0;Woo000EOol2000^Ool00`00Oomoo`10Ool00`00Oomoo`0/Ool00`00Oomoo`0_Ool0
0`00Oomoo`0]Ool001Eoo`03001oogoo02eoo`03001oogoo041oo`03001oogoo02]oo`03001oogoo
035oo`03001oogoo02aoo`005Goo00<007ooOol0:Woo00<007oo00000Woo00@007ooOomoo`<002Io
o`03001oogoo009oo`03001oogoo009oo`<000Moo`03001oogoo01aoo`03001oogoo009oo`04001o
ogooOol20004Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`0ROol50005Ool001Eoo`03001oogoo02Uoo`04001oo`000006Ool00`00Oomoo`0UOol0
0`00Ool00009Ool00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Ool00007Ool00`00Ool00002Ool0
0`00Oomoo`0POol00`00Ool00007Ool00`00Ool00006Ool00`00Oomoo`0SOol00`00Oomoo`05Ool0
01Eoo`03001oogoo02Uoo`04001oo`000007Ool00`00Oomoo`0TOol00`00Ool00007Ool40007Ool0
0`00Oomoo`0KOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`0POol00`00Ool00007Ool0
0`00Ool00007Ool00`00Oomoo`0ROol00`00Oomoo`05Ool001Eoo`03001oogoo02Uoo`03001oo`00
00Qoo`03001oogoo02Aoo`03001oo`0000Moo`03001oo`0000Uoo`03001oogoo01Yoo`03001oo`00
00Moo`80009oo`03001oogoo025oo`03001oo`0000Qoo`03001oogoo00Ioo`03001oogoo029oo`03
001oogoo00Eoo`005Goo00<007ooOol0:Goo00<007oo00001goo00<007oo00009Goo00<007oo0000
27oo0P002Goo00<007ooOol06Woo00<007oo00001goo00D007ooOomoo`0002=oo`03001oo`0000Mo
o`03001oo`0000Qoo`03001oogoo025oo`03001oogoo00Eoo`005Goo0P00:goo0P0027oo00<007oo
Ool09Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol06goo00<007ooOol01goo0`009Goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol087oo0P001goo000EOol00`00Oomoo`0ZOol0
0`00Oomoo`14Ool00`00Oomoo`0WOol00`00Oomoo`0hOol00`00Oomoo`0XOol001Eoo`03001oogoo
02Yoo`03001oogoo04Aoo`03001oogoo02Moo`03001oogoo03Uoo`03001oogoo02Moo`005Goo00<0
07ooOol0:Woo00<007ooOol0AGoo00<007ooOol09Goo00<007ooOol0>Woo00<007ooOol09goo000E
Ool00`00Oomoo`0YOol00`00Oomoo`16Ool00`00Oomoo`0UOol00`00Oomoo`0kOol00`00Oomoo`0V
Ool001Eoo`03001oogoo02Uoo`03001oogoo04Ioo`03001oogoo02Aoo`03001oogoo03eoo`03001o
ogoo02Eoo`005Goo00<007ooOol0:Goo00<007ooOol0AWoo00<007ooOol097oo00<007ooOol0?Goo
00<007ooOol09Goo000?Oooo000;000001Eoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Uoo`05001oogooOol00008Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool001Eoo`03001oogoo02Qoo`03001oogoo04Qoo`03001oogoo029o
o`03001oogoo041oo`03001oogoo02=oo`005Goo00<007ooOol09goo00<007ooOol0BGoo00<007oo
Ool08Goo00<007ooOol0@Woo00<007ooOol08Woo000EOol00`00Oomoo`0WOol00`00Oomoo`1:Ool0
0`00Oomoo`0POol00`00Oomoo`12Ool00`00Oomoo`0ROol001Eoo`03001oogoo02Ioo`03001oogoo
04]oo`03001oogoo01moo`03001oogoo04Aoo`03001oogoo025oo`005Goo00<007ooOol09Woo00<0
07ooOol0Bgoo00<007ooOol07goo00<007ooOol0AGoo00<007ooOol087oo000EOol2000VOol00`00
Oomoo`1<Ool00`00Oomoo`0NOol00`00Oomoo`16Ool00`00Oomoo`0POol001Eoo`03001oogoo02Eo
o`03001oogoo04aoo`03001oogoo01ioo`03001oogoo04Moo`03001oogoo01moo`005Goo00<007oo
Ool097oo00<007ooOol0CWoo00<007ooOol07Goo00<007ooOol0B7oo00<007ooOol07Woo000EOol0
0`00Oomoo`0TOol00`00Oomoo`1>Ool00`00Oomoo`0LOol00`00Oomoo`19Ool00`00Oomoo`0NOol0
01Eoo`03001oogoo02=oo`03001oogoo04moo`03001oogoo01aoo`03001oogoo04Yoo`03001oogoo
01eoo`005Goo00<007ooOol08goo00<007ooOol0Cgoo00<007ooOol06goo00<007ooOol0Bgoo00<0
07ooOol07Goo000EOol00`00Oomoo`0ROol00`00Oomoo`1AOol00`00Oomoo`0JOol00`00Oomoo`1<
Ool00`00Oomoo`0LOol001Eoo`8002=oo`03001oogoo055oo`03001oogoo01Yoo`03001oogoo04eo
o`03001oogoo01]oo`005Goo00<007ooOol08Goo00<007ooOol0DWoo00<007ooOol06Goo00<007oo
Ool0CWoo00<007ooOol06goo000EOol00`00Oomoo`0QOol00`00Oomoo`1BOol00`00Oomoo`0IOol0
0`00Oomoo`1?Ool00`00Oomoo`0JOol001Eoo`03001oogoo021oo`03001oogoo05Aoo`03001oogoo
01Moo`03001oogoo055oo`03001oogoo01Uoo`005Goo00<007ooOol087oo00<007ooOol0E7oo00<0
07ooOol05goo00<007ooOol0DWoo00<007ooOol067oo000EOol00`00Oomoo`0OOol00`00Oomoo`1E
Ool00`00Oomoo`0FOol00`00Oomoo`1DOol00`00Oomoo`0GOol001Eoo`03001oogoo01ioo`03001o
ogoo05Ioo`03001oogoo01Ioo`03001oogoo05Aoo`03001oogoo01Moo`005Goo0P007goo00<007oo
Ool0EWoo00<007ooOol05Woo00<007ooOol0EGoo00<007ooOol05Woo000EOol00`00Oomoo`0MOol0
0`00Oomoo`1HOol00`00Oomoo`0DOol00`00Oomoo`1GOol00`00Oomoo`0EOol001Eoo`03001oogoo
01eoo`03001oogoo05Qoo`03001oogoo01Aoo`03001oogoo05Qoo`03001oogoo01Aoo`005Goo00<0
07ooOol077oo00<007ooOol0FGoo00<007ooOol04goo00<007ooOol0FWoo00<007ooOol04goo000E
Ool00`00Oomoo`0KOol00`00Oomoo`1JOol00`00Oomoo`0COol00`00Oomoo`1KOol00`00Oomoo`0B
Ool000Aoo`8000Aoo`04001oogooOol30004Ool00`00Oomoo`0JOol00`00Oomoo`1LOol00`00Oomo
o`0BOol00`00Oomoo`1KOol00`00Oomoo`0BOol000Aoo`03001oo`0000Moo`03001oogoo00Aoo`03
001oogoo01Uoo`03001oogoo05eoo`03001oogoo015oo`03001oogoo05eoo`03001oogoo015oo`00
17oo00<007oo000027oo00<007ooOol00goo0P006Goo00<007ooOol0GWoo00<007ooOol04Goo00<0
07ooOol0GWoo00<007ooOol047oo0004Ool20009Ool00`00Oomoo`03Ool00`00Oomoo`0GOol00`00
Oomoo`1OOol00`00Oomoo`0AOol00`00Oomoo`1OOol00`00Oomoo`0?Ool000Aoo`03001oogoo00Mo
o`03001oo`0000Aoo`03001oogoo01Ioo`03001oogoo065oo`03001oogoo00moo`03001oogoo065o
o`03001oogoo00ioo`001Goo0P0027oo00<007ooOol00goo00<007ooOol05Goo00<007ooOol0HWoo
00<007ooOol03goo00<007ooOol0HWoo0P003Woo000EOol00`00Oomoo`0COol2001UOol00`00Oomo
o`0>Ool00`00Oomoo`1UOol00`00Oomoo`0;Ool001Eoo`03001oogoo019oo`03001oogoo06Ioo`03
001oogoo00eoo`03001oogoo06Ioo`03001oogoo00Yoo`005Goo00<007ooOol047oo0P00JGoo00<0
07ooOol037oo00<007ooOol0J7oo0P002Woo000EOol2000@Ool00`00Oomoo`1ZOol00`00Oomoo`0;
Ool00`00Oomoo`1ZOol20008Ool001Eoo`03001oogoo00aoo`<006eoo`03001oogoo00Yoo`03001o
ogoo06eoo`03001oogoo00Eoo`005Goo00<007ooOol02Goo0`00L7oo00<007ooOol02Woo00<007oo
Ool0MGoo000EOol00`00Oomoo`07Ool2001dOol00`00Oomoo`08Ool00`00Oomoo`1fOol001Eoo`X0
07Ioo`03001oogoo00Qoo`03001oogoo07Ioo`005Goo00<007ooOol0OGoo00<007ooOol01goo00<0
07ooOol0Mgoo000EOol00`00Oomoo`1nOol00`00Oomoo`05Ool00`00Oomoo`1hOol001Eoo`80081o
o`8000Aoo`03001oogoo07Uoo`005Goo00<007ooOol0P7oo1@00O7oo000EOol00`00Oomoo`22Ool0
0`00Oomoo`1lOol001Eoo`03001oogoo0?moo`9oo`005Goo00<007ooOol0ogoo0Woo000EOol00`00
Oomoo`3oOol2Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-0.0844519, 5.13888, 0.00396235, 
  0.00710928}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This removes all of the Mech packages."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{464, 668},
WindowMargins->{{107, Automatic}, {Automatic, 11}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 175, 6, 193, "Title"],

Cell[CellGroupData[{
Cell[1931, 61, 78, 2, 47, "Subsection"],
Cell[2012, 65, 2196, 45, 453, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4245, 115, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[4373, 120, 336, 11, 52, "Text"],

Cell[CellGroupData[{
Cell[4734, 135, 94, 2, 47, "Subsection"],
Cell[4831, 139, 544, 15, 90, "Text"],

Cell[CellGroupData[{
Cell[5400, 158, 414, 13, 72, "Special3"],
Cell[5817, 173, 121, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[5953, 179, 147, 4, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6137, 188, 90, 2, 31, "Subsection"],
Cell[6230, 192, 835, 31, 92, "Text"],

Cell[CellGroupData[{
Cell[7090, 227, 358, 11, 70, "Special3"],
Cell[7451, 240, 147, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[7635, 248, 190, 8, 24, "SmallText"],
Cell[7828, 258, 86, 2, 25, "Input"]
}, Open  ]],
Cell[7929, 263, 807, 26, 131, "Text"],

Cell[CellGroupData[{
Cell[8761, 293, 297, 12, 24, "SmallText"],
Cell[9061, 307, 69, 2, 25, "Input"]
}, Open  ]],
Cell[9145, 312, 937, 37, 94, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10131, 355, 135, 3, 33, "Section",
  PageBreakAbove->True],
Cell[10269, 360, 3201, 84, 594, "Text"],

Cell[CellGroupData[{
Cell[13495, 448, 94, 2, 47, "Subsection"],
Cell[13592, 452, 706, 11, 185, "Text"],

Cell[CellGroupData[{
Cell[14323, 467, 2081, 74, 206, "Special3"],
Cell[16407, 543, 145, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[16567, 549, 1153, 22, 280, "Text"],

Cell[CellGroupData[{
Cell[17745, 575, 90, 2, 43, "Subsubsection"],
Cell[17838, 579, 237, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[18100, 588, 129, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[18254, 595, 355, 8, 185, "Input"],
Cell[18612, 605, 60, 1, 29, "Output"],
Cell[18675, 608, 63, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18787, 615, 164, 7, 24, "SmallText"],
Cell[18954, 624, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[19084, 633, 94, 2, 31, "Subsection"],
Cell[19181, 637, 726, 11, 185, "Text"],

Cell[CellGroupData[{
Cell[19932, 652, 5403, 193, 508, "Special3"],
Cell[25338, 847, 145, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[25498, 853, 1091, 21, 261, "Text"],

Cell[CellGroupData[{
Cell[26614, 878, 90, 2, 43, "Subsubsection"],
Cell[26707, 882, 237, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[26969, 891, 129, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[27123, 898, 377, 8, 185, "Input"],
Cell[27503, 908, 59, 1, 29, "Output"],
Cell[27565, 911, 62, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27700, 920, 115, 2, 31, "Subsection"],
Cell[27818, 924, 441, 11, 92, "Text"],

Cell[CellGroupData[{
Cell[28284, 939, 1490, 52, 132, "Special3"],
Cell[29777, 993, 155, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[29947, 1000, 1742, 62, 209, "Text"],

Cell[CellGroupData[{
Cell[31714, 1066, 190, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[31929, 1078, 218, 6, 79, "Input"],
Cell[32150, 1086, 63, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32262, 1093, 164, 7, 24, "SmallText"],
Cell[32429, 1102, 53, 1, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[32531, 1109, 106, 2, 31, "Subsection"],
Cell[32640, 1113, 545, 13, 110, "Text"],

Cell[CellGroupData[{
Cell[33210, 1130, 163, 4, 24, "SmallText"],
Cell[33376, 1136, 179, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33592, 1146, 155, 4, 24, "SmallText"],
Cell[33750, 1152, 24853, 1019, 274, 7022, 794, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58640, 2176, 90, 2, 43, "Subsubsection"],
Cell[58733, 2180, 357, 12, 71, "Text"],
Cell[59093, 2194, 210, 4, 59, "Special1"],
Cell[59306, 2200, 211, 4, 59, "Special1"],
Cell[59520, 2206, 213, 4, 59, "Special1"],
Cell[59736, 2212, 274, 5, 76, "Special1"],

Cell[CellGroupData[{
Cell[60035, 2221, 129, 3, 24, "SmallText"],
Cell[60167, 2226, 445, 8, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60649, 2239, 132, 3, 24, "SmallText"],
Cell[60784, 2244, 127, 3, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[60960, 2253, 94, 2, 29, "Subsubsection"],
Cell[61057, 2257, 355, 9, 71, "Text"],
Cell[61415, 2268, 240, 8, 26, "Special1"],
Cell[61658, 2278, 238, 8, 43, "Special1"],

Cell[CellGroupData[{
Cell[61921, 2290, 129, 3, 24, "SmallText"],
Cell[62053, 2295, 424, 7, 185, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62514, 2307, 136, 3, 24, "SmallText"],
Cell[62653, 2312, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[62789, 2320, 91, 2, 29, "Subsubsection"],
Cell[62883, 2324, 704, 24, 93, "Text"],

Cell[CellGroupData[{
Cell[63612, 2352, 186, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[63823, 2364, 73, 2, 25, "Input"],
Cell[63899, 2368, 584, 12, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[64532, 2386, 196, 8, 24, "SmallText"],
Cell[64731, 2396, 25176, 1023, 274, 7025, 794, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[89956, 3425, 117, 2, 29, "Subsubsection"],
Cell[90076, 3429, 416, 11, 91, "Text"],

Cell[CellGroupData[{
Cell[90517, 3444, 106, 2, 24, "SmallText"],
Cell[90626, 3448, 201, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90864, 3458, 201, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[91090, 3470, 73, 2, 25, "Input"],
Cell[91166, 3474, 527, 11, 67, "Output"]
}, Open  ]]
}, Open  ]],
Cell[91720, 3489, 1747, 56, 229, "Text"],

Cell[CellGroupData[{
Cell[93492, 3549, 113, 2, 24, "SmallText"],
Cell[93608, 3553, 319, 8, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93964, 3566, 201, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[94190, 3578, 73, 2, 25, "Input"],
Cell[94266, 3582, 356, 8, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[94649, 3594, 1543, 52, 210, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[96229, 3651, 112, 2, 29, "Subsubsection"],
Cell[96344, 3655, 761, 19, 149, "Text"],

Cell[CellGroupData[{
Cell[97130, 3678, 147, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[97302, 3686, 110, 3, 45, "Input"],
Cell[97415, 3691, 151, 2, 48, "Output"],
Cell[97569, 3695, 78, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[97696, 3702, 306, 9, 40, "SmallText"],

Cell[CellGroupData[{
Cell[98027, 3715, 107, 3, 45, "Input"],
Cell[98137, 3720, 54, 1, 29, "Output"],
Cell[98194, 3723, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[98276, 3728, 1077, 29, 207, "Text"],

Cell[CellGroupData[{
Cell[99378, 3761, 140, 3, 24, "SmallText"],
Cell[99521, 3766, 604, 21, 349, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100162, 3792, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[100301, 3798, 97, 2, 25, "Input"],
Cell[100401, 3802, 19892, 627, 294, 5063, 438, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[120342, 4435, 170, 7, 24, "SmallText"],
Cell[120515, 4444, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[120645, 4453, 109, 2, 31, "Subsection"],
Cell[120757, 4457, 686, 15, 129, "Text"],

Cell[CellGroupData[{
Cell[121468, 4476, 163, 4, 24, "SmallText"],
Cell[121634, 4482, 215, 6, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121886, 4493, 121, 2, 24, "SmallText"],
Cell[122010, 4497, 52056, 2090, 243, 26235, 1766, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174103, 6592, 90, 2, 43, "Subsubsection"],
Cell[174196, 6596, 203, 4, 52, "Text"],
Cell[174402, 6602, 201, 4, 42, "Special1"],
Cell[174606, 6608, 243, 5, 59, "Special1"],
Cell[174852, 6615, 274, 5, 59, "Special1"],
Cell[175129, 6622, 199, 4, 42, "Special1"],

Cell[CellGroupData[{
Cell[175353, 6630, 132, 3, 24, "SmallText"],
Cell[175488, 6635, 512, 11, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176037, 6651, 132, 3, 24, "SmallText"],
Cell[176172, 6656, 115, 2, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[176336, 6664, 94, 2, 29, "Subsubsection"],
Cell[176433, 6668, 358, 9, 71, "Text"],
Cell[176794, 6679, 336, 10, 60, "Special1"],
Cell[177133, 6691, 262, 9, 43, "Special1"],
Cell[177398, 6702, 242, 8, 43, "Special1"],
Cell[177643, 6712, 461, 14, 61, "Special1"],
Cell[178107, 6728, 250, 9, 43, "Special1"],

Cell[CellGroupData[{
Cell[178382, 6741, 132, 3, 24, "SmallText"],
Cell[178517, 6746, 510, 10, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179064, 6761, 127, 2, 24, "SmallText"],
Cell[179194, 6765, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[179330, 6773, 91, 2, 29, "Subsubsection"],
Cell[179424, 6777, 478, 16, 73, "Text"],

Cell[CellGroupData[{
Cell[179927, 6797, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[180139, 6809, 74, 2, 25, "Input"],
Cell[180216, 6813, 1045, 20, 124, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[181310, 6839, 201, 8, 24, "SmallText"],
Cell[181514, 6849, 56156, 2210, 305, 23760, 1805, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[237719, 9065, 117, 2, 29, "Subsubsection"],
Cell[237839, 9069, 843, 23, 131, "Text"],

Cell[CellGroupData[{
Cell[238707, 9096, 106, 2, 24, "SmallText"],
Cell[238816, 9100, 194, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[239047, 9110, 202, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[239274, 9122, 74, 2, 25, "Input"],
Cell[239351, 9126, 829, 17, 105, "Output"]
}, Open  ]]
}, Open  ]],
Cell[240207, 9147, 1470, 37, 265, "Text"],

Cell[CellGroupData[{
Cell[241702, 9188, 113, 2, 24, "SmallText"],
Cell[241818, 9192, 340, 8, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242195, 9205, 202, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[242422, 9217, 74, 2, 25, "Input"],
Cell[242499, 9221, 421, 10, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[242947, 9235, 2801, 83, 441, "Text"],

Cell[CellGroupData[{
Cell[245773, 9322, 134, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[245932, 9329, 73, 2, 25, "Input"],
Cell[246008, 9333, 133, 2, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[246168, 9339, 587, 25, 54, "Text"],

Cell[CellGroupData[{
Cell[246780, 9368, 143, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[246948, 9376, 96, 2, 25, "Input"],
Cell[247047, 9380, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[247168, 9388, 112, 2, 29, "Subsubsection"],
Cell[247283, 9392, 781, 19, 149, "Text"],

Cell[CellGroupData[{
Cell[248089, 9415, 164, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[248278, 9423, 116, 3, 45, "Input"],
Cell[248397, 9428, 119, 2, 48, "Output"],
Cell[248519, 9432, 103, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[248649, 9438, 931, 28, 131, "Text"],

Cell[CellGroupData[{
Cell[249605, 9470, 126, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[249756, 9476, 115, 3, 45, "Input"],
Cell[249874, 9481, 183, 3, 81, "Output"],
Cell[250060, 9486, 88, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[250175, 9491, 1557, 42, 263, "Text"],

Cell[CellGroupData[{
Cell[251757, 9537, 146, 4, 24, "SmallText"],
Cell[251906, 9543, 409, 11, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[252352, 9559, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[252491, 9565, 97, 2, 25, "Input"],
Cell[252591, 9569, 47606, 1303, 258, 19622, 952, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[300246, 10878, 163, 7, 24, "SmallText"],
Cell[300412, 10887, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[300554, 10897, 120, 3, 33, "Section",
  PageBreakAbove->True],
Cell[300677, 10902, 255, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[300957, 10911, 93, 2, 47, "Subsection"],
Cell[301053, 10915, 2025, 60, 345, "Text"],

Cell[CellGroupData[{
Cell[303103, 10979, 162, 5, 24, "SmallText"],
Cell[303268, 10986, 141, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[303446, 10995, 152, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[303623, 11003, 99, 2, 25, "Input"],
Cell[303725, 11007, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[303830, 11014, 273, 9, 40, "SmallText"],

Cell[CellGroupData[{
Cell[304128, 11027, 71, 2, 25, "Input"],
Cell[304202, 11031, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[304284, 11036, 580, 18, 93, "Text"],

Cell[CellGroupData[{
Cell[304889, 11058, 195, 4, 40, "SmallText"],

Cell[CellGroupData[{
Cell[305109, 11066, 84, 2, 25, "Input"],
Cell[305196, 11070, 84, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[305329, 11077, 178, 4, 40, "SmallText"],

Cell[CellGroupData[{
Cell[305532, 11085, 74, 2, 25, "Input"],
Cell[305609, 11089, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[305691, 11094, 484, 17, 72, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[306212, 11116, 100, 2, 31, "Subsection"],
Cell[306315, 11120, 1703, 41, 342, "Text"],

Cell[CellGroupData[{
Cell[308043, 11165, 1631, 60, 208, "Special3"],
Cell[309677, 11227, 294, 13, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[309986, 11243, 1382, 34, 244, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[311405, 11282, 110, 2, 31, "Subsection"],
Cell[311518, 11286, 597, 18, 91, "Text"],

Cell[CellGroupData[{
Cell[312140, 11308, 163, 4, 24, "SmallText"],
Cell[312306, 11314, 179, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[312522, 11324, 115, 2, 24, "SmallText"],
Cell[312640, 11328, 8030, 232, 158, 2051, 153, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[320707, 11565, 90, 2, 43, "Subsubsection"],
Cell[320800, 11569, 400, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[321225, 11580, 133, 3, 24, "SmallText"],
Cell[321361, 11585, 252, 6, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[321650, 11596, 132, 3, 24, "SmallText"],
Cell[321785, 11601, 91, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[321925, 11609, 94, 2, 29, "Subsubsection"],
Cell[322022, 11613, 226, 5, 52, "Text"],
Cell[322251, 11620, 320, 12, 43, "Special1"],
Cell[322574, 11634, 219, 8, 26, "Special1"],
Cell[322796, 11644, 326, 12, 43, "Special1"],
Cell[323125, 11658, 247, 8, 43, "Special1"],

Cell[CellGroupData[{
Cell[323397, 11670, 133, 3, 24, "SmallText"],
Cell[323533, 11675, 427, 11, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[323997, 11691, 136, 3, 24, "SmallText"],
Cell[324136, 11696, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[324272, 11704, 88, 2, 29, "Subsubsection"],
Cell[324363, 11708, 382, 9, 71, "Text"],

Cell[CellGroupData[{
Cell[324770, 11721, 124, 2, 24, "SmallText"],
Cell[324897, 11725, 112, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325046, 11732, 333, 12, 40, "SmallText"],

Cell[CellGroupData[{
Cell[325404, 11748, 98, 2, 25, "Input"],
Cell[325505, 11752, 417, 10, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[325983, 11769, 92, 2, 29, "Subsubsection"],
Cell[326078, 11773, 913, 24, 150, "Text"],

Cell[CellGroupData[{
Cell[327016, 11801, 149, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[327190, 11809, 92, 2, 25, "Input"],
Cell[327285, 11813, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[327371, 11818, 262, 8, 53, "Text"],

Cell[CellGroupData[{
Cell[327658, 11830, 144, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[327827, 11838, 106, 3, 45, "Input"],
Cell[327936, 11843, 143, 3, 48, "Output"],
Cell[328082, 11848, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[328163, 11853, 569, 17, 92, "Text"],

Cell[CellGroupData[{
Cell[328757, 11874, 144, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[328926, 11882, 91, 2, 25, "Input"],
Cell[329020, 11886, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[329123, 11893, 301, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[329449, 11909, 69, 2, 25, "Input"],
Cell[329521, 11913, 67, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[329615, 11918, 505, 14, 91, "Text"],

Cell[CellGroupData[{
Cell[330145, 11936, 160, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[330330, 11944, 194, 4, 65, "Input"],
Cell[330527, 11950, 19553, 520, 182, 4558, 329, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[350129, 12476, 157, 4, 24, "SmallText"],
Cell[350289, 12482, 588, 17, 277, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350914, 12504, 116, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[351055, 12510, 94, 2, 25, "Input"],
Cell[351152, 12514, 12584, 358, 158, 6474, 277, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[363785, 12878, 163, 7, 24, "SmallText"],
Cell[363951, 12887, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[364093, 12897, 117, 3, 33, "Section",
  PageBreakAbove->True],
Cell[364213, 12902, 864, 13, 223, "Text"],

Cell[CellGroupData[{
Cell[365102, 12919, 108, 2, 47, "Subsection"],
Cell[365213, 12923, 1125, 28, 225, "Text"],

Cell[CellGroupData[{
Cell[366363, 12955, 163, 4, 24, "SmallText"],
Cell[366529, 12961, 179, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[366745, 12971, 132, 3, 24, "SmallText"],
Cell[366880, 12976, 21104, 1166, 213, 8178, 1001, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[388021, 14147, 90, 2, 43, "Subsubsection"],
Cell[388114, 14151, 605, 16, 110, "Text"],

Cell[CellGroupData[{
Cell[388744, 14171, 132, 3, 24, "SmallText"],
Cell[388879, 14176, 352, 9, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389268, 14190, 135, 3, 24, "SmallText"],
Cell[389406, 14195, 90, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[389545, 14203, 94, 2, 29, "Subsubsection"],
Cell[389642, 14207, 482, 15, 92, "Text"],
Cell[390127, 14224, 237, 8, 26, "Special1"],
Cell[390367, 14234, 232, 8, 26, "Special1"],
Cell[390602, 14244, 537, 24, 44, "Special1"],
Cell[391142, 14270, 405, 16, 54, "Text"],

Cell[CellGroupData[{
Cell[391572, 14290, 132, 3, 24, "SmallText"],
Cell[391707, 14295, 361, 9, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[392105, 14309, 136, 3, 24, "SmallText"],
Cell[392244, 14314, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[392380, 14322, 94, 2, 29, "Subsubsection"],
Cell[392477, 14326, 1121, 38, 149, "Text"],

Cell[CellGroupData[{
Cell[393623, 14368, 109, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[393757, 14374, 75, 2, 25, "Input"],
Cell[393835, 14378, 57, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[393941, 14385, 129, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[394095, 14392, 94, 2, 25, "Input"],
Cell[394192, 14396, 121, 2, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[394362, 14404, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[394501, 14410, 88, 2, 25, "Input"],
Cell[394592, 14414, 225, 4, 113, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[394878, 14425, 101, 2, 29, "Subsubsection"],
Cell[394982, 14429, 2817, 75, 500, "Text"],

Cell[CellGroupData[{
Cell[397824, 14508, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[398043, 14520, 96, 2, 25, "Input"],
Cell[398142, 14524, 192, 3, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[398383, 14533, 234, 8, 24, "SmallText"],
Cell[398620, 14543, 94, 2, 25, "Input"]
}, Open  ]],
Cell[398729, 14548, 318, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[399072, 14561, 154, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[399251, 14569, 198, 4, 79, "Input"],
Cell[399452, 14575, 77, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[399556, 14580, 260, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[399841, 14589, 111, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[399977, 14595, 204, 4, 65, "Input"],
Cell[400184, 14601, 15617, 533, 182, 5570, 403, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[415874, 15142, 96, 2, 31, "Subsection"],
Cell[415973, 15146, 1387, 31, 301, "Text"],

Cell[CellGroupData[{
Cell[417385, 15181, 179, 7, 24, "SmallText"],
Cell[417567, 15190, 70, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[417674, 15197, 105, 2, 43, "Subsubsection"],
Cell[417782, 15201, 213, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[418020, 15209, 129, 3, 24, "SmallText"],
Cell[418152, 15214, 603, 11, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[418792, 15230, 135, 3, 24, "SmallText"],
Cell[418930, 15235, 546, 10, 205, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[419525, 15251, 94, 2, 29, "Subsubsection"],
Cell[419622, 15255, 2280, 75, 327, "Text"],

Cell[CellGroupData[{
Cell[421927, 15334, 198, 8, 24, "SmallText"],
Cell[422128, 15344, 160, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[422325, 15353, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[422464, 15359, 88, 2, 25, "Input"],
Cell[422555, 15363, 458, 8, 162, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[423062, 15377, 143, 4, 24, "SmallText"],
Cell[423208, 15383, 85, 2, 25, "Input"]
}, Open  ]],
Cell[423308, 15388, 1289, 47, 133, "Text"],

Cell[CellGroupData[{
Cell[424622, 15439, 121, 2, 24, "SmallText"],
Cell[424746, 15443, 115, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[424898, 15450, 154, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[425077, 15458, 83, 2, 37, "Input"],
Cell[425163, 15462, 179, 3, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[425391, 15471, 167, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[425583, 15479, 78, 2, 37, "Input"],
Cell[425664, 15483, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[425779, 15491, 97, 2, 29, "Subsubsection"],
Cell[425879, 15495, 709, 19, 130, "Text"],

Cell[CellGroupData[{
Cell[426613, 15518, 305, 12, 24, "SmallText"],
Cell[426921, 15532, 104, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[427062, 15539, 265, 9, 40, "SmallText"],

Cell[CellGroupData[{
Cell[427352, 15552, 102, 2, 25, "Input"],
Cell[427457, 15556, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[427543, 15561, 648, 25, 74, "Text"],

Cell[CellGroupData[{
Cell[428216, 15590, 112, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[428353, 15596, 85, 2, 25, "Input"],
Cell[428441, 15600, 653, 17, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[429143, 15623, 197, 4, 40, "SmallText"],

Cell[CellGroupData[{
Cell[429365, 15631, 129, 3, 25, "Input"],
Cell[429497, 15636, 18156, 504, 182, 4931, 335, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[447702, 16146, 117, 2, 24, "SmallText"],
Cell[447822, 16150, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

