(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18952,        739]*)
(*NotebookOutlinePosition[     19896,        771]*)
(*  CellTagsIndexPosition[     19852,        767]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Generalized Coordinate Reference", "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "A. Modified ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " Symbols"
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Additional definitions are made by the Generalized Coordinate modeling \
package for several standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " symbols. The new definitions do not change the usage of these symbols in \
any way, the standard usage is simply extended so as to work correctly with \
generalized coordinates. \n\nThe letter ",
  StyleBox["\"G\"",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is appended to the ",
  StyleBox["$MechVersion",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " string to indicate that the Generalized Coordinate Package has been \
loaded."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["B. Generaized Coordinate Objects and Functions", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenConstraint",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenConstraint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, rot, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object which introduces a slave body represented by \
generalized coordinates into the model. A point on the slave body, ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", is constrained to be coincident with a point on the master, ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". The angular orientation of the slave with respect to the master is \
specified by ",
  StyleBox["rot",
    FontSlant->"Italic"],
  ". In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["rot",
    FontSlant->"Italic"],
  " is a counterclockwise angle. In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["rot",
    FontSlant->"Italic"],
  " is specified in the ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, axis",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " format, and it can be a single rotation or a sequence of rotations of the \
form used by ",
  StyleBox["RotationLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, guess1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym2, guess2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontSlant->"Italic"],
  ", are generalized coordinate symbols and their associated initial guesses \
which are added to the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to create user-defined generalized coordinate relationships. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " generalized coordinate constraints do not actually constrain any degrees \
of freedom or add any algebraic constraints to the model, they simply set up \
the necessary coordinate transformations so that a new slave body can be \
recognized appropriately by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s modeling engine.  ##  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenCylindrical4",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenCylindrical4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by two generalized coordinates ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of rotational freedom and one degree of \
translational freedom. The two axes are constrained to be colinear and the \
distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", is represented by ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". The angle from the projection of the reference direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the right-hand sense, is represented by ",
  StyleBox["beta",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["GenCylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " actually adds two DOF to the model, as opposed to constraining four.  ##  \
See also: ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenOrthoRevolute4",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenOrthoRevolute4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by two generalized coordinates ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with two degrees of rotational freedom.  The origins of the two axes \
are constrained to be coincident, and the axes are constrained to be \
orthogonal.  The symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " represents the angle between ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and the reference direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " represents the angle between ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and the reference direction of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["GenOrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " actually adds two DOF to the model, as opposed to constraining four.  ##  \
See also: ",
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenRevolute2",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenRevolute2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by a single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of rotational freedom.  The origins of the two axes \
are constrained to be coincident, and the counterclockwise angle from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["GenRevolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " actually adds one DOF to the model, as opposed to constraining two DOF \
like ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  ##  See also: ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenRevolute5",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenRevolute5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by a single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of rotational freedom. The two axes are constrained \
to be parallel and their origins are constrained to be coincident. The angle \
from the projection of the reference direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the right-hand sense, is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["GenRevolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " actually adds one DOF to the model, as opposed to constraining five.  ##  \
See also: ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenTranslate2",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenTranslate2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by a single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of translational freedom. The two axes are \
constrained to be colinear, and the distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["GenTranslate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " actually adds one DOF to the model, as opposed to constraining two DOF \
like ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  ##  See also: ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GenTranslate5",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GenTranslate5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that introduces a slave body into the model \
represented by a single generalized coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".  The ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " body is a slave to the ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " body with one degree of translational freedom.  The two axes are \
constrained to be colinear, and the distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", is represented by ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".  The projections of the reference directions of the two axes are \
constrained to be parallel."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["GenTranslate5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " actually adds one DOF to the model, as opposed to constraining five.  ##  \
See also: ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["JoinRows",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["JoinRows[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["mat1, mat2, ...",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a new matrix composed of the ",
  StyleBox["mati",
    FontSlant->"Italic"],
  " with their rows joined.  The ",
  StyleBox["mati",
    FontSlant->"Italic"],
  " must all have the same number of rows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["JoinRows",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " effectively joins matrices left-to-right, instead of top-to-bottom.  ##  \
See also: ",
  StyleBox["Join",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MapThread",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{432, 636},
WindowMargins->{{Automatic, 206}, {Automatic, 26}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 123, 3, 53, "Section",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[1879, 58, 171, 7, 48, "Subsection"],
Cell[2053, 67, 692, 19, 128, "Special2"]
}, Closed]],

Cell[CellGroupData[{
Cell[2782, 91, 116, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[2923, 97, 205, 8, 44, "Subsubsection"],
Cell[3131, 107, 2329, 87, 190, "Text"],
Cell[5463, 196, 714, 20, 76, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6214, 221, 204, 8, 44, "Subsubsection"],
Cell[6421, 231, 1711, 63, 167, "Text"],
Cell[8135, 296, 356, 13, 44, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8528, 314, 206, 8, 44, "Subsubsection"],
Cell[8737, 324, 1621, 60, 148, "Text"],
Cell[10361, 386, 360, 13, 44, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10758, 404, 201, 8, 44, "Subsubsection"],
Cell[10962, 414, 1039, 37, 110, "Text"],
Cell[12004, 453, 441, 17, 44, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12482, 475, 201, 8, 44, "Subsubsection"],
Cell[12686, 485, 1132, 38, 129, "Text"],
Cell[13821, 525, 350, 13, 44, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14208, 543, 202, 8, 44, "Subsubsection"],
Cell[14413, 553, 1108, 40, 110, "Text"],
Cell[15524, 595, 444, 17, 44, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16005, 617, 202, 8, 44, "Subsubsection"],
Cell[16210, 627, 1205, 41, 129, "Text"],
Cell[17418, 670, 352, 13, 44, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17807, 688, 202, 8, 44, "Subsubsection"],
Cell[18012, 698, 489, 18, 53, "Text"],
Cell[18504, 718, 408, 16, 44, "SmallText"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

