(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12356,        398]*)
(*NotebookOutlinePosition[     13298,        430]*)
(*  CellTagsIndexPosition[     13254,        426]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  "\n\nKinematic and Dynamic\nMechanism Analysis\nin ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Version 1.3", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18],

Cell[TextData["Robert Beretta\nDynamic Modeling"], "Subtitle",
  Evaluatable->False,
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic,
  AspectRatioFixed->True,
  FontFamily->"Times",
  FontSize->18,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell[TextData["Copyright"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " is a trademark of Dynamic Modeling.\n\n",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["\[RegisteredTrademark]",
    FontFamily->"Symbol"],
  " is registered trademark of Wolfram Research, Inc. All other product names \
mentioned are trademarks of their producers. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is not associated with Mathematica Policy Research, Inc. or MathTech, \
Inc.\n\nApril 1995\nSecond edition, first printing\nIntended for use with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Versions 2.2 or 3.0\n\nSoftware and manual written by: Robert Beretta\n\
Editor: Jan Progen\nManual layout/ Design: Jody Jasinski and Kimberly Michael\
\nProofreaders: Angela Letham, Wendy Leung, Carol Ordal\nSpecial thanks to \
Karen Beretta, Monica Davis, Ed Garner, Joe Grohens, Gary Miller, Leszek \
Sczaniecki\n\nCopyright ",
  StyleBox["\[Copyright] ",
    FontFamily->"Symbol"],
  "1997 by Dynamic Modeling, Vancouver, Washington. Published by Wolfram \
Research, Inc., Champaign, Illinois."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell["\<\

All rights reserved. No part of this document may be reproduced, stored in a \
retrieval system, or transmitted in any form or by any means, electronic, \
mechanical, photocopying, recording or otherwise, without prior written \
permission of the author, Dynamic Modeling, or the publisher, Wolfram \
Research.\
\>", "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\nDynamic Modeling is the holder of the copyright to the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " software and documentation (\"Product\") described in this document, \
including without limitation such aspects of the Product as its code, \
structure, sequence, organization, \"look and feel\", programming language \
and compilation of command names. Use of the Product, unless pursuant to the \
terms of a license granted by Wolfram Research, Inc. or as otherwise \
authorized by law, is an infringement of the copyright."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[
"\nThe author, Dynamic Modeling, and publisher, Wolfram Research, Inc., make \
no representations, express or implied, with respect to this Product, \
including without limitations, any implied warranties of merchantability or \
fitness for a particular purpose, all of which are expressly disclaimed. \
Users should be aware that included in the terms and conditions under which \
Wolfram Research is willing to license the Product is a provision that the \
author, Dynamic Modeling, publisher, Wolfram Research, Inc., and distribution \
licensees, distributors and dealers shall in no event be liable for any \
indirect, incidental or consequential damages, and that liability for direct \
damages shall be limited to the amount of the purchase price paid for the \
Product."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell["\<\

In addition to the foregoing, users should recognize that all complex \
software systems and their documentation contain errors and omissions. The \
author, Dynamic Modeling, and publisher, Wolfram Research, Inc., shall not be \
responsible under any circumstances for providing information on or \
corrections to errors and omissions discovered at any time in this document \
or the package software it describes, whether or not they are aware of the \
errors or omissions. The author, Dynamic Modeling, and publisher Wolfram \
Research, Inc., do not recommend the use of the software described in this \
document for applications in which errors or omissions could threaten life, \
injury or significant loss.\
\>", "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Contents"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell["Preface\t\t\t\t\t\t\t\tV", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["1. Getting Started"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
1.1\tInstallation and Loading\t\t\t\t\t2
1.2\tBasic 2D Model\t\t\t\t\t\t7
1.3\tBasic 3D Model\t\t\t\t\t\t16\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2. Kinematic Modeling"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
2.1\tBody Objects\t\t\t\t\t\t\t28
2.2\tPoints, Vectors, and Axes\t\t\t\t\t34
2.3\tConstraint Objects\t\t\t\t\t\t44
2.4\tBuilding the Model\t\t\t\t\t\t55
2.5\tRunning the Model\t\t\t\t\t\t62
2.6\tVariable Management\t\t\t\t\t\t69\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["3. Output Functions"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
3.1\t2D Output Functions\t\t\t\t\t\t76
3.2\t3D Output Functions\t\t\t\t\t\t88
3.3\tPlots and Graphs\t\t\t\t\t\t102
3.4\t2D Mechanism Images\t\t\t\t\t108
3.5\t3D Mechanism Images\t\t\t\t\t123\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["4. Velocity and Acceleration"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
4.1\tVelocity and Acceleration Solutions\t\t\t\t146
4.2\tVelocity and Acceleration Output\t\t\t\t164\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["5. Multistage Mechanisms"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
5.1\tStage Switching Constraints\t\t\t\t\t182
5.2\tTime Switching Constraints\t\t\t\t\t195\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["6. Cams and Gears"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
6.1\tCam Constraints\t\t\t\t\t\t210
6.2\tGear Constraints\t\t\t\t\t\t245\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["7. Loads and Reactions"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
7.1\tLoad Objects\t\t\t\t\t\t\t264
7.2\tStatic Solutions\t\t\t\t\t\t270
7.3\tResultant Forces\t\t\t\t\t\t277
7.4\tMultistage Loads\t\t\t\t\t\t284\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["8. Inverse Dynamics"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
8.1\tInertia Properties \t\t\t\t\t\t294
8.2\tKinematic and Dynamic Solutions\t\t\t\t304
8.3\tFriction and Damping\t\t\t\t\t\t312\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["9. Parametric Design"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
9.1\tCoupled Models\t\t\t\t\t\t332
9.2\tMultiple Configuration Couples\t\t\t\t\t341
9.3\tVelocity and Acceleration Couples\t\t\t\t346
9.4\tLoad-Dependent Couples\t\t\t\t\t349
9.5\tSensitivity\t\t\t\t\t\t\t353\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["10. Underconstrained Systems"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
10.1\tEquilibrium Configuration\t\t\t\t\t360
10.2\tEquilibrium Velocity\t\t\t\t\t\t368
10.3\tFree Acceleration\t\t\t\t\t\t372
10.4\tDynamic Motion Synthesis\t\t\t\t\t382
10.5\tNonholonomic Systems\t\t\t\t\t400\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["11. Performance Improvement"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
11.1\tUpdating Solutions\t\t\t\t\t\t406
11.2\tSimplifying Expressions\t\t\t\t\t409
11.3\tCompiling Expressions\t\t\t\t\t412
11.4\tCoordinate Systems\t\t\t\t\t\t414
11.5\tLocking Variables\t\t\t\t\t\t418\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["12. Debugging Models"], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
12.1\tModel Building Errors\t\t\t\t\t\t422
12.2\tFailure to Converge\t\t\t\t\t\t428
12.3\tMathematical Anomalies\t\t\t\t\t433
12.4\tEquations of Motion\t\t\t\t\t\t435\
\>", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Reference Guide", "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
A.\tModified Mathematica Built-in Symbols\t\t\t439
B.\tMechanical Systems Objects and Functions\t\t\t439\
\>", "Subsubtitle"],

Cell["References\t\t\t\t\t\t\t\t523", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Index\t\t\t\t\t\t\t\t\t525", "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Preface"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " is a set of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages designed to assist in the analysis and design of planar and \
spatial rigid body mechanisms. The packages are written entirely in the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming language and is completely portable and platform independent. \
The source code is written in the preferred package format as generally used \
by Wolfram Research, Inc. for the standard packages that are included with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " is intended to run under ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 2.2 or later."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{479, 652},
WindowMargins->{{20, Automatic}, {16, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 242, 8, 283, "Title"],
Cell[1976, 61, 95, 3, 48, "Subtitle"],
Cell[2074, 66, 358, 12, 69, "Subtitle",
  PageBreakWithin->Automatic,
  PageBreakBelow->Automatic],

Cell[CellGroupData[{
Cell[2457, 82, 110, 3, 53, "Section",
  PageBreakAbove->True],
Cell[2570, 87, 1228, 30, 246, "Special4",
  PageBreakAbove->False],
Cell[3801, 119, 412, 10, 66, "Special4",
  PageBreakAbove->False],
Cell[4216, 131, 657, 13, 90, "Special4",
  PageBreakAbove->False],
Cell[4876, 146, 879, 14, 114, "Special4",
  PageBreakAbove->False],
Cell[5758, 162, 813, 15, 102, "Special4",
  PageBreakAbove->False]
}, Closed]],

Cell[CellGroupData[{
Cell[6608, 182, 109, 3, 33, "Section",
  PageBreakAbove->True],
Cell[6720, 187, 95, 2, 48, "Subsubtitle"],
Cell[6818, 191, 96, 2, 54, "Subtitle"],
Cell[6917, 195, 186, 6, 84, "Subsubtitle"],
Cell[7106, 203, 99, 2, 54, "Subtitle"],
Cell[7208, 207, 307, 9, 138, "Subsubtitle"],
Cell[7518, 218, 97, 2, 54, "Subtitle"],
Cell[7618, 222, 269, 8, 120, "Subsubtitle"],
Cell[7890, 232, 106, 2, 54, "Subtitle"],
Cell[7999, 236, 179, 5, 66, "Subsubtitle"],
Cell[8181, 243, 102, 2, 54, "Subtitle"],
Cell[8286, 247, 169, 5, 66, "Subsubtitle"],
Cell[8458, 254, 95, 2, 54, "Subtitle"],
Cell[8556, 258, 151, 5, 66, "Subsubtitle"],
Cell[8710, 265, 100, 2, 54, "Subtitle"],
Cell[8813, 269, 224, 7, 102, "Subsubtitle"],
Cell[9040, 278, 97, 2, 54, "Subtitle"],
Cell[9140, 282, 207, 6, 84, "Subsubtitle"],
Cell[9350, 290, 98, 2, 54, "Subtitle"],
Cell[9451, 294, 287, 8, 120, "Subsubtitle"],
Cell[9741, 304, 106, 2, 54, "Subtitle"],
Cell[9850, 308, 288, 8, 120, "Subsubtitle"],
Cell[10141, 318, 105, 2, 54, "Subtitle"],
Cell[10249, 322, 281, 8, 120, "Subsubtitle"],
Cell[10533, 332, 98, 2, 54, "Subtitle"],
Cell[10634, 336, 245, 7, 102, "Subsubtitle"],
Cell[10882, 345, 83, 2, 54, "Subtitle"],
Cell[10968, 349, 135, 3, 66, "Subsubtitle"],
Cell[11106, 354, 100, 2, 48, "Subsubtitle"],
Cell[11209, 358, 97, 2, 48, "Subsubtitle"]
}, Closed]],

Cell[CellGroupData[{
Cell[11343, 365, 108, 3, 33, "Section",
  PageBreakAbove->True],
Cell[11454, 370, 874, 24, 147, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

