(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    529876,      19835]*)
(*NotebookOutlinePosition[    530819,      19867]*)
(*  CellTagsIndexPosition[    530775,      19863]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1.  Getting Started", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter is intended to help the user get ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " installed and loaded into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and to provide an overview of its functionality. ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " actually consists of two basic ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages; one for 2D mechanisms, ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and one for 3D mechanisms, ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Throughout this manual, the 2D and 3D components of ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " are often referred to by their package names, ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the entire ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " package is simply referred to as ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".\n\nSection 1.1 describes the steps necessary to install ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " on various computer systems and load the packages into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. In Sections 1.2 and 1.3 two very basic kinematic models (one 2D \
and one 3D) are developed to demonstrate the general functionality of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ". Both models are of a slider-crank mechanism, such as a small internal \
combustion engine, and they are presented with minimal explanation. The two \
models are essentially identical to show the parallelism between ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Further exploration of the functions introduced in this chapter and all \
of the other functions provided for kinematic modeling can be found in \
Chapter 2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["1.1  Installation and Loading"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section covers the installation of ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " on various computer systems and loading the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages into a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["File Locations"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " is a set of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages that are loaded after starting a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session, just like the standard packages that are delivered with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", such as ",
  StyleBox["Graphics`Graphics`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["LinearAlgebra`CrossProduct`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The new functions that are defined by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " are contained in 12 ASCII text files that must be located in a directory \
on your computer system such that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can find them by the context names ",
  StyleBox["Mech`Mech2D`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Mech`Mech3D`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The platform specific installation program that is provided with ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " places the files in the",
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["Applications",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" directory under",
    FontFamily->"Times"],
  " the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["AddOns", "Input"],
  " directory, instead of th",
  StyleBox["e ",
    FontFamily->"Times"],
  StyleBox["StandardPackages",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" directory ",
    FontFamily->"Times"],
  "that contains the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
MathematicaDirectory\\AddOns\\Applications\\Mech\\Mech2D.m
                                              Mech3D.m
                                              MechCommon.m
                                              ...\
\>", "Special3",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[TextData[{
  "A typical installation of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages on a Windows PC."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The file locations on other computer systems will vary only by the file \
name separator and the name of the top-level ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " directory. When installed in this location, the default value of the ",
  StyleBox["$Path", "Input"],
  " variable will allow ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to find and load the packages without modification."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Loading and Unloading ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"]
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Main Package", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages are loaded into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the same manner as a standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package; with a ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"Get[\"Mech`Mech2D`\"]\n\n<<Mech`Mech2D`\n\nNeeds[\"Mech`Mech3D`\"]",
  FontWeight->"Bold"]], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontFamily->"Courier"],

Cell[TextData[{
  "Loading the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "It is not possible to have both ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " loaded simultaneously because they use many of the same function names, \
with different definitions. Attempting to load both packages results in an \
error message.\n\nThe ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages are not intended to be loaded twice. Thus, it is recommended \
that ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " be used to load the packages because ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will not read the package if it has already been read. If ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is accidentally used to load one of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages after it has already been loaded, an error message is generated, \
and the ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " operation is aborted."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Secondary Packages", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " has secondary packages, ",
  StyleBox["Dyna2D/Dyna3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Graf2D/Graf3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Time2D/Time3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", that need not be loaded explicitly. They are loaded automatically if any \
of the function definitions they contain are needed. However, if the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  StyleBox["Information",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Definition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions are to work correctly with the functions in the secondary \
packages, these packages must be loaded into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Note that requesting information about a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function with ",
  StyleBox["?",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["functioname",
    FontSlant->"Italic"],
  " will not cause packages to be autoloaded."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This causes all of the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages to be loaded, including ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " itself."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Dyna2D`\>"]\), 
    \(Needs["\<Mech`Graf2D`\>"]\), 
    \(Needs["\<Mech`Time2D`\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Clearing and Unloading ",
  StyleBox["Mech",
    FontSlant->"Italic"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If it is desired to reset ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " to its initial state, or to remove ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " entirely from the current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session without quitting and restarting ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", this can be done with ",
  StyleBox["ClearMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ClearMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " resets all internal ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " definitions to their initial states, as if ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " had just been loaded.\n\n",
  StyleBox["KillMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " removes all of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions and their contexts, as if ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " had never been loaded. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Resetting or removing ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the entire ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "After executing ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " nothing remains of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " session except whatever definitions the user had made in the ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context, and a few undefined symbols that ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " creates in the ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context. The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages can be reloaded with ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " after executing ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2  Basic 2D Model", "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "In this section the basic functionality of the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package is demonstrated by building a kinematic model of a very simple \
mechanism. The mechanism is a planar slider-crank mechanism with two moving \
bodies, the crankshaft and the piston. The mechanism is modeled using the \
most abbreviated technique possible with ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Future chapters will delve into the many more complex variations on \
these techniques."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Mechanism Function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package must be loaded before calling any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the 2D slider-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!    
%%Creator: Mathematica    
%%AspectRatio: 1.5     
MathPictureStart    
%% Graphics    
/Courier findfont 10  scalefont  setfont    
% Scaling calculations    
0.5 0.0833333 0.5 0.0833333 [    
[(-4)] .16667  0 0 2 Msboxa    
[(-2)] .33333  0 0 2 Msboxa    
[(0)] .5  0 0 2 Msboxa    
[(2)] .66667  0 0 2 Msboxa    
[(4)] .83333  0 0 2 Msboxa    
[(6)] 1 0 0 2 Msboxa    
[(-5)] -0.0125 .08333  1 0 Msboxa    
[(-2.5)] -0.0125 .29167  1 0 Msboxa    
[(0)] -0.0125 .5  1 0 Msboxa    
[(2.5)] -0.0125 .70833  1 0 Msboxa    
[(5)] -0.0125 .91667  1 0 Msboxa    
[(7.5)] -0.0125 1.125 1 0 Msboxa    
[(10)] -0.0125 1.33333 1 0 Msboxa    
[ -0.001 -0.001 0 0 ]    
[ 1.001 1.501 0 0 ]    
] MathScale    
% Start of Graphics    
1 setlinecap    
1 setlinejoin    
newpath    
[ ] 0 setdash    
0 g    
p    
p    
.002  w    
.16667  0 m    
.16667  .00625  L    
s    
P    
[(-4)] .16667  0 0 2 Mshowa    
p    
.002  w    
.33333  0 m    
.33333  .00625  L    
s    
P    
[(-2)] .33333  0 0 2 Mshowa    
p    
.002  w    
.5  0 m    
.5  .00625  L    
s    
P    
[(0)] .5  0 0 2 Mshowa    
p    
.002  w    
.66667  0 m    
.66667  .00625  L    
s    
P    
[(2)] .66667  0 0 2 Mshowa    
p    
.002  w    
.83333  0 m    
.83333  .00625  L    
s    
P    
[(4)] .83333  0 0 2 Mshowa    
p    
.002  w    
1 0 m    
1 .00625  L    
s    
P    
[(6)] 1 0 0 2 Mshowa    
p    
.001  w    
.03333  0 m    
.03333  .00375  L    
s    
P    
p    
.001  w    
.06667  0 m    
.06667  .00375  L    
s    
P    
p    
.001  w    
.1  0 m    
.1  .00375  L    
s    
P    
p    
.001  w    
.13333  0 m    
.13333  .00375  L    
s    
P    
p    
.001  w    
.2  0 m    
.2  .00375  L    
s    
P    
p    
.001  w    
.23333  0 m    
.23333  .00375  L    
s    
P    
p    
.001  w    
.26667  0 m    
.26667  .00375  L    
s    
P    
p    
.001  w    
.3  0 m    
.3  .00375  L    
s    
P    
p    
.001  w    
.36667  0 m    
.36667  .00375  L    
s    
P    
p    
.001  w    
.4  0 m    
.4  .00375  L    
s    
P    
p    
.001  w    
.43333  0 m    
.43333  .00375  L    
s    
P    
p    
.001  w    
.46667  0 m    
.46667  .00375  L    
s    
P    
p    
.001  w    
.53333  0 m    
.53333  .00375  L    
s    
P    
p    
.001  w    
.56667  0 m    
.56667  .00375  L    
s    
P    
p    
.001  w    
.6  0 m    
.6  .00375  L    
s    
P    
p    
.001  w    
.63333  0 m    
.63333  .00375  L    
s    
P    
p    
.001  w    
.7  0 m    
.7  .00375  L    
s    
P    
p    
.001  w    
.73333  0 m    
.73333  .00375  L    
s    
P    
p    
.001  w    
.76667  0 m    
.76667  .00375  L    
s    
P    
p    
.001  w    
.8  0 m    
.8  .00375  L    
s    
P    
p    
.001  w    
.86667  0 m    
.86667  .00375  L    
s    
P    
p    
.001  w    
.9  0 m    
.9  .00375  L    
s    
P    
p    
.001  w    
.93333  0 m    
.93333  .00375  L    
s    
P    
p    
.001  w    
.96667  0 m    
.96667  .00375  L    
s    
P    
p    
.002  w    
0 0 m    
1 0 L    
s    
P    
p    
.002  w    
0 .08333  m    
.00625  .08333  L    
s    
P    
[(-5)] -0.0125 .08333  1 0 Mshowa    
p    
.002  w    
0 .29167  m    
.00625  .29167  L    
s    
P    
[(-2.5)] -0.0125 .29167  1 0 Mshowa    
p    
.002  w    
0 .5  m    
.00625  .5  L    
s    
P    
[(0)] -0.0125 .5  1 0 Mshowa    
p    
.002  w    
0 .70833  m    
.00625  .70833  L    
s    
P    
[(2.5)] -0.0125 .70833  1 0 Mshowa    
p    
.002  w    
0 .91667  m    
.00625  .91667  L    
s    
P    
[(5)] -0.0125 .91667  1 0 Mshowa    
p    
.002  w    
0 1.125 m    
.00625  1.125 L    
s    
P    
[(7.5)] -0.0125 1.125 1 0 Mshowa    
p    
.002  w    
0 1.33333 m    
.00625  1.33333 L    
s    
P    
[(10)] -0.0125 1.33333 1 0 Mshowa    
p    
.001  w    
0 .125  m    
.00375  .125  L    
s    
P    
p    
.001  w    
0 .16667  m    
.00375  .16667  L    
s    
P    
p    
.001  w    
0 .20833  m    
.00375  .20833  L    
s    
P    
p    
.001  w    
0 .25  m    
.00375  .25  L    
s    
P    
p    
.001  w    
0 .33333  m    
.00375  .33333  L    
s    
P    
p    
.001  w    
0 .375  m    
.00375  .375  L    
s    
P    
p    
.001  w    
0 .41667  m    
.00375  .41667  L    
s    
P    
p    
.001  w    
0 .45833  m    
.00375  .45833  L    
s    
P    
p    
.001  w    
0 .54167  m    
.00375  .54167  L    
s    
P    
p    
.001  w    
0 .58333  m    
.00375  .58333  L    
s    
P    
p    
.001  w    
0 .625  m    
.00375  .625  L    
s    
P    
p    
.001  w    
0 .66667  m    
.00375  .66667  L    
s    
P    
p    
.001  w    
0 .75  m    
.00375  .75  L    
s    
P    
p    
.001  w    
0 .79167  m    
.00375  .79167  L    
s    
P    
p    
.001  w    
0 .83333  m    
.00375  .83333  L    
s    
P    
p    
.001  w    
0 .875  m    
.00375  .875  L    
s    
P    
p    
.001  w    
0 .95833  m    
.00375  .95833  L    
s    
P    
p    
.001  w    
0 1 m    
.00375  1 L    
s    
P    
p    
.001  w    
0 1.04167 m    
.00375  1.04167 L    
s    
P    
p    
.001  w    
0 1.08333 m    
.00375  1.08333 L    
s    
P    
p    
.001  w    
0 1.16667 m    
.00375  1.16667 L    
s    
P    
p    
.001  w    
0 1.20833 m    
.00375  1.20833 L    
s    
P    
p    
.001  w    
0 1.25 m    
.00375  1.25 L    
s    
P    
p    
.001  w    
0 1.29167 m    
.00375  1.29167 L    
s    
P    
p    
.001  w    
0 .04167  m    
.00375  .04167  L    
s    
P    
p    
.001  w    
0 1.375 m    
.00375  1.375 L    
s    
P    
p    
.001  w    
0 1.41667 m    
.00375  1.41667 L    
s    
P    
p    
.001  w    
0 1.45833 m    
.00375  1.45833 L    
s    
P    
p    
.002  w    
0 0 m    
0 1.5 L    
s    
P    
P    
p    
p    
.002  w    
0 1.49375 m    
0 1.5 L    
s    
P    
p    
.002  w    
.16667  1.49375 m    
.16667  1.5 L    
s    
P    
p    
.002  w    
.33333  1.49375 m    
.33333  1.5 L    
s    
P    
p    
.002  w    
.5  1.49375 m    
.5  1.5 L    
s    
P    
p    
.002  w    
.66667  1.49375 m    
.66667  1.5 L    
s    
P    
p    
.002  w    
.83333  1.49375 m    
.83333  1.5 L    
s    
P    
p    
.001  w    
.03333  1.49625 m    
.03333  1.5 L    
s    
P    
p    
.001  w    
.06667  1.49625 m    
.06667  1.5 L    
s    
P    
p    
.001  w    
.1  1.49625 m    
.1  1.5 L    
s    
P    
p    
.001  w    
.13333  1.49625 m    
.13333  1.5 L    
s    
P    
p    
.001  w    
.2  1.49625 m    
.2  1.5 L    
s    
P    
p    
.001  w    
.23333  1.49625 m    
.23333  1.5 L    
s    
P    
p    
.001  w    
.26667  1.49625 m    
.26667  1.5 L    
s    
P    
p    
.001  w    
.3  1.49625 m    
.3  1.5 L    
s    
P    
p    
.001  w    
.36667  1.49625 m    
.36667  1.5 L    
s    
P    
p    
.001  w    
.4  1.49625 m    
.4  1.5 L    
s    
P    
p    
.001  w    
.43333  1.49625 m    
.43333  1.5 L    
s    
P    
p    
.001  w    
.46667  1.49625 m    
.46667  1.5 L    
s    
P    
p    
.001  w    
.53333  1.49625 m    
.53333  1.5 L    
s    
P    
p    
.001  w    
.56667  1.49625 m    
.56667  1.5 L    
s    
P    
p    
.001  w    
.6  1.49625 m    
.6  1.5 L    
s    
P    
p    
.001  w    
.63333  1.49625 m    
.63333  1.5 L    
s    
P    
p    
.001  w    
.7  1.49625 m    
.7  1.5 L    
s    
P    
p    
.001  w    
.73333  1.49625 m    
.73333  1.5 L    
s    
P    
p    
.001  w    
.76667  1.49625 m    
.76667  1.5 L    
s    
P    
p    
.001  w    
.8  1.49625 m    
.8  1.5 L    
s    
P    
p    
.001  w    
.86667  1.49625 m    
.86667  1.5 L    
s    
P    
p    
.001  w    
.9  1.49625 m    
.9  1.5 L    
s    
P    
p    
.001  w    
.93333  1.49625 m    
.93333  1.5 L    
s    
P    
p    
.001  w    
.96667  1.49625 m    
.96667  1.5 L    
s    
P    
p    
.002  w    
0 1.5 m    
1 1.5 L    
s    
P    
p    
.002  w    
.99375  .08333  m    
1 .08333  L    
s    
P    
p    
.002  w    
.99375  .29167  m    
1 .29167  L    
s    
P    
p    
.002  w    
.99375  .5  m    
1 .5  L    
s    
P    
p    
.002  w    
.99375  .70833  m    
1 .70833  L    
s    
P    
p    
.002  w    
.99375  .91667  m    
1 .91667  L    
s    
P    
p    
.002  w    
.99375  1.125 m    
1 1.125 L    
s    
P    
p    
.002  w    
.99375  1.33333 m    
1 1.33333 L    
s    
P    
p    
.001  w    
.99625  .125  m    
1 .125  L    
s    
P    
p    
.001  w    
.99625  .16667  m    
1 .16667  L    
s    
P    
p    
.001  w    
.99625  .20833  m    
1 .20833  L    
s    
P    
p    
.001  w    
.99625  .25  m    
1 .25  L    
s    
P    
p    
.001  w    
.99625  .33333  m    
1 .33333  L    
s    
P    
p    
.001  w    
.99625  .375  m    
1 .375  L    
s    
P    
p    
.001  w    
.99625  .41667  m    
1 .41667  L    
s    
P    
p    
.001  w    
.99625  .45833  m    
1 .45833  L    
s    
P    
p    
.001  w    
.99625  .54167  m    
1 .54167  L    
s    
P    
p    
.001  w    
.99625  .58333  m    
1 .58333  L    
s    
P    
p    
.001  w    
.99625  .625  m    
1 .625  L    
s    
P    
p    
.001  w    
.99625  .66667  m    
1 .66667  L    
s    
P    
p    
.001  w    
.99625  .75  m    
1 .75  L    
s    
P    
p    
.001  w    
.99625  .79167  m    
1 .79167  L    
s    
P    
p    
.001  w    
.99625  .83333  m    
1 .83333  L    
s    
P    
p    
.001  w    
.99625  .875  m    
1 .875  L    
s    
P    
p    
.001  w    
.99625  .95833  m    
1 .95833  L    
s    
P    
p    
.001  w    
.99625  1 m    
1 1 L    
s    
P    
p    
.001  w    
.99625  1.04167 m    
1 1.04167 L    
s    
P    
p    
.001  w    
.99625  1.08333 m    
1 1.08333 L    
s    
P    
p    
.001  w    
.99625  1.16667 m    
1 1.16667 L    
s    
P    
p    
.001  w    
.99625  1.20833 m    
1 1.20833 L    
s    
P    
p    
.001  w    
.99625  1.25 m    
1 1.25 L    
s    
P    
p    
.001  w    
.99625  1.29167 m    
1 1.29167 L    
s    
P    
p    
.001  w    
.99625  .04167  m    
1 .04167  L    
s    
P    
p    
.001  w    
.99625  1.375 m    
1 1.375 L    
s    
P    
p    
.001  w    
.99625  1.41667 m    
1 1.41667 L    
s    
P    
p    
.001  w    
.99625  1.45833 m    
1 1.45833 L    
s    
P    
p    
.002  w    
1 0 m    
1 1.5 L    
s    
P    
P    
p    
P    
0 0 m    
1 0 L    
1 1.5 L    
0 1.5 L    
closepath    
clip    
newpath    
p    
p    
p    
.5  .5  .5  r    
.08333  .08333  m    
.08333  .75  L    
.25  .75  L    
.25  1.41667 L    
.75  1.41667 L    
.75  .75  L    
.91667  .75  L    
.91667  .08333  L    
F    
.004  w    
.25  .75  m    
.25  .75  .16667  0 365.73 arc    
F    
.75  .75  m    
.75  .75  .16667  0 365.73 arc    
F    
P    
p    
1 1 1 r    
.004  w    
.5  .5  m    
.5  .5  .33333  0 365.73 arc    
F    
.33333  .5  m    
.33333  1.33333 L    
.66667  1.33333 L    
.66667  .5  L    
F    
P    
p    
.01  w    
.5  .83333  m    
.5  1.25 L    
s    
.02  w    
.5  .5  Mdot    
.5  .83333  Mdot    
.5  1.25 Mdot    
P    
P    
p    
p    
1 0 0 r    
.004  w    
.5  .5  m    
.5  .5  .3125  126 306 arc    
F    
.5  .5  m    
.5  .5  .3125  15.9465 56.0535 arc    
F    
p    
.56368  .41236  m    
.80301  .58624  L    
.67566  .76153  L    
.43632  .58764  L    
F    
P    
P    
p    
.75  0 0 r    
.004  w    
.5  .5  m    
.5  .5  .05833  0 365.73 arc    
F    
.70225  .64695  m    
.70225  .64695  .04167  0 365.73 arc    
F    
P    
p    
.02  w    
.5  .5  Mdot    
p    
.70225  .64695  Mdot    
P    
P    
P    
p    
p    
.5  .5  1 r    
.35  .88623  m    
.65  .88623  L    
.65  1.1779 L    
.35  1.1779 L    
F    
P    
p    
0 0 1 r    
.004  w    
.5  1.01123 m    
.5  1.01123 .04167  0 365.73 arc    
F    
P    
p    
p    
.01  w    
.5  1.01123 m    
.5  1.1779 L    
s    
P    
p    
.02  w    
.5  1.01123 Mdot    
.5  1.1779 Mdot    
P    
P    
P    
p    
.04  w    
.70225  .64695  m    
.5  1.01123 L    
s    
P    
P    
% End of Graphics    
MathPictureEnd    \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{200, 300},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000380001;1000`40O003h00Ob7oo0038Ool00<Qo
o`00b7oo0038Ool00<Qoo`00b7oo0038Ool00<Qoo`00b7oo0038Ool00<Qoo`00b7oo0038Ool003Eo
o`<001Uoo`<001Qoo`03001oogoo01Uoo`<001]oo`<001Yoo`8000=oo`00=Woo00<007ooOol067oo
00<007ooOol05goo00<007oo00006Woo00<007ooOol077oo00<007ooOol06Goo00<007oo00000Woo
000_Ool30002Ool4000DOol30003Ool00`00Oomoo`0FOol00`00Ool0000KOol00`00Oomoo`0IOol4
000JOol00`00Ool00002Ool003Aoo`03001oo`0001]oo`03001oogoo01Ioo`03001oo`0001]oo`03
001oogoo01Uoo`03001oo`0001]oo`8000=oo`00=Goo0P006Woo00<007oo00005goo00<007oo0000
6Woo00<007oo00006goo0P006goo00<007ooOol00Woo000fOol00`00Oomoo`0IOol00`00Oomoo`0G
Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0JOol20002Ool00<Qoo`00b7oo0038Ool0
0<Qoo`00b7oo0038Ool00<Qoo`00b7oo000FOon_0003Ool001Ioo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo005oo`005Woo00<0
07ooOol0Zgoo00<007ooOol00Goo000FOol00`00Oomoo`2[Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo0:]oo`03001oogoo005oo`005Woo00<007ooOol0Zgoo00<007ooOol00Goo000FOol00`00Oomo
o`2[Ool00`00Oomoo`01Ool001Ioo`03001oogoo0:Yoo`8000=oo`005Woo00<007ooOol0Zgoo00<0
07ooOol00Goo000FOol00`00Oomoo`2[Ool00`00Oomoo`01Ool001Ioo`03001oogoo0:]oo`03001o
ogoo005oo`005Woo00<007ooOol0Zgoo00<007ooOol00Goo000FOol00`00Oomoo`2[Ool00`00Oomo
o`01Ool0015oo`03001oogoo009oo`03001oogoo0:]oo`03001oogoo005oo`0047oo00<007oo0000
0goo00<007ooOol0Zgoo00<007ooOol00Goo000;Ool30004Ool01000Oomoogoo0P00Zgoo0P000goo
000@Ool20004Ool00`00Oomoo`0;OonA?Nl?Ool00`00Oomoo`01Ool0011oo`03001oogoo00=oo`03
001oogoo00]ooi4mk`moo`03001oogoo005oo`0047oo0`000goo00<007ooOol02gooTCg_3goo00<0
07ooOol00Goo000FOol00`00Oomoo`0;OonA?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]o
oi4mk`moo`03001oogoo005oo`005Woo00<007ooOol02gooTCg_3goo00<007ooOol00Goo000FOol0
0`00Oomoo`0;OonA?Nl>Ool20003Ool001Ioo`03001oogoo00]ooi4mk`moo`03001oogoo005oo`00
5Woo00<007ooOol02gooTCg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OonA?Nl?Ool00`00
Oomoo`01Ool001Ioo`03001oogoo00]ooi4mk`moo`03001oogoo005oo`005Woo00<007ooOol02goo
TCg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OonA?Nl?Ool00`00Oomoo`01Ool001Ioo`03
001oogoo00]ooi4mk`ioo`8000=oo`005Woo00<007ooOol02goo@Sg_3Woo@Cg_3goo00<007ooOol0
0Goo000FOol00`00Oomoo`0;Ooll?NlJOolk?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]o
ocHmkbEoocHmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo=3g_:Woo<cg_3goo00<007oo
Ool00Goo000FOol00`00Oomoo`0;Oola?Nl?OolCO00>Ool`?Nl?Ool00`00Oomoo`01Ool001Ioo`03
001oogoo00]ooc0mk`]ooael00Yooblmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo;Sg_
27oo9G`027oo;Sg_3Woo0P000goo000FOol00`00Oomoo`0;Ool/?Nl8OolYO009Ool[?Nl?Ool00`00
Oomoo`01Ool001Ioo`03001oogoo00]oob/mk`Ioobml00MoobXmk`moo`03001oogoo005oo`005Woo
00<007ooOol02goo:Cg_1goo<W`01Woo:Cg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolW
?Nl8OoleO007OolV?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]oobHmk`IoocYl00IoobDm
k`moo`03001oogoo005oo`005Woo00<007ooOol02goo9Cg_1Goo?G`01Woo93g_3goo00<007ooOol0
0Goo000FOol00`00Oomoo`0;OolT?Nl5Oom0O005OolS?Nl?Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00]oob8mk`Iood5l00Ioob8mk`ioo`8000=oo`005Woo00<007ooOol02goo8Cg_1Woo@G`027oo
8Cg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolP?Nl6Oom1O00:OolP?Nl?Ool00`00Oomo
o`01Ool001Ioo`03001oogoo00]ooalmk`Eood=l00]ooalmk`moo`03001oogoo005oo`005Woo00<0
07ooOol02goo7Sg_1Goo@g`03Goo7Sg_3goo00<007ooOol00Goo0006Ool30003Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0;OolM?Nl5Oom3O00?OolM?Nl?Ool00`00Oomoo`01Ool000Io
o`03001oogoo00Moo`03001oo`0000=oo`03001oogoo00]ooa`mk`Eood=l015ooa`mk`moo`03001o
ogoo005oo`0000Aoo`00000000=oo`03001oogoo00Qoo`04001oogooOol2000<OolL?Nl4Oom4O00B
OolK?Nl>Ool20003Ool000Moo`03001oogoo00Ioo`8000Aoo`03001oogoo00]ooa/mk`AoodAl01Ao
oaXmk`moo`03001oogoo005oo`001Woo00<007oo00001goo00<007ooOol00goo00<007ooOol02goo
6cg_0gooA7`05Woo6Cg_3goo00<007ooOol00Goo0007Ool00`00Oomoo`06Ool30003Ool00`00Oomo
o`0;OolJ?Nl4Oom3O00HOolH?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooaTmk`AoodAl
01QooaPmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo63g_1Goo@g`06Woo5cg_3goo00<0
07ooOol00Goo000FOol00`00Oomoo`0;OolG?Nl5Oom3O00KOolG?Nl?Ool00`00Oomoo`01Ool001Io
o`03001oogoo00]ooaLmk`AoodAl01aooaHmk`ioo`8000=oo`005Woo00<007ooOol02goo5cg_17oo
@g`07Woo5Cg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolF?Nl4Oom3O00OOolE?Nl?Ool0
0`00Oomoo`01Ool001Ioo`03001oogoo00]ooaDmk`Eood9l025ooa@mk`moo`03001oogoo005oo`00
5Woo00<007ooOol02goo53g_1Goo@g`08Goo53g_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;
OolD?Nl5Oom2O00SOolC?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooa@mk`Aood9l02Ao
oa<mk`moo`03001oogoo005oo`005Woo00<007ooOol02goo4cg_17oo@W`09Goo4cg_3goo00<007oo
Ool00Goo000FOol00`00Oomoo`0;OolC?Nl4Oom2O00VOolB?Nl>Ool20003Ool001Ioo`03001oogoo
00]ooa8mk`Aood9l02Mooa8mk`moo`03001oogoo005oo`005Woo00<007ooOol02goo4Sg_17oo@G`0
:Goo4Cg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolB?Nl3Oom2O00YOolA?Nl?Ool00`00
Oomoo`01Ool001Ioo`03001oogoo00]ooa4mk`Aood5l02Yooa4mk`moo`03001oogoo005oo`005Woo
00<007ooOol02goo4Cg_17oo@7`0;7oo43g_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolA
?Nl4OoloO00]Ool@?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooa4mk`Aood5l02]ooa0m
k`ioo`8000=oo`005Woo00<007ooOol02goo4Cg_17oo@W`0:goo3cg_3goo00<007ooOol00Goo000F
Ool00`00Oomoo`0;OolA?Nl3Oom5O00YOol??Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]o
oa0mk`Aoocel0003Ooml07`000Il02Qoo`lmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo
43g_0gooB7`09goo3cg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;Ool@?Nl3OolcO006G00A
O00UOol??Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]oo`lmk`Aooc5l00]L0003Ooml07`0
00al02Aoo`lmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo3cg_17oo;g`03U`047`08goo
3Sg_3Woo0P000goo000FOol00`00Oomoo`0;Ool??Nl4Ool^O00@G00@O00ROol>?Nl?Ool00`00Oomo
o`01Ool001Ioo`03001oogoo00]oo`lmk`Aoobil015L011l025oo`hmk`moo`03001oogoo005oo`00
5Woo00<007ooOol02goo3cg_17oo;G`04e`04G`07goo3Sg_3goo00<007ooOol00Goo000FOol00`00
Oomoo`0;Ool??Nl4Ool]O00CG00BO00NOol>?Nl?Ool00`00Oomoo`01Ool0015oo`03001oogoo009o
o`03001oogoo00]oo`lmk`=oobel01AL01Al01aoo`hmk`moo`03001oogoo005oo`0047oo00<007oo
00000goo00<007ooOol02goo3cg_0goo;G`055`05G`06goo3Sg_3goo00<007ooOol00Goo000@Ool0
0`00Ool00003Ool2000<Ool??Nl3Ool]O00DG00FO00JOol>?Nl>Ool20003Ool0011oo`03001oo`00
00=oo`03001oogoo00]oo`lmk`=oobel01AL01Ql01Qoo`hmk`moo`03001oogoo005oo`0047oo00<0
07oo00000goo00<007ooOol02goo3cg_0goo;G`055`06G`05goo3Sg_3goo00<007ooOol00Goo000A
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool??Nl3Ool]O00DG00KO00EOol>?Nl?Ool00`00Oomoo`01
Ool001Ioo`03001oogoo00]oo`lmk`=oobel01=L01el01Aoo`hmk`moo`03001oogoo005oo`005Woo
00<007ooOol02goo3cg_17oo;G`04U`07W`04goo3Sg_3goo00<007ooOol00Goo000FOol00`00Oomo
o`0;Ool??Nl4Ool]O00AG00QO00AOol>?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]oo`lm
k`Aoobil011L029l011oo`hmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo3cg_17oo;g`0
3U`09G`03Woo3Sg_3Woo0P000goo000FOol00`00Oomoo`0;Ool??Nl4Ool`O00;G00XO00<Ool??Nl?
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooa0mk`Aoobil0003Ooml07`000QL02Yl00]oo`lm
k`moo`03001oogoo005oo`005Woo00<007ooOol02goo43g_17oo;G`000=oog`0O000=G`02Goo3cg_
3goo00<007ooOol00Goo000FOol00`00Oomoo`0;Ool@?Nl4OomVO008Ool??Nl?Ool00`00Oomoo`01
Ool001Ioo`03001oogoo00]ooa4mk`=oobal0003Ooml07`003Ul00Ioo`lmk`moo`03001oogoo005o
o`005Woo00<007ooOol02goo4Cg_0goo:g`000=oog`0O000>g`01Goo3cg_3goo00<007ooOol00Goo
000FOol00`00Oomoo`0;OolA?Nl4OomYO003Ool@?Nl>Ool20003Ool001Ioo`03001oogoo00]ooa4m
k`AoofUl00=ooa0mk`moo`03001oogoo005oo`005Woo00<007ooOol02goo4Cg_17oo:7`00goo?G`0
0goo4Cg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolB?Nl4OolVO005OollO003OolA?Nl?
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooa8mk`AoobIl00MoocYl00=ooa4mk`moo`03001o
ogoo005oo`005Woo00<007ooOol02goo4Sg_1Goo97`02Goo9G`025`02g`00goo4Sg_3goo00<007oo
Ool00Goo000FOol00`00Oomoo`0;OolC?Nl4OolSO00;OolRO00;G00:O003OolB?Nl?Ool00`00Oomo
o`01Ool001Ioo`03001oogoo00]ooa<mk`Aoob9l00ioob1l00aL00Ql00Aooa8mk`ioo`8000=oo`00
5Woo00<007ooOol02goo4cg_1Goo8G`03goo7W`01E`00P001U`027`00goo4cg_3goo00<007ooOol0
0Goo000FOol00`00Oomoo`0;OolD?Nl4OolPO00AOolMO005G0040004G007O004OolC?Nl?Ool00`00
Oomoo`01Ool001Ioo`03001oogoo00]ooa@mk`Eooail01Aooa]l00AL00H000=L00Ml00Aooa<mk`mo
o`03001oogoo005oo`005Woo00<007ooOol02goo53g_1Goo7W`05Goo6G`015`01`000e`01W`017oo
53g_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolE?Nl5OolLO00HOolGO004G0060004G006
O004OolD?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooaHmk`Aooa]l01YooaIl00=L00H0
00EL00El00AooaDmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo5cg_0goo6W`077oo5W`0
0U`01P001E`017`01Goo5Cg_3Woo0P000goo000FOol00`00Oomoo`0;OolG?Nl4OolIO00NOolEO006
0005G004O005OolF?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooaLmk`EooaMl021ooaAl
00H000AL00El00AooaLmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo63g_1Goo5G`08Woo
4W`01P0015`01G`01Goo5cg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolI?Nl4OolDO00U
Ool@O0060003G005O005OolH?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooaXmk`Aooa=l
02Ioo`il00H000Ql00EooaTmk`moo`03001oogoo005oo`001Woo0`000goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol02goo6cg_17oo4G`0:7oo37`01`0027`017oo6Sg_3goo00<007ooOol0
0Goo0006Ool00`00Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`0;OolL?Nl4Ool?O00[Ool:O006
0008O005OolJ?Nl?Ool00`00Oomoo`01Ool000Moo`03001oogoo00Qoo`04001oogooOol2000<OolL
?Nl5Ool>O00/Ool8O0060008O005OolK?Nl>Ool20003Ool000Moo`03001oogoo00Ioo`8000Aoo`03
001oogoo00]ooa`mk`Ioo`al02moo`Il00H000Ml00Eooa`mk`moo`03001oogoo005oo`001Woo00<0
07oo00001goo00<007ooOol00goo00<007ooOol02goo7Cg_1Woo2W`0<Goo17`01P0027`017oo7Cg_
3goo00<007ooOol00Goo0007Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`0;OolN?Nl6Ool8O00c
Ool3O0060007O004OolN?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]ooalmk`Ioo`Ml03Eo
o`H000Il00Eooalmk`moo`03001oogoo005oo`005Woo00<007ooOol02goo83g_1Woo1G`0=Woo1P00
1G`01Goo83g_3goo00<007ooOol00Goo000FOol00`00Oomoo`0;OolQ?Nl6Ool3O00fOol60005O005
OolQ?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]oob8mkceoo`L000=l00Ioob8mk`ioo`80
00=oo`005Woo00<007ooOol02goo93g_>goo1P0000=oog`0O0001Woo8cg_3goo00<007ooOol00Goo
000FOol00`00Oomoo`0<OolT?NliOol60009OolT?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo
00aoobDmkcQoo`H000QoobDmk`moo`03001oogoo005oo`005Woo00<007ooOol037oo9Sg_=Woo1P00
27oo9Sg_3goo00<007ooOol00Goo000FOol00`00Oomoo`0<OolX?NldOol60005OolY?Nl?Ool00`00
Oomoo`01Ool001Ioo`03001oogoo00aoobXmkc5oo`H000EoobXmk`moo`03001oogoo005oo`005Woo
00<007ooOol037oo:cg_<7oo1P0017oo:cg_3Woo0P000goo000FOol00`00Oomoo`0=OolZ?Nl_Ool6
0005OolZ?Nl@Ool00`00Oomoo`01Ool001Ioo`03001oogoo00eoobXmkbioo`L000EoobXmka1oo`03
001oogoo005oo`005Woo00<007ooOol03Goo:Sg_;Woo1P001Woo:Sg_47oo00<007ooOol00Goo000F
Ool00`00Oomoo`0>OolY?Nl]Ool60007OolY?NlAOol00`00Oomoo`01Ool001Ioo`03001oogoo00io
obTmkbeoo`H000MoobTmka5oo`03001oogoo005oo`005Woo00<007ooOol03Woo:Cg_;7oo1P0027oo
:Cg_4Goo00<007ooOol00Goo000FOol00`00Oomoo`0?OolX?NlMOol00`00Oomoo`0<Ool60008OolX
?NlAOol20003Ool001Ioo`03001oogoo00moobPmkaeoo`03001oogoo00]oo`H000UoobLmka=oo`03
001oogoo005oo`005Woo00<007ooOol047oo9cg_7Goo00<007ooOol02goo1P002Goo9Sg_57oo00<0
07ooOol00Goo000FOol00`00Oomoo`0AOolV?NlMOol00`00Oomoo`0:Ool6000:OolV?NlDOol00`00
Oomoo`01Ool001Ioo`03001oogoo019oobDmkaeoo`03001oogoo00Uoo`L000YoobHmkaAoo`03001o
ogoo005oo`005Woo00<007ooOol04goo93g_7Goo00<007ooOol02Goo1P002goo9Cg_5Goo00<007oo
Ool00Goo000FOol00`00Oomoo`0COolT?NlMOol00`00Oomoo`08Ool6000<OolT?NlFOol00`00Oomo
o`01Ool001Ioo`03001oogoo01Aoob<mkaeoo`03001oogoo00Qoo`H000aoob<mkaMoo`03001oogoo
005oo`005Woo00<007ooOol05Goo8Sg_7Goo00<007ooOol01goo1P003Goo8Sg_5goo0P000goo000F
Ool00`00Oomoo`0GOolP?NlMOol00`00Oomoo`07Ool6000=OolQ?NlIOol00`00Oomoo`01Ool001Io
o`03001oogoo01Uooahmkaeoo`03001oogoo00Ioo`H000iooahmkaaoo`03001oogoo005oo`005Woo
00<007ooOol06Woo7Cg_0goo8cgo1P002cgo0goo7Cg_7Goo00<007ooOol00Goo000FOol00`00Oomo
o`0LOolK?Nl3OolR?Ol6000<?Ol3OolL?NlNOol00`00Oomoo`01Ool0015oo`03001oogoo009oo`03
001oogoo01mooaPmk`=oob4mo`L000`mo`=ooaTmkb5oo`03001oogoo005oo`0047oo00<007oo0000
0goo00<007ooOol08Woo5Cg_0goo8Cgo1P003Cgo0goo5Sg_97oo00<007ooOol00Goo000BOol01000
Oomoogoo0P009Woo4Sg_0goo83go1P003Sgo0goo4cg_9Woo0P000goo000@Ool20004Ool00`00Oomo
o`0XOol??Nl3OolP?Ol6000>?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool0011oo`03001oogoo00=oo`03
001oogoo02Qoo`lmk`=ooalmo`H000lmo`=oo`hmkbaoo`03001oogoo005oo`0047oo0`000goo00<0
07ooOol0:7oo3cg_0goo7cgo1P003cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0X
Ool??Nl3OolN?Ol6000@?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmk`=o
oahmo`H0010mo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo3cg_0goo7Cgo1P00
4Cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol??Nl3OolL?Ol7000A?Ol3Ool>
?Nl[Ool20003Ool001Ioo`03001oogoo02Qoo`lmk`=ooa`mo`H0018mo`=oo`hmkbaoo`03001oogoo
005oo`005Woo00<007ooOol0:7oo3cg_0goo6cgo1P004cgo0goo3Sg_;7oo00<007ooOol00Goo000F
Ool00`00Oomoo`0XOol??Nl3OolH?Ol301l6000C?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03
001oogoo02Qoo`lmk`=ooaDmo`D07`H001@mo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007oo
Ool0:7oo3cg_0goo53go1P0O1P0053go0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0X
Ool??Nl3OolC?Ol601l600000`0O?Olmo`0B?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo02Qoo`lmk`=ooa<mo`H07`H000807a<mo`=oo`hmkb]oo`8000=oo`005Woo00<007ooOol0:7oo
3cg_0goo4cgo1@0O1P000`0O4cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol?
?Nl3OolC?Ol401l7000301lC?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lm
k`=ooa<mo`@07`H000@07a<mo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo3cg_
0goo4cgo100O1@001@0O4cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol??Nl3
OolC?Ol701l2000501lC?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmk`=o
oa@mo`H07`0300007`0O00@07a<mo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo
3cg_0goo5Cgo1@0O00<0000O01l00`0O53go0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomo
o`0XOol??Nl3OolF?Ol401l00`0001l07`0201lE?Ol3Ool>?Nl[Ool20003Ool001Ioo`03001oogoo
02Qoo`lmk`=ooaLmo`<07`0300007cgo01Lmo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007oo
Ool0:7oo3cg_0goo6Sgo00<003go?Ol05cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomo
o`0XOol??Nl3OolJ?Ol00`00?Olmo`0G?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo
02Qoo`lmk`=ooaXmo`03000mocgo01Lmo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0
:7oo3cg_0goo6Sgo00<003go?Ol05cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0X
Ool??Nl3OolJ?Ol00`00?Olmo`0G?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qo
o`lmk`=ooaXmo`03000mocgo01Lmo`=oo`hmkb]oo`8000=oo`005Woo00<007ooOol0:7oo3cg_0goo
6Sgo00<003go?Ol05cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol??Nl3OolJ
?Ol00`00?Olmo`0G?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmk`=ooaXm
o`03000mocgo01Lmo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo3cg_0goo6Sgo
00<003go?Ol05cgo0goo3Sg_;7oo00<007ooOol00Goo0007Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`0XOol??Nl3OolJ?Ol00`00?Olmo`0G?Ol3Ool>?Nl/Ool00`00
Oomoo`01Ool000Moo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo02Qoo`lmk`=ooaXmo`03
000mocgo01Lmo`=oo`hmkbaoo`03001oogoo005oo`001goo00<007ooOol027oo00@007ooOomoo`80
02Uoo`lmk`=ooaXmo`03000mocgo01Lmo`=oo`hmkb]oo`8000=oo`0027oo00<007ooOol01Goo0P00
17oo00<007ooOol0:7oo3cg_0goo6Sgo00<003go?Ol05cgo0goo3Sg_;7oo00<007ooOol00Goo0006
Ool00`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`0XOol??Nl3OolJ?Ol00`00?Olmo`0G?Ol3
Ool>?Nl/Ool00`00Oomoo`01Ool000Ioo`<000Moo`<000=oo`03001oogoo02Qoo`lmk`=ooaXmo`03
000mocgo01Lmo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo3cg_0goo6Sgo00<0
03go?Ol05cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol??Nl3OolJ?Ol00`00
?Olmo`0G?Ol3Ool>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmk`=ooaXmo`03000m
ocgo01Lmo`=oo`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo3cg_0goo6Sgo00<003go
?Ol05cgo0goo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol??Nl3OolJ?Ol00`00?Olm
o`0G?Ol3Ool>?Nl[Ool20003Ool001Ioo`03001oogoo02Qoo`lmk`=ooaXmo`03000mocgo01Lmo`=o
o`hmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo3cg_0goo6Sgo00<003go?Ol05cgo0goo
3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol??NlMOol00`00Oomoo`0JOol>?Nl/Ool0
0`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmkaeoo`03001oogoo01Yoo`hmkbaoo`03001oogoo
005oo`005Woo00<007ooOol0:7oo3cg_7Goo00<007ooOol06Woo3Sg_;7oo00<007ooOol00Goo000F
Ool00`00Oomoo`0XOol??NlMOol00`00Oomoo`0JOol>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo02Qoo`lmkaeoo`03001oogoo01Yoo`hmkb]oo`8000=oo`005Woo00<007ooOol0:7oo3cg_7Goo
00<007ooOol06Woo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOol??NlMOol00`00Oomo
o`0JOol>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmkaeoo`03001oogoo01Yoo`hm
kbaoo`03001oogoo005oo`005Woo00<007ooOol0:7oo3cg_7Goo00<007ooOol06Woo3Sg_;7oo00<0
07ooOol00Goo000FOol00`00Oomoo`0XOol??NlMOol00`00Oomoo`0JOol>?Nl/Ool00`00Oomoo`01
Ool001Ioo`03001oogoo02Qoo`lmkaeoo`03001oogoo01Yoo`hmkbaoo`03001oogoo005oo`005Woo
00<007ooOol0:7oo3cg_7Goo00<007ooOol06Woo3Sg_:goo0P000goo000FOol00`00Oomoo`0XOol?
?NljOol>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmkcYoo`hmkbaoo`03001oogoo
005oo`005Woo00<007ooOol0:7oo3cg_>Woo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0X
Ool??NljOol>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmkcYoo`hmkbaoo`03001o
ogoo005oo`005Woo00<007ooOol0:7oo3cg_>Woo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomo
o`0XOol??NljOol>?Nl[Ool20003Ool001Ioo`03001oogoo02Qoo`lmkcYoo`hmkbaoo`03001oogoo
005oo`005Woo00<007ooOol0:7oo3cg_>Woo3Sg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0X
Ool??NljOol>?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qoo`lmkcYoo`hmkbaoo`03001o
ogoo005oo`005Woo00<007ooOol0:7oo3cg_>Woo3Sg_;7oo00<007ooOol00Goo000:Ool50002Ool0
0`00Oomoo`02Ool00`00Oomoo`0XOol??NljOol>?Nl/Ool00`00Oomoo`01Ool000aoo`07001oogoo
Ool007oo00000goo00<007ooOol0:7oo3cg_>Woo3Sg_;7oo00<007ooOol00Goo000<Ool01`00Oomo
ogoo001oo`0000=oo`8002Uoo`lmkcYoo`hmkb]oo`8000=oo`0037oo00L007ooOomoo`00Ool00003
Ool00`00Oomoo`0XOomG?Nl/Ool00`00Oomoo`01Ool000aoo`07001oogooOol007oo00000goo00<0
07ooOol0:7ooEcg_;7oo00<007ooOol00Goo000;Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0X
OomG?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02QooeLmkbaoo`03001oogoo005oo`005Woo
00<007ooOol0:7ooEcg_;7oo00<007ooOol00Goo000FOol00`00Oomoo`0XOomG?Nl/Ool00`00Oomo
o`01Ool001Ioo`03001oogoo02QooeLmkb]oo`8000=oo`005Woo00<007ooOol0:7ooEcg_;7oo00<0
07ooOol00Goo000FOol00`00Oomoo`0XOomG?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Qo
oeLmkbaoo`03001oogoo005oo`005Woo00<007ooOol0:7ooEcg_;7oo00<007ooOol00Goo000FOol0
0`00Oomoo`0XOomG?Nl/Ool00`00Oomoo`01Ool001Ioo`03001oogoo02QooeLmkbaoo`03001oogoo
005oo`005Woo00<007ooOol0:7ooEcg_:goo0P000goo000FOol00`00Oomoo`2[Ool00`00Oomoo`01
Ool001Ioo`03001oogoo0:]oo`03001oogoo005oo`005Woo00<007ooOol0Zgoo00<007ooOol00Goo
000FOol00`00Oomoo`2[Ool00`00Oomoo`01Ool001Ioo`03001oogoo0:]oo`03001oogoo005oo`00
5Woo00<007ooOol0Zgoo00<007ooOol00Goo000FOol00`00Oomoo`2ZOol20003Ool001Ioo`03001o
ogoo0:]oo`03001oogoo005oo`005Woo00<007ooOol0Zgoo00<007ooOol00Goo000FOol00`00Oomo
o`2[Ool00`00Oomoo`01Ool001Ioo`03001oogoo0:]oo`03001oogoo005oo`005Woo00<007ooOol0
Zgoo00<007ooOol00Goo000FOol00`00Oomoo`2[Ool00`00Oomoo`01Ool001Ioo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo005o
o`005Woo[`000goo0038Ool00<Qoo`00b7oo0038Ool00<Qoo`00b7oo0038Ool00<Qoo`00b7oo0000
\
\>"],
  ImageRangeCache->{{{0, 199}, {299, 0}} -> {-7.52685, -7.90502, 0.0688392, 
  0.0688392}}]
}, Open  ]],

Cell[TextData[
"The following example analyzes the motion of a classic slider-crank \
mechanism. This mechanism is modeled with a simple and intuitive set of \
mechanical constraints that are representative of how such a problem would \
usually be modeled."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Body Numbers"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider-crank mechanism consists of three bodies:\nBody 1 is the ground \
body.\nBody 2 is the crankshaft.\nBody 3 is the piston."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Each independent body in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model must be given a unique positive integer body number. The choice of \
each body number is arbitrary, except for the ground body, which must be body \
1. These body numbers are used throughout a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model to reference each body. The ground body, which is stationary by \
definition, is used as the reference location and orientation for the rest of \
the model. All mechanism models must have some reference to the ground body \
to be adequately constrained.\n\nTo aid in the readability of the mechanism \
models created with ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ", it is customary to name each of the bodies in a mechanism, and then \
define each of these names to be equal to the integer body number of the \
body. Each body can then be referenced by name instead of by a number."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Body names are defined to be used as references for each body."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crankshaft = 2; \)\), 
    \(\(piston = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"A real slider-crank mechanism would have a fourth body, the connecting rod \
between the crankshaft and the piston. However, in the kinematic model this \
entire part can be replaced by a simple distance constraint specifying that \
the crank pin and the piston pin are a constant distance apart. This \
technique decreases the overall size of the model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Local Coordinates"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Each body in a mechanism model must have a local coordinate system \
attached to it. How to place this coordinate system on the body is up to the \
user and is based on the needs of the model. It is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " necessary to place the local coordinate origin at the center of gravity \
of the body. The local coordinate system of each body is used to define \
points, lines, and other features on the body that are then tied together to \
make the mechanical constraints.\n\nThe local coordinate system of body 1, \
the ground body, is always coincident with the global coordinate system. \
Therefore, the global coordinate system is referenced through the ground \
body, simply by specifying body 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2D Bodies"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Ground"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The local coordinate system of the ground body originates at the rotational \
center of the crankshaft."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three points are used on the ground body.\nP1 is a point at the global \
origin that is the rotational axis of the crankshaft.\nP2 and P3 are two \
points that define the vertical line upon which the piston translates."], 
  "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the ground body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(-5)] -0.0125 .08333 1 0 Msboxa
[(-2.5)] -0.0125 .29167 1 0 Msboxa
[(0)] -0.0125 .5 1 0 Msboxa
[(2.5)] -0.0125 .70833 1 0 Msboxa
[(5)] -0.0125 .91667 1 0 Msboxa
[(7.5)] -0.0125 1.125 1 0 Msboxa
[(10)] -0.0125 1.33333 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(-5)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .29167 m
.00625 .29167 L
s
P
[(-2.5)] -0.0125 .29167 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(0)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .70833 m
.00625 .70833 L
s
P
[(2.5)] -0.0125 .70833 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(5)] -0.0125 .91667 1 0 Mshowa
p
.002 w
0 1.125 m
.00625 1.125 L
s
P
[(7.5)] -0.0125 1.125 1 0 Mshowa
p
.002 w
0 1.33333 m
.00625 1.33333 L
s
P
[(10)] -0.0125 1.33333 1 0 Mshowa
p
.001 w
0 .125 m
.00375 .125 L
s
P
p
.001 w
0 .16667 m
.00375 .16667 L
s
P
p
.001 w
0 .20833 m
.00375 .20833 L
s
P
p
.001 w
0 .25 m
.00375 .25 L
s
P
p
.001 w
0 .33333 m
.00375 .33333 L
s
P
p
.001 w
0 .375 m
.00375 .375 L
s
P
p
.001 w
0 .41667 m
.00375 .41667 L
s
P
p
.001 w
0 .45833 m
.00375 .45833 L
s
P
p
.001 w
0 .54167 m
.00375 .54167 L
s
P
p
.001 w
0 .58333 m
.00375 .58333 L
s
P
p
.001 w
0 .625 m
.00375 .625 L
s
P
p
.001 w
0 .66667 m
.00375 .66667 L
s
P
p
.001 w
0 .75 m
.00375 .75 L
s
P
p
.001 w
0 .79167 m
.00375 .79167 L
s
P
p
.001 w
0 .83333 m
.00375 .83333 L
s
P
p
.001 w
0 .875 m
.00375 .875 L
s
P
p
.001 w
0 .95833 m
.00375 .95833 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.04167 m
.00375 1.04167 L
s
P
p
.001 w
0 1.08333 m
.00375 1.08333 L
s
P
p
.001 w
0 1.16667 m
.00375 1.16667 L
s
P
p
.001 w
0 1.20833 m
.00375 1.20833 L
s
P
p
.001 w
0 1.25 m
.00375 1.25 L
s
P
p
.001 w
0 1.29167 m
.00375 1.29167 L
s
P
p
.001 w
0 .04167 m
.00375 .04167 L
s
P
p
.001 w
0 1.375 m
.00375 1.375 L
s
P
p
.001 w
0 1.41667 m
.00375 1.41667 L
s
P
p
.001 w
0 1.45833 m
.00375 1.45833 L
s
P
p
.002 w
0 0 m
0 1.5 L
s
P
P
p
p
.002 w
0 1.49375 m
0 1.5 L
s
P
p
.002 w
.16667 1.49375 m
.16667 1.5 L
s
P
p
.002 w
.33333 1.49375 m
.33333 1.5 L
s
P
p
.002 w
.5 1.49375 m
.5 1.5 L
s
P
p
.002 w
.66667 1.49375 m
.66667 1.5 L
s
P
p
.002 w
.83333 1.49375 m
.83333 1.5 L
s
P
p
.001 w
.03333 1.49625 m
.03333 1.5 L
s
P
p
.001 w
.06667 1.49625 m
.06667 1.5 L
s
P
p
.001 w
.1 1.49625 m
.1 1.5 L
s
P
p
.001 w
.13333 1.49625 m
.13333 1.5 L
s
P
p
.001 w
.2 1.49625 m
.2 1.5 L
s
P
p
.001 w
.23333 1.49625 m
.23333 1.5 L
s
P
p
.001 w
.26667 1.49625 m
.26667 1.5 L
s
P
p
.001 w
.3 1.49625 m
.3 1.5 L
s
P
p
.001 w
.36667 1.49625 m
.36667 1.5 L
s
P
p
.001 w
.4 1.49625 m
.4 1.5 L
s
P
p
.001 w
.43333 1.49625 m
.43333 1.5 L
s
P
p
.001 w
.46667 1.49625 m
.46667 1.5 L
s
P
p
.001 w
.53333 1.49625 m
.53333 1.5 L
s
P
p
.001 w
.56667 1.49625 m
.56667 1.5 L
s
P
p
.001 w
.6 1.49625 m
.6 1.5 L
s
P
p
.001 w
.63333 1.49625 m
.63333 1.5 L
s
P
p
.001 w
.7 1.49625 m
.7 1.5 L
s
P
p
.001 w
.73333 1.49625 m
.73333 1.5 L
s
P
p
.001 w
.76667 1.49625 m
.76667 1.5 L
s
P
p
.001 w
.8 1.49625 m
.8 1.5 L
s
P
p
.001 w
.86667 1.49625 m
.86667 1.5 L
s
P
p
.001 w
.9 1.49625 m
.9 1.5 L
s
P
p
.001 w
.93333 1.49625 m
.93333 1.5 L
s
P
p
.001 w
.96667 1.49625 m
.96667 1.5 L
s
P
p
.002 w
0 1.5 m
1 1.5 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .29167 m
1 .29167 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .70833 m
1 .70833 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.002 w
.99375 1.125 m
1 1.125 L
s
P
p
.002 w
.99375 1.33333 m
1 1.33333 L
s
P
p
.001 w
.99625 .125 m
1 .125 L
s
P
p
.001 w
.99625 .16667 m
1 .16667 L
s
P
p
.001 w
.99625 .20833 m
1 .20833 L
s
P
p
.001 w
.99625 .25 m
1 .25 L
s
P
p
.001 w
.99625 .33333 m
1 .33333 L
s
P
p
.001 w
.99625 .375 m
1 .375 L
s
P
p
.001 w
.99625 .41667 m
1 .41667 L
s
P
p
.001 w
.99625 .45833 m
1 .45833 L
s
P
p
.001 w
.99625 .54167 m
1 .54167 L
s
P
p
.001 w
.99625 .58333 m
1 .58333 L
s
P
p
.001 w
.99625 .625 m
1 .625 L
s
P
p
.001 w
.99625 .66667 m
1 .66667 L
s
P
p
.001 w
.99625 .75 m
1 .75 L
s
P
p
.001 w
.99625 .79167 m
1 .79167 L
s
P
p
.001 w
.99625 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .875 m
1 .875 L
s
P
p
.001 w
.99625 .95833 m
1 .95833 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.04167 m
1 1.04167 L
s
P
p
.001 w
.99625 1.08333 m
1 1.08333 L
s
P
p
.001 w
.99625 1.16667 m
1 1.16667 L
s
P
p
.001 w
.99625 1.20833 m
1 1.20833 L
s
P
p
.001 w
.99625 1.25 m
1 1.25 L
s
P
p
.001 w
.99625 1.29167 m
1 1.29167 L
s
P
p
.001 w
.99625 .04167 m
1 .04167 L
s
P
p
.001 w
.99625 1.375 m
1 1.375 L
s
P
p
.001 w
.99625 1.41667 m
1 1.41667 L
s
P
p
.001 w
.99625 1.45833 m
1 1.45833 L
s
P
p
.002 w
1 0 m
1 1.5 L
s
P
P
p
P
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
p
p
p
.5 .5 .5 r
.08333 .08333 m
.08333 .75 L
.25 .75 L
.25 1.41667 L
.75 1.41667 L
.75 .75 L
.91667 .75 L
.91667 .08333 L
F
.004 w
.25 .75 m
.25 .75 .16667 0 365.73 arc
F
.75 .75 m
.75 .75 .16667 0 365.73 arc
F
P
p
1 1 1 r
.004 w
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
.33333 .5 m
.33333 1.33333 L
.66667 1.33333 L
.66667 .5 L
F
P
p
.01 w
.5 .83333 m
.5 1.25 L
s
.025 w
.5 .5 Mdot
.5 .83333 Mdot
.5 1.25 Mdot
P
P
p
[({0,0})] .5 .5 0 -1.7 Mshowa
[(P1)] .5 .5 1.7 1 Mshowa
[({0,4})] .5 .83333 0 1.7 Mshowa
[(P2)] .5 .83333 1.7 -1 Mshowa
[({0,9})] .5 1.25 0 -1.7 Mshowa
[(P3)] .5 1.25 1.7 1 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{191, 287},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002o00017a000`40O003h00O_goo002oOol00;mo
o`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol003=o
o`<001Qoo`<001Moo`03001oogoo01Moo`<001Yoo`<001Qoo`8000=oo`00=7oo00<007ooOol05goo
00<007ooOol05Woo00<007oo000067oo00<007ooOol06goo00<007ooOol05goo00<007oo00000Woo
000]Ool30002Ool4000COol30003Ool00`00Oomoo`0EOol00`00Ool0000IOol00`00Oomoo`0HOol4
000HOol00`00Ool00002Ool0039oo`03001oo`0001Yoo`03001oogoo01Eoo`03001oo`0001Uoo`03
001oogoo01Qoo`03001oo`0001Uoo`8000=oo`00<goo0P006Goo00<007oo00005Woo00<007oo0000
67oo00<007oo00006Woo0P006Goo00<007ooOol00Woo000dOol00`00Oomoo`0HOol00`00Oomoo`0F
Ool00`00Oomoo`0HOol00`00Oomoo`0JOol00`00Oomoo`0HOol20002Ool00;moo`00_goo002oOol0
0;moo`00_goo002oOol00;moo`00_goo000FOonV0003Ool001Ioo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo005oo`005Woo00<0
07ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001o
ogoo0:9oo`03001oogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomo
o`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:5oo`8000=oo`005Woo00<007ooOol0XWoo00<0
07ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:9oo`03001o
ogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000AOol00`00Oomoo`02Ool00`00Oomo
o`2ROol00`00Oomoo`01Ool0011oo`03001oo`0000=oo`03001oogoo0:9oo`03001oogoo005oo`00
2goo0`0017oo00@007ooOomoo`800:9oo`8000=oo`0047oo0P0017oo00<007ooOol02WooRSg_3Woo
00<007ooOol00Goo000@Ool00`00Oomoo`03Ool00`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool0
011oo`<000=oo`03001oogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007ooOol02WooRSg_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007ooOol02WooRSg_3Goo0P000goo000FOol0
0`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoohXmk`ioo`03001oogoo
005oo`005Woo00<007ooOol02WooRSg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007oo
Ool02WooRSg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl=Ool20003Ool001Ioo`03
001oogoo00Yooc`mka=ooc/mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo=Sg_7Woo=Sg_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oold?NlSOolc?Nl>Ool00`00Oomoo`01Ool001Io
o`03001oogoo00Yooc4mkbQooc4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo;cg_;Goo
;Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool/?NlbOol/?Nl>Ool00`00Oomoo`01Ool0
01Ioo`03001oogoo00YoobXmkcMoobTmk`eoo`8000=oo`005Woo00<007ooOol02Woo:Cg_>Goo:3g_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolW?NllOolW?Nl>Ool00`00Oomoo`01Ool001Io
o`03001oogoo00YoobDmkd1oobDmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo93g_@goo
8cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolS?Nm5OolR?Nl>Ool00`00Oomoo`01Ool0
01Ioo`03001oogoo00Yoob8mkdMoob4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo8Cg_
BGoo83g_3Goo0P000goo000FOol00`00Oomoo`0:OolP?Nm;OolO?Nl>Ool00`00Oomoo`01Ool001Io
o`03001oogoo00Yooalmkdeooahmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo7Sg_Cgoo
7Cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolM?NmAOolL?Nl>Ool00`00Oomoo`01Ool0
00Ioo`<000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yooa`mke=ooa/mk`ioo`03
001oogoo005oo`001Woo00<007ooOol01goo00<007oo00000goo00<007ooOol02Woo6cg_EGoo6Sg_
3Woo00<007ooOol00Goo000017oo000000000goo00<007ooOol027oo00@007ooOomoo`8000]ooaXm
keMooaTmk`eoo`8000=oo`001goo00<007ooOol01Woo0P0017oo00<007ooOol02Woo6Cg_F7oo6Cg_
3Woo00<007ooOol00Goo0006Ool00`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`0:OolI?NmI
OolH?Nl>Ool00`00Oomoo`01Ool000Moo`03001oogoo00Ioo`<000=oo`03001oogoo00YooaPmke]o
oaLmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo5cg_GGoo5Sg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:OolF?NmNOolF?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaHm
kemooaDmk`eoo`8000=oo`005Woo00<007ooOol02Woo5Sg_H7oo53g_3Woo00<007ooOol00Goo000F
Ool00`00Oomoo`0:OolE?NmQOolD?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaDmkf9o
oa<mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo53g_Hgoo4cg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:OolD?NmTOolB?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa<m
kfEooa8mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Sg_IWoo4Sg_3Goo0P000goo000F
Ool00`00Oomoo`0:OolB?NmWOolA?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa4mkfQo
oa4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Cg_JGoo43g_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:OolA?NmYOol@?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa4m
kfUooa0mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Cg_JWoo3cg_3Woo00<007ooOol0
0Goo000FOol00`00Oomoo`0:Ool@?Nm[Ool??Nl=Ool20003Ool001Ioo`03001oogoo00Yooa0mkf]o
o`lmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo43g_Jgoo3cg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:Ool??Nm/Ool??Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`lm
kfeoo`hmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo3cg_KGoo3Sg_3Woo00<007ooOol0
0Goo000FOol00`00Oomoo`0:Ool??NlYOol30002Ool5000jOol>?Nl>Ool00`00Oomoo`01Ool001Io
o`03001oogoo00Yoo`lmkbYoo`03001oogoo00=oo`03001oogoo03Yoo`hmk`eoo`8000=oo`005Woo
00<007ooOol02Woo3cg_:Woo0`000goo00<007ooOol0>Woo3Sg_3Woo00<007ooOol00Goo000FOol0
0`00Oomoo`0:Ool>?Nl[Ool01000Oomoo`000Woo00<007ooOol0>Woo3Sg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:Ool>?Nl[Ool01000Oomoo`000Woo00<007ooOol0>Woo3Sg_3Woo00<007oo
Ool00Goo000FOol00`00Oomoo`0:Ool>?NlZOol40002Ool2000lOol>?Nl>Ool00`00Oomoo`01Ool0
015oo`03001oogoo009oo`03001oogoo00Yoo`hmkfioo`hmk`ioo`03001oogoo005oo`0047oo00<0
07oo00000goo00<007ooOol02Woo3Sg_KWoo3Sg_3Woo00<007ooOol00Goo000@Ool00`00Ool00003
Ool2000;Ool>?NlgOol00`00Oomoo`0dOol>?Nl=Ool20003Ool0011oo`03001oo`0000=oo`03001o
ogoo00Yoo`hmkcIoo`<003Eoo`hmk`ioo`03001oogoo005oo`0047oo00<007oo00000goo00<007oo
Ool02Woo3Sg_=goo00<007ooOol0=7oo3Sg_3Woo00<007ooOol00Goo000AOol00`00Oomoo`02Ool0
0`00Oomoo`0:Ool>?Nm^Ool>?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`hmkfioo`hm
k`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo3Sg_KWoo3Sg_3Woo00<007ooOol00Goo000F
Ool00`00Oomoo`0:Ool>?Nm^Ool>?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`lmkbeo
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo02]oo`hmk`eoo`8000=oo`005Woo00<007oo
Ool02Woo3cg_;7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol0:Woo3Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool??Nl/Ool01`00Oomo
ogoo001oo`0000Aoo`06001oogoo001oo`000goo00<007ooOol0:Woo3Sg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:Ool??Nl[Ool20003Ool00`00Ool00007Ool00`00Ool00003Ool2000[Ool>
?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`lmkbaoo`07001oogooOol007oo00001goo
00<007oo00000goo00<007ooOol0:Goo3cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool@
?Nl[Ool01`00Oomoogoo001oo`0000Moo`03001oo`0000=oo`03001oogoo02Uoo`lmk`ioo`03001o
ogoo005oo`005Woo00<007ooOol02Woo43g_;7oo00D007ooOomoo`0000Uoo`05001oogooOol0000/
Ool??Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa0mkf]oo`lmk`eoo`8000=oo`005Woo
00<007ooOol02Woo4Cg_JWoo3cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolA?NmYOol@
?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa4mkfUooa0mk`ioo`03001oogoo005oo`00
5Woo00<007ooOol02Woo4Cg_JGoo43g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolA?NmX
OolA?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa8mkfMooa4mk`ioo`03001oogoo005o
o`005Woo00<007ooOol02Woo4Sg_IWoo4Sg_3Goo0P000goo000FOol00`00Oomoo`0:OolC?NmUOolB
?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa@mkfAooa8mk`ioo`03001oogoo005oo`00
5Woo00<007ooOol02Woo53g_Hgoo4cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolE?NmR
OolC?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaDmkf5ooa@mk`ioo`03001oogoo005o
o`005Woo00<007ooOol02Woo5Sg_H7oo53g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolF
?NmOOolE?Nl=Ool20003Ool001Ioo`03001oogoo00YooaHmkeiooaHmk`ioo`03001oogoo005oo`00
5Woo00<007ooOol02Woo5cg_GGoo5Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolH?NmK
OolG?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaTmkeUooaPmk`ioo`03001oogoo005o
o`001Woo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02Woo6Cg_F7oo6Cg_3Woo
00<007ooOol00Goo0006Ool00`00Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`0:OolJ?NmGOolI
?Nl>Ool00`00Oomoo`01Ool000Moo`03001oogoo00Qoo`04001oogooOol2000;OolK?NmFOolI?Nl=
Ool20003Ool000Moo`03001oogoo00Ioo`8000Aoo`03001oogoo00Yooa`mkeAooaXmk`ioo`03001o
ogoo005oo`001Woo00<007oo00001goo00<007ooOol00goo00<007ooOol02Woo7Cg_DWoo6cg_3Woo
00<007ooOol00Goo0007Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`0:OolM?NmAOolL?Nl>Ool0
0`00Oomoo`01Ool001Ioo`03001oogoo00Yooahmkdmooadmk`ioo`03001oogoo005oo`005Woo00<0
07ooOol02Woo7cg_CGoo7Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolQ?Nm9OolP?Nl=
Ool20003Ool001Ioo`03001oogoo00Yoob8mkaYoo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo01Qoob4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo8cg_67oo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo0`000Woo00<007ooOol05Woo8Sg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0;OolS?NlGOol01`00Oomoogoo001oo`0000Aoo`03001oogoo009oo`05001o
ogooOol0000GOolS?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]oob@mkaEoo`8000=oo`03
001oo`0000Moo`@0009oo`8001AoobDmk`ioo`03001oogoo005oo`005Woo00<007ooOol02goo9Sg_
57oo00L007ooOomoo`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0AOolW?Nl>Ool00`00Oomo
o`01Ool001Ioo`03001oogoo00]oobPmka9oo`07001oogooOol007oo000027oo0P000goo00<007oo
Ool047oo:3g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0;OolY?NlBOol01@00Oomoogoo0000
2Woo00@007ooOol0019oobTmk`eoo`8000=oo`005Woo00<007ooOol037oo:3g_=goo:Cg_3Woo00<0
07ooOol00Goo000FOol00`00Oomoo`0<OolX?NlgOolX?Nl?Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00aoobPmkcMoobPmk`moo`03001oogoo005oo`005Woo00<007ooOol03Goo9cg_=goo9cg_47oo
00<007ooOol00Goo000FOol00`00Oomoo`0=OolW?NlgOolW?Nl@Ool00`00Oomoo`01Ool001Ioo`03
001oogoo00ioobHmkcMoobLmka1oo`03001oogoo005oo`005Woo00<007ooOol03Woo9Sg_6goo00<0
07ooOol06Goo9Sg_47oo0P000goo000FOol00`00Oomoo`0>OolV?NlJOol3000JOolU?NlBOol00`00
Oomoo`01Ool001Ioo`03001oogoo00moobDmka]oo`03001oogoo01Uoob@mka=oo`03001oogoo005o
o`005Woo00<007ooOol047oo93g_6goo00<007ooOol06Goo93g_4goo00<007ooOol00Goo000FOol0
0`00Oomoo`0AOolS?Nl>Ool30003Ool30004Ool00`00Oomoo`0IOolS?NlDOol00`00Oomoo`01Ool0
01Ioo`03001oogoo019oob8mk`moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo01Uoob8m
kaEoo`03001oogoo005oo`005Woo00<007ooOol04goo8Cg_3goo0`000goo00<007ooOol00goo00<0
07ooOol06Goo8Cg_5Woo00<007ooOol00Goo000FOol00`00Oomoo`0DOolP?Nl?Ool01000Oomoo`00
0Woo00<007ooOol00goo00<007ooOol06Goo83g_5Woo0P000goo000FOol00`00Oomoo`0EOolO?Nl?
Ool02000Oomoo`00Ool007oo0004Ool00`00Oomoo`0IOolO?NlHOol00`00Oomoo`01Ool001Ioo`03
001oogoo01Iooahmk`ioo`@000=oo`03001oogoo00=oo`03001oogoo01UooahmkaUoo`03001oogoo
005oo`005Woo00<007ooOol067oo73g_6goo00<007ooOol06Goo7Cg_6Woo00<007ooOol00Goo000F
Ool00`00Oomoo`0JOolJ?NlKOol00`00Oomoo`0IOolJ?NlMOol00`00Oomoo`01Ool0015oo`03001o
ogoo009oo`03001oogoo01]ooaTmka]oo`03001oogoo01UooaPmkamoo`03001oogoo005oo`0047oo
00<007oo00000goo00<007ooOol07Goo5cg_6goo00<007ooOol06Goo5Cg_8Woo00<007ooOol00Goo
000BOol01000Oomoogoo0P008goo4Sg_6goo00<007ooOol06Goo4Sg_97oo0P000goo000@Ool20004
Ool00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool0011oo`03001o
ogoo00=oo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`0047oo
0`000goo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol0
0`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo
02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_
6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00
Oomoo`0IOol>?NlXOol20003Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUo
o`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007oo
Ool00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool0
01Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<0
07ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0V
Ool>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]o
o`03001oogoo01Uoo`hmkbQoo`8000=oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo
3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol0
0`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo
005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000F
Ool00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001o
ogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo
3Sg_6goo00<007ooOol06Goo3Sg_:7oo0P000goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomo
o`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hm
kbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<0
07ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01
Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo
00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomo
o`0VOol>?NlKOol00`00Oomoo`0IOol>?NlXOol20003Ool001Ioo`03001oogoo02Ioo`hmka]oo`03
001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol0
6Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlY
Ool00`00Oomoo`01Ool000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`001goo00<007ooOol01Woo
00<007oo00000goo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo
0007Ool00`00Oomoo`08Ool01000Oomoogoo0P009goo3Sg_6goo00<007ooOol06Goo3Sg_:7oo0P00
0goo0008Ool00`00Oomoo`05Ool20004Ool00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlY
Ool00`00Oomoo`01Ool000Ioo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo02Ioo`hmka]o
o`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`001Woo0`001goo0`000goo00<007ooOol09Woo
3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol0
0`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo
01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_
:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlXOol20003
Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo
00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomo
o`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hm
ka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<0
07ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl>Ool30003Ool20005
Ool00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`moo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo01Uoo`hmkbQoo`8000=oo`005Woo00<007ooOol09Woo
3Sg_3goo0`000goo00<007ooOol00goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol0
0`00Oomoo`0VOol>?Nl?Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol06Goo3Sg_:Goo
00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl?Ool02000Oomoo`00Ool007oo0004Ool00`00
Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`ioo`@000=oo`03001o
ogoo00=oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo
00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomo
o`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hm
kbQoo`8000=oo`005Woo00<007ooOol09Woo3Sg_6Woo0`006Woo3Sg_:Goo00<007ooOol00Goo000F
Ool00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001o
ogoo02Ioo`hmkcMoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_=goo3Sg_:Goo
00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlgOol>?NlYOol00`00Oomoo`01Ool001Ioo`03
001oogoo02Ioo`hmkcMoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_4Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol047oo3Sg_:7oo0P000goo000FOol00`00Oomoo`0V
Ool>?NlAOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P0017oo00<007ooOol03goo
3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlAOol01`00Oomoogoo001oo`0000Ao
o`03001oogoo009oo`05001oogooOol0000AOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo
02Ioo`hmka1oo`8000=oo`03001oo`0000Qoo`8000=oo`80011oo`hmkbUoo`03001oogoo005oo`00
5Woo00<007ooOol09Woo3Sg_4Goo00L007ooOomoo`00Ool00007Ool00`00Ool00003Ool00`00Oomo
o`0?Ool>?NlYOol00`00Oomoo`01Ool000Yoo`D0009oo`03001oogoo009oo`03001oogoo02Ioo`hm
ka5oo`07001oogooOol007oo00001goo00<007oo00000goo00<007ooOol03goo3Sg_:Goo00<007oo
Ool00Goo000<Ool01`00Oomoogoo001oo`0000=oo`03001oogoo02Ioo`hmka9oo`05001oogooOol0
0009Ool20002Ool00`00Oomoo`0@Ool>?NlYOol00`00Oomoo`01Ool000aoo`07001oogooOol007oo
00000goo0P009goo3Sg_=goo3Sg_:7oo0P000goo000<Ool01`00Oomoogoo001oo`0000=oo`03001o
ogoo02Iooe<mkbUoo`03001oogoo005oo`0037oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0V
OomC?NlYOol00`00Oomoo`01Ool000]oo`8000Aoo`03001oogoo009oo`03001oogoo02Iooe<mkbUo
o`03001oogoo005oo`005Woo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000FOol00`00Oomo
o`0VOomC?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Iooe<mkbUoo`03001oogoo005oo`00
5Woo00<007ooOol09WooDcg_:7oo0P000goo000FOol00`00Oomoo`0VOomC?NlYOol00`00Oomoo`01
Ool001Ioo`03001oogoo02Iooe<mkbUoo`03001oogoo005oo`005Woo00<007ooOol09WooDcg_:Goo
00<007ooOol00Goo000FOol00`00Oomoo`0VOomC?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo
02Iooe<mkbUoo`03001oogoo005oo`005Woo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000F
Ool00`00Oomoo`0VOomC?NlXOol20003Ool001Ioo`03001oogoo0:9oo`03001oogoo005oo`005Woo
00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03
001oogoo0:9oo`03001oogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00
Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:5oo`8000=oo`005Woo00<007ooOol0XWoo
00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:9oo`03
001oogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomoo`0HOol00`00
Oomoo`0IOol00`00Oomoo`0HOol00`00Oomoo`0IOol00`00Oomoo`0HOol00`00Oomoo`0IOol00`00
Oomoo`01Ool001IoojH000=oo`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol0
0;moo`00_goo0000\
\>"],
  ImageRangeCache->{{{0, 190}, {286, 0}} -> {-7.60082, -8.01978, 0.0725381, 
  0.0725381}}]
}, Open  ]],

Cell[TextData["Crankshaft"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The local coordinate system of the crankshaft originates at its rotational \
center."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Two points are used on the crankshaft.\nP1 is a point at the local origin \
that is the rotational axis of the crankshaft.\nP2 is a point on the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis that is the attachment point of the connecting rod."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the crankshaft."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(-6)] -0.0125 0 1 0 Msboxa
[(-4)] -0.0125 .16667 1 0 Msboxa
[(-2)] -0.0125 .33333 1 0 Msboxa
[(0)] -0.0125 .5 1 0 Msboxa
[(2)] -0.0125 .66667 1 0 Msboxa
[(4)] -0.0125 .83333 1 0 Msboxa
[(6)] -0.0125 1 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-6)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .16667 m
.00625 .16667 L
s
P
[(-4)] -0.0125 .16667 1 0 Mshowa
p
.002 w
0 .33333 m
.00625 .33333 L
s
P
[(-2)] -0.0125 .33333 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(0)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .66667 m
.00625 .66667 L
s
P
[(2)] -0.0125 .66667 1 0 Mshowa
p
.002 w
0 .83333 m
.00625 .83333 L
s
P
[(4)] -0.0125 .83333 1 0 Mshowa
p
.002 w
0 1 m
.00625 1 L
s
P
[(6)] -0.0125 1 1 0 Mshowa
p
.001 w
0 .03333 m
.00375 .03333 L
s
P
p
.001 w
0 .06667 m
.00375 .06667 L
s
P
p
.001 w
0 .1 m
.00375 .1 L
s
P
p
.001 w
0 .13333 m
.00375 .13333 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .23333 m
.00375 .23333 L
s
P
p
.001 w
0 .26667 m
.00375 .26667 L
s
P
p
.001 w
0 .3 m
.00375 .3 L
s
P
p
.001 w
0 .36667 m
.00375 .36667 L
s
P
p
.001 w
0 .4 m
.00375 .4 L
s
P
p
.001 w
0 .43333 m
.00375 .43333 L
s
P
p
.001 w
0 .46667 m
.00375 .46667 L
s
P
p
.001 w
0 .53333 m
.00375 .53333 L
s
P
p
.001 w
0 .56667 m
.00375 .56667 L
s
P
p
.001 w
0 .6 m
.00375 .6 L
s
P
p
.001 w
0 .63333 m
.00375 .63333 L
s
P
p
.001 w
0 .7 m
.00375 .7 L
s
P
p
.001 w
0 .73333 m
.00375 .73333 L
s
P
p
.001 w
0 .76667 m
.00375 .76667 L
s
P
p
.001 w
0 .8 m
.00375 .8 L
s
P
p
.001 w
0 .86667 m
.00375 .86667 L
s
P
p
.001 w
0 .9 m
.00375 .9 L
s
P
p
.001 w
0 .93333 m
.00375 .93333 L
s
P
p
.001 w
0 .96667 m
.00375 .96667 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 .99375 m
0 1 L
s
P
p
.002 w
.16667 .99375 m
.16667 1 L
s
P
p
.002 w
.33333 .99375 m
.33333 1 L
s
P
p
.002 w
.5 .99375 m
.5 1 L
s
P
p
.002 w
.66667 .99375 m
.66667 1 L
s
P
p
.002 w
.83333 .99375 m
.83333 1 L
s
P
p
.001 w
.03333 .99625 m
.03333 1 L
s
P
p
.001 w
.06667 .99625 m
.06667 1 L
s
P
p
.001 w
.1 .99625 m
.1 1 L
s
P
p
.001 w
.13333 .99625 m
.13333 1 L
s
P
p
.001 w
.2 .99625 m
.2 1 L
s
P
p
.001 w
.23333 .99625 m
.23333 1 L
s
P
p
.001 w
.26667 .99625 m
.26667 1 L
s
P
p
.001 w
.3 .99625 m
.3 1 L
s
P
p
.001 w
.36667 .99625 m
.36667 1 L
s
P
p
.001 w
.4 .99625 m
.4 1 L
s
P
p
.001 w
.43333 .99625 m
.43333 1 L
s
P
p
.001 w
.46667 .99625 m
.46667 1 L
s
P
p
.001 w
.53333 .99625 m
.53333 1 L
s
P
p
.001 w
.56667 .99625 m
.56667 1 L
s
P
p
.001 w
.6 .99625 m
.6 1 L
s
P
p
.001 w
.63333 .99625 m
.63333 1 L
s
P
p
.001 w
.7 .99625 m
.7 1 L
s
P
p
.001 w
.73333 .99625 m
.73333 1 L
s
P
p
.001 w
.76667 .99625 m
.76667 1 L
s
P
p
.001 w
.8 .99625 m
.8 1 L
s
P
p
.001 w
.86667 .99625 m
.86667 1 L
s
P
p
.001 w
.9 .99625 m
.9 1 L
s
P
p
.001 w
.93333 .99625 m
.93333 1 L
s
P
p
.001 w
.96667 .99625 m
.96667 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .16667 m
1 .16667 L
s
P
p
.002 w
.99375 .33333 m
1 .33333 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .66667 m
1 .66667 L
s
P
p
.002 w
.99375 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .03333 m
1 .03333 L
s
P
p
.001 w
.99625 .06667 m
1 .06667 L
s
P
p
.001 w
.99625 .1 m
1 .1 L
s
P
p
.001 w
.99625 .13333 m
1 .13333 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .23333 m
1 .23333 L
s
P
p
.001 w
.99625 .26667 m
1 .26667 L
s
P
p
.001 w
.99625 .3 m
1 .3 L
s
P
p
.001 w
.99625 .36667 m
1 .36667 L
s
P
p
.001 w
.99625 .4 m
1 .4 L
s
P
p
.001 w
.99625 .43333 m
1 .43333 L
s
P
p
.001 w
.99625 .46667 m
1 .46667 L
s
P
p
.001 w
.99625 .53333 m
1 .53333 L
s
P
p
.001 w
.99625 .56667 m
1 .56667 L
s
P
p
.001 w
.99625 .6 m
1 .6 L
s
P
p
.001 w
.99625 .63333 m
1 .63333 L
s
P
p
.001 w
.99625 .7 m
1 .7 L
s
P
p
.001 w
.99625 .73333 m
1 .73333 L
s
P
p
.001 w
.99625 .76667 m
1 .76667 L
s
P
p
.001 w
.99625 .8 m
1 .8 L
s
P
p
.001 w
.99625 .86667 m
1 .86667 L
s
P
p
.001 w
.99625 .9 m
1 .9 L
s
P
p
.001 w
.99625 .93333 m
1 .93333 L
s
P
p
.001 w
.99625 .96667 m
1 .96667 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
p
1 .6 .6 r
.004 w
.5 .5 m
.5 .5 .3125 90 270 arc
F
.5 .5 m
.5 .5 .3125 -20.0535 20.0535 arc
F
p
.5 .39167 m
.79583 .39167 L
.79583 .60833 L
.5 .60833 L
F
P
P
p
1 .4 .4 r
.004 w
.5 .5 m
.5 .5 .05833 0 365.73 arc
F
.75 .5 m
.75 .5 .04167 0 365.73 arc
F
P
p
.025 w
.5 .5 Mdot
p
.75 .5 Mdot
P
P
P
p
[({0,0})] .5 .5 0 1.7 Mshowa
[(P1)] .5 .5 0 -1.7 Mshowa
[({3,0})] .75 .5 0 1.7 Mshowa
[(P2)] .75 .5 0 -1.7 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{182, 182},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002f0000]Q000`40O003h00O]Woo002fOol00;Io
o`00]Woo000/Ool3000GOol3000EOol00`00Oomoo`0FOol3000IOol3000FOol20008Ool002eoo`03
001oogoo01Ioo`03001oogoo01Aoo`03001oo`0001Moo`03001oogoo01Yoo`03001oogoo01Eoo`03
001oo`0000Moo`009Woo0`000Woo10004Woo0`000goo00<007ooOol04goo00<007oo000067oo00<0
07ooOol05goo10005Woo00<007oo00001goo000[Ool00`00Ool0000IOol00`00Oomoo`0COol00`00
Ool0000HOol00`00Oomoo`0GOol00`00Ool0000GOol20008Ool002aoo`8001Qoo`03001oo`0001Ao
o`03001oo`0001Moo`03001oo`0001Uoo`8001Moo`03001oogoo00Moo`00;Goo00<007ooOol05goo
00<007ooOol057oo00<007ooOol05goo00<007ooOol06Goo00<007ooOol05Woo0P001goo002fOol0
0;Ioo`00]Woo002fOol00;Ioo`00]Woo000:Ool2002ZOol000Yoo`03001oo`000:Uoo`001Goo0`00
0Woo00<007oo00000gooWP0027oo000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool000Yoo`03001oogoo00=o
o`03001oogoo09Yoo`03001oogoo00Ioo`002goo0P000goo00<007ooOol0VWoo00<007ooOol01Woo
000@Ool00`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001oogoo09Yoo`03001oogoo00Ioo`00
47oo0P00Vgoo00<007ooOol01Woo000@Ool00`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001o
ogoo09Yoo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000@Ool00`00Oomo
o`2JOol00`00Oomoo`06Ool0011oo`8009]oo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<0
07ooOol01Woo000@Ool00`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001oogoo09Yoo`03001o
ogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000@Ool2002KOol00`00Oomoo`06Ool0
011oo`03001oogoo09Yoo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000@
Ool00`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001oogoo09Yoo`03001oogoo00Ioo`0047oo
0P00Vgoo00<007ooOol01Woo000@Ool00`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001oogoo
09Yoo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000;Ool30002Ool00`00
Oomoo`2JOol00`00Oomoo`06Ool000aoo`05001oogooOol0002LOol00`00Oomoo`06Ool000Eoo`<0
009oo`@0009oo`8009Yoo`8000Qoo`002Woo00<007oo00000goo00<007ooOol0VWoo00<007ooOol0
1Woo000;Ool20003Ool00`00Oomoo`2JOol00`00Oomoo`06Ool000aoo`05001oogooOol0002LOol0
0`00Oomoo`06Ool0011oo`03001oogoo049oo`YnLdioo`03001oogoo00Ioo`0047oo0P00?Woo3gic
CWoo00<007ooOol01Woo000@Ool00`00Oomoo`0kOolAOW=>Ool00`00Oomoo`06Ool0011oo`03001o
ogoo03Uooa=nLdioo`03001oogoo00Ioo`0047oo00<007ooOol0=goo5GicCWoo00<007ooOol01Woo
000@Ool00`00Oomoo`0eOolGOW=>Ool00`00Oomoo`06Ool0011oo`8003AooaUnLdioo`03001oogoo
00Ioo`0047oo00<007ooOol0<7oo77icCWoo00<007ooOol01Woo000@Ool00`00Oomoo`0`OolLOW=>
Ool00`00Oomoo`06Ool0011oo`03001oogoo02mooaenLdioo`03001oogoo00Ioo`0047oo00<007oo
Ool0;Goo7gicCWoo00<007ooOol01Woo000@Ool2000]OolPOW=>Ool00`00Oomoo`06Ool0011oo`03
001oogoo02]oob5nLdioo`03001oogoo00Ioo`0047oo00<007ooOol0:Goo8gicCWoo00<007ooOol0
1Woo000@Ool00`00Oomoo`0XOolTOW=>Ool00`00Oomoo`06Ool0011oo`03001oogoo02MoobEnLdio
o`03001oogoo00Ioo`0047oo00<007ooOol09goo9GicCWoo00<007ooOol01Woo000@Ool2000WOolV
OW=>Ool00`00Oomoo`06Ool0011oo`03001oogoo02EoobMnLdioo`03001oogoo00Ioo`0047oo00<0
07ooOol097oo:7icCWoo00<007ooOol01Woo000:Ool30003Ool00`00Oomoo`0TOolXOW=>Ool00`00
Oomoo`06Ool000Yoo`03001oogoo00=oo`03001oogoo02=oobUnLdioo`03001oogoo00Ioo`001Goo
0`000goo00<007ooOol00Woo0P0097oo:GicCGoo0P0027oo000;Ool00`00Oomoo`02Ool00`00Oomo
o`0ROolZOW=>Ool00`00Oomoo`06Ool000Yoo`03001oo`0000=oo`03001oogoo025oob]nLdioo`03
001oogoo00Ioo`002goo00<007ooOol00Woo00<007ooOol087oo;7icCWoo00<007ooOol01Woo000@
Ool00`00Oomoo`0POol/OW=>Ool00`00Oomoo`06Ool0011oo`80021oobenLdioo`03001oogoo00Io
o`0047oo00<007ooOol07goo;GicCWoo00<007ooOol01Woo000@Ool00`00Oomoo`0NOol^OW=>Ool0
0`00Oomoo`06Ool0011oo`03001oogoo01ioobinLdioo`03001oogoo00Ioo`0047oo00<007ooOol0
7Woo;WicCWoo00<007ooOol01Woo000@Ool2000OOomMOW<OOol00`00Oomoo`06Ool0011oo`03001o
ogoo01iooeenLamoo`03001oogoo00Ioo`0047oo00<007ooOol07GooGWic7goo00<007ooOol01Woo
000@Ool00`00Oomoo`0MOolUOW<00`00OW=nL`06OW<00`00OW=nL`06OW<00`00OW=nL`0BOW<00`00
OW=nL`06OW<00`00OW=nL`06OW<00`00Oomoo`0LOol00`00Oomoo`06Ool0011oo`03001oogoo01ao
obEnL`03001nLgic009nL`03001nLgic009nL`03001nLgic009nL`03001nLgic009nL`03001nLgic
011nL`04001nLgicOW<20004OW<00`00OW=nL`02OW<00`00OW=nL`02OW<00`00Oomoo`0KOol00`00
Oomoo`06Ool0011oo`03001oogoo01aoobEnL`07001nLgicOW<007ic000017ic00H007icOW<007ic
0003OW<00`00OW=nL`0@OW<00`00OW=nL`03OW<00`00OW=nL`02OW<01P00OW=nL`00OW<000=nL`03
001oogoo01]oo`03001oogoo00Ioo`0047oo0P007Goo97ic0P000gic00<007ic00001gic00<007ic
00000gic0P0047ic0P0017ic00<007icOW<01Wic00<007ic00000gic0P0077oo00<007ooOol01Woo
000@Ool00`00Oomoo`0LOolUOW<01`00OW=nLgic001nL`0000MnL`03001nL`0000=nL`03001nLgic
011nL`03001nLgic00=nL`03001nLgic00EnL`03001nL`0000=nL`03001oogoo01]oo`03001oogoo
00Ioo`0047oo00<007ooOol077oo9Gic00L007icOW=nL`00OW<00007OH`00`00OW<00003OW<00`00
OW=nL`0@OW<01`00OW=nLgic001nL`0000MnL`03001nL`0000=nL`03001oogoo01]oo`03001oogoo
00Ioo`0047oo00<007ooOol06goo9gic00D007icOW=nL`0000UmS005001mS7icOW<0000DOW<01@00
OW=nLgic00002Gic00D007icOW=nL`0001ioo`03001oogoo00Ioo`0047oo00<007ooOol06goo:Wic
3Wf<7Wic1Gf<1Wic7Woo00<007ooOol01Woo000@Ool2000LOolYOW<@OH`KOW<8OH`6OW<MOol00`00
Oomoo`06Ool0011oo`03001oogoo01]oobQnLa5mS1YnL`YmS0EnLaeoo`03001oogoo00Ioo`0047oo
00<007ooOol06goo:7ic4Gf<6Gic37f<17ic7Goo00<007ooOol01Woo000;Ool00`00Oomoo`02Ool0
0`00Oomoo`0KOolXOW<BOH`HOW<<OH`4OW<MOol00`00Oomoo`06Ool000Yoo`03001oo`0000=oo`03
001oogoo01]oobQnLa9mS1QnL`amS0AnLaeoo`03001oogoo00Ioo`002Woo00<007oo00000goo0P00
77oo:7ic4Wf<5gic3Gf<17ic77oo0P0027oo000:Ool00`00Ool00003Ool00`00Oomoo`0KOolXOW<B
OH`HOW<=OH`3OW<MOol00`00Oomoo`06Ool000Yoo`03001oo`0000=oo`03001oogoo01]oobQnLa9m
S1QnL`emS0=nLaeoo`03001oogoo00Ioo`002goo00<007ooOol00Woo00<007ooOol06goo:7ic4Wf<
6Gic2gf<17ic7Goo00<007ooOol01Woo000@Ool00`00Oomoo`0KOolYOW<@OH`JOW<;OH`4OW<MOol0
0`00Oomoo`06Ool0011oo`8001aoobUnLa1mS1]nL`UmS0EnLaeoo`03001oogoo00Ioo`0047oo00<0
07ooOol06goo:Wic3Wf<7Gic1Gf<1gic7Woo00<007ooOol01Woo000@Ool00`00Oomoo`0KOol/OW<;
OH`ZOW<NOol00`00Oomoo`06Ool0011oo`03001oogoo01aoob]nL`<0009mS0D001enL`<000=nL`<0
00EnLaioo`03001oogoo00Ioo`0047oo00<007ooOol077oo;7ic00<007icOH`00gf<00<007icOW<0
7Wic00<007icOW<00Wic00<007icOW<01Gic7Woo00<007ooOol01Woo000@Ool2000MOol/OW<30003
OW<00`00OW=nL`0NOW<30003OW<00`00OW=nL`04OW<NOol00`00Oomoo`06Ool0011oo`03001oogoo
01aoobanL`04001nLgic0002OW<00`00OW=nL`0NOW<01000OW=nL`000Wic00<007icOW<017ic7Woo
00<007ooOol01Woo000@Ool00`00Oomoo`0LOol/OW<01000OW=nL`000Wic00<007icOW<07Wic00P0
07icOW<007ic001nL`001Gic7Woo00<007ooOol01Woo000@Ool00`00Oomoo`0MOolZOW<40002OW<2
000OOW<40003OW<00`00OW=nL`03OW<OOol00`00Oomoo`06Ool0011oo`03001oogoo01eooeinLamo
o`03001oogoo00Ioo`0047oo00<007ooOol07WooGGic7goo00<007ooOol01Woo000@Ool2000OOomM
OW<OOol00`00Oomoo`06Ool0011oo`03001oogoo01iooeanLb1oo`03001oogoo00Ioo`0047oo00<0
07ooOol07Woo;WicCWoo00<007ooOol01Woo000@Ool00`00Oomoo`0NOol^OW=>Ool00`00Oomoo`06
Ool0011oo`03001oogoo01moobenLdioo`03001oogoo00Ioo`0047oo0P0087oo;GicCWoo00<007oo
Ool01Woo000@Ool00`00Oomoo`0POol/OW=>Ool00`00Oomoo`06Ool0011oo`03001oogoo021ooban
Ldioo`03001oogoo00Ioo`002Woo0`000goo00<007ooOol08Goo:gicCWoo00<007ooOol01Woo000:
Ool00`00Oomoo`03Ool00`00Oomoo`0ROolZOW=>Ool00`00Oomoo`06Ool000]oo`03001oogoo009o
o`8002AoobUnLdeoo`8000Qoo`002goo00<007ooOol00Woo00<007ooOol08goo:GicCWoo00<007oo
Ool01Woo000:Ool00`00Ool00003Ool00`00Oomoo`0TOolXOW=>Ool00`00Oomoo`06Ool000]oo`03
001oogoo009oo`03001oogoo02AoobQnLdioo`03001oogoo00Ioo`0047oo00<007ooOol09Goo9gic
CWoo00<007ooOol01Woo000@Ool2000WOolVOW=>Ool00`00Oomoo`06Ool0011oo`03001oogoo02Mo
obEnLdioo`03001oogoo00Ioo`0047oo00<007ooOol09goo9GicCWoo00<007ooOol01Woo000@Ool0
0`00Oomoo`0XOolTOW=>Ool00`00Oomoo`06Ool0011oo`03001oogoo02Uoob=nLdioo`03001oogoo
00Ioo`0047oo00<007ooOol0:goo8GicCWoo00<007ooOol01Woo000@Ool2000]OolPOW=>Ool00`00
Oomoo`06Ool0011oo`03001oogoo02eooamnLdioo`03001oogoo00Ioo`0047oo00<007ooOol0;goo
7GicCWoo00<007ooOol01Woo000@Ool00`00Oomoo`0`OolLOW=>Ool00`00Oomoo`06Ool0011oo`03
001oogoo031ooaanLdioo`03001oogoo00Ioo`0047oo0P00=7oo6GicCWoo00<007ooOol01Woo000@
Ool00`00Oomoo`0eOolGOW=>Ool00`00Oomoo`06Ool0011oo`03001oogoo03MooaEnLdioo`03001o
ogoo00Ioo`0047oo00<007ooOol0>Goo4gicCWoo00<007ooOol01Woo000@Ool00`00Oomoo`0kOolA
OW=>Ool00`00Oomoo`06Ool0011oo`8003ioo`mnLdioo`03001oogoo00Ioo`0047oo00<007ooOol0
@7oo37icCWoo00<007ooOol01Woo000@Ool00`00Oomoo`15Ool7OW=>Ool00`00Oomoo`06Ool000]o
o`<0009oo`03001oogoo09Yoo`03001oogoo00Ioo`0037oo00D007ooOomoo`0009aoo`03001oogoo
00Ioo`002Woo10000Woo0P00VWoo0P0027oo000:Ool00`00Ool00003Ool00`00Oomoo`2JOol00`00
Oomoo`06Ool000]oo`8000=oo`03001oogoo09Yoo`03001oogoo00Ioo`0037oo00D007ooOomoo`00
09aoo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000@Ool00`00Oomoo`2J
Ool00`00Oomoo`06Ool0011oo`8009]oo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007oo
Ool01Woo000@Ool00`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001oogoo09Yoo`03001oogoo
00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000@Ool2002KOol00`00Oomoo`06Ool0011o
o`03001oogoo09Yoo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000@Ool0
0`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001oogoo09Yoo`03001oogoo00Ioo`0047oo0P00
Vgoo00<007ooOol01Woo000@Ool00`00Oomoo`2JOol00`00Oomoo`06Ool0011oo`03001oogoo09Yo
o`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol01Woo000@Ool00`00Oomoo`2JOol0
0`00Oomoo`06Ool0011oo`8009]oo`03001oogoo00Ioo`0047oo00<007ooOol0VWoo00<007ooOol0
1Woo000@Ool00`00Oomoo`2JOol00`00Oomoo`06Ool000Yoo`8000Aoo`03001oogoo09Yoo`03001o
ogoo00Ioo`002Woo00<007oo00000goo00<007ooOol0VWoo00<007ooOol01Woo000:Ool00`00Ool0
0003OonN0008Ool000Yoo`800:Yoo`002Woo00<007ooOol0ZGoo000;Ool2002YOol00;Ioo`00]Woo
002fOol00001\
\>"],
  ImageRangeCache->{{{0, 181}, {181, 0}} -> {-7.2789, -7.37587, 0.0764339, 
  0.0764339}}]
}, Open  ]],

Cell["Piston", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The local coordinate system of the piston originates four units below the \
attachment point of the connecting rod. Thus, when the mechanism is in its \
initial configuration, the local origin of the piston is coincident with the \
global origin."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two points are used on the piston.\nP1 is the attachment point of the \
connecting rod.\nP2 is used with P1 to define the vertical translation line \
of the piston."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the piston."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(2)] -0.0125 .16667 1 0 Msboxa
[(4)] -0.0125 .33333 1 0 Msboxa
[(6)] -0.0125 .5 1 0 Msboxa
[(8)] -0.0125 .66667 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .751 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .16667 m
.00625 .16667 L
s
P
[(2)] -0.0125 .16667 1 0 Mshowa
p
.002 w
0 .33333 m
.00625 .33333 L
s
P
[(4)] -0.0125 .33333 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(6)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .66667 m
.00625 .66667 L
s
P
[(8)] -0.0125 .66667 1 0 Mshowa
p
.001 w
0 .03333 m
.00375 .03333 L
s
P
p
.001 w
0 .06667 m
.00375 .06667 L
s
P
p
.001 w
0 .1 m
.00375 .1 L
s
P
p
.001 w
0 .13333 m
.00375 .13333 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .23333 m
.00375 .23333 L
s
P
p
.001 w
0 .26667 m
.00375 .26667 L
s
P
p
.001 w
0 .3 m
.00375 .3 L
s
P
p
.001 w
0 .36667 m
.00375 .36667 L
s
P
p
.001 w
0 .4 m
.00375 .4 L
s
P
p
.001 w
0 .43333 m
.00375 .43333 L
s
P
p
.001 w
0 .46667 m
.00375 .46667 L
s
P
p
.001 w
0 .53333 m
.00375 .53333 L
s
P
p
.001 w
0 .56667 m
.00375 .56667 L
s
P
p
.001 w
0 .6 m
.00375 .6 L
s
P
p
.001 w
0 .63333 m
.00375 .63333 L
s
P
p
.001 w
0 .7 m
.00375 .7 L
s
P
p
.001 w
0 .73333 m
.00375 .73333 L
s
P
p
.002 w
0 0 m
0 .75 L
s
P
P
p
p
.002 w
0 .74375 m
0 .75 L
s
P
p
.002 w
.16667 .74375 m
.16667 .75 L
s
P
p
.002 w
.33333 .74375 m
.33333 .75 L
s
P
p
.002 w
.5 .74375 m
.5 .75 L
s
P
p
.002 w
.66667 .74375 m
.66667 .75 L
s
P
p
.002 w
.83333 .74375 m
.83333 .75 L
s
P
p
.001 w
.03333 .74625 m
.03333 .75 L
s
P
p
.001 w
.06667 .74625 m
.06667 .75 L
s
P
p
.001 w
.1 .74625 m
.1 .75 L
s
P
p
.001 w
.13333 .74625 m
.13333 .75 L
s
P
p
.001 w
.2 .74625 m
.2 .75 L
s
P
p
.001 w
.23333 .74625 m
.23333 .75 L
s
P
p
.001 w
.26667 .74625 m
.26667 .75 L
s
P
p
.001 w
.3 .74625 m
.3 .75 L
s
P
p
.001 w
.36667 .74625 m
.36667 .75 L
s
P
p
.001 w
.4 .74625 m
.4 .75 L
s
P
p
.001 w
.43333 .74625 m
.43333 .75 L
s
P
p
.001 w
.46667 .74625 m
.46667 .75 L
s
P
p
.001 w
.53333 .74625 m
.53333 .75 L
s
P
p
.001 w
.56667 .74625 m
.56667 .75 L
s
P
p
.001 w
.6 .74625 m
.6 .75 L
s
P
p
.001 w
.63333 .74625 m
.63333 .75 L
s
P
p
.001 w
.7 .74625 m
.7 .75 L
s
P
p
.001 w
.73333 .74625 m
.73333 .75 L
s
P
p
.001 w
.76667 .74625 m
.76667 .75 L
s
P
p
.001 w
.8 .74625 m
.8 .75 L
s
P
p
.001 w
.86667 .74625 m
.86667 .75 L
s
P
p
.001 w
.9 .74625 m
.9 .75 L
s
P
p
.001 w
.93333 .74625 m
.93333 .75 L
s
P
p
.001 w
.96667 .74625 m
.96667 .75 L
s
P
p
.002 w
0 .75 m
1 .75 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .16667 m
1 .16667 L
s
P
p
.002 w
.99375 .33333 m
1 .33333 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .66667 m
1 .66667 L
s
P
p
.001 w
.99625 .03333 m
1 .03333 L
s
P
p
.001 w
.99625 .06667 m
1 .06667 L
s
P
p
.001 w
.99625 .1 m
1 .1 L
s
P
p
.001 w
.99625 .13333 m
1 .13333 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .23333 m
1 .23333 L
s
P
p
.001 w
.99625 .26667 m
1 .26667 L
s
P
p
.001 w
.99625 .3 m
1 .3 L
s
P
p
.001 w
.99625 .36667 m
1 .36667 L
s
P
p
.001 w
.99625 .4 m
1 .4 L
s
P
p
.001 w
.99625 .43333 m
1 .43333 L
s
P
p
.001 w
.99625 .46667 m
1 .46667 L
s
P
p
.001 w
.99625 .53333 m
1 .53333 L
s
P
p
.001 w
.99625 .56667 m
1 .56667 L
s
P
p
.001 w
.99625 .6 m
1 .6 L
s
P
p
.001 w
.99625 .63333 m
1 .63333 L
s
P
p
.001 w
.99625 .7 m
1 .7 L
s
P
p
.001 w
.99625 .73333 m
1 .73333 L
s
P
p
.002 w
1 0 m
1 .75 L
s
P
P
p
P
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
p
p
p
.7 .7 1 r
.35 .20833 m
.65 .20833 L
.65 .5 L
.35 .5 L
F
P
p
.6 .6 1 r
.004 w
.5 .33333 m
.5 .33333 .03333 0 365.73 arc
F
P
p
p
.01 w
.5 .33333 m
.5 .5 L
s
P
p
.025 w
.5 .33333 Mdot
.5 .5 Mdot
P
P
P
p
[({0,4})] .5 .33333 0 1.7 Mshowa
[(P1)] .5 .33333 1.7 -1 Mshowa
[({0,6})] .5 .5 0 -1.7 Mshowa
[(P2)] .5 .5 1.7 1 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{182, 136},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002f0000R1000`40O003h00O]Woo002fOol00;Io
o`00]Woo000ZOol3000FOol3000FOol00`00Oomoo`0FOol3000HOol3000FOol2000;Ool002]oo`03
001oogoo01Eoo`03001oogoo01Eoo`03001oo`0001Moo`03001oogoo01Uoo`03001oogoo01Eoo`03
001oo`0000Yoo`0097oo0`000Woo10004Goo0`000goo00<007ooOol057oo00<007oo000067oo00<0
07ooOol05Woo10005Woo00<007oo00002Woo000YOol00`00Ool0000HOol00`00Oomoo`0DOol00`00
Ool0000HOol00`00Oomoo`0FOol00`00Ool0000GOol2000;Ool002Yoo`8001Moo`03001oo`0001Eo
o`03001oo`0001Moo`03001oo`0001Qoo`8001Moo`03001oogoo00Yoo`00:goo00<007ooOol05Woo
00<007ooOol05Goo00<007ooOol05goo00<007ooOol067oo00<007ooOol05Woo0P002Woo002fOol0
0;Ioo`00]Woo002fOol00;Ioo`00]Woo0009Ool00`00Oomoo`2ZOol000Qoo`03001oo`000:]oo`00
27oo00<007oo00000gooW@002goo0008Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`09Ool000Qoo`03001o
o`0000=oo`03001oogoo09Uoo`03001oogoo00Uoo`002Goo00<007ooOol00Woo00<007ooOol0VGoo
00<007ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`03001oogoo09Uoo`03
001oogoo00Uoo`003Woo0P00VWoo00<007ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09
Ool000ioo`03001oogoo09Uoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007ooOol02Goo
000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`8009Yoo`03001oogoo00Uoo`003Woo00<0
07ooOol0VGoo00<007ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`03001o
ogoo09Uoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007ooOol02Goo000>Ool2002JOol0
0`00Oomoo`09Ool000ioo`03001oogoo09Uoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<0
07ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`03001oogoo09Uoo`03001o
ogoo00Uoo`003Woo0P00VWoo00<007ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool0
00ioo`03001oogoo09Uoo`03001oogoo00Uoo`0027oo0`000goo00<007ooOol0VGoo00<007ooOol0
2Goo0008Ool00`00Oomoo`03Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000Uoo`03001oogoo009o
o`8009Uoo`8000]oo`002Goo00<007ooOol00Woo00<007ooOol0VGoo00<007ooOol02Goo0008Ool0
0`00Ool00003Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000Uoo`03001oogoo009oo`03001oogoo
09Uoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007ooOol02Goo000>Ool00`00Oomoo`2I
Ool00`00Oomoo`09Ool000ioo`8009Yoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007oo
Ool02Goo000>Ool00`00Oomoo`0dOol_F]lfOol00`00Oomoo`09Ool000ioo`03001oogoo03AoobmJ
gcIoo`03001oogoo00Uoo`003Woo00<007ooOol0=7oo;e[O=Woo00<007ooOol02Goo000>Ool2000e
Ool_F]lfOol00`00Oomoo`09Ool000ioo`03001oogoo03AoobmJgcIoo`03001oogoo00Uoo`003Woo
00<007ooOol0=7oo3U[O00<005[OF]l01U[O00<005[OF]l01U[O00<005[OF]l035[O=Woo00<007oo
Ool02Goo000>Ool00`00Oomoo`0dOol=F]l00`00F]mJg`02F]l00`00F]mJg`02F]l00`00F]mJg`02
F]l30002F]l00`00F]mJg`0;F]lfOol00`00Oomoo`09Ool000ioo`03001oogoo03Aoo`eJg`07001J
ge[OF]l005[O000015[O00<005[OF]l00U[O00D005[OF]mJg`0000eJgcIoo`03001oogoo00Uoo`00
3Woo0P00=Goo35[O0P000e[O00<005[O00001e[O10000U[O0P0035[O=Woo00<007ooOol02Goo000>
Ool00`00Oomoo`0dOol=F]l01`00F]mJge[O001Jg`0000MJg`03001Jg`0000=Jg`03001Jge[O00]J
gcIoo`03001oogoo00Uoo`003Woo00<007ooOol0=7oo3E[O00L005[OF]mJg`00F]l00008F]l20003
F]l00`00F]mJg`0;F]lfOol00`00Oomoo`09Ool000ioo`03001oogoo03Aoo`iJg`05001Jge[OF]l0
000:F]l01000F]mJg`003U[O=Woo00<007ooOol02Goo000>Ool00`00Oomoo`0dOol_F]lfOol00`00
Oomoo`09Ool000ioo`8003EoobmJgcIoo`03001oogoo00Uoo`003Woo00<007ooOol0=7oo5U[O14io
5E[O=Woo00<007ooOol02Goo000>Ool00`00Oomoo`0dOolDF]l7CWlDF]lfOol00`00Oomoo`09Ool0
00Uoo`<0009oo`03001oogoo03Aooa=Jg`U>Oa=JgcIoo`03001oogoo00Uoo`002Woo00D007ooOomo
o`0003Iooa=Jg`U>Oa=JgcIoo`03001oogoo00Uoo`0027oo10000Woo0P00=Goo4U[O1Dio00<004io
CWl00Tio4e[O=Goo0P002goo0008Ool00`00Ool00003Ool00`00Oomoo`0dOolBF]l5CWl00`00CWm>
O`02CWlCF]lfOol00`00Oomoo`09Ool000Uoo`8000=oo`03001oogoo03Aooa9Jg`E>O`03001>Odio
009>Oa=JgcIoo`03001oogoo00Uoo`002Woo00D007ooOomoo`0003Iooa=Jg`A>O`03001>Odio009>
Oa=JgcIoo`03001oogoo00Uoo`003Woo00<007ooOol0=7oo2U[O0`000U[O1@000dio00@004ioCWm>
OaAJgcIoo`03001oogoo00Uoo`003Woo00<007ooOol0=7oo2e[O00<005[OF]l00e[O00@005[OF]mJ
g`9>O`03001>Oe[O01EJgcIoo`03001oogoo00Uoo`003Woo0P00=Goo2e[O0`000e[O00<005[OF]l0
0e[O00<005[OF]l05E[O=Woo00<007ooOol02Goo000>Ool00`00Oomoo`0dOol;F]l01000F]mJg`00
0U[O00<005[OF]l00e[O00<005[OF]l05E[O=Woo00<007ooOol02Goo000>Ool00`00Oomoo`0dOol;
F]l01000F]mJg`000U[O00<005[OF]l00e[O00<005[OF]l05E[O=Woo00<007ooOol02Goo000>Ool0
0`00Oomoo`0dOol:F]l40002F]l20005F]l00`00F]mJg`0EF]lfOol00`00Oomoo`09Ool000ioo`03
001oogoo03AooaMJg`03001Jge[O01EJgcIoo`03001oogoo00Uoo`003Woo0P00=Goo5e[O00<005[O
F]l05E[O=Woo00<007ooOol02Goo000>Ool00`00Oomoo`0dOolGF]l00`00F]mJg`0EF]lfOol00`00
Oomoo`09Ool000ioo`03001oogoo03AooaMJg`03001Jge[O01EJgcIoo`03001oogoo00Uoo`003Woo
00<007ooOol0=7oo5e[O00<005[OF]l05E[O=Woo00<007ooOol02Goo000>Ool00`00Oomoo`0dOolG
F]l00`00F]mJg`0EF]lfOol00`00Oomoo`09Ool000ioo`8003EooaMJg`03001Jge[O01EJgcIoo`03
001oogoo00Uoo`003Woo00<007ooOol0=7oo5e[O00<005[OF]l05E[O=Woo00<007ooOol02Goo000>
Ool00`00Oomoo`0dOol:F]l30003F]l30004F]l00`00F]mJg`0EF]lfOol00`00Oomoo`09Ool000io
o`03001oogoo03Aoo`]Jg`03001Jge[O009Jg`03001Jge[O00AJg`03001Jge[O01EJgcIoo`03001o
ogoo00Uoo`003Woo00<007ooOol0=7oo2e[O0`000e[O00<005[OF]l00e[O00<005[OF]l05E[O=Woo
00<007ooOol02Goo000>Ool2000eOol;F]l01000F]mJg`000U[O00<005[OF]l00e[O00<005[OF]l0
5E[O=Woo00<007ooOol02Goo000>Ool00`00Oomoo`0dOol;F]l02000F]mJg`00F]l005[O0004F]l0
0`00F]mJg`0EF]lfOol00`00Oomoo`09Ool000ioo`03001oogoo03Aoo`YJg`@000=Jg`03001Jge[O
00=Jg`03001Jge[O01EJgcIoo`03001oogoo00Uoo`0027oo0P0017oo00<007ooOol0=7oo5e[O00<0
05[OF]l05E[O=Woo00<007ooOol02Goo0008Ool00`00Ool00003Ool00`00Oomoo`0dOolGF]l00`00
F]mJg`0EF]lfOol00`00Oomoo`09Ool000Qoo`03001oo`0000=oo`8003EooaMJg`03001Jge[O01EJ
gcEoo`8000]oo`0027oo0P0017oo00<007ooOol0VGoo00<007ooOol02Goo0008Ool00`00Oomoo`03
Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000Uoo`8000=oo`03001oogoo09Uoo`03001oogoo00Uo
o`003Woo00<007ooOol0VGoo00<007ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool0
00ioo`8009Yoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007ooOol02Goo000>Ool00`00
Oomoo`12Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`12Ool00`00Oomoo`09Ool000io
o`03001oogoo045oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20004Ool00`00Oomo
o`11Ool00`00Oomoo`09Ool000ioo`03001oogoo045oo`07001oogooOol007oo000017oo00H007oo
Ool007oo0003Ool00`00Oomoo`11Ool00`00Oomoo`09Ool000ioo`80045oo`8000=oo`03001oo`00
00Moo`03001oo`0000=oo`80049oo`03001oogoo00Uoo`003Woo00<007ooOol0@Goo00L007ooOomo
o`00Ool00007Ool20004Ool00`00Oomoo`11Ool00`00Oomoo`09Ool000ioo`03001oogoo045oo`07
001oogooOol007oo00001goo00<007ooOol00goo00<007ooOol0@Goo00<007ooOol02Goo000>Ool0
0`00Oomoo`12Ool01@00Oomoogoo00002Goo0P000Woo00<007ooOol0@Woo00<007ooOol02Goo000>
Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`8009Yoo`03001oogoo00Uoo`003Woo00<007oo
Ool0VGoo00<007ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`03001oogoo
09Uoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007ooOol02Goo000>Ool2002JOol00`00
Oomoo`09Ool000ioo`03001oogoo09Uoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007oo
Ool02Goo0009Ool00`00Oomoo`02Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000Qoo`03001oo`00
00=oo`03001oogoo09Uoo`03001oogoo00Uoo`0027oo00<007oo00000goo0P00VGoo0P002goo0009
Ool00`00Oomoo`02Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000Qoo`03001oo`0000=oo`03001o
ogoo09Uoo`03001oogoo00Uoo`002Goo00<007ooOol00Woo00<007ooOol0VGoo00<007ooOol02Goo
000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`03001oogoo09Uoo`03001oogoo00Uoo`00
3Woo0P00VWoo00<007ooOol02Goo000>Ool00`00Oomoo`2IOol00`00Oomoo`09Ool000ioo`03001o
ogoo09Uoo`03001oogoo00Uoo`003Woo00<007ooOol0VGoo00<007ooOol02Goo000>Ool00`00Oomo
o`2IOol00`00Oomoo`09Ool000ioo`8009Yoo`03001oogoo00Uoo`003Woo00<007ooOol05goo00<0
07ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<007ooOol05goo00<0
07ooOol02Goo000>OonM000;Ool00001\
\>"],
  ImageRangeCache->{{{0, 181}, {135, 0}} -> {-7.14218, -1.38652, 0.0770264, 
  0.0770264}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2D Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now that the local point coordinates on each body are defined, building \
the model is simply a matter of tying the points together with the correct \
mechanical constraints. ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " provides a small library of mechanical constraint objects that translate \
desired physical conditions that are imposed on the model into mathematical \
equations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Constraint Objects"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four constraint objects are used to model the slider-crank mechanism, \
constraining a total of six degrees of freedom (three degrees of freedom for \
each moving body)."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolute2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be coincident with ",
  StyleBox["point2.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["RotationLock1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum, ang",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the angular coordinate of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians.\n\n",
  StyleBox["Translate2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel and coincident with ",
  StyleBox["axis2.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["RelativeDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " is a unique positive integer constraint number."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Some 2D constraint objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the last character in the name of any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint object is an integer that specifies the number of degrees of \
freedom that it constrains.\n\nThe first argument to each constraint object, \
",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", is the user-specified constraint number. This number is used to \
reference the constraint later in the modeling process, much like body \
numbers are used to reference specific bodies.\n\nThe ",
  StyleBox["point",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " arguments of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects are specified with ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects, used in much the same manner as the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These objects are discussed in detail in Section 2.2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Building the Model"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The ",
    FontFamily->"Times"],
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects used to model the physical relationships in the \
slider-crank mechanism are as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of the crankshaft to be coincident with the \
global origin. This constrains the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " displacement of the crankshaft axis. The one degree of freedom left for \
the crankshaft is its rotation about its axis. The syntax of the constraint \
can be interpreted as, \"Constrain a point at {0, 0} on the ground body to be \
coincident with point {0, 0} on the crankshaft\"."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the angular coordinate of the crankshaft. The \
crankshaft is now completely constrained. The syntax of this constraint can \
be interpreted as, \"Constrain the angular coordinate of the crankshaft to be \
equal to ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\"."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces a vertical line on the piston to be coincident with a \
vertical line on the ground body. This constrains two degrees of freedom, ",
  StyleBox["X",
    FontSlant->"Italic"],
  " displacement and rotation of the piston. The one degree of freedom left \
is the vertical translation of the piston relative to the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces an eccentric point on the crankshaft to lie five units \
distant from the origin of the piston. This single constraint takes the place \
of a connecting rod five units long. Since the crankshaft is already \
completely constrained, this completes the constraint of the piston."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects are finally assembled into a mechanism model with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetConstraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["constraints",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects and builds a mathematical system representing the \
mechanism model."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The fundamental model-building function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the entire slider-crank model built in one step."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(crankangle =. \), 
    \(SetConstraints[\n\t
      Revolute2[1, Point[ground, {0., 0.}], \n\t\t
        Point[crankshaft, {0., 0.}]], \n\t
      RotationLock1[2, crankshaft, crankangle], \n\t
      Translate2[3, Line[ground, {0, 4.}, {0, 9.}], 
        Line[piston, {0, 4.}, {0, 6.}]], \n\t
      RelativeDistance1[4, Point[crankshaft, {3., 0.}], 
        Point[piston, {0., 4.}], 5.]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["Null",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " upon success. All of the mechanism equations generated by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are stored internally in the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " private context."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Running the Model"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To solve the mechanism equations and return the coordinates of each of the \
bodies the model, the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is used."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a solution to the current mechanism model and returns the \
coordinates of each body in the system."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The fundamental model-solving function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This seeks a solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(crankangle = 0; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 0, X3 \[Rule] 0, Y3 \[Rule] 0, 
      Th3 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global coordinates of the origin of each body in the system. \
The symbols ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specify the location of the origin of body 2, the crankshaft, and ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (theta 2) specifies the rotation of the crankshaft. ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Xn, Yn, Thn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " triplet for each body in the system."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "A graphic of the model at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(-5)] -0.0125 .08333 1 0 Msboxa
[(-2.5)] -0.0125 .29167 1 0 Msboxa
[(0)] -0.0125 .5 1 0 Msboxa
[(2.5)] -0.0125 .70833 1 0 Msboxa
[(5)] -0.0125 .91667 1 0 Msboxa
[(7.5)] -0.0125 1.125 1 0 Msboxa
[(10)] -0.0125 1.33333 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(-5)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .29167 m
.00625 .29167 L
s
P
[(-2.5)] -0.0125 .29167 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(0)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .70833 m
.00625 .70833 L
s
P
[(2.5)] -0.0125 .70833 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(5)] -0.0125 .91667 1 0 Mshowa
p
.002 w
0 1.125 m
.00625 1.125 L
s
P
[(7.5)] -0.0125 1.125 1 0 Mshowa
p
.002 w
0 1.33333 m
.00625 1.33333 L
s
P
[(10)] -0.0125 1.33333 1 0 Mshowa
p
.001 w
0 .125 m
.00375 .125 L
s
P
p
.001 w
0 .16667 m
.00375 .16667 L
s
P
p
.001 w
0 .20833 m
.00375 .20833 L
s
P
p
.001 w
0 .25 m
.00375 .25 L
s
P
p
.001 w
0 .33333 m
.00375 .33333 L
s
P
p
.001 w
0 .375 m
.00375 .375 L
s
P
p
.001 w
0 .41667 m
.00375 .41667 L
s
P
p
.001 w
0 .45833 m
.00375 .45833 L
s
P
p
.001 w
0 .54167 m
.00375 .54167 L
s
P
p
.001 w
0 .58333 m
.00375 .58333 L
s
P
p
.001 w
0 .625 m
.00375 .625 L
s
P
p
.001 w
0 .66667 m
.00375 .66667 L
s
P
p
.001 w
0 .75 m
.00375 .75 L
s
P
p
.001 w
0 .79167 m
.00375 .79167 L
s
P
p
.001 w
0 .83333 m
.00375 .83333 L
s
P
p
.001 w
0 .875 m
.00375 .875 L
s
P
p
.001 w
0 .95833 m
.00375 .95833 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.04167 m
.00375 1.04167 L
s
P
p
.001 w
0 1.08333 m
.00375 1.08333 L
s
P
p
.001 w
0 1.16667 m
.00375 1.16667 L
s
P
p
.001 w
0 1.20833 m
.00375 1.20833 L
s
P
p
.001 w
0 1.25 m
.00375 1.25 L
s
P
p
.001 w
0 1.29167 m
.00375 1.29167 L
s
P
p
.001 w
0 .04167 m
.00375 .04167 L
s
P
p
.001 w
0 1.375 m
.00375 1.375 L
s
P
p
.001 w
0 1.41667 m
.00375 1.41667 L
s
P
p
.001 w
0 1.45833 m
.00375 1.45833 L
s
P
p
.002 w
0 0 m
0 1.5 L
s
P
P
p
p
.002 w
0 1.49375 m
0 1.5 L
s
P
p
.002 w
.16667 1.49375 m
.16667 1.5 L
s
P
p
.002 w
.33333 1.49375 m
.33333 1.5 L
s
P
p
.002 w
.5 1.49375 m
.5 1.5 L
s
P
p
.002 w
.66667 1.49375 m
.66667 1.5 L
s
P
p
.002 w
.83333 1.49375 m
.83333 1.5 L
s
P
p
.001 w
.03333 1.49625 m
.03333 1.5 L
s
P
p
.001 w
.06667 1.49625 m
.06667 1.5 L
s
P
p
.001 w
.1 1.49625 m
.1 1.5 L
s
P
p
.001 w
.13333 1.49625 m
.13333 1.5 L
s
P
p
.001 w
.2 1.49625 m
.2 1.5 L
s
P
p
.001 w
.23333 1.49625 m
.23333 1.5 L
s
P
p
.001 w
.26667 1.49625 m
.26667 1.5 L
s
P
p
.001 w
.3 1.49625 m
.3 1.5 L
s
P
p
.001 w
.36667 1.49625 m
.36667 1.5 L
s
P
p
.001 w
.4 1.49625 m
.4 1.5 L
s
P
p
.001 w
.43333 1.49625 m
.43333 1.5 L
s
P
p
.001 w
.46667 1.49625 m
.46667 1.5 L
s
P
p
.001 w
.53333 1.49625 m
.53333 1.5 L
s
P
p
.001 w
.56667 1.49625 m
.56667 1.5 L
s
P
p
.001 w
.6 1.49625 m
.6 1.5 L
s
P
p
.001 w
.63333 1.49625 m
.63333 1.5 L
s
P
p
.001 w
.7 1.49625 m
.7 1.5 L
s
P
p
.001 w
.73333 1.49625 m
.73333 1.5 L
s
P
p
.001 w
.76667 1.49625 m
.76667 1.5 L
s
P
p
.001 w
.8 1.49625 m
.8 1.5 L
s
P
p
.001 w
.86667 1.49625 m
.86667 1.5 L
s
P
p
.001 w
.9 1.49625 m
.9 1.5 L
s
P
p
.001 w
.93333 1.49625 m
.93333 1.5 L
s
P
p
.001 w
.96667 1.49625 m
.96667 1.5 L
s
P
p
.002 w
0 1.5 m
1 1.5 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .29167 m
1 .29167 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .70833 m
1 .70833 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.002 w
.99375 1.125 m
1 1.125 L
s
P
p
.002 w
.99375 1.33333 m
1 1.33333 L
s
P
p
.001 w
.99625 .125 m
1 .125 L
s
P
p
.001 w
.99625 .16667 m
1 .16667 L
s
P
p
.001 w
.99625 .20833 m
1 .20833 L
s
P
p
.001 w
.99625 .25 m
1 .25 L
s
P
p
.001 w
.99625 .33333 m
1 .33333 L
s
P
p
.001 w
.99625 .375 m
1 .375 L
s
P
p
.001 w
.99625 .41667 m
1 .41667 L
s
P
p
.001 w
.99625 .45833 m
1 .45833 L
s
P
p
.001 w
.99625 .54167 m
1 .54167 L
s
P
p
.001 w
.99625 .58333 m
1 .58333 L
s
P
p
.001 w
.99625 .625 m
1 .625 L
s
P
p
.001 w
.99625 .66667 m
1 .66667 L
s
P
p
.001 w
.99625 .75 m
1 .75 L
s
P
p
.001 w
.99625 .79167 m
1 .79167 L
s
P
p
.001 w
.99625 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .875 m
1 .875 L
s
P
p
.001 w
.99625 .95833 m
1 .95833 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.04167 m
1 1.04167 L
s
P
p
.001 w
.99625 1.08333 m
1 1.08333 L
s
P
p
.001 w
.99625 1.16667 m
1 1.16667 L
s
P
p
.001 w
.99625 1.20833 m
1 1.20833 L
s
P
p
.001 w
.99625 1.25 m
1 1.25 L
s
P
p
.001 w
.99625 1.29167 m
1 1.29167 L
s
P
p
.001 w
.99625 .04167 m
1 .04167 L
s
P
p
.001 w
.99625 1.375 m
1 1.375 L
s
P
p
.001 w
.99625 1.41667 m
1 1.41667 L
s
P
p
.001 w
.99625 1.45833 m
1 1.45833 L
s
P
p
.002 w
1 0 m
1 1.5 L
s
P
P
p
P
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
p
p
p
.5 .5 .5 r
.08333 .08333 m
.08333 .75 L
.25 .75 L
.25 1.41667 L
.75 1.41667 L
.75 .75 L
.91667 .75 L
.91667 .08333 L
F
.004 w
.25 .75 m
.25 .75 .16667 0 365.73 arc
F
.75 .75 m
.75 .75 .16667 0 365.73 arc
F
P
p
1 1 1 r
.004 w
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
.33333 .5 m
.33333 1.33333 L
.66667 1.33333 L
.66667 .5 L
F
P
p
.01 w
.5 .83333 m
.5 1.25 L
s
.025 w
.5 .5 Mdot
.5 .83333 Mdot
.5 1.25 Mdot
P
P
p
p
1 .6 .6 r
.004 w
.5 .5 m
.5 .5 .3125 90 270 arc
F
.5 .5 m
.5 .5 .3125 -20.0535 20.0535 arc
F
p
.5 .39167 m
.79583 .39167 L
.79583 .60833 L
.5 .60833 L
F
P
P
p
1 .5 .5 r
.004 w
.5 .5 m
.5 .5 .05833 0 365.73 arc
F
.75 .5 m
.75 .5 .04167 0 365.73 arc
F
P
p
.025 w
.5 .5 Mdot
p
.75 .5 Mdot
P
P
P
p
p
.7 .7 1 r
.35 .70833 m
.65 .70833 L
.65 1 L
.35 1 L
F
P
p
.6 .6 1 r
.004 w
.5 .83333 m
.5 .83333 .03333 0 365.73 arc
F
P
p
p
.01 w
.5 .83333 m
.5 1 L
s
P
p
.025 w
.5 .83333 Mdot
.5 1 Mdot
P
P
P
p
.04 w
.75 .5 m
.5 .83333 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{191, 287},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002o00017a000`40O003h00O_goo002oOol00;mo
o`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol003=o
o`<001Qoo`<001Moo`03001oogoo01Moo`<001Yoo`<001Qoo`8000=oo`00=7oo00<007ooOol05goo
00<007ooOol05Woo00<007oo000067oo00<007ooOol06goo00<007ooOol05goo00<007oo00000Woo
000]Ool30002Ool4000COol30003Ool00`00Oomoo`0EOol00`00Ool0000IOol00`00Oomoo`0HOol4
000HOol00`00Ool00002Ool0039oo`03001oo`0001Yoo`03001oogoo01Eoo`03001oo`0001Uoo`03
001oogoo01Qoo`03001oo`0001Uoo`8000=oo`00<goo0P006Goo00<007oo00005Woo00<007oo0000
67oo00<007oo00006Woo0P006Goo00<007ooOol00Woo000dOol00`00Oomoo`0HOol00`00Oomoo`0F
Ool00`00Oomoo`0HOol00`00Oomoo`0JOol00`00Oomoo`0HOol20002Ool00;moo`00_goo002oOol0
0;moo`00_goo002oOol00;moo`00_goo000FOonV0003Ool001Ioo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo005oo`005Woo00<0
07ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001o
ogoo0:9oo`03001oogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomo
o`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:5oo`8000=oo`005Woo00<007ooOol0XWoo00<0
07ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:9oo`03001o
ogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000AOol00`00Oomoo`02Ool00`00Oomo
o`2ROol00`00Oomoo`01Ool0011oo`03001oo`0000=oo`03001oogoo0:9oo`03001oogoo005oo`00
2goo0`0017oo00@007ooOomoo`800:9oo`8000=oo`0047oo0P0017oo00<007ooOol02WooRSg_3Woo
00<007ooOol00Goo000@Ool00`00Oomoo`03Ool00`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool0
011oo`<000=oo`03001oogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007ooOol02WooRSg_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007ooOol02WooRSg_3Goo0P000goo000FOol0
0`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoohXmk`ioo`03001oogoo
005oo`005Woo00<007ooOol02WooRSg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007oo
Ool02WooRSg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl=Ool20003Ool001Ioo`03
001oogoo00Yooc`mka=ooc/mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo=Sg_7Woo=Sg_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oold?NlSOolc?Nl>Ool00`00Oomoo`01Ool001Io
o`03001oogoo00Yooc4mk`moo`EnLaAooc4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo
;cg_2Woo37ic5goo;Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool/?Nl:Ool?OW<IOol/
?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoobXmk`Qooa=nLaaoobTmk`eoo`8000=oo`00
5Woo00<007ooOol02Woo:Cg_1Woo5Wic7Goo:3g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:
OolW?Nl6OolHOW<NOolW?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoobDmk`MooaUnLb1o
obDmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo93g_1goo6Wic8Woo8cg_3Woo00<007oo
Ool00Goo000FOol00`00Oomoo`0:OolS?Nl6OolLOW<SOolR?Nl>Ool00`00Oomoo`01Ool001Ioo`03
001oogoo00Yoob8mk`IooaenLbAoob4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo8Cg_
1Goo7gic9Goo83g_3Goo0P000goo000FOol00`00Oomoo`0:OolP?Nl4OolQOW<VOolO?Nl>Ool00`00
Oomoo`01Ool001Ioo`03001oogoo00Yooalmk`Eoob5nLbMooahmk`ioo`03001oogoo005oo`005Woo
00<007ooOol02Woo7Sg_1Goo8Wic:7oo7Cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolM
?Nl5OolSOW<YOolL?Nl>Ool00`00Oomoo`01Ool000Ioo`<000=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Yooa`mk`EoobAnLbYooa/mk`ioo`03001oogoo005oo`001Woo00<007ooOol0
1goo00<007oo00000goo00<007ooOol02Woo6cg_17oo9Wic:goo6Sg_3Woo00<007ooOol00Goo0000
17oo000000000goo00<007ooOol027oo00@007ooOomoo`8000]ooaXmk`AoobMnLbaooaTmk`eoo`80
00=oo`001goo00<007ooOol01Woo0P0017oo00<007ooOol02Woo6Cg_17oo:7ic;7oo6Cg_3Woo00<0
07ooOol00Goo0006Ool00`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`0:OolI?Nl4OolXOW<]
OolH?Nl>Ool00`00Oomoo`01Ool000Moo`03001oogoo00Ioo`<000=oo`03001oogoo00YooaPmk`Ao
obUnLbiooaLmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo5cg_17oo:Wic;goo5Sg_3Woo
00<007ooOol00Goo000FOol00`00Oomoo`0:OolF?Nl4Ool[OW<_OolF?Nl>Ool00`00Oomoo`01Ool0
01Ioo`03001oogoo00YooaHmk`Aoob]nLc1ooaDmk`eoo`8000=oo`005Woo00<007ooOol02Woo5Sg_
0goo;7ic<Goo53g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolE?Nl4Ool/OW<aOolD?Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaDmk`AoobanLc9ooa<mk`ioo`03001oogoo005o
o`005Woo00<007ooOol02Woo53g_17oo;Gic<Woo4cg_3Woo00<007ooOol00Goo000FOol00`00Oomo
o`0:OolD?Nl4Ool]OW<cOolB?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa<mk`Aoobin
Lc=ooa8mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Sg_1Goo;Wic<goo4Sg_3Goo0P00
0goo000FOol00`00Oomoo`0:OolB?Nl4Ool_OW<dOolA?Nl>Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00Yooa4mk`EoobmnLcAooa4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Cg_1Goo
;gic=Goo43g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolA?Nl4OomROW<3Ool@?Nl>Ool0
0`00Oomoo`01Ool001Ioo`03001oogoo00Yooa4mk`Aoof9nL`=ooa0mk`ioo`03001oogoo005oo`00
5Woo00<007ooOol02Woo4Cg_0gooHgic17oo3cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:
Ool@?Nl4OomSOW<4Ool??Nl=Ool20003Ool001Ioo`03001oogoo00Yooa0mk`=oofAnL`Aoo`lmk`io
o`03001oogoo005oo`005Woo00<007ooOol02Woo43g_0gooIGic0goo3cg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:Ool??Nl4OomUOW<3Ool??Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo
00Yoo`lmk`AoofEnL`Aoo`hmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo3cg_17oo;gic
1Wg_<7ic17oo3Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool??Nl3Ool^OW<;ONl^OW<3
Ool>?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`lmk`=oobenL`emkbenL`=oo`hmk`eo
o`8000=oo`005Woo00<007ooOol02Woo3cg_0goo;7ic3gg_7gic1Wg_1gic0goo3Sg_3Woo00<007oo
Ool00Goo000FOol00`00Oomoo`0:Ool>?Nl4Ool/OW<@ONlLOW<9ONl6OW<3Ool>?Nl>Ool00`00Oomo
o`01Ool001Ioo`03001oogoo00Yoo`hmk`Aoob]nLa9mkaYnL`]mk`EnL`=oo`hmk`ioo`03001oogoo
005oo`005Woo00<007ooOol02Woo3Sg_17oo:gic4Wg_6Gic1Wg_0P001Gg_17ic0goo3Sg_3Woo00<0
07ooOol00Goo000AOol00`00Oomoo`02Ool00`00Oomoo`0:Ool>?Nl4OolZOW<CONlIOW<5ONl50003
ONl4OW<3Ool>?Nl>Ool00`00Oomoo`01Ool0011oo`03001oo`0000=oo`03001oogoo00Yoo`hmk`Ao
obYnLa=mkaUnL`Emk`L0009mk`=nL`=oo`hmk`ioo`03001oogoo005oo`0047oo00<007oo00000goo
0P002goo3Sg_17oo:Wic2Gg_00<007g_ONl01gg_6Gic17g_1`000gg_0gic0goo3Sg_3Goo0P000goo
000@Ool00`00Ool00003Ool00`00Oomoo`0:Ool>?Nl4OolZOW<8ONl30008ONlIOW<3ONl70004ONl3
OW<3Ool>?Nl>Ool00`00Oomoo`01Ool0011oo`03001oo`0000=oo`03001oogoo00Yoo`hmk`AoobYn
L`Umk`03001mkgg_00MmkaUnL`9mk`P000Amk`=nL`=oo`hmk`ioo`03001oogoo005oo`004Goo00<0
07ooOol00Woo00<007ooOol02Woo3Sg_17oo:Wic4gg_6Wic00=mk`0000001@0017g_17ic0goo3Sg_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool>?Nl4Ool[OW<AONlKOW<70004ONl5OW<3Ool>
?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`hmk`Aoob]nLa1mka]nL`L000Amk`InL`=o
o`hmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo3Sg_17oo;7ic3gg_6Wic20000Wg_27ic
0goo3Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool??Nl3Ool/OW<>ONlKOW<7000;OW<3
Ool>?Nl=Ool20003Ool001Ioo`03001oogoo00Yoo`lmk`=oobinL`]mka]nL`L000anL`=oo`hmk`io
o`03001oogoo005oo`005Woo00<007ooOol02Woo3cg_17oo;Wic27g_77ic1`0037ic17oo3Sg_3Woo
00<007ooOol00Goo000FOol00`00Oomoo`0:Ool??Nl4OolbOW<2ONlMOW<8000<OW<4Ool>?Nl>Ool0
0`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`lmk`Aooe1nL`P000enL`=oo`lmk`ioo`03001oogoo
005oo`005Woo00<007ooOol02Woo43g_0gooD7ic1`003Wic0goo3cg_3Woo00<007ooOol00Goo000F
Ool00`00Oomoo`0:Ool@?Nl3Oom?OW<7000>OW<4Ool??Nl>Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00Yooa0mk`AoodenL`L000mnL`Aoo`lmk`eoo`8000=oo`005Woo00<007ooOol02Woo4Cg_0goo
C7ic20003gic17oo3cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolA?Nl4Oom;OW<7000@
OW<3Ool@?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa4mk`AoodYnL`L0015nL`=ooa0m
k`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Cg_1GooB7ic1`004Gic17oo43g_3Woo00<0
07ooOol00Goo000FOol00`00Oomoo`0:OolA?Nl5Ool_OW<HOol8000DOolA?Nl>Ool00`00Oomoo`01
Ool001Ioo`03001oogoo00Yooa8mk`AoobmnLaQoo`L001Eooa4mk`ioo`03001oogoo005oo`005Woo
00<007ooOol02Woo4Sg_1Goo;Wic5goo1`005Goo4Sg_3Goo0P000goo000FOol00`00Oomoo`0:OolC
?Nl4Ool^OW<FOol7000FOolB?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa@mk`Aooben
LaEoo`P001Iooa8mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo53g_17oo;Gic5Goo1`00
5Woo4cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolE?Nl4Ool/OW<DOol7000GOolC?Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaDmk`AoobanLa=oo`L001Mooa@mk`ioo`03001o
ogoo005oo`005Woo00<007ooOol02Woo5Sg_0goo;7ic4Woo20005goo53g_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:OolF?Nl4Ool[OW<AOol8000GOolE?Nl=Ool20003Ool001Ioo`03001oogoo
00YooaHmk`Aoob]nLa5oo`L001MooaHmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo5cg_
17oo:Wic47oo1`0067oo5Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolH?Nl4OolYOW<?
Ool7000HOolG?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaTmk`AoobQnL`ioo`P001Mo
oaPmk`ioo`03001oogoo005oo`001Woo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool02Woo6Cg_17oo:7ic3Woo1`005goo6Cg_3Woo00<007ooOol00Goo0006Ool00`00Oomoo`07Ool0
0`00Ool00003Ool00`00Oomoo`0:OolJ?Nl4OolWOW<=Ool7000HOolI?Nl>Ool00`00Oomoo`01Ool0
00Moo`03001oogoo00Qoo`04001oogooOol2000;OolK?Nl4OolVOW<<Ool7000IOolI?Nl=Ool20003
Ool000Moo`03001oogoo00Ioo`8000Aoo`03001oogoo00Yooa`mk`Aoo`anLbAJg`P000IJga9ooaXm
k`ioo`03001oogoo005oo`001Woo00<007oo00001goo00<007ooOol00goo00<007ooOol02Woo7Cg_
17oo2gic95[O1`001e[O4Goo6cg_3Woo00<007ooOol00Goo0007Ool00`00Oomoo`06Ool30003Ool0
0`00Oomoo`0:OolM?Nl6Ool9OW<SF]l70008F]l@OolL?Nl>Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00Yooahmk`Ioo`QnLb9Jg`L000UJg`mooadmk`ioo`03001oogoo005oo`005Woo00<007ooOol0
2Woo7cg_1Goo27ic8E[O20002E[O3Woo7Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolQ
?Nl4Ool7OW<QF]l7000:F]l<OolP?Nl=Ool20003Ool001Ioo`03001oogoo00Yoob8mk`Aoo`InLb1J
g`L000]Jg`]oob4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo8cg_1Woo0gic7e[O1`00
35[O2Woo8Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0;OolS?Nl7Ool00gicF]mJg`0LF]l8
000<F]l9OolS?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]oob@mk`MooaeJg`P000eJg`Mo
obDmk`ioo`03001oogoo005oo`005Woo00<007ooOol02goo9Sg_1Goo7E[O1`003U[O1Goo9cg_3Woo
00<007ooOol00Goo000FOol00`00Oomoo`0;OolX?Nl3OolLF]l7000?F]l4OolX?Nl>Ool00`00Oomo
o`01Ool001Ioo`03001oogoo00]oobTmk`9ooa]Jg`L0011Jg`=oobTmk`eoo`8000=oo`005Woo00<0
07ooOol037oo:3g_0Woo6U[O200045[O0goo:Cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0<
OolX?Nl2OolJF]l7000AF]l3OolX?Nl?Ool00`00Oomoo`01Ool001Ioo`03001oogoo00aoobPmk`9o
oaIJg`=>O`L0019Jg`=oobPmk`moo`03001oogoo005oo`005Woo00<007ooOol03Goo9cg_0Woo5E[O
0dio1`004e[O0goo9cg_47oo00<007ooOol00Goo000FOol00`00Oomoo`0=OolW?Nl2OolDF]l3CWl8
000CF]l3OolW?Nl@Ool00`00Oomoo`01Ool001Ioo`03001oogoo00ioobHmk`9ooaAJg`=>O`L00003
CWmJge[O015Jg`=oobLmka1oo`03001oogoo005oo`005Woo00<007ooOol03Woo9Sg_0Woo55[O0Tio
1`000Tio4e[O0goo9Sg_47oo0P000goo000FOol00`00Oomoo`0>OolV?Nl2OolDF]l00dio00000005
0003CWlCF]l3OolU?NlBOol00`00Oomoo`01Ool001Ioo`03001oogoo00moobDmk`9ooaAJg`=>O`D0
009>OaAJg`=oob@mka=oo`03001oogoo005oo`005Woo00<007ooOol047oo93g_0Woo5E[O14io0P00
0dio55[O0goo93g_4goo00<007ooOol00Goo000FOol00`00Oomoo`0AOolS?Nl2OolEF]l4CWl01000
CWm>Odio5E[O0goo8cg_57oo00<007ooOol00Goo000FOol00`00Oomoo`0BOolR?Nl2OolGF]l2CWl0
0`00CWmJg`0FF]l3OolR?NlEOol00`00Oomoo`01Ool001Ioo`03001oogoo01=oob4mk`9ooaUJg`03
001Jge[O01IJg`=oob4mkaIoo`03001oogoo005oo`005Woo00<007ooOol057oo83g_0Woo6E[O00<0
05[OF]l05U[O0goo83g_5Woo0P000goo000FOol00`00Oomoo`0EOolO?Nl2OolIF]l00`00F]mJg`0F
F]l3OolO?NlHOol00`00Oomoo`01Ool001Ioo`03001oogoo01Iooahmk`9ooaUJg`03001Jge[O01IJ
g`=ooahmkaUoo`03001oogoo005oo`005Woo00<007ooOol067oo73g_0Woo6E[O00<005[OF]l05U[O
0goo7Cg_6Woo00<007ooOol00Goo000FOol00`00Oomoo`0JOolJ?Nl2OolIF]l00`00F]mJg`0FF]l3
OolJ?NlMOol00`00Oomoo`01Ool0015oo`03001oogoo009oo`03001oogoo01]ooaTmk`9ooaUJg`03
001Jge[O01IJg`=ooaPmkamoo`03001oogoo005oo`0047oo00<007oo00000goo00<007ooOol07Goo
5cg_0Woo6E[O00<005[OF]l05U[O0goo5Cg_8Woo00<007ooOol00Goo000BOol01000Oomoogoo0P00
8goo4Sg_0Woo6E[O00<005[OF]l05U[O0goo4Sg_97oo0P000goo000@Ool20004Ool00`00Oomoo`0V
Ool>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool0011oo`03001oogoo00=o
o`03001oogoo02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`0047oo
0`000goo00<007ooOol09Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo
000FOol00`00Oomoo`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool0
01Ioo`03001oogoo02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`00
5Woo00<007ooOol09Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo000F
Ool00`00Oomoo`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlXOol20003Ool001Ioo`03001o
ogoo02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`005Woo00<007oo
Ool09Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomo
o`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo
02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol0
9Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0V
Ool>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Io
o`hmk`9ooaQJg`<001MJg`=oo`hmkbQoo`8000=oo`005Woo00<007ooOol09Woo3Sg_6goo00<007oo
Ool06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>
?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03
001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol0
0Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Io
o`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007oo
Ool09Woo3Sg_6goo00<007ooOol06Goo3Sg_:7oo0P000goo000FOol00`00Oomoo`0VOol>?NlKOol0
0`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo
01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_
:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00
Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005o
o`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol0
0`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlXOol20003Ool001Ioo`03001oogoo02Ioo`hm
ka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<0
07ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0I
Ool>?NlYOol00`00Oomoo`01Ool000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`001goo00<007oo
Ool01Woo00<007oo00000goo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007oo
Ool00Goo0007Ool00`00Oomoo`08Ool01000Oomoogoo0P009goo3Sg_6goo00<007ooOol06Goo3Sg_
:7oo0P000goo0008Ool00`00Oomoo`05Ool20004Ool00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0I
Ool>?NlYOol00`00Oomoo`01Ool000Ioo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo02Io
o`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`001Woo0`001goo0`000goo00<007oo
Ool09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>
?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03
001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol0
6Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlX
Ool20003Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005o
o`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol0
0`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo
02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_
6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00
Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uo
o`hmkbQoo`8000=oo`005Woo00<007ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007oo
Ool00Goo000FOol00`00Oomoo`0VOol>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool0
01Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<0
07ooOol09Woo3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0V
Ool>?NlKOol00`00Oomoo`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka]o
o`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_6goo00<007oo
Ool06Goo3Sg_:7oo0P000goo000FOol00`00Oomoo`0VOol>?NlJOol3000JOol>?NlYOol00`00Oomo
o`01Ool001Ioo`03001oogoo02Ioo`hmka]oo`03001oogoo01Uoo`hmkbUoo`03001oogoo005oo`00
5Woo00<007ooOol09Woo3Sg_=goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nlg
Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmkcMoo`hmkbUoo`03001oogoo005o
o`005Woo00<007ooOol09Woo3Sg_=goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>
?NlgOol>?NlXOol20003Ool001Ioo`03001oogoo02Ioo`hmkcMoo`hmkbUoo`03001oogoo005oo`00
5Woo00<007ooOol09Woo3Sg_=goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nlg
Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmkcMoo`hmkbUoo`03001oogoo005o
o`002Woo1@000Woo00<007ooOol00Woo00<007ooOol09Woo3Sg_=goo3Sg_:Goo00<007ooOol00Goo
000<Ool01`00Oomoogoo001oo`0000=oo`03001oogoo02Ioo`hmkcMoo`hmkbUoo`03001oogoo005o
o`0037oo00L007ooOomoo`00Ool00003Ool2000WOol>?NlgOol>?NlXOol20003Ool000aoo`07001o
ogooOol007oo00000goo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000<Ool01`00Oomoogoo
001oo`0000=oo`03001oogoo02Iooe<mkbUoo`03001oogoo005oo`002goo0P0017oo00<007ooOol0
0Woo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOomC?NlYOol00`00
Oomoo`01Ool001Ioo`03001oogoo02Iooe<mkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo
Dcg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOomC?NlXOol20003Ool001Ioo`03001oogoo
02Iooe<mkbUoo`03001oogoo005oo`005Woo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000F
Ool00`00Oomoo`0VOomC?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Iooe<mkbUoo`03001o
ogoo005oo`005Woo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOomC
?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Iooe<mkbQoo`8000=oo`005Woo00<007ooOol0
XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:9o
o`03001oogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol0
0`00Oomoo`01Ool001Ioo`03001oogoo0:9oo`03001oogoo005oo`005Woo00<007ooOol0XGoo0P00
0goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:9oo`03001oogoo005o
o`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool0
01Ioo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo
01Qoo`03001oogoo01Uoo`03001oogoo005oo`005WooYP000goo002oOol00;moo`00_goo002oOol0
0;moo`00_goo002oOol00;moo`00_goo002oOol00001\
\>"],
  ImageRangeCache->{{{0, 190}, {286, 0}} -> {-7.60082, -8.01978, 0.0725381, 
  0.0725381}}]
}, Open  ]],

Cell[TextData[{
  "Big surprise! The trivial solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 is for the local coordinate system of each body to be aligned with \
the global coordinate system. This is because the model was defined such as \
to have this \"perfect\" assembled configuration. The piston is defined such \
that its local origin lies at a point that is outside of the piston body, \
directly on the global origin when ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0. Note also the 3-4-5 triangle formed by the crankshaft, piston, and \
connecting rod when ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.\n\nAdvancing ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " results in a more interesting solution. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This seeks a solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2 pi/10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(crankangle = 2  \[Pi]\ 0.1; \nSolveMech[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] \(-2.38308869393142419`*^-22\), 
      Y2 \[Rule] 3.75037969088861045`*^-22, 
      Th2 \[Rule] 0.628318530717958623`, X3 \[Rule] 0.`, 
      Y3 \[Rule] 2.13478841967294563`, Th3 \[Rule] 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Now the angular coordinate of the crankshaft, ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", has advanced",
  StyleBox[" to 2 pi/10, as ",
    FontFamily->"Times"],
  "specified, and the vertical coordinate of the piston, ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", has increased to 2.13. All of the other coordinates are still zero and \
will always be so because of the specific function of this mechanism model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This seeks a solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 3 2 pi/10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(crankangle = 2  \[Pi]\ 0.3; \nSolveMech[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] \(-5.56646572556635987`*^-26\), 
      Y2 \[Rule] 1.51428842748035208`*^-26, Th2 \[Rule] 1.88495559215387586`, 
      X3 \[Rule] 0.`, Y3 \[Rule] 3.76647561249347306`, Th3 \[Rule] 0.`}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "A graphic of the model at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 6 pi/10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.5 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(-5)] -0.0125 .08333 1 0 Msboxa
[(-2.5)] -0.0125 .29167 1 0 Msboxa
[(0)] -0.0125 .5 1 0 Msboxa
[(2.5)] -0.0125 .70833 1 0 Msboxa
[(5)] -0.0125 .91667 1 0 Msboxa
[(7.5)] -0.0125 1.125 1 0 Msboxa
[(10)] -0.0125 1.33333 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(-5)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .29167 m
.00625 .29167 L
s
P
[(-2.5)] -0.0125 .29167 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(0)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .70833 m
.00625 .70833 L
s
P
[(2.5)] -0.0125 .70833 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(5)] -0.0125 .91667 1 0 Mshowa
p
.002 w
0 1.125 m
.00625 1.125 L
s
P
[(7.5)] -0.0125 1.125 1 0 Mshowa
p
.002 w
0 1.33333 m
.00625 1.33333 L
s
P
[(10)] -0.0125 1.33333 1 0 Mshowa
p
.001 w
0 .125 m
.00375 .125 L
s
P
p
.001 w
0 .16667 m
.00375 .16667 L
s
P
p
.001 w
0 .20833 m
.00375 .20833 L
s
P
p
.001 w
0 .25 m
.00375 .25 L
s
P
p
.001 w
0 .33333 m
.00375 .33333 L
s
P
p
.001 w
0 .375 m
.00375 .375 L
s
P
p
.001 w
0 .41667 m
.00375 .41667 L
s
P
p
.001 w
0 .45833 m
.00375 .45833 L
s
P
p
.001 w
0 .54167 m
.00375 .54167 L
s
P
p
.001 w
0 .58333 m
.00375 .58333 L
s
P
p
.001 w
0 .625 m
.00375 .625 L
s
P
p
.001 w
0 .66667 m
.00375 .66667 L
s
P
p
.001 w
0 .75 m
.00375 .75 L
s
P
p
.001 w
0 .79167 m
.00375 .79167 L
s
P
p
.001 w
0 .83333 m
.00375 .83333 L
s
P
p
.001 w
0 .875 m
.00375 .875 L
s
P
p
.001 w
0 .95833 m
.00375 .95833 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.04167 m
.00375 1.04167 L
s
P
p
.001 w
0 1.08333 m
.00375 1.08333 L
s
P
p
.001 w
0 1.16667 m
.00375 1.16667 L
s
P
p
.001 w
0 1.20833 m
.00375 1.20833 L
s
P
p
.001 w
0 1.25 m
.00375 1.25 L
s
P
p
.001 w
0 1.29167 m
.00375 1.29167 L
s
P
p
.001 w
0 .04167 m
.00375 .04167 L
s
P
p
.001 w
0 1.375 m
.00375 1.375 L
s
P
p
.001 w
0 1.41667 m
.00375 1.41667 L
s
P
p
.001 w
0 1.45833 m
.00375 1.45833 L
s
P
p
.002 w
0 0 m
0 1.5 L
s
P
P
p
p
.002 w
0 1.49375 m
0 1.5 L
s
P
p
.002 w
.16667 1.49375 m
.16667 1.5 L
s
P
p
.002 w
.33333 1.49375 m
.33333 1.5 L
s
P
p
.002 w
.5 1.49375 m
.5 1.5 L
s
P
p
.002 w
.66667 1.49375 m
.66667 1.5 L
s
P
p
.002 w
.83333 1.49375 m
.83333 1.5 L
s
P
p
.001 w
.03333 1.49625 m
.03333 1.5 L
s
P
p
.001 w
.06667 1.49625 m
.06667 1.5 L
s
P
p
.001 w
.1 1.49625 m
.1 1.5 L
s
P
p
.001 w
.13333 1.49625 m
.13333 1.5 L
s
P
p
.001 w
.2 1.49625 m
.2 1.5 L
s
P
p
.001 w
.23333 1.49625 m
.23333 1.5 L
s
P
p
.001 w
.26667 1.49625 m
.26667 1.5 L
s
P
p
.001 w
.3 1.49625 m
.3 1.5 L
s
P
p
.001 w
.36667 1.49625 m
.36667 1.5 L
s
P
p
.001 w
.4 1.49625 m
.4 1.5 L
s
P
p
.001 w
.43333 1.49625 m
.43333 1.5 L
s
P
p
.001 w
.46667 1.49625 m
.46667 1.5 L
s
P
p
.001 w
.53333 1.49625 m
.53333 1.5 L
s
P
p
.001 w
.56667 1.49625 m
.56667 1.5 L
s
P
p
.001 w
.6 1.49625 m
.6 1.5 L
s
P
p
.001 w
.63333 1.49625 m
.63333 1.5 L
s
P
p
.001 w
.7 1.49625 m
.7 1.5 L
s
P
p
.001 w
.73333 1.49625 m
.73333 1.5 L
s
P
p
.001 w
.76667 1.49625 m
.76667 1.5 L
s
P
p
.001 w
.8 1.49625 m
.8 1.5 L
s
P
p
.001 w
.86667 1.49625 m
.86667 1.5 L
s
P
p
.001 w
.9 1.49625 m
.9 1.5 L
s
P
p
.001 w
.93333 1.49625 m
.93333 1.5 L
s
P
p
.001 w
.96667 1.49625 m
.96667 1.5 L
s
P
p
.002 w
0 1.5 m
1 1.5 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .29167 m
1 .29167 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .70833 m
1 .70833 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.002 w
.99375 1.125 m
1 1.125 L
s
P
p
.002 w
.99375 1.33333 m
1 1.33333 L
s
P
p
.001 w
.99625 .125 m
1 .125 L
s
P
p
.001 w
.99625 .16667 m
1 .16667 L
s
P
p
.001 w
.99625 .20833 m
1 .20833 L
s
P
p
.001 w
.99625 .25 m
1 .25 L
s
P
p
.001 w
.99625 .33333 m
1 .33333 L
s
P
p
.001 w
.99625 .375 m
1 .375 L
s
P
p
.001 w
.99625 .41667 m
1 .41667 L
s
P
p
.001 w
.99625 .45833 m
1 .45833 L
s
P
p
.001 w
.99625 .54167 m
1 .54167 L
s
P
p
.001 w
.99625 .58333 m
1 .58333 L
s
P
p
.001 w
.99625 .625 m
1 .625 L
s
P
p
.001 w
.99625 .66667 m
1 .66667 L
s
P
p
.001 w
.99625 .75 m
1 .75 L
s
P
p
.001 w
.99625 .79167 m
1 .79167 L
s
P
p
.001 w
.99625 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .875 m
1 .875 L
s
P
p
.001 w
.99625 .95833 m
1 .95833 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.04167 m
1 1.04167 L
s
P
p
.001 w
.99625 1.08333 m
1 1.08333 L
s
P
p
.001 w
.99625 1.16667 m
1 1.16667 L
s
P
p
.001 w
.99625 1.20833 m
1 1.20833 L
s
P
p
.001 w
.99625 1.25 m
1 1.25 L
s
P
p
.001 w
.99625 1.29167 m
1 1.29167 L
s
P
p
.001 w
.99625 .04167 m
1 .04167 L
s
P
p
.001 w
.99625 1.375 m
1 1.375 L
s
P
p
.001 w
.99625 1.41667 m
1 1.41667 L
s
P
p
.001 w
.99625 1.45833 m
1 1.45833 L
s
P
p
.002 w
1 0 m
1 1.5 L
s
P
P
p
P
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
p
p
p
.5 .5 .5 r
.08333 .08333 m
.08333 .75 L
.25 .75 L
.25 1.41667 L
.75 1.41667 L
.75 .75 L
.91667 .75 L
.91667 .08333 L
F
.004 w
.25 .75 m
.25 .75 .16667 0 365.73 arc
F
.75 .75 m
.75 .75 .16667 0 365.73 arc
F
P
p
1 1 1 r
.004 w
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
.33333 .5 m
.33333 1.33333 L
.66667 1.33333 L
.66667 .5 L
F
P
p
.01 w
.5 .83333 m
.5 1.25 L
s
.025 w
.5 .5 Mdot
.5 .83333 Mdot
.5 1.25 Mdot
P
P
p
p
1 .6 .6 r
.004 w
.5 .5 m
.5 .5 .3125 198 378 arc
F
.5 .5 m
.5 .5 .3125 87.9465 128.054 arc
F
p
.60303 .53348 m
.51161 .81483 L
.30555 .74788 L
.39697 .46652 L
F
P
P
p
1 .4 .4 r
.004 w
.5 .5 m
.5 .5 .05833 0 365.73 arc
F
.42275 .73776 m
.42275 .73776 .04167 0 365.73 arc
F
P
p
.025 w
.5 .5 Mdot
p
.42275 .73776 Mdot
P
P
P
p
p
.7 .7 1 r
.35 1.02221 m
.65 1.02221 L
.65 1.31387 L
.35 1.31387 L
F
P
p
.6 .6 1 r
.004 w
.5 1.14721 m
.5 1.14721 .03333 0 365.73 arc
F
P
p
p
.01 w
.5 1.14721 m
.5 1.31387 L
s
P
p
.025 w
.5 1.14721 Mdot
.5 1.31387 Mdot
P
P
P
p
.04 w
.42275 .73776 m
.5 1.14721 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{191, 287},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002o00017a000`40O003h00O_goo002oOol00;mo
o`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol003=o
o`<001Qoo`<001Moo`03001oogoo01Moo`<001Yoo`<001Qoo`8000=oo`00=7oo00<007ooOol05goo
00<007ooOol05Woo00<007oo000067oo00<007ooOol06goo00<007ooOol05goo00<007oo00000Woo
000]Ool30002Ool4000COol30003Ool00`00Oomoo`0EOol00`00Ool0000IOol00`00Oomoo`0HOol4
000HOol00`00Ool00002Ool0039oo`03001oo`0001Yoo`03001oogoo01Eoo`03001oo`0001Uoo`03
001oogoo01Qoo`03001oo`0001Uoo`8000=oo`00<goo0P006Goo00<007oo00005Woo00<007oo0000
67oo00<007oo00006Woo0P006Goo00<007ooOol00Woo000dOol00`00Oomoo`0HOol00`00Oomoo`0F
Ool00`00Oomoo`0HOol00`00Oomoo`0JOol00`00Oomoo`0HOol20002Ool00;moo`00_goo002oOol0
0;moo`00_goo002oOol00;moo`00_goo000FOonV0003Ool001Ioo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo005oo`005Woo00<0
07ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001o
ogoo0:9oo`03001oogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00Oomo
o`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:5oo`8000=oo`005Woo00<007ooOol0XWoo00<0
07ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:9oo`03001o
ogoo005oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000AOol00`00Oomoo`02Ool00`00Oomo
o`2ROol00`00Oomoo`01Ool0011oo`03001oo`0000=oo`03001oogoo0:9oo`03001oogoo005oo`00
2goo0`0017oo00@007ooOomoo`800:9oo`8000=oo`0047oo0P0017oo00<007ooOol02WooRSg_3Woo
00<007ooOol00Goo000@Ool00`00Oomoo`03Ool00`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool0
011oo`<000=oo`03001oogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007ooOol02WooRSg_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007ooOol02WooRSg_3Goo0P000goo000FOol0
0`00Oomoo`0:Oon:?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoohXmk`ioo`03001oogoo
005oo`005Woo00<007ooOol02WooRSg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoohXmk`ioo`03001oogoo005oo`005Woo00<007oo
Ool02WooRSg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oon:?Nl=Ool20003Ool001Ioo`03
001oogoo00Yooc`mka=ooc/mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo=Sg_7Woo=Sg_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Oold?NlSOolc?Nl>Ool00`00Oomoo`01Ool001Io
o`03001oogoo00Yooc4mka1oo`YnL`iooc4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo
;cg_2goo5Wic37oo;Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool/?Nl9OolPOW<9Ool/
?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoobXmk`QoobInL`UoobTmk`eoo`8000=oo`00
5Woo00<007ooOol02Woo:Cg_1goo:Wic27oo:3g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:
OolW?Nl7Ool^OW<7OolW?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YoobDmk`Mooc=nL`Io
obDmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo93g_1goo=Wic1Woo8cg_3Woo00<007oo
Ool00Goo000FOol00`00Oomoo`0:OolS?Nl6OoliOW<6OolR?Nl>Ool00`00Oomoo`01Ool001Ioo`03
001oogoo00Yoob8mk`EoocanL`Ioob4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo8Cg_
17oo@7ic1Goo83g_3Goo0P000goo000FOol00`00Oomoo`0:OolP?Nl4Oom2OW<5OolO?Nl>Ool00`00
Oomoo`01Ool001Ioo`03001oogoo00Yooalmk`AoodAnL`Eooahmk`ioo`03001oogoo005oo`005Woo
00<007ooOol02Woo7Sg_17ooAgic17oo7Cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolM
?Nl4Oom9OW<4OolL?Nl>Ool00`00Oomoo`01Ool000Ioo`<000=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Yooa`mk`EoodYnL`Aooa/mk`ioo`03001oogoo005oo`001Woo00<007ooOol0
1goo00<007oo00000goo00<007ooOol02Woo6cg_1GooC7ic17oo6Sg_3Woo00<007ooOol00Goo0000
17oo000000000goo00<007ooOol027oo00@007ooOomoo`8000]ooaXmk`AoodinL`EooaTmk`eoo`80
00=oo`001goo00<007ooOol01Woo0P0017oo00<007ooOol02Woo6Cg_17ooD7ic17oo6Cg_3Woo00<0
07ooOol00Goo0006Ool00`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`0:OolI?Nl3OomBOW<4
OolH?Nl>Ool00`00Oomoo`01Ool000Moo`03001oogoo00Ioo`<000=oo`03001oogoo00YooaPmk`Ao
oe=nL`AooaLmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo5cg_17ooE7ic1Goo5Sg_3Woo
00<007ooOol00Goo000FOol00`00Oomoo`0:OolF?Nl5OomEOW<4OolF?Nl>Ool00`00Oomoo`01Ool0
01Ioo`03001oogoo00YooaHmk`AooeMnL`AooaDmk`eoo`8000=oo`005Woo00<007ooOol02Woo5Sg_
0gooFGic17oo53g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolE?Nl4OomIOW<4OolD?Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaDmk`=ooe]nL`Aooa<mk`ioo`03001oogoo005o
o`005Woo00<007ooOol02Woo53g_17ooFgic17oo4cg_3Woo00<007ooOol00Goo000FOol00`00Oomo
o`0:OolD?Nl3OomLOW<5OolB?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa<mk`Aooeen
L`Aooa8mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Sg_17ooGWic17oo4Sg_3Goo0P00
0goo000FOol00`00Oomoo`0:OolB?Nl4OomOOW<4OolA?Nl>Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00Yooa4mk`EooemnL`Aooa4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Cg_17oo
HGic17oo43g_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolA?Nl4OomQOW<4Ool@?Nl>Ool0
0`00Oomoo`01Ool001Ioo`03001oogoo00Yooa4mk`=oof9nL`Aooa0mk`ioo`03001oogoo005oo`00
5Woo00<007ooOol02Woo4Cg_1gooGgic17oo3cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:
Ool@?Nl;OomLOW<4Ool??Nl=Ool20003Ool001Ioo`03001oogoo00Yooa0mk`iooeYnL`=oo`lmk`io
o`03001oogoo005oo`005Woo00<007ooOol02Woo43g_4GooEgic0goo3cg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:Ool??NlEOomDOW<3Ool??Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo
00Yoo`lmkaQooe5nL`Aoo`hmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo3cg_6goo67ic
1Wf<<7ic17oo3Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool??NlNOolCOW<;OH`^OW<3
Ool>?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`lmkb5oo`mnL`emS2enL`=oo`hmk`eo
o`8000=oo`005Woo00<007ooOol02Woo3cg_97oo2gic3gf<;7ic0goo3Sg_3Woo00<007ooOol00Goo
000FOol00`00Oomoo`0:Ool>?NlXOol8OW<@OH`[OW<3Ool>?Nl>Ool00`00Oomoo`01Ool001Ioo`03
001oogoo00Yoo`hmkbIoo`AnL`03OomnLgic009nLa9mS2YnL`=oo`hmk`ioo`03001oogoo005oo`00
5Woo00<007ooOol02Woo3Sg_9Woo1gic00=oogicOH`04Gf<:Wic0goo3Sg_3Woo00<007ooOol00Goo
000AOol00`00Oomoo`02Ool00`00Oomoo`0:Ool>?NlVOol8OW<COH`ZOW<3Ool>?Nl>Ool00`00Oomo
o`01Ool0011oo`03001oo`0000=oo`03001oogoo00Yoo`hmkbEoo`UnLa=mS2YnL`=oo`hmk`ioo`03
001oogoo005oo`0047oo00<007oo00000goo0P002goo3Sg_9Goo2Gic2Gf<00<007f<OH`01gf<:Wic
0goo3Sg_3Goo0P000goo000@Ool00`00Ool00003Ool00`00Oomoo`0:Ool>?NlUOol9OW<8OH`30008
OH`ZOW<3Ool>?Nl>Ool00`00Oomoo`01Ool0011oo`03001oo`0000=oo`03001oogoo00Yoo`hmkbAo
o`YnL`UmS003001mS7f<00MmS2YnL`=oo`hmk`ioo`03001oogoo005oo`004Goo00<007ooOol00Woo
00<007ooOol02Woo3Sg_97oo2Wic4gf<:Wic0goo3Sg_3Woo00<007ooOol00Goo000FOol00`00Oomo
o`0:Ool>?NlTOol;OW<AOH`2OW<2OolWOW<3Ool>?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo
00Yoo`hmkb=oo`anLa1mS0InL`9oobAnL`=oo`hmk`ioo`03001oogoo005oo`005Woo00<007ooOol0
2Woo3Sg_8goo3Gic3gf<2Gic0Woo8Gic0goo3Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:
Ool??NlROol=OW<>OH`:OW<5OolNOW<3Ool>?Nl=Ool20003Ool001Ioo`03001oogoo00Yoo`lmkb5o
oa1nL`]mS0]nL`Qooa]nL`=oo`hmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo3cg_8Goo
4Gic27f<3Gic2goo5gic17oo3Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool??NlQOolE
OW<2OH`>OW<?OolDOW<4Ool>?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yoo`lmkb1oobIn
La9ooa5nL`=oo`lmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo43g_7goo9Wic5Goo3Wic
0goo3cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:Ool@?NlOOolUOW<IOol;OW<3Ool??Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa0mkaioobInLaaoo`MnL`Aoo`lmk`eoo`8000=o
o`005Woo00<007ooOol02Woo4Cg_7Goo9Wic7goo17ic17oo3cg_3Woo00<007ooOol00Goo000FOol0
0`00Oomoo`0:OolA?NlMOolUOW<WOol@?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa4m
kaaoobInLbMooa0mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo4Cg_77oo9Wic9goo43g_
3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolA?NlLOolUOW<WOolA?Nl>Ool00`00Oomoo`01
Ool001Ioo`03001oogoo00Yooa8mkaYoobInLbMooa4mk`ioo`03001oogoo005oo`005Woo00<007oo
Ool02Woo4Sg_6Woo9Wic9Woo4Sg_3Goo0P000goo000FOol00`00Oomoo`0:OolC?NlIOolUOW<WOolB
?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooa@mkaMoobInLbMooa8mk`ioo`03001oogoo
005oo`005Woo00<007ooOol02Woo53g_5goo9Wic9Woo4cg_3Woo00<007ooOol00Goo000FOol00`00
Oomoo`0:OolE?NlFOolUOW<WOolC?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaDmkaEo
obInLbIooa@mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo5Sg_57oo9Wic9Woo53g_3Woo
00<007ooOol00Goo000FOol00`00Oomoo`0:OolF?NlDOolUOW<VOolE?Nl=Ool20003Ool001Ioo`03
001oogoo00YooaHmka=oobInLbEooaHmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo5cg_
4Woo9Wic9Goo5Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolH?NlAOolUOW<UOolG?Nl>
Ool00`00Oomoo`01Ool001Ioo`03001oogoo00YooaTmk`moobInLbAooaPmk`ioo`03001oogoo005o
o`001Woo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02Woo6Cg_3goo9Wic8goo
6Cg_3Woo00<007ooOol00Goo0006Ool00`00Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`0:OolJ
?Nl>Ool<OW<9OH`@OW<TOolI?Nl>Ool00`00Oomoo`01Ool000Moo`03001oogoo00Qoo`04001oogoo
Ool2000;OolK?Nl<Ool<OW<;OH`?OW<TOolI?Nl=Ool20003Ool000Moo`03001oogoo00Ioo`8000Ao
o`03001oogoo00Yooa`mk`]oo`]nL`MmS0<000=mS0inLb=ooaXmk`ioo`03001oogoo005oo`001Woo
00<007oo00001goo00<007ooOol00goo00<007ooOol02Woo7Cg_2Woo2gic17f<1P000gf<3Gic8goo
6cg_3Woo00<007ooOol00Goo0007Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`0:OolM?Nl9Ool<
OW<4OH`60003OH`=OW<ROolL?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00Yooahmk`Qoo`an
L`AmS0L0009mS0enLb5ooadmk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo7cg_1goo37ic
1Gf<1P000Wf<37ic8Goo7Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0:OolQ?Nl4Ool=OW<5
OH`60002OH`<OW<OOolP?Nl=Ool20003Ool001Ioo`03001oogoo00Yoob8mk`Eoo`]nL`EmS0H0009m
S0anLaioob4mk`ioo`03001oogoo005oo`005Woo00<007ooOol02Woo8cg_1Woo2Wic17f<1P0000=m
S7icOW<02Wic7Woo8Sg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0;OolS?Nl6Ool9OW<4OH`6
000=OW<MOolS?Nl>Ool00`00Oomoo`01Ool001Ioo`03001oogoo00]oob@mk`Ioo`YnL`9mS0L000an
La]oobDmk`ioo`03001oogoo005oo`005Woo00<007ooOol02goo9Sg_1Woo2Gic0Wf<1P002gic6Woo
9cg_3Woo00<007ooOol00Goo000FOol00`00Oomoo`0;OolX?Nl6Ool9OW<6000;OW<IOolX?Nl>Ool0
0`00Oomoo`01Ool001Ioo`03001oogoo00]oobTmk`Moo`MnL`H000]nLaQoobTmk`eoo`8000=oo`00
5Woo00<007ooOol037oo:3g_2goo0gic1P002Wic6Goo:Cg_3Woo00<007ooOol00Goo000FOol00`00
Oomoo`0<OolX?Nl=Ool00gic000000050009OW<IOolX?Nl?Ool00`00Oomoo`01Ool001Ioo`03001o
ogoo00aoobPmk`moo`H000UnLaUoobPmk`moo`03001oogoo005oo`005Woo00<007ooOol03Goo9cg_
3goo1P0000=oogicOW<01Gic6Woo9cg_47oo00<007ooOol00Goo000FOol00`00Oomoo`0=OolW?Nl?
Ool6000ROolW?Nl@Ool00`00Oomoo`01Ool001Ioo`03001oogoo00ioobHmk`moo`H0029oobLmka1o
o`03001oogoo005oo`005Woo00<007ooOol03Woo9Sg_3goo1P001Woo00<007ooOol06Goo9Sg_47oo
0P000goo000FOol00`00Oomoo`0>OolV?Nl?Ool70004Ool3000JOolU?NlBOol00`00Oomoo`01Ool0
01Ioo`03001oogoo00moobDmka1oo`H000Eoo`03001oogoo01Uoob@mka=oo`03001oogoo005oo`00
5Woo00<007ooOol047oo93g_47oo1P001Goo00<007ooOol06Goo93g_4goo00<007ooOol00Goo000F
Ool00`00Oomoo`0AOolS?Nl@Ool60005Ool00`00Oomoo`0IOolS?NlDOol00`00Oomoo`01Ool001Io
o`03001oogoo019oob8mka1oo`H000Eoo`03001oogoo01Uoob8mkaEoo`03001oogoo005oo`005Woo
00<007ooOol04goo8Cg_47oo1P001Goo00<007ooOol06Goo8Cg_5Woo00<007ooOol00Goo000FOol0
0`00Oomoo`0DOolP?Nl@Ool70004Ool00`00Oomoo`0IOolP?NlFOol20003Ool001Ioo`03001oogoo
01Eooalmka5oo`H000Aoo`03001oogoo01UooalmkaQoo`03001oogoo005oo`005Woo00<007ooOol0
5Woo7Sg_4Goo1P0017oo00<007ooOol06Goo7Sg_6Goo00<007ooOol00Goo000FOol00`00Oomoo`0H
OolL?NlAOol60004Ool00`00Oomoo`0IOolM?NlJOol00`00Oomoo`01Ool001Ioo`03001oogoo01Yo
oaXmka5oo`H000Aoo`03001oogoo01UooaXmkaeoo`03001oogoo005oo`004Goo00<007ooOol00Woo
00<007ooOol06goo6Cg_4Goo1`000goo00<007ooOol06Goo63g_7goo00<007ooOol00Goo000@Ool0
0`00Ool00003Ool00`00Oomoo`0MOolG?NlBOol60003Ool00`00Oomoo`0IOolE?NlROol00`00Oomo
o`01Ool0019oo`04001oogooOol2000SOolB?NlBOol60003Ool00`00Oomoo`0IOolB?NlTOol20003
Ool0011oo`8000Aoo`03001oogoo02Ioo`hmka9oo`H000=oo`03001oogoo01Uoo`hmkbUoo`03001o
ogoo005oo`0047oo00<007ooOol00goo00<007ooOol09Woo3Sg_4Woo1P000goo00<007ooOol06Goo
3Sg_:Goo00<007ooOol00Goo000@Ool30003Ool00`00Oomoo`0VOol>?NlBOol60003Ool00`00Oomo
o`0IOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka9oo`L0009oo`03001oogoo
01Uoo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_4goo1P000Woo00<007ooOol0
6Goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlCOol60002Ool00`00Oomoo`0I
Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka=oo`H0009oo`03001oogoo01Uo
o`hmkbQoo`8000=oo`005Woo00<007ooOol09Woo3Sg_4goo1P000Woo00<007ooOol06Goo3Sg_:Goo
00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?NlCOol60002Ool00`00Oomoo`0IOol>?NlYOol0
0`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmka=oo`L00003Ool007oo01Yoo`hmkbUoo`03001o
ogoo005oo`005Woo00<007ooOol09Woo3Sg_57oo1P0000=oo`00Ool06Woo3Sg_:Goo00<007ooOol0
0Goo000FOol00`00Oomoo`0VOol>?NlDOol600000goo001oo`0JOol>?NlYOol00`00Oomoo`01Ool0
01Ioo`03001oogoo02Ioo`hmkaAoo`H00003Ool007oo01Yoo`hmkbUoo`03001oogoo005oo`005Woo
00<007ooOol09Woo3Sg_57oo1P0000=oo`00Ool06Woo3Sg_:7oo0P000goo000FOol00`00Oomoo`0V
Ool>?NlDOol8000KOol>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmkaEoo`L001]o
o`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_5Goo1`006goo3Sg_:Goo00<007oo
Ool00Goo000FOol00`00Oomoo`0VOol>?Nl2OolCF]l6000IF]l3Ool>?NlYOol00`00Oomoo`01Ool0
01Ioo`03001oogoo02Ioo`hmk`9ooa=Jg`H001UJg`=oo`hmkbUoo`03001oogoo005oo`005Woo00<0
07ooOol09Woo3Sg_0Woo4e[O1P006E[O0goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0V
Ool>?Nl2OolCF]l7000HF]l3Ool>?NlXOol20003Ool001Ioo`03001oogoo02Ioo`hmk`9ooaAJg`H0
01QJg`=oo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_0Woo55[O1P0065[O0goo
3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl2OolDF]l6000HF]l3Ool>?NlYOol0
0`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`9ooaAJg`H001QJg`=oo`hmkbUoo`03001oogoo
005oo`005Woo00<007ooOol09Woo3Sg_0Woo55[O1P0065[O0goo3Sg_:Goo00<007ooOol00Goo000F
Ool00`00Oomoo`0VOol>?Nl2OolDF]l7000GF]l3Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001o
ogoo02Ioo`hmk`9ooaEJg`H001MJg`=oo`hmkbQoo`8000=oo`005Woo00<007ooOol09Woo3Sg_0Woo
5E[O1P005e[O0goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl2OolEF]l6000G
F]l3Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`9ooaEJg`H001MJg`=oo`hm
kbUoo`03001oogoo005oo`001goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol09Woo3Sg_0Woo5E[O1`005U[O0goo3Sg_:Goo00<007ooOol00Goo0007Ool00`00Oomoo`06
Ool00`00Ool00003Ool00`00Oomoo`0VOol>?Nl2OolFF]l6000FF]l3Ool>?NlYOol00`00Oomoo`01
Ool000Moo`03001oogoo00Qoo`04001oogooOol2000WOol>?Nl2OolFF]l600000dioF]mJg`0CF]l3
Ool>?NlXOol20003Ool000Qoo`03001oogoo00Eoo`8000Aoo`03001oogoo02Ioo`hmk`9ooaEJg`03
CWl0000000@0009>OaAJg`=oo`hmkbUoo`03001oogoo005oo`001Woo00<007oo00001goo00<007oo
Ool00goo00<007ooOol09Woo3Sg_0Woo55[O0Tio1P000dio4e[O0goo3Sg_:Goo00<007ooOol00Goo
0006Ool30007Ool30003Ool00`00Oomoo`0VOol>?Nl2OolDF]l2CWl60003CWlCF]l3Ool>?NlYOol0
0`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`9ooaAJg`9>O`L0009>Oa=Jg`=oo`hmkbUoo`03
001oogoo005oo`005Woo00<007ooOol09Woo3Sg_0Woo55[O0dio1P000Tio4e[O0goo3Sg_:Goo00<0
07ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl2OolDF]l3CWl600000dioF]mJg`0BF]l3Ool>?NlY
Ool00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`9ooaEJg`9>O`<000A>OaAJg`=oo`hmkbQo
o`8000=oo`005Woo00<007ooOol09Woo3Sg_0Woo5E[O14io00@004ioCWm>OaEJg`=oo`hmkbUoo`03
001oogoo005oo`005Woo00<007ooOol09Woo3Sg_0Woo5e[O0Tio00<004ioF]l05U[O0goo3Sg_:Goo
00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol0
0`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03
001oogoo005oo`005Woo00<007ooOol09Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<0
07ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00
Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbQoo`8000=o
o`005Woo00<007ooOol09Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo
000FOol00`00Oomoo`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool0
01Ioo`03001oogoo02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`00
5Woo00<007ooOol09Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo000F
Ool00`00Oomoo`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool001Io
o`03001oogoo02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`005Woo
00<007ooOol09Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:7oo0P000goo000FOol00`00Oomo
o`0VOol>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo
02Ioo`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol0
9Woo3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0V
Ool>?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Io
o`hmk`9ooaUJg`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo
3Sg_0Woo6E[O00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>
?Nl2OolIF]l00`00F]mJg`0FF]l3Ool>?NlXOol20003Ool001Ioo`03001oogoo02Ioo`hmk`9ooaUJ
g`03001Jge[O01IJg`=oo`hmkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo3Sg_0Woo6E[O
00<005[OF]l05U[O0goo3Sg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOol>?Nl2OolIF]l0
0`00F]mJg`0FF]l3Ool>?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Ioo`hmk`9ooaQJg`<0
01MJg`=oo`hmkbUoo`03001oogoo005oo`002Woo1@000Woo00<007ooOol00Woo00<007ooOol09Woo
3Sg_6goo00<007ooOol06Goo3Sg_:Goo00<007ooOol00Goo000<Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo02Ioo`hmkcMoo`hmkbUoo`03001oogoo005oo`0037oo00L007ooOomoo`00Ool00003
Ool2000WOol>?NlgOol>?NlXOol20003Ool000aoo`07001oogooOol007oo00000goo00<007ooOol0
9WooDcg_:Goo00<007ooOol00Goo000<Ool01`00Oomoogoo001oo`0000=oo`03001oogoo02Iooe<m
kbUoo`03001oogoo005oo`002goo0P0017oo00<007ooOol00Woo00<007ooOol09WooDcg_:Goo00<0
07ooOol00Goo000FOol00`00Oomoo`0VOomC?NlYOol00`00Oomoo`01Ool001Ioo`03001oogoo02Io
oe<mkbUoo`03001oogoo005oo`005Woo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000FOol0
0`00Oomoo`0VOomC?NlXOol20003Ool001Ioo`03001oogoo02Iooe<mkbUoo`03001oogoo005oo`00
5Woo00<007ooOol09WooDcg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOomC?NlYOol00`00
Oomoo`01Ool001Ioo`03001oogoo02Iooe<mkbUoo`03001oogoo005oo`005Woo00<007ooOol09Woo
Dcg_:Goo00<007ooOol00Goo000FOol00`00Oomoo`0VOomC?NlYOol00`00Oomoo`01Ool001Ioo`03
001oogoo02Iooe<mkbQoo`8000=oo`005Woo00<007ooOol0XWoo00<007ooOol00Goo000FOol00`00
Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo0:9oo`03001oogoo005oo`005Woo00<007oo
Ool0XWoo00<007ooOol00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo
0:9oo`03001oogoo005oo`005Woo00<007ooOol0XGoo0P000goo000FOol00`00Oomoo`2ROol00`00
Oomoo`01Ool001Ioo`03001oogoo0:9oo`03001oogoo005oo`005Woo00<007ooOol0XWoo00<007oo
Ool00Goo000FOol00`00Oomoo`2ROol00`00Oomoo`01Ool001Ioo`03001oogoo01Qoo`03001oogoo
01Uoo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo01Qoo`03001oogoo01Uoo`03001oogoo
005oo`005WooYP000goo002oOol00;moo`00_goo002oOol00;moo`00_goo002oOol00;moo`00_goo
002oOol00001\
\>"],
  ImageRangeCache->{{{0, 190}, {286, 0}} -> {-7.60082, -8.01978, 0.0725381, 
  0.0725381}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package so that ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may be loaded."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following code generates the graphics in this section. These ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands are defined in Chapter 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
p1=Graphics[{
  {RGBColor[.5,.5,.5],
  Polygon[{{-5,-5},{-5,3},{-3,3},{-3,11},
           {3,11},{3,3},{5,3},{5,-5}}],
  Disk[{-3,3},2],Disk[{3,3},2]},
  {RGBColor[1,1,1],Disk[{0,0},4],
  Rectangle[{-2,0},{2,10}]},
  {PointSize[.025],Thickness[.01],
  Line[{{0,4},{0,9}}],
  Point[{0, 0}],Point[{0, 4}],Point[{0,9}]}},
    AspectRatio->Automatic,PlotRange->{{-6,6},{-6,12}},
    Frame->True];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t1=Graphics[\n  {Text[\"{0,0}\", {0,0},{0,-1.7}],\n   Text[\"P1\"   , \
{0,0},{1.7, 1}],\n   Text[\"{0,4}\", {0,4},{0, 1.7}],\n   Text[\"P2\"   , \
{0,4},{1.7,-1}],\n   Text[\"{0,9}\", {0,9},{0,-1.7}],\n   Text[\"P3\"   , \
{0,9},{1.7, 1}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g1=Show[{p1,t1},Frame->True];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p2=Graphics[{\n  {RGBColor[1,.6,.6],\n   Disk[{0,0},3.75,{\[Pi]/2,3 \
\[Pi]/2}+Th2],\n   Disk[{0,0},3.75,{-.35,.35   }+Th2],\n   \
Facet[crankshaft,{{0,-1.3},{3.55,-1.3},{3.55,1.3},{0,1.3}}]},\n  \
{RGBColor[1,.4,.4],Disk[{0,0},.7],\n   Disk[Location[crankshaft,{3,0}],.5]},\n\
  {PointSize[.025],\n  Point[{0, 0}],Vertex[crankshaft,{{3, 0}}]}},\n    \
AspectRatio->Automatic,PlotRange->{{-6,6},{-6,6}}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t2=Graphics[{Text[\"{0,0}\", {0, 0},{0, 1.7}],\n             Text[\"P1\"   , \
{0, 0},{0,-1.7}],\n             Text[\"{3,0}\", {3, 0},{0, 1.7}],\n           \
  Text[\"P2\"   , {3, 0},{0,-1.7}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{p2,t2}/.LastSolve[],Frame->True];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p3=Graphics[{\n  {RGBColor[.7,.7,1],\n  Box[piston,{{-1.8,2.5},{1.8,6}}]},\n \
 {RGBColor[.6,.6,1],\n   Disk[Location[piston,{0,4}],.4]},\n  \
{PointSize[.025],Thickness[.01],\n  Edge[piston,{{0,4},{0,6}}],\n  \
Vertex[piston,{{0,4},{0,6}}]}},\n    \
AspectRatio->Automatic,PlotRange->{{-6,6},{0,9}}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t3=Graphics[{Text[\"{0,4}\", {0, 4},{0  , 1.7}],\n             Text[\"P1\"   \
, {0, 4},{1.7,-1.0}],\n             Text[\"{0,6}\", {0, 6},{0  ,-1.7}],\n     \
        Text[\"P2\"   , {0, 6},{1.7, 1.0}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{p3,t3}/.LastSolve[],Frame->True];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p4=Graphics[{Thickness[.04],\n  \
Line[{Location[crankshaft,{3,0}],Location[piston,{0,4}]}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{p1, p2, p3, p4}/.LastSolve[], Frame->True];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"g2=Show[{p2,t2}/.LastSolve[],Frame->True,\n  PlotRange->{{-6,6},{-6,12}}];"],
   "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"g3=Show[{p3,t3}/.LastSolve[],Frame->True,\n  PlotRange->{{-6,6},{-6,12}}];"],
   "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[GraphicsArray[{g1,g2,g3}, GraphicsSpacing->0]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["1.3  Basic 3D Model"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "In this section the basic functionality of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is demonstrated by building a kinematic model of a very simple mechanism. \
The mechanism is a slider-crank mechanism with two moving bodies, the \
crankshaft and the piston, identical to the mechanism that was modeled with ",
  
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in Section 1.2. Even though it is simply a planar mechanism, the \
slider-crank is modeled with ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to demonstrate the parallelism between ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Mechanism Function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package must be loaded before calling any ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions. Note that the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package must first be unloaded with ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " if it was installed as a result of running the model in Section 1.2. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the 3D slider-crank model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!   
%%Creator: Mathematica   
%%AspectRatio: 1.35323    
MathPictureStart   
%% Graphics3D   
/Courier findfont 10  scalefont  setfont   
% Scaling calculations   
-0.16802 1.37431 0.0343577 1.37431 [   
[ 0 0 0 0 ]   
[ 1 1.35323 0 0 ]   
] MathScale   
% Start of Graphics   
1 setlinecap   
1 setlinejoin   
newpath   
[ ] 0 setdash   
0 g   
0 0 m   
1 0 L   
1 1.35323 L   
0 1.35323 L   
closepath   
clip   
newpath   
p   
.002 w   
.28194 .30732 m   
.06691 .13043 L   
s   
.06691 .13043 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
.26714 1.31887 m   
.28194 .30732 L   
s   
.93788 .23453 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.28194 .30732 m   
.06691 .13043 L   
s   
.06691 .13043 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.93788 .23453 m   
.28194 .30732 L   
s   
.26714 1.31887 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
P   
p   
.002 w   
.30689 .78334 m .31255 .33798 L .26949 .30272 L p   
.988 .782 .537 r   
F P   
s   
P   
p   
.002 w   
.31255 .33798 m .86808 .27803 L .83999 .2391 L p   
.538 .814 .997 r   
F P   
s   
P   
p   
.002 w   
.83999 .2391 m .26949 .30272 L .31255 .33798 L p   
.538 .814 .997 r   
F P   
s   
P   
p   
.002 w   
.47334 .40539 m .39314 .49448 L .35171 .46326 L p   
.869 .917 .858 r   
F P   
s   
P   
p   
.002 w   
.39314 .49448 m .3631 .60901 L .32059 .5811 L p   
.973 .858 .667 r   
F P   
s   
P   
p   
.002 w   
.32059 .5811 m .35171 .46326 L .39314 .49448 L p   
.973 .858 .667 r   
F P   
s   
P   
p   
.002 w   
.58376 .36434 m .47334 .40539 L .43422 .37143 L p   
.678 .883 .974 r   
F P   
s   
P   
p   
.002 w   
.35171 .46326 m .43422 .37143 L .47334 .40539 L p   
.869 .917 .858 r   
F P   
s   
P   
p   
.002 w   
.48699 .4281 m .41659 .50624 L .39646 .49099 L p   
.87 .92 .858 r   
F P   
s   
P   
p   
.002 w   
.41659 .50624 m .39032 .60674 L .36973 .59293 L p   
.974 .86 .664 r   
F P   
s   
P   
p   
.002 w   
.36973 .59293 m .39646 .49099 L .41659 .50624 L p   
.974 .86 .664 r   
F P   
s   
P   
p   
.002 w   
.3631 .60901 m .39141 .72022 L .34934 .69542 L p   
.972 .659 .331 r   
F P   
s   
P   
p   
.002 w   
.34934 .69542 m .32059 .5811 L .3631 .60901 L p   
.972 .659 .331 r   
F P   
s   
P   
p   
.002 w   
.58387 .39228 m .48699 .4281 L .46787 .41166 L p   
.675 .885 .975 r   
F P   
s   
P   
p   
.002 w   
.39646 .49099 m .46787 .41166 L .48699 .4281 L p   
.87 .92 .858 r   
F P   
s   
P   
p   
.002 w   
.39032 .60674 m .41535 .70416 L .39496 .69169 L p   
.971 .656 .321 r   
F P   
s   
P   
p   
.002 w   
.39496 .69169 m .36973 .59293 L .39032 .60674 L p   
.971 .656 .321 r   
F P   
s   
P   
p   
.002 w   
.33872 .86181 m .30689 .78334 L .26244 .76055 L p   
.942 .575 .24 r   
F P   
s   
P   
p   
.002 w   
.26949 .30272 m .26244 .76055 L .30689 .78334 L p   
.988 .782 .537 r   
F P   
s   
P   
p   
.002 w   
.69662 .38297 m .58376 .36434 L .54767 .32886 L p   
.305 .686 .977 r   
F P   
s   
P   
p   
.002 w   
.43422 .37143 m .54767 .32886 L .58376 .36434 L p   
.678 .883 .974 r   
F P   
s   
P   
p   
.002 w   
.26949 .30272 m .54757 .27171 L .54767 .32886 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .43422 .37143 L .26949 .30272 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.43422 .37143 m .35171 .46326 L .26949 .30272 L closepath p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.26513 .58587 m .26949 .30272 L .35171 .46326 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.46787 .41166 m .56607 .37519 L .58387 .39228 L p   
.675 .885 .975 r   
F P   
s   
P   
p   
.002 w   
.58436 .51637 m .58387 .39228 L .56607 .37519 L p   
.998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.43002 1.17733 m .43211 .77639 L .47223 .79908 L p   
.996 .786 .504 r   
F P   
s   
P   
p   
.002 w   
.42625 .75422 m .47223 .79908 L .43211 .77639 L p   
.663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.48631 .77297 m .46677 .7614 L p   
.46549 .75998 L .65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.41535 .70416 m .48457 .77128 L p   
.46549 .75998 L .65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.48457 .77128 m .48631 .77297 L p   
.46549 .75998 L .65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.46677 .7614 m .39496 .69169 L .41535 .70416 L p   
.65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.39646 .49099 m .46787 .41166 L p   
.55941 .75318 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.58496 .66548 m .56686 .65225 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.58535 .76445 m .58496 .66548 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.57476 .75758 m .56888 .75377 L .49396 .76311 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.49369 .94097 m .58606 .94201 L .58547 .79378 L p   
.72 .551 .66 r   
F P   
s   
P   
p   
.002 w   
.58547 .79378 m .58535 .76445 L p   
.57193 .79029 L .72 .551 .66 r   
F P   
s   
P   
p   
.002 w   
.48631 .77297 m .51886 .7798 L p   
.50754 .77545 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.49396 .76311 m .47612 .75893 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.47619 .73446 m .46743 .75953 L .39496 .69169 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.46677 .7614 m .46501 .75969 L p   
.46743 .75953 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.46501 .75969 m .39496 .69169 L p   
.46743 .75953 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.47611 .76336 m .46677 .7614 L p   
.47619 .73446 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.45558 .75411 m .47612 .75893 L p   
.4467 .74885 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.47612 .75893 m .49396 .76311 L p   
.47935 .7587 L .412 .806 .987 r   
F P   
s   
P   
p   
.47612 .75893 m .47611 .76336 L .49162 .76932 L .896 .697 .625 r   
F   
P   
p   
.002 w   
.56686 .65225 m .56715 .75265 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.59117 .75099 m .47935 .7587 L .49396 .76311 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.58535 .76445 m .49396 .76311 L .49395 .77022 L p   
.72 .551 .66 r   
F P   
s   
P   
p   
.58535 .76445 m .49395 .77022 L .57193 .79029 L .72 .551 .66 r   
F   
P   
p   
.002 w   
.47221 .76462 m .48631 .77297 L p   
.51982 .77688 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.47223 .79908 m .47114 1.1883 L .43002 1.17733 L p   
.996 .786 .504 r   
F P   
s   
P   
p   
.002 w   
.43131 .9297 m .49369 .94097 L .49395 .77022 L p   
.896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.49395 .77022 m .49396 .76311 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.56724 .78241 m .47221 .76462 L .51982 .77688 L .096 .599 .897 r   
F   
P   
p   
.49162 .76932 m .43131 .9297 L .49395 .77022 L .896 .697 .625 r   
F   
P   
p   
.002 w   
.46677 .7614 m .47221 .76462 L p   
.48621 .76724 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.56724 .78241 m .47611 .76336 L p   
.48621 .76724 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.47611 .76336 m .46677 .7614 L p   
.48621 .76724 L .096 .599 .897 r   
F P   
s   
P   
p   
.51982 .77688 m .50754 .77545 L .58547 .79378 L .096 .599 .897 r   
F   
P   
p   
.002 w   
.51886 .7798 m .58547 .79378 L p   
.50754 .77545 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.49395 .77022 m .49369 .94097 L p   
.57193 .79029 L .72 .551 .66 r   
F P   
s   
P   
p   
.002 w   
.49396 .76311 m .58535 .76445 L .65672 .75196 L p   
.412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.56724 .78241 m .47611 .76336 L p   
.47612 .75893 L .631 .478 .656 r   
F P   
s   
P   
p   
.51726 .75609 m .47612 .75893 L .47619 .73446 L .631 .478 .656 r   
F   
P   
p   
.56724 .78241 m .47612 .75893 L .51726 .75609 L .631 .478 .656 r   
F   
P   
p   
.55047 .7538 m .39646 .49099 L .55941 .75318 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.36973 .59293 m .39646 .49099 L p   
.55047 .7538 L .631 .478 .656 r   
F P   
s   
P   
p   
.56724 .78241 m .53829 .75464 L .55047 .7538 L .631 .478 .656 r   
F   
P   
p   
.53829 .75464 m .36973 .59293 L .55047 .7538 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.46787 .41166 m .56607 .37519 L .56715 .75265 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.56715 .75265 m .56724 .78241 L p   
.55941 .75318 L .631 .478 .656 r   
F P   
s   
P   
p   
.55941 .75318 m .46787 .41166 L .56715 .75265 L .631 .478 .656 r   
F   
P   
p   
.63952 .74765 m .6289 .73775 L .61212 .73892 L .412 .806 .987 r   
F   
P   
p   
.61642 .74187 m .61212 .73892 L .60628 .73933 L .412 .806 .987 r   
F   
P   
p   
.63952 .74765 m .61212 .73892 L .61642 .74187 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.58496 .66548 m .77243 .65113 L .75693 .63745 L p   
.446 .812 .995 r   
F P   
s   
P   
p   
.002 w   
.75693 .63745 m .56686 .65225 L .58496 .66548 L p   
.446 .812 .995 r   
F P   
s   
P   
p   
.002 w   
.56607 .37519 m .56643 .50101 L .58436 .51637 L p   
.998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.77011 .49971 m .58436 .51637 L .56643 .50101 L p   
.49 .816 1 r   
F P   
s   
P   
p   
.002 w   
.75693 .63745 m .56686 .65225 L .56643 .50101 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .75693 .63745 L p   
.56643 .50101 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.71996 .5425 m .71161 .56403 L .72047 .58416 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.74065 .53209 m .71996 .5425 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.61212 .73892 m .71526 .59005 L p   
.58812 .7406 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.72047 .58416 m .71161 .56403 L .69861 .55216 L p   
.875 .481 .018 r   
F P   
s   
P   
p   
.72047 .58416 m .71113 .57049 L .70402 .56448 L .875 .481 .018 r   
F   
P   
p   
.71113 .57049 m .69861 .55216 L .7037 .56375 L .875 .481 .018 r   
F   
P   
p   
.71113 .57049 m .7037 .56375 L .70402 .56448 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.39496 .69169 m .36973 .59293 L p   
.56724 .78241 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.56643 .50101 m .75472 .48385 L .77011 .49971 L p   
.49 .816 1 r   
F P   
s   
P   
p   
.002 w   
.56643 .50101 m .75472 .48385 L .77063 .55904 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.71161 .56403 m .71996 .5425 L .70707 .53037 L p   
.97 .914 .696 r   
F P   
s   
P   
p   
.002 w   
.70707 .53037 m .68661 .51112 L p   
.70194 .54357 L .97 .914 .696 r   
F P   
s   
P   
p   
.71161 .56403 m .70707 .53037 L .70194 .54357 L .97 .914 .696 r   
F   
P   
p   
.002 w   
.68661 .51112 m .67798 .53331 L .69147 .54564 L p   
.97 .914 .696 r   
F P   
s   
P   
p   
.002 w   
.69147 .54564 m .71161 .56403 L p   
.69664 .53235 L .97 .914 .696 r   
F P   
s   
P   
p   
.69664 .53235 m .68661 .51112 L .69147 .54564 L .97 .914 .696 r   
F   
P   
p   
.002 w   
.68184 .59531 m .58085 .74111 L p   
.66224 .64579 L .63 .477 .655 r   
F P   
s   
P   
p   
.58589 .74446 m .57773 .74133 L .56484 .74223 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.76164 .53891 m .74065 .53209 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.70755 .5725 m .72047 .58416 L p   
.70402 .56448 L .875 .481 .018 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .76164 .53891 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.76226 .5807 m .77063 .55904 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.72047 .58416 m .74144 .5911 L .76226 .5807 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.74144 .5911 m .72047 .58416 L .70755 .5725 L p   
.06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.73861 .55634 m .71816 .54289 L .69949 .56984 L p   
.63 .477 .655 r   
F P   
s   
P   
p   
.72883 .5825 m .70755 .5725 L .72039 .57674 L .06 .538 .893 r   
F   
P   
p   
.74144 .5911 m .73347 .58672 L .72883 .5825 L .06 .538 .893 r   
F   
P   
p   
.73347 .58672 m .70755 .5725 L .72883 .5825 L .06 .538 .893 r   
F   
P   
p   
.73861 .55634 m .69949 .56984 L .71263 .57418 L .63 .477 .655 r   
F   
P   
p   
.73861 .55634 m .72102 .57695 L .72162 .57715 L .63 .477 .655 r   
F   
P   
p   
.73861 .55634 m .71263 .57418 L .71528 .57506 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.72875 .5795 m .74144 .5911 L p   
.72039 .57674 L .06 .538 .893 r   
F P   
s   
P   
p   
.73861 .55634 m .67814 .60484 L .71143 .58817 L .63 .477 .655 r   
F   
P   
p   
.73861 .55634 m .7138 .58672 L .7139 .58694 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.71526 .59005 m .71928 .58425 L p   
.7139 .58694 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.71928 .58425 m .73861 .55634 L p   
.7139 .58694 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.7322 .5656 m .72372 .57784 L p   
.72747 .5647 L .914 .951 .806 r   
F P   
s   
P   
p   
.002 w   
.71816 .54289 m .73861 .55634 L .73171 .54983 L p   
0 .253 .705 r   
F P   
s   
P   
p   
.73171 .54983 m .7322 .5656 L .72747 .5647 L .914 .951 .806 r   
F   
P   
p   
.002 w   
.73171 .54983 m .73861 .55634 L .7322 .5656 L p   
.914 .951 .806 r   
F P   
s   
P   
p   
.73171 .54983 m .72372 .57784 L .71732 .57201 L .914 .951 .806 r   
F   
P   
p   
.6966 .55731 m .67798 .53331 L .69497 .55583 L .875 .481 .018 r   
F   
P   
p   
.70252 .56268 m .69501 .55369 L .6966 .55731 L .875 .481 .018 r   
F   
P   
p   
.69501 .55369 m .67798 .53331 L .6966 .55731 L .875 .481 .018 r   
F   
P   
p   
.57773 .74133 m .50907 .71499 L .56484 .74223 L .412 .806 .987 r   
F   
P   
p   
.56665 .73165 m .50907 .71499 L .58589 .74446 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.6966 .55731 m .57294 .73584 L p   
.70312 .56323 L .914 .949 .807 r   
F P   
s   
P   
p   
.59117 .75099 m .51477 .73994 L .43226 .74863 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.43685 .72866 m .43293 .7457 L p   
.51477 .73994 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.43293 .7457 m .43226 .74863 L p   
.51477 .73994 L .412 .806 .987 r   
F P   
s   
P   
p   
.70312 .56323 m .57294 .73584 L .57467 .73699 L .914 .949 .807 r   
F   
P   
p   
.6976 .55959 m .70046 .56611 L .69506 .56433 L .63 .476 .655 r   
F   
P   
p   
.7138 .58672 m .58085 .74111 L .58812 .7406 L .63 .477 .655 r   
F   
P   
p   
.71366 .58641 m .58085 .74111 L .7138 .58672 L .63 .477 .655 r   
F   
P   
p   
.72102 .57695 m .58085 .74111 L .72162 .57715 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.58085 .74111 m .7037 .56375 L p   
.57483 .7371 L .914 .949 .807 r   
F P   
s   
P   
p   
.70312 .56323 m .57467 .73699 L .7037 .56375 L .914 .949 .807 r   
F   
P   
p   
.62532 .74863 m .53187 .73873 L .59117 .75099 L .412 .806 .987 r   
F   
P   
p   
.53187 .73873 m .43685 .72866 L .51477 .73994 L .412 .806 .987 r   
F   
P   
p   
.53187 .73873 m .51477 .73994 L .59117 .75099 L .412 .806 .987 r   
F   
P   
p   
.57467 .73699 m .57483 .7371 L .7037 .56375 L .914 .949 .807 r   
F   
P   
p   
.7138 .58672 m .58812 .7406 L .71526 .59005 L .63 .477 .655 r   
F   
P   
p   
.66279 .61944 m .59604 .73421 L .67459 .58908 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.57294 .73584 m .67459 .58908 L p   
.59403 .73435 L .63 .476 .655 r   
F P   
s   
P   
p   
.62621 .74857 m .56123 .72805 L .62532 .74863 L .412 .806 .987 r   
F   
P   
p   
.63952 .74765 m .61642 .74187 L .62621 .74857 L .412 .806 .987 r   
F   
P   
p   
.61642 .74187 m .56123 .72805 L .62621 .74857 L .412 .806 .987 r   
F   
P   
p   
.72039 .57674 m .70885 .56887 L .72875 .5795 L .06 .538 .893 r   
F   
P   
p   
.70885 .56887 m .71431 .57068 L .72875 .5795 L .06 .538 .893 r   
F   
P   
p   
.71899 .57354 m .71431 .57068 L .71672 .57147 L .06 .538 .893 r   
F   
P   
p   
.71143 .58817 m .67814 .60484 L .66224 .64579 L .63 .477 .655 r   
F   
P   
p   
.70402 .56448 m .70252 .56268 L .70755 .5725 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.69235 .56344 m .6966 .55731 L p   
.69313 .56369 L .63 .476 .655 r   
F P   
s   
P   
p   
.6976 .55959 m .66279 .61944 L .6966 .55731 L .63 .476 .655 r   
F   
P   
p   
.70252 .56268 m .69497 .55583 L .70755 .5725 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.70046 .56611 m .70755 .5725 L p   
.6992 .56144 L .875 .481 .018 r   
F P   
s   
P   
p   
.002 w   
.70755 .5725 m .70046 .56611 L p   
.72039 .57674 L .06 .538 .893 r   
F P   
s   
P   
p   
.72039 .57674 m .70046 .56611 L .70885 .56887 L .06 .538 .893 r   
F   
P   
p   
.72162 .57715 m .71366 .58641 L .7138 .58672 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.72372 .57784 m .61212 .73892 L p   
.71732 .57201 L .914 .951 .806 r   
F P   
s   
P   
p   
.56123 .72805 m .56665 .73165 L .62532 .74863 L .412 .806 .987 r   
F   
P   
p   
.62532 .74863 m .57951 .73538 L .58589 .74446 L .412 .806 .987 r   
F   
P   
p   
.65672 .75196 m .62532 .74863 L .59117 .75099 L .412 .806 .987 r   
F   
P   
p   
.57193 .79029 m .49369 .94097 L .58547 .79378 L .72 .551 .66 r   
F   
P   
p   
.002 w   
.58547 .79378 m .56724 .78241 L p   
.51982 .77688 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.56724 .78241 m .58547 .79378 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.56715 .75265 m .56724 .78241 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.65672 .75196 m .59117 .75099 L .56888 .75377 L .412 .806 .987 r   
F   
P   
p   
.65672 .75196 m .56888 .75377 L .57476 .75758 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.58547 .79378 m .58535 .76445 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.56724 .78241 m .55047 .7538 L .55941 .75318 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.65672 .75196 m .58535 .76445 L .58606 .94201 L p   
.509 .38 .64 r   
F P   
s   
P   
p   
.002 w   
.56253 .81049 m .60537 .7445 L p   
.54258 .79637 L .63 .477 .655 r   
F P   
s   
P   
p   
.57951 .73538 m .57294 .73584 L .58589 .74446 L .412 .806 .987 r   
F   
P   
p   
.59117 .75099 m .56398 .75059 L .56715 .75265 L .412 .806 .987 r   
F   
P   
p   
.58812 .7406 m .54258 .79637 L .61212 .73892 L .63 .477 .655 r   
F   
P   
p   
.71732 .57201 m .61212 .73892 L .60995 .73743 L .914 .951 .806 r   
F   
P   
p   
.69488 .56427 m .60439 .73362 L .59604 .73421 L .63 .476 .655 r   
F   
P   
p   
.69506 .56433 m .60439 .73362 L .69488 .56427 L .63 .476 .655 r   
F   
P   
p   
.71528 .57506 m .68184 .59531 L .67814 .60484 L .63 .477 .655 r   
F   
P   
p   
.71263 .57418 m .68184 .59531 L .71528 .57506 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.69949 .56984 m .68184 .59531 L p   
.71263 .57418 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.70821 .58376 m .60439 .73362 L p   
.69506 .56433 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.60439 .73362 m .71672 .57147 L p   
.60995 .73743 L .914 .951 .806 r   
F P   
s   
P   
p   
.71732 .57201 m .60995 .73743 L .71672 .57147 L .914 .951 .806 r   
F   
P   
p   
.6289 .73775 m .60611 .71649 L .60628 .73933 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.61212 .73892 m .56253 .81049 L p   
.60995 .73743 L .914 .951 .806 r   
F P   
s   
P   
p   
.59604 .73421 m .59403 .73435 L .67459 .58908 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.60611 .71649 m .54238 .7155 L p   
.60628 .73933 L .412 .806 .987 r   
F P   
s   
P   
p   
.60628 .73933 m .54238 .7155 L .56123 .72805 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.54258 .79637 m .56253 .81049 L .55448 .80567 L p   
.461 0 0 r   
F P   
s   
P   
p   
.59604 .73421 m .55448 .80567 L .59403 .73435 L .63 .476 .655 r   
F   
P   
p   
.56715 .75265 m .4467 .74885 L .47935 .7587 L .412 .806 .987 r   
F   
P   
p   
.56398 .75059 m .4467 .74885 L .56715 .75265 L .412 .806 .987 r   
F   
P   
p   
.57467 .73699 m .53441 .79147 L .57483 .7371 L .914 .949 .807 r   
F   
P   
p   
.56123 .72805 m .50907 .71499 L .56665 .73165 L .412 .806 .987 r   
F   
P   
p   
.6976 .55959 m .69506 .56433 L .69488 .56427 L .63 .476 .655 r   
F   
P   
p   
.70402 .56448 m .70397 .56435 L .70386 .56429 L .875 .481 .018 r   
F   
P   
p   
.70397 .56435 m .69861 .55216 L .70386 .56429 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.69861 .55216 m .67798 .53331 L p   
.70386 .56429 L .875 .481 .018 r   
F P   
s   
P   
p   
.002 w   
.71816 .54289 m .71115 .5363 L p   
.71042 .54806 L .914 .949 .807 r   
F P   
s   
P   
p   
.002 w   
.71115 .5363 m .6966 .55731 L p   
.71042 .54806 L .914 .949 .807 r   
F P   
s   
P   
p   
.71816 .54289 m .6966 .55731 L .70312 .56323 L .914 .949 .807 r   
F   
P   
p   
.002 w   
.71672 .57147 m .73171 .54983 L p   
.71732 .57201 L .914 .951 .806 r   
F P   
s   
P   
p   
.72875 .5795 m .71899 .57354 L .71747 .57172 L .06 .538 .893 r   
F   
P   
p   
.002 w   
.7037 .56375 m .71816 .54289 L p   
.70312 .56323 L .914 .949 .807 r   
F P   
s   
P   
p   
.002 w   
.70791 .50034 m .68661 .51112 L .71996 .5425 L p   
.717 .926 .961 r   
F P   
s   
P   
p   
.002 w   
.71996 .5425 m .74065 .53209 L .70791 .50034 L p   
.717 .926 .961 r   
F P   
s   
P   
p   
.002 w   
.73171 .54983 m .71115 .5363 L .71816 .54289 L p   
0 .253 .705 r   
F P   
s   
P   
p   
.002 w   
.71115 .5363 m .73171 .54983 L .71672 .57147 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.71115 .5363 m .71672 .57147 L .70913 .56897 L .63 .476 .655 r   
F   
P   
p   
.6992 .56144 m .69731 .55894 L .69812 .56078 L .875 .481 .018 r   
F   
P   
p   
.6992 .56144 m .69812 .56078 L .70046 .56611 L .875 .481 .018 r   
F   
P   
p   
.71115 .5363 m .70913 .56897 L .6976 .55959 L .63 .476 .655 r   
F   
P   
p   
.70913 .56897 m .70821 .58376 L .70046 .56611 L .63 .476 .655 r   
F   
P   
p   
.70913 .56897 m .70046 .56611 L .6976 .55959 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.70349 .55941 m .70861 .5611 L p   
.71747 .57172 L .06 .538 .893 r   
F P   
s   
P   
p   
.71899 .57354 m .71672 .57147 L .71747 .57172 L .06 .538 .893 r   
F   
P   
p   
.71672 .57147 m .70349 .55941 L .71747 .57172 L .06 .538 .893 r   
F   
P   
p   
.002 w   
.70861 .5611 m .72179 .57314 L p   
.71747 .57172 L .06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.72179 .57314 m .72875 .5795 L p   
.71747 .57172 L .06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.71672 .57147 m .70821 .58376 L p   
.70913 .56897 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.67798 .53331 m .68705 .55401 L .70046 .56611 L p   
.875 .481 .018 r   
F P   
s   
P   
p   
.69731 .55894 m .67798 .53331 L .70046 .56611 L .875 .481 .018 r   
F   
P   
p   
.70885 .56887 m .68705 .55401 L .71431 .57068 L .06 .538 .893 r   
F   
P   
p   
.002 w   
.6966 .55731 m .71115 .5363 L p   
.6976 .55959 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.68705 .55401 m .70349 .55941 L p   
.71672 .57147 L .06 .538 .893 r   
F P   
s   
P   
p   
.71431 .57068 m .68705 .55401 L .71672 .57147 L .06 .538 .893 r   
F   
P   
p   
.70046 .56611 m .70821 .58376 L .69506 .56433 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.60439 .73362 m .55448 .80567 L p   
.59604 .73421 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.57294 .73584 m .53441 .79147 L p   
.57467 .73699 L .914 .949 .807 r   
F P   
s   
P   
p   
.002 w   
.54238 .7155 m .50907 .71499 L p   
.56123 .72805 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.70861 .5611 m .73004 .55033 L .74981 .56896 L p   
.712 .93 .962 r   
F P   
s   
P   
p   
.002 w   
.74981 .56896 m .76226 .5807 L p   
.74151 .57312 L .712 .93 .962 r   
F P   
s   
P   
p   
.74151 .57312 m .70861 .5611 L .74981 .56896 L .712 .93 .962 r   
F   
P   
p   
.002 w   
.76226 .5807 m .74144 .5911 L .72875 .5795 L p   
.712 .93 .962 r   
F P   
s   
P   
p   
.002 w   
.72875 .5795 m .70861 .5611 L p   
.74151 .57312 L .712 .93 .962 r   
F P   
s   
P   
p   
.76226 .5807 m .72875 .5795 L .74151 .57312 L .712 .93 .962 r   
F   
P   
p   
.002 w   
.70046 .56611 m .68705 .55401 L p   
.70885 .56887 L .06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.67459 .58908 m .69235 .56344 L p   
.66279 .61944 L .63 .476 .655 r   
F P   
s   
P   
p   
.69313 .56369 m .66279 .61944 L .69235 .56344 L .63 .476 .655 r   
F   
P   
p   
.57951 .73538 m .56665 .73165 L .57294 .73584 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.5658 .76284 m .54258 .79637 L p   
.56381 .77037 L .63 .477 .655 r   
F P   
s   
P   
p   
.58812 .7406 m .5658 .76284 L .56381 .77037 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.58085 .74111 m .5658 .76284 L p   
.58812 .7406 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.53441 .79147 m .54258 .79637 L .58085 .74111 L p   
.914 .949 .807 r   
F P   
s   
P   
p   
.57483 .7371 m .53441 .79147 L .58085 .74111 L .914 .949 .807 r   
F   
P   
p   
.002 w   
.55448 .80567 m .53441 .79147 L .54258 .79637 L p   
.461 0 0 r   
F P   
s   
P   
p   
.002 w   
.55448 .80567 m .53441 .79147 L .57294 .73584 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.59403 .73435 m .55448 .80567 L .57294 .73584 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.50907 .71499 m .43685 .72866 L p   
.56484 .74223 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.56253 .81049 m .55448 .80567 L .60439 .73362 L p   
.914 .951 .806 r   
F P   
s   
P   
p   
.60995 .73743 m .56253 .81049 L .60439 .73362 L .914 .951 .806 r   
F   
P   
p   
.65672 .75196 m .64959 .74696 L .63952 .74765 L .412 .806 .987 r   
F   
P   
p   
.64959 .74696 m .60611 .71649 L .63952 .74765 L .412 .806 .987 r   
F   
P   
p   
.65672 .75196 m .63952 .74765 L .62532 .74863 L .412 .806 .987 r   
F   
P   
p   
.4467 .74885 m .47612 .75893 L .47935 .7587 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.47612 .75893 m .44657 .75199 L p   
.47611 .76336 L .896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.43226 .74863 m .43131 .9297 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.44657 .75199 m .43226 .74863 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.43226 .74863 m .45558 .75411 L p   
.4467 .74885 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.43593 .91415 m .43131 .9297 L .43211 .77639 L p   
0 0 .097 r   
F P   
s   
P   
p   
.002 w   
.43211 .77639 m .43226 .74863 L p   
.43294 .77953 L 0 0 .097 r   
F P   
s   
P   
p   
.43294 .77953 m .43593 .91415 L .43211 .77639 L 0 0 .097 r   
F   
P   
p   
.002 w   
.39141 .72022 m .42625 .75422 L p   
.43211 .77639 L .663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.43211 .77639 m .34934 .69542 L .39141 .72022 L p   
.663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.26244 .76055 m .29488 .84123 L .33872 .86181 L p   
.942 .575 .24 r   
F P   
s   
P   
p   
.002 w   
.41591 .89217 m .33872 .86181 L .29488 .84123 L p   
0 .365 .711 r   
F P   
s   
P   
p   
.002 w   
.78191 .45826 m .69662 .38297 L .66354 .34763 L p   
0 .108 .604 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .66354 .34763 L .69662 .38297 L p   
.305 .686 .977 r   
F P   
s   
P   
p   
.002 w   
.29488 .84123 m .37404 .87233 L .41591 .89217 L p   
0 .365 .711 r   
F P   
s   
P   
p   
.002 w   
.4137 1.25092 m .41591 .89217 L .37404 .87233 L p   
.994 .785 .516 r   
F P   
s   
P   
p   
.002 w   
.35171 .46326 m .32059 .5811 L .26513 .58587 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.26244 .76055 m .26513 .58587 L .32059 .5811 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.86808 .27803 m .87814 .74458 L .84953 .71935 L p   
.989 .775 .387 r   
F P   
s   
P   
p   
.002 w   
.84953 .71935 m .83999 .2391 L .86808 .27803 L p   
.989 .775 .387 r   
F P   
s   
P   
p   
.002 w   
.32059 .5811 m .34934 .69542 L .26244 .76055 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.66354 .34763 m .75106 .42481 L .78191 .45826 L p   
0 .108 .604 r   
F P   
s   
P   
p   
.002 w   
.8152 .57142 m .78191 .45826 L .75106 .42481 L p   
.924 .588 .133 r   
F P   
s   
P   
p   
.002 w   
.78587 .57386 m .77011 .49971 L .75472 .48385 L p   
.958 .656 .231 r   
F P   
s   
P   
p   
.002 w   
.83999 .2391 m .54757 .27171 L .54767 .32886 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.29488 .84123 m .26244 .76055 L .34934 .69542 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .66354 .34763 L .83999 .2391 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.77243 .65113 m .78587 .57386 L .77063 .55904 L p   
.996 .864 .566 r   
F P   
s   
P   
p   
.002 w   
.75472 .48385 m .77063 .55904 L .78587 .57386 L p   
.958 .656 .231 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .29488 .84123 L p   
.34934 .69542 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.34934 .69542 m .43211 .77639 L .37404 .87233 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.78566 .69145 m .8152 .57142 L .78508 .54117 L p   
.99 .888 .608 r   
F P   
s   
P   
p   
.002 w   
.75106 .42481 m .78508 .54117 L .8152 .57142 L p   
.924 .588 .133 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .75693 .63745 L .77243 .65113 L p   
.996 .864 .566 r   
F P   
s   
P   
p   
.002 w   
.58606 .94201 m .65821 .93229 L .65672 .75196 L p   
.509 .38 .64 r   
F P   
s   
P   
p   
.002 w   
.49369 .94097 m .58606 .94201 L .65821 .93229 L p   
.339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.70531 1.18107 m .70098 .78411 L .66721 .76047 L p   
.998 .785 .446 r   
F P   
s   
P   
p   
.002 w   
.70098 .78411 m .78566 .69145 L .75447 .66484 L p   
.87 .967 .856 r   
F P   
s   
P   
p   
.002 w   
.75447 .66484 m .66721 .76047 L .70098 .78411 L p   
.87 .967 .856 r   
F P   
s   
P   
p   
.002 w   
.43131 .9297 m .49369 .94097 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .37084 1.24194 L .4137 1.25092 L p   
.994 .785 .516 r   
F P   
s   
P   
p   
.002 w   
.76628 1.24194 m .4137 1.25092 L .37084 1.24194 L p   
.179 .705 .863 r   
F P   
s   
P   
p   
.002 w   
.78508 .54117 m .75447 .66484 L .78566 .69145 L p   
.99 .888 .608 r   
F P   
s   
P   
p   
.002 w   
.47114 1.1883 m .70531 1.18107 L .67084 1.16963 L p   
.215 .725 .888 r   
F P   
s   
P   
p   
.002 w   
.67084 1.16963 m .43002 1.17733 L .47114 1.1883 L p   
.215 .725 .888 r   
F P   
s   
P   
p   
.002 w   
.66696 .73216 m .65672 .75196 L .65821 .93229 L p   
0 0 .229 r   
F P   
s   
P   
p   
.002 w   
.65672 .75196 m .66696 .73216 L .60611 .71649 L p   
.412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.66354 .34763 m .75106 .42481 L .83999 .2391 L closepath p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.72949 .50729 m .70791 .50034 L .74065 .53209 L p   
.091 .554 .908 r   
F P   
s   
P   
p   
.002 w   
.74065 .53209 m .76164 .53891 L .72949 .50729 L p   
.091 .554 .908 r   
F P   
s   
P   
p   
.01 w   
.54808 .56154 m   
.44598 .48049 L   
s   
P   
p   
.01 w   
.69505 .54891 m   
.70288 .54824 L   
s   
P   
p   
.01 w   
.54808 .56154 m   
.68518 .54976 L   
s   
P   
p   
.02 w   
.54808 .56154 Mdot   
P   
p   
.02 w   
.54808 .56154 Mdot   
P   
p   
.002 w   
.43226 .74863 m .43685 .72866 L .43593 .91415 L p   
0 0 .097 r   
F P   
s   
P   
p   
.002 w   
.7387 .528 m .72949 .50729 L .76164 .53891 L p   
.858 .463 0 r   
F P   
s   
P   
p   
.002 w   
.76164 .53891 m .77063 .55904 L .7387 .528 L p   
.858 .463 0 r   
F P   
s   
P   
p   
.002 w   
.43002 1.17733 m .43211 .77639 L .37404 .87233 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .37084 1.24194 L .43002 1.17733 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.73004 .55033 m .7387 .528 L .77063 .55904 L p   
.971 .919 .689 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .76226 .5807 L .73004 .55033 L p   
.971 .919 .689 r   
F P   
s   
P   
p   
.002 w   
.84384 .83119 m .76096 .87233 L .72872 .85124 L p   
.684 .949 .957 r   
F P   
s   
P   
p   
.002 w   
.76096 .87233 m .76628 1.24194 L .73348 1.23237 L p   
.996 .782 .428 r   
F P   
s   
P   
p   
.002 w   
.73348 1.23237 m .72872 .85124 L .76096 .87233 L p   
.996 .782 .428 r   
F P   
s   
P   
p   
.002 w   
.87814 .74458 m .84384 .83119 L .81408 .80867 L p   
.969 .932 .675 r   
F P   
s   
P   
p   
.002 w   
.81408 .80867 m .84953 .71935 L .87814 .74458 L p   
.969 .932 .675 r   
F P   
s   
P   
p   
.002 w   
.43593 .91415 m .43131 .9297 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.50895 .90349 m .43593 .91415 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.60709 .90466 m .50895 .90349 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.65821 .93229 m .6686 .91687 L .66696 .73216 L p   
0 0 .229 r   
F P   
s   
P   
p   
.002 w   
.65821 .93229 m .6686 .91687 L .60709 .90466 L p   
.339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.72872 .85124 m .81408 .80867 L .84384 .83119 L p   
.684 .949 .957 r   
F P   
s   
P   
p   
.002 w   
.84589 .53594 m .83999 .2391 L .75106 .42481 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.75106 .42481 m .78508 .54117 L .84589 .53594 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.01 w   
.5485 .80144 m   
.54868 .90396 L   
s   
P   
p   
.01 w   
.54871 .92335 m   
.54904 1.11028 L   
s   
P   
p   
.002 w   
.66721 .76047 m .67084 1.16963 L .70531 1.18107 L p   
.998 .785 .446 r   
F P   
s   
P   
p   
.002 w   
.84953 .71935 m .84589 .53594 L .78508 .54117 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.78508 .54117 m .75447 .66484 L .84953 .71935 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.60611 .71649 m .66696 .73216 L .6686 .91687 L p   
.909 .704 .613 r   
F P   
s   
P   
p   
.02 w   
.54871 .92335 Mdot   
P   
p   
.002 w   
.75447 .66484 m .66721 .76047 L .72872 .85124 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.67084 1.16963 m .66721 .76047 L .72872 .85124 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.43002 1.17733 m .37084 1.24194 L .73348 1.23237 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.37084 1.24194 m .73348 1.23237 L .76628 1.24194 L p   
.179 .705 .863 r   
F P   
s   
P   
p   
.002 w   
.81408 .80867 m .84953 .71935 L .75447 .66484 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.72872 .85124 m .81408 .80867 L p   
.75447 .66484 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.50895 .90349 m .43593 .91415 L .43685 .72866 L p   
.491 .363 .633 r   
F P   
s   
P   
p   
.002 w   
.43685 .72866 m .50907 .71499 L .50895 .90349 L p   
.491 .363 .633 r   
F P   
s   
P   
p   
.002 w   
.73348 1.23237 m .67084 1.16963 L .43002 1.17733 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.68661 .51112 m .67798 .53331 L .68705 .55401 L p   
.628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.70791 .50034 m .68661 .51112 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.72949 .50729 m .70791 .50034 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.7387 .528 m .72949 .50729 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.73004 .55033 m .7387 .528 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.68705 .55401 m .70861 .5611 L .73004 .55033 L p   
.628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.6686 .91687 m .60709 .90466 L .60611 .71649 L p   
.909 .704 .613 r   
F P   
s   
P   
p   
.02 w   
.54904 1.11028 Mdot   
P   
p   
.002 w   
.72872 .85124 m .73348 1.23237 L .67084 1.16963 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.50907 .71499 m .60611 .71649 L .60709 .90466 L p   
.721 .549 .657 r   
F P   
s   
P   
p   
.002 w   
.60709 .90466 m .50895 .90349 L .50907 .71499 L p   
.721 .549 .657 r   
F P   
s   
P   
p   
.01 w   
.44483 .73888 m   
.50903 .77735 L   
s   
P   
p   
.02 w   
.44598 .48049 Mdot   
P   
p   
.02 w   
.44598 .48049 Mdot   
P   
p   
.02 w   
.44483 .73888 Mdot   
P   
p   
.002 w   
.93788 .23453 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.26714 1.31887 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
P   
p   
P   
% End of Graphics   
MathPictureEnd   
   \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 287},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D00017a000`40O003h00Oe7oo003DOol00=Ao
o`00e7oo003DOol00=Aoo`00e7oo003DOol00:Moo`@002Uoo`00Wgoo20000goo0P00:7oo002GOol8
000;Ool2000XOol008moo`P001=oo`03001oo`0002Moo`00Qgoo20006goo00@007ooOol002Ioo`00
P7oo1`008goo00@007ooOol002Ioo`00N7oo2000:Woo00D007ooOomoo`0002Eoo`00L7oo2000<Woo
00D007ooOomoo`0002Eoo`00J7oo2000>Woo00<007ooOol00Woo00<007ooOol08Woo001POol80012
Ool00`00Oomoo`03Ool00`00Oomoo`0QOol005Uoo`L004Yoo`03001oogoo00=oo`03001oogoo025o
o`00DGoo2000DGoo00<007ooOol017oo00<007ooOol087oo0019Ool8001IOol00`00Oomoo`05Ool0
0`00Oomoo`0OOol0045oo`P0065oo`03001oogoo00Eoo`03001oogoo01moo`00>Goo2000JGoo00<0
07ooOol01Woo00<007ooOol07Woo000bOol7001aOol00`00Oomoo`07Ool00`00Oomoo`0MOol002Yo
o`P007Qoo`03001oogoo00Moo`03001oogoo01eoo`008Woo2000P7oo00<007ooOol027oo00<007oo
Ool077oo000JOol80028Ool00`00Oomoo`09Ool00`00Oomoo`0KOol0019oo`P0091oo`03001oogoo
00Uoo`03001oogoo01]oo`003Woo1000V7oo00<007ooOol02Woo00<007ooOol06Woo000>Ool2002J
Ool00`00Oomoo`0:Ool00`00Oomoo`0JOol000ioo`03001oo`0009Uoo`03001oogoo00]oo`03001o
ogoo01Uoo`003Woo00<007ooOol00P00Ugoo00<007ooOol037oo00<007ooOol067oo000>Ool00`00
Oomoo`02Ool00`00Oomoo`2DOol00`00Oomoo`0<Ool00`00Oomoo`0HOol000ioo`03001oogoo00=o
o`03001oogoo09=oo`03001oogoo00eoo`03001oogoo01Moo`003Woo00<007ooOol017oo00<007oo
Ool0TWoo00<007ooOol03Woo00<007ooOol05Woo000>Ool00`00Oomoo`05Ool00`00Oomoo`2BOol0
0`00Oomoo`0=Ool00`00Oomoo`0FOol000ioo`03001oogoo00Ioo`80099oo`03001oogoo00ioo`03
001oogoo01Eoo`003Woo00<007ooOol027oo00<007ooOol0Sgoo00<007ooOol03goo00<007ooOol0
57oo000>Ool00`00Oomoo`09Ool00`00Oomoo`2>Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol000io
o`03001oogoo00Yoo`03001oogoo08eoo`03001oogoo011oo`03001oogoo01=oo`003Woo00<007oo
Ool02goo00<007ooOol0S7oo00<007ooOol04Goo00<007ooOol04Woo000>Ool00`00Oomoo`0<Ool0
0`00Oomoo`2;Ool00`00Oomoo`0AOol00`00Oomoo`0BOol000ioo`03001oogoo00eoo`8008]oo`03
001oogoo019oo`03001oogoo015oo`003Woo00<007ooOol03goo00<007ooOol0R7oo00<007ooOol0
4Woo00<007ooOol04Goo000>Ool00`00Oomoo`0@Ool00`00Oomoo`27Ool00`00Oomoo`0COol00`00
Oomoo`0@Ool000ioo`03001oogoo015oo`03001oogoo08Ioo`03001oogoo01Aoo`03001oogoo00mo
o`003Goo00<007ooOol04goo00<007ooOol0QGoo00<007ooOol057oo00<007ooOol03goo000=Ool0
0`00Oomoo`0DOol20025Ool00`00Oomoo`0EOol00`00Oomoo`0>Ool000eoo`03001oogoo01Ioo`03
001oogoo089oo`03001oogoo01Ioo`03001oogoo00eoo`003Goo00<007ooOol05goo00<007ooOol0
PGoo00<007ooOol05Woo00<007ooOol03Goo000=Ool00`00Oomoo`0HOol00`00Oomoo`20Ool00`00
Oomoo`0COol5000>Ool000eoo`03001oogoo01Uoo`03001oogoo07moo`03001oo`0000@000Moo`P0
00Aoo`03001oogoo00aoo`003Goo00<007ooOol06Woo0P00N7oo2@000U7d2P0037oo00<007ooOol0
37oo000=Ool00`00Oomoo`0LOol00`00Oomoo`1/Ool90007DO@01@00DO@00000DO@00`004Woo00<0
07ooOol037oo000=Ool00`00Oomoo`0MOol00`00Oomoo`1SOol8000@DO@20003DO@200000gl<001o
o`0@Ool00`00Oomoo`0<Ool000eoo`03001oogoo01ioo`03001oogoo05Uoo`T001MAm08000=Am003
001Am000009o3003001oogoo00ioo`03001oogoo00aoo`003Goo00<007ooOol07goo00<007ooOol0
Cgoo2@007e7d00<0057d00000e7d00<0057d00000gl<00<007ooOol03Goo00<007ooOol037oo000=
Ool00`00Oomoo`0POol00`00Oomoo`15Ool9000VDO@20002DO@01000DOAAm0000U7d00D007l<O`ao
300000moo`03001oogoo00aoo`003Goo00<007ooOol08Goo0P00?7oo2@00;E7d0P00157d00@0057d
DO@0009Am003001o37l<009o3003001oogoo00aoo`03001oogoo00aoo`003Goo00<007ooOol08goo
00<007ooOol0<Goo2000157d00<0057dDO@0;U7d00<0057dDO@0157d00<0057d00000e7d00<007l<
O``00gl<00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`0TOol00`00Oomoo`0WOol9
000<DO@00`00DOAAm00/DO@20007DO@00`00DO@00003DO@00`00O`ao3003O``00`00Oomoo`0;Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo02Eoo`03001oogoo01ioo`P001EAm003001Am57d02]Am003
001Am57d00MAm08000AAm003001o37l<00=o3003001oogoo00]oo`03001oogoo00aoo`003Goo00<0
07ooOol09Woo00<007ooOol05Goo20007E7d00<0057dDO@0:E7d0P002U7d0P00157d00<007l<O``0
0gl<00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`0WOol2000<Ool9000UDO@00`00
DOAAm00WDO@2000<DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo02Uoo`04001oogooOol8000^DO@00`00DOAAm00VDO@00`00DOAAm00<DO@0
0`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0<Ool000eoo`03001oogoo
02Qoo`D003IAm003001Am57d02AAm08000iAm08000EAm003001o37l<00=o3003001oogoo00]oo`03
001oogoo00aoo`003Goo00<007ooOol0:7oo1000=e7d00<0057dDO@08e7d00<0057dDO@03U7d0P00
1E7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`0XOol20002
DO@3000dDO@00`00DOAAm00QDO@2000@DO@00`00DO@00005DO@00`00O`ao3003O``00`00Oomoo`0;
Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Qoo`03001Am00000AAm080039Am003001Am57d01mA
m080019Am003001Am00000EAm003001o37l<00=o3003001oogoo00]oo`03001oogoo00aoo`003Goo
00<007ooOol0:7oo00<0057d00001U7d0`00;e7d00<0057dDO@07U7d00<0057dDO@04E7d00@0057d
DO@000EAm003001o37l<00=o3003001oogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo
00@0057dDO@000QAm08002aAm0D001]Am08001AAm004001Am57d0005DO@00`00O`ao3003O``00`00
Oomoo`0<Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Qoo`04001Am57d000:DO@3000WDO@20002
Eil00`009[lV_`06000DDO@00`00DOAAm00CDO@01@00DOAAm57d00001E7d00<007l<O``00gl<00<0
07ooOol037oo00<007ooOol02goo000=Ool00`00Oomoo`0XOol01@00DOAAm57d0000357d0P008U7d
0`001ENO00<002Jo9[l01BJo1P00357d0P005U7d00D0057dDOAAm00000EAm003001o37l<00=o3003
001oogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo00D0057dDOAAm00000iAm0<001aA
m0<000UGW`03000V_bJo00XV_`H000AAm08001MAm003001Am57d009Am003001Am57d00=Am003001o
37l<00=o3003001oogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo00<0057dDO@00U7d
00<0057dDO@03U7d0P00657d0P003ENO00<002Jo9[l03bJo10006E7d00<0057dDO@00U7d00<0057d
DO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02goo000=Ool00`00Oomoo`0XOol0
0`00DOAAm002DO@00`00DOAAm00@DO@3000BDO@3000@Eil00`009[lV_`0B9[l00`00DOAAm00EDO@0
0`00DOAAm003DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02Qoo`03001Am57d00=Am003001Am57d019Am08000eAm0<001AGW`03000V_bJo
014V_`8001IAm003001Am57d00=Am003001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03
001oogoo00]oo`003Goo00<007ooOol0:7oo00<0057dDO@0157d00<0057dDO@04e7d0`00257d0P00
65NO00<002Jo9[l04BJo0P00557d00<0057dDO@0157d00<0057dDO@00e7d0P0017l<00<007ooOol0
37oo00<007ooOol02goo000=Ool00`00Oomoo`0XOol00`00DOAAm004DO@00`00DOAAm00FDO@20003
DO@3000KEil3000A9[l3000BDO@00`00DOAAm004DO@00`00DOAAm003DO@20004O``00`00Oomoo`0<
Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Qoo`03001Am57d00EAm003001Am57d01MAm0<001YG
W`<000Aoo`H000`V_`030000L`00011Am003001Am57d00EAm003001Am57d00=Am08000Ao3003001o
ogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo00<0057dDO@01E7d00<0057dDO@05e7d
00<006nk00005eNO100037oo1P001RJo00@0001c07<000mAm003001Am57d00EAm003001Am57d00=A
m08000Ao3003001oogoo00aoo`03001oogoo00]oo`0037oo00<007ooOol0:Goo00<0057dDO@01U7d
00<0057dDO@05E7d00D006nkKk]_^`0001=GW`D00003DO@00000015oo`H000059[l0001c07<0000=
DO@00`00DOAAm006DO@00`00DOAAm003DO@20004O``00`00Oomoo`0<Ool00`00Oomoo`0;Ool000ao
o`03001oogoo02Uoo`03001Am57d00IAm003001Am57d01AAm003001_^fnk00=_^`03001GWeNO00eG
W`H000=Am003001o;`0001Ioo`<00080L`03001Am57d00YAm003001Am57d00IAm003001Am57d00=A
m08000Ao3003001oogoo00aoo`03001oogoo00]oo`0037oo00<007ooOol0:Goo00<0057dDO@01e7d
00<0057dDO@04U7d00<006nkKk/01Fnk0P002UNO1P001U7d00@007l_Obl001Qoo`040000L`1c000:
DO@00`00DOAAm007DO@00`00DOAAm004DO@00`00O`ao3002O``00`00Oomoo`0<Ool00`00Oomoo`0;
Ool000aoo`03001oogoo02Uoo`03001Am57d00MAm003001Am57d019Am003001_^fnk00M_^`03001G
WeNO00AGW`<00003Ool0000000UAm005001o;gl_Obl0000HOol0100007<0L`002E7d00<0057dDO@0
1e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00
Oomoo`0YOol00`00DOAAm008DO@00`00DOAAm00@DO@00`00Kk]_^`09Kk/00`00EimGW`03000017oo
000000002e7d00D007l_Obmo;`0001Uoo`80000307<0057d00IAm003001Am57d00QAm003001Am57d
00AAm003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:Goo00<0
057dDO@0257d00<0057dDO@03e7d00<006nkKk/02fnk0P0000Aoo`00000000iAm005001o;gl_Obl0
000KOol0100007<000001E7d00<0057dDO@0257d00<0057dDO@0157d00<007l<O``00gl<00<007oo
Ool02goo00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00DOAAm009DO@00`00DOAAm00=DO@0
0`00Kk]_^`0;Kk/01000Ool000004E7d00D007l_Obmo;`0001aoo`040000L`1c0003DO@00`00DOAA
m00:DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03
001oogoo02Uoo`03001Am57d00YAm003001Am57d00]Am003001_^fnk00]_^`<001=Am005001o;gl_
Obl0000MOol0100007<0L`000U7d00<0057dDO@02U7d00<0057dDO@00e7d00<007l<O``00gl<00<0
07ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00DOAAm00:DO@00`00DOAAm00:
DO@00`00Kk]_^`0;Kk/2000EDO@01@00Obmo;gl_00007Woo00<0001c07<00P003E7d00<0057dDO@0
0e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00
DOAAm00;DO@00`00DOAAm008DO@00`00Kk]_^`0;Kk/2000FDO@01@00Obmo;gl_00007goo0P0000<0
L`00DO@0357d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02goo000<
Ool00`00Oomoo`0YOol00`00DOAAm00;DO@00`00DOAAm007DO@00`00Kk]_^`0<Kk/00`00DOAAm00E
DO@01@00Obmo;gl_00008Goo0P003E7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo
00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00DOAAm00<DO@00`00DOAAm005DO@00`00Kk]_
^`0<Kk/00`00DOAAm00FDO@01@00Obmo;gl_00008Woo0P00357d00<0057dDO@00e7d00<007l<O``0
0gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00DOAAm00<DO@00`00
DOAAm004DO@00`00Kk]_^`0<Kk/00`00DOAAm00GDO@01@00Obmo;gl_00008goo00<0057dDO@02U7d
00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomo
o`0YOol00`00DOAAm00=DO@00`00DOAAm003DO@00`00Kk]_^`0;Kk/00`00DOAAm00HDO@01@00Obmo
;gl_00008goo00<0057dDO@02U7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo00<0
07ooOol02goo000<Ool00`00Oomoo`0XOol00`00DOAAm00>DO@00`00DOAAm002DO@00`00Kk]_^`0;
Kk/00`00DOAAm00IDO@01@00Obmo;gl_00008goo00<0057dDO@02U7d00<0057dDO@00e7d00<007l<
O``00gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0XOol00`00DOAAm00?DO@0
1000DOAAm0003Fnk00<0057dDO@06U7d00D007l_Obmo;`0002Aoo`03001Am57d00UAm003001Am57d
00=Am003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:7oo00<0
057dDO@03e7d00<0057d00003Fnk0P00757d00D007l_Obmo;`0002Aoo`03001Am57d00UAm003001A
m57d00=Am003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:7oo
00<0057dDO@0457d00<006nkKk/02fnk0P007E7d00D007l_Obmo;`0002Aoo`03001Am57d00UAm003
001Am57d00=Am003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0
:7oo00<0057dDO@0457d0P002fnk0P007U7d00D007l_Obmo;`0002Eoo`03001Am57d00QAm003001A
m57d00=Am003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:7oo
00<0057dDO@03e7d00@007meOgD000U_^`8001mAm005001o;gl_Obl0000UOol00`00DOAAm008DO@0
0`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo
02Qoo`03001Am57d00mAm005001oMGmeOgD00008Kk/00`00DOAAm005DO@00`00DOAAm00FDO@01@00
Obmo;gl_00009Goo00<0057dDO@0257d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo
00<007ooOol02goo000<Ool00`00Oomoo`0XOol00`00DOAAm00?DO@00`00OgEoM@02OgD20005Kk/0
0`00DOAAm005DO@3000GDO@01@00Obmo;gl_00009Goo00<0057dDO@0257d00<0057dDO@00e7d00<0
07l<O``00gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0XOol00`00DOAAm00?
DO@00`00OgEoM@04OgD01@00Kk]_^fnk00001e7d1@005U7d00D007l_Obmo;`0001eoo`L0009oo`03
001Am57d00MAm003001Am57d00=Am003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`00
37oo00<007ooOol0:7oo00<0057dDO@03U7d00<007meOgD01Wme00<006nk00002E7d00<0057d0000
0`00557d00D007l_Obmo;`00011oo`d000IAm0800003Ool0057d00QAm003001Am57d00=Am003001o
37l<00=o3003001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:7oo00<0057dDO@03U7d
00<007meOgD01gme0P00357d10004e7d00D007l_Obmo;`00009oo`h001=Am004001jQ`000009DO@0
0`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo
02Qoo`03001Am57d00iAm003001oMGme00MoM@8000iAm0<0019Am0L001MAm003001Am57d00QAm003
001jQ`0000UAm003001Am57d00=Am003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`00
37oo00<007ooOol0:7oo00<0057dDO@03E7d00<007meOgD01gme0P00457d0`004E7d00<0057dDO@0
6E7d0P0000=Am0000000257d00@007Z7000000QAm003001Am57d00=Am003001o37l<00=o3003001o
ogoo00aoo`03001oogoo00Yoo`0037oo00<007ooOol0:7oo00<0057dDO@03E7d00<007meOgD01gme
0P004E7d10003e7d00<0057dDO@05e7d0P001E7d0P001U7d00@007Z7000000QAm003001Am57d00=A
m003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`0037oo00<007ooOol0:7oo00<0057d
DO@03E7d00<007meOgD01gme0P004U7d10003U7d00<0057dDO@05U7d00<0057dDO@01U7d0P001E7d
00@007Z7NXL000QAm003001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yo
o`0037oo00<007ooOol0:7oo00<0057dDO@03E7d00<007meOgD01gme0P00557d0`003E7d00<0057d
DO@0857d0P00157d00<007Z7NXL00P001e7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol0
37oo00<007ooOol02Woo000<Ool00`00Oomoo`0XOol00`00DOAAm00<DO@00`00OgEoM@07OgD2000F
DO@3000<DO@00`00DOAAm00EDO@00`00DOAAm008DO@01000KL0000000U7d00<007Z7NXL00P001e7d
00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02Woo000<Ool00`00Oomo
o`0XOol00`00DOAAm00<DO@00`00OgEoM@07OgD2000GDO@4000:DO@00`00DOAAm00EDO@00`00DOAA
m009DO@01000KL1]`0000U7d00@007Z7000000MAm003001Am57d00=Am003001o37l<00=o3003001o
ogoo00aoo`03001oogoo00Yoo`0037oo00<007ooOol0:7oo00<0057dDO@0357d00<007meOgD01gme
0P00657d10002E7d00<0057dDO@05E7d00<0057dDO@02E7d0P000Vg000@0057d001jQ`8000MAm003
001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`0037oo00<007ooOol0
:7oo00<0057dDO@0357d00<007meOgD01gme0P006U7d0`00257d00<0057dDO@05E7d00<0057dDO@0
2E7d00<007nf00000Vg00P0000AjQ`00Ool000IAm0L000Eo3003001oogoo00aoo`03001oogoo00Yo
o`0037oo00<007ooOol0:7oo00<0057dDO@02e7d00<007meOgD01gme0P00757d0`001e7d00<0057d
DO@05E7d00<0057dDO@0257d00H007nfOkIo]P00KL020002NXL90005DO@00`00O`ao3003O``00`00
Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00]Am003001oMGme00Mo
M@8001eAm0@000EAm003001Am57d021Am003001o]Wnf009o]P03001]`000009jQ`8000IAm003001A
m57d00=Am003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:Goo
00<0057dDO@02e7d00<007meOgD01gme0P007U7d1000157d00<0057dDO@0257d3P002E7d0P001Gnf
0`0000=jQ`0000001U7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol0
2Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00:DO@00`00OgEoM@08OgD2000PDO@R0004DO@20002
Fkh00`00OkIo]P03OkH200000gZ7001Am006DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomo
o`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00YAm003001oMGme00MoM@03
001oo`00025Am10000mAm0H000EK_P03001o]Wnf00=o]P03001jQ`0000MAm003001Am57d00=Am003
001o37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@0
2U7d00<007meOgD01gme0P008U7d0`000U7d00<0057dDO@0657d0P000PHl00<005^nFkh015^n00@0
07nfOkIo]P@000MAm003001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yo
o`002goo00<007ooOol0:Goo00<0057dDO@02U7d00<007meOgD01gme0P008e7d00D0057dDOAAm000
01QAm08000=Am086?003001K_U^n00AK_P03001o]Wnf00800003Og80057d00IAm003001Am57d00=A
m003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057d
DO@02E7d00<007meOgD027me0P009e7d00<0057dDO@05E7d0P001E7d00<000Hl00001U^n0`0000=o
LP00DO@01e7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02Woo000;
Ool00`00Oomoo`0YOol00`00DOAAm004DO@60009OgD00`00Ool0000WDO@00`00DOAAm00EDO@20005
DO@00`00MmT00007Fkh200000gmb001Am007DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomo
o`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`L000EAm0<000MoM@8002QAm003001Am57d
01AAm08000EAm003001gf@0000@0009K_P800004DO@007mb0008DO@00`00DOAAm003DO@00`00O`ao
3003O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00UAm004
001nZWjZ0006OgD2000XDO@00`00DOAAm00CDO@200000gOIDOAAm002DO@01000MmUgf@000U7d0PHl
0P000e7d00<007mb0000257d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007oo
Ool02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00:DO@00`00OZYnZP020004OgD2000XDO@00`00
DOAAm00CDO@00`00DOAAm004DO@00`00MmT0000:DO@20009DO@00`00DOAAm003DO@00`00O`ao3003
O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00YAm003001n
ZWjZ009nZP06001oMGme001oo`00:57d00<0057dDO@04U7d00<0057dDO@0157d00<007OI00002U7d
00<007mb00002E7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02Woo
000;Ool00`00Oomoo`0YOol00`00DOAAm00:DO@00`00OZYnZP03OZX300000goo001Am00WDO@00`00
DOAAm00ADO@200000gOIDOAAm002DO@01000MmUgf@002U7d00<007mb00002E7d00<0057dDO@00e7d
0P0017l<00<007ooOol037oo00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00:DO@0
0`00OZYnZP05OZX01000Oomoo`009e7d00<0057dDO@0457d0P001U7d00<007OI00002e7d00<007mb
00002E7d00<0057dDO@00e7d0P0017l<00<007ooOol037oo00<007ooOol02Woo000;Ool00`00Oomo
o`0YOol00`00DOAAm00;DO@00`00OZYnZP04OZX01000Oomoo`009e7d00<0057dDO@0457d00<0057d
MmT0157d00<007OI0000357d00<007mb00002E7d00<0057dDO@00e7d0P0017l<00<007ooOol037oo
00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00;DO@00`00OZYnZP04OZX01000Oomo
o`009e7d00<0057dDO@03e7d0P0000=gfE7dDO@00U7d00@007OIMmT000aAm08000YAm003001Am57d
00=Am08000Ao3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@0
2e7d00<007jZOZX01GjZ00<007oo00009e7d00<0057dDO@03U7d0P001E7d00@007OIMmT000eAm080
00YAm003001Am57d00=Am08000Ao3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0
:Goo00<0057dDO@02e7d00<007jZOZX01GjZ00@007ooOol002IAm003001Am57d00iAm003001Am7OI
00AAm003001gf@0000eAm003001oLP0000YAm003001Am57d00=Am08000Ao3003001oogoo00aoo`03
001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@0357d00<007jZOZX017jZ00@007ooOol0
02IAm003001Am57d00eAm08000EAm004001gfGOI000=DO@00`00Og80000:DO@00`00DOAAm004DO@0
0`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d
00aAm003001nZWjZ00AnZP04001oogoo000VDO@00`00DOAAm00<DO@200000e7d001Am002DO@01000
MmUgf@00257d20002e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol02goo00<007ooOol0
2Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00<DO@00`00OZYnZP05OZX00`00Ool0000VDO@00`00
DOAAm00<DO@00`00DOAAm004DO@00`00MmT000090007>cl00`00DOAAm009DO@00`00DOAAm004DO@0
0`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d
00aAm003001nZWjZ00EnZP04001oogoo000UDO@00`00DOAAm004DO@80002DO@01@00DOAAm57d0000
0WOI00<003/o>cl03S/o00<0057dDO@02E7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol0
2goo00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00=DO@00`00OZYnZP04OZX01000
Oomoo`009E7d1`001S/o0P001E7d00@007OIMmT000dk?`D000]Am003001Am57d00AAm003001o37l<
00=o3003001oogoo00]oo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@03E7d00<0
07jZOZX017jZ00@007ooOol002EAm08000/k?`03001Am57d00AAm004001gf@00>cl=0003Ool00`00
DOAAm00;DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0:Ool000]o
o`03001oogoo02Uoo`03001Am57d00eAm003001nZWjZ00EnZP03001oo`0002EAm004001o;`000007
>cl20002DO@01P00DOAAm57d001gf@<0011oo`03001Am57d00]Am003001Am57d00=Am003001o37l<
00=o3003001oogoo00]oo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@03E7d00<0
07jZOZX01GjZ00@007ooOol002AAm004001o;gl_Obl90005DO@01000MmUgf@004Woo00<0057dDO@0
2e7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02Woo000;Ool00`00
Oomoo`0YOol00`00DOAAm00>DO@00`00OZYnZP04OZX01000Oomoo`00957d00D007l_Obmo;`0000Io
o`04001Am57d0003DO@00`00MmT0000BOol01000DO@000002e7d00<0057dDO@00e7d00<007l<O``0
0gl<00<007ooOol02goo00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00>DO@00`00
OZYnZP04OZX01000Oomoo`00957d00D007l_Obmo;`0000Eoo`03001Am57d00AAm003001gf@00019o
o`03001Am57d009Am08000UAm003001Am57d00=Am003001o37l<00=o3003001oogoo00]oo`03001o
ogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@03U7d00<007jZOZX01GjZ00<007oo0000957d
00D007l_Obmo;`0000Aoo`8000EAm004001gfGOI000AOol00`00DOAAm005DO@00`00DOAAm006DO@0
0`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0:Ool000]oo`03001oogoo
02Uoo`03001Am57d00iAm003001nZWjZ00EnZP04001oogoo000SDO@01@00Obmo;gl_000017oo00<0
057dDO@0157d00<007OI00004Goo00<0057dDO@01e7d0P001U7d00<0057dDO@00e7d00<007l<O``0
0gl<00<007ooOol037oo00<007ooOol02Goo000;Ool00`00Oomoo`0YOol00`00DOAAm00?DO@00`00
OZYnZP04OZX01000Oomoo`008e7d00D007l_Obmo;`0000=oo`03001Am57d00AAm003001gf@00015o
o`03001Am57d00YAm08000AAm003001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03001o
ogoo00Uoo`002goo00<007ooOol0:Goo00<0057dDO@03e7d00<007jZOZX017jZ00@007ooOol002=A
m005001o;gl_Obl00002Ool00`00DOAAm004DO@01000MmUgf@0047oo00<0057dDO@03E7d00D0057d
DOAAm00000EAm003001o37l<00=o3003001oogoo00aoo`03001oogoo00Uoo`002goo00<007ooOol0
:Goo00<0057dDO@03U7d00@0057d000000EnZP04001oogoo000RDO@01P00Obmo;gl_001oo`8000EA
m004001gfGOI000@Ool00`00DOAAm00?DO@200000e7d001Am004DO@00`00O`ao3003O``00`00Oomo
o`0<Ool00`00Oomoo`09Ool000]oo`03001oogoo02Uoo`03001Am57d00aAm08000=Am08000AnZP05
001oogooOol0000QDO@01`00Obmo;gl_001oo`0000IAm003001gf@00011oo`03001Am57d019Am080
00EAm003001o37l<00=o3003001oogoo00aoo`03001oogoo00Uoo`002Woo00<007ooOol0:Woo00<0
057dDO@02e7d00<0057dDO@0157d0`000WjZ00<007ooOol00Woo00<0057dDO@07U7d00@007l_Obmo
;`8000IAm004001gfGOI000?Ool00`00DOAAm00DDO@20004DO@00`00O`ao3003O``00`00Oomoo`0<
Ool00`00Oomoo`09Ool000Yoo`03001oogoo02Yoo`03001Am57d00YAm003001Am57d00IAm005001D
P000OZX00005Ool00`00DOAAm00MDO@01000Obmo;gl_0P001E7d00@007OIMmT000moo`03001Am57d
01EAm004001Am0000002DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`09Ool000Yoo`03
001oogoo02Yoo`03001Am57d00QAm08000YAm003001DP000008000Eoo`03001Am57d00eAm1/0009g
fA1oo`03001Am57d01EAm004001Am57dDO@30005O``00`00Oomoo`0<Ool00`00Oomoo`09Ool000Yo
o`03001oogoo02Yoo`03001Am57d00MAm003001Am57d00]Am004001DP5B00006Ool00`00DOAAm004
DO@80003?G@00`00GSEN=@0AGSD00`00M]=fd`04000>Ool00`00DOAAm00FDO@00`00DOAAm003DO@0
0`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`09Ool000Yoo`03001oogoo02Yoo`03001Am57d
00IAm003001Am57d00eAm004001DP5B00006Ool6000;?G@00`00GSEN=@0AGSD00`00M]=fd`04M]<4
0009Ool00`00DOAAm00GDO@00`00DOAAm003DO@20004O``00`00Oomoo`0<Ool00`00Oomoo`09Ool0
00Yoo`03001oogoo02Yoo`03001Am57d00EAm003001Am57d00mAm004001DP5B00007Ool00`00?G@m
M00<?G@00`00GSEN=@0AGSD00`00M]=fd`08M]<30005Ool00`00DOAAm00HDO@00`00DOAAm002DO@0
1000OkEo]@000gl<00<007ooOol037oo00<007ooOol02Goo000:Ool00`00Oomoo`0ZOol00`00DOAA
m003DO@2000CDO@01000E81DP0001Goo0`003Ced00<005heGSD04Ehe00<007KCM]<02WKC00<007oo
Ool00Woo00<0057dDO@06E7d00<0057dDO@00U7d00@007neOkEo]@800003O``007oo00eoo`03001o
ogoo00Uoo`002Woo00<007ooOol0:Woo00<0057dDO@00U7d00<0057dDO@0557d00@005B0E80000Ao
o`D000/mM003001N=Ehe015N=@03001fdgKC00Yfd`05001oogooOol0000LDO@01@00DOAAm57d0000
1Wne0P003Woo00<007ooOol02Goo000:Ool00`00Oomoo`0ZOol01@00DOAAm57d0000657d00@005B0
E80000=oo`H000XmM003001N=Ehe015N=@03001fdgKC00Yfd`04001oogoo000MDO@01@00DOAAm57d
00001gne00<007ooOol037oo00<007ooOol02Goo000:Ool00`00Oomoo`0ZOol01000DO@000006U7d
00@005B0E800009oo`80008mM0@000PmM003001N=Ehe015N=@03001fdgKC00Yfd`03001oo`0001iA
m004001Am57d0008OkD00`00Oomoo`0<Ool00`00Oomoo`09Ool000Yoo`03001oogoo02Yoo`8001eA
m007001DP5B0001oo`0300000ced1@001Sed00<005heGSD04Ehe00<007KCM]<02WKC0P007e7d00@0
057dDO@000Mo]@03001oogoo00eoo`03001oogoo00Uoo`002Woo00<007ooOol0:Woo00<0057dDO@0
7E7d00H005B0E80000030005?G@50004?G@00`00GSEN=@0AGSD00`00M]=fd`0:M]<00`00DOAAm00N
DO@00`00DO@00008OkD00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03001oogoo02Yoo`03001A
m57d01iAm005001DP5B000<00007?G@40003?G@00`00GSEN=@0AGSD00`00M]=fd`0:M]<2000ODO@0
0`00DO@00007OkD00`00Oomoo`0>Ool00`00Oomoo`09Ool000Yoo`03001oogoo02]oo`03001Am57d
01iAm004001DP0030009?G@400000ced001N=@0BGSD00`00M]=fd`0:M]<2000ODO@00`00DO@00007
OkD00`00Oomoo`0>Ool00`00Oomoo`09Ool000Yoo`03001oogoo02]oo`03001Am57d01mAm0030000
0`0000XmM0D001=N=@03001fdgKC00Yfd`03001Am00001iAm08000Qo]@03001oogoo00ioo`03001o
ogoo00Uoo`002Woo00<007ooOol0;7oo00<0057dDO@07e7d0P0033ed10004Uhe00<007KCM]<02WKC
00@0057dDO@001eAm08000Mo]@03001oogoo00moo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo
00<0057dDO@07U7d0`003Sed00<005heGSD04Ehe00<007KCM]<02WKC00@0057dDO@001eAm003001o
]Gne00Io]@03001oogoo00moo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00<0057dDO@07U7d
0`003Sed00<005heGSD04Ehe00<007KCM]<02WKC00D0057dDOAAm00001aAm003001o]Gne00Eo]@03
001oogoo011oo`03001oogoo00Uoo`002Woo00<007ooOol0;Goo00<0057dDO@0757d00@0057d0000
00hmM003001N=Ehe015N=@03001fdgKC00Yfd`03001Am57d009Am003001Am57d01QAm08000Mo]@03
001oogoo011oo`03001oogoo00Uoo`002Woo00<007ooOol0;Goo00<0057dDO@06e7d00<0057dDO@0
0P003Sed00<005heGSD04Ehe00<007KCM]<02WKC00<0057dDO@00U7d00<0057dDO@0657d0P001gne
00<007ooOol047oo00<007ooOol02Goo000:Ool00`00Oomoo`0]Ool2000LDO@00`00DOAAm002000>
?G@00`00GSEN=@0AGSD00`00M]=fd`0:M]<00`00DOAAm003DO@00`00DOAAm00FDO@00`00OkD00006
OkD00`00Oomoo`0AOol00`00Oomoo`09Ool000Yoo`03001oogoo02eoo`8001]Am004001Am57dDO@2
000>?G@00`00GSEN=@0AGSD00`00M]=fd`0:M]<00`00DOAAm004DO@00`00DOAAm00EDO@00`00OkD0
0006OkD00`00Oomoo`0AOol00`00Oomoo`09Ool000Yoo`03001oogoo02eoo`03001oo`0001UAm003
001Am57d009Am08000hmM003001N=Ehe015N=@03001fdgKC00Yfd`03001Am57d00EAm003001Am57d
019Am0800003Emh0000000Io]@03001oogoo015oo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo
00@007ooOol001UAm003001Am57d009Am08000hmM003001N=Ehe019N=@03001fdgKC00Ufd`03001A
m57d00EAm003001Am57d011Am08000AGgP8000Ao]@03001oogoo019oo`03001oogoo00Uoo`002Woo
00<007ooOol0;7oo00@007ooOol001QAm003001Am57d00=Am003000mM3ed00dmM003001N=Ehe019N
=@03001fdgKC00Ufd`03001Am57d00IAm003001Am57d00eAm08000IGgP03001GgP0000=o]@03001o
ogoo019oo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00D007ooOomoo`0001IAm003001Am57d
00AAm003000mM3ed00dmM003001N=Ehe019N=@03001fdgKC00Ufd`03001Am57d00MAm003001Am57d
00YAm08000QGgP03001GgUON00<001Eoo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00D007oo
Oomoo`0001IAm003001Am57d00AAm003000mM3ed00dmM003001N=Ehe019N=@03001fdgKC00Ufd`03
001Am57d00MAm003001Am57d00QAm08000YGgP03001GgUON009GgP03001oogoo01=oo`03001oogoo
00Uoo`002Woo00<007ooOol0;7oo00<007ooOol00Woo00<0057dDO@04U7d00<0057dDO@01E7d00<0
03ed?G@03Ced00<005heGSD04Uhe00<007KCM]<02GKC00<0057dDO@0257d00<0057dDO@01E7d0P00
35ON00<005ONEmh00P005Woo00<007ooOol02Goo000:Ool00`00Oomoo`0/Ool00`00Oomoo`02Ool2
000CDO@00`00DOAAm005DO@00`00?G@mM00=?G@00`00GSEN=@0BGSD00`00M]=fd`09M]<00`00DOAA
m009DO@00`00DOAAm002DO@2000>Emh3000HOol00`00Oomoo`09Ool000Yoo`03001oogoo02aoo`03
001oogoo00=oo`<0011Am003001Am57d00IAm003000mM3ed00dmM003001N=Ehe019N=@03001fdgKC
00Ufd`03001Am57d00UAm003001Am57d008000mGgP8001Yoo`03001oogoo00Uoo`002Woo00<007oo
Ool0;7oo00<007ooOol01Goo0`003E7d00<0057dDO@01e7d00<003ed?G@03Ced00<005heGSD04Uhe
00<007KCM]<02GKC00<0057dDO@02U7d0P003eON0P0000=oo`00Ool06Goo00<007ooOol02Goo000:
Ool00`00Oomoo`0/Ool00`00Oomoo`07Ool3000;DO@00`00DOAAm007DO@00`00?G@mM00=?G@00`00
GSEN=@0BGSD00`00M]=fd`09M]<00`00DOAAm00:DO@3000<Emh20003Ool00`00Oomoo`0HOol00`00
Oomoo`09Ool000Yoo`03001oogoo02aoo`03001oogoo00Uoo`@000MAm003001Am57d00QAm003000m
M3ed00dmM003001N=Ehe019N=@03001fdgKC00Ufd`03001Am57d00YAm004001o;Gl]0009Emh20005
Ool00`00Oomoo`0IOol00`00Oomoo`08Ool000Yoo`03001oogoo02aoo`03001oogoo00]oo`@000AA
m003001Am57d00UAm003000mM3ed00dmM003001N=Ehe019N=@03001fdgKC00Ufd`03001Am57d00YA
m005001o;Gl]Obd00006Emh20007Ool00`00Oomoo`0IOol00`00Oomoo`08Ool000Yoo`03001oogoo
02aoo`03001oogoo00eoo`@0009Am003001Am57d00UAm003000mM3ed00dmM003001N=Ehe019N=@03
001fdgKC00Ufd`03001Am57d00YAm003001o;Gl]009o;@80009GgP8000Uoo`03001oogoo01Uoo`03
001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol03goo1000357d00<003ed?G@03Ced00<0
05heGSD04Uhe00<007KCM]<02GKC00<0057dDO@02U7d00<007l]Obd017l]0P002goo00<007ooOol0
6Goo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00
?G@mM00=?G@00`00GSEN=@0BGSD00`00M]=fd`09M]<00`00DOAAm00:DO@00`00Obeo;@04Obd00`00
Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019o
o`03001Am57d00YAm003000mM3ed00dmM003001N=Ehe019N=@03001fdgKC00Ufd`03001Am57d00YA
m003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Qoo`002Goo00<007oo
Ool0;Goo00<007ooOol04Woo00<0057dDO@02U7d00<003ed?G@03Ced00<005heGSD04Uhe00<007KC
M]<02GKC00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<007oo
Ool027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00?G@mM00=?G@0
0`00GSEN=@0BGSD00`00M]=fd`09M]<00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool0
0`00Oomoo`0IOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d
00YAm003000mM3ed00dmM003001N=Ehe019N=@03001fdgKC00Ufd`03001Am57d00YAm003001o;Gl]
00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<0
07ooOol04Woo00<0057dDO@02U7d00<003ed?G@02ced3@002Uhe00<007KCM]<02GKC00<0057dDO@0
2U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00
Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00?G@mM006?G@50009:ch20002:ch>0009
M]<<DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03
001oogoo02eoo`03001oogoo019oo`03001Am57d00YAm003000mM3ed00H0020[?PH000=fd`aAm003
001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0
;Goo00<007ooOol04Woo00<0057dDO@02U7d0`00;2/n10002e7d00<007l]Obd017l]00<007ooOol0
2goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00
DOAAm00:DO@00`00:ch[?P0E:ch00`00:ch[?P0F:ch00`00DOAAm00:DO@00`00Obeo;@04Obd00`00
Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019o
o`03001Am57d00YAm003000[?R/n01@[?P<001H[?P8000aAm003001o;Gl]00Ao;@03001oogoo00]o
o`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057d
DO@02U7d00<002/n:ch052/n0P005R/n00<007oo0000357d00<007l]Obd017l]00<007ooOol02goo
00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAA
m00:DO@01000Oc1o<7l`1P003B/n0P002b/n20001Goo00<0057dDO@02U7d00<007l]Obd017l]00<0
07ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0B
Ool00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Ool0000I000=Ool00`00DOAAm00:DO@00`00Obeo
;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03
001oogoo019oo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d
00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<0
07ooOol0;Goo00<007ooOol04Woo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol037oo0P00
67oo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol0
27oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00
Oomoo`0<Ool2000HOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0H
Ool00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d00YAm003001o
<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]o
o`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057d
DO@02U7d00<007l`Oc001Gl`00<007ooOol037oo0P0067oo00<0057dDO@02U7d00<007l]Obd017l]
00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomo
o`0BOol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm009DO@0
0`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo
02eoo`03001oogoo019oo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00aoo`8001Uoo`03
001Am57d00UAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`00
2Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol0
37oo0P006Goo00<0057dDO@02E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<0
07ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006
Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm009DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00
Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d00UA
m003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00UAm003001o;Gl]00Ao;@03001o
ogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo
00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02E7d00<007l]
Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool0
0`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAA
m009DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03
001oogoo02eoo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`80
01Uoo`03001Am57d00UAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo
00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<0
07ooOol037oo0P006Goo00<0057dDO@02E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol0
67oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00
Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm009DO@00`00Obeo;@04Obd00`00Oomoo`0;
Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001A
m57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00UAm003001o;Gl]00Ao
;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007oo
Ool04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02E7d
00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomo
o`0]Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol0
0`00DOAAm009DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool0
00Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo
00aoo`8001Uoo`03001Am57d00UAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03
001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc00
1Wl`00<007ooOol037oo0P006Goo00<0057dDO@02E7d00<007l]Obd017l]00<007ooOol02goo00<0
07ooOol067oo00<007ooOol027oo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009
DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm009DO@00`00Obeo;@04Obd00`00
Oomoo`0;Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03001oogoo019o
o`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00YAm003001o
;Gl]00=o;@03001oogoo00]oo`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0;Woo
00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057d
DO@02U7d00<007l]Obd00gl]00<007ooOol02goo00<007ooOol06Goo00<007ooOol01goo0008Ool0
0`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2
000IOol00`00DOAAm00:DO@00`00Obeo;@03Obd00`00Oomoo`0;Ool00`00Oomoo`0IOol00`00Oomo
o`07Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003
001oogoo00aoo`8001Uoo`03001Am57d00YAm003001o;Gl]00=o;@03001oogoo00]oo`03001oogoo
01Uoo`03001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<0
07l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol0
2Woo00<007ooOol06Goo00<007ooOol01goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00
DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm00:DO@00`00Obeo;@04
Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03001o
ogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00YA
m003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<007oo
Ool0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo
00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<007ooOol01goo
0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomo
o`0<Ool2000IOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol0
0`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001Am57d00UAm003001o<7l`
00Io<003001oogoo00aoo`8001Uoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03
001oogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@0
2E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02U7d00<007l]Obd017l]00<0
07ooOol02Woo00<007ooOol06Goo00<007ooOol01goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0B
Ool00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm00:DO@00`00
Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02io
o`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001A
m57d00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Moo`0027oo
00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo
0P006Goo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<007oo
Ool01goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc00
0`00Oomoo`0<Ool2000IOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomo
o`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001Am57d00UAm003
001o<7l`00Io<003001oogoo00aoo`<001Qoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo
00Yoo`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo00<0
057dDO@02E7d00<007l`Oc001Wl`00<007ooOol03Goo00<007ooOol05goo00<0057dDO@02U7d00<0
07l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<007ooOol01goo0008Ool00`00Oomoo`0^
Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0WOol00`00DOAAm00:
DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001o
ogoo02ioo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo02Moo`03001A
m57d00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Moo`0027oo
00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol09goo
00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<007ooOol01goo
0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomo
o`0WOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomo
o`07Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003
001oogoo02Moo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03
001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc00
1Wl`00<007ooOol09goo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol0
67oo00<007ooOol01goo0008Ool00`00Oomoo`0]Ool00`00Oomoo`0COol00`00DOAAm009DO@00`00
Oc1o<006Oc000`00Oomoo`0WOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00
Oomoo`0HOol00`00Oomoo`07Ool000Qoo`03001oogoo02eoo`03001oogoo01=oo`03001Am57d00UA
m003001o<7l`00Io<003001oogoo02Moo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]o
o`03001oogoo01Qoo`03001oogoo00Moo`0027oo00<007ooOol0;Goo00<007ooOol04goo00<0057d
DO@02E7d00<007l`Oc001Wl`00<007ooOol09goo00<0057dDO@02U7d00<007l]Obd017l]00<007oo
Ool02goo00<007ooOol067oo00<007ooOol01goo0008Ool00`00Oomoo`0]Ool00`00Oomoo`0COol0
0`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0WOol00`00DOAAm00:DO@00`00Obeo;@04Obd0
0`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool000Qoo`03001oogoo02eoo`03001oogoo
01=oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00iooaX000aAm003001o;Gl]00Ao;@03
001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Moo`0027oo00<007ooOol0;Goo00<007ooOol0
4goo00<0057dDO@02E7d6P006U7d00<0057dDO@02E7d00<007l]Obd017l]00<007ooOol02goo00<0
07ooOol067oo00<007ooOol01goo0008Ool00`00Oomoo`0]Ool00`00Oomoo`0COol00`00DOAAm008
DO@00`00DOAAm00cDO@00`00DOAAm008DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0H
Ool00`00Oomoo`07Ool000Qoo`03001oogoo02eoo`03001oogoo01=oo`03001Am57d00MAm003001A
m57d03EAm003001Am57d00MAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001o
ogoo00Moo`0027oo00<007ooOol0;Goo00<007ooOol04goo00<0057dDO@01U7d00<0057dDO@0=e7d
00<0057dDO@01U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol01goo
0008Ool00`00Oomoo`0]Ool00`00Oomoo`0COol00`00DOAAm006DO@00`00DOAAm00hDO@00`00DOAA
m005DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool000Qoo`03
001oogoo02eoo`03001oogoo01=oo`03001Am57d00EAm003001Am57d03YAm003001Am57d00AAm003
001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Moo`001goo00<007ooOol0
;Woo00<007ooOol04goo00<0057dDO@0157d00<0057dDO@0?57d00<0057dDO@00e7d00<007l]Obd0
17l]00<007ooOol02goo00<007ooOol067oo00<007ooOol01goo0007Ool00`00Oomoo`0^Ool00`00
Oomoo`0COol00`00DOAAm003DO@00`00DOAAm00nDO@00`00DOAAm002DO@00`00Obeo;@04Obd00`00
Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool000Moo`03001oogoo02ioo`03001oogoo01=o
o`03001Am57d009Am003001Am57d041Am005001Am57dDO@00006Obd00`00Oomoo`0;Ool00`00Oomo
o`0HOol00`00Oomoo`07Ool000Moo`03001oogoo02ioo`03001oogoo01=oo`05001Am57dDO@00014
DO@01000DOAAm0001Wl]00<007ooOol02goo00<007ooOol06Goo00<007ooOol01Woo0007Ool00`00
Oomoo`0^Ool00`00Oomoo`0COol01000DOAAm000AU7d00<0057d00001Wl]00<007ooOol02goo00<0
07ooOol06Goo00<007ooOol01Woo0007Ool00`00Oomoo`0^Ool00`00Oomoo`0COol01000DOAAm000
Ae7d0P001Wl]00<007ooOol02goo00<007ooOol06Goo00<007ooOol01Woo0007Ool00`00Oomoo`0^
Ool00`00Oomoo`0COol00`00DO@0000gDO@D0005Obd00`00Oomoo`0;Ool00`00Oomoo`0IOol00`00
Oomoo`06Ool000Moo`03001oogoo02ioo`03001oogoo01=oo`80019Am2H001@Ff`@00003Obd007oo
00aoo`03001oogoo01Uoo`03001oogoo00Ioo`001goo00<007ooOol0;Woo00<007ooOol04goo5000
?QKK0P003Goo00<007ooOol06Goo00<007ooOol01Woo0007Ool00`00Oomoo`0^Ool00`00Oomoo`0F
Ool4000E5]/U000POol00`00Oomoo`0IOol00`00Oomoo`06Ool000Moo`03001oogoo02ioo`03001o
ogoo01YooaD004Eoo`03001oogoo01Uoo`03001oogoo00Ioo`001goo00<007ooOol0;Woo00<007oo
Ool0M7oo00<007ooOol06Goo00<007ooOol01Woo0007Ool00`00Oomoo`0^Ool00`00Oomoo`1dOol0
0`00Oomoo`0IOol00`00Oomoo`06Ool000Moo`03001oogoo02ioo`03001oogoo061ooaH001Yoo`03
001oogoo00Ioo`001goo00<007ooOol0;Woo00<007ooOol0=Woo:P005Woo10005Woo00<007ooOol0
1Woo0007Ool00`00Oomoo`0^Ool00`00Oomoo`0<OolZ0014Ool3000COol00`00Oomoo`06Ool000Mo
o`03001oogoo01=oobX0075oo`@000moo`03001oogoo00Ioo`001goo5P006goo00<007ooOol0PGoo
0`0037oo00<007ooOol01Woo000;Ool7000VOol00`00Oomoo`24Ool40008Ool00`00Oomoo`06Ool0
019oo`L001moo`03001oogoo08Qoo`<000Eoo`03001oogoo00Ioo`006Goo1`0067oo00<007ooOol0
Rgoo100000=oo`00Ool01goo000POol7000AOol00`00Oomoo`1hOolI0008Ool002Moo`L000Yoo`03
001oogoo04Mooc40025oo`00;Woo1`000goo00<007ooOol05Woo<@00DWoo000eOolL0023Ool00=Ao
o`00e7oo003DOol00=Aoo`00e7oo003DOol00=Aoo`00\
\>"],
  ImageRangeCache->{{{0, 211}, {286, 0}} -> {0.122254, -0.0258127, 0.00344856,
   0.00344856}}]
}, Open  ]],

Cell[TextData[{
  "The following example analyzes the motion of a classic slider-crank \
mechanism. This mechanism is modeled with a simple and intuitive set of \
mechanical constraints that are representative of how such a problem would \
usually be modeled with ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Body Numbers"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider-crank mechanism consists of three bodies:\nBody 1 is the ground \
body.\nBody 2 is the crankshaft.\nBody 3 is the piston."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Each independent body in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model must be given a unique positive integer body number. The choice of \
each body number is arbitrary except for the ground body, which must be body \
1. These body numbers are used throughout a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model to reference each body. The ground body, which is stationary by \
definition, is used as the reference location and orientation for the rest of \
the model. All mechanism models must have some reference to the ground body \
to be adequately constrained.\n\nTo aid in the readability of the mechanism \
models created with ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ", it is customary to name each of the bodies in a mechanism, and then \
define each of these names to be equal to the integer body number of the \
body. Each body can then be referenced by name instead of by a number."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Define body names to be used to reference each body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crankshaft = 2; \)\), 
    \(\(piston = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"A real slider-crank mechanism would have a fourth body; the connecting rod \
between the crankshaft and the piston. However, in the kinematic model this \
entire part can be replaced by a simple distance constraint specifying that \
the crank pin and the piston pin are to be a constant distance apart. This \
technique decreases the overall size of the model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Local Coordinates"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Each body in a mechanism model must have a local coordinate system \
attached to it. How to place this coordinate system on the body is up to the \
user and is based on the needs of the model. It is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " necessary to place the local coordinate origin at the center of gravity \
of the body. The local coordinate system of each body is used to define \
points, lines, planes, and other features on the body that are then tied \
together to make the mechanical constraints.\n\nThe local coordinate system \
of the ground body is coincident with the global coordinate system. \
Therefore, the global coordinate system is referenced only through the ground \
body by specifying body 1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Bodies"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Ground"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The local coordinate system of the ground body originates at the center of \
the crankshaft."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Five local point coordinates are used on the ground body.\nP1 and P2 are \
two points that define the rotational axis of the crankshaft. P1 is at the \
global origin and P2 is on the positive ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis.\nP3 is a point on the positive ",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis that is used (with point 1) to define a reference line to control \
the rotation of the crankshaft and the piston.\nP4 and P5 are two points on \
the positive ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axis that are used to define the vertical translation line of the \
piston."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the ground body. The point coordinates on the ground \
body are\nP1 {0,0,0}, P2 {0,0,5}, P3 {3,0,0}, P4 {0,4,0}, and P5 {0,9,0}."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.35323 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.16802 1.37431 0.0343577 1.37431 [
[ 0 0 0 0 ]
[ 1 1.35323 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.35323 L
0 1.35323 L
closepath
clip
newpath
p
.002 w
.28194 .30732 m
.06691 .13043 L
s
.06691 .13043 m
.03436 1.28529 L
s
.03436 1.28529 m
.26714 1.31887 L
s
.26714 1.31887 m
.28194 .30732 L
s
.93788 .23453 m
.96564 1.30512 L
s
.96564 1.30512 m
.83141 1.2668 L
s
.83141 1.2668 m
.80901 .03436 L
s
.80901 .03436 m
.93788 .23453 L
s
.28194 .30732 m
.06691 .13043 L
s
.06691 .13043 m
.80901 .03436 L
s
.80901 .03436 m
.93788 .23453 L
s
.93788 .23453 m
.28194 .30732 L
s
.26714 1.31887 m
.96564 1.30512 L
s
.96564 1.30512 m
.83141 1.2668 L
s
.83141 1.2668 m
.03436 1.28529 L
s
.03436 1.28529 m
.26714 1.31887 L
s
P
p
.002 w
.30689 .78334 m .31255 .33798 L .26949 .30272 L p
.988 .782 .537 r
F P
s
P
p
.002 w
.31255 .33798 m .86808 .27803 L .83999 .2391 L p
.538 .814 .997 r
F P
s
P
p
.002 w
.83999 .2391 m .26949 .30272 L .31255 .33798 L p
.538 .814 .997 r
F P
s
P
p
.002 w
.47334 .40539 m .39314 .49448 L .35171 .46326 L p
.869 .917 .858 r
F P
s
P
p
.002 w
.39314 .49448 m .3631 .60901 L .32059 .5811 L p
.973 .858 .667 r
F P
s
P
p
.002 w
.32059 .5811 m .35171 .46326 L .39314 .49448 L p
.973 .858 .667 r
F P
s
P
p
.002 w
.58376 .36434 m .47334 .40539 L .43422 .37143 L p
.678 .883 .974 r
F P
s
P
p
.002 w
.35171 .46326 m .43422 .37143 L .47334 .40539 L p
.869 .917 .858 r
F P
s
P
p
.002 w
.3631 .60901 m .39141 .72022 L .34934 .69542 L p
.972 .659 .331 r
F P
s
P
p
.002 w
.34934 .69542 m .32059 .5811 L .3631 .60901 L p
.972 .659 .331 r
F P
s
P
p
.002 w
.33872 .86181 m .30689 .78334 L .26244 .76055 L p
.942 .575 .24 r
F P
s
P
p
.002 w
.26949 .30272 m .26244 .76055 L .30689 .78334 L p
.988 .782 .537 r
F P
s
P
p
.002 w
.69662 .38297 m .58376 .36434 L .54767 .32886 L p
.305 .686 .977 r
F P
s
P
p
.002 w
.43422 .37143 m .54767 .32886 L .58376 .36434 L p
.678 .883 .974 r
F P
s
P
p
.002 w
.26949 .30272 m .54757 .27171 L .54767 .32886 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.54767 .32886 m .43422 .37143 L .26949 .30272 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.43422 .37143 m .35171 .46326 L .26949 .30272 L closepath p
.63 .476 .655 r
F P
s
P
p
.002 w
.26513 .58587 m .26949 .30272 L .35171 .46326 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.39141 .72022 m .47223 .79908 L .43211 .77639 L p
.663 .133 0 r
F P
s
P
p
.002 w
.43211 .77639 m .34934 .69542 L .39141 .72022 L p
.663 .133 0 r
F P
s
P
p
.002 w
.26244 .76055 m .29488 .84123 L .33872 .86181 L p
.942 .575 .24 r
F P
s
P
p
.002 w
.41591 .89217 m .33872 .86181 L .29488 .84123 L p
0 .365 .711 r
F P
s
P
p
.002 w
.78191 .45826 m .69662 .38297 L .66354 .34763 L p
0 .108 .604 r
F P
s
P
p
.002 w
.54767 .32886 m .66354 .34763 L .69662 .38297 L p
.305 .686 .977 r
F P
s
P
p
.002 w
.47223 .79908 m .47114 1.1883 L .43002 1.17733 L p
.996 .786 .504 r
F P
s
P
p
.002 w
.43002 1.17733 m .43211 .77639 L .47223 .79908 L p
.996 .786 .504 r
F P
s
P
p
.002 w
.29488 .84123 m .37404 .87233 L .41591 .89217 L p
0 .365 .711 r
F P
s
P
p
.002 w
.4137 1.25092 m .41591 .89217 L .37404 .87233 L p
.994 .785 .516 r
F P
s
P
p
.002 w
.35171 .46326 m .32059 .5811 L .26513 .58587 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.26244 .76055 m .26513 .58587 L .32059 .5811 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.86808 .27803 m .87814 .74458 L .84953 .71935 L p
.989 .775 .387 r
F P
s
P
p
.002 w
.84953 .71935 m .83999 .2391 L .86808 .27803 L p
.989 .775 .387 r
F P
s
P
p
.002 w
.32059 .5811 m .34934 .69542 L .26244 .76055 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.66354 .34763 m .75106 .42481 L .78191 .45826 L p
0 .108 .604 r
F P
s
P
p
.002 w
.8152 .57142 m .78191 .45826 L .75106 .42481 L p
.924 .588 .133 r
F P
s
P
p
.002 w
.83999 .2391 m .54757 .27171 L .54767 .32886 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.29488 .84123 m .26244 .76055 L .34934 .69542 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.54767 .32886 m .66354 .34763 L .83999 .2391 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.37404 .87233 m .29488 .84123 L p
.34934 .69542 L .63 .476 .655 r
F P
s
P
p
.002 w
.34934 .69542 m .43211 .77639 L .37404 .87233 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.78566 .69145 m .8152 .57142 L .78508 .54117 L p
.99 .888 .608 r
F P
s
P
p
.002 w
.75106 .42481 m .78508 .54117 L .8152 .57142 L p
.924 .588 .133 r
F P
s
P
p
.002 w
.70531 1.18107 m .70098 .78411 L .66721 .76047 L p
.998 .785 .446 r
F P
s
P
p
.002 w
.70098 .78411 m .78566 .69145 L .75447 .66484 L p
.87 .967 .856 r
F P
s
P
p
.002 w
.75447 .66484 m .66721 .76047 L .70098 .78411 L p
.87 .967 .856 r
F P
s
P
p
.002 w
.37404 .87233 m .37084 1.24194 L .4137 1.25092 L p
.994 .785 .516 r
F P
s
P
p
.002 w
.76628 1.24194 m .4137 1.25092 L .37084 1.24194 L p
.179 .705 .863 r
F P
s
P
p
.002 w
.78508 .54117 m .75447 .66484 L .78566 .69145 L p
.99 .888 .608 r
F P
s
P
p
.002 w
.47114 1.1883 m .70531 1.18107 L .67084 1.16963 L p
.215 .725 .888 r
F P
s
P
p
.002 w
.67084 1.16963 m .43002 1.17733 L .47114 1.1883 L p
.215 .725 .888 r
F P
s
P
p
.002 w
.66354 .34763 m .75106 .42481 L .83999 .2391 L closepath p
.63 .476 .655 r
F P
s
P
p
.01 w
.54808 .56154 m
.72491 .54634 L
s
P
p
.01 w
.54808 .56154 m
.44598 .48049 L
s
P
p
.02 w
.54808 .56154 Mdot
P
p
.002 w
.43002 1.17733 m .43211 .77639 L .37404 .87233 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.37404 .87233 m .37084 1.24194 L .43002 1.17733 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.84384 .83119 m .76096 .87233 L .72872 .85124 L p
.684 .949 .957 r
F P
s
P
p
.002 w
.76096 .87233 m .76628 1.24194 L .73348 1.23237 L p
.996 .782 .428 r
F P
s
P
p
.002 w
.73348 1.23237 m .72872 .85124 L .76096 .87233 L p
.996 .782 .428 r
F P
s
P
p
.002 w
.87814 .74458 m .84384 .83119 L .81408 .80867 L p
.969 .932 .675 r
F P
s
P
p
.002 w
.81408 .80867 m .84953 .71935 L .87814 .74458 L p
.969 .932 .675 r
F P
s
P
p
.002 w
.72872 .85124 m .81408 .80867 L .84384 .83119 L p
.684 .949 .957 r
F P
s
P
p
.002 w
.84589 .53594 m .83999 .2391 L .75106 .42481 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.75106 .42481 m .78508 .54117 L .84589 .53594 L p
.63 .476 .655 r
F P
s
P
p
.01 w
.5485 .801 m
.54904 1.11028 L
s
P
p
.02 w
.5485 .801 Mdot
P
p
.02 w
.72491 .54634 Mdot
P
p
.002 w
.66721 .76047 m .67084 1.16963 L .70531 1.18107 L p
.998 .785 .446 r
F P
s
P
p
.002 w
.84953 .71935 m .84589 .53594 L .78508 .54117 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.78508 .54117 m .75447 .66484 L .84953 .71935 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.75447 .66484 m .66721 .76047 L .72872 .85124 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.67084 1.16963 m .66721 .76047 L .72872 .85124 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.43002 1.17733 m .37084 1.24194 L .73348 1.23237 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.37084 1.24194 m .73348 1.23237 L .76628 1.24194 L p
.179 .705 .863 r
F P
s
P
p
.002 w
.81408 .80867 m .84953 .71935 L .75447 .66484 L p
.63 .476 .655 r
F P
s
P
p
.002 w
.72872 .85124 m .81408 .80867 L p
.75447 .66484 L .63 .476 .655 r
F P
s
P
p
.002 w
.73348 1.23237 m .67084 1.16963 L .43002 1.17733 L p
.63 .476 .655 r
F P
s
P
p
.02 w
.54904 1.11028 Mdot
P
p
.002 w
.72872 .85124 m .73348 1.23237 L .67084 1.16963 L p
.63 .476 .655 r
F P
s
P
p
.02 w
.44598 .48049 Mdot
P
p
.002 w
.93788 .23453 m
.96564 1.30512 L
s
.96564 1.30512 m
.83141 1.2668 L
s
.83141 1.2668 m
.80901 .03436 L
s
.80901 .03436 m
.93788 .23453 L
s
.26714 1.31887 m
.96564 1.30512 L
s
.96564 1.30512 m
.83141 1.2668 L
s
.83141 1.2668 m
.03436 1.28529 L
s
.03436 1.28529 m
.26714 1.31887 L
s
P
p
[(P1)] .54808 .56154 0 -1.8 Mshowa
[(P2)] .44598 .48049 .6 -2.2 Mshowa
[(P3)] .72491 .54634 0 1.8 Mshowa
[(P4)] .5485 .801 0 1.8 Mshowa
[(P5)] .54904 1.11028 0 -1.8 Mshowa
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 287},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D00017a000`40O003h00Oe7oo003DOol00=Ao
o`00e7oo003DOol00=Aoo`00e7oo003DOol00:Moo`@002Uoo`00Wgoo20000goo0P00:7oo002GOol8
000;Ool2000XOol008moo`P001=oo`03001oo`0002Moo`00Qgoo20006goo00@007ooOol002Ioo`00
P7oo1`008goo00@007ooOol002Ioo`00N7oo2000:Woo00D007ooOomoo`0002Eoo`00L7oo2000<Woo
00D007ooOomoo`0002Eoo`00J7oo2000>Woo00<007ooOol00Woo00<007ooOol08Woo001POol80012
Ool00`00Oomoo`03Ool00`00Oomoo`0QOol005Uoo`L004Yoo`03001oogoo00=oo`03001oogoo025o
o`00DGoo2000DGoo00<007ooOol017oo00<007ooOol087oo0019Ool8001IOol00`00Oomoo`05Ool0
0`00Oomoo`0OOol0045oo`P0065oo`03001oogoo00Eoo`03001oogoo01moo`00>Goo2000JGoo00<0
07ooOol01Woo00<007ooOol07Woo000bOol7001aOol00`00Oomoo`07Ool00`00Oomoo`0MOol002Yo
o`P007Qoo`03001oogoo00Moo`03001oogoo01eoo`008Woo2000P7oo00<007ooOol027oo00<007oo
Ool077oo000JOol80028Ool00`00Oomoo`09Ool00`00Oomoo`0KOol0019oo`P0091oo`03001oogoo
00Uoo`03001oogoo01]oo`003Woo1000V7oo00<007ooOol02Woo00<007ooOol06Woo000>Ool2002J
Ool00`00Oomoo`0:Ool00`00Oomoo`0JOol000ioo`03001oo`0009Uoo`03001oogoo00]oo`03001o
ogoo01Uoo`003Woo00<007ooOol00P00Ugoo00<007ooOol037oo00<007ooOol067oo000>Ool00`00
Oomoo`02Ool00`00Oomoo`2DOol00`00Oomoo`0<Ool00`00Oomoo`0HOol000ioo`03001oogoo00=o
o`03001oogoo09=oo`03001oogoo00eoo`03001oogoo01Moo`003Woo00<007ooOol017oo00<007oo
Ool0TWoo00<007ooOol03Woo00<007ooOol05Woo000>Ool00`00Oomoo`05Ool00`00Oomoo`2BOol0
0`00Oomoo`0=Ool00`00Oomoo`0FOol000ioo`03001oogoo00Ioo`80099oo`03001oogoo00ioo`03
001oogoo01Eoo`003Woo00<007ooOol027oo00<007ooOol0Sgoo00<007ooOol03goo00<007ooOol0
57oo000>Ool00`00Oomoo`09Ool00`00Oomoo`2>Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol000io
o`03001oogoo00Yoo`03001oogoo08eoo`03001oogoo011oo`03001oogoo01=oo`003Woo00<007oo
Ool02goo00<007ooOol0S7oo00<007ooOol04Goo00<007ooOol04Woo000>Ool00`00Oomoo`0<Ool0
0`00Oomoo`2;Ool00`00Oomoo`0AOol00`00Oomoo`0BOol000ioo`03001oogoo00eoo`8008]oo`03
001oogoo019oo`03001oogoo015oo`003Woo00<007ooOol03goo00<007ooOol0R7oo00<007ooOol0
4Woo00<007ooOol04Goo000>Ool00`00Oomoo`0@Ool00`00Oomoo`27Ool00`00Oomoo`0COol00`00
Oomoo`0@Ool000ioo`03001oogoo015oo`03001oogoo08Ioo`03001oogoo01Aoo`03001oogoo00mo
o`003Goo00<007ooOol04goo00<007ooOol0QGoo00<007ooOol057oo00<007ooOol03goo000=Ool0
0`00Oomoo`0DOol20025Ool00`00Oomoo`0EOol00`00Oomoo`0>Ool000eoo`03001oogoo01Ioo`03
001oogoo089oo`03001oogoo01Ioo`03001oogoo00eoo`003Goo00<007ooOol05goo00<007ooOol0
PGoo00<007ooOol05Woo00<007ooOol03Goo000=Ool00`00Oomoo`0HOol00`00Oomoo`20Ool00`00
Oomoo`0COol5000>Ool000eoo`03001oogoo01Uoo`03001oogoo07moo`03001oo`0000@000Moo`P0
00Aoo`03001oogoo00aoo`003Goo00<007ooOol06Woo0P00N7oo2@000U7d2P0037oo00<007ooOol0
37oo000=Ool00`00Oomoo`0LOol00`00Oomoo`1/Ool90007DO@01@00DO@00000DO@00`004Woo00<0
07ooOol037oo000=Ool00`00Oomoo`0MOol00`00Oomoo`1SOol8000@DO@20003DO@200000gl<001o
o`0@Ool00`00Oomoo`0<Ool000eoo`03001oogoo01ioo`03001oogoo05Uoo`T001MAm08000=Am003
001Am000009o3003001oogoo00ioo`03001oogoo00aoo`003Goo00<007ooOol07goo00<007ooOol0
Cgoo2@007e7d00<0057d00000e7d00<0057d00000gl<00<007ooOol03Goo00<007ooOol037oo000=
Ool00`00Oomoo`0POol00`00Oomoo`15Ool9000VDO@20002DO@01000DOAAm0000U7d00D007l<O`ao
300000moo`03001oogoo00aoo`003Goo00<007ooOol08Goo0P00?7oo2@00;E7d0P00157d00@0057d
DO@0009Am003001o37l<009o3003001oogoo00aoo`03001oogoo00aoo`003Goo00<007ooOol08goo
00<007ooOol0<Goo2000157d00<0057dDO@0;U7d00<0057dDO@0157d00<0057d00000e7d00<007l<
O``00gl<00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`0TOol00`00Oomoo`0WOol9
000<DO@00`00DOAAm00/DO@20007DO@00`00DO@00003DO@00`00O`ao3003O``00`00Oomoo`0;Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo02Eoo`03001oogoo01ioo`P001EAm003001Am57d02]Am003
001Am57d00MAm08000AAm003001o37l<00=o3003001oogoo00]oo`03001oogoo00aoo`003Goo00<0
07ooOol09Woo00<007ooOol05Goo20007E7d00<0057dDO@0:E7d0P002U7d0P00157d00<007l<O``0
0gl<00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`0WOol2000<Ool9000UDO@00`00
DOAAm00WDO@2000<DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0<
Ool000eoo`03001oogoo02Uoo`04001oogooOol8000^DO@00`00DOAAm00VDO@00`00DOAAm00<DO@0
0`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0<Ool000eoo`03001oogoo
02Qoo`D003IAm003001Am57d02AAm08000iAm08000EAm003001o37l<00=o3003001oogoo00]oo`03
001oogoo00aoo`003Goo00<007ooOol0:7oo1000=e7d00<0057dDO@08e7d00<0057dDO@03U7d0P00
1E7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`0XOol20002
DO@3000dDO@00`00DOAAm00QDO@2000@DO@00`00DO@00005DO@00`00O`ao3003O``00`00Oomoo`0;
Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Qoo`03001Am00000AAm080039Am003001Am57d01mA
m080019Am003001Am00000EAm003001o37l<00=o3003001oogoo00]oo`03001oogoo00aoo`003Goo
00<007ooOol0:7oo00<0057d00001U7d0`00;e7d00<0057dDO@07U7d00<0057dDO@04E7d00@0057d
DO@000EAm003001o37l<00=o3003001oogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo
00@0057dDO@000QAm08002aAm0D001]Am08001AAm004001Am57d0005DO@00`00O`ao3003O``00`00
Oomoo`0<Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Qoo`04001Am57d000:DO@3000WDO@20002
Eil00`009[lV_`06000DDO@00`00DOAAm00CDO@01@00DOAAm57d00001E7d00<007l<O``00gl<00<0
07ooOol037oo00<007ooOol02goo000=Ool00`00Oomoo`0XOol01@00DOAAm57d0000357d0P008U7d
0`001ENO00<002Jo9[l01BJo1P00357d0P005U7d00D0057dDOAAm00000EAm003001o37l<00=o3003
001oogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo00D0057dDOAAm00000iAm0<001aA
m0<000UGW`03000V_bJo00XV_`H000AAm08001MAm003001Am57d009Am003001Am57d00=Am003001o
37l<00=o3003001oogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo00<0057dDO@00U7d
00<0057dDO@03U7d0P00657d0P003ENO00<002Jo9[l03bJo10006E7d00<0057dDO@00U7d00<0057d
DO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02goo000=Ool00`00Oomoo`0XOol0
0`00DOAAm002DO@00`00DOAAm00@DO@3000BDO@3000@Eil00`009[lV_`0B9[l00`00DOAAm00EDO@0
0`00DOAAm003DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02Qoo`03001Am57d00=Am003001Am57d019Am08000eAm0<001AGW`03000V_bJo
014V_`8001IAm003001Am57d00=Am003001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03
001oogoo00]oo`003Goo00<007ooOol0:7oo00<0057dDO@0157d00<0057dDO@04e7d0`00257d0P00
65NO00<002Jo9[l04BJo0P00557d00<0057dDO@0157d00<0057dDO@00e7d0P0017l<00<007ooOol0
37oo00<007ooOol02goo000=Ool00`00Oomoo`0XOol00`00DOAAm004DO@00`00DOAAm00FDO@20003
DO@3000KEil3000A9[l3000BDO@00`00DOAAm004DO@00`00DOAAm003DO@20004O``00`00Oomoo`0<
Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Qoo`03001Am57d00EAm003001Am57d01MAm0<001YG
W`<000Aoo`H000`V_`030000L`00011Am003001Am57d00EAm003001Am57d00=Am08000Ao3003001o
ogoo00aoo`03001oogoo00]oo`003Goo00<007ooOol0:7oo00<0057dDO@01E7d00<0057dDO@05e7d
00<006nk00005eNO0`003Goo1P001RJo00@0001c07<000mAm003001Am57d00EAm003001Am57d00=A
m08000Ao3003001oogoo00aoo`03001oogoo00]oo`0037oo00<007ooOol0:Goo00<0057dDO@01U7d
00<0057dDO@05E7d00D006nkKk]_^`0001=GW`<001Ioo`H000059[l0001c07<0000=DO@00`00DOAA
m006DO@00`00DOAAm003DO@20004O``00`00Oomoo`0<Ool00`00Oomoo`0;Ool000aoo`03001oogoo
02Uoo`03001Am57d00IAm003001Am57d01AAm003001_^fnk00=_^`03001GWeNO00eGW`<001moo`<0
0080L`03001Am57d00YAm003001Am57d00IAm003001Am57d00=Am08000Ao3003001oogoo00aoo`03
001oogoo00]oo`0037oo00<007ooOol0:Goo00<0057dDO@01e7d00<0057dDO@04U7d00<006nkKk/0
1Fnk0P002UNO0`009Goo00@0001c07<000YAm003001Am57d00MAm003001Am57d00AAm003001o37l<
009o3003001oogoo00aoo`03001oogoo00]oo`0037oo00<007ooOol0:Goo00<0057dDO@01e7d00<0
057dDO@04U7d00<006nkKk/01fnk00<005NOEil015NO0`00:Goo00@0001c07<000UAm003001Am57d
00MAm003001Am57d00AAm003001o37l<00=o3003001oogoo00]oo`03001oogoo00]oo`0037oo00<0
07ooOol0:Goo00<0057dDO@0257d00<0057dDO@0457d00<006nkKk/02Fnk00<005NOEil00`00;Goo
0P0000<0L`00DO@01U7d00<0057dDO@0257d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol0
2goo00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00DOAAm008DO@00`00DOAAm00?DO@00`00
Kk]_^`0;Kk/2000bOol0100007<000001E7d00<0057dDO@0257d00<0057dDO@0157d00<007l<O``0
0gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00DOAAm009DO@00`00
DOAAm00=DO@00`00Kk]_^`0;Kk/00`00Oomoo`0cOol0100007<0L`000e7d00<0057dDO@02U7d00<0
057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0Y
Ool00`00DOAAm00:DO@00`00DOAAm00;DO@00`00Kk]_^`0;Kk/00`00Oomoo`0eOol0100007<0L`00
0U7d00<0057dDO@02U7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol0
2goo000<Ool00`00Oomoo`0YOol00`00DOAAm00:DO@00`00DOAAm00:DO@00`00Kk]_^`0;Kk/00`00
Oomoo`0gOol00`0007<0L`02000=DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo02Uoo`03001Am57d00]Am003001Am57d00QAm003001_^fnk
00]_^`03001oogoo03Uoo`80000307<0057d00aAm003001Am57d00=Am003001o37l<00=o3003001o
ogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:Goo00<0057dDO@02e7d00<0057dDO@01e7d
00<006nkKk/036nk00<007ooOol0>goo0P003E7d00<0057dDO@00e7d00<007l<O``00gl<00<007oo
Ool02goo00<007ooOol02goo000<Ool00`00Oomoo`0YOol00`00DOAAm00<DO@00`00DOAAm005DO@0
0`00Kk]_^`0<Kk/00`00Oomoo`0mOol2000<DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomo
o`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo02Uoo`03001Am57d00aAm003001Am57d00AAm003
001_^fnk00a_^`03001oogoo03moo`03001Am57d00YAm003001Am57d00=Am003001o37l<00=o3003
001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:Goo00<0057dDO@03E7d00<0057dDO@0
0e7d00<006nkKk/02fnk00<007ooOol0@7oo00<0057dDO@02U7d00<0057dDO@00e7d00<007l<O``0
0gl<00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0XOol00`00DOAAm00>DO@00`00
DOAAm002DO@00`00Kk]_^`0;Kk/00`00Oomoo`11Ool00`00DOAAm00:DO@00`00DOAAm003DO@00`00
O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo02Qoo`03001Am57d00mA
m004001Am57d000=Kk/00`00Oomoo`13Ool00`00DOAAm009DO@00`00DOAAm003DO@00`00O`ao3003
O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo02Qoo`03001Am57d00mAm003001A
m00000e_^`03001oogoo04Aoo`03001Am57d00UAm003001Am57d00=Am003001o37l<00=o3003001o
ogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:7oo00<0057dDO@0457d00<006nkKk/02fnk
00<007ooOol0AGoo00<0057dDO@02E7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo
00<007ooOol02goo000<Ool00`00Oomoo`0XOol00`00DOAAm00@DO@2000;Kk/00`00Oomoo`17Ool0
0`00DOAAm008DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
00aoo`03001oogoo02Qoo`03001Am57d00mAm004001oMGme0009Kk/00`00Oomoo`18Ool00`00DOAA
m008DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03
001oogoo02Qoo`03001Am57d00mAm005001oMGmeOgD00008Kk/00`00Oomoo`05Ool00`00Oomoo`10
Ool00`00DOAAm008DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;
Ool000aoo`03001oogoo02Qoo`03001Am57d00mAm003001oMGme009oM@8000E_^`03001oogoo00Eo
o`<0045oo`03001Am57d00QAm003001Am57d00=Am003001o37l<00=o3003001oogoo00]oo`03001o
ogoo00]oo`0037oo00<007ooOol0:7oo00<0057dDO@03e7d00<007meOgD017me00D006nkKk]_^`00
00Moo`D0039oo`<000=oo`8000Moo`03001Am57d00MAm003001Am57d00=Am003001o37l<00=o3003
001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol0:7oo00<0057dDO@03U7d00<007meOgD0
1Wme00<006nk00002Goo00<007oo00000`00<Goo00<007ooOol017oo00<007ooOol017oo00<0057d
DO@01e7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02goo000<Ool0
0`00Oomoo`0XOol00`00DOAAm00>DO@00`00OgEoM@07OgD00`00Oomoo`0;Ool4000`Ool30003Ool0
0`00Oomoo`05Ool00`00DOAAm007DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo02Qoo`03001Am57d00iAm003001oMGme00MoM@03001oogoo
00eoo`<002moo`04001oogoo0003Ool00`00Oomoo`04Ool00`00DOAAm007DO@00`00DOAAm003DO@0
0`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo02Qoo`03001Am57d
00eAm003001oMGme00MoM@03001oogoo00moo`<002ioo`08001oogoo001oo`00Ool000Moo`03001A
m57d00IAm003001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`0037oo
00<007ooOol0:7oo00<0057dDO@03E7d00<007meOgD01gme00<007ooOol047oo1000:goo10000goo
00<007ooOol01Woo00<0057dDO@01U7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo
00<007ooOol02Woo000<Ool00`00Oomoo`0XOol00`00DOAAm00=DO@00`00OgEoM@07OgD00`00Oomo
o`0AOol4000jOol00`00DOAAm006DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool0
0`00Oomoo`0:Ool000aoo`03001oogoo02Qoo`03001Am57d00eAm003001oMGme00MoM@03001oogoo
01=oo`<003Yoo`03001Am57d00EAm003001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03
001oogoo00Yoo`0037oo00<007ooOol0:7oo00<0057dDO@0357d00<007meOgD01gme00<007ooOol0
5Goo0`00>Goo00<0057dDO@01E7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<0
07ooOol02Woo000<Ool00`00Oomoo`0XOol00`00DOAAm00<DO@00`00OgEoM@07OgD00`00Oomoo`0F
Ool4000gOol00`00DOAAm005DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00
Oomoo`0:Ool000aoo`03001oogoo02Qoo`03001Am57d00aAm003001oMGme00MoM@03001oogoo00=o
o`<000=oo`<000]oo`@003Ioo`03001Am57d00EAm003001Am57d00=Am003001o37l<00=o3003001o
ogoo00aoo`03001oogoo00Yoo`0037oo00<007ooOol0:7oo00<0057dDO@0357d00<007meOgD01gme
00<007ooOol017oo00<007ooOol00Woo00<007ooOol03Goo0`00=Woo00<0057dDO@0157d1`001Gl<
00<007ooOol037oo00<007ooOol02Woo000<Ool00`00Oomoo`0XOol00`00DOAAm00;DO@00`00OgEo
M@07OgD00`00Oomoo`05Ool30003Ool00`00Oomoo`0=Ool3000eOol80005DO@00`00O`ao3003O``0
0`00Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00]Am003001oMGme
00MoM@03001oogoo00Eoo`04001oogoo0002Ool00`00Oomoo`0>Ool4000JOol=000<Ool00`00DOAA
m004DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03
001oogoo02Uoo`03001Am57d00]Am003001oMGme00MoM@03001oogoo00Eoo`08001oogoo001oo`00
Ool0011oo`@000eooaX000]oo`03001Am57d00AAm003001Am57d00=Am003001o37l<00=o3003001o
ogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@02U7d00<007meOgD027me
00<007ooOol017oo10000goo00<007ooOol04Goo6`0037oo00<007ooOol02Goo00<0057dDO@01E7d
00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02Woo000;Ool00`00Oomo
o`0YOol00`00DOAAm00:DO@00`00OgEoM@07OgD00`00Oomoo`0QOol>000TOol00`00DOAAm005DO@0
0`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo
02Uoo`03001Am57d00YAm003001oMGme00MoM@03001oogoo025oo`<002moo`03001Am57d00EAm003
001Am57d00=Am003001o37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0
:Goo00<0057dDO@02U7d00<007meOgD01gme00<007ooOol08Woo00<007ooOol0;Woo00<0057dDO@0
1E7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02Woo000;Ool00`00
Oomoo`0YOol00`00DOAAm009DO@00`00OgEoM@08OgD00`00Oomoo`1BOol00`00DOAAm006DO@00`00
DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uo
o`03001Am57d00AAm0H000UoM@03001oogoo05=oo`03001Am57d00IAm003001Am57d00=Am003001o
37l<00=o3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:Goo1`001E7d0`001gme
00<007ooOol0Dgoo00<0057dDO@01U7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo
00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm009DO@01000OZYnZP001Wme00<007oo
Ool0Dgoo00<0057dDO@01U7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol037oo00<007oo
Ool02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00:DO@00`00OZYnZP020004OgD00`00Oomoo`1B
Ool00`00DOAAm007DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`0:
Ool000]oo`03001oogoo02Uoo`03001Am57d00YAm003001nZWjZ009nZP04001oMGme001EOol00`00
DOAAm007DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]o
o`03001oogoo02Uoo`03001Am57d00YAm003001nZWjZ00=nZP<0025oo`<0009oo`D002Yoo`03001A
m57d00MAm003001Am57d00=Am08000Ao3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007oo
Ool0:Goo00<0057dDO@02U7d00<007jZOZX01GjZ00<007ooOol087oo00<007ooOol00goo00<007oo
Ool0:Woo00<0057dDO@01e7d00<0057dDO@00e7d0P0017l<00<007ooOol037oo00<007ooOol02Woo
000;Ool00`00Oomoo`0YOol00`00DOAAm00;DO@00`00OZYnZP04OZX00`00Oomoo`0POol30003Ool0
0`00Oomoo`0ZOol00`00DOAAm007DO@00`00DOAAm003DO@20004O``00`00Oomoo`0<Ool00`00Oomo
o`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00]Am003001nZWjZ00AnZP03001oogoo021oo`04
001oogoo0002Ool00`00Oomoo`0YOol00`00DOAAm008DO@00`00DOAAm003DO@20004O``00`00Oomo
o`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00]Am003001nZWjZ00EnZP03
001oogoo01moo`04001oogoo0002Ool00`00Oomoo`0YOol00`00DOAAm008DO@00`00DOAAm003DO@2
0004O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00]Am003
001nZWjZ00EnZP03001oogoo01ioo`@0009oo`8002]oo`03001Am57d00QAm003001Am57d00=Am080
00Ao3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@0357d00<0
07jZOZX017jZ00<007ooOol0DGoo00<0057dDO@0257d00<0057dDO@0157d00<007l<O``00gl<00<0
07ooOol02goo00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00<DO@00`00OZYnZP04
OZX00`00Oomoo`1@Ool00`00DOAAm009DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0;
Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00aAm003001nZWjZ00EnZP03001o
ogoo04moo`03001Am57d00UAm003001Am57d00AAm003001o37l<00=o3003001oogoo00]oo`03001o
ogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@0357d00<007jZOZX01GjZ00<007ooOol0Cgoo
00<0057dDO@02E7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02Woo
000;Ool00`00Oomoo`0YOol00`00DOAAm00=DO@00`00OZYnZP04OZX00`00Oomoo`1?Ool00`00DOAA
m009DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0:Ool000]oo`03
001oogoo02Uoo`03001Am57d00eAm003001nZWjZ00AnZP03001oogoo04ioo`03001Am57d00]Am003
001Am57d00=Am003001o37l<00=o3003001oogoo00]oo`03001oogoo00Yoo`002goo00<007ooOol0
:Goo00<0057dDO@03E7d00<007jZOZX01GjZ00<007ooOol0CGoo00<0057dDO@02e7d00<0057dDO@0
0e7d00<007l<O``00gl<00<007ooOol02goo00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00
DOAAm00=DO@00`00OZYnZP05OZX00`00Oomoo`1=Ool00`00DOAAm00;DO@00`00DOAAm003DO@00`00
O`ao3003O``00`00Oomoo`0;Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00iA
m003001nZWjZ00AnZP03001oogoo04aoo`04001Am000000;DO@00`00DOAAm003DO@00`00O`ao3003
O``00`00Oomoo`0;Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Uoo`03001Am57d00iAm003001n
ZWjZ00AnZP03001oogoo04]oo`03001Am57d009Am08000UAm003001Am57d00=Am003001o37l<00=o
3003001oogoo00]oo`03001oogoo00Yoo`002goo00<007ooOol0:Goo00<0057dDO@03U7d00<007jZ
OZX01GjZ00<007ooOol0BGoo00<0057dDO@01E7d00<0057dDO@01U7d00<0057dDO@00e7d00<007l<
O``00gl<00<007ooOol02goo00<007ooOol02Woo000;Ool00`00Oomoo`0YOol00`00DOAAm00>DO@0
0`00OZYnZP05OZX00`00Oomoo`18Ool00`00DOAAm007DO@20006DO@00`00DOAAm003DO@00`00O`ao
3003O``00`00Oomoo`0<Ool00`00Oomoo`09Ool000]oo`03001oogoo02Uoo`03001Am57d00mAm003
001nZWjZ00AnZP03001oogoo04Moo`03001Am57d00YAm08000AAm003001Am57d00=Am003001o37l<
00=o3003001oogoo00aoo`03001oogoo00Uoo`002goo00<007ooOol0:Goo00<0057dDO@03e7d00<0
07jZOZX017jZ00<007ooOol0AWoo00<0057dDO@03E7d00D0057dDOAAm00000EAm003001o37l<00=o
3003001oogoo00aoo`03001oogoo00Uoo`002goo00<007ooOol0:Goo00<0057dDO@03U7d00@0057d
000000EnZP03001oogoo04Aoo`03001Am57d00mAm0800003DO@0057d00AAm003001o37l<00=o3003
001oogoo00aoo`03001oogoo00Uoo`002goo00<007ooOol0:Goo00<0057dDO@0357d0P000e7d0P00
17jZ00<007ooOol0@goo00<0057dDO@04U7d0P001E7d00<007l<O``00gl<00<007ooOol037oo00<0
07ooOol02Goo000:Ool00`00Oomoo`0ZOol00`00DOAAm00;DO@00`00DOAAm004DO@30002OZX00`00
Oomoo`12Ool00`00DOAAm00DDO@20004DO@00`00O`ao3003O``00`00Oomoo`0<Ool00`00Oomoo`09
Ool000Yoo`03001oogoo02Yoo`03001Am57d00YAm003001Am57d00IAm005001DP000OZX00013Ool0
0`00DOAAm00EDO@01000DO@000000U7d00<007l<O``00gl<00<007ooOol037oo00<007ooOol02Goo
000:Ool00`00Oomoo`0ZOol00`00DOAAm008DO@2000:DO@00`00E80000020012Ool00`00DOAAm00E
DO@01000DOAAm57d0`001Gl<00<007ooOol037oo00<007ooOol02Goo000:Ool00`00Oomoo`0ZOol0
0`00DOAAm007DO@00`00DOAAm00;DO@01000E81DP000@Goo00<0057dDO@05U7d00<0057dDO@00e7d
00<007l<O``00gl<00<007ooOol037oo00<007ooOol02Goo000:Ool00`00Oomoo`0ZOol00`00DOAA
m006DO@00`00DOAAm00=DO@01000E81DP000?goo00<0057dDO@05e7d00<0057dDO@00e7d0P0017l<
00<007ooOol037oo00<007ooOol02Goo000:Ool00`00Oomoo`0ZOol00`00DOAAm005DO@00`00DOAA
m00?DO@01000E81DP000?Goo00<0057dDO@0657d00<0057dDO@00U7d00@007neOkD000=o3003001o
ogoo00aoo`03001oogoo00Uoo`002Woo00<007ooOol0:Woo00<0057dDO@00e7d0P004e7d00@005B0
E80003]oo`03001Am57d01UAm003001Am57d009Am004001o]GneOkD200000gl<001oo`0=Ool00`00
Oomoo`09Ool000Yoo`03001oogoo02Yoo`03001Am57d009Am003001Am57d01AAm004001DP5B0000G
Ool30004Ool3000HOol00`00DOAAm00JDO@01@00DOAAm57d00001Wne0P003Woo00<007ooOol02Goo
000:Ool00`00Oomoo`0ZOol01@00DOAAm57d0000657d00@005B0E80001Moo`03001oogoo00Aoo`03
001oogoo01Ioo`03001Am57d01]Am005001Am57dDO@00007OkD00`00Oomoo`0<Ool00`00Oomoo`09
Ool000Yoo`03001oogoo02Yoo`04001Am000000JDO@01000E81DP0005Woo0`000Woo10005Woo00<0
057dDO@0757d00@0057dDO@000Qo]@03001oogoo00aoo`03001oogoo00Uoo`002Woo00<007ooOol0
:Woo0P007E7d00@005B0E80001Eoo`08001oogoo001oo`00Ool001Ioo`03001Am57d01eAm004001A
m57d0007OkD00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03001oogoo02Yoo`03001Am57d01eA
m003001DP5B0008001=oo`04001oogoo0002Ool2000EOol00`00DOAAm00NDO@00`00DO@00008OkD0
0`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03001oogoo02Yoo`03001Am57d01iAm005001DP5B0
E800000AOol40004Ool00`00Oomoo`0COol2000ODO@00`00DO@00007OkD00`00Oomoo`0>Ool00`00
Oomoo`09Ool000Yoo`03001oogoo02]oo`03001Am57d01iAm005001DP5B0E800000^Ool2000ODO@0
0`00DO@00007OkD00`00Oomoo`0>Ool00`00Oomoo`09Ool000Yoo`03001oogoo02]oo`03001Am57d
01mAm005001DP5B0E800000]Ool00`00DO@0000NDO@20008OkD00`00Oomoo`0>Ool00`00Oomoo`09
Ool000Yoo`03001oogoo02aoo`03001Am57d01mAm005001DP5B0E800000/Ool01000DOAAm0007E7d
0P001gne00<007ooOol03goo00<007ooOol02Goo000:Ool00`00Oomoo`0/Ool00`00DOAAm00NDO@4
0002E8000`00Oomoo`0YOol01000DOAAm0007E7d00<007neOkD01Wne00<007ooOol03goo00<007oo
Ool02Goo000:Ool00`00Oomoo`0/Ool00`00DOAAm00NDO@20002Oc0200000eB0001oo`0YOol01@00
DOAAm57d0000757d00<007neOkD01Gne00<007ooOol047oo00<007ooOol02Goo000:Ool00`00Oomo
o`0]Ool00`00DOAAm00LDO@00`00DO@00004Oc03000YOol00`00DOAAm002DO@00`00DOAAm00HDO@2
0007OkD00`00Oomoo`0@Ool00`00Oomoo`09Ool000Yoo`03001oogoo02eoo`03001Am57d01]Am004
001Am57d0006Oc02000?Ool00`00Oomoo`0FOol00`00DOAAm002DO@00`00DOAAm00HDO@20007OkD0
0`00Oomoo`0@Ool00`00Oomoo`09Ool000Yoo`03001oogoo02eoo`8001aAm004001Am57d0007Oc00
0`00Oomoo`0<Ool3000GOol00`00DOAAm003DO@00`00DOAAm00FDO@00`00OkD00006OkD00`00Oomo
o`0AOol00`00Oomoo`09Ool000Yoo`03001oogoo02eoo`8001]Am005001Am57dDO@00007Oc000`00
Oomoo`0<Ool2000HOol00`00DOAAm004DO@00`00DOAAm00EDO@00`00OkD00006OkD00`00Oomoo`0A
Ool00`00Oomoo`09Ool000Yoo`03001oogoo02eoo`03001oo`0001UAm003001Am57d009Am003001o
<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00EAm003001Am57d019Am0800003Emh00000
00Io]@03001oogoo015oo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00@007ooOol001UAm003
001Am57d009Am003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00EAm003001Am57d
011Am08000AGgP8000Ao]@03001oogoo019oo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00@0
07ooOol001QAm003001Am57d00=Am003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d
00IAm003001Am57d00eAm08000IGgP03001GgP0000=o]@03001oogoo019oo`03001oogoo00Uoo`00
2Woo00<007ooOol0;7oo00D007ooOomoo`0001IAm003001Am57d00AAm003001o<7l`00Eo<003001o
ogoo00aoo`8001Qoo`03001Am57d00MAm003001Am57d00YAm08000QGgP03001GgUON00<001Eoo`03
001oogoo00Uoo`002Woo00<007ooOol0;7oo00D007ooOomoo`0001IAm003001Am57d00AAm003001o
<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00MAm003001Am57d00QAm08000YGgP03001G
gUON009GgP03001oogoo01=oo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00<007ooOol00Woo
00<0057dDO@04U7d00<0057dDO@01E7d00<007l`Oc001Gl`00<007ooOol037oo0P0067oo00<0057d
DO@0257d00<0057dDO@01E7d0P0035ON00<005ONEmh00P005Woo00<007ooOol02Goo000:Ool00`00
Oomoo`0/Ool00`00Oomoo`02Ool2000CDO@00`00DOAAm005DO@00`00Oc1o<005Oc000`00Oomoo`0<
Ool2000HOol00`00DOAAm009DO@00`00DOAAm002DO@2000>Emh3000HOol00`00Oomoo`09Ool000Yo
o`03001oogoo02aoo`03001oogoo00=oo`<0011Am003001Am57d00IAm003001o<7l`00Eo<003001o
ogoo00aoo`8001Qoo`03001Am57d00UAm003001Am57d008000mGgP8001Yoo`03001oogoo00Uoo`00
2Woo00<007ooOol0;7oo00<007ooOol01Goo0`003E7d00<0057dDO@01e7d00<007l`Oc001Gl`00<0
07ooOol037oo0P0067oo00<0057dDO@02U7d0P003eON0P0000=oo`00Ool06Goo00<007ooOol02Goo
000:Ool00`00Oomoo`0/Ool00`00Oomoo`07Ool3000;DO@00`00DOAAm007DO@00`00Oc1o<005Oc00
0`00Oomoo`0<Ool2000HOol00`00DOAAm00:DO@3000<Emh20003Ool00`00Oomoo`0HOol00`00Oomo
o`09Ool000Yoo`03001oogoo02aoo`03001oogoo00Uoo`@000MAm003001Am57d00QAm003001o<7l`
00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00YAm004001o;Gl]0009Emh20005Ool00`00Oomo
o`0IOol00`00Oomoo`08Ool000Yoo`03001oogoo02aoo`03001oogoo00]oo`@000AAm003001Am57d
00UAm003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00YAm005001o;Gl]Obd00006
Emh20007Ool00`00Oomoo`0IOol00`00Oomoo`08Ool000Yoo`03001oogoo02aoo`03001oogoo00eo
o`@0009Am003001Am57d00UAm003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00YA
m003001o;Gl]009o;@80009GgP8000Uoo`03001oogoo01Uoo`03001oogoo00Qoo`002Goo00<007oo
Ool0;Goo00<007ooOol03goo1000357d00<007l`Oc001Gl`00<007ooOol037oo0P0067oo00<0057d
DO@02U7d00<007l]Obd017l]0P002goo00<007ooOol06Goo00<007ooOol027oo0009Ool00`00Oomo
o`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`0<Ool2000HOol0
0`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`08Ool0
00Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo
00aoo`8001Qoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03
001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02U7d00<007l`Oc00
1Gl`00<007ooOol037oo0P0067oo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02Woo00<0
07ooOol06Goo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:
DO@00`00Oc1o<005Oc000`00Oomoo`0<Ool2000HOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00
Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019o
o`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00YAm003001o
;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo
00<007ooOol04Woo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol037oo0P0067oo00<0057d
DO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool0
0`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`0<Ool2
000HOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomo
o`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d00YAm003001o<7l`00Eo<003
001oogoo00aoo`8001Qoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo
01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02U7d00<0
07l`Oc001Gl`00<007ooOol037oo0P0067oo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol0
2goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00
DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`0<Ool2000HOol00`00DOAAm00:DO@00`00Obeo;@04
Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001o
ogoo019oo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00YA
m003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007oo
Ool0;Goo00<007ooOol04Woo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol037oo0P0067oo
00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo
0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomo
o`0<Ool2000HOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol0
0`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d00YAm003001o<7l`
00Eo<003001oogoo00aoo`8001Qoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03
001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@0
2U7d00<007l`Oc001Gl`00<007ooOol037oo0P0067oo00<0057dDO@02U7d00<007l]Obd017l]00<0
07ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0B
Ool00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`0<Ool2000HOol00`00DOAAm00:DO@00`00
Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eo
o`03001oogoo019oo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00aoo`8001Qoo`03001A
m57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo
00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol037oo
0P0067oo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007oo
Ool027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm00:DO@00`00Oc1o<005Oc00
0`00Oomoo`0<Ool2000HOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomo
o`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d00YAm003
001o<7l`00Eo<003001oogoo00aoo`8001Uoo`03001Am57d00UAm003001o;Gl]00Ao;@03001oogoo
00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0
057dDO@02U7d00<007l`Oc001Gl`00<007ooOol037oo0P006Goo00<0057dDO@02E7d00<007l]Obd0
17l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00
Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm009
DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001o
ogoo02eoo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uo
o`03001Am57d00UAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qo
o`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007oo
Ool037oo0P006Goo00<0057dDO@02E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo
00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o
<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm009DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool0
0`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03001Am57d
00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00UAm003001o;Gl]00Ao;@03
001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol0
4Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02E7d00<0
07l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00Oomoo`0]
Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00
DOAAm009DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uo
o`03001oogoo02eoo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00ao
o`8001Uoo`03001Am57d00UAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001o
ogoo00Qoo`002Goo00<007ooOol0;Goo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`
00<007ooOol037oo0P006Goo00<0057dDO@02E7d00<007l]Obd017l]00<007ooOol02goo00<007oo
Ool067oo00<007ooOol027oo0009Ool00`00Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm009DO@0
0`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm009DO@00`00Obeo;@04Obd00`00Oomo
o`0;Ool00`00Oomoo`0HOol00`00Oomoo`08Ool000Uoo`03001oogoo02eoo`03001oogoo019oo`03
001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00UAm003001o;Gl]
00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Qoo`002Goo00<007ooOol0;Goo00<0
07ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@0
2E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol027oo0009Ool00`00
Oomoo`0]Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000I
Ool00`00DOAAm009DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`08
Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001o
ogoo00aoo`8001Uoo`03001Am57d00UAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Uo
o`03001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`
Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02U7d00<007l]Obd00gl]00<007ooOol02goo
00<007ooOol06Goo00<007ooOol01goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAA
m009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm00:DO@00`00Obeo;@03Obd0
0`00Oomoo`0;Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03001oogoo
019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00YAm003
001o;Gl]00=o;@03001oogoo00]oo`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0
;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0
057dDO@02U7d00<007l]Obd00gl]00<007ooOol02goo00<007ooOol06Goo00<007ooOol01goo0008
Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<
Ool2000IOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00
Oomoo`07Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io
<003001oogoo00aoo`8001Uoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03001o
ogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d
00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02U7d00<007l]Obd017l]00<007oo
Ool02Woo00<007ooOol06Goo00<007ooOol01goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol0
0`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm00:DO@00`00Obeo
;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03
001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d
00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<0
07ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P00
6Goo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<007ooOol0
1goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00
Oomoo`0<Ool2000IOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0I
Ool00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001Am57d00UAm003001o
<7l`00Io<003001oogoo00aoo`8001Uoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00Yo
o`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo00<0057d
DO@02E7d00<007l`Oc001Wl`00<007ooOol037oo0P006Goo00<0057dDO@02U7d00<007l]Obd017l]
00<007ooOol02Woo00<007ooOol06Goo00<007ooOol01goo0008Ool00`00Oomoo`0^Ool00`00Oomo
o`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0<Ool2000IOol00`00DOAAm00:DO@0
0`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo
02ioo`03001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00aoo`8001Uoo`03
001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Moo`00
27oo00<007ooOol0;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol0
37oo0`0067oo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<0
07ooOol01goo0008Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006
Oc000`00Oomoo`0=Ool00`00Oomoo`0GOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0:
Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03001oogoo019oo`03001A
m57d00UAm003001o<7l`00Io<003001oogoo02Moo`03001Am57d00YAm003001o;Gl]00Ao;@03001o
ogoo00Yoo`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0;Woo00<007ooOol04Woo
00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol09goo00<0057dDO@02U7d00<007l]Obd017l]
00<007ooOol02Woo00<007ooOol06Goo00<007ooOol01goo0008Ool00`00Oomoo`0^Ool00`00Oomo
o`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0WOol00`00DOAAm00:DO@00`00Obeo
;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000Qoo`03001oogoo02ioo`03
001oogoo019oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo02Moo`03001Am57d00YAm003
001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo00Moo`0027oo00<007ooOol0
;Woo00<007ooOol04Woo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol09goo00<0057dDO@0
2U7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06Goo00<007ooOol01goo0008Ool00`00
Oomoo`0^Ool00`00Oomoo`0BOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0WOol00`00
DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool000Qo
o`03001oogoo02eoo`03001oogoo01=oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00Qo
o`<000Aoo`03001oogoo01Eoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001o
ogoo01Qoo`03001oogoo00Moo`0027oo00<007ooOol0;Goo00<007ooOol04goo00<0057dDO@02E7d
00<007l`Oc001Wl`00<007ooOol02Goo00<007ooOol00Woo00<007oo00005Woo00<0057dDO@02U7d
00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol01goo0008Ool00`00Oomo
o`0]Ool00`00Oomoo`0COol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`09Ool30004Ool0
0`00Oomoo`0DOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol0
0`00Oomoo`07Ool000Qoo`03001oogoo02eoo`03001oogoo01=oo`03001Am57d00UAm003001o<7l`
00Io<003001oogoo00Uoo`05001oogoo001oo`02000GOol00`00DOAAm00:DO@00`00Obeo;@04Obd0
0`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool000Qoo`03001oogoo02eoo`03001oogoo
01=oo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00Uoo`05001oogoo001oo`0J000<DO@0
0`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool000Qoo`03001oogoo
02eoo`03001oogoo01=oo`03001Am57d00UAm1d001MAm003001Am57d00UAm003001o;Gl]00Ao;@03
001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Moo`0027oo00<007ooOol0;Goo00<007ooOol0
4goo00<0057dDO@0257d00<0057dDO@0<e7d00<0057dDO@0257d00<007l]Obd017l]00<007ooOol0
2goo00<007ooOol067oo00<007ooOol01goo0008Ool00`00Oomoo`0]Ool00`00Oomoo`0COol00`00
DOAAm007DO@00`00DOAAm00eDO@00`00DOAAm007DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00
Oomoo`0HOol00`00Oomoo`07Ool000Qoo`03001oogoo02eoo`03001oogoo01=oo`03001Am57d00IA
m003001Am57d03MAm003001Am57d00IAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qo
o`03001oogoo00Moo`0027oo00<007ooOol0;Goo00<007ooOol04goo00<0057dDO@01U7d00<0057d
DO@0>57d00<0057dDO@01E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007oo
Ool01goo0008Ool00`00Oomoo`0]Ool00`00Oomoo`0COol00`00DOAAm005DO@00`00DOAAm00jDO@0
0`00DOAAm004DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00Oomoo`07Ool0
00Moo`03001oogoo02ioo`03001oogoo01=oo`03001Am57d00AAm003001Am57d03aAm003001Am57d
00=Am003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00Moo`001goo00<0
07ooOol0;Woo00<007ooOol04goo00<0057dDO@00e7d00<0057dDO@0?U7d00<0057dDO@00U7d00<0
07l]Obd017l]00<007ooOol02goo00<007ooOol067oo00<007ooOol01goo0007Ool00`00Oomoo`0^
Ool00`00Oomoo`0COol00`00DOAAm002DO@00`00DOAAm010DO@01@00DOAAm57d00001Wl]00<007oo
Ool02goo00<007ooOol067oo00<007ooOol01goo0007Ool00`00Oomoo`0^Ool00`00Oomoo`0COol0
1@00DOAAm57d0000A57d00@0057dDO@000Io;@03001oogoo00]oo`03001oogoo01Uoo`03001oogoo
00Ioo`001goo00<007ooOol0;Woo00<007ooOol04goo00@0057dDO@004IAm003001Am00000Io;@03
001oogoo00]oo`03001oogoo01Uoo`03001oogoo00Ioo`001goo00<007ooOol0;Woo00<007ooOol0
4goo00@0057dDO@004MAm08000Io;@03001oogoo00]oo`03001oogoo01Uoo`03001oogoo00Ioo`00
1goo00<007ooOol0;Woo00<007ooOol04goo00<0057d0000=e7d50001Gl]00<007ooOol02goo00<0
07ooOol06Goo00<007ooOol01Woo0007Ool00`00Oomoo`0^Ool00`00Oomoo`0COol2000BDO@V000D
5]/400000gl]001oo`0<Ool00`00Oomoo`0IOol00`00Oomoo`06Ool000Moo`03001oogoo02ioo`03
001oogoo01=ooa@003hFf`8000eoo`03001oogoo01Uoo`03001oogoo00Ioo`001goo00<007ooOol0
;Woo00<007ooOol05Woo10005AKK9@0087oo00<007ooOol06Goo00<007ooOol01Woo0007Ool00`00
Oomoo`0^Ool00`00Oomoo`0JOolE0015Ool00`00Oomoo`0IOol00`00Oomoo`06Ool000Moo`03001o
ogoo02ioo`03001oogoo07Aoo`03001oogoo01Uoo`03001oogoo00Ioo`001goo00<007ooOol0;Woo
00<007ooOol0M7oo00<007ooOol06Goo00<007ooOol01Woo0007Ool00`00Oomoo`0^Ool00`00Oomo
o`1POolF000JOol00`00Oomoo`06Ool000Moo`03001oogoo02ioo`03001oogoo03IoobX001Ioo`@0
01Ioo`03001oogoo00Ioo`001goo00<007ooOol0;Woo00<007ooOol037oo:P00A7oo0`004goo00<0
07ooOol01Woo0007Ool00`00Oomoo`0COolZ001aOol4000?Ool00`00Oomoo`06Ool000MooaH001]o
o`03001oogoo085oo`<000aoo`03001oogoo00Ioo`002goo1`009Woo00<007ooOol0Q7oo100027oo
00<007ooOol01Woo000BOol7000OOol00`00Oomoo`28Ool30005Ool00`00Oomoo`06Ool001Uoo`L0
01Qoo`03001oogoo08]oo`@00003Ool007oo00Moo`0087oo1`004Goo00<007ooOol0N7oo6@0027oo
000WOol7000:Ool00`00Oomoo`17Oola000QOol002ioo`L000=oo`03001oogoo01Iooc40059oo`00
=Goo7000Pgoo003DOol00=Aoo`00e7oo003DOol00=Aoo`00e7oo003DOol00001\
\>"],
  ImageRangeCache->{{{0, 211}, {286, 0}} -> {0.122254, -0.0258127, 0.00344856,
   0.00344856}}]
}, Open  ]],

Cell[TextData["Crankshaft"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The local coordinate system of the crankshaft originates at its rotational \
center."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three local point coordinates are used on the crankshaft.\nP1 and P2 are \
two points that define the rotational axis of the crankshaft. P1 is on the \
local origin and P2 is on the positive local ",
  StyleBox["z",
    FontSlant->"Italic"],
  " axis.\nP3 is a point on the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis that is used as the attachment point of the connecting rod and as a \
reference point to control the rotation of the crank."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the crankshaft. The local point coordinates on the \
crankshaft are\nP1 {0,0,0}, P2 {0,0,5}, and P3 {3,0,0}."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98845 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00433619 1.04973 0.0262432 1.04973 [
[ 0 0 0 0 ]
[ 1 .98845 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .98845 L
0 .98845 L
closepath
clip
newpath
p
.002 w
.29885 .30692 m
.06071 .13163 L
s
.06071 .13163 m
.02624 .92898 L
s
.02624 .92898 m
.28514 .96221 L
s
.28514 .96221 m
.29885 .30692 L
s
.94661 .23751 m
.97376 .94916 L
s
.97376 .94916 m
.86642 .90857 L
s
.86642 .90857 m
.8408 .02624 L
s
.8408 .02624 m
.94661 .23751 L
s
.29885 .30692 m
.06071 .13163 L
s
.06071 .13163 m
.8408 .02624 L
s
.8408 .02624 m
.94661 .23751 L
s
.94661 .23751 m
.29885 .30692 L
s
.28514 .96221 m
.97376 .94916 L
s
.97376 .94916 m
.86642 .90857 L
s
.86642 .90857 m
.02624 .92898 L
s
.02624 .92898 m
.28514 .96221 L
s
P
p
.002 w
.49735 .42898 m .42769 .50612 L .40693 .49312 L p
.87 .922 .859 r
F P
s
P
p
.002 w
.42769 .50612 m .40147 .60632 L .38003 .59544 L p
.971 .856 .669 r
F P
s
P
p
.002 w
.38003 .59544 m .40693 .49312 L .42769 .50612 L p
.971 .856 .669 r
F P
s
P
p
.002 w
.59355 .39416 m .49735 .42898 L .47806 .41425 L p
.668 .89 .978 r
F P
s
P
p
.002 w
.40693 .49312 m .47806 .41425 L .49735 .42898 L p
.87 .922 .859 r
F P
s
P
p
.002 w
.40147 .60632 m .42589 .70492 L .40472 .69609 L p
.972 .666 .367 r
F P
s
P
p
.002 w
.40472 .69609 m .38003 .59544 L .40147 .60632 L p
.972 .666 .367 r
F P
s
P
p
.002 w
.47806 .41425 m .57618 .37851 L .59355 .39416 L p
.668 .89 .978 r
F P
s
P
p
.002 w
.59427 .51868 m .59355 .39416 L .57618 .37851 L p
.998 .787 .477 r
F P
s
P
p
.002 w
.42589 .70492 m .49636 .77642 L .47643 .76906 L p
.74 .221 0 r
F P
s
P
p
.002 w
.47643 .76906 m .40472 .69609 L .42589 .70492 L p
.74 .221 0 r
F P
s
P
p
.002 w
.40693 .49312 m .47806 .41425 L p
.57794 .79337 L .633 .48 .657 r
F P
s
P
p
.002 w
.38003 .59544 m .40693 .49312 L p
.57794 .79337 L .633 .48 .657 r
F P
s
P
p
.002 w
.57618 .37851 m .57672 .50563 L .59427 .51868 L p
.998 .787 .477 r
F P
s
P
p
.002 w
.7815 .50452 m .59427 .51868 L .57672 .50563 L p
.451 .813 .996 r
F P
s
P
p
.002 w
.47806 .41425 m .57618 .37851 L .57794 .79337 L p
.633 .48 .657 r
F P
s
P
p
.002 w
.40472 .69609 m .38003 .59544 L p
.57794 .79337 L .633 .48 .657 r
F P
s
P
p
.002 w
.49636 .77642 m .5959 .8003 L .57794 .79337 L p
0 .491 .775 r
F P
s
P
p
.002 w
.57794 .79337 m .47643 .76906 L .49636 .77642 L p
0 .491 .775 r
F P
s
P
p
.002 w
.59514 .66949 m .78498 .65884 L .77116 .64853 L p
.366 .793 .971 r
F P
s
P
p
.002 w
.77116 .64853 m .57737 .65967 L .59514 .66949 L p
.366 .793 .971 r
F P
s
P
p
.002 w
.5959 .8003 m .59514 .66949 L .57737 .65967 L p
.998 .787 .477 r
F P
s
P
p
.002 w
.57794 .79337 m .47643 .76906 L .40472 .69609 L p
.633 .48 .657 r
F P
s
P
p
.002 w
.77116 .64853 m .57737 .65967 L .57672 .50563 L p
.633 .48 .657 r
F P
s
P
p
.002 w
.78467 .5681 m .77116 .64853 L p
.57672 .50563 L .633 .48 .657 r
F P
s
P
p
.002 w
.57672 .50563 m .7678 .49082 L .7815 .50452 L p
.451 .813 .996 r
F P
s
P
p
.002 w
.57672 .50563 m .7678 .49082 L .78467 .5681 L p
.633 .48 .657 r
F P
s
P
p
.002 w
.79811 .58017 m .7815 .50452 L .7678 .49082 L p
.946 .643 .197 r
F P
s
P
p
.002 w
.57737 .65967 m .57794 .79337 L .5959 .8003 L p
.998 .787 .477 r
F P
s
P
p
.002 w
.78498 .65884 m .79811 .58017 L .78467 .5681 L p
.994 .866 .534 r
F P
s
P
p
.002 w
.7678 .49082 m .78467 .5681 L .79811 .58017 L p
.946 .643 .197 r
F P
s
P
p
.002 w
.78467 .5681 m .77116 .64853 L .78498 .65884 L p
.994 .866 .534 r
F P
s
P
p
.002 w
.70883 .55974 m .71745 .53733 L .73263 .55028 L p
.972 .925 .679 r
F P
s
P
p
.002 w
.73263 .55028 m .72421 .57218 L .70883 .55974 L p
.972 .925 .679 r
F P
s
P
p
.002 w
.75372 .53996 m .73263 .55028 L .71745 .53733 L p
.695 .94 .962 r
F P
s
P
p
.002 w
.73263 .55028 m .72421 .57218 L p
.77623 .5902 L .633 .48 .657 r
F P
s
P
p
.002 w
.75372 .53996 m .73263 .55028 L p
.77623 .5902 L .633 .48 .657 r
F P
s
P
p
.002 w
.71818 .58098 m .70883 .55974 L .72421 .57218 L p
.875 .481 .017 r
F P
s
P
p
.002 w
.72421 .57218 m .7334 .59298 L .71818 .58098 L p
.875 .481 .017 r
F P
s
P
p
.002 w
.72421 .57218 m .7334 .59298 L p
.77623 .5902 L .633 .48 .657 r
F P
s
P
p
.002 w
.71745 .53733 m .73902 .52674 L .75372 .53996 L p
.695 .94 .962 r
F P
s
P
p
.002 w
.77529 .54728 m .75372 .53996 L .73902 .52674 L p
.023 .518 .874 r
F P
s
P
p
.002 w
.77529 .54728 m .75372 .53996 L p
.77623 .5902 L .633 .48 .657 r
F P
s
P
p
.002 w
.74017 .58864 m .71818 .58098 L .7334 .59298 L p
0 .489 .844 r
F P
s
P
p
.002 w
.7334 .59298 m .75493 .6005 L .77623 .5902 L p
.633 .48 .657 r
F P
s
P
p
.002 w
.7334 .59298 m .75493 .6005 L .74017 .58864 L p
0 .489 .844 r
F P
s
P
p
.01 w
.55857 .57015 m
.45178 .50091 L
s
P
p
.02 w
.55857 .57015 Mdot
P
p
.002 w
.73902 .52674 m .76104 .53419 L .77529 .54728 L p
.023 .518 .874 r
F P
s
P
p
.002 w
.77623 .5902 m .78467 .5681 L .77529 .54728 L p
.633 .48 .657 r
F P
s
P
p
.002 w
.78467 .5681 m .77529 .54728 L .76104 .53419 L p
.848 .453 0 r
F P
s
P
p
.002 w
.76194 .57807 m .74017 .58864 L .75493 .6005 L p
.682 .945 .96 r
F P
s
P
p
.002 w
.75493 .6005 m .77623 .5902 L .76194 .57807 L p
.682 .945 .96 r
F P
s
P
p
.002 w
.76104 .53419 m .7706 .55546 L .78467 .5681 L p
.848 .453 0 r
F P
s
P
p
.002 w
.77623 .5902 m .78467 .5681 L .7706 .55546 L p
.971 .93 .666 r
F P
s
P
p
.002 w
.7706 .55546 m .76194 .57807 L .77623 .5902 L p
.971 .93 .666 r
F P
s
P
p
.002 w
.71745 .53733 m .70883 .55974 L p
.76194 .57807 L .631 .478 .656 r
F P
s
P
p
.002 w
.73902 .52674 m .71745 .53733 L p
.76194 .57807 L .631 .478 .656 r
F P
s
P
p
.002 w
.70883 .55974 m .71818 .58098 L p
.76194 .57807 L .631 .478 .656 r
F P
s
P
p
.01 w
.55857 .57015 m
.70883 .55974 L
s
P
p
.002 w
.76104 .53419 m .73902 .52674 L p
.76194 .57807 L .631 .478 .656 r
F P
s
P
p
.01 w
.70883 .55974 m
.73959 .5576 L
s
P
p
.002 w
.71818 .58098 m .74017 .58864 L .76194 .57807 L p
.631 .478 .656 r
F P
s
P
p
.02 w
.73959 .5576 Mdot
P
p
.002 w
.76194 .57807 m .7706 .55546 L .76104 .53419 L p
.631 .478 .656 r
F P
s
P
p
.02 w
.45178 .50091 Mdot
P
p
.002 w
.94661 .23751 m
.97376 .94916 L
s
.97376 .94916 m
.86642 .90857 L
s
.86642 .90857 m
.8408 .02624 L
s
.8408 .02624 m
.94661 .23751 L
s
.28514 .96221 m
.97376 .94916 L
s
.97376 .94916 m
.86642 .90857 L
s
.86642 .90857 m
.02624 .92898 L
s
.02624 .92898 m
.28514 .96221 L
s
P
p
[(P1)] .55857 .57015 .6 -2 Mshowa
[(P2)] .45178 .50091 .6 -2.2 Mshowa
[(P3)] .73959 .5576 2 -2 Mshowa
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 209},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D0000dA000`40O003h00Oe7oo003DOol00=Ao
o`00e7oo003DOol00=Aoo`00[Woo10008Woo002VOol80003Ool00`00Oomoo`0POol009moo`L000]o
o`80025oo`00Ugoo20004Woo0P008Goo002@Ool7000JOol00`00Ool0000POol008Uoo`L0025oo`03
001oo`00021oo`00PGoo2000:7oo00@007ooOol001moo`00NWoo1`00<7oo00@007ooOol001moo`00
LWoo2000=goo00D007ooOomoo`0001ioo`00Jgoo1`00?goo00D007ooOomoo`0001ioo`00Hgoo2000
AWoo00<007ooOol00Woo00<007ooOol06goo001LOol7001>Ool00`00Oomoo`02Ool00`00Oomoo`0K
Ool005Aoo`P005Eoo`03001oogoo00=oo`03001oogoo01Yoo`00CGoo1`00GGoo00<007ooOol00goo
00<007ooOol06Woo0015Ool8001TOol00`00Oomoo`04Ool00`00Oomoo`0IOol003ioo`L006aoo`03
001oogoo00Aoo`03001oogoo01Uoo`00=goo1`00Lgoo00<007ooOol01Goo00<007ooOol067oo000_
Ool8001jOol00`00Oomoo`05Ool00`00Oomoo`0HOol002Qoo`L0089oo`03001oogoo00Ioo`03001o
ogoo01Moo`0087oo2000RWoo00<007ooOol01Goo00<007ooOol05goo000IOol7002BOol00`00Oomo
o`06Ool00`00Oomoo`0FOol0015oo`P009Uoo`03001oogoo00Ioo`03001oogoo01Ioo`003Goo1000
XGoo00<007ooOol01goo00<007ooOol05Goo000=Ool3002ROol00`00Oomoo`07Ool00`00Oomoo`0E
Ool000eoo`04001oogoo002QOol00`00Oomoo`08Ool00`00Oomoo`0DOol000eoo`05001oogooOol0
002POol00`00Oomoo`08Ool00`00Oomoo`0DOol000eoo`03001oogoo009oo`8009ioo`03001oogoo
00Uoo`03001oogoo01=oo`003Goo00<007ooOol017oo00<007ooOol0Vgoo00<007ooOol02Goo00<0
07ooOol04goo000=Ool00`00Oomoo`05Ool00`00Oomoo`2JOol00`00Oomoo`0:Ool00`00Oomoo`0B
Ool000eoo`03001oogoo00Ioo`8009Yoo`03001oogoo00Yoo`03001oogoo019oo`003Goo00<007oo
Ool027oo00<007ooOol0Ugoo00<007ooOol02goo00<007ooOol04Goo000=Ool00`00Oomoo`09Ool0
0`00Oomoo`2FOol00`00Oomoo`0;Ool00`00Oomoo`0AOol000eoo`03001oogoo00Yoo`8009Ioo`03
001oogoo00aoo`03001oogoo011oo`0037oo00<007ooOol03Goo00<007ooOol0Tgoo00<007ooOol0
37oo00<007ooOol047oo000<Ool00`00Oomoo`0>Ool00`00Oomoo`2BOol00`00Oomoo`0=Ool00`00
Oomoo`0?Ool000aoo`03001oogoo00moo`80099oo`03001oogoo00eoo`03001oogoo00moo`0037oo
00<007ooOol04Goo00<007ooOol0Sgoo00<007ooOol03Woo00<007ooOol03Woo000<Ool00`00Oomo
o`0BOol00`00Oomoo`2>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool000aoo`03001oogoo01=oo`80
08ioo`03001oogoo00moo`03001oogoo00eoo`0037oo00<007ooOol05Goo00<007ooOol0Rgoo00<0
07ooOol03goo00<007ooOol03Goo000<Ool00`00Oomoo`0FOol00`00Oomoo`2:Ool00`00Oomoo`0@
Ool00`00Oomoo`0<Ool000aoo`03001oogoo01Moo`8008Yoo`03001oogoo011oo`03001oogoo00ao
o`0037oo00<007ooOol06Goo00<007ooOol0Qgoo00<007ooOol04Goo00<007ooOol02goo000<Ool0
0`00Oomoo`0JOol20027Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool000aoo`03001oogoo01aoo`03
001oogoo08Aoo`03001oogoo00ioo`D000aoo`0037oo00<007ooOol07Goo00<007ooOol0Pgoo00<0
07ooOol01Goo2@0017oo00<007ooOol02Woo000<Ool00`00Oomoo`0NOol20022Ool9000=Ool00`00
Oomoo`0:Ool000aoo`03001oogoo021oo`03001oogoo07Ioo`T00003Ool007oo01=oo`03001oogoo
00Yoo`0037oo00<007ooOol08Goo00<007ooOol0K7oo2@002Woo00<007ooOol04Woo00<007ooOol0
2Woo000<Ool00`00Oomoo`0ROol2001SOol9000COol00`00Oomoo`0BOol00`00Oomoo`0:Ool000ao
o`03001oogoo02Aoo`03001oogoo05Moo`T001aoo`03001oogoo019oo`03001oogoo00Yoo`0037oo
00<007ooOol09Goo00<007ooOol0CGoo2@009Goo00<007ooOol04Woo00<007ooOol02Woo000<Ool0
0`00Oomoo`0VOol20013Ool:000^Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool000aoo`03001oogoo
02Qoo`03001oogoo03Moo`T003Qoo`03001oogoo019oo`03001oogoo00Yoo`002goo00<007ooOol0
:Woo00<007ooOol0;Goo2@00@Goo00<007ooOol04Woo00<007ooOol02Woo000;Ool00`00Oomoo`0[
Ool2000TOol9001:Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool000]oo`03001oogoo02eoo`03001o
ogoo01Qoo`T005Aoo`03001oogoo015oo`03001oogoo00Yoo`002goo00<007ooOol0;Woo00<007oo
Ool03Woo2@00GGoo00<007ooOol04Woo00<007ooOol02Goo000;Ool00`00Oomoo`0_Ool20005Ool9
001VOol00`00Oomoo`0BOol00`00Oomoo`09Ool000]oo`03001oogoo035oo`D006moo`03001oogoo
019oo`03001oogoo00Uoo`002goo00<007ooOol0<Goo00<007ooOol0LGoo00<007ooOol04Woo00<0
07ooOol02Goo000;Ool00`00Oomoo`0aOol00`00Oomoo`1aOol00`00Oomoo`0BOol00`00Oomoo`09
Ool000]oo`03001oogoo035oo`03001oogoo075oo`03001oogoo019oo`03001oogoo00Uoo`002goo
00<007ooOol0<Goo00<007ooOol0LGoo00<007ooOol04Woo00<007ooOol02Goo000;Ool00`00Oomo
o`0aOol00`00Oomoo`1aOol00`00Oomoo`0BOol00`00Oomoo`09Ool000]oo`03001oogoo035oo`03
001oogoo075oo`03001oogoo019oo`03001oogoo00Uoo`002goo00<007ooOol0<Goo00<007ooOol0
LGoo00<007ooOol04Woo00<007ooOol02Goo000;Ool00`00Oomoo`0aOol00`00Oomoo`1aOol00`00
Oomoo`0BOol00`00Oomoo`09Ool000]oo`03001oogoo035oo`03001oogoo075oo`03001oogoo019o
o`03001oogoo00Uoo`002goo00<007ooOol0<Goo00<007ooOol0LGoo00<007ooOol04Woo00<007oo
Ool02Goo000;Ool00`00Oomoo`0aOol00`00Oomoo`1aOol00`00Oomoo`0BOol00`00Oomoo`09Ool0
00]oo`03001oogoo035oo`03001oogoo075oo`03001oogoo019oo`03001oogoo00Uoo`002goo00<0
07ooOol0<Goo00<007ooOol0LGoo00<007ooOol04Woo00<007ooOol02Goo000;Ool00`00Oomoo`0a
Ool00`00Oomoo`1aOol00`00Oomoo`0BOol00`00Oomoo`09Ool000]oo`03001oogoo035oo`03001o
ogoo03Ioo`8003Uoo`03001oogoo019oo`03001oogoo00Uoo`002Woo00<007ooOol0<Woo00<007oo
Ool0=7oo0P0000=Am@000000>7oo00<007ooOol04Woo00<007ooOol02Goo000:Ool00`00Oomoo`0b
Ool00`00Oomoo`0aOol30003DOD01000Obl00000=Woo00<007ooOol04Woo00<007ooOol02Goo000:
Ool00`00Oomoo`0bOol00`00Oomoo`0^Ool30006DOD01@00Obmo;gl_0000=Goo00<007ooOol04Woo
00<007ooOol02Goo000:Ool00`00Oomoo`0bOol00`00Oomoo`0/Ool20009DOD01@00Obmo;gl_0000
=Goo00<007ooOol04Woo00<007ooOol02Goo000:Ool00`00Oomoo`0bOol00`00Oomoo`0YOol3000;
DOD01@00Obmo;gl_0000=Goo00<007ooOol04Woo00<007ooOol02Goo000:Ool00`00Oomoo`0bOol0
0`00Oomoo`0VOol3000>DOD01@00Obmo;gl_0000=Goo00<007ooOol04Woo00<007ooOol02Goo000:
Ool00`00Oomoo`0bOol00`00Oomoo`0TOol2000ADOD01@00Obmo;gl_0000=Goo00<007ooOol04Woo
00<007ooOol02Goo000:Ool00`00Oomoo`0aOol00`00Oomoo`0SOol2000CDOD01@00Obmo;gl_0000
=Goo00<007ooOol04goo00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomoo`0ROol00`00
DOEAm@0CDOD01@00Obmo;gl_0000=Goo00<007ooOol04goo00<007ooOol027oo000:Ool00`00Oomo
o`0aOol00`00Oomoo`0QOol00`00DOEAm@0DDOD01@00Obmo;gl_0000=Goo00<007ooOol04goo00<0
07ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomoo`0POol00`00DOEAm@0EDOD01@00Obmo;gl_
0000=Goo00<007ooOol04goo00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomoo`0OOol0
0`00DOEAm@0FDOD01@00Obmo;gl_0000=Goo00<007ooOol04goo00<007ooOol027oo000:Ool00`00
Oomoo`0aOol00`00Oomoo`0NOol00`00DOEAm@0GDOD01@00Obmo;gl_0000=Goo00<007ooOol04goo
00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomoo`0MOol00`00DOEAm@0HDOD01@00Obmo
;gl_0000=Goo00<007ooOol04goo00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomoo`0L
Ool00`00DOEAm@0IDOD01@00Obmo;gl_0000=Goo00<007ooOol04goo00<007ooOol027oo000:Ool0
0`00Oomoo`0aOol00`00Oomoo`0KOol00`00DOEAm@0JDOD01@00Obmo;gl_0000=Goo00<007ooOol0
4goo00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomoo`0KOol00`00DOEAm@0JDOD01@00
Obmo;gl_0000=Goo00<007ooOol04goo00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomo
o`0JOol00`00DOEAm@0KDOD01@00Obmo;gl_0000=Goo00<007ooOol04goo00<007ooOol027oo000:
Ool00`00Oomoo`0aOol00`00Oomoo`0IOol00`00DOEAm@0LDOD01@00Obmo;gl_0000=Goo00<007oo
Ool04goo00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00Oomoo`0HOol00`00DOEAm@0MDOD0
1@00Obmo;gl_0000=Woo00<007ooOol04Woo00<007ooOol027oo000:Ool00`00Oomoo`0aOol00`00
Oomoo`0GOol00`00DOEAm@0NDOD01@00Obmo;gl_0000=Woo00<007ooOol04Woo00<007ooOol027oo
0009Ool00`00Oomoo`0bOol00`00Oomoo`0FOol00`00DOEAm@0ODOD01@00Obmo;gl_0000=Woo00<0
07ooOol04Woo00<007ooOol027oo0009Ool00`00Oomoo`0bOol00`00Oomoo`0EOol00`00DOEAm@0P
DOD01@00Obmo;gl_0000=Woo00<007ooOol04Woo00<007ooOol027oo0009Ool00`00Oomoo`0bOol0
0`00Oomoo`0DOol00`00DOEAm@0QDOD01@00Obmo;gl_00007Goo1`004Woo00<007ooOol04Woo00<0
07ooOol027oo0009Ool00`00Oomoo`0bOol00`00Oomoo`0DOol00`00DOEAm@06DOD2000IDOD01@00
Obmo;gl_000047oo3@001U7e0P004Goo00<007ooOol04Woo00<007ooOol027oo0009Ool00`00Oomo
o`0bOol00`00Oomoo`0DOol00`00DOEAm@05DOD5000GDOD01@00Obmo;gl_00000Woo3P004e7e00<0
07Z6000047oo00<007ooOol04Woo00<007ooOol027oo0009Ool00`00Oomoo`0bOol00`00Oomoo`0C
Ool00`00DOEAm@07DOD5000FDOD7000RDOD00`00NXH0000?Ool00`00Oomoo`0BOol00`00Oomoo`08
Ool000Uoo`03001oogoo039oo`03001oogoo01=oo`03001AmE7e00YAm@@001AAm@03001AmE7e02IA
m@03001jQP0000moo`03001oogoo019oo`03001oogoo00Qoo`002Goo00<007ooOol0<Woo00<007oo
Ool04goo00<0057eDOD02e7e10004e7e00<0057eDOD09U7e00<007Z600003goo00<007ooOol04Woo
00<007ooOol027oo0009Ool00`00Oomoo`0bOol00`00Oomoo`0COol00`00DOEAm@0=DOD4000ADOD0
0`00DOEAm@0VDOD01000NXIjQP003Woo00<007ooOol04Woo00<007ooOol027oo0009Ool00`00Oomo
o`0bOol00`00Oomoo`0BOol00`00DOEAm@0?DOD4000@DOD00`00DOEAm@0ODOD20006DOD00`00NXH0
000>Ool00`00Oomoo`0BOol00`00Oomoo`08Ool000Uoo`03001oogoo039oo`03001oogoo019oo`03
001AmE7e015Am@@000iAm@03001AmE7e01iAm@03001Am57d008000AAm@03001jQP0000ioo`03001o
ogoo019oo`03001oogoo00Qoo`002Goo00<007ooOol0<Woo00<007ooOol04Woo00<0057eDOD04U7e
1@00357e00<0057eDOD0757e0P001E7d0P000U7e00<007Z600003Woo00<007ooOol04goo00<007oo
Ool01goo0009Ool00`00Oomoo`0bOol00`00Oomoo`0BOol00`00DOEAm@0DDOD4000;DOD00`00DOEA
m@0KDOD00`00DOAAm006DO@200001E7e001jQWZ600003Goo00<007ooOol04goo00<007ooOol01goo
0009Ool00`00Oomoo`0bOol00`00Oomoo`0AOol00`00DOEAm@0GDOD40009DOD00`00DOEAm@0JDOD0
0`00DOAAm008DO@20000157e001jQP003Goo00<007ooOol04goo00<007ooOol01goo0009Ool00`00
Oomoo`0bOol00`00Oomoo`0AOol00`00DOEAm@0HDOD40008DOD00`00DOEAm@0JDOD00`00DOAAm008
DO@01P00KL000000NXH000eoo`03001oogoo01=oo`03001oogoo00Moo`002Goo00<007ooOol0<Woo
00<007ooOol04Goo00<0057eDOD00U7e0`000e7e0`003e7e10001U7e00<0057eDOD06E7e00<0057d
DO@00e7d00<0057dDO@0157d0`0000=jQP00Ool037oo00<007ooOol04goo00<007ooOol01goo0009
Ool00`00Oomoo`0bOol00`00Oomoo`0AOol00`00DOEAm@03DOD00`00DOEAm@02DOD00`00DOEAm@0@
DOD40005DOD00`00DOEAm@09DODH0005DO@30002NXH00`00Oomoo`0:Ool00`00Oomoo`0COol00`00
Oomoo`07Ool000Uoo`03001oogoo039oo`03001oogoo015oo`03001AmE7e00=Am@<000=Am@03001A
mE7e015AmBX000EAm003001o]Gne00800003NXH007oo00]oo`03001oogoo01=oo`03001oogoo00Mo
o`002Goo00<007ooOol0<Woo00<007ooOol047oo00<0057eDOD0157e00@0057eDOD0009Am@03001A
mE7e019AmA80015Am@03001Am57d00QAm007001o]GneOkD007Z6000037oo00<007ooOol04goo00<0
07ooOol01goo0009Ool00`00Oomoo`0bOol00`00Oomoo`0@Ool00`00DOEAm@04DOD02000DOEAm@00
DOD0057e000DDOD30002DOD00`00DOEAm@0JDOD00`00DOAAm007DO@00`00OkEo]@02OkD200000gZ6
Oomoo`0:Ool00`00Oomoo`0COol00`00Oomoo`07Ool000Uoo`03001oogoo039oo`03001oogoo011o
o`03001AmE7e00=Am@@000=Am@03001AmE7e01AAm@05001AmE7eDOD0000MDOD00`00DOAAm006DO@0
1000OkEo]Gne0P0000=oL@0000002goo00<007ooOol04goo00<007ooOol01goo0008Ool00`00Oomo
o`0cOol00`00Oomoo`0@Ool00`00DOEAm@0UDOD00`00DOEAm@0KDOD30004DO@200001EON001o]Gne
00000gma00<007ooOol02Goo00<007ooOol04goo00<007ooOol01goo0008Ool00`00Oomoo`0cOol0
0`00Oomoo`0?Ool00`00DOEAm@0VDOD00`00DOEAm@0LDOD60004Emh30003Og400`00Oomoo`09Ool0
0`00Oomoo`0COol00`00Oomoo`07Ool000Qoo`03001oogoo03=oo`03001oogoo00moo`03001AmE7e
02IAm@03001AmE7e01iAm@8000030O/005ON00AGgP8000=oL@03001oogoo00Uoo`03001oogoo01=o
o`03001oogoo00Moo`0027oo00<007ooOol0<goo00<007ooOol03goo00<0057eDOD09U7e00<0057e
DOD0857e0`000UON0P0000EAm@00Og5oL@0000aoo`03001oogoo01=oo`03001oogoo00Moo`0027oo
00<007ooOol0<goo00<007ooOol03goo00<0057eDOD09U7e00<0057eDOD08U7e0`000e7e00@007ma
Og4000aoo`03001oogoo01=oo`03001oogoo00Moo`0027oo00<007ooOol0<goo00<007ooOol03goo
00<0057eDOD09U7e00<0057eDOD0457e0`000e7e0P00457e00@007maOg4000aoo`03001oogoo01=o
o`03001oogoo00Moo`0027oo00<007ooOol0<goo00<007ooOol047oo00<0057eDOD09E7e00<0057e
DOD04E7e00<0057eDOD0157e00<0057eDOD0357e00D007maOg5oL@0000aoo`03001oogoo01=oo`03
001oogoo00Moo`0027oo00<007ooOol0<goo00<007ooOol047oo00<0057eDOD06E7e0`000U7e1@00
0U7e00<0057eDOD04E7e0`000e7e00<0057eDOD03E7e00D007maOg5oL@0000aoo`03001oogoo01=o
o`03001oogoo00Moo`0027oo00<007ooOol0<goo00<007ooOol047oo00<0057eDOD06U7e00<0057e
DOD00e7e00<0057eDOD00U7e00<0057eDOD04E7e00@0057eDOD000=Am@03001AmE7e00aAm@04001o
LGma000=Ool00`00Oomoo`0COol00`00Oomoo`07Ool000Qoo`03001oogoo03=oo`03001oogoo011o
o`03001AmE7e01YAm@<000=Am@03001AmE7e009Am@03001AmE7e015Am@08001AmE7e001Am@00DOD0
00iAm@04001oLGma000=Ool00`00Oomoo`0COol00`00Oomoo`07Ool000Qoo`03001oogoo03=oo`03
001oogoo015oo`03001AmE7e01UAm@04001AmE7e0002DOD00`00DOEAm@02DOD00`00DOEAm@0@DOD4
0003DOD00`00DOEAm@0=DOD01000Og5oL@003Goo00<007ooOol04goo00<007ooOol01goo0008Ool0
0`00Oomoo`0bOol00`00Oomoo`0BOol00`00DOEAm@0IDOD01000DOEAm@000U7e00<0057eDOD00U7e
00<0057eDOD09e7e00@007maOg4000eoo`03001oogoo01=oo`03001oogoo00Moo`0027oo00<007oo
Ool0<Woo00<007ooOol04Woo00<0057eDOD0657e10000U7e0P00157e00<0057eDOD09U7e00D007ma
Og5oL@0000eoo`03001oogoo01=oo`03001oogoo00Moo`0027oo00<007ooOol0<Woo00<007ooOol0
4Woo00<0057eDOD0957e00<0057eDOD09U7e00D007maOg5oL@0000eoo`03001oogoo01=oo`03001o
ogoo00Moo`0027oo00<007ooOol0<Woo00<007ooOol04goo00<0057eDOD08e7e00<0057eDOD0757e
2`000Wma00<007ooOol03Goo00<007ooOol04Woo00<007ooOol01goo0008Ool00`00Oomoo`0bOol0
0`00Oomoo`0COol00`00DOEAm@0SDOD00`00DOEAm@08DODD000;;cl3000?Ool00`00Oomoo`0COol0
0`00Oomoo`06Ool000Qoo`03001oogoo039oo`03001oogoo01=oo`03001AmE7e02=Am@/001P_?`X0
00moo`03001oogoo01=oo`03001oogoo00Ioo`0027oo00<007ooOol0<Woo00<007ooOol04goo00<0
057eDOD08e7e0`0032lo50006Goo00<007ooOol04goo00<007ooOol01Woo0008Ool00`00Oomoo`0b
Ool00`00Oomoo`0DOol00`00DOEAm@0RDOD00`00Obmo;`0<000]Ool00`00Oomoo`0COol00`00Oomo
o`06Ool000Qoo`03001oogoo039oo`03001oogoo01Aoo`03001AmE7e029Am@05001o;gl_Obl0000g
Ool00`00Oomoo`0COol00`00Oomoo`06Ool000Qoo`03001oogoo039oo`03001oogoo01Aoo`03001A
mE7e029Am@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo
03=oo`03001oogoo01Aoo`03001AmE7e029Am@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00
Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01Eoo`03001AmE7e025Am@05001o;gl_Obl0
000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01Eoo`03
001AmE7e025Am@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001o
ogoo03=oo`03001oogoo01Eoo`03001AmE7e025Am@05001o;gl_Obl0000gOol00`00Oomoo`0COol0
0`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01Ioo`03001AmE7e021Am@05001o;gl_
Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01Mo
o`03001AmE7e01mAm@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03
001oogoo03=oo`03001oogoo01Qoo`03001AmE7e01iAm@05001o;gl_Obl0000gOol00`00Oomoo`0C
Ool00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01Uoo`03001AmE7e01eAm@05001o
;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo
01Yoo`03001AmE7e01aAm@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Mo
o`03001oogoo03=oo`03001oogoo01]oo`03001AmE7e01]Am@05001o;gl_Obl0000gOol00`00Oomo
o`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01aoo`03001AmE7e01YAm@05
001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001o
ogoo01eoo`03001AmE7e01UAm@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool0
00Moo`03001oogoo03=oo`03001oogoo01ioo`03001AmE7e01QAm@05001o;gl_Obl0000gOol00`00
Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01moo`03001AmE7e01MA
m@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03
001oogoo021oo`03001AmE7e01IAm@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06
Ool000Moo`03001oogoo03=oo`03001oogoo025oo`03001AmE7e01EAm@05001o;gl_Obl0000gOol0
0`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo029oo`03001AmE7e
01AAm@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=o
o`03001oogoo02=oo`03001AmE7e01=Am@05001o;gl_Obl0000gOol00`00Oomoo`0COol00`00Oomo
o`06Ool000Moo`03001oogoo03=oo`03001oogoo02Aoo`<0019Am@05001o;gl_Obl0000gOol00`00
Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo02Eoo`H000iAm@05001o
;gl_Obl0000gOol00`00Oomoo`0DOol00`00Oomoo`05Ool000Moo`03001oogoo03=oo`03001oogoo
02Moo`800081n0@000YAm@05001o;gl_Obl0000gOol00`00Oomoo`0DOol00`00Oomoo`05Ool000Io
o`03001oogoo03Aoo`03001oogoo02]oo`<000030OP00000008000IAm@05001o;gl_Obl0000gOol0
0`00Oomoo`0DOol00`00Oomoo`05Ool000Ioo`03001oogoo03Aoo`03001oogoo02moo`P0009Am@05
001o;gl_Obl0000gOol00`00Oomoo`0DOol00`00Oomoo`05Ool000Ioo`03001oogoo03Aoo`03001o
ogoo03=oo`L000=o;`03001oogoo03Eoo`03001oogoo01Aoo`03001oogoo00Eoo`001Woo00<007oo
Ool0=7oo00<007ooOol0=goo1@0000=o;`00Ool0=Woo00<007ooOol057oo00<007ooOol01Goo0006
Ool00`00Oomoo`0dOol00`00Oomoo`0kOol3000gOol00`00Oomoo`0DOol00`00Oomoo`05Ool000Io
o`03001oogoo03Aoo`03001oogoo07Eoo`03001oogoo01Aoo`03001oogoo00Eoo`001Woo00<007oo
Ool0=7oo00<007ooOol0MGoo00<007ooOol057oo00<007ooOol01Goo0006Ool00`00Oomoo`0dOol0
0`00Oomoo`1eOol00`00Oomoo`0DOol00`00Oomoo`05Ool000Ioo`03001oogoo03Aoo`03001oogoo
07Eoo`03001oogoo01Aoo`03001oogoo00Eoo`001Woo00<007ooOol0=7oo00<007ooOol0MWoo00<0
07ooOol04goo00<007ooOol01Goo0006Ool00`00Oomoo`0dOol00`00Oomoo`1fOol00`00Oomoo`0C
Ool00`00Oomoo`05Ool000Ioo`03001oogoo03Aoo`03001oogoo07Ioo`03001oogoo01=oo`03001o
ogoo00Eoo`001Woo00<007ooOol0=7oo00<007ooOol0MWoo00<007ooOol04goo00<007ooOol01Goo
0006Ool00`00Oomoo`0dOol00`00Oomoo`1fOol00`00Oomoo`0COol00`00Oomoo`05Ool000Ioo`03
001oogoo03Aoo`03001oogoo07Ioo`03001oogoo01=oo`03001oogoo00Eoo`001Woo00<007ooOol0
<goo00<007ooOol0Mgoo00<007ooOol04goo00<007ooOol01Goo0006Ool00`00Oomoo`0cOol00`00
Oomoo`1gOol00`00Oomoo`0COol00`00Oomoo`05Ool000Ioo`03001oogoo03=oo`03001oogoo07Mo
o`03001oogoo01=oo`03001oogoo00Eoo`001Woo00<007ooOol0<goo00<007ooOol0Mgoo00<007oo
Ool04goo00<007ooOol01Goo0006Ool00`00Oomoo`0cOol00`00Oomoo`1gOol00`00Oomoo`0COol0
0`00Oomoo`05Ool000Ioo`03001oogoo03=oo`03001oogoo07Moo`03001oogoo01=oo`03001oogoo
00Eoo`001Goo00<007ooOol0=7oo00<007ooOol0Mgoo00<007ooOol04goo00<007ooOol01Goo0005
Ool00`00Oomoo`0dOol00`00Oomoo`1gOol00`00Oomoo`0COol00`00Oomoo`05Ool000Eoo`03001o
ogoo03Aoo`03001oogoo07Moo`03001oogoo01Aoo`03001oogoo00Aoo`001Goo00<007ooOol0=7oo
00<007ooOol0Mgoo00<007ooOol057oo00<007ooOol017oo0005Ool00`00Oomoo`0dOol00`00Oomo
o`1gOol00`00Oomoo`0DOol00`00Oomoo`04Ool000Eoo`03001oogoo03Aoo`03001oogoo07Moo`03
001oogoo01Aoo`03001oogoo00Aoo`001Goo00<007ooOol0=7oo00<007ooOol0HGoo60005Goo00<0
07ooOol017oo0005Ool00`00Oomoo`0dOol00`00Oomoo`0eOol/000HOol3000BOol00`00Oomoo`04
Ool000Eoo`03001oogoo03Aoo`03001oogoo00Uoob`004Moo`<000moo`03001oogoo00Aoo`001Goo
00<007ooOol057oo;000MWoo0`0037oo00<007ooOol017oo0005OolG000POol00`00Oomoo`22Ool2
000:Ool00`00Oomoo`04Ool000Uoo`P002]oo`03001oogoo08Aoo`<000Moo`03001oogoo00Aoo`00
4Goo20008goo00<007ooOol0Qgoo0`0017oo00<007ooOol017oo000IOol8000KOol00`00Oomoo`2:
Ool300000goo001oo`05Ool0025oo`P001=oo`03001oogoo07IooaT000Ioo`00:Goo20002goo00<0
07ooOol0AWoo<0007goo000aOol80003Ool00`00Oomoo`0FOol`001?Ool003Uooa`007moo`00e7oo
003DOol00=Aoo`00e7oo003DOol00001\
\>"],
  ImageRangeCache->{{{0, 211}, {208, 0}} -> {-0.00542468, -0.0250047, 
  0.00452708, 0.00452708}}]
}, Open  ]],

Cell["Piston", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The local coordinate system on the piston originates at a point that is four \
units below the attachment point of the connecting rod. Thus, when the \
slider-crank mechanism is in its initial configuration, the local origin of \
the piston is coincident with the global origin."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three local point coordinates are used on the piston.\nP1 is a point on \
the local ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis that is the attachment point of the connecting rod.\nP2 is another \
point on the local ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis that is the other end of the translation line of the piston."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the piston. The local point coordinates on the piston \
are\nP1 {0,4,0}, P2 {0,6,0}, and P3 {0,4,5}."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .80548 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0251912 1.00765 -0.0520444 1.00765 [
[ 0 0 0 0 ]
[ 1 .80548 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .80548 L
0 .80548 L
closepath
clip
newpath
p
.002 w
.29449 .28363 m
.05131 .12238 L
s
.05131 .12238 m
.02519 .7266 L
s
.02519 .7266 m
.28411 .78029 L
s
.28411 .78029 m
.29449 .28363 L
s
.95424 .21984 m
.97481 .75918 L
s
.97481 .75918 m
.86645 .69372 L
s
.86645 .69372 m
.84704 .02519 L
s
.84704 .02519 m
.95424 .21984 L
s
.29449 .28363 m
.05131 .12238 L
s
.05131 .12238 m
.84704 .02519 L
s
.84704 .02519 m
.95424 .21984 L
s
.95424 .21984 m
.29449 .28363 L
s
.28411 .78029 m
.97481 .75918 L
s
.97481 .75918 m
.86645 .69372 L
s
.86645 .69372 m
.02519 .7266 L
s
.02519 .7266 m
.28411 .78029 L
s
P
p
.002 w
.66875 .57312 m .59575 .58335 L .59473 .40743 L p
.516 .387 .643 r
F P
s
P
p
.002 w
.59473 .40743 m .66656 .39321 L .66875 .57312 L p
.516 .387 .643 r
F P
s
P
p
.002 w
.50401 .40593 m .59473 .40743 L .59575 .58335 L p
.72 .552 .661 r
F P
s
P
p
.002 w
.59473 .40743 m .66656 .39321 L p
.61781 .35164 L .456 .814 .996 r
F P
s
P
p
.002 w
.50401 .40593 m .59473 .40743 L p
.61781 .35164 L .456 .814 .996 r
F P
s
P
p
.002 w
.59575 .58335 m .50362 .58227 L .50401 .40593 L p
.72 .552 .661 r
F P
s
P
p
.002 w
.442 .38939 m .50401 .40593 L .50362 .58227 L p
.892 .695 .628 r
F P
s
P
p
.002 w
.442 .38939 m .50401 .40593 L p
.61781 .35164 L .456 .814 .996 r
F P
s
P
p
.002 w
.59575 .58335 m .66875 .57312 L p
.61932 .54319 L .359 .79 .968 r
F P
s
P
p
.002 w
.50362 .58227 m .59575 .58335 L p
.61932 .54319 L .359 .79 .968 r
F P
s
P
p
.002 w
.50362 .58227 m .4406 .57037 L .442 .38939 L p
.892 .695 .628 r
F P
s
P
p
.002 w
.4406 .57037 m .50362 .58227 L p
.61932 .54319 L .359 .79 .968 r
F P
s
P
p
.002 w
.681 .55658 m .66875 .57312 L .66656 .39321 L p
0 0 .268 r
F P
s
P
p
.002 w
.66656 .39321 m .67853 .37022 L .681 .55658 L p
0 0 .268 r
F P
s
P
p
.002 w
.66656 .39321 m .67853 .37022 L .61781 .35164 L p
.456 .814 .996 r
F P
s
P
p
.002 w
.44561 .36611 m .442 .38939 L p
.61781 .35164 L .456 .814 .996 r
F P
s
P
p
.002 w
.44561 .36611 m .442 .38939 L .4406 .57037 L p
0 0 .072 r
F P
s
P
p
.002 w
.66875 .57312 m .681 .55658 L .61932 .54319 L p
.359 .79 .968 r
F P
s
P
p
.002 w
.44423 .55361 m .4406 .57037 L p
.61932 .54319 L .359 .79 .968 r
F P
s
P
p
.002 w
.4406 .57037 m .44423 .55361 L .44561 .36611 L p
0 0 .072 r
F P
s
P
p
.01 w
.55894 .56358 m
.55901 .58852 L
s
P
p
.01 w
.55862 .44051 m
.5589 .54679 L
s
P
p
.002 w
.61932 .54319 m .681 .55658 L .67853 .37022 L p
.912 .706 .611 r
F P
s
P
p
.002 w
.67853 .37022 m .61781 .35164 L .61932 .54319 L p
.912 .706 .611 r
F P
s
P
p
.02 w
.55901 .58852 Mdot
P
p
.002 w
.61781 .35164 m .51873 .34984 L .44561 .36611 L p
.456 .814 .996 r
F P
s
P
p
.002 w
.51873 .34984 m .44561 .36611 L .44423 .55361 L p
.49 .362 .632 r
F P
s
P
p
.002 w
.61932 .54319 m .51855 .54189 L .44423 .55361 L p
.359 .79 .968 r
F P
s
P
p
.002 w
.44423 .55361 m .51855 .54189 L .51873 .34984 L p
.49 .362 .632 r
F P
s
P
p
.01 w
.43111 .35315 m
.45514 .36961 L
s
P
p
.002 w
.51855 .54189 m .61932 .54319 L .61781 .35164 L p
.721 .549 .656 r
F P
s
P
p
.002 w
.61781 .35164 m .51873 .34984 L .51855 .54189 L p
.721 .549 .656 r
F P
s
P
p
.01 w
.45514 .36961 m
.51867 .41314 L
s
P
p
.02 w
.43111 .35315 Mdot
P
p
.002 w
.95424 .21984 m
.97481 .75918 L
s
.97481 .75918 m
.86645 .69372 L
s
.86645 .69372 m
.84704 .02519 L
s
.84704 .02519 m
.95424 .21984 L
s
.28411 .78029 m
.97481 .75918 L
s
.97481 .75918 m
.86645 .69372 L
s
.86645 .69372 m
.02519 .7266 L
s
.02519 .7266 m
.28411 .78029 L
s
P
p
[(P1)] .55862 .44051 -0.3 0 Mshowa
[(P2)] .55901 .58852 0 -2 Mshowa
[(P3)] .43111 .35315 0 2 Mshowa
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 170},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D0000ZQ000`40O003h00Oe7oo003DOol00=Ao
o`00e7oo003DOol00=Aoo`00[Woo1@008Goo002VOol80004Ool2000POol009ioo`P000aoo`80021o
o`00UGoo2@0057oo00<007oo00007goo002=Ool8000MOol00`00Ool0000OOol008Eoo`P002Eoo`04
001oogoo000NOol007aoo`T002eoo`04001oogoo000NOol007Aoo`P003Ioo`05001oogooOol0000M
Ool006aoo`P003ioo`05001oogooOol0000MOol006=oo`T004Ioo`03001oogoo009oo`03001oogoo
01Yoo`00Fgoo2000Cgoo00<007ooOol00Woo00<007ooOol06Woo001BOol9001GOol00`00Oomoo`03
Ool00`00Oomoo`0IOol004Yoo`P0061oo`03001oogoo00=oo`03001oogoo01Uoo`00@Woo2000J7oo
00<007ooOol017oo00<007ooOol067oo000iOol9001`Ool00`00Oomoo`05Ool00`00Oomoo`0GOol0
035oo`P007Uoo`03001oogoo00Eoo`03001oogoo01Moo`00:Goo2000PGoo00<007ooOol01Woo00<0
07ooOol05Woo000POol90029Ool00`00Oomoo`06Ool00`00Oomoo`0FOol001Qoo`P009=oo`03001o
ogoo00Ioo`03001oogoo01Eoo`0047oo2000Vgoo00<007ooOol01Woo00<007ooOol05Goo000;Ool5
002SOol00`00Oomoo`07Ool00`00Oomoo`0DOol000]oo`<00:Eoo`03001oogoo00Moo`03001oogoo
01Aoo`002goo00@007ooOol00:Aoo`03001oogoo00Qoo`03001oogoo01=oo`002goo00@007ooOomo
o`800:9oo`03001oogoo00Qoo`03001oogoo01=oo`002goo00<007ooOol00goo00<007ooOol0Wgoo
00<007ooOol02Goo00<007ooOol04Woo000;Ool00`00Oomoo`04Ool2002OOol00`00Oomoo`09Ool0
0`00Oomoo`0BOol000]oo`03001oogoo00Ioo`03001oogoo09aoo`03001oogoo00Yoo`03001oogoo
015oo`002goo00<007ooOol01goo0P00W7oo00<007ooOol02Woo00<007ooOol04Goo000;Ool00`00
Oomoo`09Ool00`00Oomoo`2IOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool000]oo`03001oogoo00Yo
o`8009Uoo`03001oogoo00aoo`03001oogoo00moo`002goo00<007ooOol037oo00<007ooOol0UWoo
00<007ooOol037oo00<007ooOol03goo000:Ool00`00Oomoo`0>Ool2002FOol00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool000Yoo`03001oogoo011oo`03001oogoo09=oo`03001oogoo00eoo`03001oogoo
00ioo`002Woo00<007ooOol04Goo0P00Tgoo00<007ooOol03Woo00<007ooOol03Goo000:Ool00`00
Oomoo`0COol00`00Oomoo`2@Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool000Yoo`03001oogoo01Ao
o`80091oo`03001oogoo00moo`03001oogoo00aoo`002Woo00<007ooOol05Woo00<007ooOol0SGoo
00<007ooOol03goo00<007ooOol037oo000:Ool00`00Oomoo`0GOol2002=Ool00`00Oomoo`0@Ool0
0`00Oomoo`0;Ool000Yoo`03001oogoo01Uoo`03001oogoo08Yoo`03001oogoo011oo`03001oogoo
00]oo`002Woo00<007ooOol06Woo0P00RWoo00<007ooOol04Goo00<007ooOol02Woo000:Ool00`00
Oomoo`0LOol00`00Oomoo`27Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool000Yoo`03001oogoo01eo
o`8008Moo`03001oogoo00eoo`H000]oo`002Woo00<007ooOol07goo00<007ooOol0Q7oo00<007oo
Ool00goo2P001Goo00<007ooOol02Goo000:Ool00`00Oomoo`0POol2001oOol;000?Ool00`00Oomo
o`09Ool000Yoo`03001oogoo029oo`03001oogoo075oo`/000Eoo`03001oogoo019oo`03001oogoo
00Uoo`002Woo00<007ooOol08goo0P00Igoo2P0047oo00<007ooOol04Woo00<007ooOol02Goo000:
Ool00`00Oomoo`0UOol00`00Oomoo`1IOol;000JOol00`00Oomoo`0BOol00`00Oomoo`09Ool000Yo
o`03001oogoo02Ioo`8004moo`X002Eoo`03001oogoo019oo`03001oogoo00Uoo`002Woo00<007oo
Ool0:7oo00<007ooOol0@Goo2`00;goo00<007ooOol04Woo00<007ooOol02Goo000:Ool00`00Oomo
o`0YOol2000fOol;000jOol00`00Oomoo`0BOol00`00Oomoo`09Ool000Yoo`03001oogoo02]oo`03
001oogoo02Uoo`X004Eoo`03001oogoo019oo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo0P00
7Woo2`00Cgoo00<007ooOol04Woo00<007ooOol02Goo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0@
Ool;001JOol00`00Oomoo`0BOol00`00Oomoo`09Ool000Uoo`03001oogoo031oo`8000Ioo`X006Io
o`03001oogoo019oo`03001oogoo00Qoo`002Goo00<007ooOol0<Woo1P00L7oo00<007ooOol04Woo
00<007ooOol027oo0009Ool00`00Oomoo`0bOol00`00Oomoo`0EOol30003Ool2001FOol00`00Oomo
o`0BOol00`00Oomoo`08Ool000Uoo`03001oogoo039oo`03001oogoo01Ioo`03001oogoo00Aoo`03
001oogoo05=oo`03001oogoo019oo`03001oogoo00Qoo`002Goo00<007ooOol0<Woo00<007ooOol0
5Woo0`000goo00<007ooOol0E7oo00<007ooOol04Woo00<007ooOol027oo0009Ool00`00Oomoo`0b
Ool00`00Oomoo`0FOol01000Oomoo`000goo00<007ooOol0Dgoo00<007ooOol04Woo00<007ooOol0
27oo0009Ool00`00Oomoo`0bOol00`00Oomoo`0FOol02000Oomoo`00Ool007oo001EOol00`00Oomo
o`0BOol00`00Oomoo`08Ool000Uoo`03001oogoo039oo`03001oogoo01Eoo`@000=oo`03001oogoo
05Aoo`03001oogoo019oo`03001oogoo00Qoo`002Goo00<007ooOol0<Woo00<007ooOol0Lgoo00<0
07ooOol04Woo00<007ooOol027oo0009Ool00`00Oomoo`0bOol00`00Oomoo`1cOol00`00Oomoo`0B
Ool00`00Oomoo`08Ool000Uoo`03001oogoo039oo`03001oogoo07=oo`03001oogoo019oo`03001o
ogoo00Qoo`002Goo00<007ooOol0<Woo00<007ooOol0Lgoo00<007ooOol04Woo00<007ooOol027oo
0009Ool00`00Oomoo`0bOol00`00Oomoo`1cOol00`00Oomoo`0BOol00`00Oomoo`08Ool000Uoo`03
001oogoo039oo`03001oogoo07=oo`03001oogoo019oo`03001oogoo00Qoo`002Goo00<007ooOol0
<Woo00<007ooOol0Lgoo00<007ooOol04Woo00<007ooOol027oo0009Ool00`00Oomoo`0bOol00`00
Oomoo`0IOol2000?OolI000`Ool00`00Oomoo`0BOol00`00Oomoo`08Ool000Uoo`03001oogoo039o
o`03001oogoo01Qoo`D000Qoo`D0008mM003001N=5hd019N=003001fd`00008002eoo`03001oogoo
019oo`03001oogoo00Qoo`002Goo00<007ooOol0<Woo00<007ooOol06Goo1@000Woo1@001ced00<0
05hdGS@04Uhd00<007KCM]<00WKC0`00:Woo00<007ooOol04Woo00<007ooOol027oo0009Ool00`00
Oomoo`0bOol00`00Oomoo`0LOol4000<?G@00`00GSAN=00BGS@00`00M]=fd`05M]<3000WOol00`00
Oomoo`0BOol00`00Oomoo`08Ool000Uoo`03001oogoo039oo`03001oogoo01eoo`@000/mM003001N
=5hd019N=003001fdgKC00Qfd`8002Eoo`03001oogoo019oo`03001oogoo00Qoo`0027oo00<007oo
Ool0<goo00<007ooOol07Goo00<003ed00000`002Ced00<005hdGS@04Uhd00<007KCM]<02GKC00<0
07ooOol08goo00<007ooOol04Woo00<007ooOol027oo0008Ool00`00Oomoo`0cOol00`00Oomoo`0L
Ool20002?G@40008?G@00`00GSAN=00BGS@00`00M]=fd`09M]<00`00Oomoo`0SOol00`00Oomoo`0B
Ool00`00Oomoo`08Ool000Qoo`03001oogoo03=oo`03001oogoo01aoo`8000@mM0@000HmM003001N
=5hd019N=003001fdgKC00Ufd`03001oogoo02=oo`03001oogoo01=oo`03001oogoo00Moo`0027oo
00<007ooOol0<goo00<007ooOol077oo0P001Ced10001Ced00<005hdGS@04Uhd00<007KCM]<02GKC
00<007ooOol08goo00<007ooOol04goo00<007ooOol01goo0008Ool00`00Oomoo`0cOol00`00Oomo
o`0LOol20007?G@40003?G@00`00GSAN=00BGS@00`00M]=fd`09M]<00`00Oomoo`0SOol00`00Oomo
o`0COol00`00Oomoo`07Ool000Qoo`03001oogoo03=oo`03001oogoo01aoo`8000PmM0@0008mM003
001N=5hd019N=003001fdgKC00Ufd`03001oogoo02=oo`03001oogoo01=oo`03001oogoo00Moo`00
27oo00<007ooOol0<goo00<007ooOol077oo0P002Sed1@0055hd00<007KCM]<02GKC00<007ooOol0
8goo00<007ooOol04goo00<007ooOol01goo0008Ool00`00Oomoo`0bOol00`00Oomoo`0MOol2000;
?G@4000DGS@00`00M]=fd`09M]<00`00Oomoo`0SOol00`00Oomoo`0COol00`00Oomoo`07Ool000Qo
o`03001oogoo039oo`03001oogoo01eoo`8000dmM0<001=N=003001fdgKC00Ufd`03001oogoo02=o
o`03001oogoo01=oo`03001oogoo00Moo`0027oo00<007ooOol0<Woo00<007ooOol07Goo0P003Sed
00<005hdGS@04Uhd00<007KCM]<02GKC00<007ooOol08goo00<007ooOol04goo00<007ooOol01goo
0008Ool00`00Oomoo`0bOol00`00Oomoo`0MOol2000>?G@00`00GSAN=00BGS@00`00M]=fd`09M]<0
0`00Oomoo`0SOol00`00Oomoo`0COol00`00Oomoo`07Ool000Qoo`03001oogoo039oo`03001oogoo
01eoo`8000hmM003001N=5hd019N=003001fdgKC00Ufd`03001oogoo02=oo`03001oogoo01=oo`03
001oogoo00Moo`0027oo00<007ooOol0<Woo00<007ooOol07Goo0P003Sed00<005hdGS@00Uhd0`00
0Uhd1@001Uhd00<007KCM]<02GKC00<007ooOol08goo00<007ooOol04goo00<007ooOol01goo0008
Ool00`00Oomoo`0bOol00`00Oomoo`0MOol2000>?G@00`00GSAN=003GS@00`00GSAN=003GS@00`00
GSAN=006GS@00`00M]=fd`09M]<00`00Oomoo`0SOol00`00Oomoo`0COol00`00Oomoo`07Ool000Qo
o`03001oogoo039oo`03001oogoo01eoo`8000hmM003001N=5hd00=N=0<000=N=003001N=5hd00IN
=003001fdgKC00Ufd`03001oogoo02=oo`03001oogoo01=oo`03001oogoo00Moo`0027oo00<007oo
Ool0<Woo00<007ooOol07Goo0P003Sed00<005hdGS@00ehd00@005hdGS@0009N=003001N=5hd00IN
=003001fdgKC00Ufd`03001oogoo02Aoo`03001oogoo019oo`03001oogoo00Moo`0027oo00<007oo
Ool0<Woo00<007ooOol07Goo0P003Sed00<005hdGS@00ehd00@005hdGS@0009N=003001N=5hd00IN
=003001fdgKC00Ufd`03001oogoo02Aoo`03001oogoo019oo`03001oogoo00Moo`0027oo00<007oo
Ool0<Woo00<007ooOol07Goo0P003Sed00<005hdGS@00Uhd10000Uhd0P0025hd00<007KCM]<02GKC
00<007ooOol097oo00<007ooOol04Woo00<007ooOol01goo0008Ool00`00Oomoo`0bOol00`00Oomo
o`0MOol00`00?G@mM00=?G@00`00GSAN=00BGS@00`00M]=fd`09M]<00`00Oomoo`0TOol00`00Oomo
o`0BOol00`00Oomoo`07Ool000Qoo`03001oogoo039oo`03001oogoo01eoo`03000mM3ed00dmM003
001N=5hd019N=003001fdgKC00Yfd`03001oogoo02=oo`03001oogoo019oo`03001oogoo00Moo`00
27oo00<007ooOol0<Woo00<007ooOol07Goo00<003ed?G@03Ced00<005hdGS@04Uhd00<007KCM]<0
2WKC00<007ooOol08goo00<007ooOol04Woo00<007ooOol01goo0008Ool00`00Oomoo`0bOol00`00
Oomoo`0MOol00`00?G@mM00=?G@00`00GSAN=00BGS@00`00M]=fd`0:M]<00`00Oomoo`0SOol00`00
Oomoo`0BOol00`00Oomoo`07Ool000Moo`03001oogoo03=oo`03001oogoo01eoo`03000mM3ed00dm
M003001N=5hd019N=003001fdgKC00Yfd`03001oogoo02=oo`03001oogoo019oo`03001oogoo00Mo
o`001goo00<007ooOol0<goo00<007ooOol07Goo00<003ed?G@03Ced00<005hdGS@04Uhd00<007KC
M]<02WKC00<007ooOol08goo00<007ooOol04Woo00<007ooOol01goo0007Ool00`00Oomoo`0cOol0
0`00Oomoo`0MOol00`00?G@mM00=?G@00`00GSAN=00BGS@00`00M]=fd`0:M]<00`00Oomoo`0SOol0
0`00Oomoo`0BOol00`00Oomoo`07Ool000Moo`03001oogoo03=oo`03001oogoo01eoo`03000mM3ed
00dmM003001N=5hd019N=003001fdgKC00Yfd`03001oogoo02=oo`03001oogoo01=oo`03001oogoo
00Ioo`001goo00<007ooOol0<goo00<007ooOol07Goo00<003ed?G@03Ced00<005hdGS@04Uhd00<0
07KCM]<02WKC00<007ooOol08goo00<007ooOol04goo00<007ooOol01Woo0007Ool00`00Oomoo`0c
Ool00`00Oomoo`0MOol00`00?G@mM00=?G@00`00GSAN=00BGS@00`00M]=fd`0:M]<00`00Oomoo`0S
Ool00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01eoo`03000m
M3ed00dmM003001N=5hd019N=003001fdgKC00Yfd`03001oogoo02=oo`03001oogoo01=oo`03001o
ogoo00Ioo`001goo00<007ooOol0<goo00<007ooOol07Goo00<003ed?G@03Ced00<005hdGS@04Uhd
00<007KCM]<02WKC00<007ooOol08goo00<007ooOol04goo00<007ooOol01Woo0007Ool00`00Oomo
o`0cOol00`00Oomoo`0MOol00`00?G@mM00=?G@00`00GSAN=00BGS@00`00M]=fd`0:M]<00`00Oomo
o`0SOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01eoo`03
000mM3ed00dmM003001N=5hd019N=003001fdgKC00Yfd`03001oogoo02=oo`03001oogoo01=oo`03
001oogoo00Ioo`001goo00<007ooOol0<goo00<007ooOol07Goo00<003ed?G@03Ced00<005hdGS@0
4Uhd00<007KCM]<02WKC00<007ooOol08goo00<007ooOol04goo00<007ooOol01Woo0007Ool00`00
Oomoo`0cOol00`00Oomoo`0MOol00`00?G@mM00=?G@00`00GSAN=00BGS@00`00M]=fd`0:M]<00`00
Oomoo`0SOol00`00Oomoo`0COol00`00Oomoo`06Ool000Moo`03001oogoo03=oo`03001oogoo01eo
o`03000mM3ed00dmM003001N=5hd019N=003001fdgKC00Yfd`03001oogoo02=oo`03001oogoo01=o
o`03001oogoo00Ioo`001goo00<007ooOol0<goo00<007ooOol07Goo00<003ed?G@02ced6P002WKC
00<007ooOol08goo00<007ooOol04goo00<007ooOol01Woo0007Ool00`00Oomoo`0cOol00`00Oomo
o`0MOol00`00?G@mM006?G@5000J;ch40006M]<00`00Oomoo`0SOol00`00Oomoo`0COol00`00Oomo
o`06Ool000Moo`03001oogoo03=oo`03001oogoo01eoo`03000mM3ed00H000h_?P8001<_?P@0009f
d`03001oogoo02=oo`03001oogoo01=oo`03001oogoo00Ioo`001goo00<007ooOol0<goo00<007oo
Ool07Goo0`00;Bln0`009Goo00<007ooOol04goo00<007ooOol01Woo0007Ool00`00Oomoo`0cOol0
0`00Oomoo`0MOol00`00;ch_?P0^;ch00`00Oomoo`0TOol00`00Oomoo`0COol00`00Oomoo`06Ool0
00Moo`03001oogoo03=oo`03001oogoo01eoo`03000_?Rln01@_?P8001L_?P03001oogoo02Eoo`03
001oogoo01=oo`03001oogoo00Ioo`001goo00<007ooOol0<goo00<007ooOol07Goo0`0052ln0P00
5bln00<007ooOol09Goo00<007ooOol04goo00<007ooOol01Woo0007Ool00`00Oomoo`0cOol00`00
Oomoo`0POol4000@;ch2000C;ch4000XOol00`00Oomoo`0COol00`00Oomoo`06Ool000Ioo`03001o
ogoo03Aoo`03001oogoo02Aoo`@000`_?P8000/_?PP002aoo`03001oogoo01=oo`03001oogoo00Io
o`001Woo00<007ooOol0=7oo00<007ooOol0:7oo6@00=7oo00<007ooOol04goo00<007ooOol01Woo
0006Ool00`00Oomoo`0dOol00`00Oomoo`0dOol2000oOol00`00Oomoo`0COol00`00Oomoo`06Ool0
00Ioo`03001oogoo03Aoo`03001oogoo03Aoo`<003ioo`03001oogoo01=oo`03001oogoo00Ioo`00
1Woo00<007ooOol0=7oo00<007ooOol0=Goo00<007ooOol0?Goo00<007ooOol04goo00<007ooOol0
1Woo0006Ool00`00Oomoo`0dOol00`00Oomoo`1eOol00`00Oomoo`0DOol00`00Oomoo`05Ool000Io
o`03001oogoo03Aoo`03001oogoo07Eoo`03001oogoo01Aoo`03001oogoo00Eoo`001Woo00<007oo
Ool0=7oo00<007ooOol0MWoo00<007ooOol04goo00<007ooOol01Goo0006Ool00`00Oomoo`0dOol0
0`00Oomoo`1fOol00`00Oomoo`0COol00`00Oomoo`05Ool000Ioo`03001oogoo03Aoo`03001oogoo
07Ioo`03001oogoo01=oo`03001oogoo00Eoo`001Woo00<007ooOol0=7oo00<007ooOol0MWoo00<0
07ooOol04goo00<007ooOol01Goo0006Ool00`00Oomoo`0dOol00`00Oomoo`1fOol00`00Oomoo`0C
Ool00`00Oomoo`05Ool000Ioo`03001oogoo03Aoo`03001oogoo031oo`<000=oo`<003eoo`03001o
ogoo01=oo`03001oogoo00Eoo`001Woo00<007ooOol0=7oo00<007ooOol0<Goo00<007ooOol00Woo
00<007ooOol0?Goo00<007ooOol04goo00<007ooOol01Goo0006Ool00`00Oomoo`0dOol00`00Oomo
o`0aOol30003Ool00`00Oomoo`0lOol00`00Oomoo`0COol00`00Oomoo`05Ool000Ioo`03001oogoo
03Aoo`03001oogoo035oo`04001oogoo0002Ool00`00Oomoo`0lOol00`00Oomoo`0COol00`00Oomo
o`05Ool000Ioo`03001oogoo03=oo`03001oogoo039oo`08001oogoo001oo`00Ool003eoo`03001o
ogoo01=oo`03001oogoo00Eoo`001Woo00<007ooOol0<goo00<007ooOol0<Goo10000goo00<007oo
Ool0?7oo00<007ooOol04goo00<007ooOol01Goo0006Ool00`00Oomoo`0cOol00`00Oomoo`1gOol0
0`00Oomoo`0COol00`00Oomoo`05Ool000Ioo`03001oogoo03=oo`03001oogoo07Moo`03001oogoo
01=oo`03001oogoo00Eoo`001Woo00<007ooOol0<goo00<007ooOol0Mgoo00<007ooOol04goo00<0
07ooOol01Goo0005Ool00`00Oomoo`0dOol00`00Oomoo`1gOol00`00Oomoo`0COol00`00Oomoo`05
Ool000Eoo`03001oogoo03Aoo`03001oogoo07Moo`03001oogoo01=oo`03001oogoo00Eoo`001Goo
00<007ooOol0=7oo00<007ooOol0Mgoo00<007ooOol04goo00<007ooOol01Goo0005Ool00`00Oomo
o`0dOol00`00Oomoo`1[Ool=000EOol00`00Oomoo`05Ool000Eoo`03001oogoo03Aoo`03001oogoo
059ooaT000eoo`8001=oo`03001oogoo00Eoo`001Goo00<007ooOol0=7oo00<007ooOol0>7oo6P00
:7oo0P004Goo00<007ooOol01Goo0005Ool00`00Oomoo`0dOol00`00Oomoo`0OOolI0014Ool00`00
Oomoo`0?Ool00`00Oomoo`04Ool000Eoo`03001oogoo03Aoo`03001oogoo00IooaT005ioo`8000mo
o`03001oogoo00Aoo`001Goo00<007ooOol08goo6P00NGoo0P003Goo00<007ooOol017oo0005Ool0
0`00Oomoo`0:OolI000AOol00`00Oomoo`21Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool000Eoo`d0
02Yoo`03001oogoo089oo`8000Yoo`03001oogoo00Aoo`0027oo1@00;goo00<007ooOol0Q7oo00<0
07ooOol01goo00<007ooOol017oo000=Ool5000ZOol00`00Oomoo`25Ool20007Ool00`00Oomoo`04
Ool0019oo`D002Eoo`03001oogoo08Moo`8000Eoo`03001oogoo00Aoo`005goo1@0087oo00<007oo
Ool0RGoo00<007ooOol00Woo00<007ooOol017oo000LOol5000KOol00`00Oomoo`2:Ool20002Ool0
0`00Oomoo`04Ool0025oo`D001Ioo`03001oogoo08aoo`<000Ioo`009Woo1@004Goo00<007ooOol0
O7oo4`001Woo000[Ool5000<Ool00`00Oomoo`1HOolT000IOol0031oo`D000Moo`03001oogoo03Ao
ob@003eoo`00=Goo1@000Woo00<007ooOol047oo9000HGoo000jOolE0025Ool00=Aoo`00e7oo003D
Ool00=Aoo`00e7oo0000\
\>"],
  ImageRangeCache->{{{0, 211}, {169, 0}} -> {-0.0278127, 0.0516453, 
  0.00473002, 0.00473002}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now that the local point coordinates on each 3D body are defined, building \
the model is simply a matter of tying the points together with the correct \
mechanical constraints. ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " provides a library of mechanical constraint objects that translate the \
desired physical conditions that are imposed on the model into mathematical \
equations. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Constraint Objects"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Five constraint objects are used to model the slider-crank mechanism, \
constraining a total of 12 degrees of freedom (6 degrees of freedom for each \
moving body). "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolute5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be colinear with ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and constrains the origins of the two axes to be coincident.\n\n",
  StyleBox["ProjectedAngle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2, vector3, ang",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the direction angle of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians greater than the direction angle of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", with the direction angles measured as projected on a plane that is \
normal to ",
  StyleBox["vector3.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["Cylindrical4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be colinear with ",
  StyleBox["axis2.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["RelativeDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["Orthogonal1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be orthogonal to ",
  StyleBox["vector2.",
    FontSlant->"Italic"],
  "\n\n ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " is a unique positive integer constraint number."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Some 3D constraint objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that the last character in the name of any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint object is an integer that specifies the number of degrees of \
freedom that it constrains.\n\nThe first argument to each constraint object, \
",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", is the user-specified constraint number. This number is used to \
reference the constraint later in the modeling process, just as body numbers \
are used to reference specific bodies.\n\nThe ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " arguments required by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects are specified with ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects, used in much the same manner as the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives, ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These objects are discussed in detail in Section 2.2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Building the Model"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The ",
    FontFamily->"Times"],
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects used to model the physical relationships in the \
slider-crank model are as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the rotational axis of the crankshaft to be coincident \
with an axis on the ground body. This constrains five degrees of freedom: ",
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " displacement and rotation about the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " or ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axes. The one degree of freedom left for the crankshaft is rotation about \
the global ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis. The syntax of this constraint can be interpreted as, \"Constrain a \
line on the ground body spanning from {0,0,0} to {0,0,5} to be coincident \
with a line on the crankshaft spanning from {0,0,0} to {0,0,5}, and constrain \
the origins of the two lines to be coincident\"."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the rotational orientation of the crankshaft. This \
constraint works by projecting two vectors onto a specified plane, and then \
specifying the angle between the two vectors. The crankshaft is now \
completely constrained. The syntax of this constraint can be interpreted as, \
\"Constrain the counterclockwise direction angle of the vector {3,0,0} on the \
crankshaft to be ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " units greater than the direction angle of the vector {3,0,0} on the \
ground body, when the two vectors are projected on a plane on the ground body \
defined by the three points {0,0,0}, {3,0,0}, and {0,4,0}\"."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces a vertical (",
  StyleBox["+Y",
    FontSlant->"Italic"],
  ") line on the piston to be colinear with a vertical line on the ground \
body. This constrains four degrees of freedom, ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " displacement of the piston, and ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis rotation of the piston. The two degrees of freedom left are the \
pistons vertical translation in the cylinder and rotation of the piston in \
the cylinder."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces an eccentric point on the crankshaft to lie five units \
distant from a point on the vertical axis of the piston. This models the \
length of the connecting rod. The syntax of this constraint can be \
interpreted as, \"Constraint the absolute distance between a point {3,0,0} on \
the crankshaft and a point {0,4,0} on the piston to be equal to 5.0\"."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An ",
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces a vector in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction on the piston to be orthogonal to a vector in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction on the ground body. This constraint stops the piston from \
rotating in the cylinder, a function that would have been performed by the \
connecting rod in a real piston engine. This completes the constraint of the \
piston."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects are finally assembled into a mechanism model with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetConstraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["constraint",
    FontSlant->"Italic"],
  StyleBox["s",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" takes",
    FontFamily->"Times"],
  " ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint objects and builds a mathematical system representing the \
mechanism model."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The fundamental model-building function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the entire slider-crank model built in one step. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(crankangle =. \), 
    \(SetConstraints[\n\t
      Revolute5[1, Line[ground, {0, 0, 0}, {0, 0, 5}], \n\t\t
        Line[crankshaft, {0, 0, 0}, {0, 0, 5}]], \n\t
      ProjectedAngle1[2, Vector[crankshaft, {3, 0, 0}], \n\t\t
        Vector[ground, {3, 0, 0}], 
        Plane[ground, {0, 0, 0}, {3, 0, 0}, {0, 4, 0}], crankangle], \n\t
      Cylindrical4[3, Line[ground, {0, 4, 0}, {0, 9, 0}], \n\t\t
        Line[piston, {0, 4, 0}, {0, 9, 0}]], \n\t
      RelativeDistance1[4, Point[crankshaft, {3, 0, 0}], \n\t\t
        Point[piston, {0, 4, 0}], 5.], \n\t
      Orthogonal1[5, Vector[piston, {0, 0, 5}], \n\t\t
        Vector[ground, {3, 0, 0}]]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["Null",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". All of the mechanism equations generated by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are stored internally in the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " private context. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Running the Model"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To solve the constraint equations and return the coordinates of each of \
the bodies the model, the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is used."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a solution to the current mechanism model and returns the \
coordinates of each body in the system."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The fundamental model-solving function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This seeks a solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(crankangle = 0.; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] 0, Y2 \[Rule] 0, Z2 \[Rule] 0, Eo2 \[Rule] 1, 
      Ei2 \[Rule] 0, Ej2 \[Rule] 0, Ek2 \[Rule] 0, X3 \[Rule] 0, 
      Y3 \[Rule] 0, Z3 \[Rule] 0, Eo3 \[Rule] 1, Ei3 \[Rule] 0, 
      Ej3 \[Rule] 0, Ek3 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global coordinates of the origin of each body in the system. \
",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Z2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specify the location of the origin of body 2, the crankshaft.\n\n",
  StyleBox["Eo2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ei2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ej2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Ek2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are the Euler generalized parameters specifying the angular orientation \
of the crankshaft. ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a {",
  StyleBox["Xn, Yn, Zn, Eon, Ein, Ejn, Ekn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Times"],
  " set for each body in the system. For those unfamiliar with Euler \
parameters, suffice it to say that the four Euler parameters provide a \
numerically robust means of specifying the three degrees of freedom of the \
angular orientation of a body in 3D space. Values of {1, 0, 0, 0} for the \
four parameters, respectively, correspond to alignment with the global \
coordinate system. It is not necessary to have an understanding of the Euler \
parameters to utilize ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because postprocessing functions use the Euler parameters to generate \
more familiar output, such as the rotation of a body about an axis or the \
angle between two vectors. Euler parameters are discussed further in Chapter \
4."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the slider-crank model at the initial configuration."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!   
%%Creator: Mathematica   
%%AspectRatio: 1.35323    
MathPictureStart   
%% Graphics3D   
/Courier findfont 10  scalefont  setfont   
% Scaling calculations   
-0.16802 1.37431 0.0343577 1.37431 [   
[ 0 0 0 0 ]   
[ 1 1.35323 0 0 ]   
] MathScale   
% Start of Graphics   
1 setlinecap   
1 setlinejoin   
newpath   
[ ] 0 setdash   
0 g   
0 0 m   
1 0 L   
1 1.35323 L   
0 1.35323 L   
closepath   
clip   
newpath   
p   
.002 w   
.28194 .30732 m   
.06691 .13043 L   
s   
.06691 .13043 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
.26714 1.31887 m   
.28194 .30732 L   
s   
.93788 .23453 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.28194 .30732 m   
.06691 .13043 L   
s   
.06691 .13043 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.93788 .23453 m   
.28194 .30732 L   
s   
.26714 1.31887 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
P   
p   
.002 w   
.30689 .78334 m .31255 .33798 L .26949 .30272 L p   
.988 .782 .537 r   
F P   
s   
P   
p   
.002 w   
.31255 .33798 m .86808 .27803 L .83999 .2391 L p   
.538 .814 .997 r   
F P   
s   
P   
p   
.002 w   
.83999 .2391 m .26949 .30272 L .31255 .33798 L p   
.538 .814 .997 r   
F P   
s   
P   
p   
.002 w   
.47334 .40539 m .39314 .49448 L .35171 .46326 L p   
.869 .917 .858 r   
F P   
s   
P   
p   
.002 w   
.39314 .49448 m .3631 .60901 L .32059 .5811 L p   
.973 .858 .667 r   
F P   
s   
P   
p   
.002 w   
.32059 .5811 m .35171 .46326 L .39314 .49448 L p   
.973 .858 .667 r   
F P   
s   
P   
p   
.002 w   
.58376 .36434 m .47334 .40539 L .43422 .37143 L p   
.678 .883 .974 r   
F P   
s   
P   
p   
.002 w   
.35171 .46326 m .43422 .37143 L .47334 .40539 L p   
.869 .917 .858 r   
F P   
s   
P   
p   
.002 w   
.48699 .4281 m .41659 .50624 L .39646 .49099 L p   
.87 .92 .858 r   
F P   
s   
P   
p   
.002 w   
.41659 .50624 m .39032 .60674 L .36973 .59293 L p   
.974 .86 .664 r   
F P   
s   
P   
p   
.002 w   
.36973 .59293 m .39646 .49099 L .41659 .50624 L p   
.974 .86 .664 r   
F P   
s   
P   
p   
.002 w   
.3631 .60901 m .39141 .72022 L .34934 .69542 L p   
.972 .659 .331 r   
F P   
s   
P   
p   
.002 w   
.34934 .69542 m .32059 .5811 L .3631 .60901 L p   
.972 .659 .331 r   
F P   
s   
P   
p   
.002 w   
.58387 .39228 m .48699 .4281 L .46787 .41166 L p   
.675 .885 .975 r   
F P   
s   
P   
p   
.002 w   
.39646 .49099 m .46787 .41166 L .48699 .4281 L p   
.87 .92 .858 r   
F P   
s   
P   
p   
.002 w   
.39032 .60674 m .41535 .70416 L .39496 .69169 L p   
.971 .656 .321 r   
F P   
s   
P   
p   
.002 w   
.39496 .69169 m .36973 .59293 L .39032 .60674 L p   
.971 .656 .321 r   
F P   
s   
P   
p   
.002 w   
.33872 .86181 m .30689 .78334 L .26244 .76055 L p   
.942 .575 .24 r   
F P   
s   
P   
p   
.002 w   
.26949 .30272 m .26244 .76055 L .30689 .78334 L p   
.988 .782 .537 r   
F P   
s   
P   
p   
.002 w   
.69662 .38297 m .58376 .36434 L .54767 .32886 L p   
.305 .686 .977 r   
F P   
s   
P   
p   
.002 w   
.43422 .37143 m .54767 .32886 L .58376 .36434 L p   
.678 .883 .974 r   
F P   
s   
P   
p   
.002 w   
.26949 .30272 m .54757 .27171 L .54767 .32886 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .43422 .37143 L .26949 .30272 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.43422 .37143 m .35171 .46326 L .26949 .30272 L closepath p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.26513 .58587 m .26949 .30272 L .35171 .46326 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.46787 .41166 m .56607 .37519 L .58387 .39228 L p   
.675 .885 .975 r   
F P   
s   
P   
p   
.002 w   
.58436 .51637 m .58387 .39228 L .56607 .37519 L p   
.998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.43002 1.17733 m .43211 .77639 L .47223 .79908 L p   
.996 .786 .504 r   
F P   
s   
P   
p   
.002 w   
.42625 .75422 m .47223 .79908 L .43211 .77639 L p   
.663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.48631 .77297 m .46677 .7614 L p   
.46549 .75998 L .65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.41535 .70416 m .48457 .77128 L p   
.46549 .75998 L .65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.48457 .77128 m .48631 .77297 L p   
.46549 .75998 L .65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.46677 .7614 m .39496 .69169 L .41535 .70416 L p   
.65 .119 0 r   
F P   
s   
P   
p   
.002 w   
.39646 .49099 m .46787 .41166 L p   
.55941 .75318 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.58496 .66548 m .56686 .65225 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.58535 .76445 m .58496 .66548 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.57476 .75758 m .56888 .75377 L .49396 .76311 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.49369 .94097 m .58606 .94201 L .58547 .79378 L p   
.72 .551 .66 r   
F P   
s   
P   
p   
.002 w   
.58547 .79378 m .58535 .76445 L p   
.57193 .79029 L .72 .551 .66 r   
F P   
s   
P   
p   
.002 w   
.48631 .77297 m .51886 .7798 L p   
.50754 .77545 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.49396 .76311 m .47612 .75893 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.47619 .73446 m .46743 .75953 L .39496 .69169 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.46677 .7614 m .46501 .75969 L p   
.46743 .75953 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.46501 .75969 m .39496 .69169 L p   
.46743 .75953 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.47611 .76336 m .46677 .7614 L p   
.47619 .73446 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.45558 .75411 m .47612 .75893 L p   
.4467 .74885 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.47612 .75893 m .49396 .76311 L p   
.47935 .7587 L .412 .806 .987 r   
F P   
s   
P   
p   
.47612 .75893 m .47611 .76336 L .49162 .76932 L .896 .697 .625 r   
F   
P   
p   
.002 w   
.56686 .65225 m .56715 .75265 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.59117 .75099 m .47935 .7587 L .49396 .76311 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.58535 .76445 m .49396 .76311 L .49395 .77022 L p   
.72 .551 .66 r   
F P   
s   
P   
p   
.58535 .76445 m .49395 .77022 L .57193 .79029 L .72 .551 .66 r   
F   
P   
p   
.002 w   
.47221 .76462 m .48631 .77297 L p   
.51982 .77688 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.47223 .79908 m .47114 1.1883 L .43002 1.17733 L p   
.996 .786 .504 r   
F P   
s   
P   
p   
.002 w   
.43131 .9297 m .49369 .94097 L .49395 .77022 L p   
.896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.49395 .77022 m .49396 .76311 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.56724 .78241 m .47221 .76462 L .51982 .77688 L .096 .599 .897 r   
F   
P   
p   
.49162 .76932 m .43131 .9297 L .49395 .77022 L .896 .697 .625 r   
F   
P   
p   
.002 w   
.46677 .7614 m .47221 .76462 L p   
.48621 .76724 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.56724 .78241 m .47611 .76336 L p   
.48621 .76724 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.47611 .76336 m .46677 .7614 L p   
.48621 .76724 L .096 .599 .897 r   
F P   
s   
P   
p   
.51982 .77688 m .50754 .77545 L .58547 .79378 L .096 .599 .897 r   
F   
P   
p   
.002 w   
.51886 .7798 m .58547 .79378 L p   
.50754 .77545 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.49395 .77022 m .49369 .94097 L p   
.57193 .79029 L .72 .551 .66 r   
F P   
s   
P   
p   
.002 w   
.49396 .76311 m .58535 .76445 L .65672 .75196 L p   
.412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.56724 .78241 m .47611 .76336 L p   
.47612 .75893 L .631 .478 .656 r   
F P   
s   
P   
p   
.51726 .75609 m .47612 .75893 L .47619 .73446 L .631 .478 .656 r   
F   
P   
p   
.56724 .78241 m .47612 .75893 L .51726 .75609 L .631 .478 .656 r   
F   
P   
p   
.55047 .7538 m .39646 .49099 L .55941 .75318 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.36973 .59293 m .39646 .49099 L p   
.55047 .7538 L .631 .478 .656 r   
F P   
s   
P   
p   
.56724 .78241 m .53829 .75464 L .55047 .7538 L .631 .478 .656 r   
F   
P   
p   
.53829 .75464 m .36973 .59293 L .55047 .7538 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.46787 .41166 m .56607 .37519 L .56715 .75265 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.56715 .75265 m .56724 .78241 L p   
.55941 .75318 L .631 .478 .656 r   
F P   
s   
P   
p   
.55941 .75318 m .46787 .41166 L .56715 .75265 L .631 .478 .656 r   
F   
P   
p   
.63952 .74765 m .6289 .73775 L .61212 .73892 L .412 .806 .987 r   
F   
P   
p   
.61642 .74187 m .61212 .73892 L .60628 .73933 L .412 .806 .987 r   
F   
P   
p   
.63952 .74765 m .61212 .73892 L .61642 .74187 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.58496 .66548 m .77243 .65113 L .75693 .63745 L p   
.446 .812 .995 r   
F P   
s   
P   
p   
.002 w   
.75693 .63745 m .56686 .65225 L .58496 .66548 L p   
.446 .812 .995 r   
F P   
s   
P   
p   
.002 w   
.56607 .37519 m .56643 .50101 L .58436 .51637 L p   
.998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.77011 .49971 m .58436 .51637 L .56643 .50101 L p   
.49 .816 1 r   
F P   
s   
P   
p   
.002 w   
.75693 .63745 m .56686 .65225 L .56643 .50101 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .75693 .63745 L p   
.56643 .50101 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.71996 .5425 m .71161 .56403 L .72047 .58416 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.74065 .53209 m .71996 .5425 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.61212 .73892 m .71526 .59005 L p   
.58812 .7406 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.72047 .58416 m .71161 .56403 L .69861 .55216 L p   
.875 .481 .018 r   
F P   
s   
P   
p   
.72047 .58416 m .71113 .57049 L .70402 .56448 L .875 .481 .018 r   
F   
P   
p   
.71113 .57049 m .69861 .55216 L .7037 .56375 L .875 .481 .018 r   
F   
P   
p   
.71113 .57049 m .7037 .56375 L .70402 .56448 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.39496 .69169 m .36973 .59293 L p   
.56724 .78241 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.56643 .50101 m .75472 .48385 L .77011 .49971 L p   
.49 .816 1 r   
F P   
s   
P   
p   
.002 w   
.56643 .50101 m .75472 .48385 L .77063 .55904 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.71161 .56403 m .71996 .5425 L .70707 .53037 L p   
.97 .914 .696 r   
F P   
s   
P   
p   
.002 w   
.70707 .53037 m .68661 .51112 L p   
.70194 .54357 L .97 .914 .696 r   
F P   
s   
P   
p   
.71161 .56403 m .70707 .53037 L .70194 .54357 L .97 .914 .696 r   
F   
P   
p   
.002 w   
.68661 .51112 m .67798 .53331 L .69147 .54564 L p   
.97 .914 .696 r   
F P   
s   
P   
p   
.002 w   
.69147 .54564 m .71161 .56403 L p   
.69664 .53235 L .97 .914 .696 r   
F P   
s   
P   
p   
.69664 .53235 m .68661 .51112 L .69147 .54564 L .97 .914 .696 r   
F   
P   
p   
.002 w   
.68184 .59531 m .58085 .74111 L p   
.66224 .64579 L .63 .477 .655 r   
F P   
s   
P   
p   
.58589 .74446 m .57773 .74133 L .56484 .74223 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.76164 .53891 m .74065 .53209 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.70755 .5725 m .72047 .58416 L p   
.70402 .56448 L .875 .481 .018 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .76164 .53891 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.76226 .5807 m .77063 .55904 L p   
.72047 .58416 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.72047 .58416 m .74144 .5911 L .76226 .5807 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.74144 .5911 m .72047 .58416 L .70755 .5725 L p   
.06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.73861 .55634 m .71816 .54289 L .69949 .56984 L p   
.63 .477 .655 r   
F P   
s   
P   
p   
.72883 .5825 m .70755 .5725 L .72039 .57674 L .06 .538 .893 r   
F   
P   
p   
.74144 .5911 m .73347 .58672 L .72883 .5825 L .06 .538 .893 r   
F   
P   
p   
.73347 .58672 m .70755 .5725 L .72883 .5825 L .06 .538 .893 r   
F   
P   
p   
.73861 .55634 m .69949 .56984 L .71263 .57418 L .63 .477 .655 r   
F   
P   
p   
.73861 .55634 m .72102 .57695 L .72162 .57715 L .63 .477 .655 r   
F   
P   
p   
.73861 .55634 m .71263 .57418 L .71528 .57506 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.72875 .5795 m .74144 .5911 L p   
.72039 .57674 L .06 .538 .893 r   
F P   
s   
P   
p   
.73861 .55634 m .67814 .60484 L .71143 .58817 L .63 .477 .655 r   
F   
P   
p   
.73861 .55634 m .7138 .58672 L .7139 .58694 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.71526 .59005 m .71928 .58425 L p   
.7139 .58694 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.71928 .58425 m .73861 .55634 L p   
.7139 .58694 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.7322 .5656 m .72372 .57784 L p   
.72747 .5647 L .914 .951 .806 r   
F P   
s   
P   
p   
.002 w   
.71816 .54289 m .73861 .55634 L .73171 .54983 L p   
0 .253 .705 r   
F P   
s   
P   
p   
.73171 .54983 m .7322 .5656 L .72747 .5647 L .914 .951 .806 r   
F   
P   
p   
.002 w   
.73171 .54983 m .73861 .55634 L .7322 .5656 L p   
.914 .951 .806 r   
F P   
s   
P   
p   
.73171 .54983 m .72372 .57784 L .71732 .57201 L .914 .951 .806 r   
F   
P   
p   
.6966 .55731 m .67798 .53331 L .69497 .55583 L .875 .481 .018 r   
F   
P   
p   
.70252 .56268 m .69501 .55369 L .6966 .55731 L .875 .481 .018 r   
F   
P   
p   
.69501 .55369 m .67798 .53331 L .6966 .55731 L .875 .481 .018 r   
F   
P   
p   
.57773 .74133 m .50907 .71499 L .56484 .74223 L .412 .806 .987 r   
F   
P   
p   
.56665 .73165 m .50907 .71499 L .58589 .74446 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.6966 .55731 m .57294 .73584 L p   
.70312 .56323 L .914 .949 .807 r   
F P   
s   
P   
p   
.59117 .75099 m .51477 .73994 L .43226 .74863 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.43685 .72866 m .43293 .7457 L p   
.51477 .73994 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.43293 .7457 m .43226 .74863 L p   
.51477 .73994 L .412 .806 .987 r   
F P   
s   
P   
p   
.70312 .56323 m .57294 .73584 L .57467 .73699 L .914 .949 .807 r   
F   
P   
p   
.6976 .55959 m .70046 .56611 L .69506 .56433 L .63 .476 .655 r   
F   
P   
p   
.7138 .58672 m .58085 .74111 L .58812 .7406 L .63 .477 .655 r   
F   
P   
p   
.71366 .58641 m .58085 .74111 L .7138 .58672 L .63 .477 .655 r   
F   
P   
p   
.72102 .57695 m .58085 .74111 L .72162 .57715 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.58085 .74111 m .7037 .56375 L p   
.57483 .7371 L .914 .949 .807 r   
F P   
s   
P   
p   
.70312 .56323 m .57467 .73699 L .7037 .56375 L .914 .949 .807 r   
F   
P   
p   
.62532 .74863 m .53187 .73873 L .59117 .75099 L .412 .806 .987 r   
F   
P   
p   
.53187 .73873 m .43685 .72866 L .51477 .73994 L .412 .806 .987 r   
F   
P   
p   
.53187 .73873 m .51477 .73994 L .59117 .75099 L .412 .806 .987 r   
F   
P   
p   
.57467 .73699 m .57483 .7371 L .7037 .56375 L .914 .949 .807 r   
F   
P   
p   
.7138 .58672 m .58812 .7406 L .71526 .59005 L .63 .477 .655 r   
F   
P   
p   
.66279 .61944 m .59604 .73421 L .67459 .58908 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.57294 .73584 m .67459 .58908 L p   
.59403 .73435 L .63 .476 .655 r   
F P   
s   
P   
p   
.62621 .74857 m .56123 .72805 L .62532 .74863 L .412 .806 .987 r   
F   
P   
p   
.63952 .74765 m .61642 .74187 L .62621 .74857 L .412 .806 .987 r   
F   
P   
p   
.61642 .74187 m .56123 .72805 L .62621 .74857 L .412 .806 .987 r   
F   
P   
p   
.72039 .57674 m .70885 .56887 L .72875 .5795 L .06 .538 .893 r   
F   
P   
p   
.70885 .56887 m .71431 .57068 L .72875 .5795 L .06 .538 .893 r   
F   
P   
p   
.71899 .57354 m .71431 .57068 L .71672 .57147 L .06 .538 .893 r   
F   
P   
p   
.71143 .58817 m .67814 .60484 L .66224 .64579 L .63 .477 .655 r   
F   
P   
p   
.70402 .56448 m .70252 .56268 L .70755 .5725 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.69235 .56344 m .6966 .55731 L p   
.69313 .56369 L .63 .476 .655 r   
F P   
s   
P   
p   
.6976 .55959 m .66279 .61944 L .6966 .55731 L .63 .476 .655 r   
F   
P   
p   
.70252 .56268 m .69497 .55583 L .70755 .5725 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.70046 .56611 m .70755 .5725 L p   
.6992 .56144 L .875 .481 .018 r   
F P   
s   
P   
p   
.002 w   
.70755 .5725 m .70046 .56611 L p   
.72039 .57674 L .06 .538 .893 r   
F P   
s   
P   
p   
.72039 .57674 m .70046 .56611 L .70885 .56887 L .06 .538 .893 r   
F   
P   
p   
.72162 .57715 m .71366 .58641 L .7138 .58672 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.72372 .57784 m .61212 .73892 L p   
.71732 .57201 L .914 .951 .806 r   
F P   
s   
P   
p   
.56123 .72805 m .56665 .73165 L .62532 .74863 L .412 .806 .987 r   
F   
P   
p   
.62532 .74863 m .57951 .73538 L .58589 .74446 L .412 .806 .987 r   
F   
P   
p   
.65672 .75196 m .62532 .74863 L .59117 .75099 L .412 .806 .987 r   
F   
P   
p   
.57193 .79029 m .49369 .94097 L .58547 .79378 L .72 .551 .66 r   
F   
P   
p   
.002 w   
.58547 .79378 m .56724 .78241 L p   
.51982 .77688 L .096 .599 .897 r   
F P   
s   
P   
p   
.002 w   
.56724 .78241 m .58547 .79378 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.002 w   
.56715 .75265 m .56724 .78241 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.65672 .75196 m .59117 .75099 L .56888 .75377 L .412 .806 .987 r   
F   
P   
p   
.65672 .75196 m .56888 .75377 L .57476 .75758 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.58547 .79378 m .58535 .76445 L p   
.58126 .76179 L .998 .787 .477 r   
F P   
s   
P   
p   
.56724 .78241 m .55047 .7538 L .55941 .75318 L .631 .478 .656 r   
F   
P   
p   
.002 w   
.65672 .75196 m .58535 .76445 L .58606 .94201 L p   
.509 .38 .64 r   
F P   
s   
P   
p   
.002 w   
.56253 .81049 m .60537 .7445 L p   
.54258 .79637 L .63 .477 .655 r   
F P   
s   
P   
p   
.57951 .73538 m .57294 .73584 L .58589 .74446 L .412 .806 .987 r   
F   
P   
p   
.59117 .75099 m .56398 .75059 L .56715 .75265 L .412 .806 .987 r   
F   
P   
p   
.58812 .7406 m .54258 .79637 L .61212 .73892 L .63 .477 .655 r   
F   
P   
p   
.71732 .57201 m .61212 .73892 L .60995 .73743 L .914 .951 .806 r   
F   
P   
p   
.69488 .56427 m .60439 .73362 L .59604 .73421 L .63 .476 .655 r   
F   
P   
p   
.69506 .56433 m .60439 .73362 L .69488 .56427 L .63 .476 .655 r   
F   
P   
p   
.71528 .57506 m .68184 .59531 L .67814 .60484 L .63 .477 .655 r   
F   
P   
p   
.71263 .57418 m .68184 .59531 L .71528 .57506 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.69949 .56984 m .68184 .59531 L p   
.71263 .57418 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.70821 .58376 m .60439 .73362 L p   
.69506 .56433 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.60439 .73362 m .71672 .57147 L p   
.60995 .73743 L .914 .951 .806 r   
F P   
s   
P   
p   
.71732 .57201 m .60995 .73743 L .71672 .57147 L .914 .951 .806 r   
F   
P   
p   
.6289 .73775 m .60611 .71649 L .60628 .73933 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.61212 .73892 m .56253 .81049 L p   
.60995 .73743 L .914 .951 .806 r   
F P   
s   
P   
p   
.59604 .73421 m .59403 .73435 L .67459 .58908 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.60611 .71649 m .54238 .7155 L p   
.60628 .73933 L .412 .806 .987 r   
F P   
s   
P   
p   
.60628 .73933 m .54238 .7155 L .56123 .72805 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.54258 .79637 m .56253 .81049 L .55448 .80567 L p   
.461 0 0 r   
F P   
s   
P   
p   
.59604 .73421 m .55448 .80567 L .59403 .73435 L .63 .476 .655 r   
F   
P   
p   
.56715 .75265 m .4467 .74885 L .47935 .7587 L .412 .806 .987 r   
F   
P   
p   
.56398 .75059 m .4467 .74885 L .56715 .75265 L .412 .806 .987 r   
F   
P   
p   
.57467 .73699 m .53441 .79147 L .57483 .7371 L .914 .949 .807 r   
F   
P   
p   
.56123 .72805 m .50907 .71499 L .56665 .73165 L .412 .806 .987 r   
F   
P   
p   
.6976 .55959 m .69506 .56433 L .69488 .56427 L .63 .476 .655 r   
F   
P   
p   
.70402 .56448 m .70397 .56435 L .70386 .56429 L .875 .481 .018 r   
F   
P   
p   
.70397 .56435 m .69861 .55216 L .70386 .56429 L .875 .481 .018 r   
F   
P   
p   
.002 w   
.69861 .55216 m .67798 .53331 L p   
.70386 .56429 L .875 .481 .018 r   
F P   
s   
P   
p   
.002 w   
.71816 .54289 m .71115 .5363 L p   
.71042 .54806 L .914 .949 .807 r   
F P   
s   
P   
p   
.002 w   
.71115 .5363 m .6966 .55731 L p   
.71042 .54806 L .914 .949 .807 r   
F P   
s   
P   
p   
.71816 .54289 m .6966 .55731 L .70312 .56323 L .914 .949 .807 r   
F   
P   
p   
.002 w   
.71672 .57147 m .73171 .54983 L p   
.71732 .57201 L .914 .951 .806 r   
F P   
s   
P   
p   
.72875 .5795 m .71899 .57354 L .71747 .57172 L .06 .538 .893 r   
F   
P   
p   
.002 w   
.7037 .56375 m .71816 .54289 L p   
.70312 .56323 L .914 .949 .807 r   
F P   
s   
P   
p   
.002 w   
.70791 .50034 m .68661 .51112 L .71996 .5425 L p   
.717 .926 .961 r   
F P   
s   
P   
p   
.002 w   
.71996 .5425 m .74065 .53209 L .70791 .50034 L p   
.717 .926 .961 r   
F P   
s   
P   
p   
.002 w   
.73171 .54983 m .71115 .5363 L .71816 .54289 L p   
0 .253 .705 r   
F P   
s   
P   
p   
.002 w   
.71115 .5363 m .73171 .54983 L .71672 .57147 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.71115 .5363 m .71672 .57147 L .70913 .56897 L .63 .476 .655 r   
F   
P   
p   
.6992 .56144 m .69731 .55894 L .69812 .56078 L .875 .481 .018 r   
F   
P   
p   
.6992 .56144 m .69812 .56078 L .70046 .56611 L .875 .481 .018 r   
F   
P   
p   
.71115 .5363 m .70913 .56897 L .6976 .55959 L .63 .476 .655 r   
F   
P   
p   
.70913 .56897 m .70821 .58376 L .70046 .56611 L .63 .476 .655 r   
F   
P   
p   
.70913 .56897 m .70046 .56611 L .6976 .55959 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.70349 .55941 m .70861 .5611 L p   
.71747 .57172 L .06 .538 .893 r   
F P   
s   
P   
p   
.71899 .57354 m .71672 .57147 L .71747 .57172 L .06 .538 .893 r   
F   
P   
p   
.71672 .57147 m .70349 .55941 L .71747 .57172 L .06 .538 .893 r   
F   
P   
p   
.002 w   
.70861 .5611 m .72179 .57314 L p   
.71747 .57172 L .06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.72179 .57314 m .72875 .5795 L p   
.71747 .57172 L .06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.71672 .57147 m .70821 .58376 L p   
.70913 .56897 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.67798 .53331 m .68705 .55401 L .70046 .56611 L p   
.875 .481 .018 r   
F P   
s   
P   
p   
.69731 .55894 m .67798 .53331 L .70046 .56611 L .875 .481 .018 r   
F   
P   
p   
.70885 .56887 m .68705 .55401 L .71431 .57068 L .06 .538 .893 r   
F   
P   
p   
.002 w   
.6966 .55731 m .71115 .5363 L p   
.6976 .55959 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.68705 .55401 m .70349 .55941 L p   
.71672 .57147 L .06 .538 .893 r   
F P   
s   
P   
p   
.71431 .57068 m .68705 .55401 L .71672 .57147 L .06 .538 .893 r   
F   
P   
p   
.70046 .56611 m .70821 .58376 L .69506 .56433 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.60439 .73362 m .55448 .80567 L p   
.59604 .73421 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.57294 .73584 m .53441 .79147 L p   
.57467 .73699 L .914 .949 .807 r   
F P   
s   
P   
p   
.002 w   
.54238 .7155 m .50907 .71499 L p   
.56123 .72805 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.70861 .5611 m .73004 .55033 L .74981 .56896 L p   
.712 .93 .962 r   
F P   
s   
P   
p   
.002 w   
.74981 .56896 m .76226 .5807 L p   
.74151 .57312 L .712 .93 .962 r   
F P   
s   
P   
p   
.74151 .57312 m .70861 .5611 L .74981 .56896 L .712 .93 .962 r   
F   
P   
p   
.002 w   
.76226 .5807 m .74144 .5911 L .72875 .5795 L p   
.712 .93 .962 r   
F P   
s   
P   
p   
.002 w   
.72875 .5795 m .70861 .5611 L p   
.74151 .57312 L .712 .93 .962 r   
F P   
s   
P   
p   
.76226 .5807 m .72875 .5795 L .74151 .57312 L .712 .93 .962 r   
F   
P   
p   
.002 w   
.70046 .56611 m .68705 .55401 L p   
.70885 .56887 L .06 .538 .893 r   
F P   
s   
P   
p   
.002 w   
.67459 .58908 m .69235 .56344 L p   
.66279 .61944 L .63 .476 .655 r   
F P   
s   
P   
p   
.69313 .56369 m .66279 .61944 L .69235 .56344 L .63 .476 .655 r   
F   
P   
p   
.57951 .73538 m .56665 .73165 L .57294 .73584 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.5658 .76284 m .54258 .79637 L p   
.56381 .77037 L .63 .477 .655 r   
F P   
s   
P   
p   
.58812 .7406 m .5658 .76284 L .56381 .77037 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.58085 .74111 m .5658 .76284 L p   
.58812 .7406 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.53441 .79147 m .54258 .79637 L .58085 .74111 L p   
.914 .949 .807 r   
F P   
s   
P   
p   
.57483 .7371 m .53441 .79147 L .58085 .74111 L .914 .949 .807 r   
F   
P   
p   
.002 w   
.55448 .80567 m .53441 .79147 L .54258 .79637 L p   
.461 0 0 r   
F P   
s   
P   
p   
.002 w   
.55448 .80567 m .53441 .79147 L .57294 .73584 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.59403 .73435 m .55448 .80567 L .57294 .73584 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.50907 .71499 m .43685 .72866 L p   
.56484 .74223 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.56253 .81049 m .55448 .80567 L .60439 .73362 L p   
.914 .951 .806 r   
F P   
s   
P   
p   
.60995 .73743 m .56253 .81049 L .60439 .73362 L .914 .951 .806 r   
F   
P   
p   
.65672 .75196 m .64959 .74696 L .63952 .74765 L .412 .806 .987 r   
F   
P   
p   
.64959 .74696 m .60611 .71649 L .63952 .74765 L .412 .806 .987 r   
F   
P   
p   
.65672 .75196 m .63952 .74765 L .62532 .74863 L .412 .806 .987 r   
F   
P   
p   
.4467 .74885 m .47612 .75893 L .47935 .7587 L .412 .806 .987 r   
F   
P   
p   
.002 w   
.47612 .75893 m .44657 .75199 L p   
.47611 .76336 L .896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.43226 .74863 m .43131 .9297 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.44657 .75199 m .43226 .74863 L p   
.49162 .76932 L .896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.43226 .74863 m .45558 .75411 L p   
.4467 .74885 L .412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.43593 .91415 m .43131 .9297 L .43211 .77639 L p   
0 0 .097 r   
F P   
s   
P   
p   
.002 w   
.43211 .77639 m .43226 .74863 L p   
.43294 .77953 L 0 0 .097 r   
F P   
s   
P   
p   
.43294 .77953 m .43593 .91415 L .43211 .77639 L 0 0 .097 r   
F   
P   
p   
.002 w   
.39141 .72022 m .42625 .75422 L p   
.43211 .77639 L .663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.43211 .77639 m .34934 .69542 L .39141 .72022 L p   
.663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.26244 .76055 m .29488 .84123 L .33872 .86181 L p   
.942 .575 .24 r   
F P   
s   
P   
p   
.002 w   
.41591 .89217 m .33872 .86181 L .29488 .84123 L p   
0 .365 .711 r   
F P   
s   
P   
p   
.002 w   
.78191 .45826 m .69662 .38297 L .66354 .34763 L p   
0 .108 .604 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .66354 .34763 L .69662 .38297 L p   
.305 .686 .977 r   
F P   
s   
P   
p   
.002 w   
.29488 .84123 m .37404 .87233 L .41591 .89217 L p   
0 .365 .711 r   
F P   
s   
P   
p   
.002 w   
.4137 1.25092 m .41591 .89217 L .37404 .87233 L p   
.994 .785 .516 r   
F P   
s   
P   
p   
.002 w   
.35171 .46326 m .32059 .5811 L .26513 .58587 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.26244 .76055 m .26513 .58587 L .32059 .5811 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.86808 .27803 m .87814 .74458 L .84953 .71935 L p   
.989 .775 .387 r   
F P   
s   
P   
p   
.002 w   
.84953 .71935 m .83999 .2391 L .86808 .27803 L p   
.989 .775 .387 r   
F P   
s   
P   
p   
.002 w   
.32059 .5811 m .34934 .69542 L .26244 .76055 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.66354 .34763 m .75106 .42481 L .78191 .45826 L p   
0 .108 .604 r   
F P   
s   
P   
p   
.002 w   
.8152 .57142 m .78191 .45826 L .75106 .42481 L p   
.924 .588 .133 r   
F P   
s   
P   
p   
.002 w   
.78587 .57386 m .77011 .49971 L .75472 .48385 L p   
.958 .656 .231 r   
F P   
s   
P   
p   
.002 w   
.83999 .2391 m .54757 .27171 L .54767 .32886 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.29488 .84123 m .26244 .76055 L .34934 .69542 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .66354 .34763 L .83999 .2391 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.77243 .65113 m .78587 .57386 L .77063 .55904 L p   
.996 .864 .566 r   
F P   
s   
P   
p   
.002 w   
.75472 .48385 m .77063 .55904 L .78587 .57386 L p   
.958 .656 .231 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .29488 .84123 L p   
.34934 .69542 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.34934 .69542 m .43211 .77639 L .37404 .87233 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.78566 .69145 m .8152 .57142 L .78508 .54117 L p   
.99 .888 .608 r   
F P   
s   
P   
p   
.002 w   
.75106 .42481 m .78508 .54117 L .8152 .57142 L p   
.924 .588 .133 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .75693 .63745 L .77243 .65113 L p   
.996 .864 .566 r   
F P   
s   
P   
p   
.002 w   
.58606 .94201 m .65821 .93229 L .65672 .75196 L p   
.509 .38 .64 r   
F P   
s   
P   
p   
.002 w   
.49369 .94097 m .58606 .94201 L .65821 .93229 L p   
.339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.70531 1.18107 m .70098 .78411 L .66721 .76047 L p   
.998 .785 .446 r   
F P   
s   
P   
p   
.002 w   
.70098 .78411 m .78566 .69145 L .75447 .66484 L p   
.87 .967 .856 r   
F P   
s   
P   
p   
.002 w   
.75447 .66484 m .66721 .76047 L .70098 .78411 L p   
.87 .967 .856 r   
F P   
s   
P   
p   
.002 w   
.43131 .9297 m .49369 .94097 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .37084 1.24194 L .4137 1.25092 L p   
.994 .785 .516 r   
F P   
s   
P   
p   
.002 w   
.76628 1.24194 m .4137 1.25092 L .37084 1.24194 L p   
.179 .705 .863 r   
F P   
s   
P   
p   
.002 w   
.78508 .54117 m .75447 .66484 L .78566 .69145 L p   
.99 .888 .608 r   
F P   
s   
P   
p   
.002 w   
.47114 1.1883 m .70531 1.18107 L .67084 1.16963 L p   
.215 .725 .888 r   
F P   
s   
P   
p   
.002 w   
.67084 1.16963 m .43002 1.17733 L .47114 1.1883 L p   
.215 .725 .888 r   
F P   
s   
P   
p   
.002 w   
.66696 .73216 m .65672 .75196 L .65821 .93229 L p   
0 0 .229 r   
F P   
s   
P   
p   
.002 w   
.65672 .75196 m .66696 .73216 L .60611 .71649 L p   
.412 .806 .987 r   
F P   
s   
P   
p   
.002 w   
.66354 .34763 m .75106 .42481 L .83999 .2391 L closepath p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.72949 .50729 m .70791 .50034 L .74065 .53209 L p   
.091 .554 .908 r   
F P   
s   
P   
p   
.002 w   
.74065 .53209 m .76164 .53891 L .72949 .50729 L p   
.091 .554 .908 r   
F P   
s   
P   
p   
.01 w   
.54808 .56154 m   
.44598 .48049 L   
s   
P   
p   
.01 w   
.69505 .54891 m   
.70288 .54824 L   
s   
P   
p   
.01 w   
.54808 .56154 m   
.68518 .54976 L   
s   
P   
p   
.02 w   
.54808 .56154 Mdot   
P   
p   
.02 w   
.54808 .56154 Mdot   
P   
p   
.002 w   
.43226 .74863 m .43685 .72866 L .43593 .91415 L p   
0 0 .097 r   
F P   
s   
P   
p   
.002 w   
.7387 .528 m .72949 .50729 L .76164 .53891 L p   
.858 .463 0 r   
F P   
s   
P   
p   
.002 w   
.76164 .53891 m .77063 .55904 L .7387 .528 L p   
.858 .463 0 r   
F P   
s   
P   
p   
.002 w   
.43002 1.17733 m .43211 .77639 L .37404 .87233 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .37084 1.24194 L .43002 1.17733 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.73004 .55033 m .7387 .528 L .77063 .55904 L p   
.971 .919 .689 r   
F P   
s   
P   
p   
.002 w   
.77063 .55904 m .76226 .5807 L .73004 .55033 L p   
.971 .919 .689 r   
F P   
s   
P   
p   
.002 w   
.84384 .83119 m .76096 .87233 L .72872 .85124 L p   
.684 .949 .957 r   
F P   
s   
P   
p   
.002 w   
.76096 .87233 m .76628 1.24194 L .73348 1.23237 L p   
.996 .782 .428 r   
F P   
s   
P   
p   
.002 w   
.73348 1.23237 m .72872 .85124 L .76096 .87233 L p   
.996 .782 .428 r   
F P   
s   
P   
p   
.002 w   
.87814 .74458 m .84384 .83119 L .81408 .80867 L p   
.969 .932 .675 r   
F P   
s   
P   
p   
.002 w   
.81408 .80867 m .84953 .71935 L .87814 .74458 L p   
.969 .932 .675 r   
F P   
s   
P   
p   
.002 w   
.43593 .91415 m .43131 .9297 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.50895 .90349 m .43593 .91415 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.60709 .90466 m .50895 .90349 L p   
.65821 .93229 L .339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.65821 .93229 m .6686 .91687 L .66696 .73216 L p   
0 0 .229 r   
F P   
s   
P   
p   
.002 w   
.65821 .93229 m .6686 .91687 L .60709 .90466 L p   
.339 .783 .96 r   
F P   
s   
P   
p   
.002 w   
.72872 .85124 m .81408 .80867 L .84384 .83119 L p   
.684 .949 .957 r   
F P   
s   
P   
p   
.002 w   
.84589 .53594 m .83999 .2391 L .75106 .42481 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.75106 .42481 m .78508 .54117 L .84589 .53594 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.01 w   
.5485 .80144 m   
.54868 .90396 L   
s   
P   
p   
.01 w   
.54871 .92335 m   
.54904 1.11028 L   
s   
P   
p   
.002 w   
.66721 .76047 m .67084 1.16963 L .70531 1.18107 L p   
.998 .785 .446 r   
F P   
s   
P   
p   
.002 w   
.84953 .71935 m .84589 .53594 L .78508 .54117 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.78508 .54117 m .75447 .66484 L .84953 .71935 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.60611 .71649 m .66696 .73216 L .6686 .91687 L p   
.909 .704 .613 r   
F P   
s   
P   
p   
.02 w   
.54871 .92335 Mdot   
P   
p   
.002 w   
.75447 .66484 m .66721 .76047 L .72872 .85124 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.67084 1.16963 m .66721 .76047 L .72872 .85124 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.43002 1.17733 m .37084 1.24194 L .73348 1.23237 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.37084 1.24194 m .73348 1.23237 L .76628 1.24194 L p   
.179 .705 .863 r   
F P   
s   
P   
p   
.002 w   
.81408 .80867 m .84953 .71935 L .75447 .66484 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.72872 .85124 m .81408 .80867 L p   
.75447 .66484 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.50895 .90349 m .43593 .91415 L .43685 .72866 L p   
.491 .363 .633 r   
F P   
s   
P   
p   
.002 w   
.43685 .72866 m .50907 .71499 L .50895 .90349 L p   
.491 .363 .633 r   
F P   
s   
P   
p   
.002 w   
.73348 1.23237 m .67084 1.16963 L .43002 1.17733 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.68661 .51112 m .67798 .53331 L .68705 .55401 L p   
.628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.70791 .50034 m .68661 .51112 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.72949 .50729 m .70791 .50034 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.7387 .528 m .72949 .50729 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.73004 .55033 m .7387 .528 L p   
.68705 .55401 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.68705 .55401 m .70861 .5611 L .73004 .55033 L p   
.628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.6686 .91687 m .60709 .90466 L .60611 .71649 L p   
.909 .704 .613 r   
F P   
s   
P   
p   
.02 w   
.54904 1.11028 Mdot   
P   
p   
.002 w   
.72872 .85124 m .73348 1.23237 L .67084 1.16963 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.50907 .71499 m .60611 .71649 L .60709 .90466 L p   
.721 .549 .657 r   
F P   
s   
P   
p   
.002 w   
.60709 .90466 m .50895 .90349 L .50907 .71499 L p   
.721 .549 .657 r   
F P   
s   
P   
p   
.01 w   
.44483 .73888 m   
.50903 .77735 L   
s   
P   
p   
.02 w   
.44598 .48049 Mdot   
P   
p   
.02 w   
.44598 .48049 Mdot   
P   
p   
.02 w   
.44483 .73888 Mdot   
P   
p   
.002 w   
.93788 .23453 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.26714 1.31887 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
P   
p   
P   
% End of Graphics   
MathPictureEnd   
   \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{221, 300},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0001;1000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00[Woo1000:goo002VOol80003Ool2000ZOol0
09ioo`P000]oo`8002Yoo`00UWoo20004goo00<007oo0000:Goo002?Ool7000KOol01000Oomoo`00
:7oo0027Ool8000ROol01000Oomoo`00:7oo001oOol8000ZOol01@00Oomoogoo00009goo001gOol8
000bOol00`00Oomoo`02Ool00`00Oomoo`0TOol0071oo`L003Yoo`03001oogoo009oo`03001oogoo
02Aoo`00J7oo2000@Goo00<007ooOol00goo00<007ooOol08goo001POol80019Ool00`00Oomoo`04
Ool00`00Oomoo`0ROol005Qoo`P0055oo`03001oogoo00Aoo`03001oogoo029oo`00D7oo2000FGoo
00<007ooOol01Goo00<007ooOol08Goo0019Ool7001QOol00`00Oomoo`06Ool00`00Oomoo`0POol0
045oo`P006Qoo`03001oogoo00Ioo`03001oogoo021oo`00>Goo2000L7oo00<007ooOol01goo00<0
07ooOol07goo000aOol8001hOol00`00Oomoo`08Ool00`00Oomoo`0NOol002Yoo`L0081oo`03001o
ogoo00Qoo`03001oogoo01ioo`008Woo2000Qgoo00<007ooOol02Goo00<007ooOol07Goo000JOol8
002?Ool00`00Oomoo`0:Ool00`00Oomoo`0LOol0019oo`P009Moo`03001oogoo00Yoo`03001oogoo
01aoo`003Woo1000Wgoo00<007ooOol02goo00<007ooOol06goo000>Ool2002QOol00`00Oomoo`0;
Ool00`00Oomoo`0KOol000ioo`04001oo`00002OOol00`00Oomoo`0<Ool00`00Oomoo`0JOol000io
o`05001oogooOol0002NOol00`00Oomoo`0=Ool00`00Oomoo`0IOol000ioo`03001oogoo009oo`03
001oogoo09]oo`03001oogoo00eoo`03001oogoo01Uoo`003Woo00<007ooOol00goo00<007ooOol0
VWoo00<007ooOol03Woo00<007ooOol067oo000>Ool00`00Oomoo`04Ool00`00Oomoo`2IOol00`00
Oomoo`0?Ool00`00Oomoo`0GOol000ioo`03001oogoo00Eoo`8009Yoo`03001oogoo00ioo`03001o
ogoo01Moo`003Woo00<007ooOol01goo00<007ooOol0Ugoo00<007ooOol03goo00<007ooOol05Woo
000>Ool00`00Oomoo`08Ool00`00Oomoo`2FOol00`00Oomoo`0@Ool00`00Oomoo`0EOol000ioo`03
001oogoo00Uoo`03001oogoo09Eoo`03001oogoo011oo`03001oogoo01Eoo`003Woo00<007ooOol0
2Woo0P00UGoo00<007ooOol04Goo00<007ooOol057oo000>Ool00`00Oomoo`0<Ool00`00Oomoo`2B
Ool00`00Oomoo`0BOol00`00Oomoo`0COol000ioo`03001oogoo00eoo`03001oogoo095oo`03001o
ogoo019oo`03001oogoo01=oo`003Woo00<007ooOol03Woo00<007ooOol0T7oo00<007ooOol04goo
00<007ooOol04Woo000>Ool00`00Oomoo`0?Ool2002@Ool00`00Oomoo`0DOol00`00Oomoo`0AOol0
00ioo`03001oogoo015oo`03001oogoo08eoo`03001oogoo01Aoo`03001oogoo015oo`003Woo00<0
07ooOol04Woo00<007ooOol0S7oo00<007ooOol05Goo00<007ooOol047oo000>Ool00`00Oomoo`0C
Ool00`00Oomoo`2;Ool00`00Oomoo`0FOol00`00Oomoo`0?Ool000eoo`03001oogoo01Eoo`03001o
ogoo08Yoo`03001oogoo01Ioo`03001oogoo00moo`003Goo00<007ooOol05Woo0P00RWoo00<007oo
Ool05goo00<007ooOol03Woo000=Ool00`00Oomoo`0HOol00`00Oomoo`27Ool00`00Oomoo`0HOol0
0`00Oomoo`0=Ool000eoo`03001oogoo01Uoo`03001oogoo08Ioo`03001oogoo01Qoo`03001oogoo
00eoo`003Goo00<007ooOol06Woo00<007ooOol0QGoo00<007ooOol05Goo1@003Woo000=Ool00`00
Oomoo`0KOol20025Ool00`00Ool000040008Ool90004Ool00`00Oomoo`0<Ool000eoo`03001oogoo
01eoo`03001oogoo07]oo`T0009Am0/000eoo`03001oogoo00aoo`003Goo00<007ooOol07Woo00<0
07ooOol0LGoo2@001e7d00D0057d0000057d00<001Aoo`03001oogoo00aoo`003Goo00<007ooOol0
7goo00<007ooOol0Igoo2@00457d0P000e7d0P0000=o3000Ool04Woo00<007ooOol037oo000=Ool0
0`00Oomoo`0POol2001MOol:000HDO@20003DO@00`00DO@00002O``00`00Oomoo`0@Ool00`00Oomo
o`0<Ool000eoo`03001oogoo029oo`03001oogoo055oo`T0025Am003001Am00000=Am003001Am000
00=o3003001oogoo00moo`03001oogoo00aoo`003Goo00<007ooOol08goo00<007ooOol0Agoo2@00
:57d0P000U7d00@0057dDO@0009Am005001o37l<O``0000AOol00`00Oomoo`0<Ool000eoo`03001o
ogoo02Aoo`03001oogoo03eoo`T002mAm08000AAm004001Am57d0002DO@00`00O`ao3002O``00`00
Oomoo`0>Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Eoo`03001oogoo03=oo`T000AAm003001A
m57d031Am003001Am57d00AAm003001Am00000=Am003001o37l<00=o3003001oogoo00eoo`03001o
ogoo00aoo`003Goo00<007ooOol09Woo0P00:goo20003E7d00<0057dDO@0;U7d0P001e7d00<0057d
00000e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol037oo000=Ool00`00Oomoo`0XOol0
0`00Oomoo`0OOol9000EDO@00`00DOAAm00/DO@20009DO@20004DO@00`00O`ao3003O``00`00Oomo
o`0=Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Uoo`03001oogoo01Eoo`T001iAm003001Am57d
02]Am003001Am57d00UAm08000AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00aoo`00
3Goo00<007ooOol0:Woo00<007ooOol037oo20009e7d00<0057dDO@0:E7d0P00357d00<0057dDO@0
0e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol037oo000=Ool00`00Oomoo`0[Ool20003
Ool9000_DO@00`00DOAAm00XDO@00`00DOAAm00<DO@00`00DOAAm003DO@00`00O`ao3003O``00`00
Oomoo`0=Ool00`00Oomoo`0<Ool000eoo`03001oogoo02]oo`D003QAm003001Am57d02IAm08000mA
m003001Am57d00=Am003001o37l<00=o3003001oogoo00eoo`03001oogoo00aoo`003Goo00<007oo
Ool0:goo1000>E7d00<0057dDO@0957d0P00457d0P001E7d00<007l<O``00gl<00<007ooOol03Goo
00<007ooOol037oo000=Ool00`00Oomoo`0[Ool20002DO@2000gDO@00`00DOAAm00SDO@00`00DOAA
m00@DO@20005DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0<Ool000eoo`03001oogoo
02]oo`03001Am00000=Am0<003AAm003001Am57d025Am080019Am003001Am00000IAm003001o37l<
009o3003001oogoo00eoo`03001oogoo00aoo`003Goo00<007ooOol0:goo00<0057d00001U7d0P00
<U7d00<0057dDO@07e7d0P00557d00<0057d00001U7d00<007l<O``00Wl<00<007ooOol03Goo00<0
07ooOol037oo000=Ool00`00Oomoo`0[Ool01000DOAAm0001e7d0`00;U7d10007U7d00<0057dDO@0
4e7d00@0057dDO@000IAm003001o37l<009o3003001oogoo00ioo`03001oogoo00]oo`003Goo00<0
07ooOol0:goo00@0057dDO@000YAm08002YAm080009GW`03000V_`0000@001MAm08001IAm004001A
m57d0006DO@00`00O`ao3002O``00`00Oomoo`0>Ool00`00Oomoo`0;Ool000eoo`03001oogoo02]o
o`05001Am57dDO@0000;DO@2000UDO@30005Eil00`009[lV_`039[l5000ADO@00`00DOAAm00EDO@0
1@00DOAAm57d00001U7d00<007l<O``00Wl<00<007ooOol03Woo00<007ooOol02goo000=Ool00`00
Oomoo`0[Ool01@00DOAAm57d00003E7d0`00857d0P002ENO00<002Jo9[l01bJo1@002U7d0P00657d
00D0057dDOAAm00000IAm003001o37l<009o3003001oogoo00ioo`03001oogoo00]oo`003Goo00<0
07ooOol0:goo00<0057dDO@00U7d00<0057dDO@03E7d0P006e7d0`0035NO00<002Jo9[l02bJo1@00
0e7d0P006E7d00<0057dDO@00U7d00<0057dDO@0157d00<007l<O``00Wl<00<007ooOol03Woo00<0
07ooOol02goo000=Ool00`00Oomoo`0[Ool00`00DOAAm002DO@00`00DOAAm00?DO@3000FDO@2000@
Eil00`009[lV_`0?9[l3000KDO@00`00DOAAm002DO@00`00DOAAm004DO@00`00O`ao3002O``00`00
Oomoo`0>Ool00`00Oomoo`0;Ool000eoo`03001oogoo02]oo`03001Am57d00=Am003001Am57d015A
m080015Am0<001=GW`03000V_bJo014V_`03001Am57d01MAm003001Am57d00=Am003001Am57d00AA
m003001o37l<009o3003001oogoo00ioo`03001oogoo00]oo`003Goo00<007ooOol0:goo00<0057d
DO@00e7d00<0057dDO@04e7d0P003E7d0P005eNO00<002Jo9[l04BJo00<0057dDO@05U7d00<0057d
DO@00e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000=Ool0
0`00Oomoo`0[Ool00`00DOAAm004DO@00`00DOAAm00DDO@30007DO@3000JEil4000@9[l2000EDO@0
0`00DOAAm004DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02]oo`03001Am57d00AAm003001Am57d01MAm08000=Am08001YGW`8000Eoo`H0
00/V_`8001AAm003001Am57d00AAm003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03
001oogoo00]oo`003Goo00<007ooOol0:goo00<0057dDO@01E7d00<0057dDO@0657d0`006ENO0`00
3Goo1P001bJo00<0057dDO@04E7d00<0057dDO@0157d00<0057dDO@0157d00<007l<O``00gl<00<0
07ooOol03Goo00<007ooOol02goo000=Ool00`00Oomoo`0[Ool00`00DOAAm005DO@00`00DOAAm00H
DO@00`00Kk/0000FEil300000goo0000000COol600029[l00`00DOAAm00?DO@00`00DOAAm005DO@0
0`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo
02aoo`03001Am57d00IAm003001Am57d01IAm004001_^fnkKk/2000BEil200001Goo00000000DO@0
0P0067oo1000457d00<0057dDO@01E7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo
00<007ooOol02goo000<Ool00`00Oomoo`0/Ool00`00DOAAm006DO@00`00DOAAm00EDO@00`00Kk]_
^`04Kk/00`00EimGW`0<Eil300000goo00000004DO@01000Obl000006Woo00<0057dDO@0357d00<0
057dDO@01U7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000<
Ool00`00Oomoo`0/Ool00`00DOAAm007DO@00`00DOAAm00CDO@00`00Kk]_^`06Kk/00`00EimGW`08
Eil3000017oo000000001U7d00D007l_Obmo;`0001Yoo`8000aAm003001Am57d00IAm003001Am57d
00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0;7oo00<0
057dDO@01e7d00<0057dDO@04U7d00<006nkKk/026nk0P001UNO0P0000Aoo`00000000UAm005001o
;gl_Obl0000KOol2000:DO@00`00DOAAm007DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomo
o`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02aoo`03001Am57d00QAm003001Am57d015Am003
001_^fnk00Y_^`03001GWeNO00H000aAm005001o;gl_Obl0000LOol20009DO@00`00DOAAm007DO@0
0`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo
02aoo`03001Am57d00QAm003001Am57d011Am003001_^fnk00a_^`800003Ool0000000mAm005001o
;gl_Obl0000NOol00`00DOAAm005DO@00`00DOAAm008DO@00`00DOAAm004DO@00`00O`ao3003O``0
0`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02aoo`03001Am57d00UAm003001Am57d
00iAm003001_^fnk00a_^`@0015Am005001o;gl_Obl0000OOol00`00DOAAm004DO@00`00DOAAm009
DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001o
ogoo02aoo`03001Am57d00UAm003001Am57d00eAm003001_^fnk00a_^`8001AAm005001o;gl_Obl0
000POol20003DO@00`00DOAAm00:DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo02]oo`8000aAm003001Am57d00]Am003001_^fnk00a_^`03
001Am57d01AAm005001o;gl_Obl0000QOol01@1c001Am57d0000357d00<0057dDO@00e7d00<007l<
O``00gl<00<007ooOol03Goo00<007ooOol02goo000<Ool00`00Oomoo`0[Ool2000<DO@00`00DOAA
m00:DO@00`00Kk]_^`0<Kk/00`00DOAAm00EDO@01@00Obmo;gl_00008Woo00<0L`0000003E7d00<0
057dDO@00e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000<Ool00`00Oomoo`0[
Ool2000=DO@00`00DOAAm008DO@00`00Kk]_^`0<Kk/00`00DOAAm00FDO@01@00Obmo;gl_00008goo
0P003E7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000<Ool0
0`00Oomoo`0[Ool2000=DO@00`00DOAAm007DO@00`00Kk]_^`0<Kk/00`00DOAAm00GDO@01@00Obmo
;gl_000097oo00<0057dDO@02e7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol03Goo00<0
07ooOol02goo000<Ool00`00Oomoo`0[Ool2000>DO@00`00DOAAm005DO@00`00Kk]_^`0=Kk/00`00
DOAAm00GDO@01@00Obmo;gl_00009Goo00<0057dDO@02U7d00<0057dDO@00e7d00<007l<O``00gl<
00<007ooOol03Goo00<007ooOol02goo000<Ool00`00Oomoo`0[Ool2000>DO@00`00DOAAm004DO@0
0`00Kk]_^`0=Kk/00`00DOAAm00HDO@01@00Obmo;gl_00009Goo00<0057dDO@02U7d00<0057dDO@0
0e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000<Ool00`00Oomoo`0[Ool00`00
DOAAm00>DO@00`00DOAAm003DO@00`00Kk]_^`0<Kk/00`00DOAAm00IDO@01@00Obmo;gl_00009Goo
00<0057dDO@02U7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo
000<Ool00`00Oomoo`0[Ool00`00DOAAm00>DO@00`00DOAAm002DO@00`00Kk]_^`0<Kk/00`00DOAA
m00JDO@01@00Obmo;gl_00009Goo00<0057dDO@02U7d00<0057dDO@00e7d00<007l<O``00gl<00<0
07ooOol03Goo00<007ooOol02goo000<Ool00`00Oomoo`0[Ool00`00DOAAm00?DO@01000DOAAm000
3Vnk00<0057dDO@06e7d00D007l_Obmo;`0002Ioo`03001Am57d00UAm003001Am57d00=Am003001o
37l<00=o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0057dDO@03e7d
00<0057d00003Vnk00<0057dDO@0757d00D007l_Obmo;`0002Ioo`03001Am57d00UAm003001Am57d
00=Am003001o37l<00=o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0
057dDO@0457d00<006nkKk/036nk00<0057dDO@07E7d00D007l_Obmo;`0002Ioo`03001Am57d00UA
m003001Am57d00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007oo
Ool0:goo00<0057dDO@0457d0P0036nk00<0057dDO@07U7d00D007l_Obmo;`0002Moo`03001Am57d
00QAm003001Am57d00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<0
07ooOol0:goo00<0057dDO@03e7d00<007meOgD00P002Fnk0P00857d00D007l_Obmo;`0002Moo`03
001Am57d00QAm003001Am57d00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`00
37oo00<007ooOol0:goo00<0057dDO@03e7d00<007meOgD00Wme00<006nkKk/01Vnk00<0057dDO@0
1E7d00<0057dDO@05e7d00D007l_Obmo;`0002Moo`03001Am57d00QAm003001Am57d00AAm003001o
37l<009o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0057dDO@03e7d
00<007meOgD00gme00<006nkKk/016nk00<0057dDO@01E7d0`00657d00D007l_Obmo;`0002Moo`03
001Am57d00QAm003001Am57d00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`00
37oo00<007ooOol0:goo00<0057dDO@03e7d00<007meOgD017me0P000fnk00<0057dDO@01E7d1@00
5e7d00D007l_Obmo;`0001moo`L0009oo`03001Am57d00MAm003001Am57d00AAm003001o37l<009o
3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0057dDO@03U7d00<007me
OgD01gme00<006nk00002E7d00<0057d00000`005E7d00D007l_Obmo;`00015oo`h000IAm0800003
Ool0057d00QAm003001Am57d00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`00
37oo00<007ooOol0:goo00<0057dDO@03U7d00<007meOgD027me0P00357d1000557d00D007l_Obmo
;`0000=oo`h001AAm004001jQ`000009DO@00`00DOAAm004DO@00`00O`ao3002O``00`00Oomoo`0=
Ool00`00Oomoo`0;Ool000aoo`03001oogoo02]oo`03001Am57d00iAm003001oMGme00QoM@03001A
m57d00eAm0<001=Am0P001MAm08000YAm003001jQ`0000UAm003001Am57d00AAm003001o37l<009o
3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0057dDO@03U7d00<007me
OgD01gme0P00457d0`004U7d00<0057dDO@06e7d00<0057dDO@00P00257d00@007Z7000000QAm003
001Am57d00AAm003001o37l<009o3003001oogoo00ioo`03001oogoo00Yoo`0037oo00<007ooOol0
:goo00<0057dDO@03E7d00<007meOgD027me0P004E7d1000457d00<0057dDO@06E7d0P001E7d0P00
1U7d00@007Z7000000QAm003001Am57d00AAm003001o37l<009o3003001oogoo00ioo`03001oogoo
00Yoo`0037oo00<007ooOol0:goo00<0057dDO@03E7d00<007meOgD027me0P004U7d10003e7d00<0
057dDO@0657d00<0057dDO@01U7d0P001E7d00@007Z7NXL000QAm003001Am57d00AAm003001o37l<
00=o3003001oogoo00eoo`03001oogoo00Yoo`0037oo00<007ooOol0:goo00<0057dDO@03E7d00<0
07meOgD027me00<0057dDO@04e7d0`003U7d00<0057dDO@05e7d00<0057dDO@0257d0P00157d00<0
07Z7NXL00P001e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo
000<Ool00`00Oomoo`0[Ool00`00DOAAm00<DO@00`00OgEoM@08OgD2000FDO@3000=DO@00`00DOAA
m00GDO@00`00DOAAm008DO@00`00KL000003DO@00`00NXMjQ`020007DO@00`00DOAAm004DO@00`00
O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000aoo`03001oogoo02]oo`03001Am57d00aA
m003001oMGme00QoM@8001MAm0<000aAm003001Am57d01IAm003001Am57d00YAm003001]`00000=A
m004001jQ`000007DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:
Ool000aoo`03001oogoo02]oo`03001Am57d00aAm003001oMGme00QoM@8001QAm0@000YAm003001A
m57d01IAm003001Am57d00YAm0800006KL00057dDO@007Z70P001e7d00<0057dDO@0157d00<007l<
O``00gl<00<007ooOol03Goo00<007ooOol02Woo000<Ool00`00Oomoo`0[Ool00`00DOAAm00<DO@0
0`00OgEoM@07OgD2000JDO@40009DO@00`00DOAAm00FDO@00`00DOAAm009DO@03000OkIo]P00KL00
057d001jQ`00Ool000IAm0P000Eo3003001oogoo00eoo`03001oogoo00Yoo`0037oo00<007ooOol0
:goo00<0057dDO@02e7d00<007meOgD027me0P00757d0`00257d00<0057dDO@05e7d00<0057dDO@0
257d00H007nfOkIo]P00KL020002NXL90006DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomo
o`0:Ool000]oo`03001oogoo02aoo`03001Am57d00]Am003001oMGme00QoM@8001eAm0<000MAm003
001Am57d01MAm003001Am57d00MAm003001o]Wnf00=o]P<0009jQ`8000IAm003001Am57d00AAm003
001o37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@0
2e7d00<007meOgD027me0P007U7d10001E7d00<0057dDO@03E7d2`002E7d00<007nfOkH017nf0`00
00=jQ`00DO@01U7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo
000;Ool00`00Oomoo`0/Ool00`00DOAAm00;DO@00`00OgEoM@07OgD2000PDO@40004DO@00`00DOAA
m004DO@C00000e7d001Am005DO@200000e^n001o]P05OkH200000gZ7001Am006DO@00`00DOAAm004
DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02aoo`03001A
m57d00YAm003001oMGme00QoM@80029Am1H000aAm080009Am08000AK_P03001o]Wnf00Ao]P03001j
Q`0000MAm003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo
00<007ooOol0;7oo00<0057dDO@02U7d00<007meOgD027me0P008U7d3@005E7d10001e^n00<007nf
OkH00gnf0`001e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo
000;Ool00`00Oomoo`0/Ool00`00DOAAm00:DO@00`00OgEoM@08OgD2000SDO@20003DO@00`00DOAA
m00HDO@01P00DOAAm0001S`000MK_P04001o]WnfOkH30008DO@00`00DOAAm004DO@00`00O`ao3003
O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02aoo`03001Am57d00YAm003001o
MGme00MoM@8002UAm003001Am57d01QAm003001Am57d00=Am08000IK_P06001o]Wnf001oLP00257d
00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool00`00Oomo
o`0/Ool00`00DOAAm009DO@00`00OgEoM@08OgD2000YDO@00`00DOAAm00GDO@00`00DOAAm003DO@0
1000MmUgf@001U^n0`0000=oLP00DO@01e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol0
3Goo00<007ooOol02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm004DO@6000:OgD2000YDO@00`00
DOAAm00FDO@00`00DOAAm004DO@01000MmT000001e^n0P0000=oLP00DO@01e7d00<0057dDO@0157d
00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool00`00Oomoo`0/Ool70005DO@3
0007OgD00`00Ool0000YDO@00`00DOAAm00FDO@00`00DOAAm003DO@00`00MmUgf@050002Fkh20000
0e7d00000009DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool0
00]oo`03001oogoo02aoo`03001Am57d00UAm004001nZWjZ0006OgD2000ZDO@00`00DOAAm00EDO@0
0`00DOAAm003DO@01000MmUgf@000e7d10000e7d0P002E7d00<0057dDO@0157d00<007l<O``00gl<
00<007ooOol03Goo00<007ooOol02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm00:DO@00`00OZYn
ZP020004OgD2000ZDO@00`00DOAAm00DDO@00`00MmUAm004DO@00`00MmT0000;DO@20009DO@00`00
DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02ao
o`03001Am57d00YAm003001nZWjZ009nZP04001oMGmeOgD2000ZDO@00`00DOAAm00JDO@01000MmUg
f@002U7d00<007mb00002E7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007oo
Ool02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm00:DO@00`00OZYnZP03OZX300000goo001Am00Y
DO@00`00DOAAm00CDO@00`00MmUAm003DO@01000MmUgf@002e7d0P002U7d00<0057dDO@0157d00<0
07l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm00:
DO@00`00OZYnZP05OZX01000Oomoo`00:E7d00<0057dDO@04U7d00<0057dDO@00e7d0P0000=gf@00
DO@02e7d0P002U7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo
000;Ool00`00Oomoo`0/Ool00`00DOAAm00;DO@00`00OZYnZP04OZX01000Oomoo`00:E7d00<0057d
DO@04U7d00<0057dDO@00e7d00@007OI000000aAm08000YAm003001Am57d00AAm003001o37l<00=o
3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@02e7d00<007jZ
OZX01GjZ00<007oo0000:E7d00<0057dDO@04E7d00<007OIDO@00e7d00@007OIMmT000eAm08000YA
m003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007oo
Ool0;7oo00<0057dDO@02e7d00<007jZOZX01GjZ00<007oo0000:E7d00<0057dDO@0457d00<0057d
DO@00e7d00@007OIMmT000iAm003001Am57d00UAm003001Am57d00AAm003001o37l<00=o3003001o
ogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@02e7d00<007jZOZX01GjZ
00@007ooOol002QAm003001Am57d00mAm003001Am00000AAm003001gf@0000iAm08000]Am003001A
m57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo
00<0057dDO@0357d00<007jZOZX017jZ00@007ooOol002QAm003001Am57d00mAm003001Am57d00=A
m004001gfGOI000>DO@2000;DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00
Oomoo`0:Ool000]oo`03001oogoo02aoo`03001Am57d00aAm003001nZWjZ00EnZP03001oo`0002QA
m003001Am57d00iAm003001Am00000=Am004001gfGOI000:DO@7000;DO@00`00DOAAm004DO@00`00
O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02aoo`03001Am57d00aA
m003001nZWjZ00EnZP03001oo`0002QAm003001Am57d00eAm003001Am57d00AAm004001gf@00DO@:
0005>cl00`00DOAAm00:DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomo
o`0:Ool000]oo`03001oogoo02]oo`8000iAm003001nZWjZ00EnZP04001oogoo000WDO@00`00DOAA
m00=DO@00`00DO@00003DO@00`00MmUgf@02000?>cl00`00DOAAm00:DO@00`00DOAAm004DO@00`00
O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02]oo`8000mAm003001n
ZWjZ00EnZP03001oo`0002MAm003001Am57d00=Am0X000EAm004001gfGOI000?>cl3000<DO@00`00
DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02]o
o`8000mAm003001nZWjZ00EnZP03001oo`0002MAm0H000Pk?`03001Am57d00=Am004001gfGOI0006
>cl:0002Ool00`00DOAAm00;DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00
Oomoo`0:Ool000]oo`03001oogoo02]oo`8000mAm003001nZWjZ00EnZP03001oo`0002MAm08000`k
?`03001Am57d00=Am003001gf@0000L000]oo`03001Am57d00aAm003001Am57d00=Am003001o37l<
00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0:goo0P003e7d00<007jZOZX0
1GjZ00@007ooOol002IAm004001o;`000006>cl40005DO@01000MmUgf@004Woo00<0057dDO@0357d
00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool00`00Oomo
o`0[Ool2000@DO@00`00OZYnZP05OZX00`00Ool0000VDO@01000Obmo;gl_1P000Woo00<0057dDO@0
0e7d00@007OIMmT0019oo`04001Am000000<DO@00`00DOAAm003DO@00`00O`ao3004O``00`00Oomo
o`0<Ool00`00Oomoo`0:Ool000]oo`03001oogoo02]oo`03001Am57d00mAm003001nZWjZ00EnZP03
001oo`0002IAm005001o;gl_Obl00007Ool00`00DOAAm003DO@00`00MmT0000BOol00`00DOAAm002
DO@2000:DO@00`00DOAAm003DO@00`00O`ao3004O``00`00Oomoo`0<Ool00`00Oomoo`0:Ool000]o
o`03001oogoo02]oo`03001Am57d00mAm003001nZWjZ00EnZP03001oo`0000iAm003OomAm57d01EA
m005001o;gl_Obl00006Ool00`00DOAAm003DO@01000MmUgf@004Goo00<0057dDO@01E7d0P00257d
00<0057dDO@00e7d00<007l<O``017l<00<007ooOol037oo00<007ooOol02Woo000;Ool00`00Oomo
o`0[Ool00`00DOAAm00?DO@00`00OZYnZP05OZX01000Oomoo`003U7d00=ooe7dDO@0557d00D007l_
Obmo;`0000Eoo`03001Am57d00=Am004001gfGOI000AOol00`00DOAAm008DO@00`00DOAAm005DO@0
0`00DOAAm003DO@00`00O`ao3004O``00`00Oomoo`0=Ool00`00Oomoo`09Ool000]oo`03001oogoo
02]oo`03001Am57d011Am003001nZWjZ00EnZP03001oo`0000mAm003OomAm57d01=Am005001o;gl_
Obl00005Ool00`00DOAAm003DO@00`00MmT0000AOol00`00DOAAm00:DO@20005DO@00`00DOAAm003
DO@00`00O`ao3004O``00`00Oomoo`0=Ool00`00Oomoo`09Ool000]oo`03001oogoo02]oo`03001A
m57d011Am003001nZWjZ00EnZP03001oo`0002EAm005001o;gl_Obl00004Ool00`00DOAAm003DO@0
1000MmUgf@004Goo00<0057dDO@0357d0P000e7d00<0057dDO@00e7d00<007l<O``017l<00<007oo
Ool03Goo00<007ooOol02Goo000;Ool00`00Oomoo`0[Ool00`00DOAAm00@DO@00`00OZYnZP05OZX0
1000Oomoo`00957d00D007l_Obmo;`0000=oo`03001Am57d00=Am004001gfGOI000AOol00`00DOAA
m00?DO@200000e7d001Am004DO@00`00O`ao3004O``00`00Oomoo`0=Ool00`00Oomoo`09Ool000]o
o`03001oogoo02]oo`03001Am57d00iAm0800003DO@0000000InZP04001oogoo000SDO@01@00Obmo
;gl_00000Woo00<0057dDO@0157d00<007OI00004Goo00<0057dDO@04U7d0P001E7d00<007l<O``0
17l<00<007ooOol03Goo00<007ooOol02Goo000;Ool00`00Oomoo`0[Ool00`00DOAAm00=DO@00`00
DOAAm002DO@30004OZX01@00Oomoogoo00008U7d00D007l_Obmo;`00009oo`03001Am57d00=Am004
001gfGOI000@Ool00`00DOAAm00DDO@20004DO@00`00O`ao3004O``00`00Oomoo`0=Ool00`00Oomo
o`09Ool000Yoo`03001oogoo02aoo`03001Am57d00aAm003001Am57d00AAm003001DP00000=nZP03
001oogoo009oo`03001Am57d01mAm007001o;gl_Obl007oo00001E7d00@007OIMmT0011oo`03001A
m57d01EAm004001Am0000002DO@00`00O`ao3004O``00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yo
o`03001oogoo02aoo`03001Am57d00YAm08000QAm006001DP000001nZP001Goo00D0057dDOAAm7oo
00eAm0d0009Am004001o;gl_Obl20005DO@01000MmUgf@0047oo00<0057dDO@05U7d00@0057dDOAA
m0<000Io3003001oogoo00eoo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00<0057dDO@02E7d
00<0057dDO@02E7d00<005B0E8000`001Goo00<0057dDO@00U7d00=ooe7dDO@0157d1@000Sed00<0
05heGSD025he3P000WOI47oo00<0057dDO@05e7d00<0057dDO@00e7d00<007l<O``017l<00<007oo
Ool03Goo00<007ooOol02Goo000:Ool00`00Oomoo`0/Ool00`00DOAAm008DO@00`00DOAAm00;DO@0
1@00E81DP5B000001Woo00<0057dDO@00e7d1@001ced00<005heGSD04ehe00<007KCM]<010003Goo
00<0057dDO@0657d00<0057dDO@00e7d0P001Gl<00<007ooOol03Goo00<007ooOol02Goo000:Ool0
0`00Oomoo`0/Ool00`00DOAAm006DO@2000?DO@01@00E81DP5B000001Woo1@0033ed00<005heGSD0
4ehe00<007KCM]<017KC100027oo00<0057dDO@06E7d00<0057dDO@00U7d00@007neOkD000Ao3003
001oogoo00eoo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00<0057dDO@01E7d00<0057dDO@0
457d00D005B0E81DP00000Ioo`8000hmM003001N=Ehe01=N=@03001fdgKC00Qfd`<000Aoo`03001A
m57d01YAm003001Am57d009Am004001o]GneOkD20002O``00`00Oomoo`0=Ool00`00Oomoo`09Ool0
00Yoo`03001oogoo02aoo`03001Am57d00AAm003001Am57d019Am080009DP003001oogoo00=oo`<0
00dmM003001N=Ehe01=N=@03001fdgKC00Yfd`03001oogoo009oo`03001Am57d01YAm003001Am57d
009Am003001o]Gne00=o]@03001o300000moo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00<0
057dDO@00U7d0P005e7d00@005B0E80000Aoo`D000/mM003001N=Ehe01=N=@03001fdgKC00Yfd`05
001oogooOol0000MDO@01@00DOAAm57d00001gne0P003goo00<007ooOol02Goo000:Ool00`00Oomo
o`0/Ool01@00DOAAm57d00006U7d00@005B0E80000=oo`H000XmM003001N=Ehe01=N=@03001fdgKC
00Yfd`04001oogoo000NDO@01@00DOAAm57d000027ne00<007ooOol03Goo00<007ooOol02Goo000:
Ool00`00Oomoo`0/Ool01000DOAAm000757d00@005B0E800009oo`80008mM0@000PmM003001N=Ehe
01=N=@03001fdgKC00Yfd`03001oo`0001mAm005001Am57dDO@00008OkD00`00Oomoo`0=Ool00`00
Oomoo`09Ool000Yoo`03001oogoo02aoo`<001iAm007001DP5B0001oo`0300000ced1@001Sed00<0
05heGSD04ehe00<007KCM]<02WKC0P00857d00@0057dDO@000Qo]@03001oogoo00ioo`03001oogoo
00Uoo`002Woo00<007ooOol0;7oo00<0057dDO@07e7d00H005B0E80000030005?G@50004?G@00`00
GSEN=@0CGSD00`00M]=fd`0:M]<00`00DOAAm00ODO@01000DOAAm00027ne00<007ooOol03Woo00<0
07ooOol02Goo000:Ool00`00Oomoo`0/Ool00`00DOAAm00PDO@01@00E81DP00300001ced10000ced
00<005heGSD04ehe00<007KCM]<02WKC0P00857d00<0057d000027ne00<007ooOol03goo00<007oo
Ool02Goo000:Ool00`00Oomoo`0]Ool00`00DOAAm00PDO@01000E8000`002Ced100000<mM000GSD0
55he00<007KCM]<02WKC0P00857d00<0057d000027ne00<007ooOol03goo00<007ooOol02Goo000:
Ool00`00Oomoo`0]Ool00`00DOAAm00QDO@00`0000<0000:?G@5000EGSD00`00M]=fd`0:M]<00`00
DO@0000ODO@00`00DO@00007OkD00`00Oomoo`0@Ool00`00Oomoo`09Ool000Yoo`03001oogoo02io
o`03001Am57d025Am08000`mM0@001AN=@03001fdgKC00Yfd`04001Am57d000NDO@20008OkD00`00
Oomoo`0@Ool00`00Oomoo`09Ool000Yoo`03001oogoo02ioo`03001Am57d021Am0<000hmM003001N
=Ehe01=N=@03001fdgKC00Yfd`04001Am57d000NDO@20008OkD00`00Oomoo`0@Ool00`00Oomoo`09
Ool000Yoo`03001oogoo02ioo`03001Am57d021Am0<000hmM003001N=Ehe01=N=@03001fdgKC00Yf
d`05001Am57dDO@0000MDO@20007OkD00`00Oomoo`0AOol00`00Oomoo`09Ool000Yoo`03001oogoo
02moo`03001Am57d01iAm004001Am000000>?G@00`00GSEN=@0CGSD00`00M]=fd`0:M]<00`00DOAA
m002DO@00`00DOAAm00JDO@00`00OkEo]@06OkD00`00Oomoo`0AOol00`00Oomoo`09Ool000Yoo`03
001oogoo02moo`03001Am57d01iAm004001Am000000>?G@00`00GSEN=@0CGSD00`00M]=fd`0:M]<0
0`00DOAAm003DO@00`00DOAAm00IDO@00`00OkEo]@05OkD00`00Oomoo`0BOol00`00Oomoo`09Ool0
00Yoo`03001oogoo02moo`03001Am57d01eAm003001Am57d008000hmM003001N=Ehe01=N=@03001f
dgKC00Yfd`03001Am57d00=Am003001Am57d01UAm003001o]Gne00Eo]@03001oogoo019oo`03001o
ogoo00Uoo`002Woo00<007ooOol0;goo0P007E7d00@0057dDOAAm08000hmM003001N=Ehe01=N=@03
001fdgKC00Yfd`03001Am57d00AAm003001Am57d01MAm08000Mo]@03001oogoo019oo`03001oogoo
00Uoo`002Woo00<007ooOol0;goo0P007E7d00@0057dDOAAm08000hmM003001N=Ehe01=N=@03001f
dgKC00Yfd`03001Am57d00EAm003001Am57d01EAm0<000Io]@03001oogoo01=oo`03001oogoo00Uo
o`002Woo00<007ooOol0;goo00<007oo00006e7d00<0057dDO@00U7d0P003Sed00<005heGSD04ehe
00<007KCM]<02WKC00<0057dDO@01E7d00<0057dDO@04e7d0P000UON00<007neOkD017ne00<007oo
Ool04goo00<007ooOol02Goo000:Ool00`00Oomoo`0_Ool00`00Ool0000JDO@00`00DOAAm003DO@2
000>?G@00`00GSEN=@0CGSD00`00M]=fd`0:M]<00`00DOAAm006DO@00`00DOAAm00@DO@20004Emh2
0004OkD00`00Oomoo`0DOol00`00Oomoo`09Ool000Yoo`03001oogoo02moo`03001oo`0001YAm003
001Am57d00=Am003000mM3ed00dmM003001N=Ehe01=N=@03001fdgKC00Yfd`03001Am57d00MAm003
001Am57d00eAm08000IGgP04001GgP000002OkD00`00Oomoo`0DOol00`00Oomoo`09Ool000Yoo`03
001oogoo02moo`04001oogoo000HDO@00`00DOAAm004DO@00`00?G@mM00=?G@00`00GSEN=@0CGSD0
0`00M]=fd`0:M]<00`00DOAAm007DO@00`00DOAAm00;DO@20008Emh01000EmiGgUON0P005goo00<0
07ooOol02Goo000:Ool00`00Oomoo`0_Ool01000Oomoo`00657d00<0057dDO@0157d00<003ed?G@0
3Ced00<005heGSD04ehe00<007KCM]<02WKC00<0057dDO@0257d00<0057dDO@0257d0P002UON00<0
05ONEmh00UON00<007ooOol05Goo00<007ooOol02Goo000:Ool00`00Oomoo`0_Ool01@00Oomoogoo
00005U7d00<0057dDO@01E7d00<003ed?G@03Ced00<005heGSD04ehe00<007KCM]<02WKC00<0057d
DO@02E7d00<0057dDO@01E7d0P0035ON00<005ONEmh00P0067oo00<007ooOol02Goo000:Ool00`00
Oomoo`0_Ool01000Oomoogoo0P00557d00<0057dDO@01U7d00<003ed?G@03Ced00<005heGSD04ehe
00<007KCM]<02WKC00<0057dDO@02U7d00<0057dDO@00U7d0P003UON0`006Woo00<007ooOol02Goo
000:Ool00`00Oomoo`0_Ool00`00Oomoo`02Ool3000BDO@00`00DOAAm006DO@00`00?G@mM00=?G@0
0`00GSEN=@0CGSD00`00M]=fd`0:M]<00`00DOAAm00:DO@00`00DOAAm002000?Emh2000LOol00`00
Oomoo`09Ool000Yoo`03001oogoo02moo`03001oogoo00Aoo`@000iAm003001Am57d00MAm003000m
M3ed00dmM003001N=Ehe01=N=@03001fdgKC00Yfd`03001Am57d00]Am08000mGgP800003Ool007oo
01]oo`03001oogoo00Uoo`002Woo00<007ooOol0;goo00<007ooOol01Woo10002e7d00<0057dDO@0
257d00<003ed?G@03Ced00<005heGSD04ehe00<007KCM]<02WKC00<0057dDO@02e7d0`0035ON0P00
0goo00<007ooOol06Woo00<007ooOol02Goo000:Ool00`00Oomoo`0_Ool00`00Oomoo`08Ool50008
DO@00`00DOAAm008DO@00`00?G@mM00=?G@00`00GSEN=@0CGSD00`00M]=fd`0:M]<00`00DOAAm00;
DO@01000Obeo;@002EON0P001Goo00<007ooOol06Woo00<007ooOol02Goo000:Ool00`00Oomoo`0_
Ool00`00Oomoo`0:Ool60004DO@00`00DOAAm009DO@00`00?G@mM00=?G@00`00GSEN=@0CGSD00`00
M]=fd`0:M]<00`00DOAAm00;DO@01@00Obeo;Gl]00001UON0P001goo00<007ooOol06goo00<007oo
Ool027oo000:Ool00`00Oomoo`0_Ool00`00Oomoo`0=Ool50002DO@00`00DOAAm009DO@00`00?G@m
M00=?G@00`00GSEN=@0CGSD00`00M]=fd`0:M]<00`00DOAAm00;DO@00`00Obeo;@02Obd20002Emh2
0009Ool00`00Oomoo`0KOol00`00Oomoo`08Ool000Yoo`03001oogoo02moo`03001oogoo011oo`@0
00aAm003000mM3ed00dmM003001N=Ehe01=N=@03001fdgKC00Yfd`03001Am57d00]Am003001o;Gl]
00Ao;@8000]oo`03001oogoo01]oo`03001oogoo00Qoo`002Goo00<007ooOol0<7oo00<007ooOol0
4goo00<0057dDO@02U7d00<003ed?G@03Ced00<005heGSD04ehe00<007KCM]<02WKC00<0057dDO@0
2e7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007ooOol027oo0009Ool00`00
Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00?G@mM00=?G@00`00GSEN=@0CGSD00`00
M]=fd`0:M]<00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00
Oomoo`08Ool000Uoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003000mM3ed00dm
M003001N=Ehe01=N=@03001fdgKC00Yfd`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yo
o`03001oogoo01]oo`03001oogoo00Qoo`002Goo00<007ooOol0<7oo00<007ooOol04goo00<0057d
DO@02U7d00<003ed?G@03Ced00<005heGSD04ehe00<007KCM]<02WKC00<0057dDO@02e7d00<007l]
Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007ooOol027oo0009Ool00`00Oomoo`0`Ool0
0`00Oomoo`0COol00`00DOAAm00:DO@00`00?G@mM00=?G@00`00GSEN=@0CGSD00`00M]=fd`0:M]<0
0`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`08Ool0
00Uoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003000mM3ed00dmM003001N=Ehe
01=N=@03001fdgKC00Yfd`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo
01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d00<0
03ed?G@02Sed70002gKC3E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007oo
Ool027oo0009Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00?G@mM002?G@8
000;:ch2000?:ch40007M]<=DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00
Oomoo`08Ool000Uoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm0D002P[?PD0009f
d`eAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<0
07ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d00<002/n:ch0;b/n0`00357d00<007l]Obd0
17l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0`Ool00`00
Oomoo`0COol00`00DOAAm009DO@00`00:ch[?P0F:ch2000I:ch00`00DOAAm00;DO@00`00Obeo;@04
Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo031oo`03001o
ogoo01=oo`03001Am57d00UAm003000[?R/n01H[?P<001L[?P8000eAm003001o;Gl]00Ao;@03001o
ogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0<7oo00<007ooOol04goo
00<0057dDO@02E7d00<002/n:ch05R/n0P005b/n00<007oo00003E7d00<007l]Obd017l]00<007oo
Ool02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0`Ool00`00Oomoo`0COol0
0`00DOAAm00:DO@00`00Oc1o<007000>:ch2000<:ch80005Ool00`00DOAAm00;DO@00`00Obeo;@04
Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo02moo`03001o
ogoo01Aoo`03001Am57d00YAm003001o<7l`00Eo<003001oo`0001/000eoo`03001Am57d00]Am003
001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0
;goo00<007ooOol057oo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol03Goo0P006Goo00<0
057dDO@02e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009
Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`0=
Ool2000IOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00
Oomoo`08Ool000Uoo`03001oogoo02moo`03001oogoo01Aoo`03001Am57d00YAm003001o<7l`00Eo
<003001oogoo00eoo`8001Uoo`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00]oo`03001o
ogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@02U7d
00<007l`Oc001Gl`00<007ooOol03Goo0P006Goo00<0057dDO@02e7d00<007l]Obd017l]00<007oo
Ool02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol0
0`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`0=Ool2000IOol00`00DOAAm00;DO@00`00Obeo
;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo02moo`03
001oogoo01Aoo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00eoo`8001Yoo`03001Am57d
00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<0
07ooOol0;goo00<007ooOol057oo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol03Goo0P00
6Woo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol0
27oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00
Oomoo`0=Ool2000JOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0J
Ool00`00Oomoo`08Ool000Uoo`03001oogoo02moo`03001oogoo01Aoo`03001Am57d00UAm003001o
<7l`00Io<003001oogoo00eoo`8001Yoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]o
o`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo00<0057d
DO@02E7d00<007l`Oc001Wl`00<007ooOol03Goo0P006Woo00<0057dDO@02U7d00<007l]Obd017l]
00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomo
o`0DOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0=Ool2000JOol00`00DOAAm00:DO@0
0`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo
02moo`03001oogoo01Aoo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00eoo`8001Yoo`03
001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`00
2Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol0
3Goo0P006Woo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<0
07ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm009DO@00`00Oc1o<006
Oc000`00Oomoo`0=Ool2000JOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00
Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo02moo`03001oogoo01Aoo`03001Am57d00UA
m003001o<7l`00Io<003001oogoo00eoo`8001Yoo`03001Am57d00YAm003001o;Gl]00Ao;@03001o
ogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo
00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol03Goo0P006Woo00<0057dDO@02U7d00<007l]
Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool0
0`00Oomoo`0DOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0=Ool2000JOol00`00DOAA
m00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03
001oogoo02moo`03001oogoo01Aoo`03001Am57d00UAm003001o<7l`00Io<003001oogoo00eoo`80
01Yoo`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo
00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@02E7d00<007l`Oc001Wl`00<0
07ooOol03Goo0P006Woo00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol0
6Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm009DO@00`00
Oc1o<006Oc000`00Oomoo`0=Ool2000JOol00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;
Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo02moo`03001oogoo01Aoo`03001A
m57d00UAm003001o<7l`00Io<003001oogoo00eoo`8001Yoo`03001Am57d00YAm003001o;Gl]00Ao
;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`0027oo00<007ooOol0<7oo00<007oo
Ool057oo00<0057dDO@02E7d00<007l`Oc001Wl`00<007ooOol03Goo0P006Woo00<0057dDO@02U7d
00<007l]Obd017l]00<007ooOol02goo00<007ooOol06goo00<007ooOol01goo0008Ool00`00Oomo
o`0`Ool00`00Oomoo`0DOol00`00DOAAm009DO@00`00Oc1o<006Oc000`00Oomoo`0=Ool2000JOol0
0`00DOAAm00;DO@00`00Obeo;@03Obd00`00Oomoo`0;Ool00`00Oomoo`0KOol00`00Oomoo`07Ool0
00Qoo`03001oogoo031oo`03001oogoo01Aoo`03001Am57d00UAm003001o<7l`00Io<003001oogoo
00eoo`8001Yoo`03001Am57d00]Am003001o;Gl]00=o;@03001oogoo00]oo`03001oogoo01]oo`03
001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol057oo00<0057dDO@02E7d00<007l`Oc00
1Wl`00<007ooOol03Goo0P006Woo00<0057dDO@02e7d00<007l]Obd00gl]00<007ooOol02goo00<0
07ooOol06goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:
DO@00`00Oc1o<006Oc000`00Oomoo`0=Ool2000JOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00
Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01=o
o`03001Am57d00YAm003001o<7l`00Io<003001oogoo00eoo`8001Yoo`03001Am57d00]Am003001o
;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo
00<007ooOol04goo00<0057dDO@02U7d00<007l`Oc001Wl`00<007ooOol03Goo0P006Woo00<0057d
DO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007ooOol01goo0008Ool0
0`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<006Oc000`00Oomoo`0=Ool2
000JOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomo
o`07Ool000Qoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003001o<7l`00Io<003
001oogoo00eoo`8001Yoo`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo
01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d00<0
07l`Oc001Wl`00<007ooOol03Goo0P006Woo00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol0
2Woo00<007ooOol06goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00
DOAAm00:DO@00`00Oc1o<006Oc000`00Oomoo`0=Ool2000JOol00`00DOAAm00;DO@00`00Obeo;@04
Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001o
ogoo01=oo`03001Am57d00YAm003001o<7l`00Io<003001oogoo00eoo`8001Yoo`03001Am57d00]A
m003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01]oo`03001oogoo00Moo`0027oo00<007oo
Ool0<7oo00<007ooOol04goo00<0057dDO@02U7d00<007l`Oc001Wl`00<007ooOol03Goo0P006Woo
00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007ooOol01goo
0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<006Oc000`00Oomo
o`0=Ool2000JOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol0
0`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003001o<7l`
00Io<003001oogoo00eoo`8001Yoo`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03
001oogoo01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@0
2U7d00<007l`Oc001Wl`00<007ooOol03Goo0P006Woo00<0057dDO@02e7d00<007l]Obd017l]00<0
07ooOol02Woo00<007ooOol06goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0C
Ool00`00DOAAm00:DO@00`00Oc1o<006Oc000`00Oomoo`0=Ool3000IOol00`00DOAAm00;DO@00`00
Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031o
o`03001oogoo01=oo`03001Am57d00YAm003001o<7l`00Io<003001oogoo00ioo`03001oogoo01Qo
o`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01]oo`03001oogoo00Mo
o`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d00<007l`Oc001Wl`00<007oo
Ool0:Goo00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007oo
Ool01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<006Oc00
0`00Oomoo`0YOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol0
0`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003001o<7l`
00Io<003001oogoo02Uoo`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo
01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d00<0
07l`Oc001Wl`00<007ooOol0:Goo00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<0
07ooOol06goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:
DO@00`00Oc1o<006Oc000`00Oomoo`0YOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:
Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01=oo`03001A
m57d00YAm003001o<7l`00Io<003001oogoo02Uoo`03001Am57d00]Am003001o;Gl]00Ao;@03001o
ogoo00]oo`03001oogoo01Yoo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo
00<0057dDO@02U7d00<007l`Oc001Wl`00<007ooOol0:Goo00<0057dDO@02e7d00<007l]Obd017l]
00<007ooOol02goo00<007ooOol06Woo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomo
o`0COol00`00DOAAm00:DO@00`00Oc1o<006Oc000`00Oomoo`0YOol00`00DOAAm00;DO@00`00Obeo
;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03
001oogoo01=oo`03001Am57d00YAm003001o<7l`00Io<003001oogoo02Uoo`03001Am57d00]Am003
001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Moo`0027oo00<007ooOol0
<7oo00<007ooOol04goo00<0057dDO@02U7d00<007l`Oc001Wl`00<007ooOol0:Goo00<0057dDO@0
2e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol01goo0008Ool00`00
Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<006Oc000`00Oomoo`0LOol>000=
DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Qoo`03001o
ogoo031oo`03001oogoo01=oo`03001Am57d00YAm003001o<7l`00Io<003001oogoo009ooaX000iA
m003001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Mo
o`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d3P00:E7d00<0057dDO@02E7d
00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol01goo0008Ool00`00Oomo
o`0`Ool00`00Oomoo`0COol00`00DOAAm009DO@00`00DOAAm00fDO@00`00DOAAm008DO@00`00Obeo
;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03
001oogoo01=oo`03001Am57d00QAm003001Am57d03QAm003001Am57d00MAm003001o;Gl]00Ao;@03
001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol0
4goo00<0057dDO@01e7d00<0057dDO@0>U7d00<0057dDO@01U7d00<007l]Obd017l]00<007ooOol0
2goo00<007ooOol06Woo00<007ooOol01goo0008Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00
DOAAm006DO@00`00DOAAm00lDO@00`00DOAAm005DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00
Oomoo`0JOol00`00Oomoo`07Ool000Qoo`03001oogoo02moo`03001oogoo01Aoo`03001Am57d00EA
m003001Am57d03iAm003001Am57d00AAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yo
o`03001oogoo00Moo`001goo00<007ooOol0<7oo00<007ooOol057oo00<0057dDO@0157d00<0057d
DO@0@57d00<0057dDO@00e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007oo
Ool01goo0007Ool00`00Oomoo`0`Ool00`00Oomoo`0DOol00`00DOAAm003DO@00`00DOAAm012DO@0
0`00DOAAm002DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool0
00Moo`03001oogoo031oo`03001oogoo01Aoo`03001Am57d00=Am003001Am57d04=Am005001Am57d
DO@00006Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Moo`03001oogoo031o
o`03001oogoo01Aoo`03001Am57d009Am003001Am57d04EAm004001Am57d0006Obd00`00Oomoo`0;
Ool00`00Oomoo`0KOol00`00Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo01Aoo`05001A
m57dDO@00019DO@00`00DO@00006Obd00`00Oomoo`0;Ool00`00Oomoo`0KOol00`00Oomoo`06Ool0
00Moo`03001oogoo031oo`03001oogoo01Aoo`04001Am57d001;DO@20006Obd00`00Oomoo`0;Ool0
0`00Oomoo`0KOol00`00Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo01Aoo`03001Am000
03YAm1D000Eo;@03001oogoo00]oo`03001oogoo01]oo`03001oogoo00Ioo`001goo00<007ooOol0
<7oo00<007ooOol057oo0P004e7d:0005AKK100000=o;@00Ool037oo00<007ooOol06goo00<007oo
Ool01Woo0007Ool00`00Oomoo`0`Ool00`00Oomoo`0DOolE00115]/2000=Ool00`00Oomoo`0KOol0
0`00Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo01Moo`D001HFfbH0025oo`03001oogoo
01]oo`03001oogoo00Ioo`001goo00<007ooOol0<7oo00<007ooOol077oo5P00Agoo00<007ooOol0
6goo00<007ooOol01Woo0007Ool00`00Oomoo`0`Ool00`00Oomoo`1iOol00`00Oomoo`0KOol00`00
Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo07Uoo`03001oogoo01]oo`03001oogoo00Io
o`001goo00<007ooOol0<7oo00<007ooOol0NGoo00<007ooOol06goo00<007ooOol01Woo0007Ool0
0`00Oomoo`0`Ool00`00Oomoo`1TOolG000LOol00`00Oomoo`06Ool000Moo`03001oogoo031oo`03
001oogoo03Qoob`001Moo`@001Qoo`03001oogoo00Ioo`001goo00<007ooOol0<7oo00<007ooOol0
37oo;000Agoo100057oo00<007ooOol01Woo0007Ool00`00Oomoo`0COol/001gOol4000@Ool00`00
Oomoo`06Ool000MooaH001eoo`03001oogoo08Moo`<000eoo`03001oogoo00Ioo`002goo1`00:7oo
00<007ooOol0RWoo10002Goo00<007ooOol01Woo000BOol8000POol00`00Oomoo`2>Ool40005Ool0
0`00Oomoo`06Ool001Yoo`L001Uoo`03001oogoo099oo`@00003Ool007oo00Moo`008Goo1`004Woo
00<007ooOol0OWoo6P0027oo000XOol8000:Ool00`00Oomoo`1;Oolc000ROol0031oo`L000=oo`03
001oogoo01Mooc@005Eoo`00=goo7@00RGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003M
Ool00=eoo`00\
\>"],
  ImageRangeCache->{{{0, 220}, {299, 0}} -> {0.122254, -0.0271372, 0.00330748,
   0.00330748}}]
}, Open  ]],

Cell[TextData[{
  "Not a very interesting solution! The solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 is for the local coordinate system of each body to be aligned with \
the global coordinate system. This is because the model was defined such as \
to have this \"perfect\" assembled configuration. The piston is defined such \
that its local origin lies at a point that is outside of the piston body. \
This point is coincident with the global origin when ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0. Note the 3-4-5 triangle formed by the crankshaft, piston, and \
connecting rod when ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.\n\nAdvancing ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " results in a more interesting solution."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This seeks a solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2 pi/10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(crankangle = 2  \[Pi]\ 0.1; \nSolveMech[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] 3.3528693881054461`*^-25, 
      Y2 \[Rule] 1.93449032478554414`*^-25, Z2 \[Rule] 0.`, 
      Eo2 \[Rule] 0.951056516295153464`, Ei2 \[Rule] 0.`, Ej2 \[Rule] 0.`, 
      Ek2 \[Rule] 0.309016994374947406`, X3 \[Rule] 0.`, 
      Y3 \[Rule] 2.13478841966804555`, Z3 \[Rule] 0.`, Eo3 \[Rule] 1.`, 
      Ei3 \[Rule] 0.`, Ej3 \[Rule] 0.`, Ek3 \[Rule] 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Now two of the Euler parameters of the crankshaft ",
  StyleBox["Eo2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Ek2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " have changed, and the vertical coordinate of the piston ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has increased to 2.13. All of the other coordinates have not changed, and \
never will, because of the specific function of this particular mechanism \
model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This seeks a solution at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 3 2 pi/10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(crankangle = 2\ \[Pi]\ 0.3; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] 9.89195870030694379`*^-22, 
      Y2 \[Rule] \(-4.39833262721645823`*^-21\), Z2 \[Rule] 0.`, 
      Eo2 \[Rule] 0.587785252292403992`, Ei2 \[Rule] 0.`, Ej2 \[Rule] 0.`, 
      Ek2 \[Rule] 0.809016994375384079`, X3 \[Rule] 0.`, 
      Y3 \[Rule] 3.7664756125549319`, Z3 \[Rule] 0.`, Eo3 \[Rule] 1.`, 
      Ei3 \[Rule] 0.`, Ej3 \[Rule] 0.`, Ek3 \[Rule] 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a graphic of the model at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 6 pi/10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!   
%%Creator: Mathematica   
%%AspectRatio: 1.35323    
MathPictureStart   
%% Graphics3D   
/Courier findfont 10  scalefont  setfont   
% Scaling calculations   
-0.16802 1.37431 0.0343577 1.37431 [   
[ 0 0 0 0 ]   
[ 1 1.35323 0 0 ]   
] MathScale   
% Start of Graphics   
1 setlinecap   
1 setlinejoin   
newpath   
[ ] 0 setdash   
0 g   
0 0 m   
1 0 L   
1 1.35323 L   
0 1.35323 L   
closepath   
clip   
newpath   
p   
.002 w   
.28194 .30732 m   
.06691 .13043 L   
s   
.06691 .13043 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
.26714 1.31887 m   
.28194 .30732 L   
s   
.93788 .23453 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.28194 .30732 m   
.06691 .13043 L   
s   
.06691 .13043 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.93788 .23453 m   
.28194 .30732 L   
s   
.26714 1.31887 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
P   
p   
.002 w   
.30689 .78334 m .31255 .33798 L .26949 .30272 L p   
.988 .782 .537 r   
F P   
s   
P   
p   
.002 w   
.31255 .33798 m .86808 .27803 L .83999 .2391 L p   
.538 .814 .997 r   
F P   
s   
P   
p   
.002 w   
.83999 .2391 m .26949 .30272 L .31255 .33798 L p   
.538 .814 .997 r   
F P   
s   
P   
p   
.002 w   
.47334 .40539 m .39314 .49448 L .35171 .46326 L p   
.869 .917 .858 r   
F P   
s   
P   
p   
.002 w   
.39314 .49448 m .3631 .60901 L .32059 .5811 L p   
.973 .858 .667 r   
F P   
s   
P   
p   
.002 w   
.32059 .5811 m .35171 .46326 L .39314 .49448 L p   
.973 .858 .667 r   
F P   
s   
P   
p   
.002 w   
.58376 .36434 m .47334 .40539 L .43422 .37143 L p   
.678 .883 .974 r   
F P   
s   
P   
p   
.002 w   
.35171 .46326 m .43422 .37143 L .47334 .40539 L p   
.869 .917 .858 r   
F P   
s   
P   
p   
.002 w   
.54341 .40062 m .45446 .45522 L .43489 .43921 L p   
.767 .912 .937 r   
F P   
s   
P   
p   
.002 w   
.45446 .45522 m .40012 .54511 L .37973 .53043 L p   
.921 .907 .792 r   
F P   
s   
P   
p   
.002 w   
.37973 .53043 m .43489 .43921 L .45446 .45522 L p   
.921 .907 .792 r   
F P   
s   
P   
p   
.002 w   
.40012 .54511 m .51525 .57348 L .49633 .55903 L p   
.14 .604 .925 r   
F P   
s   
P   
p   
.002 w   
.49633 .55903 m .37973 .53043 L .40012 .54511 L p   
.14 .604 .925 r   
F P   
s   
P   
p   
.002 w   
.3631 .60901 m .39141 .72022 L .34934 .69542 L p   
.972 .659 .331 r   
F P   
s   
P   
p   
.002 w   
.34934 .69542 m .32059 .5811 L .3631 .60901 L p   
.972 .659 .331 r   
F P   
s   
P   
p   
.002 w   
.64463 .39582 m .54341 .40062 L .52506 .38371 L p   
.48 .795 .999 r   
F P   
s   
P   
p   
.002 w   
.43489 .43921 m .52506 .38371 L .54341 .40062 L p   
.767 .912 .937 r   
F P   
s   
P   
p   
.002 w   
.33872 .86181 m .30689 .78334 L .26244 .76055 L p   
.942 .575 .24 r   
F P   
s   
P   
p   
.002 w   
.26949 .30272 m .26244 .76055 L .30689 .78334 L p   
.988 .782 .537 r   
F P   
s   
P   
p   
.002 w   
.69662 .38297 m .58376 .36434 L .54767 .32886 L p   
.305 .686 .977 r   
F P   
s   
P   
p   
.002 w   
.43422 .37143 m .54767 .32886 L .58376 .36434 L p   
.678 .883 .974 r   
F P   
s   
P   
p   
.002 w   
.26949 .30272 m .54757 .27171 L .54767 .32886 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .43422 .37143 L .26949 .30272 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.43422 .37143 m .35171 .46326 L .26949 .30272 L closepath p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.26513 .58587 m .26949 .30272 L .35171 .46326 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.39141 .72022 m .47223 .79908 L .43211 .77639 L p   
.663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.43211 .77639 m .34934 .69542 L .39141 .72022 L p   
.663 .133 0 r   
F P   
s   
P   
p   
.002 w   
.51525 .57348 m .45892 .75504 L .43904 .74325 L p   
.974 .881 .678 r   
F P   
s   
P   
p   
.002 w   
.43904 .74325 m .49633 .55903 L .51525 .57348 L p   
.974 .881 .678 r   
F P   
s   
P   
p   
.002 w   
.26244 .76055 m .29488 .84123 L .33872 .86181 L p   
.942 .575 .24 r   
F P   
s   
P   
p   
.002 w   
.41591 .89217 m .33872 .86181 L .29488 .84123 L p   
0 .365 .711 r   
F P   
s   
P   
p   
.002 w   
.73176 .44336 m .64463 .39582 L .62763 .37868 L p   
0 .384 .813 r   
F P   
s   
P   
p   
.002 w   
.52506 .38371 m .62763 .37868 L .64463 .39582 L p   
.48 .795 .999 r   
F P   
s   
P   
p   
.002 w   
.37973 .53043 m .43489 .43921 L .52506 .38371 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.76545 .51651 m .76142 .62407 L .37973 .53043 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.62763 .37868 m .71589 .42675 L .73176 .44336 L p   
0 .384 .813 r   
F P   
s   
P   
p   
.002 w   
.71589 .42675 m .76545 .51651 L p   
.37973 .53043 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.62763 .37868 m .71589 .42675 L p   
.37973 .53043 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.52506 .38371 m .62763 .37868 L p   
.37973 .53043 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.78191 .45826 m .69662 .38297 L .66354 .34763 L p   
0 .108 .604 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .66354 .34763 L .69662 .38297 L p   
.305 .686 .977 r   
F P   
s   
P   
p   
.002 w   
.45892 .75504 m .52394 .78778 L .50489 .77639 L p   
0 .296 .686 r   
F P   
s   
P   
p   
.002 w   
.50489 .77639 m .43904 .74325 L .45892 .75504 L p   
0 .296 .686 r   
F P   
s   
P   
p   
.002 w   
.47223 .79908 m .47114 1.1883 L .43002 1.17733 L p   
.996 .786 .504 r   
F P   
s   
P   
p   
.002 w   
.43002 1.17733 m .43211 .77639 L .47223 .79908 L p   
.996 .786 .504 r   
F P   
s   
P   
p   
.002 w   
.29488 .84123 m .37404 .87233 L .41591 .89217 L p   
0 .365 .711 r   
F P   
s   
P   
p   
.002 w   
.4137 1.25092 m .41591 .89217 L .37404 .87233 L p   
.994 .785 .516 r   
F P   
s   
P   
p   
.002 w   
.78073 .53193 m .73176 .44336 L .71589 .42675 L p   
.792 .364 0 r   
F P   
s   
P   
p   
.002 w   
.35171 .46326 m .32059 .5811 L .26513 .58587 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.26244 .76055 m .26513 .58587 L .32059 .5811 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.52394 .78778 m .59875 .79248 L .58071 .78108 L p   
.269 .721 .957 r   
F P   
s   
P   
p   
.002 w   
.58071 .78108 m .50489 .77639 L .52394 .78778 L p   
.269 .721 .957 r   
F P   
s   
P   
p   
.002 w   
.43904 .74325 m .49633 .55903 L .63805 .5938 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.86808 .27803 m .87814 .74458 L .84953 .71935 L p   
.989 .775 .387 r   
F P   
s   
P   
p   
.002 w   
.84953 .71935 m .83999 .2391 L .86808 .27803 L p   
.989 .775 .387 r   
F P   
s   
P   
p   
.002 w   
.59875 .79248 m .65513 .60795 L .63805 .5938 L p   
.98 .893 .662 r   
F P   
s   
P   
p   
.002 w   
.65513 .60795 m .77684 .63794 L .76142 .62407 L p   
.14 .604 .925 r   
F P   
s   
P   
p   
.002 w   
.76142 .62407 m .63805 .5938 L .65513 .60795 L p   
.14 .604 .925 r   
F P   
s   
P   
p   
.002 w   
.32059 .5811 m .34934 .69542 L .26244 .76055 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.66354 .34763 m .75106 .42481 L .78191 .45826 L p   
0 .108 .604 r   
F P   
s   
P   
p   
.002 w   
.8152 .57142 m .78191 .45826 L .75106 .42481 L p   
.924 .588 .133 r   
F P   
s   
P   
p   
.002 w   
.83999 .2391 m .54757 .27171 L .54767 .32886 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.50489 .77639 m .43904 .74325 L p   
.63805 .5938 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.63805 .5938 m .58071 .78108 L .59875 .79248 L p   
.98 .893 .662 r   
F P   
s   
P   
p   
.002 w   
.77684 .63794 m .78073 .53193 L .76545 .51651 L p   
.999 .808 .465 r   
F P   
s   
P   
p   
.002 w   
.71589 .42675 m .76545 .51651 L .78073 .53193 L p   
.792 .364 0 r   
F P   
s   
P   
p   
.002 w   
.29488 .84123 m .26244 .76055 L .34934 .69542 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.54767 .32886 m .66354 .34763 L .83999 .2391 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.48827 .76282 m .4866 .74044 L .44629 .71556 L p   
.994 .752 .442 r   
F P   
s   
P   
p   
.002 w   
.46092 .69684 m .44629 .71556 L .4866 .74044 L p   
.895 .943 .833 r   
F P   
s   
P   
p   
.002 w   
.4866 .74044 m .5008 .7223 L .46092 .69684 L p   
.895 .943 .833 r   
F P   
s   
P   
p   
.002 w   
.5008 .7223 m .4866 .74044 L .48827 .76282 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.48335 .69335 m .46092 .69684 L .5008 .7223 L p   
.496 .846 .995 r   
F P   
s   
P   
p   
.002 w   
.5008 .7223 m .52262 .71896 L .48335 .69335 L p   
.496 .846 .995 r   
F P   
s   
P   
p   
.002 w   
.53933 .73243 m .52262 .71896 L .5008 .7223 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.54109 .7549 m .53933 .73243 L p   
.5008 .7223 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.52679 .77314 m .54109 .7549 L p   
.5008 .7223 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.50489 .77639 m .52679 .77314 L p   
.5008 .7223 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.48827 .76282 m .50489 .77639 L p   
.5008 .7223 L .631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.50489 .77639 m .48827 .76282 L .47268 .75346 L p   
.548 0 0 r   
F P   
s   
P   
p   
.50489 .77639 m .47268 .75346 L .48285 .76176 L .548 0 0 r   
F   
P   
p   
.002 w   
.44795 .7386 m .46499 .75254 L .48101 .76211 L p   
.548 0 0 r   
F P   
s   
P   
p   
.002 w   
.48101 .76211 m .50489 .77639 L p   
.47077 .75374 L .548 0 0 r   
F P   
s   
P   
p   
.47077 .75374 m .44795 .7386 L .48101 .76211 L .548 0 0 r   
F   
P   
p   
.002 w   
.58624 .98798 m .49362 .98702 L .49334 1.16971 L p   
.72 .551 .66 r   
F P   
s   
P   
p   
.5159 .78876 m .51475 .78782 L .51671 .79693 L .63 .477 .655 r   
F   
P   
p   
.51475 .78782 m .49142 .76877 L .51671 .79693 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.49362 .98702 m .55978 .98771 L p   
.55196 .98418 L .318 .775 .949 r   
F P   
s   
P   
p   
.002 w   
.50489 .77639 m .48947 .76717 L p   
.49223 .76761 L .479 .844 .991 r   
F P   
s   
P   
p   
.002 w   
.63805 .5938 m .58071 .78108 L .50489 .77639 L p   
.631 .478 .656 r   
F P   
s   
P   
p   
.002 w   
.52679 .77314 m .50649 .77615 L p   
.49223 .76761 L .479 .844 .991 r   
F P   
s   
P   
p   
.002 w   
.50649 .77615 m .50489 .77639 L p   
.49223 .76761 L .479 .844 .991 r   
F P   
s   
P   
p   
.002 w   
.47268 .75346 m .44795 .7386 L p   
.48285 .76176 L .548 0 0 r   
F P   
s   
P   
p   
.002 w   
.44629 .71556 m .44795 .7386 L .48827 .76282 L p   
.994 .752 .442 r   
F P   
s   
P   
p   
.002 w   
.4864 .74129 m .47793 .73607 L .48263 .76187 L p   
.982 .694 .354 r   
F P   
s   
P   
p   
.4864 .74129 m .48263 .76187 L .49015 .76636 L .982 .694 .354 r   
F   
P   
p   
.002 w   
.48947 .76717 m .48101 .76211 L p   
.48165 .76201 L .479 .844 .991 r   
F P   
s   
P   
p   
.49109 .76693 m .48947 .76717 L .48165 .76201 L .479 .844 .991 r   
F   
P   
p   
.48263 .76187 m .48165 .76201 L .46964 .75409 L .479 .844 .991 r   
F   
P   
p   
.49109 .76693 m .48165 .76201 L .48263 .76187 L .479 .844 .991 r   
F   
P   
p   
.4864 .74129 m .49015 .76636 L .49034 .76648 L .982 .694 .354 r   
F   
P   
p   
.49223 .76761 m .48947 .76717 L .49109 .76693 L .479 .844 .991 r   
F   
P   
p   
.002 w   
.52894 .97379 m .49109 .76693 L p   
.52238 .97083 L .982 .694 .354 r   
F P   
s   
P   
p   
.002 w   
.49109 .76693 m .4864 .74129 L p   
.49034 .76648 L .982 .694 .354 r   
F P   
s   
P   
p   
.49034 .76648 m .52238 .97083 L .49109 .76693 L .982 .694 .354 r   
F   
P   
p   
.52679 .77314 m .49223 .76761 L .50288 .76516 L .479 .844 .991 r   
F   
P   
p   
.49223 .76761 m .49109 .76693 L .50288 .76516 L .479 .844 .991 r   
F   
P   
p   
.002 w   
.51055 .73488 m .4864 .74129 L .49109 .76693 L p   
.63 .477 .655 r   
F P   
s   
P   
p   
.51055 .73488 m .49109 .76693 L .49259 .7667 L .63 .477 .655 r   
F   
P   
p   
.51055 .73488 m .49259 .7667 L .50398 .765 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.51161 .76386 m .52679 .77314 L p   
.50288 .76516 L .479 .844 .991 r   
F P   
s   
P   
p   
.51055 .73488 m .50139 .77691 L .51322 .7618 L .63 .477 .655 r   
F   
P   
p   
.47793 .73607 m .50514 .75639 L .48485 .76153 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.51161 .76386 m .50328 .75877 L p   
.51008 .75634 L .896 .949 .832 r   
F P   
s   
P   
p   
.002 w   
.4864 .74129 m .51055 .73488 L .50222 .72961 L p   
.575 .886 .991 r   
F P   
s   
P   
p   
.002 w   
.54109 .7549 m .52679 .77314 L .51161 .76386 L p   
.896 .949 .832 r   
F P   
s   
P   
p   
.54109 .7549 m .51161 .76386 L .52037 .75267 L .896 .949 .832 r   
F   
P   
p   
.55196 .98418 m .46532 .97695 L .49362 .98702 L .318 .775 .949 r   
F   
P   
p   
.5771 .98296 m .53763 .97772 L .55196 .98418 L .318 .775 .949 r   
F   
P   
p   
.6586 .97899 m .5664 .97802 L .5771 .98296 L .318 .775 .949 r   
F   
P   
p   
.5664 .97802 m .53763 .97772 L .5771 .98296 L .318 .775 .949 r   
F   
P   
p   
.53763 .97772 m .46532 .97695 L .55196 .98418 L .318 .775 .949 r   
F   
P   
p   
.002 w   
.58624 .98798 m .58761 .98781 L p   
.55196 .98418 L .318 .775 .949 r   
F P   
s   
P   
p   
.5771 .98296 m .55196 .98418 L .58761 .98781 L .318 .775 .949 r   
F   
P   
p   
.002 w   
.55978 .98771 m .58624 .98798 L p   
.55196 .98418 L .318 .775 .949 r   
F P   
s   
P   
p   
.002 w   
.53933 .73243 m .54109 .7549 L .52607 .7454 L p   
.994 .75 .427 r   
F P   
s   
P   
p   
.002 w   
.43569 .9622 m .43107 .97659 L p   
.46532 .97695 L .318 .775 .949 r   
F P   
s   
P   
p   
.6586 .97899 m .56547 .97198 L .46532 .97695 L .318 .775 .949 r   
F   
P   
p   
.51384 .76101 m .53441 .97352 L .54061 .97321 L .63 .477 .655 r   
F   
P   
p   
.51322 .7618 m .53425 .97353 L .51384 .76101 L .63 .477 .655 r   
F   
P   
p   
.53425 .97353 m .54061 1.0376 L .53441 .97352 L .63 .477 .655 r   
F   
P   
p   
.53425 .97353 m .53441 .97352 L .51384 .76101 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.49334 1.16971 m .58696 1.17036 L .58624 .98798 L p   
.72 .551 .66 r   
F P   
s   
P   
p   
.002 w   
.54849 1.03569 m .56542 1.0316 L .55449 .97252 L p   
.63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.55449 .97252 m .53581 .87149 L p   
.54365 .97306 L .63 .477 .655 r   
F P   
s   
P   
p   
.54365 .97306 m .54849 1.03569 L .55449 .97252 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.53581 .87149 m .51055 .73488 L p   
.54849 1.03569 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.50678 .7543 m .50222 .72961 L p   
.50748 .75474 L .982 .692 .346 r   
F P   
s   
P   
p   
.51055 .73488 m .51322 .7618 L .51384 .76101 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.50222 .72961 m .51055 .73488 L .51508 .75942 L p   
.982 .692 .346 r   
F P   
s   
P   
p   
.50222 .72961 m .51508 .75942 L .50765 .75484 L .982 .692 .346 r   
F   
P   
p   
.52037 .75267 m .51008 .75634 L .50901 .75145 L .896 .949 .832 r   
F   
P   
p   
.51008 .75634 m .50328 .75877 L .50678 .7543 L .896 .949 .832 r   
F   
P   
p   
.50514 .75639 m .50328 .75877 L .48485 .76153 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.48263 .76187 m .47793 .73607 L p   
.48485 .76153 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.46499 .75254 m .48751 .74913 L .51161 .76386 L p   
.479 .844 .991 r   
F P   
s   
P   
p   
.50288 .76516 m .46499 .75254 L .51161 .76386 L .479 .844 .991 r   
F   
P   
p   
.51322 .7618 m .50139 .77691 L .5159 .78876 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.49142 .76877 m .52894 .97379 L p   
.51671 .79693 L .63 .477 .655 r   
F P   
s   
P   
p   
.51671 .79693 m .52894 .97379 L .53425 .97353 L .63 .477 .655 r   
F   
P   
p   
.50748 .75474 m .55449 .97252 L .5529 .97179 L .982 .692 .346 r   
F   
P   
p   
.50222 .72961 m .50765 .75484 L .50748 .75474 L .982 .692 .346 r   
F   
P   
p   
.50765 .75484 m .55449 .97252 L .50748 .75474 L .982 .692 .346 r   
F   
P   
p   
.002 w   
.50222 .72961 m .47793 .73607 L .4864 .74129 L p   
.575 .886 .991 r   
F P   
s   
P   
p   
.002 w   
.47793 .73607 m .50222 .72961 L .50678 .7543 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.50678 .7543 m .50748 .75814 L p   
.50514 .75639 L .63 .476 .655 r   
F P   
s   
P   
p   
.47793 .73607 m .50678 .7543 L .50514 .75639 L .63 .476 .655 r   
F   
P   
p   
.52037 .75267 m .50901 .75145 L .52607 .7454 L .896 .949 .832 r   
F   
P   
p   
.50901 .75145 m .50069 .75055 L .51142 .74837 L .896 .949 .832 r   
F   
P   
p   
.50901 .75145 m .51142 .74837 L .52607 .7454 L .896 .949 .832 r   
F   
P   
p   
.50069 .75055 m .48751 .74913 L .49691 .74822 L .896 .949 .832 r   
F   
P   
p   
.50069 .75055 m .49691 .74822 L .52607 .7454 L .896 .949 .832 r   
F   
P   
p   
.51008 .75634 m .50678 .7543 L .50901 .75145 L .896 .949 .832 r   
F   
P   
p   
.002 w   
.54631 .96874 m .50678 .7543 L p   
.5529 .97179 L .982 .692 .346 r   
F P   
s   
P   
p   
.50748 .75474 m .5529 .97179 L .50678 .7543 L .982 .692 .346 r   
F   
P   
p   
.002 w   
.50224 .73032 m .52607 .7454 L p   
.49691 .74822 L .896 .949 .832 r   
F P   
s   
P   
p   
.002 w   
.48751 .74913 m .49105 .74461 L p   
.49691 .74822 L .896 .949 .832 r   
F P   
s   
P   
p   
.002 w   
.49105 .74461 m .50224 .73032 L p   
.49691 .74822 L .896 .949 .832 r   
F P   
s   
P   
p   
.51508 .75942 m .51161 .76386 L .51008 .75634 L .896 .949 .832 r   
F   
P   
p   
.002 w   
.51508 .75942 m .55449 .97252 L p   
.50765 .75484 L .982 .692 .346 r   
F P   
s   
P   
p   
.50398 .765 m .49142 .76877 L .50139 .77691 L .63 .477 .655 r   
F   
P   
p   
.49259 .7667 m .49142 .76877 L .50398 .765 L .63 .477 .655 r   
F   
P   
p   
.50288 .76516 m .49109 .76693 L .46964 .75409 L .479 .844 .991 r   
F   
P   
p   
.49034 .76648 m .5206 .97003 L .52238 .97083 L .982 .694 .354 r   
F   
P   
p   
.49015 .76636 m .5206 .97003 L .49034 .76648 L .982 .694 .354 r   
F   
P   
p   
.002 w   
.48263 .76187 m .5206 .97003 L p   
.49015 .76636 L .982 .694 .354 r   
F P   
s   
P   
p   
.002 w   
.49109 .76693 m .49142 .76877 L p   
.49259 .7667 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.50748 .75814 m .54631 .96874 L p   
.48485 .76153 L .63 .476 .655 r   
F P   
s   
P   
p   
.48485 .76153 m .54631 .96874 L .54119 .969 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.5206 .97003 m .48297 .76372 L p   
.54065 .96903 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.50892 .95234 m .43569 .9622 L p   
.53205 .96946 L .318 .775 .949 r   
F P   
s   
P   
p   
.56547 .97198 m .55493 .96831 L .53205 .96946 L .318 .775 .949 r   
F   
P   
p   
.48614 .76631 m .54119 .969 L .48297 .76372 L .63 .476 .655 r   
F   
P   
p   
.56547 .97198 m .43569 .9622 L .46532 .97695 L .318 .775 .949 r   
F   
P   
p   
.54119 .969 m .55727 1.02821 L .54065 .96903 L .63 .476 .655 r   
F   
P   
p   
.54119 .969 m .54065 .96903 L .48297 .76372 L .63 .476 .655 r   
F   
P   
p   
.60748 .96989 m .58904 .9666 L .56547 .97198 L .318 .775 .949 r   
F   
P   
p   
.58904 .9666 m .50892 .95234 L .55493 .96831 L .318 .775 .949 r   
F   
P   
p   
.58904 .9666 m .55493 .96831 L .56547 .97198 L .318 .775 .949 r   
F   
P   
p   
.55493 .96831 m .50892 .95234 L .53205 .96946 L .318 .775 .949 r   
F   
P   
p   
.002 w   
.54061 1.0376 m .54849 1.03569 L p   
.54061 .97321 L .63 .477 .655 r   
F P   
s   
P   
p   
.53441 .97352 m .54061 1.0376 L .54061 .97321 L .63 .477 .655 r   
F   
P   
p   
.002 w   
.5206 .97003 m .53232 1.03425 L p   
.52238 .97083 L .982 .694 .354 r   
F P   
s   
P   
p   
.002 w   
.52894 .97379 m .54061 1.0376 L p   
.53425 .97353 L .63 .477 .655 r   
F P   
s   
P   
p   
.002 w   
.53232 1.03425 m .54061 1.0376 L .52894 .97379 L p   
.982 .694 .354 r   
F P   
s   
P   
p   
.52238 .97083 m .53232 1.03425 L .52894 .97379 L .982 .694 .354 r   
F   
P   
p   
.002 w   
.55727 1.02821 m .53232 1.03425 L .5206 .97003 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.54065 .96903 m .55727 1.02821 L .5206 .97003 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.54631 .96874 m .55727 1.02821 L p   
.54119 .969 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.60735 .95342 m .50892 .95234 L p   
.58904 .9666 L .318 .775 .949 r   
F P   
s   
P   
p   
.60748 .96989 m .60745 .96568 L .58904 .9666 L .318 .775 .949 r   
F   
P   
p   
.60745 .96568 m .60735 .95342 L .58904 .9666 L .318 .775 .949 r   
F   
P   
p   
.6586 .97899 m .63738 .9684 L .60748 .96989 L .318 .775 .949 r   
F   
P   
p   
.63738 .9684 m .60735 .95342 L .60748 .96989 L .318 .775 .949 r   
F   
P   
p   
.6586 .97899 m .60748 .96989 L .56547 .97198 L .318 .775 .949 r   
F   
P   
p   
.002 w   
.52607 .7454 m .54109 .7549 L p   
.52037 .75267 L .896 .949 .832 r   
F P   
s   
P   
p   
.002 w   
.52607 .7454 m .50224 .73032 L p   
.52501 .73162 L .994 .75 .427 r   
F P   
s   
P   
p   
.53933 .73243 m .52607 .7454 L .52501 .73162 L .994 .75 .427 r   
F   
P   
p   
.002 w   
.55727 1.02821 m .54631 .96874 L p   
.56542 1.0316 L .982 .692 .346 r   
F P   
s   
P   
p   
.5529 .97179 m .56542 1.0316 L .54631 .96874 L .982 .692 .346 r   
F   
P   
p   
.52037 .75267 m .51508 .75942 L .51008 .75634 L .896 .949 .832 r   
F   
P   
p   
.50514 .75639 m .50748 .75814 L .50328 .75877 L .63 .476 .655 r   
F   
P   
p   
.002 w   
.50328 .75877 m .48751 .74913 L p   
.50901 .75145 L .896 .949 .832 r   
F P   
s   
P   
p   
.002 w   
.48297 .76372 m .48263 .76187 L p   
.48614 .76631 L .63 .476 .655 r   
F P   
s   
P   
p   
.48485 .76153 m .48614 .76631 L .48263 .76187 L .63 .476 .655 r   
F   
P   
p   
.46964 .75409 m .48165 .76201 L .46499 .75254 L .479 .844 .991 r   
F   
P   
p   
.002 w   
.48101 .76211 m .46499 .75254 L p   
.48165 .76201 L .479 .844 .991 r   
F P   
s   
P   
p   
.002 w   
.43107 .97659 m .4406 .97818 L p   
.46532 .97695 L .318 .775 .949 r   
F P   
s   
P   
p   
.002 w   
.4406 .97818 m .49362 .98702 L p   
.46532 .97695 L .318 .775 .949 r   
F P   
s   
P   
p   
.002 w   
.55449 .97252 m .56542 1.0316 L p   
.5529 .97179 L .982 .692 .346 r   
F P   
s   
P   
p   
.002 w   
.58761 .98781 m .6586 .97899 L p   
.5771 .98296 L .318 .775 .949 r   
F P   
s   
P   
p   
.002 w   
.50049 .70718 m .48335 .69335 L .52262 .71896 L p   
.516 0 0 r   
F P   
s   
P   
p   
.002 w   
.52262 .71896 m .53933 .73243 L .50049 .70718 L p   
.516 0 0 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .29488 .84123 L p   
.34934 .69542 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.34934 .69542 m .43211 .77639 L .37404 .87233 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.78566 .69145 m .8152 .57142 L .78508 .54117 L p   
.99 .888 .608 r   
F P   
s   
P   
p   
.002 w   
.75106 .42481 m .78508 .54117 L .8152 .57142 L p   
.924 .588 .133 r   
F P   
s   
P   
p   
.002 w   
.76545 .51651 m .76142 .62407 L .77684 .63794 L p   
.999 .808 .465 r   
F P   
s   
P   
p   
.002 w   
.50224 .73032 m .50049 .70718 L .53933 .73243 L p   
.994 .75 .427 r   
F P   
s   
P   
p   
.002 w   
.70531 1.18107 m .70098 .78411 L .66721 .76047 L p   
.998 .785 .446 r   
F P   
s   
P   
p   
.002 w   
.70098 .78411 m .78566 .69145 L .75447 .66484 L p   
.87 .967 .856 r   
F P   
s   
P   
p   
.002 w   
.75447 .66484 m .66721 .76047 L .70098 .78411 L p   
.87 .967 .856 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .37084 1.24194 L .4137 1.25092 L p   
.994 .785 .516 r   
F P   
s   
P   
p   
.002 w   
.76628 1.24194 m .4137 1.25092 L .37084 1.24194 L p   
.179 .705 .863 r   
F P   
s   
P   
p   
.002 w   
.6586 .97899 m .58624 .98798 L .58696 1.17036 L p   
.509 .38 .64 r   
F P   
s   
P   
p   
.002 w   
.78508 .54117 m .75447 .66484 L .78566 .69145 L p   
.99 .888 .608 r   
F P   
s   
P   
p   
.002 w   
.47114 1.1883 m .70531 1.18107 L .67084 1.16963 L p   
.215 .725 .888 r   
F P   
s   
P   
p   
.002 w   
.67084 1.16963 m .43002 1.17733 L .47114 1.1883 L p   
.215 .725 .888 r   
F P   
s   
P   
p   
.002 w   
.4301 1.16267 m .49334 1.16971 L .49362 .98702 L p   
.896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.49362 .98702 m .43107 .97659 L .4301 1.16267 L p   
.896 .697 .625 r   
F P   
s   
P   
p   
.002 w   
.66354 .34763 m .75106 .42481 L .83999 .2391 L closepath p   
.63 .476 .655 r   
F P   
s   
P   
p   
.01 w   
.44598 .48049 m   
.54808 .56154 L   
s   
P   
p   
.01 w   
.49554 .73139 m   
.50099 .71377 L   
s   
P   
p   
.01 w   
.50328 .70635 m   
.516 .66526 L   
s   
P   
p   
.01 w   
.516 .66526 m   
.54808 .56154 L   
s   
P   
p   
.02 w   
.54808 .56154 Mdot   
P   
p   
.01 w   
.54808 .56154 m   
.72491 .54634 L   
s   
P   
p   
.02 w   
.54808 .56154 Mdot   
P   
p   
.002 w   
.43002 1.17733 m .43211 .77639 L .37404 .87233 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.37404 .87233 m .37084 1.24194 L .43002 1.17733 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.84384 .83119 m .76096 .87233 L .72872 .85124 L p   
.684 .949 .957 r   
F P   
s   
P   
p   
.002 w   
.76096 .87233 m .76628 1.24194 L .73348 1.23237 L p   
.996 .782 .428 r   
F P   
s   
P   
p   
.002 w   
.73348 1.23237 m .72872 .85124 L .76096 .87233 L p   
.996 .782 .428 r   
F P   
s   
P   
p   
.002 w   
.58696 1.17036 m .66013 1.16429 L .6586 .97899 L p   
.509 .38 .64 r   
F P   
s   
P   
p   
.002 w   
.49334 1.16971 m .58696 1.17036 L .66013 1.16429 L p   
.223 .73 .894 r   
F P   
s   
P   
p   
.002 w   
.87814 .74458 m .84384 .83119 L .81408 .80867 L p   
.969 .932 .675 r   
F P   
s   
P   
p   
.002 w   
.81408 .80867 m .84953 .71935 L .87814 .74458 L p   
.969 .932 .675 r   
F P   
s   
P   
p   
.002 w   
.4301 1.16267 m .49334 1.16971 L p   
.66013 1.16429 L .223 .73 .894 r   
F P   
s   
P   
p   
.002 w   
.72872 .85124 m .81408 .80867 L .84384 .83119 L p   
.684 .949 .957 r   
F P   
s   
P   
p   
.002 w   
.84589 .53594 m .83999 .2391 L .75106 .42481 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.66902 .96472 m .6586 .97899 L .66013 1.16429 L p   
0 0 .229 r   
F P   
s   
P   
p   
.002 w   
.6586 .97899 m .66902 .96472 L .60735 .95342 L p   
.318 .775 .949 r   
F P   
s   
P   
p   
.002 w   
.75106 .42481 m .78508 .54117 L .84589 .53594 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.43475 1.15296 m .4301 1.16267 L .43107 .97659 L p   
0 0 .097 r   
F P   
s   
P   
p   
.002 w   
.43107 .97659 m .43569 .9622 L .43475 1.15296 L p   
0 0 .097 r   
F P   
s   
P   
p   
.01 w   
.5485 .801 m   
.54877 .95278 L   
s   
P   
p   
.02 w   
.5485 .801 Mdot   
P   
p   
.02 w   
.72491 .54634 Mdot   
P   
p   
.002 w   
.66721 .76047 m .67084 1.16963 L .70531 1.18107 L p   
.998 .785 .446 r   
F P   
s   
P   
p   
.002 w   
.46092 .69684 m .44629 .71556 L .44795 .7386 L p   
.628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.50049 .70718 m .48335 .69335 L .46092 .69684 L p   
.628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.50224 .73032 m .50049 .70718 L p   
.46092 .69684 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.48751 .74913 m .50224 .73032 L p   
.46092 .69684 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.46499 .75254 m .48751 .74913 L p   
.46092 .69684 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.44795 .7386 m .46499 .75254 L p   
.46092 .69684 L .628 .474 .654 r   
F P   
s   
P   
p   
.002 w   
.84953 .71935 m .84589 .53594 L .78508 .54117 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.78508 .54117 m .75447 .66484 L .84953 .71935 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.43475 1.15296 m .4301 1.16267 L p   
.66013 1.16429 L .223 .73 .894 r   
F P   
s   
P   
p   
.002 w   
.50881 1.1463 m .43475 1.15296 L p   
.66013 1.16429 L .223 .73 .894 r   
F P   
s   
P   
p   
.002 w   
.60836 1.14703 m .50881 1.1463 L p   
.66013 1.16429 L .223 .73 .894 r   
F P   
s   
P   
p   
.002 w   
.66013 1.16429 m .67071 1.15466 L .66902 .96472 L p   
0 0 .229 r   
F P   
s   
P   
p   
.002 w   
.66013 1.16429 m .67071 1.15466 L .60836 1.14703 L p   
.223 .73 .894 r   
F P   
s   
P   
p   
.002 w   
.75447 .66484 m .66721 .76047 L .72872 .85124 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.67084 1.16963 m .66721 .76047 L .72872 .85124 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.54061 1.0376 m .56542 1.0316 L .55727 1.02821 L p   
.489 .878 .966 r   
F P   
s   
P   
p   
.002 w   
.55727 1.02821 m .53232 1.03425 L .54061 1.0376 L p   
.489 .878 .966 r   
F P   
s   
P   
p   
.01 w   
.54891 1.03292 m   
.54904 1.11028 L   
s   
P   
p   
.002 w   
.43002 1.17733 m .37084 1.24194 L .73348 1.23237 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.37084 1.24194 m .73348 1.23237 L .76628 1.24194 L p   
.179 .705 .863 r   
F P   
s   
P   
p   
.002 w   
.81408 .80867 m .84953 .71935 L .75447 .66484 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.72872 .85124 m .81408 .80867 L p   
.75447 .66484 L .63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.73348 1.23237 m .67084 1.16963 L .43002 1.17733 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.01 w   
.54891 1.03292 m   
.54911 1.14659 L   
s   
P   
p   
.01 w   
.54478 1.03123 m   
.54891 1.03292 L   
s   
P   
p   
.002 w   
.72872 .85124 m .73348 1.23237 L .67084 1.16963 L p   
.63 .476 .655 r   
F P   
s   
P   
p   
.002 w   
.60735 .95342 m .66902 .96472 L .67071 1.15466 L p   
.909 .704 .613 r   
F P   
s   
P   
p   
.02 w   
.54913 1.15871 Mdot   
P   
p   
.002 w   
.50881 1.1463 m .43475 1.15296 L .43569 .9622 L p   
.491 .363 .633 r   
F P   
s   
P   
p   
.002 w   
.43569 .9622 m .50892 .95234 L .50881 1.1463 L p   
.491 .363 .633 r   
F P   
s   
P   
p   
.002 w   
.67071 1.15466 m .60836 1.14703 L .60735 .95342 L p   
.909 .704 .613 r   
F P   
s   
P   
p   
.002 w   
.50892 .95234 m .60735 .95342 L .60836 1.14703 L p   
.721 .549 .657 r   
F P   
s   
P   
p   
.002 w   
.60836 1.14703 m .50881 1.1463 L .50892 .95234 L p   
.721 .549 .657 r   
F P   
s   
P   
p   
.01 w   
.44371 .98975 m   
.50889 1.0165 L   
s   
P   
p   
.02 w   
.44598 .48049 Mdot   
P   
p   
.02 w   
.44598 .48049 Mdot   
P   
p   
.02 w   
.44371 .98975 Mdot   
P   
p   
.002 w   
.93788 .23453 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.80901 .03436 L   
s   
.80901 .03436 m   
.93788 .23453 L   
s   
.26714 1.31887 m   
.96564 1.30512 L   
s   
.96564 1.30512 m   
.83141 1.2668 L   
s   
.83141 1.2668 m   
.03436 1.28529 L   
s   
.03436 1.28529 m   
.26714 1.31887 L   
s   
P   
p   
P   
% End of Graphics   
MathPictureEnd   
   \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{221, 300},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0001;1000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00[Woo1000:goo002VOol80003Ool2000ZOol0
09ioo`P000]oo`8002Yoo`00UWoo20004goo00<007oo0000:Goo002?Ool7000KOol01000Oomoo`00
:7oo0027Ool8000ROol01000Oomoo`00:7oo001oOol8000ZOol01@00Oomoogoo00009goo001gOol8
000bOol00`00Oomoo`02Ool00`00Oomoo`0TOol0071oo`L003Yoo`03001oogoo009oo`03001oogoo
02Aoo`00J7oo2000@Goo00<007ooOol00goo00<007ooOol08goo001POol80019Ool00`00Oomoo`04
Ool00`00Oomoo`0ROol005Qoo`P0055oo`03001oogoo00Aoo`03001oogoo029oo`00D7oo2000FGoo
00<007ooOol01Goo00<007ooOol08Goo0019Ool7001QOol00`00Oomoo`06Ool00`00Oomoo`0POol0
045oo`P006Qoo`03001oogoo00Ioo`03001oogoo021oo`00>Goo2000L7oo00<007ooOol01goo00<0
07ooOol07goo000aOol8001hOol00`00Oomoo`08Ool00`00Oomoo`0NOol002Yoo`L0081oo`03001o
ogoo00Qoo`03001oogoo01ioo`008Woo2000Qgoo00<007ooOol02Goo00<007ooOol07Goo000JOol8
002?Ool00`00Oomoo`0:Ool00`00Oomoo`0LOol0019oo`P009Moo`03001oogoo00Yoo`03001oogoo
01aoo`003Woo1000Wgoo00<007ooOol02goo00<007ooOol06goo000>Ool2002QOol00`00Oomoo`0;
Ool00`00Oomoo`0KOol000ioo`04001oo`00002OOol00`00Oomoo`0<Ool00`00Oomoo`0JOol000io
o`05001oogooOol0002NOol00`00Oomoo`0=Ool00`00Oomoo`0IOol000ioo`03001oogoo009oo`03
001oogoo09]oo`03001oogoo00eoo`03001oogoo01Uoo`003Woo00<007ooOol00goo00<007ooOol0
VWoo00<007ooOol03Woo00<007ooOol067oo000>Ool00`00Oomoo`04Ool00`00Oomoo`2IOol00`00
Oomoo`0?Ool00`00Oomoo`0GOol000ioo`03001oogoo00Eoo`8009Yoo`03001oogoo00ioo`03001o
ogoo01Moo`003Woo00<007ooOol01goo00<007ooOol0Ugoo00<007ooOol03goo00<007ooOol05Woo
000>Ool00`00Oomoo`08Ool00`00Oomoo`2FOol00`00Oomoo`0@Ool00`00Oomoo`0EOol000ioo`03
001oogoo00Uoo`03001oogoo09Eoo`03001oogoo011oo`03001oogoo01Eoo`003Woo00<007ooOol0
2Woo0P00UGoo00<007ooOol04Goo00<007ooOol057oo000>Ool00`00Oomoo`0<Ool00`00Oomoo`2B
Ool00`00Oomoo`0BOol00`00Oomoo`0COol000ioo`03001oogoo00eoo`03001oogoo095oo`03001o
ogoo019oo`03001oogoo01=oo`003Woo00<007ooOol03Woo00<007ooOol0T7oo00<007ooOol04goo
00<007ooOol04Woo000>Ool00`00Oomoo`0?Ool2002@Ool00`00Oomoo`0DOol00`00Oomoo`0AOol0
00ioo`03001oogoo015oo`03001oogoo08eoo`03001oogoo01Aoo`03001oogoo015oo`003Woo00<0
07ooOol04Woo00<007ooOol0S7oo00<007ooOol05Goo00<007ooOol047oo000>Ool00`00Oomoo`0C
Ool00`00Oomoo`2;Ool00`00Oomoo`0FOol00`00Oomoo`0?Ool000eoo`03001oogoo01Eoo`03001o
ogoo08Yoo`03001oogoo01Ioo`03001oogoo00moo`003Goo00<007ooOol05Woo0P00RWoo00<007oo
Ool05goo00<007ooOol03Woo000=Ool00`00Oomoo`0HOol00`00Oomoo`27Ool00`00Oomoo`0HOol0
0`00Oomoo`0=Ool000eoo`03001oogoo01Uoo`03001oogoo08Ioo`03001oogoo01Qoo`03001oogoo
00eoo`003Goo00<007ooOol06Woo00<007ooOol0QGoo00<007ooOol05Goo1@003Woo000=Ool00`00
Oomoo`0KOol20025Ool00`00Ool000040008Ool90004Ool00`00Oomoo`0<Ool000eoo`03001oogoo
01eoo`03001oogoo07]oo`T0009Am0/000eoo`03001oogoo00aoo`003Goo00<007ooOol07Woo00<0
07ooOol0LGoo2@001e7d00D0057d0000057d00<001Aoo`03001oogoo00aoo`003Goo00<007ooOol0
7goo00<007ooOol0Igoo2@00457d0P000e7d0P0000=o3000Ool04Woo00<007ooOol037oo000=Ool0
0`00Oomoo`0POol2001MOol:000HDO@20003DO@00`00DO@00002O``00`00Oomoo`0@Ool00`00Oomo
o`0<Ool000eoo`03001oogoo029oo`03001oogoo055oo`T0025Am003001Am00000=Am003001Am000
00=o3003001oogoo00moo`03001oogoo00aoo`003Goo00<007ooOol08goo00<007ooOol0Agoo2@00
:57d0P000U7d00@0057dDO@0009Am005001o37l<O``0000AOol00`00Oomoo`0<Ool000eoo`03001o
ogoo02Aoo`03001oogoo03eoo`T002mAm08000AAm004001Am57d0002DO@00`00O`ao3002O``00`00
Oomoo`0>Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Eoo`03001oogoo03=oo`T000AAm003001A
m57d031Am003001Am57d00AAm003001Am00000=Am003001o37l<00=o3003001oogoo00eoo`03001o
ogoo00aoo`003Goo00<007ooOol09Woo0P00:goo20003E7d00<0057dDO@0;U7d0P001e7d00<0057d
00000e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol037oo000=Ool00`00Oomoo`0XOol0
0`00Oomoo`0OOol9000EDO@00`00DOAAm00/DO@20009DO@20004DO@00`00O`ao3003O``00`00Oomo
o`0=Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Uoo`03001oogoo01Eoo`T001iAm003001Am57d
02]Am003001Am57d00UAm08000AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00aoo`00
3Goo00<007ooOol0:Woo00<007ooOol037oo20009e7d00<0057dDO@0:E7d0P00357d00<0057dDO@0
0e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol037oo000=Ool00`00Oomoo`0[Ool20003
Ool9000_DO@00`00DOAAm00XDO@00`00DOAAm00<DO@00`00DOAAm003DO@00`00O`ao3003O``00`00
Oomoo`0=Ool00`00Oomoo`0<Ool000eoo`03001oogoo02]oo`D003QAm003001Am57d02IAm08000mA
m003001Am57d00=Am003001o37l<00=o3003001oogoo00eoo`03001oogoo00aoo`003Goo00<007oo
Ool0:goo1000>E7d00<0057dDO@0957d0P00457d0P001E7d00<007l<O``00gl<00<007ooOol03Goo
00<007ooOol037oo000=Ool00`00Oomoo`0[Ool20002DO@2000gDO@00`00DOAAm00SDO@00`00DOAA
m00@DO@20005DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0<Ool000eoo`03001oogoo
02]oo`03001Am00000=Am0<003AAm003001Am57d025Am080019Am003001Am00000IAm003001o37l<
009o3003001oogoo00eoo`03001oogoo00aoo`003Goo00<007ooOol0:goo00<0057d00001U7d0P00
<U7d00<0057dDO@07e7d0P00557d00<0057d00001U7d00<007l<O``00Wl<00<007ooOol03Goo00<0
07ooOol037oo000=Ool00`00Oomoo`0[Ool01000DOAAm0001e7d0`00;U7d10007U7d00<0057dDO@0
4e7d00@0057dDO@000IAm003001o37l<009o3003001oogoo00ioo`03001oogoo00]oo`003Goo00<0
07ooOol0:goo00@0057dDO@000YAm08002YAm080009GW`03000V_`0000@001MAm08001IAm004001A
m57d0006DO@00`00O`ao3002O``00`00Oomoo`0>Ool00`00Oomoo`0;Ool000eoo`03001oogoo02]o
o`05001Am57dDO@0000;DO@2000UDO@30005Eil00`009[lV_`039[l5000ADO@00`00DOAAm00EDO@0
1@00DOAAm57d00001U7d00<007l<O``00Wl<00<007ooOol03Woo00<007ooOol02goo000=Ool00`00
Oomoo`0[Ool01@00DOAAm57d00003E7d0`00857d0P002ENO00<002Jo9[l01bJo1@002U7d0P00657d
00D0057dDOAAm00000IAm003001o37l<009o3003001oogoo00ioo`03001oogoo00]oo`003Goo00<0
07ooOol0:goo00<0057dDO@00U7d00<0057dDO@03E7d0P006e7d0`0035NO00<002Jo9[l02bJo1@00
0e7d0P006E7d00<0057dDO@00U7d00<0057dDO@0157d00<007l<O``00Wl<00<007ooOol03Woo00<0
07ooOol02goo000=Ool00`00Oomoo`0[Ool00`00DOAAm002DO@00`00DOAAm00?DO@3000FDO@2000@
Eil00`009[lV_`0?9[l3000KDO@00`00DOAAm002DO@00`00DOAAm004DO@00`00O`ao3002O``00`00
Oomoo`0>Ool00`00Oomoo`0;Ool000eoo`03001oogoo02]oo`03001Am57d00=Am003001Am57d015A
m080015Am0<001=GW`03000V_bJo014V_`03001Am57d01MAm003001Am57d00=Am003001Am57d00AA
m003001o37l<009o3003001oogoo00ioo`03001oogoo00]oo`003Goo00<007ooOol0:goo00<0057d
DO@00e7d00<0057dDO@04e7d0P003E7d0P005eNO00<002Jo9[l04BJo00<0057dDO@05U7d00<0057d
DO@00e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000=Ool0
0`00Oomoo`0[Ool00`00DOAAm004DO@00`00DOAAm00DDO@30007DO@3000JEil4000@9[l2000EDO@0
0`00DOAAm004DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02]oo`03001Am57d00AAm003001Am57d01MAm08000=Am08001YGW`8000Eoo`H0
00/V_`8001AAm003001Am57d00AAm003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03
001oogoo00]oo`003Goo00<007ooOol0:goo00<0057dDO@01E7d00<0057dDO@0657d0`006ENO0`00
3Goo1P001bJo00<0057dDO@04E7d00<0057dDO@0157d00<0057dDO@0157d00<007l<O``00gl<00<0
07ooOol03Goo00<007ooOol02goo000=Ool00`00Oomoo`0[Ool00`00DOAAm005DO@00`00DOAAm00H
DO@00`00Kk/0000FEil3000;Ool60005Ool600029[l00`00DOAAm00?DO@00`00DOAAm005DO@00`00
DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02ao
o`03001Am57d00IAm003001Am57d01IAm004001_^fnkKk/2000BEil20002Ool<0006DO@20009Ool4
000@DO@00`00DOAAm005DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomo
o`0;Ool000aoo`03001oogoo02aoo`03001Am57d00IAm003001Am57d01EAm003001_^fnk00A_^`03
001GWeNO00aGW`L001AAm08000]oo`03001Am57d00aAm003001Am57d00IAm003001Am57d00AAm003
001o37l<00=o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0;7oo00<0057dDO@0
1e7d00<0057dDO@04e7d00<006nkKk/01Vnk00<005NOEil025NO0`007E7d0P002Woo0P00357d00<0
057dDO@01U7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000<
Ool00`00Oomoo`0/Ool00`00DOAAm007DO@00`00DOAAm00BDO@00`00Kk]_^`08Kk/20006Eil4000P
DO@00`00Oomoo`08Ool2000:DO@00`00DOAAm007DO@00`00DOAAm004DO@00`00O`ao3003O``00`00
Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02aoo`03001Am57d00QAm003001Am57d015A
m003001_^fnk00Y_^`03001GWeNO00<00003Ool0057d029Am08000Uoo`8000UAm003001Am57d00MA
m003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007oo
Ool0;7oo00<0057dDO@0257d00<0057dDO@0457d00<006nkKk/036nk0P000Woo0P009U7d0P002Goo
00<0057dDO@01E7d00<0057dDO@0257d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo
00<007ooOol02goo000<Ool00`00Oomoo`0/Ool00`00DOAAm009DO@00`00DOAAm00>DO@00`00Kk]_
^`0<Kk/00`00Oomoo`02000ZDO@00`00Oomoo`07Ool00`00DOAAm004DO@00`00DOAAm009DO@00`00
DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02ao
o`03001Am57d00UAm003001Am57d00eAm003001_^fnk00a_^`04001oogoo000]DO@20008Ool20003
DO@00`00DOAAm00:DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;
Ool000aoo`03001oogoo02]oo`8000aAm003001Am57d00]Am003001_^fnk00a_^`04001oo`00000`
DO@20007Ool01@1c001Am57d0000357d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol03Goo
00<007ooOol02goo000<Ool00`00Oomoo`0[Ool2000<DO@00`00DOAAm00:DO@00`00Kk]_^`0<Kk/3
000dDO@20006Ool00`1c0000000=DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo02]oo`8000eAm003001Am57d00QAm003001_^fnk00a_^`80
03QAm003001oogoo00Aoo`8000eAm003001Am57d00=Am003001o37l<00=o3003001oogoo00eoo`03
001oogoo00]oo`0037oo00<007ooOol0:goo0P003E7d00<0057dDO@01e7d00<006nkKk/036nk0P00
>U7d00<007ooOol017oo00<0057dDO@02e7d00<0057dDO@00e7d00<007l<O``00gl<00<007ooOol0
3Goo00<007ooOol02goo000<Ool00`00Oomoo`0[Ool2000>DO@00`00DOAAm005DO@00`00Kk]_^`0;
Kk/2000lDO@00`00Oomoo`05Ool00`00DOAAm00:DO@00`00DOAAm003DO@00`00O`ao3003O``00`00
Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02]oo`8000iAm003001Am57d00AAm003001_
^fnk00]_^`03001Am57d03eAm003001oogoo00Aoo`03001Am57d00YAm003001Am57d00=Am003001o
37l<00=o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0057dDO@03U7d
00<0057dDO@00e7d00<006nkKk/02Vnk00<0057dDO@0?U7d0P001Goo00<0057dDO@02U7d00<0057d
DO@00e7d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02goo000<Ool00`00Oomoo`0[Ool0
0`00DOAAm00>DO@00`00DOAAm002DO@00`00Kk]_^`0;Kk/00`00DOAAm00oDO@20004Ool00`00DOAA
m00:DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03
001oogoo02]oo`03001Am57d00mAm004001Am57d000=Kk/00`00DOAAm010DO@20005Ool00`00DOAA
m009DO@00`00DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03
001oogoo02]oo`03001Am57d00mAm003001Am00000i_^`03001Am57d045Am08000Aoo`03001Am57d
00UAm003001Am57d00=Am003001o37l<00=o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<0
07ooOol0:goo00<0057dDO@0457d00<006nkKk/036nk00<0057dDO@0@U7d0P0017oo00<0057dDO@0
2E7d00<0057dDO@0157d00<007l<O``00Wl<00<007ooOol03Goo00<007ooOol02goo000<Ool00`00
Oomoo`0[Ool00`00DOAAm00@DO@2000<Kk/00`00DOAAm014DO@20004Ool00`00DOAAm008DO@00`00
DOAAm004DO@00`00O`ao3002O``00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02]o
o`03001Am57d00mAm003001oMGme008000U_^`8004IAm003001UH7oo00=oo`03001Am57d00QAm003
001Am57d00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0
:goo00<0057dDO@03e7d00<007meOgD00Wme00<006nkKk/01Vnk00<0057dDO@01E7d00<0057dDO@0
?U7d0P000goo00<0057dDO@0257d00<0057dDO@0157d00<007l<O``00Wl<00<007ooOol03Goo00<0
07ooOol02goo000<Ool00`00Oomoo`0[Ool00`00DOAAm00?DO@00`00OgEoM@03OgD00`00Kk]_^`04
Kk/20006DO@30010DO@20002Ool00`00DOAAm008DO@00`00DOAAm004DO@00`00O`ao3002O``00`00
Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo02]oo`03001Am57d00mAm003001oMGme00Ao
M@8000=_^`8000IAm0D003mAm08000=oo`03001Am57d00MAm003001Am57d00AAm003001o37l<009o
3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0057dDO@03U7d00<007me
OgD01gme00@006nk000000QAm003001Am00000<003iAm080009oo`03001Am57d00MAm003001Am57d
00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo00<0
057dDO@03U7d00<007meOgD027me00<007oo00002e7d1000?E7d00D006EPOomoo`0000UAm003001A
m57d00AAm003001o37l<009o3003001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0:goo
00<0057dDO@03U7d00<007meOgD027me0P003U7d0`00?E7d0P0000=oo`00DO@0257d00<0057dDO@0
157d00<007l<O``00Wl<00<007ooOol03Goo00<007ooOol02goo000<Ool00`00Oomoo`0[Ool00`00
DOAAm00>DO@00`00OgEoM@07OgD00`00Ool0000?DO@3000lDO@01@00IF0007oo0000257d00<0057d
DO@0157d00<007l<O``00Wl<00<007ooOol03Woo00<007ooOol02Woo000<Ool00`00Oomoo`0[Ool0
0`00DOAAm00=DO@00`00OgEoM@08OgD2000ADO@4000kDO@200000goo001Am007DO@00`00DOAAm004
DO@00`00O`ao3002O``00`00Oomoo`0>Ool00`00Oomoo`0:Ool000aoo`03001oogoo02]oo`03001A
m57d00eAm003001oMGme00QoM@03001Am57d015Am0@003YAm004001UH0000008DO@00`00DOAAm004
DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000aoo`03001oogoo02]oo`03001A
m57d00eAm003001oMGme00QoM@03001Am57d01=Am0<003YAm004001UH7oo0007DO@00`00DOAAm004
DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000aoo`03001oogoo02]oo`03001A
m57d00aAm003001oMGme00QoM@03001Am57d01EAm0<003UAm0@000MAm003001Am57d00AAm003001o
37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`0037oo00<007ooOol0:goo00<0057dDO@0357d
00<007meOgD027me6E7d0`00>57d00@007l^000000MAm003001Am57d00AAm003001o37l<00=o3003
001oogoo00eoo`03001oogoo00Yoo`0037oo00<007ooOol0:goo00<0057dDO@0357d00<007meOgD0
1gme0`00657d1000=U7d00@007l^Obh000MAm003001Am57d00AAm003001o37l<00=o3003001oogoo
00eoo`03001oogoo00Yoo`0037oo00<007ooOol0:goo00<0057dDO@0357d00<007meOgD01gme1`00
5E7d1000=E7d00<007l^Obh00P001U7d20001Gl<00<007ooOol03Goo00<007ooOol02Woo000<Ool0
0`00Oomoo`0[Ool00`00DOAAm00;DO@00`00OgEoM@08OgD00`00Oomoo`0200024Wd4000CDO@3000[
DO@00`00DOAAm006DO@00`00Obio;P090006DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomo
o`0:Ool000]oo`03001oogoo02aoo`03001Am57d00]Am003001oMGme00QoM@03001oogoo009oo`03
000BOA9m00<BO@@0011Am0<0025Am0X000QAm003001o;Wl^008000IAm003001Am57d00AAm003001o
37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@02e7d
00<007meOgD027me00<007ooOol01Goo10000a9m10003E7d10005E7d5000257d00@007l^Obh000MA
m003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007oo
Ool0;7oo00<0057dDO@02e7d00<007meOgD01gme00<007ooOol02Woo10000a9m1@002E7d10002U7d
5000257d00<0057dDO@01e7d00@007l^Obh000MAm003001Am57d00AAm003001o37l<00=o3003001o
ogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@02U7d00<007meOgD027me
00<007ooOol03Woo1000119m10001e7d5P00757d00@007l^Obh000MAm003001Am57d00AAm003001o
37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@02U7d
00<007meOgD027me00<007ooOol04Woo10000Q9m00<0057d00000`000e7d30009U7d00@007l^Obh0
00MAm003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<0
07ooOol0;7oo00<0057dDO@02U7d00<007meOgD027me00<007ooOol05Woo0P001U7d1P00;e7d00<0
07l^0000257d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;
Ool00`00Oomoo`0/Ool00`00DOAAm00:DO@00`00OgEoM@07OgD00`00Oomoo`0HOol00`00DOAAm008
DO@4000/DO@01000Obio;P00257d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<0
07ooOol02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm009DO@00`00OgEoM@08OgD00`00Oomoo`0H
Ool00`00DOAAm007DO@30002DO@5000WDO@01000Obio;P00257d00<0057dDO@0157d00<007l<O``0
0gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm004DO@6000:
OgD00`00Oomoo`0GOol00`00DOAAm008DO@20007DO@5000SDO@01000Obio;P00257d00<0057dDO@0
157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool00`00Oomoo`0/Ool70005
DO@30007OgD00`00Oomoo`0HOol00`00DOAAm008DO@2000;DO@5000ODO@00`00Obh00009DO@00`00
DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02ao
o`03001Am57d00UAm004001nZWjZ0006OgD00`00Oomoo`0HOol00`00DOAAm007DO@3000?DO@5000K
DO@00`00Obh00009DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:
Ool000]oo`03001oogoo02aoo`03001Am57d00YAm003001nZWjZ008000AoM@03001oogoo01Moo`03
001Am57d00QAm08001AAm0D001MAm003001o;P0000UAm003001Am57d00AAm003001o37l<00=o3003
001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@02U7d00<007jZOZX0
0WjZ00D007meOgEoM@0001Uoo`03001Am57d00QAm08001EAm08000034Wd0000000@0019Am003001o
;P0000UAm003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo
00<007ooOol0;7oo00<0057dDO@02U7d00<007jZOZX00gjZ0`006Woo00<0057dDO@01e7d0`00557d
00<007nEOiD00P000a9m1P003U7d0P002U7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol0
3Goo00<007ooOol02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm00:DO@00`00OZYnZP05OZX00`00
Oomoo`0HOol00`00DOAAm007DO@2000EDO@00`00OiEoU@02OiD00`004WdBO@054Wd5000:DO@2000:
DO@00`00DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001o
ogoo02aoo`03001Am57d00]Am003001nZWjZ00AnZP03001oogoo01Moo`03001Am57d00QAm08001EA
m003001oUGnE009oU@03001oogoo00@000DBO@D000IAm08000YAm003001Am57d00AAm003001o37l<
00=o3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@02e7d00<0
07jZOZX01GjZ00<007ooOol05Woo00<0057dDO@0257d0P00557d00<007nEOiD00WnE00<007ooOol0
1Goo10001Q9m10000U7d0P002U7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<0
07ooOol02Woo000;Ool00`00Oomoo`0/Ool00`00DOAAm00;DO@00`00OZYnZP05OZX00`00Oomoo`0F
Ool00`00DOAAm007DO@3000DDO@00`00OiEoU@02OiD00`00Oomoo`09Ool500054Wd3000;DO@00`00
DOAAm004DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02ao
o`03001Am57d00]Am003001nZWjZ00EnZP03001oogoo01Eoo`03001Am57d00QAm08001EAm003001o
UGnE009oU@03001oogoo00ioo`@000<BO@03001Am57d00UAm003001Am57d00AAm003001o37l<00=o
3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0;7oo00<0057dDO@0357d00<007jZ
OZX017jZ00<007ooOol05Goo00<0057dDO@0257d0P00557d00<007nEOiD00WnE00<007ooOol04goo
10002e7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool0
0`00Oomoo`0/Ool00`00DOAAm00<DO@00`00OZYnZP05OZX00`00Oomoo`0DOol00`00DOAAm007DO@3
000DDO@00`00OiEoU@02OiD00`00Oomoo`0FOol00`00DOAAm009DO@00`00DOAAm004DO@00`00O`ao
3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02aoo`03001Am57d00aAm003
001nZWjZ00EnZP03001oogoo01=oo`03001Am57d00QAm08001EAm003001oUGnE009oU@03001oogoo
01Eoo`03001Am57d00YAm003001Am57d00AAm003001o37l<00=o3003001oogoo00eoo`03001oogoo
00Yoo`002goo00<007ooOol0:goo0P003U7d00<007jZOZX01GjZ00<007ooOol04goo00<0057dDO@0
257d0P005E7d00D007nEOiEoU@0001Qoo`03001Am57d00YAm003001Am57d00AAm003001o37l<00=o
3003001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol0:goo0P003e7d00<007jZOZX01GjZ
00<007ooOol04Woo00<0057dDO@01e7d0`00557d00<007nEOiD00WnE00<007ooOol05Woo00<0057d
DO@02U7d00<0057dDO@0157d00<007l<O``00gl<00<007ooOol03Goo00<007ooOol02Woo000;Ool0
0`00Oomoo`0[Ool2000?DO@00`00OZYnZP05OZX00`00Oomoo`0AOol00`00DOAAm008DO@2000EDO@0
0`00OiEoU@02OiD00`00Oomoo`0FOol00`00DOAAm00;DO@00`00DOAAm003DO@00`00O`ao3003O``0
0`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02]oo`8000mAm003001nZWjZ00EnZP03
001oogoo015oo`03001Am57d00QAm08001EAm005001oUGnEOiD0000HOol00`00DOAAm00<DO@00`00
DOAAm003DO@00`00O`ao3003O``00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo02]o
o`8000mAm003001nZWjZ00EnZP03001oogoo015oo`03001Am57d00MAm0<001AAm003001oUGnE009o
U@03001oogoo01Ioo`03001Am57d00aAm003001Am57d00=Am003001o37l<00=o3003001oogoo00eo
o`03001oogoo00Yoo`002goo00<007ooOol0:goo0P00457d00<007jZOZX01GjZ00<007ooOol03goo
00<0057dDO@0257d0P005E7d00<007nEOiD00WnE00<007ooOol05Goo00@0057d000000aAm003001A
m57d00=Am003001o37l<00Ao3003001oogoo00aoo`03001oogoo00Yoo`002goo00<007ooOol0:goo
00<0057dDO@03e7d00<007jZOZX01GjZ00<007ooOol03goo00<0057dDO@0257d0P005E7d00D007nE
OiEoU@0001Moo`03001Am57d009Am08000YAm003001Am57d00=Am003001o37l<00Ao3003001oogoo
00aoo`03001oogoo00Yoo`002goo00<007ooOol0:goo00<0057dDO@03e7d00<007jZOZX01GjZ00<0
07ooOol03goo00<0057dDO@01e7d0`00557d00<007nEOiD00WnE00<007ooOol057oo00<0057dDO@0
1E7d0P00257d00<0057dDO@00e7d00<007l<O``017l<00<007ooOol037oo00<007ooOol02Woo000;
Ool00`00Oomoo`0[Ool00`00DOAAm00?DO@00`00OZYnZP05OZX00`00Oomoo`0>Ool00`00DOAAm008
DO@2000EDO@00`00OiEoU@02OiD00`00Oomoo`0COol00`00DOAAm008DO@00`00DOAAm005DO@00`00
DOAAm003DO@00`00O`ao3004O``00`00Oomoo`0=Ool00`00Oomoo`09Ool000]oo`03001oogoo02]o
o`03001Am57d011Am003001nZWjZ00EnZP03001oogoo00eoo`03001Am57d00QAm08001EAm005001o
UGnEOiD0000EOol00`00DOAAm00:DO@20005DO@00`00DOAAm003DO@00`00O`ao3004O``00`00Oomo
o`0=Ool00`00Oomoo`09Ool000]oo`03001oogoo02]oo`03001Am57d011Am003001nZWjZ00EnZP03
001oogoo00eoo`03001Am57d00QAm08001AAm003001oUGnE009oU@03001oogoo01=oo`03001Am57d
00aAm08000=Am003001Am57d00=Am003001o37l<00Ao3003001oogoo00eoo`03001oogoo00Uoo`00
2goo00<007ooOol0:goo00<0057dDO@0457d00<007jZOZX01GjZ00<007ooOol037oo00<0057d0000
1@000e7d0`00557d00<007nEOiD00WnE00<007ooOol04Woo00<0057dDO@03e7d0P0000=Am000DO@0
157d00<007l<O``017l<00<007ooOol03Goo00<007ooOol02Goo000;Ool00`00Oomoo`0[Ool00`00
DOAAm00>DO@200000e7d00000006OZX00`00Oomoo`0;Ool20006DO@200000e7d0000000EDO@01@00
OiEoUGnE000057oo00<0057dDO@04U7d0P001E7d00<007l<O``017l<00<007ooOol03Goo00<007oo
Ool02Goo000;Ool00`00Oomoo`0[Ool00`00DOAAm00=DO@00`00DOAAm002DO@30004OZX00`00Oomo
o`0;Ool20007DO@4000DDO@00`00OiEoU@02OiD00`00Oomoo`0AOol00`00DOAAm00DDO@20004DO@0
0`00O`ao3004O``00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03001oogoo02aoo`03001Am57d
00aAm003001Am57d00AAm003001DP00000=nZP03001oogoo00]oo`03001Am57d00QAm08001AAm003
001oUGnE009oU@03001oogoo011oo`03001Am57d01EAm004001Am0000002DO@00`00O`ao3004O``0
0`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03001oogoo02aoo`03001Am57d00YAm08000QAm006
001DP000001nZP0037oo0P002U7d10004U7d00<007nEOiD00WnE00<007ooOol03goo00<0057dDO@0
5U7d00@0057dDOAAm0<000Io3003001oogoo00eoo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo
00<0057dDO@02E7d00<0057dDO@02E7d00<005B0E8000`002goo00<0057dDO@02E7d00<007k]O^d0
0P00457d00<007nEOiD00WnE00<007ooOol03goo00<0057dDO@05e7d00<0057dDO@00e7d00<007l<
O``017l<00<007ooOol03Goo00<007ooOol02Goo000:Ool00`00Oomoo`0/Ool00`00DOAAm008DO@0
0`00DOAAm00;DO@01@00E81DP5B000002goo00<0057dDO@02E7d00@007k]O^enk@8000mAm003001o
UGnE009oU@03001oogoo00ioo`03001Am57d01QAm003001Am57d00=Am08000Eo3003001oogoo00eo
o`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00<0057dDO@01U7d0P003e7d00D005B0E81DP000
00Uoo`8000]Am003001nkGk]00=nk@8000eAm003001oUGnE009oU@03001oogoo00eoo`03001Am57d
01UAm003001Am57d009Am004001o]Gne0004O``00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03
001oogoo02aoo`03001Am57d00EAm003001Am57d011Am005001DP5B0E8000008Ool2000;DO@00`00
O^enk@05O^d00`00DOAAm009DO@00`00OiEoU@02OiD00`00Oomoo`0=Ool00`00DOAAm00JDO@00`00
DOAAm002DO@01000OkEo]Gne0P000Wl<00<007ooOol03Goo00<007ooOol02Goo000:Ool00`00Oomo
o`0/Ool00`00DOAAm004DO@00`00DOAAm00BDO@20002E8000`00Oomoo`05Ool2000:DO@01000LmX0
00001Gk]00<0057dDO@02E7d00<007nEOiD00WnE00<007ooOol03Goo00<0057dDO@06U7d00<0057d
DO@00U7d00<007neOkD00gne00<007l<00003goo00<007ooOol02Goo000:Ool00`00Oomoo`0/Ool0
0`00DOAAm002DO@2000GDO@01000E81DP0001Goo00<0057d00002E7d0P000g?J0P000gk]00<0057d
DO@02E7d00<007nEOiD00WnE00<007ooOol037oo00<0057dDO@06e7d00D0057dDOAAm00000Mo]@80
00moo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo00D0057dDOAAm00001YAm004001DP5B00004
Ool200000e7d001Am007DO@00`00LmYcfP04LmX01@00O^enkGk]00002U7d00D007nEOiEoU@0000io
o`03001Am57d01aAm005001Am57dDO@00008OkD00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03
001oogoo02aoo`04001Am57d000LDO@01000E81DP00017oo1@000e7d0`0027?J0P0000=nk@00DO@0
257d00<007nEOiD00WnE00<007ooOol02goo00<0057dDO@07E7d00D0057dDOAAm00000Qo]@03001o
ogoo00eoo`03001oogoo00Uoo`002Woo00<007ooOol0;7oo0`007U7d00@005B0E80000Eoo`H000<o
O`800003LmX007?J00EcfP8000UAm003001oUGnE009oU@03001oogoo00Yoo`03001Am57d01iAm004
001Am57d0008OkD00`00Oomoo`0>Ool00`00Oomoo`09Ool000Yoo`03001oogoo02aoo`03001Am57d
01mAm004001DP5B00007Ool30005?gl01000DOAcfP0017?J00<0057dDO@0257d00D007nEOiEoU@00
00aoo`03001Am57d01mAm004001Am57d0008OkD00`00Oomoo`0>Ool00`00Oomoo`09Ool000Yoo`03
001oogoo02aoo`03001Am57d021Am004001DP5B00008Ool20005DO@00`00O//00003LmX00`00DOAA
m008DO@00`00OiEoU@02OiD00`00Oomoo`0:Ool2000PDO@00`00DO@00008OkD00`00Oomoo`0?Ool0
0`00Oomoo`09Ool000Yoo`03001oogoo02eoo`03001Am57d021Am004001DP5B00009Ool5DO@01P00
O//00000LmX000]Am003001oUGnE009oU@03001oogoo00Yoo`80021Am003001Am00000Qo]@03001o
ogoo00moo`03001oogoo00Uoo`002Woo00<007ooOol0;Goo00<0057dDO@08E7d00@005B0E80000Qo
o`03001Am57d00=Am004001nb`00000<DO@01@00OiEoUGnE00003Goo00<0057d00007e7d00<0057d
00001gne00<007ooOol047oo00<007ooOol02Goo000:Ool00`00Oomoo`0^Ool00`00DOAAm00QDO@0
1000E81DP00027oo00<0057dDO@00U7d00<007k;00001000257d00<007nEOiD00WnE00<007ooOol0
2goo00@0057dDO@001iAm08000Qo]@03001oogoo011oo`03001oogoo00Uoo`002Woo00<007ooOol0
;Woo00<0057dDO@0857d100000=DP000Ool01Woo1E7d00<007k;000012;n2@0017nE00<007ooOol0
2goo00@0057dDO@001iAm08000Qo]@03001oogoo011oo`03001oogoo00Uoo`002Woo00<007ooOol0
;Woo00<0057dDO@0857d0P000Wl`00<005B000001Woo00<0057dDO@00U7d00<007k;000020001B;n
0P000WnE3Woo00D0057dDOAAm00001eAm08000Mo]@03001oogoo015oo`03001oogoo00Uoo`002Woo
00<007ooOol0;goo00<0057dDO@07U7d00<0057d00000gl`0`001Goo00<0057dDO@00U7d00<007k;
000027oo2@003Woo00<0057dDO@00U7d00<0057dDO@06U7d00<007neOkD01Wne00<007ooOol04Goo
00<007ooOol02Goo000:Ool00`00Oomoo`0_Ool00`00DOAAm00NDO@00`00DO@00005Oc020004Ool0
0`00DOAAm003DO@2000OOol00`00DOAAm003DO@00`00DOAAm00IDO@00`00OkEo]@05OkD00`00Oomo
o`0BOol00`00Oomoo`09Ool000Yoo`03001oogoo02moo`03001Am57d01eAm004001Am57d0007Oc00
1@00Oomoogoo00001E7d00<007k;00000goo0P006Goo00<0057dDO@00e7d00<0057dDO@06E7d00<0
07neOkD01Gne00<007ooOol04Woo00<007ooOol02Goo000:Ool00`00Oomoo`0_Ool2000MDO@01@00
DOAAm57d00001gl`00<007ooOol00Woo00<0057dDO@00U7d00<007k;00000Woo0`006Goo00<0057d
DO@0157d00<0057dDO@05e7d0P001gne00<007ooOol04Woo00<007ooOol02Goo000:Ool00`00Oomo
o`0_Ool2000MDO@01@00DOAAm57d00001gl`00<007ooOol00Woo00<0057dDO@00U7d00<007k;0000
0goo0P006Goo00<0057dDO@01E7d00<0057dDO@05E7d0`001Wne00<007ooOol04goo00<007ooOol0
2Goo000:Ool00`00Oomoo`0_Ool00`00Ool0000KDO@00`00DOAAm002DO@00`00Oc1o<005Oc000`00
Oomoo`02Ool00`00DOAAm002DO@00`00O//00003Ool2000IOol00`00DOAAm005DO@00`00DOAAm00C
DO@20002Emh00`00OkEo]@04OkD00`00Oomoo`0COol00`00Oomoo`09Ool000Yoo`03001oogoo02mo
o`03001oo`0001YAm003001Am57d00=Am003001o<7l`00Eo<003001oogoo009oo`03001Am57d00=A
m08000=oo`8001Uoo`03001Am57d00IAm003001Am57d011Am08000AGgP8000Ao]@03001oogoo01Ao
o`03001oogoo00Uoo`002Woo00<007ooOol0;goo00<007oo00006U7d00<0057dDO@00e7d00<007l`
Oc001Gl`00<007ooOol00Woo00<0057dDO@00e7d0P000goo0P006Goo00<0057dDO@01e7d00<0057d
DO@03E7d0P001UON00@005ON0000009o]@03001oogoo01Aoo`03001oogoo00Uoo`002Woo00<007oo
Ool0;goo00@007ooOol001QAm003001Am57d00AAm003001o<7l`00Eo<003001oogoo009oo`03001A
m57d00=Am003001nb`00009oo`8001Uoo`03001Am57d00MAm003001Am57d00]Am08000QGgP04001G
gUONEmh2000GOol00`00Oomoo`09Ool000Yoo`03001oogoo02moo`04001oogoo000HDO@00`00DOAA
m004DO@00`00Oc1o<005Oc000`00Oomoo`03Ool00`00DOAAm002DO@00`00O//00002Ool2000IOol0
0`00DOAAm008DO@00`00DOAAm008DO@2000:Emh00`00EmiGgP02Emh00`00Oomoo`0EOol00`00Oomo
o`09Ool000Yoo`03001oogoo02moo`05001oogooOol0000FDO@00`00DOAAm005DO@00`00Oc1o<005
Oc000`00Oomoo`03Ool00`00DOAAm002DO@00`00O//00002Ool2000IOol00`00DOAAm009DO@00`00
DOAAm005DO@2000<Emh00`00EmiGgP02000HOol00`00Oomoo`09Ool000Yoo`03001oogoo02moo`04
001oogooOol2000DDO@00`00DOAAm006DO@00`00Oc1o<005Oc000`00Oomoo`03Ool00`00DOAAm003
DO@20002Ool2000IOol00`00DOAAm00:DO@00`00DOAAm002DO@2000>Emh3000JOol00`00Oomoo`09
Ool000Yoo`03001oogoo02moo`03001oogoo009oo`<0019Am003001Am57d00IAm003001o<7l`00Eo
<003001oogoo00=oo`03001Am57d00=Am080009oo`8001Uoo`03001Am57d00YAm003001Am57d0080
00mGgP8001aoo`03001oogoo00Uoo`002Woo00<007ooOol0;goo00<007ooOol017oo10003U7d00<0
057dDO@01e7d00<007l`Oc001Gl`00<007ooOol00goo00<0057dDO@00e7d0P000Woo0P006Goo00<0
057dDO@02e7d0P003eON0P0000=oo`00Ool06goo00<007ooOol02Goo000:Ool00`00Oomoo`0_Ool0
0`00Oomoo`06Ool4000;DO@00`00DOAAm008DO@00`00Oc1o<005Oc000`00Oomoo`03Ool00`00DOAA
m003DO@01000O//007oo0P006Goo00<0057dDO@02e7d0`0035ON0P000goo00<007ooOol06Woo00<0
07ooOol02Goo000:Ool00`00Oomoo`0_Ool00`00Oomoo`08Ool50008DO@00`00DOAAm008DO@00`00
Oc1o<005Oc000`00Oomoo`04Ool00`00DOAAm002DO@01000O//007oo0P006Goo00<0057dDO@02e7d
00@007l]Obd000UGgP8000Eoo`03001oogoo01Yoo`03001oogoo00Uoo`002Woo00<007ooOol0;goo
00<007ooOol02Woo1P00157d00<0057dDO@02E7d00<007l`Oc001Gl`00<007ooOol017oo00<0057d
DO@00U7d00@007k;001oo`8001Uoo`03001Am57d00]Am005001o;Gl]Obd00006Emh20007Ool00`00
Oomoo`0KOol00`00Oomoo`08Ool000Yoo`03001oogoo02moo`03001oogoo00eoo`D0009Am003001A
m57d00UAm003001o<7l`00Eo<003001oogoo00Aoo`03001Am57d00=Am0800003Ool0000001Uoo`03
001Am57d00]Am003001o;Gl]009o;@80009GgP8000Uoo`03001oogoo01]oo`03001oogoo00Qoo`00
2Woo00<007ooOol0;goo00<007ooOol047oo1000357d00<007l`Oc001Gl`00<007ooOol017oo00<0
057dDO@00e7d0P0000=oo`0000006Goo00<0057dDO@02e7d00<007l]Obd017l]0P002goo00<007oo
Ool06goo00<007ooOol027oo0009Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@0
0`00Oc1o<005Oc000`00Oomoo`04Ool00`00DOAAm003DO@200000goo0000000IOol00`00DOAAm00;
DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`08Ool000Uoo`03001o
ogoo031oo`03001oogoo01=oo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00Eoo`03001A
m57d009Am003001nb`00008001Uoo`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03
001oogoo01]oo`03001oogoo00Qoo`002Goo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@0
2U7d00<007l`Oc001Gl`00<007ooOol01Goo00<0057dDO@00U7d1@006Goo00<0057dDO@02e7d00<0
07l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007ooOol027oo0009Ool00`00Oomoo`0`
Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`05Ool00`00DOAAm003
DO@4000IOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00
Oomoo`08Ool000Uoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003001o<7l`00Eo
<003001oogoo00Eoo`03001Am57d00=Am0@001Uoo`03001Am57d00]Am003001o;Gl]00Ao;@03001o
ogoo00Yoo`03001oogoo01]oo`03001oogoo00Qoo`002Goo00<007ooOol0<7oo00<007ooOol04goo
00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol01Goo00<0057dDO@00e7d10006Goo00<0057d
DO@02e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009Ool0
0`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00Oomoo`05Ool0
0`00DOAAm003DO@4000IOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomo
o`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003
001o<7l`00Eo<003001oogoo00Ioo`03001Am57d009Am0@001Uoo`03001Am57d00]Am003001o;Gl]
00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0<7oo00<0
07ooOol04goo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol01Woo00<0057dDO@00e7d0`00
6Goo00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol0
27oo0009Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<005Oc000`00
Oomoo`06Ool00`00DOAAm003DO@3000IOol00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0;
Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo031oo`03001oogoo01=oo`03001A
m57d00YAm003001o<7l`00Eo<003001oogoo00Ioo`03001Am57d00=Am0<001Uoo`03001Am57d00]A
m003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007oo
Ool0<7oo00<007ooOol04goo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol01Woo00<0057d
DO@00e7d0`006Goo00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo
00<007ooOol027oo0009Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o
<005Oc000`00Oomoo`06Ool00`00DOAAm003DO@3000IOol00`00DOAAm00;DO@00`00Obeo;@04Obd0
0`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo031oo`03001oogoo
01=oo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00Moo`03001Am57d00=Am08001Uoo`03
001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`00
2Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@02U7d00<007l`Oc001Gl`00<007ooOol0
1goo00<0057dDO@00e7d0P006Goo00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02goo00<0
07ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm00:
DO@00`00Oc1o<005Oc000`00Oomoo`07Ool00`00DOAAm003DO@2000IOol00`00DOAAm00;DO@00`00
Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo02mo
o`03001oogoo01Aoo`03001Am57d00YAm003001o<7l`00Eo<003001oogoo00Moo`03001Am57d00=A
m08001Uoo`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001o
ogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@02U7d00<007l`Oc001Gl`
00<007ooOol00Woo7@002Goo00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02goo00<007oo
Ool06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm00:DO@0
0`00Oc1o<002Oc080003?G@00`00GSEN=@0CGSD01000M]=fdgKC1`000Woo00<0057dDO@02e7d00<0
07l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_
Ool00`00Oomoo`0DOol00`00DOAAm00:DO@5000;?G@00`00GSEN=@0CGSD00`00M]=fd`08M]<4000<
DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001o
ogoo02moo`03001oogoo01Aoo`03001Am57d00YAm003000mM3ed00dmM003001N=Ehe01=N=@03001f
dgKC00]fd`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001o
ogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@02E7d0P003ced00<005he
GSD04ehe00<007KCM]<02gKC00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007oo
Ool06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm009DO@2
000??G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomo
o`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo02moo`03001oogoo01Aoo`03
001Am57d00UAm08000lmM003001N=Ehe01=N=@03001fdgKC00]fd`03001Am57d00YAm003001o;Gl]
00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0;goo00<0
07ooOol057oo00<0057dDO@02E7d0P0000<mM000?G@033ed00<005heGSD04ehe00<007KCM]<02gKC
00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo
0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm009DO@6000;?G@00`00GSEN=@0CGSD0
0`00M]=fd`0;M]<00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol0
0`00Oomoo`08Ool000Uoo`03001oogoo02moo`03001oogoo01Aoo`03001Am57d00UAm0T000PmM003
001N=Ehe01=N=@03001fdgKC00]fd`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03
001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@0
2E7d0`000Sed1P001Sed00<005heGSD04ehe00<007KCM]<02gKC00<0057dDO@02U7d00<007l]Obd0
17l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00
Oomoo`0DOol00`00DOAAm009DO@20006?G@50004?G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<00`00
DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uo
o`03001oogoo02moo`03001oogoo01Aoo`03001Am57d00UAm08000PmM0H00003?G@005he01AN=@03
001fdgKC00]fd`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03
001oogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo00<0057dDO@02E7d0P002Sed1P00
5Ehe00<007KCM]<02gKC00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol0
6Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool00`00Oomoo`0DOol00`00DOAAm009DO@2000=
?G@4000DGSD00`00M]=fd`0;M]<00`00DOAAm00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00
Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03001oogoo02moo`03001oogoo01Aoo`03001Am57d00UA
m08000lmM003001N=Ehe01=N=@03001fdgKC00]fd`03001Am57d00YAm003001o;Gl]00Ao;@03001o
ogoo00]oo`03001oogoo01Yoo`03001oogoo00Qoo`002Goo00<007ooOol0;goo00<007ooOol057oo
00<0057dDO@02E7d0P003ced00<005heGSD04ehe00<007KCM]<02gKC00<0057dDO@02U7d00<007l]
Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol027oo0009Ool00`00Oomoo`0_Ool0
0`00Oomoo`0DOol00`00DOAAm009DO@2000??G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<00`00DOAA
m00:DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`08Ool000Uoo`03
001oogoo02moo`03001oogoo01Aoo`03001Am57d00UAm08000lmM003001N=Ehe01=N=@03001fdgKC
00]fd`03001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo
00Qoo`0027oo00<007ooOol0<7oo00<007ooOol057oo00<0057dDO@02E7d0P003ced00<005heGSD0
4ehe00<007KCM]<02gKC00<0057dDO@02U7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol0
6goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0DOol00`00DOAAm009DO@2000?
?G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<00`00DOAAm00;DO@00`00Obeo;@03Obd00`00Oomoo`0;
Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01Aoo`03001A
m57d00UAm08000lmM003001N=Ehe01=N=@03001fdgKC00]fd`03001Am57d00]Am003001o;Gl]00=o
;@03001oogoo00]oo`03001oogoo01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007oo
Ool057oo00<0057dDO@02E7d0P003ced00<005heGSD04ehe00<007KCM]<02gKC00<0057dDO@02e7d
00<007l]Obd00gl]00<007ooOol02goo00<007ooOol06goo00<007ooOol01goo0008Ool00`00Oomo
o`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@2000??G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<0
0`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`07Ool0
00Qoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm08000lmM003001N=Ehe01=N=@03
001fdgKC00]fd`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01]oo`03
001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d0P003ced00<0
05heGSD04ehe00<007KCM]<02gKC00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<0
07ooOol06goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:
DO@2000??G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<00`00DOAAm00;DO@00`00Obeo;@04Obd00`00
Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01=o
o`03001Am57d00YAm08000lmM003001N=Ehe01=N=@03001fdgKC00]fd`03001Am57d00]Am003001o
;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo
00<007ooOol04goo00<0057dDO@02U7d0P003ced00<005heGSD04ehe00<007KCM]<02gKC00<0057d
DO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007ooOol01goo0008Ool0
0`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@2000??G@00`00GSEN=@0CGSD00`00M]=f
d`0;M]<00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomo
o`07Ool000Qoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm08000lmM003001N=Ehe
01=N=@03001fdgKC00]fd`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo
01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d0P00
3ced00<005heGSD04ehe00<007KCM]<02gKC00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol0
2Woo00<007ooOol06goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00
DOAAm00:DO@2000??G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<00`00DOAAm00;DO@00`00Obeo;@04
Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001o
ogoo01=oo`03001Am57d00YAm08000lmM003001N=Ehe01=N=@03001fdgKC00]fd`03001Am57d00]A
m003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01]oo`03001oogoo00Moo`0027oo00<007oo
Ool0<7oo00<007ooOol04goo00<0057dDO@02U7d0P003ced00<005heGSD04ehe00<007KCM]<02gKC
00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007ooOol01goo
0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@2000??G@00`00GSEN=@0CGSD0
0`00M]=fd`0;M]<00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol0
0`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm08000lmM003
001N=Ehe01=N=@03001fdgKC00]fd`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03
001oogoo01]oo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@0
2U7d0P003ced00<005heGSD04ehe00<007KCM]<02gKC00<0057dDO@02e7d00<007l]Obd017l]00<0
07ooOol02Woo00<007ooOol06goo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0C
Ool00`00DOAAm00:DO@2000??G@00`00GSEN=@0CGSD00`00M]=fd`0;M]<00`00DOAAm00;DO@00`00
Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomoo`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031o
o`03001oogoo01=oo`03001Am57d00YAm08000lmM003001N=Ehe01=N=@03001fdgKC00]fd`03001A
m57d00]Am003001o;Gl]00Ao;@03001oogoo00Yoo`03001oogoo01]oo`03001oogoo00Moo`0027oo
00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d0P003ced00<005heGSD04ehe00<007KC
M]<02gKC00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02Woo00<007ooOol06goo00<007oo
Ool01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@2000??G@00`00GSEN
=@0CGSD00`00M]=fd`0;M]<00`00DOAAm00;DO@00`00Obeo;@04Obd00`00Oomoo`0:Ool00`00Oomo
o`0KOol00`00Oomoo`07Ool000Qoo`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm080
00`mM1d000Yfd`03001Am57d00]Am003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03
001oogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d0P0013ed2000
2akl0P0041kl1`000gKC00<0057dDO@02e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol0
6Woo00<007ooOol01goo0008Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@6000/
7_`4000=DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Qo
o`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003000No1kl01LNo003000No1kl01LN
o08000eAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Moo`0027oo
00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d00<001kl7_`05Qkl0`005akl00<007oo
00003E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol01goo0008Ool0
0`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm00:DO@00`00Oc1o<004Oc0B00000akl000No00<
7_`>000=DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Qo
o`03001oogoo031oo`03001oogoo01=oo`03001Am57d00YAm003001o<7l`00Io<003001oogoo009o
oaX000iAm003001Am57d00YAm003001o;Gl]00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001o
ogoo00Moo`0027oo00<007ooOol0<7oo00<007ooOol04goo00<0057dDO@02U7d3P00:E7d00<0057d
DO@02E7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo00<007ooOol01goo0008Ool0
0`00Oomoo`0`Ool00`00Oomoo`0COol00`00DOAAm009DO@00`00DOAAm00fDO@00`00DOAAm008DO@0
0`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Qoo`03001oogoo
031oo`03001oogoo01=oo`03001Am57d00QAm003001Am57d03QAm003001Am57d00MAm003001o;Gl]
00Ao;@03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00Moo`0027oo00<007ooOol0<7oo00<0
07ooOol04goo00<0057dDO@01e7d00<0057dDO@0>U7d00<0057dDO@01U7d00<007l]Obd017l]00<0
07ooOol02goo00<007ooOol06Woo00<007ooOol01goo0008Ool00`00Oomoo`0_Ool00`00Oomoo`0D
Ool00`00DOAAm006DO@00`00DOAAm00lDO@00`00DOAAm005DO@00`00Obeo;@04Obd00`00Oomoo`0;
Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Qoo`03001oogoo02moo`03001oogoo01Aoo`03001A
m57d00EAm003001Am57d03iAm003001Am57d00AAm003001o;Gl]00Ao;@03001oogoo00]oo`03001o
ogoo01Yoo`03001oogoo00Moo`001goo00<007ooOol0<7oo00<007ooOol057oo00<0057dDO@0157d
00<0057dDO@0@57d00<0057dDO@00e7d00<007l]Obd017l]00<007ooOol02goo00<007ooOol06Woo
00<007ooOol01goo0007Ool00`00Oomoo`0`Ool00`00Oomoo`0DOol00`00DOAAm003DO@00`00DOAA
m012DO@00`00DOAAm002DO@00`00Obeo;@04Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomo
o`07Ool000Moo`03001oogoo031oo`03001oogoo01Aoo`03001Am57d00=Am003001Am57d04=Am005
001Am57dDO@00006Obd00`00Oomoo`0;Ool00`00Oomoo`0JOol00`00Oomoo`07Ool000Moo`03001o
ogoo031oo`03001oogoo01Aoo`03001Am57d009Am003001Am57d04EAm004001Am57d0006Obd00`00
Oomoo`0;Ool00`00Oomoo`0KOol00`00Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo01Ao
o`05001Am57dDO@00019DO@00`00DO@00006Obd00`00Oomoo`0;Ool00`00Oomoo`0KOol00`00Oomo
o`06Ool000Moo`03001oogoo031oo`03001oogoo01Aoo`04001Am57d001;DO@20006Obd00`00Oomo
o`0;Ool00`00Oomoo`0KOol00`00Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo01Aoo`03
001Am00003YAm1D000Eo;@03001oogoo00]oo`03001oogoo01]oo`03001oogoo00Ioo`001goo00<0
07ooOol0<7oo00<007ooOol057oo0P004e7d:0005AKK100000=o;@00Ool037oo00<007ooOol06goo
00<007ooOol01Woo0007Ool00`00Oomoo`0`Ool00`00Oomoo`0DOolE00115]/2000=Ool00`00Oomo
o`0KOol00`00Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo01Moo`D001HFfbH0025oo`03
001oogoo01]oo`03001oogoo00Ioo`001goo00<007ooOol0<7oo00<007ooOol077oo5P00Agoo00<0
07ooOol06goo00<007ooOol01Woo0007Ool00`00Oomoo`0`Ool00`00Oomoo`1iOol00`00Oomoo`0K
Ool00`00Oomoo`06Ool000Moo`03001oogoo031oo`03001oogoo07Uoo`03001oogoo01]oo`03001o
ogoo00Ioo`001goo00<007ooOol0<7oo00<007ooOol0NGoo00<007ooOol06goo00<007ooOol01Woo
0007Ool00`00Oomoo`0`Ool00`00Oomoo`1TOolG000LOol00`00Oomoo`06Ool000Moo`03001oogoo
031oo`03001oogoo03Qoob`001Moo`@001Qoo`03001oogoo00Ioo`001goo00<007ooOol0<7oo00<0
07ooOol037oo;000Agoo100057oo00<007ooOol01Woo0007Ool00`00Oomoo`0COol/001gOol4000@
Ool00`00Oomoo`06Ool000MooaH001eoo`03001oogoo08Moo`<000eoo`03001oogoo00Ioo`002goo
1`00:7oo00<007ooOol0RWoo10002Goo00<007ooOol01Woo000BOol8000POol00`00Oomoo`2>Ool4
0005Ool00`00Oomoo`06Ool001Yoo`L001Uoo`03001oogoo099oo`@00003Ool007oo00Moo`008Goo
1`004Woo00<007ooOol0OWoo6P0027oo000XOol8000:Ool00`00Oomoo`1;Oolc000ROol0031oo`L0
00=oo`03001oogoo01Mooc@005Eoo`00=goo7@00RGoo003MOol00=eoo`00gGoo003MOol00=eoo`00
gGoo003MOol00=eoo`00\
\>"],
  ImageRangeCache->{{{0, 220}, {299, 0}} -> {0.122254, -0.0271372, 0.00330748,
   0.00330748}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following code generates the graphics in this section. These ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands are defined in Chapter 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
pl1={{-3, 5,0},{-3,11,0},{ 3,11,0},{ 3, 5,0},{ 4.4,4.4,0},
     { 5, 3,0},{ 5,-5,0},{-5,-5,0},{-5, 3,0},{-4.4,4.4,0},
     {-3, 5,0}};
pl2=Join[{{2,10,0},{-2,10,0}},
  Table[{4 Cos[i], 4 Sin[i],0},
    {i, 120 N[Degree], 420 N[Degree], 30 N[Degree]}],
  {{2,10,0}}];
pl3={{pl2[[2]],pl2[[3]],pl1[[1]],pl1[[2]]},
     {pl2[[2]],pl1[[2]],pl1[[3]],pl2[[1]]}};
pl3=Join[pl3,{Map[#*{-1,1,1}&,pl3[[1]]],
 {pl2[[4]],pl2[[3]],pl1[[-1]],pl1[[-2]],pl1[[-3]]},
 {pl2[[5]],pl2[[4]],pl1[[-3]],{-5,0,0}},
 {pl2[[6]],pl2[[5]],{-5,0,0},pl1[[8]]},
 {pl2[[7]],pl2[[6]],pl1[[8]]},
 {pl2[[8]],pl2[[7]],pl1[[8]],{0,-5,0}}}];
pl3=Join[pl3,Map[#*{-1,1,1}&,Take[pl3,-5],{2}]];

p1=Graphics3D[{
  {Extrude[pl1,{0,0,-1},2],
   Extrude[pl2,{0,0,-1},2],
   Polygon/@pl3},
  {PointSize[.02],Thickness[.01],
  Point[{0,0,0}],Point[{0,0,5}],Point[{3,0,0}],
  Point[{0,4,0}],Point[{0,9,0}],
  Line[{{0,0,0},{0,0,5}}],
  Line[{{0,0,0},{3,0,0}}],
  Line[{{0,4,0},{0,9,0}}]}},
    PlotRange->{{-6,6},{-6,12},{-3,6}},
    ViewPoint->{1,.7,3},ViewVertical->{0,1,0}];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t1=Graphics3D[\n  {Text[\"P1\", {0,0,0},{0 ,-1.8}],\n   Text[\"P2\", \
{0,0,5},{.6,-2.2}],\n   Text[\"P3\", {3,0,0},{0 , 1.8}],\n   Text[\"P4\", \
{0,4,0},{0 , 1.8}],\n   Text[\"P5\", {0,9,0},{0 ,-1.8}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g1=Show[{p1,t1}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"pl1=Join[{{0,1.3,-1}},\n  Table[{3.5 Cos[i],3.5 Sin[i],-1},\n    {i,90 \
N[Degree], 270 N[Degree], 30 N[Degree]}],\n    {{0   \
,-1.3,-1},{3.25,-1.3,-1},{3.5, 0  ,-1},\n     {3.25, 1.3,-1},{0   , \
1.3,-1}}];\npl2={Take[pl1,-5],Take[pl1,{2,8}]};\npl1=Point[2,#]&/@pl1;\n\
p2=Graphics3D[{\n  {Extrude[pl1,{0,0,-1},1],\n   Facet[2,#]&/@pl2},\n  \
{PointSize[.02],Thickness[.01],\n  Vertex[2,{{0,0,0},{0,0,5},{3,0,0}}],\n  \
Edge[2,{{3,0,0},{0,0,0},{0,0,5}}]}},\n    PlotRange->{{-6,6},{-6,6},{-3,6}},\n\
    ViewPoint->{1,.7,3},ViewVertical->{0,1,0}];\np3=Graphics3D[{\n  \
Bar[Line[2,{3,0,-1},{3,0,0}],.5,8]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t2=Graphics3D[{Text[\"P1\", {0,0,0},{.6 ,-2.0}],\n               \
Text[\"P2\", {0,0,5},{.6 ,-2.2}],\n               Text[\"P3\", \
{3,0,0},{2.0,-2.0}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g2=Show[{p2, p3, t2}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p3=Graphics3D[{\n  {Bar[Line[piston,{0,3,0},{0,6,0}],2.,8]},\n  \
{PointSize[.02],Thickness[.01],\n  Edge[  \
piston,{{0,4,5.8},{0,4,0},{0,6.4,0}}],\n  \
Vertex[piston,{{0,4,5.8},{0,4,0},{0,6.4,0}}]}},\n    \
PlotRange->{{-6,6},{0,9},{-3,6}},\n    \
ViewPoint->{1,.7,3},ViewVertical->{0,1,0}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t3=Graphics3D[{Text[\"P1\", {0,4,0},{-.3,0}],\n               Text[\"P2\", \
{0,6.4,0},{0,-2.0}],\n               Text[\"P3\", {0,4,5.8},{0, 2.0}]}];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g3=Show[{p3, t3}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p4=Graphics3D[{Bar[Line[2,{3,0, 0},3,{0,4,0}],.3, 4,\n               \
Angle->{45 N[Degree], 405 N[Degree]}],\n               \
Bar[Line[2,{3,0,-1},{3,0,1}],.5, 8]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{p1,p2,p3,p4}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[{g1,g2,g3},Frame->True,\n  GraphicsSpacing->0]];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{448, 652},
WindowMargins->{{123, Automatic}, {Automatic, 16}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 84, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1840, 57, 78, 2, 47, "Subsection"],
Cell[1921, 61, 2174, 63, 303, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4132, 129, 130, 3, 33, "Section",
  PageBreakAbove->True],
Cell[4265, 134, 365, 13, 52, "Text"],

Cell[CellGroupData[{
Cell[4655, 151, 94, 2, 47, "Subsection"],
Cell[4752, 155, 1841, 65, 189, "Text"],

Cell[CellGroupData[{
Cell[6618, 224, 471, 14, 88, "Special3"],
Cell[7092, 240, 216, 8, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[7323, 251, 446, 11, 91, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7806, 267, 167, 6, 32, "Subsection"],
Cell[7976, 275, 85, 2, 43, "Subsubsection"],
Cell[8064, 279, 497, 21, 53, "Text"],
Cell[8564, 302, 202, 5, 104, "Special3"],
Cell[8769, 309, 182, 8, 18, "Special4",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[8976, 321, 188, 8, 28, "SmallText"],
Cell[9167, 331, 84, 2, 30, "Input"]
}, Open  ]],
Cell[9266, 336, 1182, 38, 171, "Text"],
Cell[10451, 376, 91, 2, 43, "Subsubsection"],
Cell[10545, 380, 1251, 42, 152, "Text"],

Cell[CellGroupData[{
Cell[11821, 426, 308, 12, 28, "SmallText"],
Cell[12132, 440, 158, 4, 70, "Input"]
}, Open  ]],
Cell[12305, 447, 157, 6, 43, "Subsubsection"],
Cell[12465, 455, 621, 24, 73, "Text"],
Cell[13089, 481, 621, 23, 101, "Special3"],
Cell[13713, 506, 183, 8, 18, "Special4",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[13921, 518, 280, 12, 28, "SmallText"],
Cell[14204, 532, 69, 2, 30, "Input"]
}, Open  ]],
Cell[14288, 537, 937, 37, 94, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15274, 580, 110, 3, 33, "Section",
  PageBreakAbove->True],
Cell[15387, 585, 643, 16, 111, "Text"],

Cell[CellGroupData[{
Cell[16055, 605, 98, 2, 47, "Subsection"],
Cell[16156, 609, 268, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[16449, 624, 176, 8, 28, "SmallText"],
Cell[16628, 634, 84, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16749, 641, 126, 2, 28, "SmallText"],
Cell[16878, 645, 31556, 1229, 308, 11841, 980, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[48449, 1877, 315, 6, 71, "Text"],
Cell[48767, 1885, 95, 2, 43, "Subsubsection"],
Cell[48865, 1889, 211, 4, 76, "Special1"],
Cell[49079, 1895, 1006, 21, 223, "Text"],

Cell[CellGroupData[{
Cell[50110, 1920, 144, 4, 28, "SmallText"],
Cell[50257, 1926, 135, 4, 70, "Input"]
}, Open  ]],
Cell[50407, 1933, 429, 7, 90, "Text"],
Cell[50839, 1942, 100, 2, 43, "Subsubsection"],
Cell[50942, 1946, 818, 15, 185, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[51797, 1966, 89, 2, 31, "Subsection"],
Cell[51889, 1970, 89, 2, 43, "Subsubsection"],
Cell[51981, 1974, 178, 4, 52, "Text"],
Cell[52162, 1980, 300, 6, 59, "Special1"],

Cell[CellGroupData[{
Cell[52487, 1990, 116, 2, 28, "SmallText"],
Cell[52606, 1994, 25149, 1147, 295, 6959, 917, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[77770, 3144, 93, 2, 43, "Subsubsection"],
Cell[77866, 3148, 159, 4, 33, "Text"],
Cell[78028, 3154, 340, 8, 59, "Special1"],

Cell[CellGroupData[{
Cell[78393, 3166, 115, 2, 28, "SmallText"],
Cell[78511, 3170, 16190, 983, 190, 6186, 854, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[94716, 4156, 79, 2, 43, "Subsubsection"],
Cell[94798, 4160, 321, 6, 71, "Text"],
Cell[95122, 4168, 243, 5, 59, "Special1"],

Cell[CellGroupData[{
Cell[95390, 4177, 111, 2, 28, "SmallText"],
Cell[95504, 4181, 13730, 861, 144, 5487, 754, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[109283, 5048, 94, 2, 31, "Subsection"],
Cell[109380, 5052, 498, 12, 92, "Text"],
Cell[109881, 5066, 101, 2, 43, "Subsubsection"],
Cell[109985, 5070, 244, 5, 52, "Text"],
Cell[110232, 5077, 1703, 69, 208, "Special3"],
Cell[111938, 5148, 130, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[112071, 5153, 1407, 47, 207, "Text"],
Cell[113481, 5202, 101, 2, 43, "Subsubsection"],
Cell[113585, 5206, 306, 10, 53, "Text"],
Cell[113894, 5218, 660, 18, 94, "Special1"],
Cell[114557, 5238, 495, 15, 61, "Special1"],
Cell[115055, 5255, 506, 13, 77, "Special1"],
Cell[115564, 5270, 471, 11, 77, "Special1"],
Cell[116038, 5283, 321, 12, 54, "Text"],
Cell[116362, 5297, 464, 17, 55, "Special3"],
Cell[116829, 5316, 143, 3, 18, "Special4",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[116997, 5323, 136, 3, 28, "SmallText"],
Cell[117136, 5328, 446, 10, 190, "Input"]
}, Open  ]],
Cell[117597, 5341, 519, 19, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[118153, 5365, 97, 2, 31, "Subsection"],
Cell[118253, 5369, 358, 13, 53, "Text"],

Cell[CellGroupData[{
Cell[118636, 5386, 268, 8, 55, "Special3"],
Cell[118907, 5396, 142, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[119086, 5404, 198, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[119309, 5416, 103, 3, 45, "Input"],
Cell[119415, 5421, 127, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[119569, 5427, 919, 33, 94, "Text"],

Cell[CellGroupData[{
Cell[120513, 5464, 199, 8, 24, "SmallText"],
Cell[120715, 5474, 25763, 1214, 295, 7302, 981, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[146493, 6691, 947, 25, 170, "Text"],

Cell[CellGroupData[{
Cell[147465, 6720, 204, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[147694, 6732, 100, 2, 45, "Input"],
Cell[147797, 6736, 237, 4, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[148061, 6744, 558, 16, 92, "Text"],
Cell[148622, 6762, 206, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[148853, 6774, 100, 2, 45, "Input"],
Cell[148956, 6778, 232, 4, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149225, 6787, 205, 8, 24, "SmallText"],
Cell[149433, 6797, 25960, 1216, 295, 7369, 981, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175430, 8018, 292, 12, 24, "SmallText"],
Cell[175725, 8032, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[175843, 8040, 91, 2, 31, "Subsection"],
Cell[175937, 8044, 259, 8, 53, "Text"],
Cell[176199, 8054, 465, 15, 241, "Input"],
Cell[176667, 8071, 318, 6, 133, "Input"],
Cell[176988, 8079, 104, 2, 25, "Input"],
Cell[177095, 8083, 480, 8, 223, "Input"],
Cell[177578, 8093, 272, 5, 79, "Input"],
Cell[177853, 8100, 114, 2, 25, "Input"],
Cell[177970, 8104, 377, 7, 187, "Input"],
Cell[178350, 8113, 280, 5, 84, "Input"],
Cell[178633, 8120, 114, 2, 30, "Input"],
Cell[178750, 8124, 170, 4, 66, "Input"],
Cell[178923, 8130, 124, 2, 30, "Input"],
Cell[179050, 8134, 153, 4, 48, "Input"],
Cell[179206, 8140, 153, 4, 48, "Input"],
Cell[179362, 8146, 127, 2, 30, "Input"],
Cell[179492, 8150, 85, 2, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[179626, 8158, 120, 3, 33, "Section",
  PageBreakAbove->True],
Cell[179749, 8163, 889, 28, 132, "Text"],

Cell[CellGroupData[{
Cell[180663, 8195, 98, 2, 47, "Subsection"],
Cell[180764, 8199, 578, 20, 73, "Text"],

Cell[CellGroupData[{
Cell[181367, 8223, 188, 8, 28, "SmallText"],
Cell[181558, 8233, 84, 2, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181679, 8240, 127, 2, 28, "SmallText"],
Cell[181809, 8244, 76984, 2798, 295, 36406, 2292, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[258808, 11045, 405, 11, 72, "Text"],
Cell[259216, 11058, 95, 2, 43, "Subsubsection"],
Cell[259314, 11062, 211, 4, 76, "Special1"],
Cell[259528, 11068, 1005, 21, 223, "Text"],

Cell[CellGroupData[{
Cell[260558, 11093, 132, 3, 28, "SmallText"],
Cell[260693, 11098, 135, 4, 70, "Input"]
}, Open  ]],
Cell[260843, 11105, 435, 7, 90, "Text"],
Cell[261281, 11114, 100, 2, 43, "Subsubsection"],
Cell[261384, 11118, 807, 15, 204, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[262228, 11138, 89, 2, 31, "Subsection"],
Cell[262320, 11142, 89, 2, 43, "Subsubsection"],
Cell[262412, 11146, 167, 4, 33, "Text"],
Cell[262582, 11152, 699, 18, 127, "Special1"],

Cell[CellGroupData[{
Cell[263306, 11174, 232, 5, 44, "SmallText"],
Cell[263541, 11181, 45949, 1131, 295, 7781, 655, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[309505, 12315, 93, 2, 43, "Subsubsection"],
Cell[309601, 12319, 159, 4, 33, "Text"],
Cell[309763, 12325, 541, 13, 93, "Special1"],

Cell[CellGroupData[{
Cell[310329, 12342, 209, 4, 44, "SmallText"],
Cell[310541, 12348, 24676, 790, 217, 6544, 561, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[335232, 13141, 79, 2, 43, "Subsubsection"],
Cell[335314, 13145, 353, 6, 71, "Text"],
Cell[335670, 13153, 424, 12, 76, "Special1"],

Cell[CellGroupData[{
Cell[336119, 13169, 201, 4, 44, "SmallText"],
Cell[336323, 13175, 17813, 516, 178, 3907, 339, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[354185, 13697, 94, 2, 31, "Subsection"],
Cell[354282, 13701, 500, 12, 92, "Text"],
Cell[354785, 13715, 101, 2, 43, "Subsubsection"],
Cell[354889, 13719, 240, 5, 52, "Text"],
Cell[355132, 13726, 2352, 91, 254, "Special3"],
Cell[357487, 13819, 130, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[357620, 13824, 1633, 58, 226, "Text"],
Cell[359256, 13884, 101, 2, 43, "Subsubsection"],
Cell[359360, 13888, 302, 10, 53, "Text"],
Cell[359665, 13900, 1030, 31, 128, "Special1"],
Cell[360698, 13933, 867, 19, 129, "Special1"],
Cell[361568, 13954, 768, 26, 94, "Special1"],
Cell[362339, 13982, 546, 12, 94, "Special1"],
Cell[362888, 13996, 597, 17, 77, "Special1"],
Cell[363488, 14015, 321, 12, 54, "Text"],
Cell[363812, 14029, 539, 21, 55, "Special3"],
Cell[364354, 14052, 143, 3, 18, "Special4",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[364522, 14059, 137, 3, 28, "SmallText"],
Cell[364662, 14064, 708, 14, 270, "Input"]
}, Open  ]],
Cell[365385, 14081, 507, 19, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[365929, 14105, 97, 2, 31, "Subsection"],
Cell[366029, 14109, 279, 9, 53, "Text"],
Cell[366311, 14120, 268, 8, 55, "Special3"],
Cell[366582, 14130, 142, 3, 18, "Special4",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[366749, 14137, 198, 8, 28, "SmallText"],

Cell[CellGroupData[{
Cell[366972, 14149, 104, 3, 50, "Input"],
Cell[367079, 14154, 259, 4, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[367365, 14162, 1929, 59, 267, "Text"],

Cell[CellGroupData[{
Cell[369319, 14225, 156, 4, 28, "SmallText"],
Cell[369478, 14231, 78815, 2821, 308, 36406, 2292, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[448308, 17055, 970, 25, 170, "Text"],

Cell[CellGroupData[{
Cell[449303, 17084, 204, 8, 28, "SmallText"],

Cell[CellGroupData[{
Cell[449532, 17096, 100, 2, 50, "Input"],
Cell[449635, 17100, 397, 6, 86, "Output"]
}, Open  ]]
}, Open  ]],
Cell[450059, 17110, 578, 18, 92, "Text"],

Cell[CellGroupData[{
Cell[450662, 17132, 206, 8, 28, "SmallText"],

Cell[CellGroupData[{
Cell[450893, 17144, 115, 3, 50, "Input"],
Cell[451011, 17149, 402, 6, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[451462, 17161, 213, 8, 28, "SmallText"],
Cell[451678, 17171, 73635, 2513, 308, 30813, 1979, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[525350, 19689, 190, 8, 28, "SmallText"],
Cell[525543, 19699, 69, 2, 30, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[525661, 19707, 91, 2, 31, "Subsection"],
Cell[525755, 19711, 259, 8, 53, "Text"],
Cell[526017, 19721, 1101, 32, 565, "Input"],
Cell[527121, 19755, 281, 5, 115, "Input"],
Cell[527405, 19762, 92, 2, 30, "Input"],
Cell[527500, 19766, 685, 11, 318, "Input"],
Cell[528188, 19779, 230, 5, 66, "Input"],
Cell[528421, 19786, 110, 2, 30, "Input"],
Cell[528534, 19790, 369, 8, 138, "Input"],
Cell[528906, 19800, 228, 5, 66, "Input"],
Cell[529137, 19807, 106, 2, 30, "Input"],
Cell[529246, 19811, 242, 5, 66, "Input"],
Cell[529491, 19818, 108, 2, 30, "Input"],
Cell[529602, 19822, 146, 4, 48, "Input"],
Cell[529751, 19828, 85, 2, 30, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

