(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    263673,      11088]*)
(*NotebookOutlinePosition[    264615,      11120]*)
(*  CellTagsIndexPosition[    264571,      11116]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["2.  Kinematic Modeling", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers the building and running of basic kinematic models \
with ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  ". Throughout this chapter the simplest and most commonly used forms of \
each ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " command are presented. For more detailed information on specific \
commands, consult the reference guide in the appendix.\n\n",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " follows most of the conventions set by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as to its use of function names, options, and option settings. One \
significant deviation from standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " practice is that ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " often uses the same name for an option and for the name of a function \
that performs a service related to the option. For example, ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the name of an option that is used to set the values of local point \
coordinates, and it is also the name of a function that returns the local \
point coordinates."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1  Body Objects", "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " data object that is used to define the points and properties of a \
mechanism body. It is not necessary to u",
  StyleBox["se body ob",
    FontFamily->"Times"],
  "jects in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " kinematic models, as demonstrated in Sections 1.2 and 1.3, but the u",
  StyleBox["se of body object",
    FontFamily->"Times"],
  "s allows points to be defined once, inside ",
  StyleBox["the body obj",
    FontFamily->"Times"],
  "ect, and then to be referenced throughout the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. This can reduce the likelihood of error due to changing the \
definition of a point at one place on the model, while failing to change it \
elsewhere."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Body ", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects are created by the ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, and used to define specific properties of a body in a mechanism \
model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Body[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object that contains properties of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " (a positive integer). Each property of the body is specified with an \
option. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["A function to define body objects.", "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts three options for defining inertia properties of a body: ",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These options will be discussed further in Section 8.1. The options for \
",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that are relevant in the kinematic phase of analysis are the ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["2D", "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointList \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["xn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["yn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the local coordinates of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " points on the body. The points are referenced by their local point number \
",
  StyleBox["n",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["InitialGuess \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Th",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets numeric initial guesses. An initial guess of {{0, 0}, 0} corresponds \
to alignment with the global coordinate system."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "2D options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D", "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointList \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["z1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["xn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["yn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["zn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the local coordinates of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " points on the body. The points are referenced by their local point number \
",
  StyleBox["n",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["InitialGuess \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Eo",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ei",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ej",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ek",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets numeric initial guesses for a 3D body. A guess of {{0, 0, 0}, {1, 0, \
0, 0}} corresponds to alignment with the global coordinate system."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "3D options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["2D/3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointList \[Rule] Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves the existing points on the body unchanged.\n\n",
  StyleBox["InitialGuess \[Rule] Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the guesses for a new body such that it is aligned with the global \
coordinate system, or leaves the guesses for an existing body unchanged."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Default option settings for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Executing the ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function does not, in itself, have any affect on the current ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. The returned body objects must be added to the model with the ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, which is discussed in the next subsection. \n\nInitial guesses \
specified with a body object are referred to as the permanent initial \
guesses. These initial guesses are used the first time that a solution is \
sought with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Each subsequent solution attempt uses the previous solution as its \
initial guess. When the initial guesses are set with ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", they may be explicitly set to user-specified values, or reset to the \
stored values of the permanent initial guesses. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Example"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The 2D example mechanism of Section 1.2 can be modified to use three body \
objects instead of repeatedly calling out the several local point coordinates \
on the ground, crankshaft, and piston bodies. These body objects store the \
local point definitions for future reference, through their integer point \
numbers, by other ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the crankshaft-piston mechanism bodies. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .5 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0119048 0.31746 [
[ -0.001 -0.001 0 0 ]
[ 1.001 .501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 .5 L
s
P
P
p
p
.002 w
0 .5 m
1 .5 L
s
P
p
.002 w
1 0 m
1 .5 L
s
P
P
p
P
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0119048 0.34127 0.488095 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(-5)] -0.0125 .08333 1 0 Msboxa
[(-2.5)] -0.0125 .29167 1 0 Msboxa
[(0)] -0.0125 .5 1 0 Msboxa
[(2.5)] -0.0125 .70833 1 0 Msboxa
[(5)] -0.0125 .91667 1 0 Msboxa
[(7.5)] -0.0125 1.125 1 0 Msboxa
[(10)] -0.0125 1.33333 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(-5)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .29167 m
.00625 .29167 L
s
P
[(-2.5)] -0.0125 .29167 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(0)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .70833 m
.00625 .70833 L
s
P
[(2.5)] -0.0125 .70833 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(5)] -0.0125 .91667 1 0 Mshowa
p
.002 w
0 1.125 m
.00625 1.125 L
s
P
[(7.5)] -0.0125 1.125 1 0 Mshowa
p
.002 w
0 1.33333 m
.00625 1.33333 L
s
P
[(10)] -0.0125 1.33333 1 0 Mshowa
p
.001 w
0 .125 m
.00375 .125 L
s
P
p
.001 w
0 .16667 m
.00375 .16667 L
s
P
p
.001 w
0 .20833 m
.00375 .20833 L
s
P
p
.001 w
0 .25 m
.00375 .25 L
s
P
p
.001 w
0 .33333 m
.00375 .33333 L
s
P
p
.001 w
0 .375 m
.00375 .375 L
s
P
p
.001 w
0 .41667 m
.00375 .41667 L
s
P
p
.001 w
0 .45833 m
.00375 .45833 L
s
P
p
.001 w
0 .54167 m
.00375 .54167 L
s
P
p
.001 w
0 .58333 m
.00375 .58333 L
s
P
p
.001 w
0 .625 m
.00375 .625 L
s
P
p
.001 w
0 .66667 m
.00375 .66667 L
s
P
p
.001 w
0 .75 m
.00375 .75 L
s
P
p
.001 w
0 .79167 m
.00375 .79167 L
s
P
p
.001 w
0 .83333 m
.00375 .83333 L
s
P
p
.001 w
0 .875 m
.00375 .875 L
s
P
p
.001 w
0 .95833 m
.00375 .95833 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.04167 m
.00375 1.04167 L
s
P
p
.001 w
0 1.08333 m
.00375 1.08333 L
s
P
p
.001 w
0 1.16667 m
.00375 1.16667 L
s
P
p
.001 w
0 1.20833 m
.00375 1.20833 L
s
P
p
.001 w
0 1.25 m
.00375 1.25 L
s
P
p
.001 w
0 1.29167 m
.00375 1.29167 L
s
P
p
.001 w
0 .04167 m
.00375 .04167 L
s
P
p
.001 w
0 1.375 m
.00375 1.375 L
s
P
p
.001 w
0 1.41667 m
.00375 1.41667 L
s
P
p
.001 w
0 1.45833 m
.00375 1.45833 L
s
P
p
.002 w
0 0 m
0 1.5 L
s
P
P
p
p
.002 w
0 1.49375 m
0 1.5 L
s
P
p
.002 w
.16667 1.49375 m
.16667 1.5 L
s
P
p
.002 w
.33333 1.49375 m
.33333 1.5 L
s
P
p
.002 w
.5 1.49375 m
.5 1.5 L
s
P
p
.002 w
.66667 1.49375 m
.66667 1.5 L
s
P
p
.002 w
.83333 1.49375 m
.83333 1.5 L
s
P
p
.001 w
.03333 1.49625 m
.03333 1.5 L
s
P
p
.001 w
.06667 1.49625 m
.06667 1.5 L
s
P
p
.001 w
.1 1.49625 m
.1 1.5 L
s
P
p
.001 w
.13333 1.49625 m
.13333 1.5 L
s
P
p
.001 w
.2 1.49625 m
.2 1.5 L
s
P
p
.001 w
.23333 1.49625 m
.23333 1.5 L
s
P
p
.001 w
.26667 1.49625 m
.26667 1.5 L
s
P
p
.001 w
.3 1.49625 m
.3 1.5 L
s
P
p
.001 w
.36667 1.49625 m
.36667 1.5 L
s
P
p
.001 w
.4 1.49625 m
.4 1.5 L
s
P
p
.001 w
.43333 1.49625 m
.43333 1.5 L
s
P
p
.001 w
.46667 1.49625 m
.46667 1.5 L
s
P
p
.001 w
.53333 1.49625 m
.53333 1.5 L
s
P
p
.001 w
.56667 1.49625 m
.56667 1.5 L
s
P
p
.001 w
.6 1.49625 m
.6 1.5 L
s
P
p
.001 w
.63333 1.49625 m
.63333 1.5 L
s
P
p
.001 w
.7 1.49625 m
.7 1.5 L
s
P
p
.001 w
.73333 1.49625 m
.73333 1.5 L
s
P
p
.001 w
.76667 1.49625 m
.76667 1.5 L
s
P
p
.001 w
.8 1.49625 m
.8 1.5 L
s
P
p
.001 w
.86667 1.49625 m
.86667 1.5 L
s
P
p
.001 w
.9 1.49625 m
.9 1.5 L
s
P
p
.001 w
.93333 1.49625 m
.93333 1.5 L
s
P
p
.001 w
.96667 1.49625 m
.96667 1.5 L
s
P
p
.002 w
0 1.5 m
1 1.5 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .29167 m
1 .29167 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .70833 m
1 .70833 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.002 w
.99375 1.125 m
1 1.125 L
s
P
p
.002 w
.99375 1.33333 m
1 1.33333 L
s
P
p
.001 w
.99625 .125 m
1 .125 L
s
P
p
.001 w
.99625 .16667 m
1 .16667 L
s
P
p
.001 w
.99625 .20833 m
1 .20833 L
s
P
p
.001 w
.99625 .25 m
1 .25 L
s
P
p
.001 w
.99625 .33333 m
1 .33333 L
s
P
p
.001 w
.99625 .375 m
1 .375 L
s
P
p
.001 w
.99625 .41667 m
1 .41667 L
s
P
p
.001 w
.99625 .45833 m
1 .45833 L
s
P
p
.001 w
.99625 .54167 m
1 .54167 L
s
P
p
.001 w
.99625 .58333 m
1 .58333 L
s
P
p
.001 w
.99625 .625 m
1 .625 L
s
P
p
.001 w
.99625 .66667 m
1 .66667 L
s
P
p
.001 w
.99625 .75 m
1 .75 L
s
P
p
.001 w
.99625 .79167 m
1 .79167 L
s
P
p
.001 w
.99625 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .875 m
1 .875 L
s
P
p
.001 w
.99625 .95833 m
1 .95833 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.04167 m
1 1.04167 L
s
P
p
.001 w
.99625 1.08333 m
1 1.08333 L
s
P
p
.001 w
.99625 1.16667 m
1 1.16667 L
s
P
p
.001 w
.99625 1.20833 m
1 1.20833 L
s
P
p
.001 w
.99625 1.25 m
1 1.25 L
s
P
p
.001 w
.99625 1.29167 m
1 1.29167 L
s
P
p
.001 w
.99625 .04167 m
1 .04167 L
s
P
p
.001 w
.99625 1.375 m
1 1.375 L
s
P
p
.001 w
.99625 1.41667 m
1 1.41667 L
s
P
p
.001 w
.99625 1.45833 m
1 1.45833 L
s
P
p
.002 w
1 0 m
1 1.5 L
s
P
P
p
P
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
p
p
p
.5 .5 .5 r
.08333 .08333 m
.08333 .75 L
.25 .75 L
.25 1.41667 L
.75 1.41667 L
.75 .75 L
.91667 .75 L
.91667 .08333 L
F
.004 w
.25 .75 m
.25 .75 .16667 0 365.73 arc
F
.75 .75 m
.75 .75 .16667 0 365.73 arc
F
P
p
1 1 1 r
.004 w
.5 .5 m
.5 .5 .33333 0 365.73 arc
F
.33333 .5 m
.33333 1.33333 L
.66667 1.33333 L
.66667 .5 L
F
P
p
.01 w
.5 .83333 m
.5 1.25 L
s
.025 w
.5 .5 Mdot
.5 .83333 Mdot
.5 1.25 Mdot
P
P
p
[({0,0})] .5 .5 0 -1.7 Mshowa
[(P1)] .5 .5 1.7 1 Mshowa
[({0,4})] .5 .83333 0 1.7 Mshowa
[(P2)] .5 .83333 1.7 -1 Mshowa
[({0,9})] .5 1.25 0 -1.7 Mshowa
[(P3)] .5 1.25 1.7 1 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.34127 0.0119048 0.65873 0.488095 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(-5)] -0.0125 .08333 1 0 Msboxa
[(-2.5)] -0.0125 .29167 1 0 Msboxa
[(0)] -0.0125 .5 1 0 Msboxa
[(2.5)] -0.0125 .70833 1 0 Msboxa
[(5)] -0.0125 .91667 1 0 Msboxa
[(7.5)] -0.0125 1.125 1 0 Msboxa
[(10)] -0.0125 1.33333 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(-5)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .29167 m
.00625 .29167 L
s
P
[(-2.5)] -0.0125 .29167 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(0)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .70833 m
.00625 .70833 L
s
P
[(2.5)] -0.0125 .70833 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(5)] -0.0125 .91667 1 0 Mshowa
p
.002 w
0 1.125 m
.00625 1.125 L
s
P
[(7.5)] -0.0125 1.125 1 0 Mshowa
p
.002 w
0 1.33333 m
.00625 1.33333 L
s
P
[(10)] -0.0125 1.33333 1 0 Mshowa
p
.001 w
0 .125 m
.00375 .125 L
s
P
p
.001 w
0 .16667 m
.00375 .16667 L
s
P
p
.001 w
0 .20833 m
.00375 .20833 L
s
P
p
.001 w
0 .25 m
.00375 .25 L
s
P
p
.001 w
0 .33333 m
.00375 .33333 L
s
P
p
.001 w
0 .375 m
.00375 .375 L
s
P
p
.001 w
0 .41667 m
.00375 .41667 L
s
P
p
.001 w
0 .45833 m
.00375 .45833 L
s
P
p
.001 w
0 .54167 m
.00375 .54167 L
s
P
p
.001 w
0 .58333 m
.00375 .58333 L
s
P
p
.001 w
0 .625 m
.00375 .625 L
s
P
p
.001 w
0 .66667 m
.00375 .66667 L
s
P
p
.001 w
0 .75 m
.00375 .75 L
s
P
p
.001 w
0 .79167 m
.00375 .79167 L
s
P
p
.001 w
0 .83333 m
.00375 .83333 L
s
P
p
.001 w
0 .875 m
.00375 .875 L
s
P
p
.001 w
0 .95833 m
.00375 .95833 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.04167 m
.00375 1.04167 L
s
P
p
.001 w
0 1.08333 m
.00375 1.08333 L
s
P
p
.001 w
0 1.16667 m
.00375 1.16667 L
s
P
p
.001 w
0 1.20833 m
.00375 1.20833 L
s
P
p
.001 w
0 1.25 m
.00375 1.25 L
s
P
p
.001 w
0 1.29167 m
.00375 1.29167 L
s
P
p
.001 w
0 .04167 m
.00375 .04167 L
s
P
p
.001 w
0 1.375 m
.00375 1.375 L
s
P
p
.001 w
0 1.41667 m
.00375 1.41667 L
s
P
p
.001 w
0 1.45833 m
.00375 1.45833 L
s
P
p
.002 w
0 0 m
0 1.5 L
s
P
P
p
p
.002 w
0 1.49375 m
0 1.5 L
s
P
p
.002 w
.16667 1.49375 m
.16667 1.5 L
s
P
p
.002 w
.33333 1.49375 m
.33333 1.5 L
s
P
p
.002 w
.5 1.49375 m
.5 1.5 L
s
P
p
.002 w
.66667 1.49375 m
.66667 1.5 L
s
P
p
.002 w
.83333 1.49375 m
.83333 1.5 L
s
P
p
.001 w
.03333 1.49625 m
.03333 1.5 L
s
P
p
.001 w
.06667 1.49625 m
.06667 1.5 L
s
P
p
.001 w
.1 1.49625 m
.1 1.5 L
s
P
p
.001 w
.13333 1.49625 m
.13333 1.5 L
s
P
p
.001 w
.2 1.49625 m
.2 1.5 L
s
P
p
.001 w
.23333 1.49625 m
.23333 1.5 L
s
P
p
.001 w
.26667 1.49625 m
.26667 1.5 L
s
P
p
.001 w
.3 1.49625 m
.3 1.5 L
s
P
p
.001 w
.36667 1.49625 m
.36667 1.5 L
s
P
p
.001 w
.4 1.49625 m
.4 1.5 L
s
P
p
.001 w
.43333 1.49625 m
.43333 1.5 L
s
P
p
.001 w
.46667 1.49625 m
.46667 1.5 L
s
P
p
.001 w
.53333 1.49625 m
.53333 1.5 L
s
P
p
.001 w
.56667 1.49625 m
.56667 1.5 L
s
P
p
.001 w
.6 1.49625 m
.6 1.5 L
s
P
p
.001 w
.63333 1.49625 m
.63333 1.5 L
s
P
p
.001 w
.7 1.49625 m
.7 1.5 L
s
P
p
.001 w
.73333 1.49625 m
.73333 1.5 L
s
P
p
.001 w
.76667 1.49625 m
.76667 1.5 L
s
P
p
.001 w
.8 1.49625 m
.8 1.5 L
s
P
p
.001 w
.86667 1.49625 m
.86667 1.5 L
s
P
p
.001 w
.9 1.49625 m
.9 1.5 L
s
P
p
.001 w
.93333 1.49625 m
.93333 1.5 L
s
P
p
.001 w
.96667 1.49625 m
.96667 1.5 L
s
P
p
.002 w
0 1.5 m
1 1.5 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .29167 m
1 .29167 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .70833 m
1 .70833 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.002 w
.99375 1.125 m
1 1.125 L
s
P
p
.002 w
.99375 1.33333 m
1 1.33333 L
s
P
p
.001 w
.99625 .125 m
1 .125 L
s
P
p
.001 w
.99625 .16667 m
1 .16667 L
s
P
p
.001 w
.99625 .20833 m
1 .20833 L
s
P
p
.001 w
.99625 .25 m
1 .25 L
s
P
p
.001 w
.99625 .33333 m
1 .33333 L
s
P
p
.001 w
.99625 .375 m
1 .375 L
s
P
p
.001 w
.99625 .41667 m
1 .41667 L
s
P
p
.001 w
.99625 .45833 m
1 .45833 L
s
P
p
.001 w
.99625 .54167 m
1 .54167 L
s
P
p
.001 w
.99625 .58333 m
1 .58333 L
s
P
p
.001 w
.99625 .625 m
1 .625 L
s
P
p
.001 w
.99625 .66667 m
1 .66667 L
s
P
p
.001 w
.99625 .75 m
1 .75 L
s
P
p
.001 w
.99625 .79167 m
1 .79167 L
s
P
p
.001 w
.99625 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .875 m
1 .875 L
s
P
p
.001 w
.99625 .95833 m
1 .95833 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.04167 m
1 1.04167 L
s
P
p
.001 w
.99625 1.08333 m
1 1.08333 L
s
P
p
.001 w
.99625 1.16667 m
1 1.16667 L
s
P
p
.001 w
.99625 1.20833 m
1 1.20833 L
s
P
p
.001 w
.99625 1.25 m
1 1.25 L
s
P
p
.001 w
.99625 1.29167 m
1 1.29167 L
s
P
p
.001 w
.99625 .04167 m
1 .04167 L
s
P
p
.001 w
.99625 1.375 m
1 1.375 L
s
P
p
.001 w
.99625 1.41667 m
1 1.41667 L
s
P
p
.001 w
.99625 1.45833 m
1 1.45833 L
s
P
p
.002 w
1 0 m
1 1.5 L
s
P
P
p
P
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
p
p
p
1 .6 .6 r
.004 w
.5 .5 m
.5 .5 .3125 90 270 arc
F
.5 .5 m
.5 .5 .3125 -20.0535 20.0535 arc
F
p
.5 .39167 m
.79583 .39167 L
.79583 .60833 L
.5 .60833 L
F
P
P
p
1 .4 .4 r
.004 w
.5 .5 m
.5 .5 .05833 0 365.73 arc
F
.75 .5 m
.75 .5 .04167 0 365.73 arc
F
P
p
.025 w
.5 .5 Mdot
p
.75 .5 Mdot
P
P
P
p
[({0,0})] .5 .5 0 1.7 Mshowa
[(P1)] .5 .5 0 -1.7 Mshowa
[({3,0})] .75 .5 0 1.7 Mshowa
[(P2)] .75 .5 0 -1.7 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.65873 0.0119048 0.97619 0.488095 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0833333 0.5 0.0833333 [
[(-4)] .16667 0 0 2 Msboxa
[(-2)] .33333 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(2)] .66667 0 0 2 Msboxa
[(4)] .83333 0 0 2 Msboxa
[(6)] 1 0 0 2 Msboxa
[(-5)] -0.0125 .08333 1 0 Msboxa
[(-2.5)] -0.0125 .29167 1 0 Msboxa
[(0)] -0.0125 .5 1 0 Msboxa
[(2.5)] -0.0125 .70833 1 0 Msboxa
[(5)] -0.0125 .91667 1 0 Msboxa
[(7.5)] -0.0125 1.125 1 0 Msboxa
[(10)] -0.0125 1.33333 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(-4)] .16667 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(-2)] .33333 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(2)] .66667 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(4)] .83333 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(6)] 1 0 0 2 Mshowa
p
.001 w
.03333 0 m
.03333 .00375 L
s
P
p
.001 w
.06667 0 m
.06667 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.13333 0 m
.13333 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.23333 0 m
.23333 .00375 L
s
P
p
.001 w
.26667 0 m
.26667 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43333 0 m
.43333 .00375 L
s
P
p
.001 w
.46667 0 m
.46667 .00375 L
s
P
p
.001 w
.53333 0 m
.53333 .00375 L
s
P
p
.001 w
.56667 0 m
.56667 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73333 0 m
.73333 .00375 L
s
P
p
.001 w
.76667 0 m
.76667 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.86667 0 m
.86667 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.93333 0 m
.93333 .00375 L
s
P
p
.001 w
.96667 0 m
.96667 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(-5)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .29167 m
.00625 .29167 L
s
P
[(-2.5)] -0.0125 .29167 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(0)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .70833 m
.00625 .70833 L
s
P
[(2.5)] -0.0125 .70833 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(5)] -0.0125 .91667 1 0 Mshowa
p
.002 w
0 1.125 m
.00625 1.125 L
s
P
[(7.5)] -0.0125 1.125 1 0 Mshowa
p
.002 w
0 1.33333 m
.00625 1.33333 L
s
P
[(10)] -0.0125 1.33333 1 0 Mshowa
p
.001 w
0 .125 m
.00375 .125 L
s
P
p
.001 w
0 .16667 m
.00375 .16667 L
s
P
p
.001 w
0 .20833 m
.00375 .20833 L
s
P
p
.001 w
0 .25 m
.00375 .25 L
s
P
p
.001 w
0 .33333 m
.00375 .33333 L
s
P
p
.001 w
0 .375 m
.00375 .375 L
s
P
p
.001 w
0 .41667 m
.00375 .41667 L
s
P
p
.001 w
0 .45833 m
.00375 .45833 L
s
P
p
.001 w
0 .54167 m
.00375 .54167 L
s
P
p
.001 w
0 .58333 m
.00375 .58333 L
s
P
p
.001 w
0 .625 m
.00375 .625 L
s
P
p
.001 w
0 .66667 m
.00375 .66667 L
s
P
p
.001 w
0 .75 m
.00375 .75 L
s
P
p
.001 w
0 .79167 m
.00375 .79167 L
s
P
p
.001 w
0 .83333 m
.00375 .83333 L
s
P
p
.001 w
0 .875 m
.00375 .875 L
s
P
p
.001 w
0 .95833 m
.00375 .95833 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.04167 m
.00375 1.04167 L
s
P
p
.001 w
0 1.08333 m
.00375 1.08333 L
s
P
p
.001 w
0 1.16667 m
.00375 1.16667 L
s
P
p
.001 w
0 1.20833 m
.00375 1.20833 L
s
P
p
.001 w
0 1.25 m
.00375 1.25 L
s
P
p
.001 w
0 1.29167 m
.00375 1.29167 L
s
P
p
.001 w
0 .04167 m
.00375 .04167 L
s
P
p
.001 w
0 1.375 m
.00375 1.375 L
s
P
p
.001 w
0 1.41667 m
.00375 1.41667 L
s
P
p
.001 w
0 1.45833 m
.00375 1.45833 L
s
P
p
.002 w
0 0 m
0 1.5 L
s
P
P
p
p
.002 w
0 1.49375 m
0 1.5 L
s
P
p
.002 w
.16667 1.49375 m
.16667 1.5 L
s
P
p
.002 w
.33333 1.49375 m
.33333 1.5 L
s
P
p
.002 w
.5 1.49375 m
.5 1.5 L
s
P
p
.002 w
.66667 1.49375 m
.66667 1.5 L
s
P
p
.002 w
.83333 1.49375 m
.83333 1.5 L
s
P
p
.001 w
.03333 1.49625 m
.03333 1.5 L
s
P
p
.001 w
.06667 1.49625 m
.06667 1.5 L
s
P
p
.001 w
.1 1.49625 m
.1 1.5 L
s
P
p
.001 w
.13333 1.49625 m
.13333 1.5 L
s
P
p
.001 w
.2 1.49625 m
.2 1.5 L
s
P
p
.001 w
.23333 1.49625 m
.23333 1.5 L
s
P
p
.001 w
.26667 1.49625 m
.26667 1.5 L
s
P
p
.001 w
.3 1.49625 m
.3 1.5 L
s
P
p
.001 w
.36667 1.49625 m
.36667 1.5 L
s
P
p
.001 w
.4 1.49625 m
.4 1.5 L
s
P
p
.001 w
.43333 1.49625 m
.43333 1.5 L
s
P
p
.001 w
.46667 1.49625 m
.46667 1.5 L
s
P
p
.001 w
.53333 1.49625 m
.53333 1.5 L
s
P
p
.001 w
.56667 1.49625 m
.56667 1.5 L
s
P
p
.001 w
.6 1.49625 m
.6 1.5 L
s
P
p
.001 w
.63333 1.49625 m
.63333 1.5 L
s
P
p
.001 w
.7 1.49625 m
.7 1.5 L
s
P
p
.001 w
.73333 1.49625 m
.73333 1.5 L
s
P
p
.001 w
.76667 1.49625 m
.76667 1.5 L
s
P
p
.001 w
.8 1.49625 m
.8 1.5 L
s
P
p
.001 w
.86667 1.49625 m
.86667 1.5 L
s
P
p
.001 w
.9 1.49625 m
.9 1.5 L
s
P
p
.001 w
.93333 1.49625 m
.93333 1.5 L
s
P
p
.001 w
.96667 1.49625 m
.96667 1.5 L
s
P
p
.002 w
0 1.5 m
1 1.5 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .29167 m
1 .29167 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .70833 m
1 .70833 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.002 w
.99375 1.125 m
1 1.125 L
s
P
p
.002 w
.99375 1.33333 m
1 1.33333 L
s
P
p
.001 w
.99625 .125 m
1 .125 L
s
P
p
.001 w
.99625 .16667 m
1 .16667 L
s
P
p
.001 w
.99625 .20833 m
1 .20833 L
s
P
p
.001 w
.99625 .25 m
1 .25 L
s
P
p
.001 w
.99625 .33333 m
1 .33333 L
s
P
p
.001 w
.99625 .375 m
1 .375 L
s
P
p
.001 w
.99625 .41667 m
1 .41667 L
s
P
p
.001 w
.99625 .45833 m
1 .45833 L
s
P
p
.001 w
.99625 .54167 m
1 .54167 L
s
P
p
.001 w
.99625 .58333 m
1 .58333 L
s
P
p
.001 w
.99625 .625 m
1 .625 L
s
P
p
.001 w
.99625 .66667 m
1 .66667 L
s
P
p
.001 w
.99625 .75 m
1 .75 L
s
P
p
.001 w
.99625 .79167 m
1 .79167 L
s
P
p
.001 w
.99625 .83333 m
1 .83333 L
s
P
p
.001 w
.99625 .875 m
1 .875 L
s
P
p
.001 w
.99625 .95833 m
1 .95833 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.04167 m
1 1.04167 L
s
P
p
.001 w
.99625 1.08333 m
1 1.08333 L
s
P
p
.001 w
.99625 1.16667 m
1 1.16667 L
s
P
p
.001 w
.99625 1.20833 m
1 1.20833 L
s
P
p
.001 w
.99625 1.25 m
1 1.25 L
s
P
p
.001 w
.99625 1.29167 m
1 1.29167 L
s
P
p
.001 w
.99625 .04167 m
1 .04167 L
s
P
p
.001 w
.99625 1.375 m
1 1.375 L
s
P
p
.001 w
.99625 1.41667 m
1 1.41667 L
s
P
p
.001 w
.99625 1.45833 m
1 1.45833 L
s
P
p
.002 w
1 0 m
1 1.5 L
s
P
P
p
P
0 0 m
1 0 L
1 1.5 L
0 1.5 L
closepath
clip
newpath
p
p
p
.7 .7 1 r
.35 .70833 m
.65 .70833 L
.65 1 L
.35 1 L
F
P
p
.6 .6 1 r
.004 w
.5 .83333 m
.5 .83333 .03333 0 365.73 arc
F
P
p
p
.01 w
.5 .83333 m
.5 1 L
s
P
p
.025 w
.5 .83333 Mdot
.5 1 Mdot
P
P
P
p
[({0,4})] .5 .83333 0 1.7 Mshowa
[(P1)] .5 .83333 1.7 -1 Mshowa
[({0,6})] .5 1 0 -1.7 Mshowa
[(P2)] .5 1 1.7 1 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{479, 239},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007O0000ka000`40O003h00Oogooh7oo00000goo
0000003o003K0002Ool00003Ool007oo0?moomYoo`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@00
0Goo0Goo00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo0?moomYoo`40005oo`5oo`00
00=oo`00Ool0ogoofWoo0@000Goo0Goo00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo
0?moomYoo`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@000Goo0Goo00000goo001oo`3oOooJOol1
0001Ool1Ool00003Ool007oo0?moomYoo`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@000Goo0Goo
00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo0?moomYoo`40005oo`5oo`0000=oo`00
Ool0ogoofWoo0@000Goo0Goo00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo0?moomYo
o`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@000Goo0Goo00000goo001oo`3oOooJOol10001Ool1
Ool00003Ool007oo03Ioo`<0015oo`<0015oo`03001oogoo015oo`<001=oo`<0015oo`8002moo`<0
015oo`<0015oo`03001oogoo015oo`<001=oo`<0015oo`8002ioo`<0015oo`<0015oo`03001oogoo
015oo`<001=oo`<0015oo`8000ioo`40005oo`5oo`0000=oo`00Ool0=goo00<007ooOol047oo00<0
07ooOol047oo00<007oo00004Woo00<007ooOol057oo00<007ooOol047oo00<007oo0000;goo00<0
07ooOol047oo00<007ooOol047oo00<007oo00004Woo00<007ooOol057oo00<007ooOol047oo00<0
07oo0000;Woo00<007ooOol047oo00<007ooOol047oo00<007oo00004Woo00<007ooOol057oo00<0
07ooOol047oo00<007oo00003Goo0@000Goo0Goo00000goo001oo`0`Ool30002Ool4000<Ool30003
Ool00`00Oomoo`0?Ool00`00Ool0000COol00`00Oomoo`0AOol4000AOol00`00Ool0000XOol30002
Ool4000<Ool30003Ool00`00Oomoo`0?Ool00`00Ool0000COol00`00Oomoo`0AOol4000AOol00`00
Ool0000WOol30002Ool4000<Ool30003Ool00`00Oomoo`0?Ool00`00Ool0000COol00`00Oomoo`0A
Ool4000AOol00`00Ool0000=Ool10001Ool1Ool00003Ool007oo03Eoo`03001oo`0001=oo`03001o
ogoo00moo`03001oo`0001=oo`03001oogoo015oo`03001oo`00019oo`8002ioo`03001oo`0001=o
o`03001oogoo00moo`03001oo`0001=oo`03001oogoo015oo`03001oo`00019oo`8002eoo`03001o
o`0001=oo`03001oogoo00moo`03001oo`0001=oo`03001oogoo015oo`03001oo`00019oo`8000io
o`40005oo`5oo`0000=oo`00Ool0=Woo0P004Woo00<007oo000047oo00<007oo00004Woo00<007oo
00004goo0P004Woo00<007ooOol0;Woo0P004Woo00<007oo000047oo00<007oo00004Woo00<007oo
00004goo0P004Woo00<007ooOol0;Goo0P004Woo00<007oo000047oo00<007oo00004Woo00<007oo
00004goo0P004Woo00<007ooOol03Goo0@000Goo0Goo00000goo001oo`0gOol00`00Oomoo`0AOol0
0`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol2000_Ool00`00Oomo
o`0AOol00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol2000^Ool0
0`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0AOol2
000=Ool10001Ool1Ool00003Ool007oo0?moomYoo`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@00
0Goo0Goo00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo0?moomYoo`40005oo`5oo`00
00=oo`00Ool0ogoofWoo0@000Goo0Goo00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo
0?moomYoo`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@000Goo0Goo00000goo001oo`0OOon0000G
Oomo000GOon0000=Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo07aoo`03001oogoo01Eo
o`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`00
00=oo`00Ool07goo00<007ooOol0O7oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo
00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`1lOol0
0`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool1
0001Ool1Ool00003Ool007oo01moo`03001oogoo07aoo`03001oogoo01Eoo`03001oogoo07]oo`03
001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo0P00
O7oo0P005goo00<007ooOol0Ngoo00<007ooOol05Goo0P00O7oo0P003Goo0@000Goo0Goo00000goo
001oo`0OOol00`00Oomoo`1lOol00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00
Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo07aoo`03001o
ogoo01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005o
o`5oo`0000=oo`00Ool06goo00D007ooOomoo`0007ioo`03001oogoo011oo`03001oogoo009oo`03
001oogoo07]oo`03001oogoo015oo`05001oogooOol0001nOol00`00Oomoo`0;Ool10001Ool1Ool0
0003Ool007oo01Yoo`03001oo`00009oo`03001oogoo07aoo`03001oogoo00moo`03001oo`0000=o
o`03001oogoo07]oo`03001oogoo011oo`03001oo`00009oo`03001oogoo07aoo`03001oogoo00]o
o`40005oo`5oo`0000=oo`00Ool05Goo0`0017oo00<007ooOol00P00O7oo0P0037oo0`0017oo00@0
07ooOomoo`8007]oo`8000eoo`<000Aoo`03001oogoo008007aoo`8000eoo`40005oo`5oo`0000=o
o`00Ool06Woo0P000goo00<007ooOol027ooJCg_2goo00<007ooOol03goo0P0017oo00<007ooOol0
Ngoo00<007ooOol047oo0P000goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo
001oo`0JOol00`00Oomoo`02Ool00`00Oomoo`08OomY?Nl;Ool00`00Oomoo`0?Ool00`00Oomoo`03
Ool00`00Oomoo`1kOol00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`1lOol00`00Oomoo`0;
Ool10001Ool1Ool00003Ool007oo01Yoo`<0009oo`03001oogoo00QoofTmk`]oo`03001oogoo00mo
o`<000=oo`03001oogoo07]oo`03001oogoo011oo`<0009oo`03001oogoo07aoo`03001oogoo00]o
o`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol027ooJCg_2goo00<007ooOol05Goo00<007oo
Ool0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001o
o`0OOol20009OomY?Nl:Ool2000GOol00`00Oomoo`1kOol00`00Oomoo`0EOol2001lOol2000=Ool1
0001Ool1Ool00003Ool007oo01moo`03001oogoo00QoofTmk`]oo`03001oogoo01Eoo`03001oogoo
07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool0
7goo00<007ooOol027ooJCg_2goo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<0
07ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08OomY?Nl;
Ool00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;
Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00QoofTmk`]oo`03001oogoo01Eoo`03001o
ogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00
Ool07goo00<007ooOol027ooJCg_2goo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo
00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol20009OomY?Nl:Ool2
000GOol00`00Oomoo`1kOol00`00Oomoo`0EOol2001lOol2000=Ool10001Ool1Ool00003Ool007oo
01moo`03001oogoo00Qoob/mka=oob/mk`]oo`03001oogoo01Eoo`03001oogoo07]oo`03001oogoo
01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol0
27oo9cg_6goo9cg_2goo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0
O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08OolU?NlOOolU?Nl;
Ool00`00Oomoo`0EOol00`00Oomoo`0hOol4OW<oOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00
Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00Qoob4mkbMoob4mk`]oo`03001o
ogoo01Eoo`03001oogoo039oo`YnLcmoo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]o
o`40005oo`5oo`0000=oo`00Ool07goo0P002Goo7cg_:goo7cg_2Woo0P005goo00<007ooOol0;goo
3Gic?goo00<007ooOol05Goo0P00O7oo0P003Goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomo
o`08OolN?Nl]OolN?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0[OolAOW<oOol00`00Oomoo`0EOol0
0`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00Qooadm
kbmooadmk`]oo`03001oogoo01Eoo`03001oogoo02Uooa=nLcmoo`03001oogoo01Eoo`03001oogoo
07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol027oo73g_<Goo73g_
2goo00<007ooOol05Goo00<007ooOol0:7oo57ic?goo00<007ooOol05Goo00<007ooOol0O7oo00<0
07ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08OolJ?NleOolJ?Nl;Ool00`00
Oomoo`0EOol00`00Oomoo`0VOolFOW<oOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;
Ool10001Ool1Ool00003Ool007oo01moo`8000UooaTmkcMooaTmk`Yoo`8001Moo`03001oogoo02Ao
oaQnLcmoo`03001oogoo01Eoo`8007aoo`8000eoo`40005oo`5oo`0000=oo`00Ool07goo00<007oo
Ool027oo63g_>Goo63g_2goo00<007ooOol05Goo00<007ooOol08goo6Gic?goo00<007ooOol05Goo
00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08OolG
?NlkOolG?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0ROolJOW<oOol00`00Oomoo`0EOol00`00Oomo
o`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00QooaHmkceooaHm
k`]oo`03001oogoo00Eoo`<000=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo025ooa]n
Lcmoo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool0
47oo0`000goo00<007ooOol00Woo00D007ooOomoo`0000YooaDmkcmooaDmk`]oo`03001oogoo00Eo
o`03001oogoo00Moo`03001oo`0000=oo`03001oogoo021ooaanLcmoo`03001oogoo00Ioo`<000=o
o`03001oogoo009oo`05001oogooOol0001nOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo
011oo`03001oogoo00Moo`03001oo`00009oo`03001oogoo00Qooa@mkd5ooa@mk`]oo`03001oogoo
00<000=oo`03001oogoo00Qoo`04001oogooOol2000POolMOW<nOol20008Ool00`00Oomoo`07Ool0
0`00Ool00002Ool00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo00]oo`<0
00=oo`03001oogoo00Qoo`03001oogoo008000Uooa<mkd=ooa<mk`Yoo`8000Qoo`03001oogoo00Io
o`8000Aoo`03001oogoo01iooainLcmoo`04001oogooOol30003Ool00`00Oomoo`08Ool00`00Oomo
o`02001lOol2000=Ool10001Ool1Ool00003Ool007oo015oo`03001oogoo00Ioo`8000=oo`03001o
ogoo00Qooa<mkdAooa8mk`]oo`03001oogoo00Eoo`03001oo`0000Moo`03001oogoo00=oo`03001o
ogoo01eooamnLcmoo`03001oogoo00Moo`03001oogoo00Ioo`8000=oo`03001oogoo07aoo`03001o
ogoo00]oo`40005oo`5oo`0000=oo`00Ool047oo00<007oo00001goo00<007ooOol00Woo00<007oo
Ool027oo4Sg_AGoo4Sg_2goo00<007ooOol01Woo00<007ooOol01Woo0`000goo00<007ooOol077oo
87ic?goo00<007ooOol01Woo00<007oo00001goo00<007ooOol00Woo00<007ooOol0O7oo00<007oo
Ool02goo0@000Goo0Goo00000goo001oo`0AOol00`00Oomoo`06Ool30002Ool00`00Oomoo`08OolB
?Nm6OolA?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0LOolPOW<oOol00`00Oomoo`07Ool00`00Oomo
o`06Ool30002Ool00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03
001oogoo00Qooa4mkdMooa4mk`]oo`03001oogoo01Eoo`03001oogoo01]oob5nLcmoo`03001oogoo
01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo0P002Goo43g_
BGoo43g_2Woo0P005goo00<007ooOol06goo8Gic?goo00<007ooOol05Goo0P00O7oo0P003Goo0@00
0Goo0Goo00000goo001oo`0OOol00`00Oomoo`08Ool??Nm:Ool@?Nl;Ool00`00Oomoo`0EOol00`00
Oomoo`0JOolROW<oOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool0
0003Ool007oo01moo`03001oogoo00Qoo`lmkd]oo`lmk`]oo`03001oogoo01Eoo`03001oogoo01Uo
ob=nLcmoo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00
Ool07goo00<007ooOol027oo3cg_Bgoo3cg_2goo00<007ooOol05Goo00<007ooOol06Goo8gic?goo
00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol0
0`00Oomoo`08Ool>?Nm=Ool>?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0HOolTOW<oOol00`00Oomo
o`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`8000Uoo`hm
kdeoo`hmk`Yoo`8001Moo`03001oogoo01QoobAnLcmoo`03001oogoo01Eoo`8007aoo`8000eoo`40
005oo`5oo`0000=oo`00Ool07goo00<007ooOol027oo3Cg_Cgoo3Cg_2goo00<007ooOol05Goo00<0
07ooOol05goo9Gic?goo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo
00000goo001oo`0OOol00`00Oomoo`08Ool=?Nm@Ool<?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0G
OolUOW<oOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool0
07oo01moo`03001oogoo00Qoo``mke5oo``mk`]oo`03001oogoo01Eoo`03001oogoo01MooaanL`03
001nLgic00InL`03001nLgic00InL`03001nLgic00YnL`03001nLgic00InL`03001nLgic00AnL`9o
o`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`00
00=oo`00Ool07goo00<007ooOol027oo33g_DGoo33g_2goo00<007ooOol05Goo00<007ooOol05Woo
77ic00<007icOW<00Wic00<007icOW<00Wic00<007icOW<00Wic00<007icOW<00Wic00<007icOW<0
27ic00@007icOW=nL`8000AnL`03001nLgic009nL`03001nLgoo009oo`03001oogoo01=oo`03001o
ogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo0P002Goo
33g_DGoo33g_2Woo0P005goo00<007ooOol05Woo77ic00L007icOW=nL`00OW<00004OW<01P00OW=n
L`00OW<000=nL`03001nLgic00QnL`03001nLgic00=nL`03001nLgic009nL`06001nLgic001nL`00
0goo00<007ooOol04goo00<007ooOol05Goo0P00O7oo0P003Goo0@000Goo0Goo00000goo001oo`0O
Ool00`00Oomoo`08Ool<?NmBOol;?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0FOolKOW<20003OW<0
0`00OW<00007OW<00`00OW<00003OW<20008OW<20004OW<00`00OW=nL`06OW<00`00OW<00003Ool2
000DOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo
01moo`03001oogoo00Qoo``mke9oo`/mk`]oo`03001oogoo01Eoo`03001oogoo01IooaanL`07001n
LgicOW<007ic00001gic00<007ic00000gic00<007icOW<027ic00<007icOW<00gic00<007icOW<0
1Gic00@007ic001nL`9oo`03001oogoo01=oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo
00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol027oo2cg_77oo0`000Woo1@00;Goo2cg_
2goo00<007ooOol05Goo00<007ooOol05Goo7Gic00L007icOW=nL`00OW<00007OW<00`00OW<00003
OW<00`00OW=nL`08OW<01`00OW=nLgic001nL`0000MnL`04001nL`00OW<2Ool00`00Oomoo`0COol0
0`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03
001oogoo00Qoo`/mkaeoo`03001oogoo00=oo`03001oogoo02eoo`/mk`]oo`03001oogoo01Eoo`03
001oogoo01EooainL`05001nLgicOW<00002OW<5OH`2OW<01@00OW=nLgic000037ic00D007icOW=n
L`0000UnL`05001nLgicOol0000FOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool1
0001Ool1Ool00003Ool007oo01moo`03001oogoo00Qoo`/mkaeoo`<000=oo`03001oogoo02eoo`/m
k`]oo`03001oogoo01Eoo`03001oogoo01Eoob9nL`YmS29nLaQoo`03001oogoo01Eoo`03001oogoo
07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo0P002Goo2cg_7Goo00@007ooOol0
009oo`03001oogoo02eoo`/mk`Yoo`8001Moo`03001oogoo01Eoob9nL`]mS25nLaQoo`03001oogoo
01Eoo`8007aoo`8000eoo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol027oo2cg_7Goo00@0
07ooOol0009oo`03001oogoo02eoo`/mk`]oo`03001oogoo01Eoo`03001oogoo01Eoob5nL`emS1En
L`QmS0=nLaQoo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=o
o`00Ool07goo00<007ooOol027oo2cg_77oo10000Woo0P00<7oo2Sg_2goo00<007ooOol05Goo00<0
07ooOol05Goo87ic3Wf<5Gic2Gf<0Wic67oo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol0
2goo0@000Goo0Goo00000goo001oo`0KOol01@00Oomoogoo00002Woo2Sg_EGoo2Sg_2goo00<007oo
Ool047oo00<007ooOol00Woo00<007ooOol05Goo87ic3Wf<57ic2Wf<0Wic67oo00<007ooOol04Goo
00D007ooOomoo`0007ioo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool06Woo00<007oo0000
0Woo00<007ooOol027oo2Sg_EGoo2Sg_2goo00<007ooOol03goo00<007oo00000goo00<007ooOol0
5Goo87ic3Wf<57ic2Wf<0gic5goo00<007ooOol047oo00<007oo00000Woo00<007ooOol0O7oo00<0
07ooOol02goo0@000Goo0Goo00000goo001oo`0JOol00`00Ool00002Ool20009Ool:?NmEOol:?Nl:
Ool2000AOol00`00Ool00003Ool2000EOolQOW<>OH`COW<;OH`3OW<FOol2000BOol00`00Ool00002
Ool2001lOol2000=Ool10001Ool1Ool00003Ool007oo01Yoo`03001oo`00009oo`03001oogoo00Qo
o`XmkeEoo`Xmk`]oo`03001oogoo00moo`03001oo`0000=oo`03001oogoo01Eoob1nL`imS1AnL`Ym
S0=nLaMoo`03001oogoo011oo`03001oo`00009oo`03001oogoo07aoo`03001oogoo00]oo`40005o
o`5oo`0000=oo`00Ool06Woo00<007oo00000Woo00<007ooOol027oo2Sg_EGoo2Sg_2goo00<007oo
Ool03goo00<007oo00000goo00<007ooOol05Goo87ic3Wf<57ic2Gf<0gic67oo00<007ooOol047oo
00<007oo00000Woo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0KOol0
1@00Oomoogoo00002Woo2cg_E7oo2Sg_2goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0
5Goo8Gic3Gf<5Gic27f<0gic67oo00<007ooOol04Goo00D007ooOomoo`0007ioo`03001oogoo00]o
o`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol027oo2cg_Dgoo2cg_2goo00<007ooOol05Goo
00<007ooOol05Goo8Wic2gf<5gic1Wf<17ic67oo00<007ooOol05Goo00<007ooOol0O7oo00<007oo
Ool02goo0@000Goo0Goo00000goo001oo`0OOol20009Ool;?NmCOol;?Nl:Ool2000GOol00`00Oomo
o`0EOolROW<:OH`HOW<5OH`5OW<HOol00`00Oomoo`0EOol2001lOol2000=Ool10001Ool1Ool00003
Ool007oo01moo`03001oogoo00Qoo`/mke=oo`/mk`]oo`03001oogoo01Eoo`03001oogoo01Eoob=n
L`QmS2=nLaQoo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=o
o`00Ool07goo00<007ooOol027oo2cg_87oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
7Woo2cg_2goo00<007ooOol05Goo00<007ooOol05Goo97ic1Wf<97ic67oo00<007ooOol05Goo00<0
07ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08Ool;?NlO
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0M
Ool;?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0EOolROW<30002OW<5000FOW<30003OW<30003OW<H
Ool00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01mo
o`03001oogoo00Qoo``mkaioo`07001oogooOol007oo000017oo00H007ooOol007oo0003Ool00`00
Oomoo`0MOol;?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0FOolROW<00`00OW=nL`03OW<00`00OW=n
L`0GOW<00`00OW=nL`02OW<00`00OW=nL`03OW<HOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00
Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`8000Uoo``mkaeoo`8000=oo`03001oo`0000Mo
o`03001oo`0000=oo`8001eoo``mk`Yoo`8001Moo`03001oogoo01Ioob9nL`<000=nL`03001nLgic
01MnL`<000=nL`04001nLgicOW<IOol00`00Oomoo`0EOol2001lOol2000=Ool10001Ool1Ool00003
Ool007oo01moo`03001oogoo00Qoo``mkaioo`07001oogooOol007oo00001goo00<007oo00000goo
00<007ooOol077oo33g_2goo00<007ooOol05Goo00<007ooOol05Woo8Wic00@007icOW<0009nL`03
001nLgic01MnL`04001nLgic0002OW<01000OW=nLgic6Goo00<007ooOol05Goo00<007ooOol0O7oo
00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08Ool<?NlNOol01`00Oomo
ogoo001oo`0000Moo`03001oo`0000=oo`03001oogoo01aoo``mk`]oo`03001oogoo01Eoo`03001o
ogoo01Moob5nL`04001nLgic0002OW<00`00OW=nL`0GOW<02000OW=nL`00OW<007ic0002OW<IOol0
0`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03
001oogoo00Qoo`dmkaioo`05001oogooOol00009Ool01@00Oomoogoo00007goo33g_2goo00<007oo
Ool05Goo00<007ooOol05goo87ic10000Wic0P0067ic10000gic00<007icOW<06Woo00<007ooOol0
5Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08
Ool=?Nm?Ool=?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0GOom:OW<JOol00`00Oomoo`0EOol00`00
Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00Qoo`hmkdio
o`dmk`]oo`03001oogoo01Eoo`03001oogoo01MoobEnLcmoo`03001oogoo01Eoo`03001oogoo07ao
o`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo0P002Goo3Sg_CGoo3Sg_2Woo0P005goo
00<007ooOol067oo97ic?goo00<007ooOol05Goo0P00O7oo0P003Goo0@000Goo0Goo00000goo001o
o`0OOol00`00Oomoo`08Ool??Nm<Ool>?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0HOolTOW<oOol0
0`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03
001oogoo00Qoo`lmkd]oo`lmk`]oo`03001oogoo01Eoo`03001oogoo01Uoob=nLcmoo`03001oogoo
01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol0
27oo3cg_Bgoo3cg_2goo00<007ooOol05Goo00<007ooOol06Woo8Wic?goo00<007ooOol05Goo00<0
07ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08Ool??Nm:
Ool@?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0JOolROW<oOol00`00Oomoo`0EOol00`00Oomoo`1l
Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`8000Uooa0mkdUooa0mk`Yoo`8001Mo
o`03001oogoo01]oob5nLcmoo`03001oogoo01Eoo`8007aoo`8000eoo`40005oo`5oo`0000=oo`00
Ool07goo00<007ooOol027oo4Cg_Agoo4Cg_2goo00<007ooOol05Goo00<007ooOol06goo8Gic?goo
00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol0
0`00Oomoo`08OolB?Nm6OolA?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0LOolPOW<oOol00`00Oomo
o`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo011oo`<000=oo`03
001oogoo009oo`05001oogooOol0000:OolB?Nm5OolB?Nl;Ool00`00Oomoo`05Ool30003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0MOolOOW<oOol00`00Oomoo`06Ool30003Ool00`00
Oomoo`02Ool01@00Oomoogoo0000OWoo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0@Ool0
0`00Oomoo`07Ool00`00Ool00002Ool00`00Oomoo`08OolC?Nm3OolC?Nl;Ool00`00Oomoo`05Ool0
0`00Oomoo`07Ool00`00Ool00003Ool00`00Oomoo`0MOolOOW<oOol00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Ool00002Ool00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo
015oo`03001oogoo00Qoo`03001oogoo008000Uooa@mkd9ooa<mk`Yoo`8000Qoo`03001oogoo00Qo
o`04001oogooOol2000OOolNOW<nOol20009Ool00`00Oomoo`08Ool00`00Oomoo`02001lOol2000=
Ool10001Ool1Ool00003Ool007oo015oo`03001oogoo00Ioo`8000=oo`03001oogoo00Qooa@mkd5o
oa@mk`]oo`03001oogoo00Ioo`03001oogoo00Ioo`8000Aoo`03001oogoo01mooaenLcmoo`03001o
ogoo00Moo`03001oogoo00Ioo`8000=oo`03001oogoo02YoobIJgbaoo`03001oogoo00]oo`40005o
o`5oo`0000=oo`00Ool047oo00<007oo00001goo00<007ooOol00Woo00<007ooOol027oo5Cg_?goo
5Cg_2goo00<007ooOol01Goo00<007oo00001goo00<007ooOol00goo00<007ooOol087oo77ic?goo
00<007ooOol01Woo00<007oo00001goo00<007ooOol00Woo00<007ooOol0:Woo9U[O;7oo00<007oo
Ool02goo0@000Goo0Goo00000goo001oo`0AOol00`00Oomoo`06Ool30002Ool00`00Oomoo`08OolF
?NlEOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0COolF?Nl;Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool30003Ool00`00Oomoo`0ROolJOW<oOol00`00Oomoo`07Ool00`00Oomoo`06Ool3
0002Ool00`00Oomoo`0ZOol9F]l00`00F]mJg`06F]l00`00F]mJg`06F]l00`00F]mJg`08F]l/Ool0
0`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00QooaPmka9oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`<0009oo`03001oogoo015ooaLmk`]oo`03001oogoo
01Eoo`03001oogoo02=ooaUnLcmoo`03001oogoo01Eoo`03001oogoo02Yoo`QJg`03001Jge[O009J
g`03001Jge[O009Jg`03001Jge[O009Jg`<0009Jg`03001Jge[O00MJgbaoo`03001oogoo00]oo`40
005oo`5oo`0000=oo`00Ool07goo0P002Goo6Cg_4Goo00L007ooOomoo`00Ool00004Ool00`00Oomo
o`02Ool01@00Oomoogoo00004Goo6Cg_2Woo0P005goo00<007ooOol097oo67ic?goo00<007ooOol0
5Goo0P00:goo25[O00L005[OF]mJg`00F]l00004F]l00`00F]mJg`02F]l01@00F]mJge[O00002E[O
:goo0P003Goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`08OolJ?Nl?Ool20003Ool00`00
Ool00007Ool40002Ool2000@OolI?Nl;Ool00`00Oomoo`0EOol00`00Oomoo`0TOolHOW<oOol00`00
Oomoo`0EOol00`00Oomoo`0ZOol7F]l20003F]l00`00F]l00007F]l40002F]l20008F]l/Ool00`00
Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00QooaXmka1oo`07001oogooOol0
07oo00001goo00<007oo00000goo00<007ooOol03Woo6Sg_2goo00<007ooOol05Goo00<007ooOol0
9Woo5Wic?goo00<007ooOol05Goo00<007ooOol0:Woo25[O00L005[OF]mJg`00F]l00007F]l00`00
F]l00003F]l00`00F]mJg`07F]l/Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03
001oogoo00Qooa`mk`ioo`07001oogooOol007oo000027oo0P000goo00<007ooOol037oo73g_2goo
00<007ooOol05Goo00<007ooOol0:7oo57ic?goo00<007ooOol05Goo00<007ooOol0:Woo25[O00L0
05[OF]mJg`00F]l00008F]l20003F]l00`00F]mJg`07F]l/Ool00`00Oomoo`0;Ool10001Ool1Ool0
0003Ool007oo01moo`03001oogoo00Qooahmk`eoo`05001oogooOol0000:Ool01000Oomoo`003Goo
7Sg_2goo00<007ooOol05Goo00<007ooOol0:Goo4gic?goo00<007ooOol05Goo00<007ooOol0:Woo
2E[O00D005[OF]mJg`0000YJg`04001Jge[O000:F]l/Ool00`00Oomoo`0;Ool10001Ool1Ool00003
Ool007oo01moo`03001oogoo00Qooalmkb]ooalmk`]oo`03001oogoo01Eoo`03001oogoo02]ooa5n
Lcmoo`03001oogoo01Eoo`03001oogoo02YoobIJgbaoo`03001oogoo00]oo`40005oo`5oo`0000=o
o`00Ool07goo0P002Goo7cg_:goo7cg_2Woo0P005goo00<007ooOol0;goo3Gic?goo00<007ooOol0
5Goo0P00:goo9U[O:goo0P003Goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`09OolN?Nl[
OolN?Nl<Ool00`00Oomoo`0EOol00`00Oomoo`0aOol;OW<oOol00`00Oomoo`0EOol00`00Oomoo`0Z
OolVF]l/Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00Uooahmkb]o
oahmk`aoo`03001oogoo01Eoo`03001oogoo03Aoo`QnLcmoo`03001oogoo01Eoo`03001oogoo02Yo
oa1Jg`I>Oa1Jgbaoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol02Woo
7Cg_:goo7Cg_3Goo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0:Woo
45[O1dio3e[O;7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0:OolM
?Nl[OolM?Nl=Ool00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`0ZOol?
F]l8CWl?F]l/Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`8000aooa`mkaEoo`03
001oogoo01=ooadmk`aoo`8001Moo`03001oogoo07]oo`03001oogoo01Eoo`8002]oo`iJg`E>O`04
001>OdioCWl?F]l[Ool2000=Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo00aooa/mkaEo
o`03001oogoo01=ooa/mk`moo`03001oogoo01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001o
ogoo02Yoo`mJg`A>O`04001>OdioCWl?F]l/Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo
01moo`03001oogoo00aooa/mkaEoo`03001oogoo01=ooa/mk`moo`03001oogoo01Eoo`03001oogoo
07]oo`03001oogoo01Eoo`03001oogoo02Yoo`mJg`A>O`03001>Odio011Jgbaoo`03001oogoo00]o
o`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol03Goo6Sg_5Goo00<007ooOol04goo6Sg_47oo
00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0:Woo3e[O14io00<004io
F]l045[O;7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0=OolJ?Nl8
Ool30003Ool30004Ool00`00Oomoo`0COolJ?Nl@Ool00`00Oomoo`0EOol00`00Oomoo`1kOol00`00
Oomoo`0EOol00`00Oomoo`0ZOol5F]l30002F]l50003F]l00dio001Jg`0AF]l/Ool00`00Oomoo`0;
Ool10001Ool1Ool00003Ool007oo01moo`80011ooaPmk`Uoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo01=ooaTmka1oo`8001Moo`03001oogoo07]oo`03001oogoo01Eoo`8002]oo`IJg`03
001Jge[O00=Jg`03001Jge[O00AJg`03001Jge[O011Jgb]oo`8000eoo`40005oo`5oo`0000=oo`00
Ool07goo00<007ooOol047oo5cg_2Goo0`000goo00<007ooOol00goo00<007ooOol04goo5cg_4goo
00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0:Woo1U[O0`000e[O00<0
05[OF]l015[O00<005[OF]l045[O;7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol0
0`00Oomoo`0AOolF?Nl9Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol04goo5Sg_57oo
00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0:Woo1U[O00@005[OF]l0
009Jg`03001Jge[O00AJg`03001Jge[O011Jgbaoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00
Ool07goo00<007ooOol04Woo5Cg_2Goo00P007ooOol007oo001oo`0017oo00<007ooOol04goo53g_
5Woo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0:Woo1U[O00@005[O
F]l0009Jg`03001Jge[O00AJg`03001Jge[O011Jgbaoo`03001oogoo00]oo`40005oo`5oo`0000=o
o`00Ool06goo00D007ooOomoo`0001Iooa<mk`Qoo`@000=oo`03001oogoo00=oo`03001oogoo01=o
oa8mkaQoo`03001oogoo011oo`03001oogoo009oo`03001oogoo07]oo`03001oogoo015oo`05001o
ogooOol0000/Ool5F]l40002F]l20006F]l00`00F]mJg`0@F]l/Ool00`00Oomoo`0;Ool10001Ool1
Ool00003Ool007oo01Yoo`03001oo`00009oo`03001oogoo01Qoo`lmkaEoo`03001oogoo01=ooa0m
kaYoo`03001oogoo00moo`03001oo`0000=oo`03001oogoo07]oo`03001oogoo011oo`03001oo`00
009oo`03001oogoo02Yooa=Jg`03001Jge[O011Jgbaoo`03001oogoo00]oo`40005oo`5oo`0000=o
o`00Ool077oo00<007ooOol00P007Woo2Sg_5Goo00<007ooOol04goo2Sg_7goo0P004goo00@007oo
Oomoo`8007]oo`8001Aoo`03001oogoo008002]ooa=Jg`03001Jge[O011Jgb]oo`8000eoo`40005o
o`5oo`0000=oo`00Ool06Woo0P000goo00<007ooOol07Goo2Sg_5Goo00<007ooOol04goo2Sg_87oo
00<007ooOol03goo0P0017oo00<007ooOol0Ngoo00<007ooOol047oo0P000goo00<007ooOol0:Woo
4e[O00<005[OF]l045[O;7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0JOol00`00Oomo
o`02Ool00`00Oomoo`0MOol:?NlEOol00`00Oomoo`0COol:?NlPOol00`00Oomoo`0?Ool00`00Oomo
o`03Ool00`00Oomoo`1kOol00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol5F]l30003
F]l30005F]l00`00F]mJg`0@F]l/Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01Yoo`<0
009oo`03001oogoo01eoo`XmkaEoo`03001oogoo01=oo`Xmkb1oo`03001oogoo00moo`<000=oo`03
001oogoo07]oo`03001oogoo011oo`<0009oo`03001oogoo02Yoo`IJg`03001Jge[O009Jg`03001J
ge[O00EJg`03001Jge[O011Jgbaoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<0
07ooOol07Goo2Sg_5Goo00<007ooOol04goo2Sg_87oo00<007ooOol05Goo00<007ooOol0Ngoo00<0
07ooOol05Goo00<007ooOol0:Woo1U[O0`000e[O00<005[OF]l015[O00<005[OF]l045[O;7oo00<0
07ooOol02goo0@000Goo0Goo00000goo001oo`0OOol2000NOol:?NlEOol00`00Oomoo`0COol:?NlO
Ool2000GOol00`00Oomoo`1kOol00`00Oomoo`0EOol2000[Ool6F]l01000F]mJg`000U[O00<005[O
F]l015[O00<005[OF]l045[O:goo0P003Goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0M
Ool:?NlEOol00`00Oomoo`0COol:?NlPOol00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0E
Ool00`00Oomoo`0ZOol6F]l02000F]mJg`00F]l005[O0005F]l00`00F]mJg`0@F]l/Ool00`00Oomo
o`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo01eoo`XmkaEoo`03001oogoo01=oo`Xm
kb1oo`03001oogoo01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo02Yoo`EJg`@000=J
g`03001Jge[O00AJg`03001Jge[O011Jgbaoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool0
7goo00<007ooOol07Goo2Sg_5Goo00<007ooOol04goo2Sg_87oo00<007ooOol05Goo00<007ooOol0
Ngoo00<007ooOol05Goo00<007ooOol0:Woo4e[O00<005[OF]l045[O;7oo00<007ooOol02goo0@00
0Goo0Goo00000goo001oo`0OOol00`00Oomoo`0MOol:?NlEOol00`00Oomoo`0COol:?NlPOol00`00
Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`0ZOolCF]l00`00F]mJg`0@F]l/
Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`8001ioo`XmkaEoo`03001oogoo01=o
o`Xmkamoo`8001Moo`03001oogoo07]oo`03001oogoo01Eoo`8002]ooa=Jg`03001Jge[O011Jgb]o
o`8000eoo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol07Goo2Sg_5Goo00<007ooOol04goo
2Sg_87oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007oo
Ool02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0MOol:?NlEOol00`00Oomoo`0COol:
?NlPOol00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomo
o`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo01eoo`XmkaEoo`03001oogoo01=oo`Xm
kb1oo`03001oogoo01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo
00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol07Goo2Sg_5Goo00<007ooOol04goo2Sg_
87oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol0
2goo0@000Goo0Goo00000goo001oo`0OOol2000NOol:?NlEOol00`00Oomoo`0COol:?NlOOol2000G
Ool00`00Oomoo`1kOol00`00Oomoo`0EOol2001lOol2000=Ool10001Ool1Ool00003Ool007oo01mo
o`03001oogoo01eoo`XmkaEoo`03001oogoo01=oo`Xmkb1oo`03001oogoo01Eoo`03001oogoo07]o
o`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo
00<007ooOol07Goo2Sg_5Goo00<007ooOol04goo2Sg_87oo00<007ooOol05Goo00<007ooOol0Ngoo
00<007ooOol05Goo00<007ooOol0<goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0=7oo
00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0MOol:?NlEOol00`00Oomo
o`0COol:?NlPOol00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`0bOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P0017oo00<007ooOol0<goo00<007ooOol0
2goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0MOol:?NlEOol00`00Oomoo`0COol:?NlP
Ool00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`0bOol01`00Oomoogoo
001oo`0000Aoo`06001oogoo001oo`000goo00<007ooOol0<goo00<007ooOol02goo0@000Goo0Goo
00000goo001oo`0OOol00`00Oomoo`0MOol:?NlEOol00`00Oomoo`0COol:?NlPOol00`00Oomoo`0E
Ool00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`0aOol20003Ool00`00Ool00007Ool00`00
Ool00003Ool2000dOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`8001ioo`XmkaEo
o`03001oogoo01=oo`Xmkamoo`8001Moo`03001oogoo07]oo`03001oogoo01Eoo`8003=oo`07001o
ogooOol007oo00001goo0P0017oo00<007ooOol0<Woo0P003Goo0@000Goo0Goo00000goo001oo`0O
Ool00`00Oomoo`0MOol:?NlEOol00`00Oomoo`0COol:?NlPOol00`00Oomoo`0EOol00`00Oomoo`1k
Ool00`00Oomoo`0EOol00`00Oomoo`0bOol01`00Oomoogoo001oo`0000Moo`03001oogoo00=oo`03
001oogoo03=oo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol07Goo2Sg_
5Goo00<007ooOol04goo2Sg_87oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<0
07ooOol0<goo00D007ooOomoo`0000Uoo`80009oo`03001oogoo03Aoo`03001oogoo00]oo`40005o
o`5oo`0000=oo`00Ool04Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0001moo`Xm
kaEoo`03001oogoo01=oo`Xmkb1oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo07]oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol0001nOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo015oo`03001oogoo00Io
o`03001oo`00009oo`03001oogoo01eoo`XmkaEoo`03001oogoo01=oo`Xmkb1oo`03001oogoo00Io
o`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo07]oo`03001oogoo00Moo`03001oogoo00Io
o`03001oo`00009oo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool04Goo
00<007ooOol027oo00<007ooOol00P007Woo2Sg_5Goo00<007ooOol04goo2Sg_7goo0P0027oo00<0
07ooOol027oo00@007ooOomoo`8007]oo`8000Uoo`03001oogoo00Qoo`03001oogoo008007aoo`80
00eoo`40005oo`5oo`0000=oo`00Ool04Woo00<007ooOol01Goo0P000goo00<007ooOol07Goo2Sg_
5Goo00<007ooOol04goo2Sg_87oo00<007ooOol01goo00<007ooOol01Goo0P0017oo00<007ooOol0
Ngoo00<007ooOol027oo00<007ooOol01Goo0P000goo00<007ooOol0O7oo00<007ooOol02goo0@00
0Goo0Goo00000goo001oo`0@Ool00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`0MOol:?NlE
Ool00`00Oomoo`0COol:?NlPOol00`00Oomoo`05Ool00`00Ool00007Ool00`00Oomoo`03Ool00`00
Oomoo`1kOol00`00Oomoo`06Ool00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`1lOol00`00
Oomoo`0;Ool10001Ool1Ool00003Ool007oo011oo`<000Moo`<0009oo`03001oogoo01eoo`XmkaEo
o`03001oogoo01=oo`Xmkb1oo`03001oogoo00Eoo`<000Moo`<000=oo`03001oogoo07]oo`03001o
ogoo00Ioo`<000Moo`<0009oo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00
Ool07goo00<007ooOol07Goo2Sg_5Goo00<007ooOol04goo2Sg_87oo00<007ooOol05Goo00<007oo
Ool0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001o
o`0OOol2000NOol:?NlEOol00`00Oomoo`0COol:?NlOOol2000GOol00`00Oomoo`1kOol00`00Oomo
o`0EOol2001lOol2000=Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo01eoo`XmkaEoo`03
001oogoo01=oo`Xmkb1oo`03001oogoo01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo
07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol07Goo2Sg_5Goo00<0
07ooOol04goo2Sg_87oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0
O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0MOol:?Nl8Ool30003
Ool20005Ool00`00Oomoo`0COol:?NlPOol00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0E
Ool00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo01eo
o`Xmk`Uoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo01=oo`Xmkb1oo`03001oogoo01Eo
o`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`00
00=oo`00Ool07goo0P007Woo2Sg_2Goo0`000goo00<007ooOol00goo00<007ooOol04goo2Sg_7goo
0P005goo00<007ooOol0Ngoo00<007ooOol05Goo0P00O7oo0P003Goo0@000Goo0Goo00000goo001o
o`0OOol00`00Oomoo`0MOol:?Nl9Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol04goo
2Sg_87oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007oo
Ool02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0MOol:?Nl9Ool02000Oomoo`00Ool0
07oo0004Ool00`00Oomoo`0COol:?NlPOol00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0E
Ool00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo01eo
o`Xmk`Qoo`@000=oo`03001oogoo00=oo`03001oogoo01=oo`Xmkb1oo`03001oogoo01Eoo`03001o
ogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00
Ool07goo00<007ooOol07Goo2Sg_5Goo00<007ooOol04goo2Sg_87oo00<007ooOol05Goo00<007oo
Ool0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001o
o`0OOol00`00Oomoo`0MOol:?NlEOol00`00Oomoo`0COol:?NlPOol00`00Oomoo`0EOol00`00Oomo
o`1kOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo
01moo`8001ioo`XmkaEoo`03001oogoo01=oo`Xmkamoo`8001Moo`03001oogoo07]oo`03001oogoo
01Eoo`8007aoo`8000eoo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol07Goo2Sg_:goo2Sg_
87oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol0
2goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0MOol:?Nl[Ool:?NlPOol00`00Oomoo`0E
Ool00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool0
0003Ool007oo01moo`03001oogoo01eoo`Xmkb]oo`Xmkb1oo`03001oogoo01Eoo`03001oogoo07]o
o`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo
00<007ooOol07Goo2Sg_:goo2Sg_87oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo
00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol2000NOol:?Nl[Ool:
?NlOOol2000GOol00`00Oomoo`1kOol00`00Oomoo`0EOol2001lOol2000=Ool10001Ool1Ool00003
Ool007oo01moo`03001oogoo01eoo`Xmkb]oo`Xmkb1oo`03001oogoo01Eoo`03001oogoo07]oo`03
001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<0
07ooOol07Goo2Sg_37oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol02Woo2Sg_87oo00<0
07ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@00
0Goo0Goo00000goo001oo`0DOol50002Ool01@00Oomoogoo00007goo2Sg_2goo00<007ooOol00Woo
00<007ooOol00Woo00@007ooOomoo`8000Aoo`03001oogoo00Uoo`Xmkb1oo`03001oogoo00Uoo`D0
009oo`03001oogoo009oo`03001oogoo07]oo`03001oogoo00Yoo`D0009oo`05001oogooOol0001n
Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01Ioo`07001oogooOol007oo00000Woo00<0
07ooOol07Goo2Sg_2goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo0000
2goo2Sg_87oo00<007ooOol02goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`1kOol00`00Oomo
o`0<Ool01`00Oomoogoo001oo`00009oo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`00
00=oo`00Ool05Woo00L007ooOomoo`00Ool00002Ool2000NOol:?Nl:Ool20003Ool00`00Ool00008
Ool20003Ool2000:Ool:?NlOOol2000=Ool01`00Oomoogoo001oo`0000=oo`8007]oo`8000ioo`07
001oogooOol007oo00000Woo0P00O7oo0P003Goo0@000Goo0Goo00000goo001oo`0FOol01`00Oomo
ogoo001oo`00009oo`03001oogoo01eooaDmk`07000mkcg_?Nl003g_00001cg_00<003g_00000cg_
00<003g_?Nl04cg_87oo00<007ooOol02goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`1kOol0
0`00Oomoo`0<Ool01`00Oomoogoo001oo`00009oo`03001oogoo07aoo`03001oogoo00]oo`40005o
o`5oo`0000=oo`00Ool05Woo00L007ooOomoo`00Ool00002Ool00`00Oomoo`0MOolE?Nl01`00?Nlm
kcg_000mk`0000Lmk`03000mk`0000<mk`03000mkcg_01<mkb1oo`03001oogoo00]oo`07001oogoo
Ool007oo00000goo00<007ooOol0Ngoo00<007ooOol037oo00L007ooOomoo`00Ool00002Ool00`00
Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01Eoo`8000Aoo`05001oogooOol0
000OOolF?Nl01@00?Nlmkcg_00002Cg_0P000Sg_00<003g_?Nl053g_87oo00<007ooOol02Woo0P00
17oo00<007ooOol00Woo00<007ooOol0Ngoo00<007ooOol02goo0P0017oo00D007ooOomoo`0007io
o`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol07Goo?cg_87oo00<007oo
Ool05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo
0Goo00000goo001oo`0OOol2000NOolo?NlOOol2000GOol00`00Oomoo`1kOol00`00Oomoo`0EOol2
001lOol2000=Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo01eooclmkb1oo`03001oogoo
01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5o
o`0000=oo`00Ool07goo00<007ooOol07Goo?cg_87oo00<007ooOol05Goo00<007ooOol0Ngoo00<0
07ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00
Oomoo`0MOolo?NlPOol00`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`1l
Ool00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01moo`03001oogoo01eooclmkb1oo`03001o
ogoo01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005o
o`5oo`0000=oo`00Ool07goo00<007ooOol07Goo?cg_87oo00<007ooOol05Goo00<007ooOol0Ngoo
00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol02goo0@000Goo0Goo00000goo001oo`0OOol2
000NOolo?NlOOol2000GOol00`00Oomoo`1kOol00`00Oomoo`0EOol2001lOol2000=Ool10001Ool1
Ool00003Ool007oo01moo`03001oogoo07aoo`03001oogoo01Eoo`03001oogoo07]oo`03001oogoo
01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<007ooOol0
O7oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<007ooOol0
2goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`1lOol00`00Oomoo`0EOol00`00Oomoo`1k
Ool00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool007oo01mo
o`03001oogoo07aoo`03001oogoo01Eoo`03001oogoo07]oo`03001oogoo01Eoo`03001oogoo07ao
o`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo0P00O7oo0P005goo00<007ooOol0Ngoo
00<007ooOol05Goo0P00O7oo0P003Goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`1lOol0
0`00Oomoo`0EOol00`00Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`1lOol00`00Oomoo`0;Ool1
0001Ool1Ool00003Ool007oo01moo`03001oogoo07aoo`03001oogoo01Eoo`03001oogoo07]oo`03
001oogoo01Eoo`03001oogoo07aoo`03001oogoo00]oo`40005oo`5oo`0000=oo`00Ool07goo00<0
07ooOol0O7oo00<007ooOol05Goo00<007ooOol0Ngoo00<007ooOol05Goo00<007ooOol0O7oo00<0
07ooOol02goo0@000Goo0Goo00000goo001oo`0OOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00
Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0EOol00`00
Oomoo`1kOol00`00Oomoo`0EOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`0;Ool10001Ool1Ool00003Ool0
07oo01mooh0001Moogl001Mooh0000eoo`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@000Goo0Goo
00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo0?moomYoo`40005oo`5oo`0000=oo`00
Ool0ogoofWoo0@000Goo0Goo00000goo001oo`3oOooJOol10001Ool1Ool00003Ool007oo0?moomYo
o`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@000Goo0Goo00000goo001oo`3oOooJOol10001Ool1
Ool00003Ool007oo0?moomYoo`40005oo`5oo`0000=oo`00Ool0ogoofWoo0@000Goo0Goo00000goo
001oo`3oOooJOol10001Ool1Ool00003Ool007oo0?moomYoo`40005oo`5oo`0000=oo`00Ool0ogoo
fWoo0@000Goo0Goo00000goo001oo`3oOooJOol10001Ool1Ool00003Ool000000?l00=/0009oo`00
\
\>"],
  ImageRangeCache->{{{0, 478}, {238, 0}} -> {-0.08796, -0.0406581, 0.00664419,
   0.00664419}, {{13.1875, 163.688}, {231.875, 6.0625}} -> {-9.30032,
   -9.14709, 0.0949229, 0.0949229}, {{163.688, 314.25}, {231.875, 6.0625}} ->
   {-23.5777, -9.14116, 0.0948765, 0.0948765}, {{314.25, 464.75}, {231.875, 
  6.0625}} -> {-37.878, -9.14709, 0.0949229, 0.0949229}}]
}, Open  ]],

Cell[TextData[
"The ground body object uses three local point definitions.  \nP1 is a point \
at the global origin that is the rotational axis of the crankshaft.\nP2 and \
P3 are two points that define the vertical line upon which the piston \
translates."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This defines a body object for the ground body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(bd[1] = 
      Body[ground, 
        PointList 
          \[Rule] {\n\t\t\t\t (*P1*) \ {0., 0.}, \n\t\t\t\t
             (*P2*) \ {0., 4.}, \n\t\t\t\t (*P3*) \ {0., 9.}}]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysBody[1, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The crankshaft uses two local point definitions.\nP1 is a point at the \
local origin that is the rotational axis of the crankshaft.\nP2 is a point on \
the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis that is the attachment point of the connecting rod."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This defines a body object for the piston. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(crank = 2; \)\), 
    \(\(bd[2] = 
      Body[crank, 
        PointList 
          \[Rule] {\n\t\t\t\t (*P1*) \ {0., 0.}, \n\t\t\t\t
             (*P2*) \ {3., 0.}}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The piston also uses two local point definitions.\nP1 is a point on the \
local ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis that is the attachment point of the connecting rod.\nP2 is a point \
on the local ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis that is the upper end of the translation line of the piston. "
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This defines a body object for the piston."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(piston = 3; \)\), 
    \(\(bd[3] = 
      Body[piston, 
        PointList 
          \[Rule] {\n\t\t\t\t (*P1*) \ {0., 4.}, \n\t\t\t\t
             (*P2*) \ {0., 6.}}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["InitialGuess"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Alternately, the piston could have been defined with the local origin at \
the attachment point of the connecting rod. This would suggest that a \
different initial guess be used than the default of ",
  StyleBox["X3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0, ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0, ",
  StyleBox["Th3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a body object for the piston with relocated origin and corresponding \
initial guess. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(piston = 3; \)\), 
    \(\(bd[3] = 
      Body[piston, PointList \[Rule] {{0., 0.}, {0., 2.}}, 
        InitialGuess \[Rule] {{0, 4}, 0}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "This body object functions identically to the first one, except the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of the piston is always 4 units greater, because the origin of \
the body has moved 4 units upward.\n\nNote that each of these body objects \
must be added to the current model with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " before they will have any effect on the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["SetBodies"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to apply the data contained in body objects to the \
current kinematic model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetBodies[ Body[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["... ",
    FontFamily->"Times"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data objects and adds the point and property data contained therein to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s internal database."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The body object processing function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "All properties specified in a call to ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " overwrite properties that are currently defined unless the property \
specification is the default, ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", in which case the property is left unchanged.\n\nIf ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is passed a body object with an ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specification other than ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the current initial guesses of each body are reset to the values of the \
permanent initial guesses.\n\nThere is a subtle issue regarding the use of \
the ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specification with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". When ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run with a new ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specification, the changed guess is immediately reflected in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s internal database. The same holds true for changing inertia properties \
with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; the mass matrix is immediately updated.\n\nHowever, changing the \
coordinates of a point with ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must reflect a change throughout the constraint equations defined with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This cannot be done without rebuilding the constraint equations. \
Therefore, if the constraint equations have already been built with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " when ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is passed a ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specification other than ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the constraint equations will all be automatically rebuilt by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the next time that a solution is sought, which may cause a noticeable \
delay in the operation of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nThe following command incorporates the three body objects that were \
defined in the previous subsection into the current model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This starts a model with the three body objects. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[1], bd[2], bd[3]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["Null",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". All of the mechanism points and properties passed to ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are stored in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s internal database.\n\nNow that local point definitions have been added \
to the current model, they can be referenced by their local point numbers in \
",
  StyleBox["any Mech",
    FontSlant->"Italic"],
  " function. Instead of using the local coordinates of a point, simply use \
the integer point number. For example, the ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint in the crankshaft-piston model would use four local point \
numbers instead of the four explicit 2D coordinates in the ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a constraint with, and without, local point numbers. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Translate2[3, Line[ground, 2, 3], Line[piston, 1, 2]]; \)\)], "Input",\

  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["is equivalent to", "SmallText"],

Cell[BoxData[
    \(\(Translate2[3, Line[ground, {0, 4}, {0, 9}], 
      Line[piston, {0, 4}, {0, 6}]]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Updating Properties"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " only sets the values of the properties that are not specified with the \
default, ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Thus, ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to update the value of individual body properties without \
affecting properties already defined."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This updates only the crankshaft's initial guess."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[Body[crank, InitialGuess \[Rule] {{1, 1}, 0}]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["PointList"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", like many ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " options, can also be used as a function. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointList[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["pnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the local coordinates of point ",
  StyleBox["pnum",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another usage of ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the local coordinates of point 2 on the piston. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(PointList[piston, 2]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"0.`", ",", 
        StyleBox["2.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2.2  Points, Vectors, and Axes"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section explains the functionality and syntax of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s method of defining the basic geometric entities that make up a \
mechanism model: points, vectors, and axes. A look at the usage statements \
for most of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s functions shows that they take arguments of type ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", or ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". In all cases there are several ways to specify a ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", or ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", depending on whether the entity is defined in global or local \
coordinates, is located entirely on a single body, or spans across multiple \
bodies."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "A ",
  StyleBox["point",
    FontSlant->"Italic"],
  " argument is satisfied by a point object. A point object can be a list of \
coordinates, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or an expression with the head ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". A point object is used to specify location.\n\nA ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " argument is satisfied by a vector object. A vector object can be a list \
of the vector components, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or an expression with the head ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". A vector object is used to specify direction.\n\nAn ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " argument is satisfied by an axis object. An axis object can be an \
expression with the head ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". An axis object is used to specify location and direction."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The three basic types of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " geometry objects."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Points"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The most basic geometric entity used by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " is t",
  StyleBox["he point object. Point ob",
    FontFamily->"Times"],
  "jects reference the location of a 2D or 3D point in global coordinates or \
in local coordinates on a specified bod",
  StyleBox["y. Point objects m",
    FontFamily->"Times"],
  "ay be given as 2D or 3D vectors, or they may have the head ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " just like the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitive. This does not lead to any conflict or require a \
redefinition of ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because it has no definition by default. The ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " head is only used to hold its arguments in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ", just as it is in standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".\n\nAny ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function that calls for a point object accepts either of the following \
syntax."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D "], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a point with local coordinates ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " located on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a local coordinate pair ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or a positive integer point number that references a local coordinate \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a point with the specified global coordinates."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 2D point objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["3D "], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a point with local coordinates ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " located on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a local coordinate triplet ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or a positive integer point number that references a local coordinate \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a point with the specified global coordinates. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 3D point objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"Assuming that the appropriate body object definition has been made, any \
point on any body can be referenced through either its global coordinates, \
its local coordinates, or its local coordinate number. The following example \
shows several point objects that are functionally identical."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Local points are defined on the ground body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(SetBodies[
      Body[ground, \n\t\tPointList \[Rule] {{0, 0}, {2, \(-4\)}, {3, 6}}]]
      \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are three identical point specifications."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Point[ground, {2, \(-4\)}]; \)\), 
    \(\(Point[ground, 2]; \)\), 
    \(\({2, \(-4\)}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Vectors"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The basic geometric entity specifying direction is the vector object. \
Vector objects reference the direction of a 2D or 3D vector, in global \
coordinates or in local coordinates on a specified body. Vector objects may \
be given as 2D or 3D vectors in global coordinates, or they may have the head \
",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and be given in local coordinates on a specific body.\n\nA ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to specify a vector object, in which case the direction of \
the ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used as the direction of the vector. A ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (3D only) may also be used to specify a vector object, in which case the \
normal direction of the ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used as the direction of the vector. See the following two subsections \
for further information on ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nAny ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function that calls for a vector object accepts either of the following \
syntax."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a vector with local coordinates ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " located on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a local coordinate pair ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or a positive integer point number that references a local coordinate \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a vector with the specified global components."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 2D vector objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a vector with local coordinates ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " located on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a local coordinate triplet ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or a positive integer point number that references a local coordinate \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a vector with the specified global components."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 3D vector objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"Assuming that the appropriate body object definition has been made, any \
vector on any body can be referenced through either its global coordinates, \
its local coordinates, or its local point number. The following example shows \
several vector objects that are functionally identical."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This defines some coordinates on the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(crank = 2; \)\), 
    \(SetBodies[
      Body[crank, \n\t\tPointList \[Rule] {{0, 0}, {2, \(-4\)}, {3, 6}}]]\)}],
   "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are two identical vector specifications."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Vector[crank, {3, 6}]; \)\), 
    \(\(Vector[crank, 3]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Lines"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " to reference a line in 2D or 3D space. A ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is defined two points: an origin point and an end point. The two points \
may be on the same or two different bodies. Because a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object possesses both direction and location, it can be used in place of \
a vector object or an axis object in any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function that calls for a vector or an axis object. \n\n",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects have the same head as the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics primitive. This does not lead to any conflict or require a \
redefinition of ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because it has no definition by default. The ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " head is only used to hold its arguments in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ", just as it is in standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". \n\nAny ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function that calls for a vector or axis object accepts any of the \
following syntax."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D "], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a line from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", where the each of the ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  " a",
  StyleBox["re any valid form of ",
    FontFamily->"Times"],
  StyleBox["Mech",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" point",
    FontFamily->"Times"],
  " object.\n\n",
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a line spanning from local point ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be local coordinate pairs ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or positive integer point numbers that reference local coordinates \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["bnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a line spanning two bodies from local point ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to local point ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum2.",
    FontSlant->"Italic"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 2D line objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a line from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", where each of the ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  " are any valid form of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  StyleBox[" point objec",
    FontFamily->"Times"],
  "t.\n\n",
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a line spanning from local point ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be local coordinate triplets ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or positive integer point numbers that reference local coordinates \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["bnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a line spanning two bodies from local point ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to local point ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 3D line objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"Assuming that the appropriate body object definition has been made, any line \
spanning bodies or on a single body can be referenced with a combination of \
global points, local points, or local point numbers. The following example \
shows several line objects that are functionally identical."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This defines several points on the two bodies."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ground = 1; crank = 2; \), 
    \(SetBodies[\n\t
      Body[ground, PointList \[Rule] {{0, 0}, {2, \(-4\)}, {3, 6}}], \n\t
      Body[crank, PointList \[Rule] {{0, 0}, {5, 0}, {4, \(-1\)}}]]\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are three identical line definitions. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Line[ground, {2, \(-4\)}, crank, {4, \(-1\)}]; \)\), 
    \(\(Line[ground, 2, crank, 3]; \)\), 
    \(\(Line[Point[ground, 2], Point[crank, 3]]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are two more identical line definitions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Line[ground, {0, 0}, ground, {2, \(-4\)}]; \)\), 
    \(\(Line[ground, 1, 2]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package so that ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be loaded."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Planes"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to reference a planar surface in 3D space. A ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is defined by three points and has a specific origin, normal direction, \
and reference direction (see ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "). The first of the three points is the origin, and the vector from the \
first point to the second point is the reference direction. The third \
coplanar point cannot be colinear with the first two points. The positive \
normal is given by the cross product of the vector from the first point to \
the second point and the vector from the first point to the third point. \n\n\
Because a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object possesses the properties of direction and location, it can be used \
in place of a vector object or an axis object in any ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function that calls for a vector or an axis. If a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used to specify direction, the normal direction is used as the \
direction vector.\n\nAny ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function that calls for a vector or axis object accepts any of the \
following syntax."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Plane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a plane defined by three coplanar points. The plane originates \
at ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " and the reference direction is the vector from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2. ",
    FontSlant->"Italic"],
  "Each of the ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  " must be ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["point ",
    FontFamily->"Times"],
  "objects. \n \n",
  StyleBox["Plane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a plane on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " with three defining coplanar points ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["lpnt3",
    FontSlant->"Italic"],
  ". The coordinates ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be local coordinate triplets ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or positive integer point numbers that reference local coordinates on \
body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["Plane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["bnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["bnum3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references a plane with three defining points at ",
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining plane objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[
"Assuming that the appropriate body object definition has been made, a plane \
spanning any one, two, or three bodies can be referenced with a combination \
of global points, local points, or local point numbers. The following example \
shows several plane objects that are functionally identical."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Local points are defined on the two bodies. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ground = 1; crank = 2; \), 
    \(SetBodies[\n\t
      Body[ground, \n\t\t
        PointList \[Rule] {{0, 0, 0}, {2, \(-4\), 0}, {3, 6, 6}}], \n\t
      Body[crank, \n\t\t
        PointList \[Rule] {{0, 0, 0}, {5, 0, 1}, {4, \(-1\), 0}}]]\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are two identical plane definitions. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Plane[Point[ground, 1], Point[crank, 2], Point[crank, 3]]; \)\), 
    \(\(Plane[ground, 1, crank, 2, crank, 3]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are three more identical plane definitions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Plane[ground, {0, 0, 0}, ground, {2, \(-4\), 0}, ground, {3, 6, 6}]; 
    \)\), 
    \(\(Plane[ground, 1, 2, {3, 6, 6}]; \)\), 
    \(\(Plane[ground, 1, 2, 3]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package so that ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be loaded."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Axes "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Th",
  StyleBox["e axis obje",
    FontFamily->"Times"],
  "ct is used by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " to reference an axis in 2D or 3D space. An axis object is specified by \
origin and direction. Optionally, 3D axis objects may have a reference \
direction specified. The reference direction is a vector that is not parallel \
to the direction of the axis. The reference direction is used by some ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints to control rotation about the axis. \n\nAn axis object may \
have the head ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify an axis object, the origin and direction of the ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are used as the origin and direction of the axis. Because a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object has no specific reference direction, a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should not be used in place of a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " axis object in a function where the reference direction is relevant. \n\n\
If a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify an axis object, the origin of the ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used as the origin of the axis, the normal direction of the ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used as the direction of the axis, and the line from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " on the ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used as the reference direction of the axis. \n\nAny ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function that calls for an axis object accepts any of the following \
syntax."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D "], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis that originates at ",
  StyleBox["point",
    FontSlant->"Italic"],
  " and points in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". ",
  StyleBox["point",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  StyleBox[" point o",
    FontFamily->"Times"],
  "bject and ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector object.\n\n",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis originating at ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " and having a direction vector equal to the local coordinates of ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be local coordinate pairs ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or positive integer point numbers that reference local coordinates \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n \n",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["bnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis originating at ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " and having a direction vector equal to the coordinates of ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum2.",
    FontSlant->"Italic"],
  " "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 2D axis objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["3D "], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis that originates at ",
  StyleBox["point",
    FontSlant->"Italic"],
  " and points in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". ",
  StyleBox["point",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " point object and ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector object. \n\n",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis that originates at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", points in the direction of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", and has reference direction ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["point",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " point object and the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  " must be ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector objects.\n\n",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis originating at ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " and having a direction vector equal to the local coordinates of ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be local coordinate triplets ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or positive integer point numbers that reference local coordinates \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n \n",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" lpnt3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis originating at ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", having a direction vector equal to the coordinates of ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", and having a reference direction equal to the coordinates of ",
  StyleBox["lpnt3",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["bnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" bnum3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" lpnt3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " references an axis originating at ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  ", having a direction vector equal to the coordinates of ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ", and having a reference direction equal to the coordinates of ",
  StyleBox["lpnt3",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum3",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Methods of defining 3D axis objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"Assuming that the appropriate body object definitions have been made, any \
axis with origin and direction specified with coordinates on a single body or \
multiple bodies can be referenced with a combination of global points, local \
points, or local point numbers. The following example shows several axis \
objects that are functionally identical."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Local points are defined on the two bodies. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(ground = 1; crank = 2; \), 
    \(SetBodies[\n\t
      Body[ground, PointList \[Rule] {{0, 0}, {2, \(-4\)}, {3, 6}}], \n\t
      Body[crank, PointList \[Rule] {{0, 0}, {5, 0}, {4, \(-1\)}}]]\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are three functionally identical axis definitions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Axis[Point[ground, 2], Line[ground, 2, crank, 3]]; \)\), 
    \(\(Axis[ground, 2, crank, {\(-1\), \(-1\)}]; \)\), 
    \(\(Line[ground, 2, crank, 3]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are three more identical axis definitions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Axis[Point[ground, 1], Vector[ground, 2]]; \)\), 
    \(\(Axis[ground, {0, 0}, {2, \(-4\)}]; \)\), 
    \(\(Line[ground, 1, 2]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["The Zeroth Point"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "For convenience, local point 0 (zero) can be used to reference the local \
origin of any body, although point 0 is never defined. The zeroth point can \
always be used, regardless of whether or not any ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects have been defined and passed to ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The following examples show the use of the zeroth point."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are two identical 2D point objects. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Point[3, {0, 0}]; \)\), 
    \(\(Point[3, 0]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are two identical 3D line objects. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Line[2, {0, 0, 0}, {1, 5.2, 0}]; \)\), 
    \(\(Line[2, 0, {1, 5.2, 0}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2.3  Constraint Objects"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Constraint objects are used to define the mathematical relationships that \
make up the kinematic model in terms of the physical relationships of the \
various mechanism bodies. All ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint functions return constraint objects with the head ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These constraint objects are passed to the ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to build the mathematical model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["General Format"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"All arguments to any constraint function follow the same general format."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["constraintfunction",
    FontSlant->"Italic"],
  StyleBox["[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["points",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["|",
    FontFamily->"Times"],
  StyleBox["vectors",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["|",
    FontFamily->"Times"],
  StyleBox["axes",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["scalars",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint object with the head ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " is a positive integer constraint number that must be unique among all of \
the constraints in a single model.\n\n",
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " are ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " geometry objects as defined in Section 2.2. \n\nSome constraint functions \
require a scalar expression to specify an angle or distance."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Format for all constraint functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Further, all constraint function names end with a single digit, except the \
general constraint function ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This digit signifies the number of degrees of freedom constrained by the \
constraint. For example, the ",
  StyleBox["2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint function name signifies that it contains two constraint \
equations and constrains two degrees of freedom in a model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2D Basic Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " basic constraints specify elementary geometric relationships between \
points and lines on mechanism bodies. Elementary relationships are used for \
the majority of simple mechanical joints. A shaft spinning in a bearing is \
modeled by specifying that two points are coincident. A connecting rod can be \
modeled by specifying a constant distance between two points. A guide pin in \
a slot is modeled by specifying that a point on one body lies on a line on \
another body. A piston in a cylinder is modeled by specifying that two lines \
on two different bodies are colinear.\n\nMany seemingly different mechanical \
joints are often modeled with the same constraint, such as a connecting rod \
versus a guide pin in a circular track; both are modeled by specifying the \
distance between two points on two different bodies. It is up to the user to \
determine the true nature of the kinematic relationships that make up a \
mechanism.\n\nThe entire set of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint functions is quite redundant; all basic 2D mechanisms could, \
in fact, be modeled with a small subset of the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints. The goal in this is to provide a constraint that is similar \
in form to the actual mechanical joint being modeled. Thus, the readability \
of the model can be improved."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OriginLock2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " locks the origin of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to that of body ",
  StyleBox["bnum2. ",
    FontSlant->"Italic"],
  "The coordinates of the local origins of the two bodies are identical.\n\n",
  
  StyleBox["RotationLock1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2, ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the angular coordinate of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians greater than the angular coordinate of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Local coordinate constraints directly control the local coordinates of \
specified bodies. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["PointOnLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " places ",
  StyleBox["point",
    FontSlant->"Italic"],
  " ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units to the left of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["RelativeX1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["RelativeY1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the global ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["DirectedDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", measured in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["RelativeDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Point-on-line constraints force a point on a body to travel along a \
specified line. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolute2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be coincident with ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["DirectedPosition2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["PointOnLines2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie at the intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Point-at-position constraints force a point on a body to lie at a specified \
position. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parallel1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Orthogonal1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be orthogonal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["RelativeAngle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2, ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the direction angle of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians greater than the direction angle of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Angular constraints control the angle between the direction vectors of two \
lines. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Translate2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel and coincident with ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Compound constraints enforce multiple geometric relationships \
simultaneously. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "There are several other compound constraints available for modeling gears \
and cams, these are discussed in Chapter 6. \n\nTo demonstrate the ambiguity \
in determining which constraint is the \"correct\" constraint, the set of \
four constraints used in the crankshaft-piston model are examined. The first \
constraint, ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", could be modeled with a pair of constraints with one degree of freedom \
each; a ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to control the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the crankshaft axis, and a ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to control the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is functionally identical to a pair of one degree of freedom \
constraints. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(piston = 3; \)\), 
    \(\(Revolute2[1, Point[ground, {0, 0}], Point[crank, {0, 0}]]; \)\), 
    \(\(RelativeX1[1, Point[crank, {0, 0}], 0]; \)\), 
    \(\(RelativeY1[2, Point[crank, {0, 0}], 0]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The second constraint, ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", could be modeled by constraining the angle between two lines, one on the \
crankshaft and one on the ground. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are two equivalent constraints. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(RotationLock1[2, crank, crankangle]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["is equivalent to", "SmallText"],

Cell[BoxData[
    \(\(RelativeAngle1[2, Line[crank, {0, 0}, {1, 0}], 
      Line[ground, {0, 0}, {1, 0}], crankangle]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, in this application, cannot be replaced by the use of any \
other constraint. It is somewhat unique, geometrically."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This constraint has no functional equivalent. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(RelativeDistance1[4, Point[crank, {3, 0}], Point[piston, {0, 4}], 
      5.0]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Basic Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " basic constraints specify elementary geometric relationships between \
points, lines, and planes on mechanism bodies. Elementary relationships are \
used for the majority of mechanical joints. A shaft spinning in a bearing is \
modeled by specifying that two axes are coincident. A connecting rod can be \
modeled by specifying a constant distance between two points. A guide pin in \
a slot is modeled by specifying that a point on one body lies on a line on \
another body. A piston in a cylinder is modeled by specifying that two lines \
on two different bodies are colinear.\n\nMany seemingly different mechanical \
joints are often modeled with the same constraint, such as a connecting rod \
versus a guide pin in a circular track; both are modeled by specifying the \
distance between two points on two different bodies. It is up to the user to \
determine the true nature of the kinematic relationships that make up a \
mechanism. \n\nThe entire set of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint functions is quite redundant; all basic 3D mechanisms could, \
in fact, be modeled with a small subset of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints. The goal in this is to provide a constraint that is similar \
in form to the actual mechanical joint being modeled. Thus, the readability \
of the model is improved. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OriginLock3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Xoff, Yoff, Zoff",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " locates the origin of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " at the global coordinates ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Xoff, Yoff, Zoff",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n \n",
  StyleBox["RotationLock3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Xax, Yax, Zax",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rotates body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about the specified global axis ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Xax, Yax, Zax",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Local coordinate constraints directly control the local coordinates of \
specified bodies."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnPlane1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a plane defined by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The plane may be specified with a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, or by the plane's normal with an ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.\n\n",
  StyleBox["RelativeX1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["RelativeY1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the global ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["RelativeZ1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the global ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["DirectedDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", measured in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["RelativeDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " could have been named \"PointOnSphere1\".\n\n",
  StyleBox["PointOnCylinder1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units distant from ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["PointOnCone1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a cone revolved about ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " with half angle ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ". The vertex of the cone lies at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["PointOnTorus1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, majr, minr",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a torus of major radius ",
  StyleBox["majr",
    FontSlant->"Italic"],
  " and minor radius ",
  StyleBox["minr",
    FontSlant->"Italic"],
  ". The major axis of the torus is specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and the center of the torus lies at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Point-on-surface constraints force a point to lie on a specified surface. "],
   "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnLine2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["PointOnCircle2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " revolved about ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The center of the circle lies at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["PointOnPlanes2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the intersection of two planes. The planes are specified by \
their normals with ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", which may be ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Point-on-line constraints force a point to lie on a line or curve. "], 
  "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Spherical3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be coincident with ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["DirectedPosition3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["PointAtIntersection3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie at the intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and a plane that is specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Point-at-position constraints control the position of a point. "], "Special4",\

  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Orthogonal1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be orthogonal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["ProjectedAngle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2, vector3, ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the angle of the projection of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", relative to the projection of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", to be equal to ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " when the two vectors are projected on a plane that is normal to ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["RelativeAngle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2, ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the included angle between the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ". Note that ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " becomes singular as ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " approaches zero.  In this case use the ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint instead. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Angular constraints control the angle between two vectors. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parallel2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the two vectors to be parallel in 3D space. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Parallel constraint enforces parallelism between two vectors. "], "Special4",\

  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineToLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the perpendicular distance between the two axes to be equal to \
",
  StyleBox["dist",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["LineToCircle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["c",
    FontSlant->"Italic"],
  StyleBox["num, axis1, axis2, rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to pass through the perimeter of a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", with the axis of the circle specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["PlaneToCircle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains a plane, specified by normal with ",
  StyleBox["axis1,",
    FontSlant->"Italic"],
  " to lie tangent to a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ". The axis of the circle is specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["LineToPlane2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from, and parallel to, a plane specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["LineOnCylinder3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the two axes to be parallel and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart. \n\n",
  StyleBox["PlaneToPlane3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two planes to be parallel and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart. The planes are specified by their normals with ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", which may be ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Constraints that enforce more complex geometric relationships. "], "Special4",\

  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Cylindrical4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a hinge that can translate along its axis and rotate about its \
axis. The two axes are constrained to be colinear. \n\n",
  StyleBox["Revolute5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a hinge or revolving joint. The two axes are constrained to be \
colinear, and their origins are constrained to be coincident. \n\n",
  StyleBox["Translate5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a linear slider that cannot rotate. The two axes are constrained \
to be colinear, and their reference directions are coplanar. \n\n",
  StyleBox["ParaRevolute4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models two side-by-side hinges. The two axes are constrained to be \
parallel, and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart. Further, the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie directly adjacent to the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["OrthoRevolute4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pair of hinges with offset orthogonal axes. The two axes are \
constrained to be orthogonal, and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart. Further, the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie directly adjacent to the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Compound constraints enforce multiple geometric relationships \
simultaneously. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "There are several other compound constraints available for modeling gears \
and cams; these are discussed in Chapter 6. \n\nTo demonstrate the ambiguity \
in determining which constraint is the \"correct\" constraint, the set of \
five constraints used in the crankshaft-piston model are reexamined. The \
first constraint, ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", could be modeled with two constraints; a ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint to control the position of the crankshaft, and a ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint to control the direction vector of the crankshaft's axis. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here the ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is functionally replaced by two other constraints. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(piston = 3; \)\), 
    \(\(Revolute5[1, Line[ground, {0, 0, 0}, {0, 0, 5}], 
      Line[crank, {0, 0, 0}, {0, 0, 5}]]; \)\), 
    \(Spherical3[1, \n\tPoint[ground, {0, 0, 0}], Point[ground, {0, 0, 0}]]; 
    \nParallel2[2, \n\tVector[ground, {0, 0, 5}], Vector[crank, {0, 0, 5}]]; 
    \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The third constraint, ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", could be modeled by using two ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here the ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is functionally replaced. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Cylindrical4[3, Line[ground, {0, 4, 0}, {0, 9, 0}], 
      Line[piston, {0, 4, 0}, {0, 9, 0}]]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["is equivalent to", "SmallText"],

Cell[BoxData[{
    \(\(PointOnLine2[3, Point[piston, {0, 4, 0}], 
      Line[ground, {0, 4, 0}, {0, 9, 0}]]; \)\), 
    \(\(PointOnLine2[4, Point[piston, {0, 9, 0}], 
      Line[ground, {0, 4, 0}, {0, 9, 0}]]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint in this application cannot be replaced by the use of any other \
constraint. It is somewhat unique, geometrically."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This constraint has no functional equivalent. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(RelativeDistance1[4, Point[crank, {3, 0, 0}], 
      Point[piston, {0, 4, 0}], 5.0]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["The General Constraint"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The general constraint allows the user to enter a mathematical relationship \
directly as an equation."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Constraint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["equation",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " adds the equation (which must have the head ",
  StyleBox["Equal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") to the constraint vector of the current model. ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " controls as many degrees of freedom as the number of equations provided."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The general constraint function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "For example, to constrain the origin of body 2 to lie on a paraboloid \
surface in the global coordinate system with its axis in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction and ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " intercept at {0, 0, 4}, ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would be used as follows. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a general mathematical constraint."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraint[1, 3\ X2\^2 + 2\ Y2\^2 + 4 == Z2]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["Constraint", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2.4  Building the Model"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Constraint objects are processed into a kinematic model with the ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The system of equations generated by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not returned to the user; it is stored in several variables in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s private context. Thus only one mechanism model can be \"current\" in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " at any given time. Several means of accessing and modifying the model are \
provided by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "; these are discussed in the following section. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["SetConstraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s core model building function. ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes constraint objects that represent the physical interactions in the \
mechanism model and processes them into a system of kinematic equations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetConstraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["constraints",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts constraint objects and builds a mathematical system representing \
the mechanism model. ",
  StyleBox["constraints",
    FontSlant->"Italic"],
  " can be a list or sequence of constraints. Each of the ",
  StyleBox["constraints",
    FontSlant->"Italic"],
  " must be a constraint object with the head ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", such as are returned by all of the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint functions. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The core model-building function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts options that determine how certain parts of the mathematical \
model are built. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that determines whether or not to reset all of the initial guesses when ",
  
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run.\n \n",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to reset all initial guesses to the values of the permanent initial \
guesses specified with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n \n",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " resets the initial guesses only if the current initial guesses are not \
sufficient to cover all of the dependent variables in the current model, \
otherwise it leaves the guesses unchanged.\n\n",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is the default setting.",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The actual constraint expressions that are generated by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be extracted with ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be very useful for debugging a model because it is often possible to \
read the constraint expressions directly and relate them to the function of \
the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Constraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of constraint expressions generated by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " from constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". Each expression should evaluate to a number when all of the dependent \
variables in the current model are defined. Each expression is expected to \
evaluate to zero when the constraint is satisfied. \n\n",
  StyleBox["Constraints[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnu",
    FontSlant->"Italic"],
  StyleBox["m",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["enum",
    FontSlant->"Italic"],
  StyleBox["}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns expression ",
  StyleBox["enum",
    FontSlant->"Italic"],
  " in constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", in a multiple degree of freedom constraint. \n\n",
  StyleBox["Constraints[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire constraint vector. The length of the constraint vector \
is equal to the number of degrees of freedom in the current model."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Constraints function. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Consider the 2D crankshaft-piston model of Section 1.2. This model is \
built with various settings for the options for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to show their affect on the resulting equations. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the crankshaft-piston model rebuilt. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(piston = 3; \)\), 
    \(crankangle =. \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(cs[1] = Revolute2[1, Point[ground, {0., 0.}], Point[crank, {0., 0.}]]; 
    \n\(cs[2] = RotationLock1[2, crank, crankangle]; \)\), 
    \(\(cs[3] = 
      Translate2[3, Line[ground, {0., 4.}, {0., 9.}], 
        Line[piston, {0., 4.}, {0., 6.}]]; \)\), 
    \(\(cs[4] = 
      RelativeDistance1[4, Point[crank, {3., 0.}], Point[piston, {0., 4.}], 
        5.]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs[1], cs[2], cs[3], cs[4]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The first constraint ",
  StyleBox["cs[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a two degree of freedom constraint that constrains the origin of the \
crankshaft to lie at the global origin."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the expression generated by the ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints[1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-X2\), \(-Y2\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Obviously, when these two expressions are driven to zero, the desired \
result is achieved, the coordinates of the local origin of the crankshaft ",
  StyleBox["{X2, Y2}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are zero. \n\nThe third constraint ",
  StyleBox["cs[3]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a two degree of freedom constraint that allows the piston to translate \
along a vertical axis, but constrains its rotation and its translation in the \
",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the expression generated by the ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints[3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({10.`\ Sin[Th3], 
      2.`\ Cos[Th3]\ \((X3 - 4.`\ Sin[Th3])\) - 
        2.`\ \((\(4.`\[InvisibleSpace]\) - Y3 - 4.`\ Cos[Th3])\)\ Sin[Th3]}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The first expression, ",
  StyleBox["10 Sin[Th3]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", constrains the rotation of the piston; this expression can be equal to \
zero if ",
  StyleBox["Th3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is any integer multiple of ",
  StyleBox["\[Pi]",
    FontFamily->"Symbol"],
  ". The reason that the solution ",
  StyleBox["Th3\[Rule]0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is found is because the default initial guess is ",
  StyleBox["Th3\[Rule]0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If a different initial guess were used, such as ",
  StyleBox["Th3\[Rule]3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the model would converge to ",
  StyleBox["Th3\[Rule]\[Pi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " instead. \n\nThe second expression in the list constrains the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the piston to be zero. Notice that at any value of ",
  StyleBox["Th3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that satisfies the first expression, the second expression reduces to ",
  StyleBox["2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["X3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["-2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["X3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", either of which will drive ",
  StyleBox["X3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to zero. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Initial Guesses"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " serves both as an option for several ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions, and as a function for temporarily setting a model's initial \
guesses. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetGuess[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SetGuess[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets new initial guesses for the current model. These guesses are used \
only for the very next solution attempt.\n\n",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether to reset the current initial guesses to the values \
specified with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["SetGuess[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " resets the current initial guesses to the values of the permanent initial \
guesses specified in the ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects passed to ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["SetBodies[Body[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bn",
    FontSlant->"Italic"],
  StyleBox["um",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["InitialGuess\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets a new permanent initial ",
  StyleBox["guess",
    FontSlant->"Italic"],
  " for body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", and resets all of the current initial guesses to the permanent initial \
guess values."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Various methods of setting initial guesses."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the values for the dependent variables that will be used as the \
next set of initial guesses. The value returned by ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is determined by the last solution rule obtained by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or the last set of guesses set with ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " utility."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "To advance the position for the model in large steps, it is sometimes \
necessary to specify a better initial guess than the current one. For \
example, to turn the crankshaft 3/4 of a turn at once, it might be necessary \
to set a new initial guess for ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the angular coordinate of the crankshaft and the height of the piston, \
respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This runs the model at its initial position. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(crankangle = 0; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 0, X3 \[Rule] 0, Y3 \[Rule] 0, 
      Th3 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This sets new guesses for ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetGuess[Th2 \[Rule] 5, Y3 \[Rule] \(-2.5\)]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      \(X2 \[Rule] 0\), ",", \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 5\), ",", 
        \(X3 \[Rule] 0\), ",", 
        RowBox[{"Y3", "\[Rule]", 
          RowBox[{"-", 
            StyleBox["2.5`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}]}], ",", \(Th3 \[Rule] 0\)}], "}"}]], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This runs the model at 3/4 turn of the crank. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(crankangle = 3.0\ \[Pi]/2; \nSolveMech[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] 0.`, Y2 \[Rule] 2.76430184455019389`*^-24, 
      Th2 \[Rule] 4.71238898038468967`, X3 \[Rule] 0.`, 
      Y3 \[Rule] \(-1.99999999999999911`\), Th3 \[Rule] 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "If ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " were to be run at this time with the default options, the initial guesses \
would remain at their current values, ",
  StyleBox["Th2\[Rule]4.71",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Y3\[Rule]-2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option resets the guesses to their defaults. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option resets the initial guesses. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(crankangle =. \), 
    \(SetConstraints[cs[1], cs[2], cs[3], cs[4], SetGuess \[Rule] True]\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This shows the current guesses."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 0, X3 \[Rule] 0, Y3 \[Rule] 0, 
      Th3 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["$MechProcessFunction"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechProcessFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a function that is applied to all of the mechanism equations that are \
generated by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as they are created. The default setting, ",
  StyleBox["$MechProcessFunction = Chop",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", can reduce the size of the constraint expressions substantially if any \
of the constraints involve the local origins of bodies in the model which \
have local coordinates of ",
  StyleBox["{0., 0. (0.)}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Setting ",
  StyleBox["$MechProcessFunction = Identity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " disables this action."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Set ",
  StyleBox["$MechProcessFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " equal to ",
  StyleBox["Identity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to disable chopping."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\($MechProcessFunction = Identity; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here the model is built without chopping the constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs[1], cs[2], cs[3], cs[4]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints[1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(0.`\[InvisibleSpace]\) - X2 + 0.`\ Cos[Th2] + 0.`\ Sin[Th2], 
      \(0.`\[InvisibleSpace]\) - Y2 + 0.`\ Cos[Th2] + 0.`\ Sin[Th2]}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Obviously, the run time of the model is increased by increasing the size \
of the constraint expressions. However, if the model contains very small \
physical dimensions, it may not be acceptable to apply ",
  StyleBox["Chop",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the constraints."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["SetSymbols"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The default symbols that appear in the solution rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be changed with the ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetSymbols[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the basis for the symbols that are created by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A model set-up function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Because ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " changes the behavior of all ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions that return symbolic expressions, ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be run before building any other part of the mechanism model with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has the effect of executing ",
  StyleBox["ClearMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the basis for the symbols that are hard-coded into the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. \n\nIn ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the default setting is ",
  StyleBox[
  "SymbolBasis \[Rule] {\"T\", {\"X\",\"Y\"},\n{\"Ei\",\"Ej\"}, \"Th\", \"Lmb\
\", \"d\"}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\nIn ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the default setting is ",
  StyleBox[
  "SymbolBasis \[Rule] {\"T\", {\"X\",\"Y\",\"Z\"},\n\
{\"Eo\",\"Ei\",\"Ej\",\"Ek\"}, {\"Wx\",\"Wy\",\"Wz\"}, \"Lmb\", \"d\"}",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Hard-coded symbols."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Wx",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wy",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Wz",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " symbols are used by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to represent angular velocities used in 3D velocity analysis, which is \
discussed in Chapter 4. The ",
  StyleBox["Lmb",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " symbols are Lagrange multipliers used in static and dynamic analysis, \
which is discussed in Chapter 7. The ",
  StyleBox["d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " symbol is used in 2D and 3D velocity analysis to symbolically represent \
differentiation. \n\nIf the current model is rebuilt with a new setting for ",
  
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the solution rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are changed accordingly. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This causes new symbols to be used in all subsequent models. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetSymbols[
      SymbolBasis 
        \[Rule] {
          "\<Tm\>", {"\<Xcoord\>", "\<Ycoord\>"}, {"\<Ei\>", "\<Ej\>"}, 
          "\<Theta\>", "\<Lmb\>", "\<d\>"}]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is rebuilt with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(crankangle =. \), 
    \(SetConstraints[cs[1], cs[2], cs[3], cs[4]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This runs the model at ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(crankangle = .5; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({Xcoord2 \[Rule] 0.`, Ycoord2 \[Rule] 0.`, Theta2 \[Rule] 0.5`, 
      Xcoord3 \[Rule] 0.`, Ycoord3 \[Rule] 1.68899886310171272`, 
      Theta3 \[Rule] 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2.5  Running the Model"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section covers the use of the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, which is used to seek a solution to the mechanism model. The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " commands covered in the previous sections were all concerned with \
building a mechanism model. ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the sole function for \"running\" the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["SolveMech"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is used without arguments to seek a single solution to the \
mechanism model, with all of the current values of any user-defined variables \
in the model. When ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a \"solution\", what it is really trying to do is numerically find \
the location and orientation of each of the bodies in the model at which all \
of the constraints are satisfied."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a solution to the current mechanism model."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s run time command. "
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Time Dependence"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Most mechanism models have some dependency on time that is specified (by \
default) by the symbol ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". When ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " appears in a mechanism model, the model's location becomes explicitly a \
function of time, a technique that ",
  StyleBox["must",
    FontSlant->"Italic"],
  " be used in the velocity and acceleration portions of the analysis. It is \
not necessary to have any dependency on ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in a model used only for location analysis, but it is customary to make \
the primary driving expression a function of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " anyway. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a special symbol that represents time in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. Another symbol can be substituted for ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The symbol for time."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has several special invocations that are useful for finding a solution or \
many solutions at a range of values of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["time",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a solution to the mechanism model with the specified numerical \
value of ",
  StyleBox["time",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["SolveMech[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["t2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["tn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks ",
  StyleBox["n",
    FontSlant->"Italic"],
  " solutions to the mechanism model with ",
  StyleBox["n",
    FontSlant->"Italic"],
  " specified values of time ",
  StyleBox["ti",
    FontSlant->"Italic"],
  ". A nested list of solution rules is returned. \n\n",
  StyleBox["SolveMech[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["t2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["tn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["m",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks ",
  StyleBox["m",
    FontSlant->"Italic"],
  " solutions to the mechanism model. The solution points include all of the \
specified times ",
  StyleBox["ti",
    FontSlant->"Italic"],
  " as well as ",
  StyleBox["m",
    FontSlant->"Italic"],
  " minus ",
  StyleBox["n",
    FontSlant->"Italic"],
  " more points in time evenly dispersed throughout the ",
  StyleBox["ti",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "More arguments for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The 2D crankshaft-piston model is used to demonstrate the various forms of \
",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". When this example was first used in Section 1.2, the sym",
  StyleBox["bol ",
    FontFamily->"Times"],
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" wa",
    FontFamily->"Times"],
  "s used to specify the rotation of the crankshaft. Now ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is replaced with 2 pi",
  StyleBox[" ",
    FontFamily->"Symbol"],
  StyleBox["t",
    FontSlant->"Italic"],
  " so that the rotation of the crankshaft is a function of time. Thus, the \
crankshaft has an angular velocity of one revolution per second. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The crankshaft-piston model with a time-dependent driver. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(piston = 3; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      Revolute2[1, \n\t\tPoint[ground, {0., 0.}], Point[crank, {0., 0.}]], \n
      \tRotationLock1[2, crank, 2.0\ \[Pi]\ T], \n\t
      Translate2[3, Line[ground, {0, 4.}, {0, 9.}], 
        Line[piston, {0, 4.}, {0, 6.}]], \n\t
      RelativeDistance1[4, \n\t\tPoint[crank, {3., 0.}], 
        Point[piston, {0., 4.}], 5.]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Now, instead of changing the value of ",
  StyleBox["crankangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to drive the model the value of time is changed directly with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This runs the model at 1/10 turn of the crankshaft. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[.1] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 0.628318530717958623`\), ",", 
        \(X3 \[Rule] 0\), ",", \(Y3 \[Rule] 2.13478841966841548`\), ",", 
        \(Th3 \[Rule] 0\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This seeks 3 solutions from 0 to 0.5 turns, inclusive."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[{0, .5}, 3] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{T \[Rule] 0, X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 0, X3 \[Rule] 0, 
        Y3 \[Rule] 0, Th3 \[Rule] 0}, {T \[Rule] 0.25`, X2 \[Rule] 0, 
        Y2 \[Rule] 0, Th2 \[Rule] 1.57079632679489655`, X3 \[Rule] 0, 
        Y3 \[Rule] 4.`, Th3 \[Rule] 0}, {T \[Rule] 0.5`, X2 \[Rule] 0, 
        Y2 \[Rule] 0, Th2 \[Rule] 3.14159265358979311`, X3 \[Rule] 0, 
        Y3 \[Rule] 0, Th3 \[Rule] 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The unusual form of the iteration specifier in ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is very useful if an even spread of data is desired, with a few \
particular data specified in between. For example, the following example \
generates six solution points with the points ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0., 0.223, and 0.3 included, and the other three points spread so as to \
fill the gaps as evenly as possible. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This seeks 6 solution points, including ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.223"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(First/@SolveMech[{0, .223, .3}, 6]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, T \[Rule] 0.0743333333333333357`, 
      T \[Rule] 0.14866666666666668`, T \[Rule] 0.222999999999999998`, 
      T \[Rule] 0.261500000000000021`, T \[Rule] 0.3`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData["Initial Guesses at Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveMech[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a solution to the mechanism model, taking the value of time, and \
the values of all the initial guesses from ",
  StyleBox["rules",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["SolveMech[{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks solutions as specified by each of the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  ", and returns a nested list of solutions. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Setting initial guesses with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The primary reason for passing rules into ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", instead of just specifying the value of time, is to accelerate the \
solution process. The supplied rules may be known to be very good initial \
guesses, such as rules obtained from a prior run with a slightly different \
value for a parameter."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This calls ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with a list of guesses. The value of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.2 is pulled from the guesses. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[{T \[Rule] .2, X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 1.2, 
          X3 \[Rule] 0, Y3 \[Rule] 3, Th3 \[Rule] 0}] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.2`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 1.25663706143591724`\), ",", 
        \(X3 \[Rule] 0\), ",", \(Y3 \[Rule] 3.76647561249347395`\), ",", 
        \(Th3 \[Rule] 0\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Controlling SolveMech"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The nonlinear equation solver used by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be controlled by setting the values of several options. Many of these \
options are the same as those used by ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", although ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not utilize ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["DampingFactor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as well as other built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions. ",
  StyleBox["DampingFactor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["n",
    FontSlant->"Italic"],
  " uses a damping factor of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " in the Newton's method solver. The default setting is ",
  StyleBox["DampingFactor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n \n",
  StyleBox["MaxIterations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and other ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions. With ",
  StyleBox["MaxIterations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["n",
    FontSlant->"Italic"],
  ", a maximum of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " iterations are used to seek a solution to the model. The default settin",
  StyleBox["g is ",
    FontFamily->"Times"],
  StyleBox["MaxIterations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["15",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"],
  "\n \n",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies a function that is applied to each constraint expressions \
at each iteration, to see if the model has converged. ",
  StyleBox["ZeroTest[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["number",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should return ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " if the number is sufficiently close to zero. The default setting is ",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["(Abs[#] < 10^-9 &)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Options for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The operation of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be inspected by the use of two \"hook\" functions that are called \
during the execution of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Note that all ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system variables that can be set by the user have names of the form ",
  StyleBox["\"$Mech*\"",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechPostIterate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a function that is applied to the iteration counter at each iteration. \
Setting ",
  StyleBox["$MechPostIterate = Print",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the iteration counter to be printed at each iteration. The default \
definition is ",
  StyleBox["$MechPostIterate =.",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\n",
  StyleBox["$MechPreSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a function that is applied to the numerical value of time before each \
solution attempt. ",
  StyleBox["$MechPreSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to automatically set initial guesses at each solution point, \
or to print the value of time that ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is currently working on. The default definition is ",
  StyleBox["$MechPreSolve =.",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Controls for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Failure to Converge"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The default setting for ",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will suffice for many models, but may need to be changed for several \
reasons.\n\nIf the numerical size of the dimensions of the model are very \
large or small, ",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may need to be changed accordingly. For example, if a typical point in \
the model is ",
  StyleBox["Point[2, {3400, -7800}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", it might be necessary to specify ",
  StyleBox["ZeroTest \[Rule] (Abs[#] < 10^-6 &)", "Input"],
  ". \n\nIf the model is large (eight or more bodies for 2D, four or more for \
3D) solving the linear equations at each iteration begins to suffer from \
numerical error. Thus, it may be necessary to lower the convergence criteria.\
\n\nThe primary indication that the convergence criteria must be changed is \
that ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a valid solution that is apparently correct, but an error message \
is generated claiming that convergence has failed after ",
  StyleBox["n",
    FontSlant->"Italic"],
  " iterations. If the model fails to converge and returns a solution that is \
obviously not valid, try to find an inconsistency in the constraint set or \
consult Chapter 12, Debugging Models. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Nonlinear Equation Solver"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "At the core of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s numerical solution block is a Newton-Rhapson simultaneous nonlinear \
equation solver, similar to the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In fact, ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " can be used to solve arbitrary systems of equations that have no relation \
to mechanism analysis. \n\n",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s general constraint function ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to build a constraint object from an arbitrary algebraic \
equation. The algebraic constraint can be incorporated into a mechanism model \
along with other geometric constraints, or an entire model can be built from \
general constraints."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Constraint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["equation",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbol",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint object that can be used to add ",
  StyleBox["equation",
    FontSlant->"Italic"],
  " to the model's constraint vector. The ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " is added to the vector of dependent variables in the model, with the \
associated initial ",
  StyleBox["guess",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " controls as many degrees of freedom as the number of equations provided."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The general constraint function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following uses ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " to find the intersection of a parabola and a circle."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This prevents impending spelling errors."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \(xvar; yvar; \), 
    \(On[General::"\<spell1\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This builds the nonmechanism model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tConstraint[1, yvar == xvar\^2 - 1, {yvar, 1}], \n\t
      Constraint[2, yvar == 2 + 3\ xvar, {xvar, 0}]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This plots the two functions, showing their intersection. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[{xvar\^2 - 1, 2 + 3\ xvar}, {xvar, \(-1.5\), 4.5}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.261905 0.15873 0.0823707 0.0270622 [
[.10317 .06987 -6 -9 ]
[.10317 .06987 6 0 ]
[.42063 .06987 -3 -9 ]
[.42063 .06987 3 0 ]
[.57937 .06987 -3 -9 ]
[.57937 .06987 3 0 ]
[.7381 .06987 -3 -9 ]
[.7381 .06987 3 0 ]
[.89683 .06987 -3 -9 ]
[.89683 .06987 3 0 ]
[.2494 .21768 -6 -4.5 ]
[.2494 .21768 0 4.5 ]
[.2494 .35299 -12 -4.5 ]
[.2494 .35299 0 4.5 ]
[.2494 .4883 -12 -4.5 ]
[.2494 .4883 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.10317 .08237 m
.10317 .08862 L
s
[(-1)] .10317 .06987 0 1 Mshowa
.42063 .08237 m
.42063 .08862 L
s
[(1)] .42063 .06987 0 1 Mshowa
.57937 .08237 m
.57937 .08862 L
s
[(2)] .57937 .06987 0 1 Mshowa
.7381 .08237 m
.7381 .08862 L
s
[(3)] .7381 .06987 0 1 Mshowa
.89683 .08237 m
.89683 .08862 L
s
[(4)] .89683 .06987 0 1 Mshowa
.125 Mabswid
.13492 .08237 m
.13492 .08612 L
s
.16667 .08237 m
.16667 .08612 L
s
.19841 .08237 m
.19841 .08612 L
s
.23016 .08237 m
.23016 .08612 L
s
.29365 .08237 m
.29365 .08612 L
s
.3254 .08237 m
.3254 .08612 L
s
.35714 .08237 m
.35714 .08612 L
s
.38889 .08237 m
.38889 .08612 L
s
.45238 .08237 m
.45238 .08612 L
s
.48413 .08237 m
.48413 .08612 L
s
.51587 .08237 m
.51587 .08612 L
s
.54762 .08237 m
.54762 .08612 L
s
.61111 .08237 m
.61111 .08612 L
s
.64286 .08237 m
.64286 .08612 L
s
.6746 .08237 m
.6746 .08612 L
s
.70635 .08237 m
.70635 .08612 L
s
.76984 .08237 m
.76984 .08612 L
s
.80159 .08237 m
.80159 .08612 L
s
.83333 .08237 m
.83333 .08612 L
s
.86508 .08237 m
.86508 .08612 L
s
.07143 .08237 m
.07143 .08612 L
s
.03968 .08237 m
.03968 .08612 L
s
.00794 .08237 m
.00794 .08612 L
s
.92857 .08237 m
.92857 .08612 L
s
.96032 .08237 m
.96032 .08612 L
s
.99206 .08237 m
.99206 .08612 L
s
.25 Mabswid
0 .08237 m
1 .08237 L
s
.2619 .21768 m
.26815 .21768 L
s
[(5)] .2494 .21768 1 0 Mshowa
.2619 .35299 m
.26815 .35299 L
s
[(10)] .2494 .35299 1 0 Mshowa
.2619 .4883 m
.26815 .4883 L
s
[(15)] .2494 .4883 1 0 Mshowa
.125 Mabswid
.2619 .10943 m
.26565 .10943 L
s
.2619 .1365 m
.26565 .1365 L
s
.2619 .16356 m
.26565 .16356 L
s
.2619 .19062 m
.26565 .19062 L
s
.2619 .24474 m
.26565 .24474 L
s
.2619 .27181 m
.26565 .27181 L
s
.2619 .29887 m
.26565 .29887 L
s
.2619 .32593 m
.26565 .32593 L
s
.2619 .38006 m
.26565 .38006 L
s
.2619 .40712 m
.26565 .40712 L
s
.2619 .43418 m
.26565 .43418 L
s
.2619 .46124 m
.26565 .46124 L
s
.2619 .51537 m
.26565 .51537 L
s
.2619 .54243 m
.26565 .54243 L
s
.2619 .56949 m
.26565 .56949 L
s
.2619 .59655 m
.26565 .59655 L
s
.2619 .05531 m
.26565 .05531 L
s
.2619 .02825 m
.26565 .02825 L
s
.2619 .00118 m
.26565 .00118 L
s
.25 Mabswid
.2619 0 m
.2619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .1162 m
.06244 .09804 L
.10458 .08189 L
.14415 .0702 L
.18221 .06213 L
.20178 .05919 L
.21267 .05791 L
.22272 .05696 L
.23293 .05621 L
.23832 .05591 L
.24402 .05565 L
.24641 .05557 L
.24897 .05549 L
.25119 .05543 L
.25361 .05538 L
.25507 .05536 L
.25643 .05534 L
.25773 .05533 L
.2584 .05532 L
.25912 .05532 L
.25983 .05531 L
.26048 .05531 L
.26176 .05531 L
.26293 .05531 L
.26416 .05531 L
.26538 .05532 L
.26607 .05533 L
.26671 .05533 L
.26912 .05536 L
.27131 .0554 L
.27364 .05546 L
.27847 .0556 L
.2838 .05582 L
.29326 .05636 L
.30213 .05705 L
.32232 .05923 L
.34082 .062 L
.38045 .0704 L
.41855 .08167 L
.45911 .09708 L
.49816 .11526 L
.53966 .13817 L
.57964 .16374 L
.61811 .19159 L
.65902 .2247 L
.69843 .25998 L
.73632 .29705 L
.77666 .33991 L
.81548 .38446 L
.85676 .43538 L
Mistroke
.89652 .48788 L
.93476 .54159 L
.97546 .6022 L
.97619 .60332 L
Mfstroke
.02381 .01472 m
.06244 .03448 L
.10458 .05603 L
.14415 .07627 L
.18221 .09573 L
.22272 .11645 L
.26171 .1364 L
.30316 .15759 L
.34309 .17802 L
.3815 .19766 L
.42237 .21857 L
.46172 .23869 L
.49955 .25805 L
.53984 .27865 L
.57861 .29848 L
.61984 .31957 L
.65954 .33988 L
.69774 .35941 L
.73838 .3802 L
.77751 .40022 L
.81909 .42148 L
.85916 .44198 L
.89771 .4617 L
.93871 .48267 L
.97619 .50184 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{291, 179},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004S0000/a000`40O003h00OC7oo00<007ooOol0
e7oo001<Ool2003EOol004aoo`03001oogoo0=Aoo`00C7oo00<007ooOol0e7oo001<Ool00`00Oomo
o`3DOol000Moo`8004=oo`03001oogoo0=Aoo`002Goo0P00@Goo00<007ooOol0e7oo000;Ool2000o
Ool00`00Oomoo`3DOol000eoo`8003eoo`03001oogoo0=Aoo`003goo0P00>goo0P00eGoo000AOol2
000iOol00`00Oomoo`3DOol001=oo`8003Moo`03001oogoo0=Aoo`005Goo0P00=Goo00<007ooOol0
e7oo000GOol20005Ool5000YOol00`00Oomoo`0XOol5000ZOol3000[Ool2000/Ool3000NOol001Uo
o`8000Eoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo02Yoo`03001oogoo02eoo`03001o
ogoo02Yoo`03001oogoo01eoo`006Woo0`000goo00<007ooOol0:Goo00<007ooOol0:Woo00<007oo
Ool0:goo00<007ooOol0:goo00<007ooOol0:Goo10007Woo000MOol200000goo001oo`0VOol8000Y
Ool00`00Oomoo`0[Ool00`00Oomoo`0/Ool00`00Oomoo`0XOol00`00Ool0000OOol001moo`8001ao
o`/000Aoo`04001oogooOol;000NOol00`00Oomoo`0ZOol00`00Ool0000[Ool00`00Ool0000[Ool2
000OOol001moo`@0015oo`T000moo`03001oogoo00aoo`X001=oo`8002eoo`03001oogoo02]oo`03
001oogoo02]oo`03001oogoo01eoo`008goo0P002goo100067oo00<007ooOol05Woo1000^Woo000U
Ool20005Ool4000LOol00`00Oomoo`0JOol4002fOol002Moo`D0021oo`03001oogoo01ioo`<00;=o
o`009Goo1P008Goo00<007ooOol08Goo1000[goo000QOol40006Ool2000OOol00`00Oomoo`0UOol4
002[Ool00?l002<0005oo`000goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol017oo0`00
27oo00<007ooOol01Goo0P002Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo10001Goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0
1Woo00<007ooOol01Woo00<007ooOol00Woo000IOol30002Ool00`00Oomoo`0@Ool2000IOol00`00
Oomoo`0[Ool01000Oomoogoo0`009Woo00<007ooOol0:goo00<007ooOol0:goo00<007ooOol07Goo
000FOol3000JOol2000GOol00`00Oomoo`0bOol3002OOol001Aoo`8001moo`03001oogoo01Aoo`03
001oogoo03Eoo`8009eoo`004Goo0`008Woo0P0057oo00<007ooOol0=goo0P00Vgoo000?Ool2000W
Ool2000BOol00`00Oomoo`0iOol2002IOol000eoo`8002]oo`80011oo`03001oogoo03]oo`8009Mo
o`002goo0P00;goo0P003Woo0P00?Woo0P00UGoo0009Ool2000cOol2000<Ool00`00Oomoo`0oOol2
002COol000Moo`8003Moo`8000Yoo`03001oogoo045oo`03001oogoo091oo`00@Woo0P0027oo00<0
07ooOol0@Woo0P00T7oo0014Ool20006Ool00`00Oomoo`14Ool2002>Ool004Ioo`8000Aoo`03001o
ogoo04Ioo`8008aoo`00B7oo0P000Woo00<007ooOol0B7oo0P00RWoo001:Ool3001<Ool20028Ool0
04aoo`8004eoo`8008Ioo`00C7oo0`00CWoo0P00Q7oo001<Ool00`00Oomoo`02001>Ool00`00Oomo
o`21Ool004aoo`03001oogoo009oo`8004eoo`03001oogoo081oo`00C7oo00<007ooOol017oo0P00
C7oo0P00P7oo001<Ool00`00Oomoo`06Ool2001<Ool00`00Oomoo`1mOol004aoo`03001oogoo00Qo
o`8004]oo`03001oogoo07aoo`00C7oo00<007ooOol02Woo0P00BWoo0P00O7oo001<Ool2000=Ool2
001:Ool00`00Oomoo`1iOol004aoo`03001oogoo00ioo`8004Uoo`8007Uoo`00C7oo00<007ooOol0
47oo0P00BGoo00<007ooOol0MWoo001<Ool00`00Oomoo`0BOol20018Ool2001fOol004aoo`03001o
ogoo01Aoo`8004Qoo`03001oogoo07=oo`00C7oo00<007ooOol05Woo0P00Agoo0P00Lgoo001<Ool0
0`00Oomoo`0HOol20017Ool00`00Oomoo`1`Ool004aoo`8001]oo`8004Ioo`80071oo`00C7oo00<0
07ooOol077oo0P00AWoo00<007ooOol0KGoo001<Ool00`00Oomoo`0NOol20015Ool00`00Oomoo`1/
Ool004aoo`03001oogoo021oo`8004Aoo`8006aoo`00C7oo00<007ooOol08Woo0P00A7oo00<007oo
Ool0JGoo001<Ool00`00Oomoo`0TOol20013Ool00`00Oomoo`1XOol004Eoo`03001oogoo00Aoo`03
001oogoo02Ioo`80049oo`03001oogoo06Moo`00A7oo00<007oo00001Goo00<007ooOol0:7oo0P00
@Goo00<007ooOol0IWoo0016Ool00`00Oomoo`03Ool3000ZOol20010Ool2001VOol004Aoo`8000Io
o`03001oogoo02aoo`80041oo`03001oogoo06=oo`00A7oo00<007ooOol01Goo00<007ooOol0;Woo
0P00?goo00<007ooOol0HWoo0014Ool30005Ool00`00Oomoo`0`Ool2000nOol00`00Oomoo`1QOol0
04aoo`03001oogoo039oo`8003eoo`03001oogoo061oo`00C7oo00<007ooOol0=7oo0P00?7oo0P00
H7oo001<Ool00`00Oomoo`0fOol00`00Oomoo`0kOol00`00Oomoo`1MOol004aoo`03001oogoo03Mo
o`8003aoo`03001oogoo05aoo`00C7oo0P00>Woo0P00>goo00<007ooOol0Fgoo001<Ool00`00Oomo
o`0kOol2000jOol00`00Oomoo`1JOol004aoo`03001oogoo03eoo`8003Uoo`8005Yoo`00C7oo00<0
07ooOol0?goo0P00>Goo00<007ooOol0Egoo001<Ool00`00Oomoo`11Ool00`00Oomoo`0gOol00`00
Oomoo`1FOol004aoo`03001oogoo049oo`8003Qoo`03001oogoo05Eoo`00C7oo00<007ooOol0A7oo
0P00=goo00<007ooOol0E7oo001<Ool00`00Oomoo`16Ool2000fOol00`00Oomoo`1COol004aoo`80
04Uoo`8003Eoo`03001oogoo059oo`00C7oo00<007ooOol0BWoo0P00=7oo00<007ooOol0DGoo001<
Ool00`00Oomoo`1<Ool3000bOol00`00Oomoo`1@Ool004aoo`03001oogoo04moo`80035oo`03001o
ogoo04moo`00C7oo00<007ooOol0DGoo0P00<7oo00<007ooOol0CWoo001<Ool00`00Oomoo`1COol2
000_Ool00`00Oomoo`1=Ool004aoo`03001oogoo05Eoo`8002ioo`03001oogoo04aoo`00C7oo00<0
07ooOol0Egoo0P00;Goo00<007ooOol0Bgoo001<Ool2001JOol2000/Ool00`00Oomoo`1:Ool004ao
o`03001oogoo05]oo`8002]oo`03001oogoo04Uoo`00C7oo00<007ooOol0GGoo00<007ooOol0:Goo
00<007ooOol0B7oo001<Ool00`00Oomoo`1NOol2000ZOol00`00Oomoo`17Ool004aoo`03001oogoo
061oo`8002Uoo`03001oogoo04Ioo`00C7oo00<007ooOol0HWoo0P009goo00<007ooOol0AWoo001<
Ool00`00Oomoo`1TOol2000VOol00`00Oomoo`15Ool004aoo`8006Moo`8002Eoo`03001oogoo04Ao
o`00C7oo00<007ooOol0J7oo0P0097oo00<007ooOol0@goo001<Ool00`00Oomoo`1ZOol2000SOol0
0`00Oomoo`12Ool004aoo`03001oogoo06aoo`80029oo`03001oogoo045oo`00C7oo00<007ooOol0
KWoo0P008Goo00<007ooOol0@7oo001<Ool00`00Oomoo`1`Ool2000POol00`00Oomoo`0oOol003io
o`D0009oo`03001oogoo00Aoo`03001oogoo079oo`8001moo`03001oogoo03ioo`00@7oo00L007oo
Oomoo`00Ool00005Ool00`00Oomoo`1dOol2000NOol00`00Oomoo`0mOol0041oo`07001oogooOol0
07oo00001Goo0`00MWoo0P0077oo00<007ooOol0?Goo0010Ool01`00Oomoogoo001oo`0000Eoo`03
001oogoo07Qoo`8001]oo`03001oogoo03aoo`00@7oo00L007ooOomoo`00Ool00005Ool00`00Oomo
o`1jOol00`00Oomoo`0IOol00`00Oomoo`0kOol003moo`8000Aoo`03001oogoo00Aoo`03001oogoo
07]oo`8001Yoo`03001oogoo03Yoo`00C7oo00<007ooOol0OGoo0P006Goo00<007ooOol0>Goo001<
Ool00`00Oomoo`1oOol2000HOol00`00Oomoo`0hOol004aoo`03001oogoo085oo`8001Ioo`03001o
ogoo03Qoo`00C7oo00<007ooOol0Pgoo0P005Goo00<007ooOol0=goo001<Ool20026Ool2000DOol0
0`00Oomoo`0fOol004aoo`03001oogoo08Moo`8001=oo`03001oogoo03Eoo`00C7oo00<007ooOol0
RGoo0P004Woo00<007ooOol0=7oo001<Ool00`00Oomoo`2;Ool2000AOol00`00Oomoo`0cOol004ao
o`03001oogoo08eoo`8000moo`03001oogoo03=oo`00C7oo00<007ooOol0Sgoo0P003Woo00<007oo
Ool0<Woo001<Ool00`00Oomoo`2AOol00`00Oomoo`0<Ool00`00Oomoo`0aOol004aoo`03001oogoo
099oo`8000eoo`03001oogoo031oo`00C7oo0P00UGoo0P0037oo00<007ooOol0;goo001<Ool00`00
Oomoo`2FOol2000:Ool00`00Oomoo`0_Ool004aoo`03001oogoo09Qoo`8000Uoo`03001oogoo02io
o`00C7oo00<007ooOol0VWoo0P0027oo00<007ooOol0;Goo001<Ool00`00Oomoo`2LOol20007Ool0
0`00Oomoo`0/Ool004aoo`03001oogoo09ioo`8000Ioo`03001oogoo02]oo`00C7oo00<007ooOol0
X7oo0P0017oo00<007ooOol0:goo001<Ool00`00Oomoo`2ROol20003Ool00`00Oomoo`0ZOol004ao
o`800:Eoo`80009oo`03001oogoo02Uoo`00C7oo00<007ooOol0YWoo0P0000=oo`00Ool0:Goo001<
Ool00`00Oomoo`2XOol3000YOol004aoo`03001oogoo0:Yoo`<002Moo`00C7oo00<007ooOol0Zgoo
00@007oo000002Eoo`00C7oo00<007ooOol0[7oo00<007ooOol00P008goo001<Ool00`00Oomoo`2]
Ool01000Oomoogoo0P008Goo001<Ool2002_Ool00`00Oomoo`02Ool2000OOol004aoo`03001oogoo
0:ioo`03001oogoo00Aoo`8001eoo`00C7oo00<007ooOol0[goo00<007ooOol01Goo0P006goo001<
Ool00`00Oomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`0HOol004aoo`03001oogoo0;5oo`03001o
ogoo00Ioo`8001Qoo`00C7oo00<007ooOol0/Woo00<007ooOol01goo0P005Woo000nOol50002Ool0
0`00Oomoo`04Ool00`00Oomoo`2bOol00`00Oomoo`09Ool2000DOol0041oo`07001oogooOol007oo
00001Goo00<007ooOol0/goo00<007ooOol02Woo0P004Woo0010Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool3002dOol00`00Oomoo`0;Ool2000@Ool0041oo`04001oogooOol20006Ool00`00Oomoo`2e
Ool00`00Oomoo`0<Ool2000>Ool0041oo`05001oogooOol00007Ool00`00Oomoo`2eOol00`00Oomo
o`0>Ool2000<Ool003moo`8000=oo`<000Eoo`03001oogoo0;Ioo`03001oogoo00moo`8000Yoo`00
C7oo00<007ooOol0]goo00<007ooOol047oo0P0027oo001<Ool00`00Oomoo`2hOol00`00Oomoo`0I
Ool004aoo`03001oogoo0;Qoo`03001oogoo01Uoo`00C7oo00<007ooOol0^Goo00<007ooOol067oo
001<Ool2002kOol00`00Oomoo`0GOol004aoo`03001oogoo0;]oo`03001oogoo01Ioo`00C7oo00<0
07ooOol0^goo00<007ooOol05Woo001<Ool00`00Oomoo`2lOol00`00Oomoo`0EOol004aoo`03001o
ogoo0;eoo`03001oogoo01Aoo`00C7oo00<007ooOol0_Woo00<007ooOol04goo001<Ool00`00Oomo
o`2nOol00`00Oomoo`0COol004aoo`03001oogoo0;moo`03001oogoo019oo`00C7oo0P00`Goo00<0
07ooOol04Goo001<Ool00`00Oomoo`30Ool00`00Oomoo`0AOol004aoo`03001oogoo0<5oo`03001o
ogoo011oo`00C7oo00<007ooOol0`Goo00<007ooOol047oo001<Ool00`00Oomoo`32Ool00`00Oomo
o`0?Ool004aoo`03001oogoo0<=oo`03001oogoo00ioo`00C7oo00<007ooOol0`goo00<007ooOol0
3Woo001<Ool00`00Oomoo`34Ool00`00Oomoo`0=Ool004aoo`800<Eoo`03001oogoo00eoo`00C7oo
00<007ooOol0aGoo00<007ooOol037oo001<Ool00`00Oomoo`36Ool00`00Oomoo`0;Ool004aoo`03
001oogoo0<Ioo`03001oogoo00]oo`00C7oo00<007ooOol0agoo00<007ooOol02Woo001<Ool00`00
Oomoo`38Ool00`00Oomoo`09Ool004aoo`03001oogoo0<Qoo`03001oogoo00Uoo`00C7oo0P00bWoo
00<007ooOol027oo001<Ool00`00Oomoo`39Ool00`00Oomoo`08Ool004aoo`03001oogoo0<Yoo`80
00Qoo`00C7oo00<007ooOol0e7oo001<Ool00`00Oomoo`3DOol004aoo`03001oogoo0=Aoo`00C7oo
00<007ooOol0e7oo0000\
\>"],
  ImageRangeCache->{{{0, 290}, {178, 0}} -> {-1.67178, -3.04387, 0.0218743, 
  0.128301}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This seeks a solution to the two equations."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({yvar \[Rule] \(-0.373863542611995747`\), 
      xvar \[Rule] \(-0.791287847537331856`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This looks for the other solution. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[{yvar \[Rule] 10, xvar \[Rule] 4}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({yvar \[Rule] 13.3738635426119967`, xvar \[Rule] 3.79128784753733194`}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2.6  Variable Management"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Mechanism models often need to have many adjustable parameters that can be \
tweaked between runs of the model. A ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model may have any number of user-defined variables, provided that all \
such variables in a model have numerical values before ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["User-Defined Variables"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"Symbolic parameters can enter a kinematic model in two ways. The coordinates \
of a local point can be given in symbolic form or the arguments of a \
constraint function that specify a distance or angle can be given as a \
symbolic expression. The following example shows how local point \
specifications can be symbolic."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This prevents impending spell check warnings."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \(xaxis; yaxis; angle; \), 
    \(On[General::"\<spell1\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"All local coordinates can be specified symbolically. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[xaxis, yaxis, radius, angle]\), 
    \(\(Point[2, {xaxis, yaxis}]; \)\), 
    \(\(Body[2, PointList \[Rule] {{0, 0}, {xaxis, yaxis}}]; \)\), 
    \(\(Line[3, {0, 0}, radius\ {Cos[angle], Sin[angle]}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The crankshaft-piston model can be built with several variables in the \
arguments to its constraint functions. The following example introduces \
symbols into the model to represent the frequency of the crankshaft rotation, \
the length of the connecting rod, and the stroke of the crankshaft. "], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the crankshaft-piston body objects, with a symbol included in the \
points list. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[stroke]\), 
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(piston = 3; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(bd[ground] = Body[ground, PointList \[Rule] {{0, 0}, {0, 4}, {0, 9}}]; 
    \nbd[crank] = Body[crank, PointList \[Rule] {{0, 0}, {stroke/2, 0}}]; \n
    bd[piston] = Body[piston, PointList \[Rule] {{0, 0}, {0, 4}, {0, 6}}]; 
    \)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetBodies[bd[ground], bd[crank], bd[piston]]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This builds the constraint equations with two symbols embedded. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[crankfreq, rodlength]\), 
    \(SetConstraints[\n\tRevolute2[1, Point[ground, 1], Point[crank, 1]], \n\t
      RotationLock1[2, crank, 2.0\ \[Pi]\ crankfreq\ T], \n\t
      Translate2[3, Line[ground, 2, 3], Line[piston, 2, 3]], \n\t
      RelativeDistance1[4, \n\t\tPoint[crank, 2], Point[piston, 2], 
        rodlength]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "If ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called now to seek a solution, an error message is generated because \
some of the symbols in the model have not yet been defined. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This attempts to find a solution. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SolveMech::"undef" \( : \ \) 
      "SolveMech called with undefined variables present.  Use \
CheckSystem."\)], "Message"],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 0, X3 \[Rule] 0, 
      Y3 \[Rule] 0, Th3 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["CheckSystem[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " checks the model for errors such as stray variables or redundant \
constraints. ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " if any errors are found, and generates a message describing the error."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A debugging aid. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " reports the names of any undefined symbols, as well as several other \
possible errors in the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This checks the integrity of the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CheckSystem[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CheckSystem::"undef" \( : \ \) 
      "The current system contains the following undefined Symbols: \
\!\({crankfreq, rodlength, stroke}\)"\)], "Message"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This defines the undefined symbols, checks the model, and runs it. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(crankfreq = 2; \)\), 
    \(\(stroke = 5.5; \)\), 
    \(\(rodlength = 4.1; \)\), 
    \(CheckSystem[]\), 
    \(SolveMech[0]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(True\)], "Output"],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 0.`, Y2 \[Rule] 0.`, Th2 \[Rule] 0.`, 
      X3 \[Rule] 0.`, Y3 \[Rule] \(-0.959029760092920824`\), Th3 \[Rule] 0.`}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData["Dependent Variables  "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "It is acceptable to use ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " dependent variables explicitly when defining local points or constraints. \
Highly abstract compound constraints can be specified in this manner. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This is an extremely obtuse constraint. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(RelativeY1[1, Point[2, {1, 0}], X3\^2]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "This constraint would cause the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of a point on body 2 to be equal to the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the origin of body 3, squared. When using dependent \
variables in constraints, care must be taken to ensure that the dependence of \
the constraint on the variables is explicit at the time that ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run. If not, differentiation with respect to those variables cannot \
occur, and the constraints will not be processed correctly. \n\nNote that the \
names of the dependent variables used by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " are cleared and protected when ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run. Thus, if there happens to be a definition in place such as ",
  StyleBox["Y2 = 3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", it is removed by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Parameters"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another method of managing variables in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model is to use the \"parameters\" functions. The parameters list is \
basically a list of rules stored in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s internal database that is applied to the mechanism model immediately \
before the solution phase. By using parameters, problems can be avoided such \
as failing to define all of the symbols in a model or accidentally defining \
them before ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run and hard coding them into the model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  StyleBox["\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["numbe",
    FontSlant->"Italic"],
  StyleBox["r",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["... ",
    FontFamily->"Times"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " adds ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  " with numerical values to the parameters list and protects ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["ClearParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " clears ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  " from the parameters list. \n\n",
  StyleBox["Parameters[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of rules showing the values of all of the currently \
defined parameters.\n\n",
  StyleBox["Parameterize[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["defsyms",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts defined symbols ",
  StyleBox["defsyms",
    FontSlant->"Italic"],
  ", unsets them, and adds them to the parameters list with the numerical \
values of their previous definitions. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Parameter management functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Note that when a parameter is set with ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Parameterize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", it is protected until it is unset with ",
  StyleBox["ClearParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is to ensure that the parameter cannot be accidentally given a \
definition in the course of running the model. \n\nThe crankshaft-piston \
model, which was built in the previous subsection, is used to demonstrate the \
use of parameters. The definitions of the three symbols in the model are \
cleared and then added to the parameters list. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This adds three symbols to the parameters list. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[crankfreq, stroke, rodlength]; \)\), 
    \(SetParameters[crankfreq \[Rule] 2, stroke \[Rule] 5.5, 
      rodlength \[Rule] 4.1]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(crankfreq \[Rule] 2\), ",", 
        RowBox[{"rodlength", "\[Rule]", 
          StyleBox["4.09999999999999964`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", 
        RowBox[{"stroke", "\[Rule]", 
          StyleBox["5.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The crankshaft-piston model can now be built without worrying about the \
definitions of the parameters. ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used at any time in the model-building process. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here the crankshaft-piston model is rebuilt with reference to the body \
objects previously defined. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRevolute2[1, Point[ground, 1], Point[crank, 1]], \n\t
      RotationLock1[2, crank, 2.0\ \[Pi]\ crankfreq\ T], \n\t
      Translate2[3, Line[ground, 2, 3], Line[piston, 2, 3]], \n\t
      RelativeDistance1[4, \n\t\tPoint[crank, 2], Point[piston, 2], 
        rodlength]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The parameters are included in the solution rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[.1] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(crankfreq \[Rule] 2\), ",", 
        RowBox[{"rodlength", "\[Rule]", 
          StyleBox["4.09999999999999964`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", 
        RowBox[{"stroke", "\[Rule]", 
          StyleBox["5.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 1.25663706143591724`\), ",", 
        \(X3 \[Rule] 0\), ",", \(Y3 \[Rule] 2.62637107785221557`\), ",", 
        \(Th3 \[Rule] 0\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Set a new value for ",
  StyleBox["crankfreq",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Only the specified value is updated, the others are left unchanged. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetParameters[crankfreq \[Rule] 3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(crankfreq \[Rule] 3\), ",", 
        RowBox[{"rodlength", "\[Rule]", 
          StyleBox["4.09999999999999964`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", 
        RowBox[{"stroke", "\[Rule]", 
          StyleBox["5.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The parameters are protected."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(rodlength = 4; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Set::"wrsym" \( : \ \) "Symbol \!\(rodlength\) is Protected."\)], 
  "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This removes all of the parameters from the parameters list."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ClearParameters[All]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{480, 684},
WindowMargins->{{56, Automatic}, {Automatic, 12}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 87, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1843, 57, 78, 2, 47, "Subsection"],
Cell[1924, 61, 1257, 33, 224, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3218, 99, 108, 3, 33, "Section",
  PageBreakAbove->True],
Cell[3329, 104, 942, 29, 129, "Text"],

Cell[CellGroupData[{
Cell[4296, 137, 75, 2, 47, "Subsection"],
Cell[4374, 141, 394, 15, 53, "Text"],

Cell[CellGroupData[{
Cell[4793, 160, 546, 20, 55, "Special3"],
Cell[5342, 182, 127, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[5484, 188, 860, 32, 94, "Text"],

Cell[CellGroupData[{
Cell[6369, 224, 70, 2, 23, "Special5"],
Cell[6442, 228, 1641, 65, 101, "Special3"],
Cell[8086, 295, 202, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[8325, 309, 70, 2, 23, "Special5"],
Cell[8398, 313, 2394, 98, 116, "Special3"],
Cell[10795, 413, 202, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[11034, 427, 83, 2, 23, "Special5"],
Cell[11120, 431, 482, 12, 101, "Special3"],
Cell[11605, 445, 215, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[11835, 457, 1079, 28, 189, "Text"],
Cell[12917, 487, 90, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[13032, 493, 188, 8, 24, "SmallText"],
Cell[13223, 503, 84, 2, 25, "Input"]
}, Open  ]],
Cell[13322, 508, 469, 11, 90, "Text"],

Cell[CellGroupData[{
Cell[13816, 523, 129, 3, 24, "SmallText"],
Cell[13948, 528, 59295, 3260, 247, 20844, 2780, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[73258, 3791, 318, 6, 59, "Special1"],

Cell[CellGroupData[{
Cell[73601, 3801, 126, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[73752, 3807, 258, 7, 105, "Input"],
Cell[74013, 3816, 50, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[74090, 3821, 352, 9, 59, "Special1"],

Cell[CellGroupData[{
Cell[74467, 3834, 122, 2, 24, "SmallText"],
Cell[74592, 3838, 232, 7, 85, "Input"]
}, Open  ]],
Cell[74839, 3848, 415, 12, 59, "Special1"],

Cell[CellGroupData[{
Cell[75279, 3864, 121, 2, 24, "SmallText"],
Cell[75403, 3868, 234, 7, 85, "Input"]
}, Open  ]],
Cell[75652, 3878, 95, 2, 43, "Subsubsection"],
Cell[75750, 3882, 523, 18, 72, "Text"],

Cell[CellGroupData[{
Cell[76298, 3904, 174, 4, 24, "SmallText"],
Cell[76475, 3910, 204, 5, 65, "Input"]
}, Open  ]],
Cell[76694, 3918, 519, 13, 110, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[77250, 3936, 89, 2, 31, "Subsection"],
Cell[77342, 3940, 314, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[77681, 3956, 767, 30, 55, "Special3"],
Cell[78451, 3988, 139, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[78605, 3994, 2873, 87, 464, "Text"],

Cell[CellGroupData[{
Cell[81503, 4085, 129, 3, 24, "SmallText"],
Cell[81635, 4090, 89, 2, 25, "Input"]
}, Open  ]],
Cell[81739, 4095, 1073, 33, 171, "Text"],

Cell[CellGroupData[{
Cell[82837, 4132, 143, 4, 24, "SmallText"],
Cell[82983, 4138, 120, 3, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83140, 4146, 37, 0, 24, "SmallText"],
Cell[83180, 4148, 145, 3, 45, "Input"]
}, Open  ]],
Cell[83340, 4154, 102, 2, 43, "Subsubsection"],
Cell[83445, 4158, 521, 17, 73, "Text"],

Cell[CellGroupData[{
Cell[83991, 4179, 129, 3, 24, "SmallText"],
Cell[84123, 4184, 115, 2, 25, "Input"]
}, Open  ]],
Cell[84253, 4189, 92, 2, 43, "Subsubsection"],
Cell[84348, 4193, 277, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[84650, 4208, 565, 24, 40, "Special3"],
Cell[85218, 4234, 209, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[85464, 4248, 137, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[85626, 4255, 79, 2, 25, "Input"],
Cell[85708, 4259, 168, 5, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[85925, 4270, 190, 8, 24, "SmallText"],
Cell[86118, 4280, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[86248, 4289, 131, 3, 33, "Section",
  PageBreakAbove->True],
Cell[86382, 4294, 973, 32, 128, "Text"],

Cell[CellGroupData[{
Cell[87380, 4330, 2076, 80, 179, "Special3"],
Cell[89459, 4412, 203, 8, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[89699, 4425, 86, 2, 47, "Subsection"],
Cell[89788, 4429, 1258, 40, 168, "Text"],

Cell[CellGroupData[{
Cell[91071, 4473, 81, 2, 23, "Special5"],
Cell[91155, 4477, 1524, 62, 103, "Special3"],
Cell[92682, 4541, 140, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[92859, 4549, 81, 2, 23, "Special5"],
Cell[92943, 4553, 1749, 72, 103, "Special3"],
Cell[94695, 4627, 140, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[94850, 4633, 365, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[95240, 4643, 188, 8, 24, "SmallText"],
Cell[95431, 4653, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95552, 4660, 123, 2, 24, "SmallText"],
Cell[95678, 4664, 180, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95895, 4674, 125, 2, 24, "SmallText"],
Cell[96023, 4678, 154, 4, 65, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[96226, 4688, 87, 2, 31, "Subsection"],
Cell[96316, 4692, 1459, 43, 228, "Text"],

Cell[CellGroupData[{
Cell[97800, 4739, 80, 2, 23, "Special5"],
Cell[97883, 4743, 1568, 64, 103, "Special3"],
Cell[99454, 4809, 141, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[99632, 4817, 80, 2, 23, "Special5"],
Cell[99715, 4821, 1750, 72, 103, "Special3"],
Cell[101468, 4895, 141, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[101624, 4901, 362, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[102011, 4911, 122, 2, 24, "SmallText"],
Cell[102136, 4915, 174, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102347, 4925, 124, 2, 24, "SmallText"],
Cell[102474, 4929, 121, 3, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[102644, 4938, 85, 2, 31, "Subsection"],
Cell[102732, 4942, 1654, 54, 247, "Text"],

Cell[CellGroupData[{
Cell[104411, 5000, 81, 2, 23, "Special5"],
Cell[104495, 5004, 2909, 123, 164, "Special3"],
Cell[107407, 5129, 139, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[107583, 5137, 80, 2, 23, "Special5"],
Cell[107666, 5141, 2941, 126, 164, "Special3"],
Cell[110610, 5269, 139, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[110764, 5275, 368, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[111157, 5285, 125, 2, 24, "SmallText"],
Cell[111285, 5289, 254, 6, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111576, 5300, 122, 2, 24, "SmallText"],
Cell[111701, 5304, 210, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111948, 5313, 124, 2, 24, "SmallText"],
Cell[112075, 5317, 143, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112255, 5325, 292, 12, 24, "SmallText"],
Cell[112550, 5339, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[112668, 5347, 86, 2, 31, "Subsection"],
Cell[112757, 5351, 1636, 45, 286, "Text"],
Cell[114396, 5398, 80, 2, 23, "Special5"],
Cell[114479, 5402, 4460, 190, 195, "Special3"],
Cell[118942, 5594, 137, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[119082, 5599, 371, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[119478, 5609, 188, 8, 24, "SmallText"],
Cell[119669, 5619, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119790, 5626, 123, 2, 24, "SmallText"],
Cell[119916, 5630, 302, 8, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120255, 5643, 121, 2, 24, "SmallText"],
Cell[120379, 5647, 177, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120593, 5655, 127, 2, 24, "SmallText"],
Cell[120723, 5659, 225, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120985, 5669, 292, 12, 24, "SmallText"],
Cell[121280, 5683, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[121398, 5691, 85, 2, 31, "Subsection"],
Cell[121486, 5695, 2384, 77, 326, "Text"],

Cell[CellGroupData[{
Cell[123895, 5776, 81, 2, 23, "Special5"],
Cell[123979, 5780, 3124, 130, 179, "Special3"],
Cell[127106, 5912, 139, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[127282, 5920, 81, 2, 23, "Special5"],
Cell[127366, 5924, 5632, 233, 316, "Special3"],
Cell[133001, 6159, 139, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[133155, 6165, 425, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[133605, 6176, 188, 8, 24, "SmallText"],
Cell[133796, 6186, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133917, 6193, 123, 2, 24, "SmallText"],
Cell[134043, 6197, 254, 6, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134334, 6208, 135, 3, 24, "SmallText"],
Cell[134472, 6213, 215, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134724, 6222, 126, 2, 24, "SmallText"],
Cell[134853, 6226, 193, 4, 65, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[135095, 6236, 96, 2, 31, "Subsection"],
Cell[135194, 6240, 543, 14, 91, "Text"],
Cell[135740, 6256, 80, 2, 23, "Special5"],

Cell[CellGroupData[{
Cell[135845, 6262, 120, 2, 24, "SmallText"],
Cell[135968, 6266, 111, 3, 45, "Input"]
}, Open  ]],
Cell[136094, 6272, 80, 2, 23, "Special5"],

Cell[CellGroupData[{
Cell[136199, 6278, 119, 2, 24, "SmallText"],
Cell[136321, 6282, 138, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136496, 6290, 190, 8, 24, "SmallText"],
Cell[136689, 6300, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[136819, 6309, 124, 3, 33, "Section",
  PageBreakAbove->True],
Cell[136946, 6314, 628, 17, 92, "Text"],

Cell[CellGroupData[{
Cell[137599, 6335, 94, 2, 47, "Subsection"],
Cell[137696, 6339, 150, 4, 33, "Text"],
Cell[137849, 6345, 1508, 59, 161, "Special3"],
Cell[139360, 6406, 139, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[139502, 6411, 669, 19, 111, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[140208, 6435, 100, 2, 31, "Subsection"],
Cell[140311, 6439, 1587, 31, 340, "Text"],
Cell[141901, 6472, 1042, 39, 101, "Special3"],
Cell[142946, 6513, 195, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[143144, 6520, 2746, 117, 225, "Special3"],
Cell[145893, 6639, 190, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[146086, 6646, 1395, 57, 132, "Special3"],
Cell[147484, 6705, 192, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[147679, 6712, 1343, 54, 117, "Special3"],
Cell[149025, 6768, 188, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[149216, 6775, 467, 19, 55, "Special3"],
Cell[149686, 6796, 184, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[149873, 6803, 916, 27, 169, "Text"],

Cell[CellGroupData[{
Cell[150814, 6834, 189, 8, 24, "SmallText"],
Cell[151006, 6844, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151127, 6851, 259, 9, 24, "SmallText"],
Cell[151389, 6862, 314, 7, 125, "Input"]
}, Open  ]],
Cell[151718, 6872, 300, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[152043, 6885, 116, 2, 24, "SmallText"],
Cell[152162, 6889, 100, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[152299, 6896, 37, 0, 24, "SmallText"],
Cell[152339, 6898, 160, 3, 45, "Input"]
}, Open  ]],
Cell[152514, 6904, 302, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[152841, 6917, 125, 2, 24, "SmallText"],
Cell[152969, 6921, 142, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153148, 6929, 190, 8, 24, "SmallText"],
Cell[153341, 6939, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[153459, 6947, 100, 2, 31, "Subsection"],
Cell[153562, 6951, 1581, 31, 340, "Text"],
Cell[155146, 6984, 1696, 70, 103, "Special3"],
Cell[156845, 7056, 194, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[157042, 7063, 4952, 199, 411, "Special3"],
Cell[161997, 7264, 181, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[162181, 7271, 1622, 65, 148, "Special3"],
Cell[163806, 7338, 174, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[163983, 7345, 1435, 57, 132, "Special3"],
Cell[165421, 7404, 169, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[165593, 7411, 1824, 68, 164, "Special3"],
Cell[167420, 7481, 163, 4, 18, "Special4",
  PageBreakAbove->False],
Cell[167586, 7487, 373, 13, 55, "Special3"],
Cell[167962, 7502, 168, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[168133, 7509, 2990, 112, 317, "Special3"],
Cell[171126, 7623, 169, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[171298, 7630, 2384, 76, 269, "Special3"],
Cell[173685, 7708, 184, 5, 18, "Special4",
  PageBreakAbove->False],
Cell[173872, 7715, 825, 20, 168, "Text"],

Cell[CellGroupData[{
Cell[174722, 7739, 189, 8, 24, "SmallText"],
Cell[174914, 7749, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175035, 7756, 239, 8, 24, "SmallText"],
Cell[175277, 7766, 402, 9, 185, "Input"]
}, Open  ]],
Cell[175694, 7778, 318, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[176037, 7794, 217, 8, 24, "SmallText"],
Cell[176257, 7804, 159, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176453, 7812, 37, 0, 24, "SmallText"],
Cell[176493, 7814, 252, 5, 85, "Input"]
}, Open  ]],
Cell[176760, 7822, 300, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[177085, 7835, 125, 2, 24, "SmallText"],
Cell[177213, 7839, 148, 3, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[177410, 7848, 102, 2, 31, "Subsection"],
Cell[177515, 7852, 177, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[177717, 7860, 745, 26, 71, "Special3"],
Cell[178465, 7888, 135, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[178615, 7894, 459, 15, 73, "Text"],

Cell[CellGroupData[{
Cell[179099, 7913, 121, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[179245, 7919, 103, 2, 26, "Input"],
Cell[179351, 7923, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[179460, 7930, 191, 8, 24, "SmallText"],
Cell[179654, 7940, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[179784, 7949, 124, 3, 33, "Section",
  PageBreakAbove->True],
Cell[179911, 7954, 796, 22, 111, "Text"],

Cell[CellGroupData[{
Cell[180732, 7980, 94, 2, 47, "Subsection"],
Cell[180829, 7984, 484, 15, 72, "Text"],

Cell[CellGroupData[{
Cell[181338, 8003, 937, 32, 86, "Special3"],
Cell[182278, 8037, 136, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[182429, 8043, 250, 8, 53, "Text"],

Cell[CellGroupData[{
Cell[182704, 8055, 1475, 52, 195, "Special3"],
Cell[184182, 8109, 211, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[184442, 8124, 91, 2, 31, "Subsection"],
Cell[184536, 8128, 580, 18, 92, "Text"],

Cell[CellGroupData[{
Cell[185141, 8150, 1536, 51, 178, "Special3"],
Cell[186680, 8203, 125, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[186842, 8211, 189, 8, 24, "SmallText"],
Cell[187034, 8221, 84, 2, 25, "Input"]
}, Open  ]],
Cell[187133, 8226, 337, 9, 72, "Text"],

Cell[CellGroupData[{
Cell[187495, 8239, 124, 2, 24, "SmallText"],
Cell[187622, 8243, 155, 5, 85, "Input"],
Cell[187780, 8250, 424, 9, 145, "Input"],
Cell[188207, 8261, 101, 2, 25, "Input"]
}, Open  ]],
Cell[188323, 8266, 293, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[188641, 8279, 219, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[188885, 8291, 73, 2, 25, "Input"],
Cell[188961, 8295, 52, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[189040, 8300, 638, 18, 130, "Text"],

Cell[CellGroupData[{
Cell[189703, 8322, 221, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[189949, 8334, 73, 2, 25, "Input"],
Cell[190025, 8338, 183, 4, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[190235, 8346, 1670, 59, 172, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[191942, 8410, 95, 2, 31, "Subsection"],
Cell[192040, 8414, 327, 11, 53, "Text"],

Cell[CellGroupData[{
Cell[192392, 8429, 2004, 74, 210, "Special3"],
Cell[194399, 8505, 146, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[194582, 8513, 628, 20, 88, "Special3"],
Cell[195213, 8535, 202, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[195430, 8547, 578, 16, 91, "Text"],

Cell[CellGroupData[{
Cell[196033, 8567, 124, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[196182, 8573, 103, 3, 45, "Input"],
Cell[196288, 8578, 127, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[196464, 8586, 268, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[196757, 8602, 103, 2, 25, "Input"],
Cell[196863, 8606, 367, 10, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[197279, 8622, 125, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[197429, 8628, 99, 2, 45, "Input"],
Cell[197531, 8632, 207, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[197765, 8639, 594, 21, 73, "Text"],

Cell[CellGroupData[{
Cell[198384, 8664, 206, 8, 24, "SmallText"],
Cell[198593, 8674, 154, 4, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198784, 8683, 110, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[198919, 8689, 70, 2, 25, "Input"],
Cell[198992, 8693, 127, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[199180, 8702, 100, 2, 31, "Subsection"],
Cell[199283, 8706, 885, 26, 133, "Text"],

Cell[CellGroupData[{
Cell[200193, 8736, 294, 12, 24, "SmallText"],
Cell[200490, 8750, 96, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200623, 8757, 137, 3, 24, "SmallText"],
Cell[200763, 8762, 101, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[200901, 8769, 192, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[201118, 8781, 73, 2, 25, "Input"],
Cell[201194, 8785, 170, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[201391, 8792, 382, 10, 72, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[201810, 8807, 90, 2, 31, "Subsection"],
Cell[201903, 8811, 346, 12, 54, "Text"],

Cell[CellGroupData[{
Cell[202274, 8827, 383, 15, 40, "Special3"],
Cell[202660, 8844, 127, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[202802, 8850, 824, 31, 94, "Text"],

Cell[CellGroupData[{
Cell[203651, 8885, 969, 33, 149, "Special3"],
Cell[204623, 8920, 122, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[204760, 8926, 1158, 40, 152, "Text"],

Cell[CellGroupData[{
Cell[205943, 8970, 143, 4, 24, "SmallText"],
Cell[206089, 8976, 224, 6, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206350, 8987, 200, 8, 24, "SmallText"],
Cell[206553, 8997, 128, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206718, 9005, 198, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[206941, 9017, 104, 3, 45, "Input"],
Cell[207048, 9022, 190, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[207287, 9031, 191, 8, 24, "SmallText"],
Cell[207481, 9041, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[207611, 9050, 123, 3, 33, "Section",
  PageBreakAbove->True],
Cell[207737, 9055, 546, 16, 92, "Text"],

Cell[CellGroupData[{
Cell[208308, 9075, 89, 2, 47, "Subsection"],
Cell[208400, 9079, 605, 16, 111, "Text"],

Cell[CellGroupData[{
Cell[209030, 9099, 211, 7, 40, "Special3"],
Cell[209244, 9108, 175, 7, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[209434, 9118, 98, 2, 43, "Subsubsection"],
Cell[209535, 9122, 887, 27, 131, "Text"],

Cell[CellGroupData[{
Cell[210447, 9153, 461, 18, 56, "Special3"],
Cell[210911, 9173, 123, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[211049, 9179, 348, 12, 54, "Text"],

Cell[CellGroupData[{
Cell[211422, 9195, 2167, 89, 162, "Special3"],
Cell[213592, 9286, 211, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[213818, 9298, 859, 27, 112, "Text"],

Cell[CellGroupData[{
Cell[214702, 9329, 189, 8, 24, "SmallText"],
Cell[214894, 9339, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215015, 9346, 138, 3, 24, "SmallText"],
Cell[215156, 9351, 130, 4, 65, "Input"],
Cell[215289, 9357, 404, 8, 165, "Input"],
Cell[215696, 9367, 348, 12, 54, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[216081, 9384, 132, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[216238, 9391, 80, 2, 25, "Input"],
Cell[216321, 9395, 404, 9, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[216774, 9410, 134, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[216933, 9417, 88, 2, 25, "Input"],
Cell[217024, 9421, 429, 6, 86, "Output"]
}, Open  ]]
}, Open  ]],
Cell[217480, 9431, 585, 15, 92, "Text"],

Cell[CellGroupData[{
Cell[218090, 9450, 207, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[218322, 9462, 93, 2, 25, "Input"],
Cell[218418, 9466, 209, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[218654, 9473, 110, 2, 43, "Subsubsection"],
Cell[218767, 9477, 1133, 43, 101, "Special3"],
Cell[219903, 9522, 222, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[220128, 9533, 450, 11, 91, "Text"],

Cell[CellGroupData[{
Cell[220603, 9548, 330, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[220958, 9564, 191, 3, 65, "Input"],
Cell[221152, 9569, 403, 9, 48, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[221616, 9585, 101, 2, 31, "Subsection"],
Cell[221720, 9589, 589, 21, 74, "Text"],

Cell[CellGroupData[{
Cell[222334, 9614, 2676, 103, 214, "Special3"],
Cell[225013, 9719, 204, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[225232, 9731, 579, 20, 74, "Text"],

Cell[CellGroupData[{
Cell[225836, 9755, 1130, 34, 151, "Special3"],
Cell[226969, 9791, 206, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[227190, 9803, 102, 2, 43, "Subsubsection"],
Cell[227295, 9807, 1483, 35, 343, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[228815, 9847, 105, 2, 31, "Subsection"],
Cell[228923, 9851, 987, 29, 187, "Text"],
Cell[229913, 9882, 1296, 49, 87, "Special3"],
Cell[231212, 9933, 135, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[231350, 9938, 203, 7, 33, "Text"],

Cell[CellGroupData[{
Cell[231578, 9949, 119, 2, 24, "SmallText"],
Cell[231700, 9953, 146, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231883, 9962, 115, 2, 24, "SmallText"],
Cell[232001, 9966, 182, 3, 68, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[232220, 9974, 138, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[232383, 9981, 123, 3, 26, "Input"],
Cell[232509, 9986, 13362, 430, 187, 4311, 312, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[245920, 10422, 122, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[246067, 10428, 70, 2, 25, "Input"],
Cell[246140, 10432, 123, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[246312, 10440, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[246451, 10446, 103, 2, 25, "Input"],
Cell[246557, 10450, 111, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[246717, 10458, 190, 8, 24, "SmallText"],
Cell[246910, 10468, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[247040, 10477, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[247168, 10482, 468, 13, 91, "Text"],

Cell[CellGroupData[{
Cell[247661, 10499, 102, 2, 47, "Subsection"],

Cell[CellGroupData[{
Cell[247788, 10505, 189, 8, 24, "SmallText"],
Cell[247980, 10515, 84, 2, 25, "Input"]
}, Open  ]],
Cell[248079, 10520, 396, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[248500, 10531, 124, 2, 24, "SmallText"],
Cell[248627, 10535, 155, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[248819, 10544, 133, 3, 24, "SmallText"],
Cell[248955, 10549, 270, 5, 85, "Input"]
}, Open  ]],
Cell[249240, 10557, 372, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[249637, 10568, 170, 4, 24, "SmallText"],
Cell[249810, 10574, 154, 5, 85, "Input"],
Cell[249967, 10581, 288, 5, 125, "Input"],
Cell[250258, 10588, 109, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[250404, 10595, 147, 4, 24, "SmallText"],
Cell[250554, 10601, 388, 7, 145, "Input"]
}, Open  ]],
Cell[250957, 10611, 300, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[251282, 10624, 113, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[251420, 10630, 71, 2, 25, "Input"],
Cell[251494, 10634, 143, 3, 44, "Message"],
Cell[251640, 10639, 140, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[251807, 10645, 487, 16, 71, "Special3"],
Cell[252297, 10663, 120, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[252420, 10668, 259, 8, 53, "Text"],

Cell[CellGroupData[{
Cell[252704, 10680, 118, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[252847, 10686, 72, 2, 25, "Input"],
Cell[252922, 10690, 174, 3, 63, "Message"],
Cell[253099, 10695, 39, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[253187, 10702, 150, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[253362, 10710, 188, 6, 105, "Input"],
Cell[253553, 10718, 38, 1, 29, "Output"],
Cell[253594, 10721, 182, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[253803, 10728, 104, 2, 43, "Subsubsection"],
Cell[253910, 10732, 302, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[254237, 10744, 119, 2, 24, "SmallText"],
Cell[254359, 10748, 103, 2, 26, "Input"]
}, Open  ]],
Cell[254477, 10753, 1176, 33, 188, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[255690, 10791, 90, 2, 31, "Subsection"],
Cell[255783, 10795, 707, 18, 129, "Text"],

Cell[CellGroupData[{
Cell[256515, 10817, 1558, 58, 178, "Special3"],
Cell[258076, 10877, 134, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[258225, 10883, 772, 20, 149, "Text"],

Cell[CellGroupData[{
Cell[259022, 10907, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[259174, 10913, 197, 4, 65, "Input"],
Cell[259374, 10919, 395, 10, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[259796, 10933, 327, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[260148, 10946, 181, 4, 24, "SmallText"],
Cell[260332, 10952, 348, 6, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[260717, 10963, 231, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[260973, 10975, 80, 2, 25, "Input"],
Cell[261056, 10979, 738, 17, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[261843, 11002, 257, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[262125, 11014, 93, 2, 25, "Input"],
Cell[262221, 11018, 395, 10, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[262665, 11034, 108, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[262798, 11040, 78, 2, 25, "Input"],
Cell[262879, 11044, 99, 2, 25, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[263027, 11052, 140, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[263192, 11059, 79, 2, 25, "Input"],
Cell[263274, 11063, 36, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[263359, 11070, 190, 8, 24, "SmallText"],
Cell[263552, 11080, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

