(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1171567,      34622]*)
(*NotebookOutlinePosition[   1172511,      34654]*)
(*  CellTagsIndexPosition[   1172467,      34650]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["3.  Output Functions", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  "'s numerical and graphical output functions. In general, ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s output functions are used to convert the symbolic coordinates that \
define the location and orientation of each body into more specialized \
quantities, such as the distance between two points or the angle between two \
lines. Graphical output functions use the symbolic coordinates to locate \
graphics primitives to reflect the location of the bodies in the model. \
Throughout this chapter, ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output functions are used as a supplement to, not a replacement for, \
built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions. Most output from ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " is generated through a mixture of both. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3.1  2D Output Functions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Numerical output from a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model can be generated with output functions that are defined in the \
auxiliary package ",
  StyleBox["Graf2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This package is autoloaded after the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " main package has been loaded if any of the output functions are called. \
Each output function returns a symbolic expression that represents the \
quantity being sought, in terms of the model's dependent variables, ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on. To achieve a numerical result, the dependent variables must \
be replaced with numbers, usually by applying a solution rule returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". More complicated and specific output functions can easily be defined by \
the user, making use of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s basic output functions and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in vector algebra functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " output functions, a 2D model is developed that can have various geometric \
quantities measured. The model is a planar quick-return mechanism consisting \
of three moving bodies: the crank, drive arm, and slider. A real quick-return \
mechanism would have a fourth body, the connecting rod between the drive arm \
and the slider, but this body is simply modeled with a relative-distance \
constraint.\n\nThe motion of the quick-return mechanism is driven by the \
rotation of the crank which, in turn, forces the drive arm to rock about its \
lower pivot point on the ground, via a pin on the crank that slides in a \
straight slot on the drive arm. The top of the drive arm is attached to a \
connecting rod, which is attached to the slider, which slides on horizontal \
path on the ground."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData["Here is a graphic of the 2D quick-return model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!  
%%Creator: Mathematica  
%%AspectRatio: .61905   
MathPictureStart  
%% Graphics  
/Courier findfont 10  scalefont  setfont  
% Scaling calculations  
0.285714 0.047619 0.047619 0.047619 [  
[ 0 0 0 0 ]  
[ 1 .61905 0 0 ]  
] MathScale  
% Start of Graphics  
1 setlinecap  
1 setlinejoin  
newpath  
[ ] 0 setdash  
0 g  
p  
P  
0 0 m  
1 0 L  
1 .61905 L  
0 .61905 L  
closepath  
clip  
newpath  
p  
p  
p  
.01 w  
.04762 .52381 m  
.85714 .52381 L  
.85714 .04762 L  
.04762 .04762 L  
.04762 .52381 L  
.04762 .42857 L  
.28571 .28571 L  
.04762 .14286 L  
s  
P  
P  
p  
1 0 0 r  
.01 w  
newpath  
.28571 .28571 .19048 0 365.73 arc  
s  
.32986 .14985 m  
.32986 .14985 .02857 0 365.73 arc  
F  
.28571 .28571 m  
.28571 .28571 .02857 0 365.73 arc  
F  
P  
p  
p  
0 1 0 r  
.004 w  
.28571 .04762 m  
.28571 .04762 .02857 0 365.73 arc  
F  
.45562 .44107 m  
.45562 .44107 .02857 0 365.73 arc  
F  
.2726 .05328 m  
.29883 .04196 L  
.46873 .43541 L  
.4425 .44674 L  
F  
P  
p  
.02 w  
.28571 .04762 Mdot  
.45562 .44107 Mdot  
P  
p  
.02 w  
.32986 .14985 Mdot  
P  
p  
.01 w  
.32347 .13505 m  
.43674 .39736 L  
s  
P  
P  
p  
p  
0 0 1 r  
.004 w  
.67888 .52381 m  
.67888 .52381 .01905 0 365.73 arc  
F  
.67888 .57143 m  
.67888 .52381 L  
.82173 .52381 L  
.82173 .57143 L  
F  
P  
.018 w  
.45562 .44107 m  
.67888 .52381 L  
s  
P  
P  
% End of Graphics  
MathPictureEnd  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{305, 189},
  ImageMargins->{{99, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004a0000_A000`40O003h00Oogoo<Woo003oOolb
Ool00?mooc9oo`00ogoo<Woo003oOolbOol00?mooc9oo`00ogoo<Woo001DOol50n3HOol0055oo`/3
h=Eoo`00DGoo30?Pe7oo001@Ool>0n3COol004moo`l3h==oo`00Cgoo40?PdWoo001>Ool80n000`00
0n03h0060n3BOol000eood4000L3h0<000L3h:L002]oo`003Goo@@001P?P1@001P?PY`00:goo000=
Oom100070n0300070n2W000[Ool000eoo`<003ioo`P3h0030003h0?P00H3h:Aoo`<002]oo`003Goo
0`00?Woo40?PYGoo0`00:goo000=Ool3000oOol?0n2UOol3000[Ool000eoo`<0041oo`h3h:Eoo`<0
02]oo`003Goo0`00@7oo3P?PYGoo0`00:goo000=Ool30012Ool<0n2UOol3000[Ool000eoo`<004=o
o``3h:Aoo`<002]oo`003Goo0`00AWoo2@?PY7oo0`00:goo000=Ool30016Ool:0n2SOol3000[Ool0
00eoo`<004Ioo`X3h:=oo`<002]oo`003Goo0`00Agoo2P?PXWoo0`00:goo000=Ool30013Ool4O00:
0n2ROol3000[Ool000eoo`<003]oo`el00T3h003O01oogoo09moo`<002]oo`003Goo0`00>7oo47`0
2P?P0g`0WWoo0`00:goo000=Ool3000aOolCO005Ool90n09O02HOol3000[Ool000eoo`<0031oo`al
00eoo`X3h0]l09Eoo`<002]oo`003Goo0`00;goo2W`047oo2P?P00=oog`0O00027`0UGoo0`00:goo
000=Ool3000]Ool6O00GOol:0n06Ool6O02COol3000[Ool000eoo`<002]oo`Il01Uoo`X3h0Qoo`Ml
091oo`<002]oo`003Goo0`00:Goo27`06Woo2@?P2Goo27`0SWoo0`00:goo000=Ool3000XOol6O00M
Ool:0n09Ool8O02=Ool3000[Ool000eoo`<002Ioo`Il021oo`T3h003O01oogoo00Yoo`Il08]oo`<0
02]oo`003Goo0`0097oo1W`08Woo2P?P0g`02goo1W`0RGoo0`00:goo000=Ool3000ROol7O00TOol9
0n04O00;Ool6O028Ool3000[Ool000eoo`<0025oo`Il02Ioo`@3h0<000<3h0Al00aoo`Il08Ioo`<0
02]oo`003Goo0`0087oo1G`09goo00=l00?P0n000P?P0`000`?P17`03Woo17`0QWoo0`00:goo000=
Ool3000OOol5O00XOol2O0030n0400020n05O00>Ool4O025Ool3000[Ool000eoo`@001eoo`Al02Uo
o`=l00@3h0<000<3h0Al00moo`Al08Aoo`<002]oo`003Goo1P006Woo17`0:Woo17`00`?P10000P?P
17`047oo17`0Pgoo0`00:goo000=Ool8000GOol4O00[Ool4O0030n0400030n03O00AOol4O022Ool3
000[Ool000eoo`T001Eoo`Al02aoo`El00030n00000000<000<3h0Al015oo`Al085oo`<002]oo`00
3Goo0`000Woo1P004Woo17`0;Woo17`00P?P1@000`?P0W`04goo17`0P7oo0`00:goo000=Ool30004
Ool6000?Ool4O00_Ool4O0030n0400030n02O00DOol4O01oOol3000[Ool000eoo`<000Eoo`L000ao
o`Al035oo`Al00<3h0@000<3h003O01oogoo01=oo`Al07ioo`<002]oo`003Goo0`001goo1P002Woo
17`0<Woo17`010?P0`000`?P5goo1G`0O7oo0`00:goo000=Ool30009Ool60007Ool4O00cOol5O003
0n0400020n0HOol4O01lOol3000[Ool000eoo`<000]oo`H000Eoo`Al03Eoo`=l00@3h0<000<3h1Qo
o`=l07aoo`<002]oo`003Goo0`0037oo1P0017oo0g`0=goo0g`00`?P0`000`?P67oo17`0Ngoo0`00
:goo000=Ool3000>Ool600000gooO01l0002O00jOol30n0400030n0GOol4O01kOol3000[Ool000eo
o`<0011oo`@000El03]oo`<3h0<000<3h1Qoo`El07Uoo`<002]oo`003Goo0`004Goo0P0017`0?Goo
0`?P10000`?P67oo17`0NGoo0`00:goo000=Ool3000COol4O002000kOol40n0300030n0IOol3O01i
Ool3000[Ool000eoo`<001=oo`=l00D003Yoo`<3h0@00083h1Uoo`Al07Qoo`<002]oo`003Goo0`00
4Woo17`01P00>Goo10?P0`000`?P67oo17`0N7oo0`00:goo000=Ool3000AOol5O002Ool6000hOol3
0n0300030n0IOol5O01fOol3000[Ool000eoo`<0011oo`Al00Ioo`H003Ioo`<3h0@000<3h1Uoo`Al
07Ioo`<002]oo`003Goo0`0047oo17`01goo1P00=Woo0`?P0`000`?P6Woo0g`0MWoo0`00:goo000=
Ool3000@Ool3O00:Ool6000dOol30n0400030n0IOol4O01eOol3000[Ool000eoo`<0011oo`=l00ao
o`H0039oo`@3h0<000<3h1Yoo`=l07Eoo`<002]oo`003Goo0`003goo17`03Goo1P00<Woo0`?P1000
0P?P6Woo17`0M7oo0`00:goo000=Ool3000?Ool3O00@Ool6000`Ool40n0300030n0JOol3O01dOol3
000[Ool000eoo`<000ioo`Al019oo`H002moo`<3h0<000<3h1Yoo`=l07Aoo`<002]oo`003Goo0`00
3Woo0g`057oo1P00;Woo0`?P10000`?P6Goo17`0Lgoo0`00:goo000=Ool3000>Ool3O00FOol6000]
Ool30n0300030n0JOol3O01cOol3000[Ool000eoo`<000eoo`Al01Qoo`H002]oo`<3h0@000<3h1Uo
o`=l07=oo`<002]oo`003Goo0`003Goo0g`06Woo1P00:goo0`?P0`000`?P6Goo0g`0Lgoo0`00:goo
000=Ool3000=Ool3O00LOol6000YOol30n0400020n0IOol3O01cOol3000[Ool000eoo`<000eoo`=l
01ioo`H002Moo`@3h0<000<3h1Qoo`=l07=oo`<002]oo`003Goo0`003Goo0g`07goo1P009goo0`?P
0`000`?P67oo17`0LWoo0`00:goo000=Ool3000=Ool3O00QOol6000UOol30n0400030n0HOol3O01b
Ool3000[Ool000eoo`<000aoo`Al02=oo`H002Aoo`<3h0<000<3h1Qoo`=l079oo`<002]oo`003Goo
0`0037oo0g`09Goo1P008goo0`?P10000`?P5goo17`0LGoo0`00:goo000=Ool3000<Ool3O00WOol6
000ROol30n0300030n0HOol3O01aOol3000[Ool000eoo`<000aoo`=l02Uoo`H000Eoo`Ml01Aoo`<3
h0@000<3h1Moo`=l075oo`<002]oo`003Goo0`0037oo0g`0:Woo1`0000=oog`0O0002G`04Woo10?P
0`000`?P5goo0g`0LGoo0`00:goo000=Ool3000<Ool3O00/Ool5000=O00BOol30n0300030n0GOol3
O01aOol3000[Ool000eoo`<000aoo`=l02ioo`8000ml015oo`<3h0@000<3h1Ioo`=l075oo`<002]o
o`003Goo0`0037oo0g`0<7oo47`04Goo0`?P0`000`?P5Woo0g`0LGoo0`00:goo000=Ool3000<Ool3
O00_OolAO00AOol30n0400030n0EOol3O01aOol3000[Ool000eoo`<000aoo`=l02mooa5l019oo`<3
h0<000<3h1Eoo`=l075oo`<002]oo`003Goo0`0037oo0g`0;goo4G`04Woo0`?P10000`?P57oo0g`0
LGoo0`00:goo000=Ool3000<Ool3O00_OolAO00COol30n0300030n0DOol3O01aOol3000[Ool000eo
o`<000aoo`=l02mooa5l01=oo`<3h0<000<3h1Aoo`=l075oo`<002]oo`003Goo0`0037oo0g`0;goo
4G`04goo0`?P10000`?P4goo0g`0LGoo0`00:goo000=Ool3000<Ool3O00^Ool2000?O00EOol30n03
00030n0COol3O01aOol3000[Ool000eoo`<000aoo`=l02aoo`D000el01Ioo`<3h0@000<3h19oo`=l
075oo`<002]oo`003Goo0`0037oo0g`0:goo1P0037`067oo0`?P0`000`?P4Woo0g`0LGoo0`00:goo
000=Ool3000<Ool3O00YOol60004Ool9O00IOol30n0400030n0AOol3O01aOol3000[Ool000eoo`<0
00aoo`=l02Moo`H000Moo`Ml01]oo`<3h0<000<3h15oo`=l075oo`<002]oo`003Goo0`0037oo0g`0
9Woo1P002Goo17`07Goo0`?P0`000`?P4Goo0g`0LGoo0`00:goo000=Ool3000<Ool3O00TOol6000/
Ool30n0400030n0?Ool4O01aOol3000[Ool000eoo`<000aoo`Al029oo`D002moo`<3h0<000<3h0mo
o`=l079oo`<002]oo`003Goo0`003Goo0g`087oo1P00<7oo0`?P10000`?P3Woo0g`0LWoo0`00:goo
000=Ool3000=Ool3O00NOol6000cOol30n0300030n0=Ool4O01bOol3000[Ool000eoo`<000eoo`=l
01eoo`H003Aoo`<3h0@000<3h0aoo`=l07=oo`<002]oo`003Goo0`003Goo0g`06goo1P00=goo0`?P
0`000`?P37oo0g`0Lgoo0`00:goo000=Ool3000=Ool4O00HOol6000iOol30n0300030n0<Ool3O01c
Ool3000[Ool000eoo`<000ioo`=l01Moo`H003]oo`83h0@000<3h0]oo`=l07=oo`<002]oo`003Goo
0`003Woo0g`05Goo1P00?Goo0`?P0`000`?P2Woo17`0Lgoo0`00:goo000=Ool3000>Ool4O00BOol6
000oOol30n0400030n09Ool3O01dOol3000[Ool000eoo`<000moo`=l015oo`H0045oo`<3h0<000<3
h0Uoo`=l07Aoo`<002]oo`003Goo0`003goo0g`03goo1P00@goo0`?P10000`?P1goo17`0M7oo0`00
:goo000=Ool3000?Ool4O00=Ool50016Ool30n0300030n07Ool3O01eOol3000[Ool000eoo`<0011o
o`=l00]oo`H004Moo`<3h0<000@3h0Ioo`=l07Eoo`<002]oo`003Goo0`0047oo17`027oo1P00BWoo
0P?P10000`?P1Goo17`0MGoo0`00:goo000=Ool3000AOol3O007Ool6001;Ool30n0300030n05Ool3
O01fOol3000[Ool000eoo`<0015oo`Al00Aoo`H004eoo`<3h0@000<3h0=oo`Al07Ioo`<002]oo`00
3Goo0`004Woo17`000=oo`0000001000D7oo0`?P0`000`?P0Woo17`0Mgoo0`00:goo000=Ool3000C
Ool3O006001AOol30n0400030n0017ooO01l07`0N7oo0`00:goo000=Ool3000COol4O003001DOol3
0n0300030n04O01hOol3000[Ool000eoo`<0019oo`8000=l0003001oogoo05Aoo`<3h0<000@3h09l
07Uoo`<002]oo`003Goo0`004Goo0`0017`0Egoo0P?P10000`?P0W`0NGoo0`00:goo000=Ool3000?
Ool60004O01FOol30n0300030n000g`0Oomoo`1hOol3000[Ool000eoo`<000ioo`D000=oo`=l05Mo
o`83h0@000<3h7Yoo`<002]oo`003Goo0`0037oo1P0017oo17`0EWoo0`?P0`000`?PNWoo0`00:goo
000=Ool3000:Ool60006Ool4O01FOol30n0300040n1iOol3000[Ool000eoo`<000Uoo`H000Qoo`El
05Eoo`T3h7Uoo`<002]oo`003Goo0`001goo1P002goo17`0EGoo2P?PN7oo0`00:goo000=Ool30005
Ool6000>Ool4O01DOol00g`00n03h0070n1hOol3000[Ool000eoo`<000Aoo`H0011oo`Al059oo`9l
00T3h7Qoo`<002]oo`003Goo0`000Woo1P004Woo17`0DGoo17`02`?PMGoo0`00:goo000=Ool30000
0goo00000003000EOol4O01?Ool5O00=0n1cOol3000[Ool000eoo`P001Moo`Al04eoo`Al009oo`h3
h79oo`<002]oo`003Goo1P006Woo1G`0B7oo1W`00goo3`?PLGoo0`00:goo000=Ool5000LOol6O015
Ool6O003Ool70n000`000n03h0060n1aOol3000[Ool000eoo`<001moo`Il04=oo`Ml00=oo`H3h0@0
00H3h75oo`<002]oo`003Goo0`0087oo1g`0@7oo1G`01Woo1P?P1`0010?PL7oo0`00:goo000=Ool3
000SOol4O00oOol4O007Ool70n0:00000`?POomoo`1^Ool3000[Ool000eoo`<002Aoo`El03Yoo`Il
00Qoo`L3h0`006moo`<002]oo`003Goo0`009Goo1W`0=goo1W`02Goo20?P3P00K7oo0`00:goo000=
Ool3000VOol6O00eOol7O00:Ool80n0?001ZOol3000[Ool000eoo`<002Moo`Ml035oo`Il00ioo`/3
h0h006Moo`<002]oo`003Goo0`00:Woo1g`0;7oo1W`04Goo3@?P3P00I7oo0`00:goo000=Ool3000[
Ool8O00WOol9O00AOol=0n02Ool>001ROol3000[Ool000eoo`<002eoo`Ul025oo`Ul01Eoo`/3h0Io
o`h005moo`<002]oo`003Goo0`00<7oo2G`06goo2W`067oo2@?P2Goo3P00GGoo0`00:goo000=Ool3
000bOol<O00AOol<O00MOol50n0>Ool>001JOol3000[Ool000eoo`<003Eoob=l03Ioo`h005Moo`<0
02]oo`003Goo0`00>7oo7G`0>goo3P00EGoo0`00:goo000=Ool3000mOolCO013Ool>001BOol3000[
Ool000eoo`<009Eoo`l004moo`<002]oo`003Goo0`00V7oo3P00CGoo0`00:goo000=Ool3002KOol>
001:Ool3000[Ool000eoo`<009eoo`h004Qoo`<002]oo`003Goo0`00X7oo3P00AGoo0`00:goo000=
Ool3002SOol>0012Ool3000[Ool000eoo`<00:Eoo`h0041oo`<002]oo`003Goo0`00Z7oo3P00?Goo
0`00:goo000=Ool3002ZOol>0002Ool701lbOol3000[Ool000eoo`<00:eoo`h000L07c5oo`<002]o
o`003Goo0`00/7oo3P001@0O<7oo0`00:goo000=Ool3002bOol>000301l`Ool3000[Ool000eool@0
00<07c8002]oo`003Gooa0000`0O<P00:goo000=Oonk000201l7000X01l=000[Ool00<Qoo`D07`@0
02P07cQoo`00bGoo1P0O00<0000O01l09`0O>7oo003:Ool_01lhOol00<]oobh07cQoo`00cWoo:`0O
>7oo003>Ool[01lhOol00<ioob/07cQoo`00cWoo:`0O>7oo003>Ool[01lhOol00<ioob/07cQoo`00
cWoo:`0O>7oo003>Ool[01lhOol00<ioob/07cQoo`00ogoo<Woo003oOolbOol00?mooc9oo`00ogoo
<Woo003oOolbOol00?mooc9oo`00ogoo<Woo003oOolbOol00?mooc9oo`00ogoo<Woo003oOolbOol0
0?mooc9oo`00ogoo<Woo003oOolbOol00001\
\>"],
  ImageRangeCache->{{{0, 304}, {188, 0}} -> {-6.01078, -1.00006, 0.06915, 
  0.06915}}],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four body objects are defined for the quick-return mechanism model."], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground (body 1) requires four point definitions.\nP1 is the rotational \
axis of the drive arm.\nP2 is the rotational axis of the crank.\nP3 and P4 \
are two points that define the line upon which the slider slides."], 
  "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The crank (body 2) requires two local point definitions.\nP1 is the crank's \
rotational axis.\nP2 is the location of the pin on the crank that engages \
with the drive arm."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The drive arm (body 3) requires two local point definitions.\nP1 is the \
point on the drive arm where the drive arm pivots with respect to the ground.\
\nP2 is the point where the drive arm is attached to the pseudo connecting \
rod."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider (body 4) requires two local point definitions.\nP1 and P2 are two \
points along the horizontal axis of the slider define its translation line."],
   "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here are the bodies in the quick-return model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147392 0.47619 [
[ -0.001 -0.001 0 0 ]
[ 1.001 .62005 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 .61905 L
s
P
P
p
p
.002 w
0 .61905 m
1 .61905 L
s
P
p
.002 w
1 0 m
1 .61905 L
s
P
P
p
P
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0147392 0.477324 0.295486 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
p
p
p
0 1 0 r
.004 w
.28571 .04762 m
.28571 .04762 .02857 0 365.73 arc
F
.50621 .41512 m
.50621 .41512 .02857 0 365.73 arc
F
.27346 .05497 m
.29796 .04027 L
.51846 .40777 L
.49396 .42247 L
F
P
p
.02 w
.28571 .04762 Mdot
.50621 .41512 Mdot
P
p
.01 w
.33471 .12929 m
.48171 .37428 L
s
P
P
p
[({0,0})] .28571 .04762 1.6 0 Mshowa
[(P1)] .28571 .04762 -2.6 0 Mshowa
[({0,9})] .50621 .41512 1.6 0 Mshowa
[(P2)] .50621 .41512 -2.6 0 Mshowa
p
/Times-Bold findfont 12 scalefont setfont
[(Drive Arm)] .61905 .28571 0 0 Mshowa
P
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147392 0.97619 0.295486 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
p
p
p
.5 .5 1 r
.004 w
.71805 .52381 m
.71805 .52381 .01905 0 365.73 arc
F
.71805 .57143 m
.71805 .52381 L
.86091 .52381 L
.86091 .57143 L
F
P
p
.008 w
.71805 .52381 Mdot
.86091 .52381 Mdot
P
P
p
[({0,0})] .71805 .52381 0 2 Mshowa
[(P1)] .71805 .52381 2 -1.8 Mshowa
[({3,0})] .86091 .52381 0 2 Mshowa
[(P2)] .86091 .52381 -2 -1.8 Mshowa
p
/Times-Bold findfont 12 scalefont setfont
[(Slider)] .78571 .38095 0 0 Mshowa
P
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.323561 0.477324 0.604308 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
p
p
.008 w
.28571 .04762 Mdot
p
.01 w
.04762 .52381 m
.85714 .52381 L
.85714 .04762 L
.04762 .04762 L
.04762 .52381 L
.04762 .42857 L
.28571 .28571 L
.04762 .14286 L
s
P
P
p
[({0,0})] .28571 .04762 0 1.8 Mshowa
[(P1)] .28571 .04762 0 -1.8 Mshowa
[({0,5})] .28571 .28571 -1.4 0 Mshowa
[(P2)] .28571 .28571 3 0 Mshowa
[({-5,10})] .04762 .52381 -0.7 -1.8 Mshowa
[(P3)] .04762 .52381 -1.6 1.8 Mshowa
[({12,10})] .85714 .52381 .7 -1.8 Mshowa
[(P4)] .85714 .52381 1.6 1.8 Mshowa
p
/Times-Bold findfont 12 scalefont setfont
[(Ground)] .61905 .28571 0 0 Mshowa
P
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323561 0.97619 0.604308 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
p
p
p
1 .6 .6 r
.01 w
.28571 .28571 m
.28571 .28571 .19048 0 365.73 arc
F
P
p
1 .4 .4 r
.01 w
.42857 .28571 m
.42857 .28571 .02857 0 365.73 arc
F
.28571 .28571 m
.28571 .28571 .02857 0 365.73 arc
F
P
p
p
.02 w
.28571 .28571 Mdot
.42857 .28571 Mdot
P
P
P
p
[({0,0})] .28571 .28571 0 2.4 Mshowa
[(P1)] .28571 .28571 0 -2.4 Mshowa
[({3,0})] .42857 .28571 0 2.4 Mshowa
[(P2)] .42857 .28571 0 -2.4 Mshowa
p
/Times-Bold findfont 12 scalefont setfont
[(Crank)] .61905 .28571 0 0 Mshowa
P
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{460.313, 284.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007<000171000`40O003h00O00=oo`000000o`00
b@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00
Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005o
o`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?mo
olQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003
Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0@7oo1`?PogooPGoo0@000Goo00000goo001oo`0o
Ool90n3oOon0Ool10001Ool00003Ool007oo02Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00=oo`/3h?moogmoo`40005oo`0000=oo`00Ool09Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo2`?P0goo0`000Woo1@00ogooLWoo0@00
0Goo00000goo001oo`0UOol01`00Oomoogoo001oo`0000Aoo`06001oogoo001oo`000goo00<007oo
Ool00Woo1@?P00<000?P0n0010?P0goo00<007ooOol00goo00<007ooOol0ogooLWoo0@000Goo0000
0goo001oo`0TOol20003Ool00`00Ool00007Ool00`00Ool00003Ool20003Ool40n0300050n03Ool3
0003Ool00`00Oomoo`3oOombOol10001Ool00003Ool007oo02Eoo`07001oogooOol007oo00001goo
00<007oo00000goo00<007ooOol00Woo1@?P00<000?P0n0010?P0goo00@007ooOol0009oo`03001o
ogoo0?moog9oo`40005oo`0000=oo`00Ool09Goo00L007ooOomoo`00Ool00007Ool00`00Ool00003
Ool00`00Oomoo`02Ool;0n04Ool01000Oomoo`000Woo00<007ooOol0ogooLWoo0@000Goo00000goo
001oo`0VOol01@00Oomoogoo00002Goo00D007ooOomoo`0000Ioo`/3h09oo`@0009oo`800?moogAo
o`40005oo`0000=oo`00Ool0?goo2`?PogooOWoo0@000Goo00000goo001oo`11Ool:0n3oOommOol1
0001Ool00003Ool007oo04Eoo`H3h?moogeoo`40005oo`0000=oo`00Ool0AGoo1`?PogooO7oo0@00
0Goo00000goo001oo`16Ool70n3oOomkOol10001Ool00003Ool007oo04Ioo`L3h?moog]oo`40005o
o`0000=oo`00Ool0Agoo1`?PogooNWoo0@000Goo00000goo001oo`18Ool60n3oOomjOol10001Ool0
0003Ool007oo04Qoo`L3h?moogUoo`40005oo`0000=oo`00Ool0BGoo1`?PogooN7oo0@000Goo0000
0goo001oo`19Ool70n3oOomhOol10001Ool00003Ool007oo04Yoo`L3h?moogMoo`40005oo`0000=o
o`00Ool0Bgoo0`?P00<000?P0n00ogooMgoo0@000Goo00000goo001oo`1;Ool30n0010000n03h0?P
ogooMWoo0@000Goo00000goo001oo`1<Ool20n0200030n3oOomeOol10001Ool00003Ool007oo04ao
o`<3h0800083h?moogEoo`40005oo`0000=oo`00Ool0CGoo0`?P00@000?P0n03h?moogAoo`40005o
o`0000=oo`00Ool0CWoo0P?P0P000P?PogooM7oo0@000Goo00000goo001oo`1>Ool30n0010000n03
h0?PogooLgoo0@000Goo00000goo001oo`1?Ool20n0200030n3oOombOol10001Ool00003Ool007oo
04moo`<3h0800083h?moog9oo`40005oo`0000=oo`00Ool0D7oo0`?P00@000?P0n03h?moog5oo`40
005oo`0000=oo`00Ool0DGoo0P?P0P000P?PogooLGoo0@000Goo00000goo001oo`1AOol30n001000
0n03h0?PogooL7oo0@000Goo00000goo001oo`1BOol20n0200030n3oOom_Ool10001Ool00003Ool0
07oo059oo`<3h0800083h?moofmoo`40005oo`0000=oo`00Ool0Dgoo0`?P00@000?P0n03h?moofio
o`40005oo`0000=oo`00Ool0E7oo0P?P0P000P?PogooKWoo0@000Goo00000goo001oo`1DOol30n00
10000n03h0?PogooKGoo0@000Goo00000goo001oo`1EOol20n0200030n3oOom/Ool10001Ool00003
Ool007oo05Eoo`<3h0800083h?moofaoo`40005oo`0000=oo`00Ool0EWoo0`?P00@000?P0n03h?mo
of]oo`40005oo`0000=oo`00Ool0Egoo0P?P0P000P?PogooJgoo0@000Goo00000goo001oo`1GOol3
0n0010000n03h0?PogooJWoo0@000Goo00000goo001oo`1HOol20n0200030n3oOomYOol10001Ool0
0003Ool007oo05Qoo`<3h0800083h?moofUoo`40005oo`0000=oo`00Ool0FGoo0`?P00@000?P0n03
h?moofQoo`40005oo`0000=oo`00Ool0FWoo0P?P0P000`?PogooIgoo0@000Goo00000goo001oo`1J
Ool30n0010000n03h0?PogooIgoo0@000Goo00000goo001oo`1KOol20n0200030n3oOomVOol10001
Ool00003Ool007oo05aoo`83h0040003h0?P0n3oOomVOol10001Ool00003Ool007oo05aoo`83h080
00<3h?moofEoo`40005oo`0000=oo`00Ool0GGoo0P?P0P000`?P2Goo1P000goo100000=oo`000000
0P0000=oo`0000000goo0`001Goo0`0000=oo`0000001P0000Eoo`00000007oo00800004Ool00000
003oOolTOol10001Ool00003Ool007oo05eoo`<3h0040003h0?P0n0:Ool20002Ool20003Ool20003
Ool20002Ool20002Ool20002Ool00`00Oomoo`03Ool01000Oomoogoo0P000Woo0P000goo0P0000Ao
o`00001oo`800?moobEoo`40005oo`0000=oo`00Ool0GWoo0P?P0P000`?P2Goo0P000goo0P000Woo
0P000goo0P0000Ioo`00001oo`00Ool20008Ool01000Oomoogoo0P000Woo0P000goo0P0000Aoo`00
001oo`800?moobEoo`40005oo`0000=oo`00Ool0Ggoo0P?P00@000?P0n03h0Uoo`8000=oo`80009o
o`8000=oo`800006Ool00000Ool007oo1@001Woo10000goo0P000goo0P0000Aoo`00001oo`800?mo
obEoo`40005oo`0000=oo`00Ool0Ggoo0P?P0P000`?P27oo0P000goo0P000Woo0P0000=oo`00Ool0
0P0000Ioo`00001oo`00Ool200000goo00000006Ool01000Ool000000goo0P0000=oo`00Ool00P00
00Aoo`00001oo`800?moobEoo`40005oo`0000=oo`00Ool0H7oo0P?P0P000`?P1goo0P000goo0P00
00=oo`0000002@0000Aoo`00001oo`<000Moo`04001oo`000002Ool:00000goo0000003oOolVOol1
0001Ool00003Ool007oo061oo`<3h0040003h0?P0n07Ool20003Ool2000KOol2003oOolfOol10001
Ool00003Ool007oo065oo`83h08000<3h0Ioo`80009oo`8000Qoo`80019oo`800?moocIoo`40005o
o`0000=oo`00Ool0HWoo0P?P00@000?P0n03h0Eoo`H000Uoo`8001=oo`03001oogoo0?moocAoo`40
005oo`0000=oo`00Ool0HWoo0P?P0P000`?PogooGgoo0@000Goo00000goo001oo`1SOol20n020003
0n3oOomNOol10001Ool00003Ool007oo06=oo`<3h0040003h0?P0n3oOomNOol10001Ool00003Ool0
07oo06Aoo`83h08000<3h?mooeeoo`40005oo`0000=oo`00Ool0IGoo0P?P00@000?P0n03h?mooeeo
o`40005oo`0000=oo`00Ool0IGoo0P?P0P000`?PogooG7oo0@000Goo00000goo001oo`1VOol20n02
00030n3oOomKOol10001Ool00003Ool007oo06Ioo`<3h0040003h0?P0n3oOomKOol10001Ool00003
Ool007oo06Moo`83h08000<3h?mooeYoo`40005oo`0000=oo`00Ool0J7oo0P?P00@000?P0n03h?mo
oeYoo`40005oo`0000=oo`00Ool0J7oo0P?P0P000`?Pogoo4Woo00<007oo00000P000Woo200000=o
o`0000000`0000Aoo`000000009oo`@002Qoo`40005oo`0000=oo`00Ool0JGoo0P?P0P000`?Pogoo
4Goo0P000Woo0P000Woo0P000Woo0P0000Aoo`00001oo`800003Ool00000009oo`03001oogoo0080
02Uoo`40005oo`0000=oo`00Ool0JGoo0`?P00@000?P0n03h?mooa5oo`04001oogooOol20002Ool2
0002Ool2000017oo000007oo0P0000=oo`0000001Goo0P00:Goo0@000Goo00000goo001oo`1ZOol2
0n000`000n03h0020n3oOolCOol30002Ool20002Ool2000017oo000007oo0P0000=oo`0000000`00
0Woo0P00:Goo0@000Goo00000goo001oo`1[Ool60n3oOolAOol40003Ool20002Ool2000017oo0000
07oo0P0000Aoo`00001oo`80009oo`800003Ool007oo02Ioo`40005oo`0000=oo`00Ool0Jgoo1`?P
ogoo3goo0`001Goo0P0000Aoo`000000009oo`@0009oo`<0009oo`D002Moo`40005oo`0000=oo`00
Ool0K7oo20?Pogoo3Goo0P000goo00<007ooOol00P0027oo0P00<goo0@000Goo00000goo001oo`1/
Ool:0n3oOol;Ool20002Ool20002Ool20002Ool20004Ool2000cOol10001Ool00003Ool007oo05Ao
o`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00=oo`/3h?moo`]oo`<00003Ool007oo00<0
009oo`8000=oo`<003=oo`40005oo`0000=oo`00Ool0Dgoo00<007ooOol00Woo00<007ooOol00Woo
00@007ooOomoo`8000Aoo`03001oogoo009oo`/3h09oo`<000=oo`<00?moodIoo`40005oo`0000=o
o`00Ool0Dgoo00L007ooOomoo`00Ool00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo1@?P
00<000?P0n000`?P0goo00<007ooOol00Woo00<007ooOol0ogooAWoo0@000Goo00000goo001oo`1B
Ool20003Ool00`00Ool00008Ool20003Ool20002Ool50n0300040n03Ool30003Ool00`00Oomoo`3o
Oom5Ool10001Ool00003Ool007oo05=oo`07001oogooOol007oo00001goo00<007oo00000goo00<0
07ooOol00Woo1@?P00<000?P0n000`?P0goo00@007ooOol0009oo`03001oogoo0?moodEoo`40005o
o`0000=oo`00Ool0Dgoo00L007ooOomoo`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`02Ool;
0n03Ool02000Oomoo`00Ool007oo003oOom6Ool10001Ool00003Ool007oo05Aoo`05001oogooOol0
0009Ool20002Ool00`00Oomoo`04Ool:0n02Ool40003Ool00`00Oomoo`3oOom5Ool10001Ool00003
Ool007oo06eoo`T3h?mooe9oo`40005oo`0000=oo`00Ool0Kgoo1@?PogooE7oo0@000Goo00000goo
001oo`3oOoo8Ool10001Ool00003Ool007oo0?moogUoo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01eoo`40005oo`0000=oo`00
Ool0ogooN7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol01Woo00@007ooOomoo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01ao
o`40005oo`0000=oo`00Ool0ogooN7oo00L007ooOomoo`00Ool00004Ool01P00Oomoo`00Ool000=o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`06001oogoo001oo`000goo00<007oo
Ool077oo0@000Goo00000goo001oo`3oOomgOol20003Ool00`00Ool00007Ool00`00Ool00003Ool2
0006Ool20004Ool00`00Oomoo`06Ool00`00Ool00003Ool2000MOol10001Ool00003Ool007oo0?mo
ogQoo`07001oogooOol007oo00001goo00<007oo00000goo00<007ooOol01Woo00<007ooOol00goo
00<007ooOol01Goo00<007oo00000goo00<007ooOol077oo0@000Goo00000goo001oo`3oOomhOol0
1`00Oomoogoo001oo`0000Moo`03001oo`0000=oo`03001oogoo00Ioo`07001oogooOol007oo0000
1goo00<007oo00000goo00<007ooOol077oo0@000Goo00000goo001oo`3oOomiOol01@00Oomoogoo
00002Goo00D007ooOomoo`0000Yoo`05001oogooOol00009Ool01@00Oomoogoo00007goo0@000Goo
00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoo
b7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=o
o`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOon0Ool5?Om3Ool10001Ool00003Ool007oo0?mo
ogmoo`Lmod9oo`40005oo`0000=oo`00Ool0ogooOWoo13go00@003go?OlmoaYoo`03001oogoo02Eo
o`40005oo`0000=oo`00Ool0ogooOgoo8Cgo:7oo0@000Goo00000goo001oo`3oOomoOolQ?OlXOol1
0001Ool00003Ool007oo0?moogmoob4mobQoo`40005oo`0000=oo`00Ool0ogooPWoo7Sgo:7oo0@00
0Goo00000goo001oo`3oOon2OolN?OlXOol10001Ool00003Ool007oo0?mooh9ooahmobQoo`40005o
o`0000=oo`00Ool0ogooPWoo7Sgo:7oo0@000Goo00000goo001oo`3oOon2OolN?OlXOol10001Ool0
0003Ool007oo0?moog=oo`<0009oo`D000Eooahmo`Eoo`<000=oo`<001Yoo`40005oo`0000=oo`00
Ool0ogooM7oo00<007ooOol00goo00<007ooOol01Goo7Sgo1Woo00<007ooOol00Woo00<007ooOol0
6Woo0@000Goo00000goo001oo`3oOomdOol30003Ool00`00Oomoo`0YOol30003Ool00`00Oomoo`0I
Ool10001Ool00003Ool007oo0?moogAoo`04001oogoo0002Ool00`00Oomoo`0YOol01000Oomoo`00
0Woo00<007ooOol06Goo0@000Goo00000goo001oo`3oOomdOol01000Oomoo`000Woo00<007ooOol0
:Goo00P007ooOol007oo001oo`006Woo0@000Goo00000goo001oo`3oOomcOol40002Ool2000ZOol4
0003Ool00`00Oomoo`0IOol10001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoo
b7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=o
o`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40
005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo
0?moolQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool0
0003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001oo`0jOol0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`3oOomiOol10001Ool00003Ool007oo03Uoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo0?moogQo
o`40005oo`0000=oo`00Ool0>Goo00L007ooOomoo`00Ool00004Ool01P00Oomoo`00Ool000=oo`03
001oogoo0?moogQoo`40005oo`0000=oo`00Ool0>7oo0P000goo00<007oo00001goo00<007oo0000
0goo0P00ogooNGoo0@000Goo00000goo001oo`0iOol01`00Oomoogoo001oo`0000Moo`03001oo`00
00=oo`03001oogoo0?moogQoo`40005oo`0000=oo`00Ool0>Goo00L007ooOomoo`00Ool00007Ool0
0`00Ool00003Ool00`00Oomoo`3oOomhOol10001Ool00003Ool007oo03Yoo`05001oogooOol00009
Ool01@00Oomoogoo0000ogooNgoo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo
0?moolQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool0
0003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001oo`13Ool0
0`00Oomoo`3oOon2Ool10001Ool00003Ool007oo015oojX00?moo`eoo`40005oo`0000=oo`00Ool0
4GooZP00ogoo3Goo0@000Goo00000goo001oo`0AOol2002VOol2003oOol=Ool10001Ool00003Ool0
07oo015oo`800:Ioo`800?moo`eoo`40005oo`0000=oo`00Ool04Goo0P00YWoo0P00ogoo3Goo0@00
0Goo00000goo001oo`0AOol2002VOol2003oOol=Ool10001Ool00003Ool007oo015oo`800:Ioo`80
0?moo`eoo`40005oo`0000=oo`00Ool04Goo0P00YWoo0P00ogoo3Goo0@000Goo00000goo001oo`0A
Ool2002VOol2003oOol=Ool10001Ool00003Ool007oo015oo`8002aoo`<0009oo`D0071oo`800?mo
o`eoo`40005oo`0000=oo`00Ool04Goo0P00;Goo00<007ooOol00goo00<007ooOol0L7oo0P00ogoo
3Goo0@000Goo00000goo001oo`0AOol2000]Ool30003Ool00`00Oomoo`1`Ool2001TOolBOW>FOol1
0001Ool00003Ool007oo015oo`8002eoo`04001oogoo0002Ool00`00Oomoo`1`Ool2001POolIOW>C
Ool10001Ool00003Ool007oo015oo`8002eoo`04001oogoo0002Ool00`00Oomoo`1`Ool2001MOolP
OW>?Ool10001Ool00003Ool007oo015oo`8002aoo`@0009oo`80079oo`8005]oobAnLheoo`40005o
o`0000=oo`00Ool04Goo0P00YWoo0P00FGoo9gicS7oo0@000Goo00000goo001oo`0AOol2002VOol2
001GOol[OW>:Ool10001Ool00003Ool007oo015oo`800:Ioo`8005IoobinLhQoo`40005oo`0000=o
o`00Ool04Goo0P00YWoo0P00E7oo<GicQgoo0@000Goo00000goo001oo`0AOol2002VOol2001DOolb
OW>6Ool10001Ool00003Ool007oo015oo`@00:Aoo`8005=oocAnLhEoo`40005oo`0000=oo`00Ool0
4Goo1@00Xgoo0P00DWoo=WicQ7oo0@000Goo00000goo001oo`0AOol200000goo00000002002QOol2
001@OoliOW>3Ool10001Ool00003Ool007oo015oo`80009oo`D009moo`8004mooc]nLh9oo`40005o
o`0000=oo`00Ool04Goo0P0017oo1@00WGoo0P00CWoo?GicPGoo0@000Goo00000goo001oo`0AOol2
0006Ool4002LOol2001=OoloOW>0Ool10001Ool00003Ool007oo015oo`8000Qoo`@009Yoo`8004eo
od1nLgmoo`40005oo`0000=oo`00Ool04Goo0P002Goo1@00V7oo0P00C7oo@GicOgoo0@000Goo0000
0goo001oo`0AOol2000;Ool5002FOol2001<Oom2OW=nOol10001Ool00003Ool007oo015oo`8000eo
o`@009Eoo`8004]ood=nLgioo`40005oo`0000=oo`00Ool04Goo0P003goo1000Tgoo0P00BWooAGic
OGoo0@000Goo00000goo001oo`0AOol2000@Ool5002AOol2001:Oom6OW=lOol10001Ool00003Ool0
07oo015oo`80019oo`@0091oo`8004UooaYnL`03001nLgic00InL`03001nLgic00InL`03001nLgic
00UnL`03001nLgic00InL`03001nLgic00=nL`=oo`03001oogoo07Ioo`40005oo`0000=oo`00Ool0
4Goo0P0057oo1000SWoo0P00BGoo6Gic00<007icOW<00Wic00<007icOW<00Wic00<007icOW<00Wic
00<007icOW<00Wic00<007icOW<01gic00@007icOW=nL`8000AnL`03001nLgic009nL`03001nLgoo
009oo`03001oogoo07Eoo`40005oo`0000=oo`00Ool04Goo0P005Goo1@00S7oo0P00B7oo6Wic00L0
07icOW=nL`00OW<00004OW<01P00OW=nL`00OW<000=nL`03001nLgic00MnL`03001nLgic00=nL`03
001nLgic009nL`06001nLgic001nL`000goo00<007ooOol0MGoo0@000Goo00000goo001oo`0AOol2
000GOol5002:Ool20018OolIOW<20003OW<00`00OW<00007OW<00`00OW<00003OW<20007OW<20004
OW<00`00OW=nL`06OW<01000OW<007ic0Woo0P00MWoo0@000Goo00000goo001oo`0AOol2000IOol4
0029Ool20018OolJOW<01`00OW=nLgic001nL`0000MnL`03001nL`0000=nL`03001nLgic00MnL`03
001nLgic00=nL`03001nLgic00EnL`04001nL`00OW<2Ool00`00Oomoo`1eOol10001Ool00003Ool0
07oo015oo`8001]oo`@008Moo`8004QooaYnL`07001nLgicOW<007ic00001gic00<007ic00000gic
00<007icOW<01gic00L007icOW=nL`00OW<00007OW<01000OW<007ic0Woo00<007ooOol0MGoo0@00
0Goo00000goo001oo`0AOol2000LOol50025Ool20017OolLOW<01@00OW=nLgic00002Gic00D007ic
OW=nL`0000]nL`05001nLgicOW<00009OW<01@00OW=nLgoo0000N7oo0@000Goo00000goo001oo`0A
Ool2000NOol40024Ool20016Oom=OW=iOol10001Ool00003Ool007oo015oo`80021oo`@0089oo`80
04IoodenLgUoo`40005oo`0000=oo`00Ool04Goo0P008Goo1@00P7oo0P00AWooCGicNGoo0@000Goo
00000goo001oo`0AOol2000SOol5001nOol20016Oom>OW=hOol10001Ool00003Ool007oo015oo`80
02Eoo`@007eoo`8004IoodinLgQoo`40005oo`0000=oo`00Ool04Goo0P009goo1000Ngoo0P00AWoo
9Gic17f<6Gic1Gf<1gicN7oo0@000Goo00000goo001oo`0AOol2000XOol5001iOol20015OolTOW<8
OH`EOW<9OH`5OW=hOol10001Ool00003Ool007oo015oo`8002Yoo`D000Yoo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo01Moo`@0009oo`@0009oo`<000Aoo`P00005Ool00000001oo`05000L
Ool20015OolSOW<:OH`DOW<:OH`4OW<@Ool40002Ool40002Ool800000goo00000004000017oo0000
0000BGoo0@000Goo00000goo001oo`0AOol2000MOol30003Ool30006Ool40008Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0EOol20002Ool20002
Ool20002Ool200000goo00000002Ool200000goo00000002Ool2000017oo000007oo0P0000=oo`00
00007Goo0P00AGoo8Wic2gf<4gic2gf<17ic3goo0P000goo00<007ooOol00P000Woo0P0000=oo`00
00000Woo0P0000=oo`0000000Woo0P0000=oo`000000BWoo0@000Goo00000goo001oo`0AOol2000N
Ool00`00Oomoo`02Ool00`00Oomoo`08Ool40006Ool01`00Oomoogoo001oo`0000Aoo`06001oogoo
001oo`000goo00<007ooOol057oo0P000goo0P000Woo0P000Woo0P0000=oo`0000000Woo0P0000=o
o`0000000Woo0P0000Aoo`00001oo`800003Ool0000001eoo`8004Eoob9nL`amS19nL`]mS0AnL`io
o`8000Moo`8000=oo`04001oo`000002Ool200000goo00000002Ool200000goo0000001:Ool10001
Ool00003Ool007oo015oo`8001ioo`<000=oo`03001oogoo00Qoo`@000Aoo`8000=oo`03001oo`00
00Uoo`04001oogooOol2000EOol20002Ool400000goo00000002Ool200000goo00000002Ool20000
0goo00000002Ool2000017oo000007oo0P0000=oo`0000007Goo0P00AGoo8Wic1Gf<00<007f<OH`0
17f<4Gic1Wf<00<007f<OH`00gf<17ic3Woo0P001goo0P0017oo0`000Woo0P0000=oo`0000000Woo
1000Bgoo0@000Goo00000goo001oo`0AOol2000NOol01000Oomoo`000Woo00<007ooOol01goo1000
1Woo00L007ooOomoo`00Ool00007Ool20004Ool00`00Oomoo`0DOol20007Ool200001Goo00000000
Ool00P000Woo0P0000=oo`0000000Woo0P0000Aoo`00001oo`800003Ool0000001eoo`8004Eoob9n
L`AmS0<000EmS19nL`AmS0<000AmS0AnL`ioo`8000Moo`800005Ool00000001oo`020002Ool20000
0goo00000002Ool200000goo001oo`1:Ool10001Ool00003Ool007oo015oo`8001ioo`08001oogoo
001oo`00Ool000Ioo`@000Qoo`07001oogooOol007oo00001goo00<007ooOol00goo00<007ooOol0
57oo0P001Woo1@0000Aoo`000000009oo`<00004Ool00000Ool50003Ool4000MOol20015OolROW<5
OH`00`00OHamS004OH`BOW<5OH`00`00OHamS003OH`4OW<>Ool20006Ool5000017oo000000000Woo
1@000goo0P0000Aoo`00000004Uoo`40005oo`0000=oo`00Ool04Goo0P007Goo10000goo00<007oo
Ool00goo1@002Woo00D007ooOomoo`0000Qoo`<0009oo`03001oogoo01Eoo`8000Aoo`03001oogoo
01]oo`8001eoo`8004Eoob=nL`YmS1AnL`YmS0AnL`ioo`8000Aoo`03001oogoo019oo`8004eoo`40
005oo`0000=oo`00Ool04Goo0P00:Goo1000=goo0P000Woo0P007Goo0P007Goo0P00AGoo8gic2Gf<
5Gic27f<1Wic3goo0P000Woo0P0057oo0P00CGoo0@000Goo00000goo001oo`0AOol2000WOol4000j
Ool300000goo001oo`0KOol3000MOol20016OolSOW<7OH`GOW<7OH`6OW<@Ool300000goo001oo`0B
Ool3001=Ool10001Ool00003Ool007oo015oo`8002Eoo`D007aoo`8004IoobAnL`EmS1UnL`EmS0Mn
LgQoo`40005oo`0000=oo`00Ool04Goo0P0097oo1000OWoo0P00AWooCWicN7oo0@000Goo00000goo
001oo`0AOol2000ROol40020Ool20016Oom=OW=iOol10001Ool00003Ool007oo015oo`80021oo`D0
085oo`8004IoodenLgUoo`40005oo`0000=oo`00Ool04Goo0P007goo1000Pgoo0P00AWooCGicNGoo
0@000Goo00000goo001oo`0AOol2000MOol40025Ool20017Oom<OW=iOol10001Ool00003Ool007oo
015oo`8001]oo`D008Ioo`8004Mood]nLgYoo`40005oo`0000=oo`00Ool04Goo0P006Woo1000R7oo
0P00B7oo87ic0`000Wic1@004gic0`000gic0`0017icNWoo0@000Goo00000goo001oo`0AOol2000H
Ool4002:Ool20018OolQOW<00`00OW=nL`03OW<00`00OW=nL`0DOW<00`00OW=nL`02OW<00`00OW=n
L`04OW=jOol10001Ool00003Ool007oo015oo`8001Ioo`D008]oo`8004Qoob5nL`<000=nL`03001n
Lgic01AnL`<000=nL`03001nLgic00=nLgYoo`40005oo`0000=oo`00Ool04Goo0P005Goo1000SGoo
0P00B7oo8Gic00@007icOW<0009nL`03001nLgic01AnL`04001nLgic0002OW<00`00OW=nL`02OW=k
Ool10001Ool00003Ool007oo015oo`8001=oo`@008moo`8004Uoob1nL`04001nLgic0002OW<00`00
OW=nL`0DOW<02000OW=nL`00OW<007ic0002OW=lOol10001Ool00003Ool007oo015oo`80015oo`D0
091oo`8004YooainL`@0009nL`8001EnL`@000=nL`04001nLgicOW=lOol10001Ool00003Ool007oo
015oo`80011oo`@0099oo`8004YoodEnLgeoo`40005oo`0000=oo`00Ool04Goo0P003Woo1000U7oo
0P00BgooA7icOGoo0@000Goo00000goo001oo`0AOol2000<Ool5002EOol2001;Oom3OW=nOol10001
Ool00003Ool007oo015oo`8000]oo`@009Moo`8004aood5nLgmoo`40005oo`0000=oo`00Ool04Goo
0P002Goo1000VGoo0P00CGoo@7icOgoo0@000Goo00000goo001oo`0AOol20007Ool5002JOol2001=
OoloOW>0Ool10001Ool00003Ool007oo015oo`8000Ioo`@009aoo`8004ioocinLh1oo`40005oo`00
00=oo`00Ool04Goo0P0017oo1000WWoo0P00Cgoo?7icPGoo0@000Goo00000goo001oo`0AOol20002
Ool5002OOol2001@OoljOW>2Ool10001Ool00003Ool007oo015oo`800003Ool0000000800:5oo`80
055oocMnLhAoo`40005oo`0000=oo`00Ool04Goo1@00Xgoo0P00DWoo=GicQGoo0@000Goo00000goo
001oo`0AOol4002TOol2001COolcOW>6Ool10001Ool00003Ool007oo015oo`800:Ioo`8005Aooc5n
LhMoo`40005oo`0000=oo`00Ool04Goo0P00YWoo0P00EWoo;WicR7oo0@000Goo00000goo001oo`0A
Ool2002VOol2001GOol[OW>:Ool10001Ool00003Ool007oo015oo`800:Ioo`8005UoobMnLhaoo`40
005oo`0000=oo`00Ool04Goo0P00YWoo0P00Fgoo97icSGoo0@000Goo00000goo001oo`0AOol2002V
Ool2001MOolPOW>?Ool10001Ool00003Ool007oo015oo`80009oo`<000=oo`80091oo`<000Aoo`<0
009oo`8005iooaenLi5oo`40005oo`0000=oo`00Ool04Goo0P000goo00<007ooOol017oo00<007oo
Ool0SWoo00<007ooOol017oo00@007ooOomoo`80061ooaUnLi=oo`40005oo`0000=oo`00Ool04Goo
0P000goo0`000goo00<007ooOol0Sgoo0`000Woo10000Woo0P00I7oo4WicUWoo0@000Goo00000goo
001oo`0AOol20003Ool01000Oomoo`000goo00<007ooOol0SWoo00P007ooOol007oo001oo`000goo
0P00JWoo1WicW7oo0@000Goo00000goo001oo`0AOol20003Ool02000Oomoo`00Ool007oo002@Ool0
1000Oomoo`000Woo0P000goo0P00ogoo3Goo0@000Goo00000goo001oo`0AOol20002Ool40003Ool0
0`00Oomoo`2>Ool40004Ool01000Oomoogoo0P00ogoo3Goo0@000Goo00000goo001oo`0AOol2002V
Ool2003oOol=Ool10001Ool00003Ool007oo015oo`800:Ioo`800?moo`eoo`40005oo`0000=oo`00
Ool04Goo0P00YWoo0P00ogoo3Goo0@000Goo00000goo001oo`0AOol2002VOol2003oOol=Ool10001
Ool00003Ool007oo015oo`800:Ioo`800?moo`eoo`40005oo`0000=oo`00Ool04Goo0P00YWoo0P00
ogoo3Goo0@000Goo00000goo001oo`0AOol2002VOol2003oOol=Ool10001Ool00003Ool007oo015o
ojX00?moo`eoo`40005oo`0000=oo`00Ool04GooZP00ogoo3Goo0@000Goo00000goo001oo`3oOoo8
Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo
001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool047oo00<007oo
Ool02goo00<007ooOol02goo00<007ooOol0L7oo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool0ogoo2Woo0@000Goo00000goo001oo`0?Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`050002Ool00`00Oomoo`02Ool00`00Oomoo`1^Ool00`00Oomoo`05000017oo000000000goo00<0
07ooOol01@000Woo00<007ooOol00Woo00<007ooOol0ogoo2Goo0@000Goo00000goo001oo`0?Ool0
0`00Oomoo`06Ool00`00Ool00004Ool01@00Oomoogoo00000goo00<007oo00000goo00<007ooOol0
KWoo00<007ooOol00Woo00D007ooOomoo`0000Ioo`05001oogooOol00003Ool00`00Ool00003Ool0
0`00Oomoo`3oOol9Ool10001Ool00003Ool007oo00ioo`8000=oo`<000Aoo`03001oogoo00Ioo`07
001oogooOol007oo00000goo0P00KWoo0P0017oo00<007ooOol00Woo00<007ooOol01goo00L007oo
Oomoo`00Ool00003Ool2003oOol:Ool10001Ool00003Ool007oo00moo`03001oogoo00Ioo`8000Uo
o`07001oogooOol007oo00000goo00<007ooOol0KWoo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol01goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`3oOol9Ool10001Ool00003Ool007oo
00moo`03001oogoo00Ioo`03001oogoo00Qoo`07001oogooOol007oo00000goo00<007ooOol0KWoo
00<007ooOol00Woo00L007ooOomoo`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oogoo
0?moo`Uoo`40005oo`0000=oo`00Ool047oo00<007ooOol01Goo0`001goo0P0017oo00D007ooOomo
o`00079oo`03001oogoo008000Aoo`03001oogoo00Ioo`8000Aoo`05001oogooOol0003oOol<Ool1
0001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo00000goo001o
o`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoob7oo0@000Goo
00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=oo`00Ool0ogoo
b7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool007oo0?moolQoo`40005oo`0000=o
o`00Ool0ogoob7oo0@000Goo00000goo001oo`3oOoo8Ool10001Ool00003Ool000000?l00<T0005o
o`00\
\>"],
  ImageRangeCache->{{{0, 459.313}, {283.875, 0}} -> {-0.0551187, -0.0330589, 
  0.00459434, 0.00459434}, {{11.9375, 219.25}, {276.625, 148.313}} ->
   {-7.21156, -1.73461, 0.101317, 0.101317}, {{240, 447.313}, {276.625, 
  148.313}} -> {-30.3181, -1.73461, 0.101317, 0.101317}, {{11.9375, 219.25}, {
  135.5, 7.1875}} -> {-7.21156, -16.0329, 0.101317, 0.101317}, {{240, 
  447.313}, {135.5, 7.1875}} -> {-30.3181, -16.0329, 0.101317, 0.101317}}],

Cell[TextData[
"Names are defined for each of the body numbers in the mechanism."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(drivearm = 3; \)\), 
    \(\(slider = 4; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData["Body objects are defined for each body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bd[ground] = 
      Body[ground, 
        PointList \[Rule] {{0, 0}, {0, 5}, {\(-5\), 10}, {12, 10}}]; \)\), 
    \(\(bd[crank] = 
      Body[crank, PointList \[Rule] {{0, 0}, {3, 0}}, 
        InitialGuess \[Rule] {{0, 5}, 0}]; \)\), 
    \(\(bd[drivearm] = 
      Body[drivearm, PointList \[Rule] {{0, 0}, {0, 9}}, 
        InitialGuess \[Rule] {{0, 0}, \(-0.5\)}]; \)\), 
    \(\(bd[slider] = 
      Body[slider, PointList \[Rule] {{0, 0}, {3, 0}}, 
        InitialGuess \[Rule] {{9, 10}, 0}]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"This incorporates the body properties into the current model."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[Array[bd, 4]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Five constraints and one driving constraint are required to model the \
quick-return mechanism."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of the crank to be coincident with its pivot \
point on the ground. This constrains two degrees of freedom, ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " displacement of the crank axis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the angular coordinate of the crank. This driving \
constraint is used to rotate the crank."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the lower pivot point of the drive arm to be coincident \
with the global origin. The drive arm can pivot about this point on the \
ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the crank and the drive arm where the pin on the crank \
slides in a slot on the drive arm."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the drive arm and the slider replaces the pseudo \
connecting rod, which is 5.0 units long."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the slider and the ground allows the slider to \
translate horizontally along a track on the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are five constraints for the quick-return model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[1] = Revolute2[1, Point[ground, 2], Point[crank, 1]]; \)\), 
    \(\(cs[2] = RotationLock1[2, crank, 2\ N[\[Pi]]\ T]; \)\), 
    \(cs[3] = Revolute2[3, \n\t\tPoint[ground, 1], Point[drivearm, 1]]; \n
    cs[4] = PointOnLine1[4, \n\t\tPoint[crank, 2], Line[drivearm, 1, 2]]; \n
    cs[5] = RelativeDistance1[5, \n\t\tPoint[drivearm, 2], Point[slider, 1], 
        5.0]; \ncs[6] = 
      Translate2[6, \n\t\tLine[ground, 3, 4], Line[slider, 1, 2]]; \)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This incorporates the constraints into the current model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 6]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This runs the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.15"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.15] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.15`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 5.`\), ",", \(Th2 \[Rule] 0.942477796076937934`\), ",", 
        \(X3 \[Rule] 0\), ",", \(Y3 \[Rule] 0\), ",", 
        \(Th3 \[Rule] \(-0.233107297124505175`\)\), ",", 
        \(X4 \[Rule] 6.92194029010490208`\), ",", \(Y4 \[Rule] 10.`\), ",", 
        \(Th4 \[Rule] 0\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the quick-return mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.15."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!  
%%Creator: Mathematica  
%%AspectRatio: .61905   
MathPictureStart  
%% Graphics  
/Courier findfont 10  scalefont  setfont  
% Scaling calculations  
0.285714 0.047619 0.047619 0.047619 [  
[ 0 0 0 0 ]  
[ 1 .61905 0 0 ]  
] MathScale  
% Start of Graphics  
1 setlinecap  
1 setlinejoin  
newpath  
[ ] 0 setdash  
0 g  
p  
P  
0 0 m  
1 0 L  
1 .61905 L  
0 .61905 L  
closepath  
clip  
newpath  
p  
p  
.008 w  
.28571 .04762 Mdot  
p  
.01 w  
.04762 .52381 m  
.85714 .52381 L  
.85714 .04762 L  
.04762 .04762 L  
.04762 .52381 L  
.04762 .42857 L  
.28571 .28571 L  
.04762 .14286 L  
s  
P  
P  
p  
p  
1 0 0 r  
.01 w  
newpath  
.28571 .28571 .19048 0 365.73 arc  
s  
.36968 .40129 m  
.36968 .40129 .02857 0 365.73 arc  
F  
.28571 .28571 m  
.28571 .28571 .02857 0 365.73 arc  
F  
P  
p  
.02 w  
.28571 .28571 Mdot  
.36968 .40129 Mdot  
P  
P  
p  
p  
0 1 0 r  
.004 w  
.28571 .04762 m  
.28571 .04762 .02857 0 365.73 arc  
F  
.38472 .4646 m  
.38472 .4646 .02857 0 365.73 arc  
F  
.27181 .05092 m  
.29961 .04432 L  
.39861 .4613 L  
.37082 .4679 L  
F  
P  
p  
.02 w  
.28571 .04762 Mdot  
.38472 .4646 Mdot  
P  
p  
.01 w  
.30771 .14028 m  
.37372 .41827 L  
s  
P  
P  
p  
0 0 1 r  
.004 w  
.61533 .52381 m  
.61533 .52381 .01905 0 365.73 arc  
F  
.61533 .57143 m  
.61533 .52381 L  
.75819 .52381 L  
.75819 .57143 L  
F  
P  
p  
.018 w  
.38472 .4646 m  
.61533 .52381 L  
s  
P  
P  
% End of Graphics  
MathPictureEnd  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{277, 171},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004E0000Za000`40O003h00Oogoo5Woo003oOolF
Ool00?mooaIoo`00ogoo5Woo003oOolFOol00?mooaIoo`00ogoo5Woo001;Ool70n33Ool004Uoo`/3
h<5oo`00BGoo30?P`7oo0018Ool>0n2oOol004Qoo`h3h;moo`00B7oo3P?P_goo0017Ool60n020007
0n2oOol000aooc/000D3h0@000H3h9L002Qoo`0037oo>`001@?P10001P?PU`00:7oo000<Ool2000i
Ool60n0200070n2EOol2000XOol000aoo`8003Yoo`h3h9Eoo`8002Qoo`0037oo0P00>goo30?PUWoo
0P00:7oo000<Ool2000kOol;0n2GOol2000XOol000aoo`8003aoo`X3h9Moo`8002Qoo`0037oo0P00
?Goo2@?PUgoo0P00:7oo000<Ool2000oOol80n2FOol2000XOol000aoo`80041oo`L3h9Ioo`8002Qo
o`0037oo0P00@7oo1`?PUWoo0P00:7oo000<Ool20010Ool70n2FOol2000XOol000aoo`8003Qoo`03
O01oogoo00Eoo`P3h09oo`03O01oogoo091oo`8002Qoo`0037oo0P00=Goo37`01`?P1G`0T7oo0P00
:7oo000<Ool2000`Ool00g`0Ooml000>O0070n08O0000gooO01oo`2:Ool2000XOol000aoo`8002io
o`Ql00]oo`L3h0Aoo`Ul08Qoo`8002Qoo`0037oo0P00:goo27`03Woo20?P1Goo2G`0QWoo0P00:7oo
000<Ool2000YOol6O00BOol80n0;Ool6O023Ool2000XOol000aoo`8002Qoo`Al01Ioo`L3h0eoo`El
089oo`8002Qoo`0037oo0P009goo0g`067oo1`?P47oo0g`0PGoo0P00:7oo000<Ool2000TOol5O00I
Ool80n0@Ool4O01oOol2000XOol000aoo`80029oo`Il01Yoo`P3h15oo`El07eoo`8002Qoo`0037oo
0P008Goo17`07Woo1`?P4goo17`0O7oo0P00:7oo000<Ool2000POol3O00POol70n0EOol3O01kOol2
000XOol000aoo`8001moo`=l025oo`@3h0040003h0?P0n0EOol3O01jOol2000XOol000aoo`8001io
o`=l029oo`<3h0<00083h1Ioo`=l07Uoo`8002Qoo`0037oo10006goo0g`097oo0`?P0P000P?P5goo
0g`0N7oo0P00:7oo000<Ool5000IOol3O00UOol30n0200020n0HOol3O01gOol2000XOol000aoo`80
0003Ool00000008001Eoo`Al02Ioo`<3h08000<3h1Qoo`Al07Eoo`8002Qoo`0037oo0P000Woo1@00
4Woo17`09goo0`?P0`000P?P6Goo17`0M7oo0P00:7oo000<Ool20004Ool4000AOol2O00ZOol30n02
00020n0KOol3O01cOol2000XOol000aoo`8000Ioo`@000ioo`=l02Yoo`<3h0800083h1aoo`=l079o
o`8002Qoo`0037oo0P001goo1@002goo0g`0:goo0`?P0P000`?P77oo0W`0LWoo0P00:7oo000<Ool2
0009Ool50008Ool3O00/Ool30n0300020n0MOol00g`0Oomoo`1`Ool2000XOol000aoo`8000]oo`@0
00Ioo`=l02eoo`@3h0800083h1eoo`9l075oo`8002Qoo`0037oo0P003Goo10000goo0g`0;goo0`?P
0P000P?P7Woo0W`0L7oo0P00:7oo000<Ool2000>Ool500000gooO01l000`Ool30n0200030n0NOol0
0g`0Oomoo`1^Ool2000XOol000aoo`80011oo`@0009l031oo`<3h08000<3h1ioo`9l06moo`8002Qo
o`0037oo0P004Woo00@007`0O01l031oo`<3h0<00083h1ioo`=l06ioo`8002Qoo`0037oo0P004goo
0W`00`00;goo0`?P0P000P?P7goo0g`0KGoo0P00:7oo000<Ool2000COol00g`0Ool00003000^Ool3
0n0200030n0OOol3O01/Ool2000XOol000aoo`80019oo`9l00=oo`@002aoo`<3h08000<3h21oo`9l
06aoo`8002Qoo`0037oo0P004Woo00=l07ooOol00goo1@00:Woo0`?P0`000P?P87oo0g`0Jgoo0P00
:7oo000<Ool2000AOol2O007Ool4000ZOol30n0200020n0QOol2O01[Ool2000XOol000aoo`80011o
o`9l00Yoo`@002Qoo`<3h08000<3h21oo`9l06]oo`8002Qoo`0037oo0P003goo0W`037oo1@009Woo
0`?P0P000`?P87oo0g`0JWoo0P00:7oo000<Ool2000?Ool2O00>Ool5000TOol30n0300020n0QOol2
O01ZOol2000XOol000aoo`8000moo`=l00moo`@002Aoo`<3h0800083h25oo`=l06Uoo`8002Qoo`00
37oo0P003goo0W`04Woo10008Woo0`?P0P000`?P8Goo0W`0JGoo0P00:7oo000<Ool2000?Ool2O00C
Ool5000POol30n0200030n0QOol2O01YOol2000XOol000aoo`8000ioo`=l01Eoo`@001moo`<3h0<0
0083h25oo`=l06Qoo`8002Qoo`0037oo0P003Woo0W`067oo10007Goo10?P0P000P?P8Goo0W`0JGoo
0P00:7oo000<Ool2000=Ool3O00IOol5000LOol30n0200030n0POol3O01XOol2000XOol000aoo`80
00eoo`9l01aoo`@001]oo`<3h08000<3h21oo`=l06Qoo`8002Qoo`0037oo0P003Goo0W`07Woo1000
6Goo0`?P0P000`?P8Goo0W`0J7oo0P00:7oo000<Ool2000<Ool3O00OOol5000GOol30n0300020n0Q
Ool3O01WOol2000XOol000aoo`8000aoo`9l029oo`@001Moo`<3h0800083h25oo`9l06Qoo`8002Qo
o`0037oo0P0037oo0W`097oo10005Goo0`?P0P000`?P87oo0g`0Igoo0P00:7oo000<Ool2000<Ool2
O00UOol50006Ool6O007Ool30n0200030n0POol3O01WOol2000XOol000aoo`8000aoo`9l02Moo`D0
0003Ooml07`000Ul00Eoo`<3h0<00083h25oo`9l06Moo`8002Qoo`0037oo0P0037oo0W`0:Goo1000
37`01Goo0`?P0P000P?P8Goo0g`0IWoo0P00:7oo000<Ool2000<Ool2O00[Ool2000=O004Ool30n02
00030n0POol2O01WOol2000XOol000aoo`8000]oo`9l02eoo`il00Aoo`<3h08000<3h21oo`9l06Mo
o`8002Qoo`0037oo0P002goo0W`0;Goo3W`017oo0`?P0`000P?P87oo0W`0Igoo0P00:7oo000<Ool2
000;Ool2O00]Ool5O0020007O005Ool30n0200020n0POol2O01WOol2000XOol000aoo`8000]oo`9l
02aoo`El00@000Il00Eoo`<3h08000<3h1moo`9l06Moo`8002Qoo`0037oo0P002goo0W`0;7oo1G`0
10001g`017oo0`?P0P000`?P7goo0W`0Igoo0P00:7oo000<Ool2000;Ool2O00/Ool6O0020007O005
Ool30n0300020n0OOol2O01WOol2000XOol000aoo`8000]oo`9l02aoo`ml00Eoo`@3h0800083h1mo
o`9l06Moo`8002Qoo`0037oo0P002goo0g`0:goo00<007`0O00037`01Woo0`?P0P000`?P7Woo0W`0
Igoo0P00:7oo000<Ool2000<Ool2O00YOol4000<O007Ool30n0200030n0NOol3O01VOol2000XOol0
00aoo`8000aoo`9l02Moo`D0009oo`Yl00Qoo`<3h0<00083h1ioo`9l06Moo`8002Qoo`0037oo0P00
37oo0W`09Goo1@001Goo1g`02Woo10?P0P000P?P7Woo0W`0Igoo0P00:7oo000<Ool2000<Ool2O00T
Ool4000IOol30n0200030n0LOol3O01WOol2000XOol000aoo`8000aoo`9l029oo`@001]oo`<3h080
00<3h1aoo`9l06Qoo`8002Qoo`0037oo0P0037oo0g`07goo1@0077oo0`?P0P000`?P77oo0g`0Igoo
0P00:7oo000<Ool2000<Ool3O00NOol4000NOol30n0300020n0LOol2O01XOol2000XOol000aoo`80
00eoo`9l01aoo`@0025oo`<3h08000<3h1]oo`9l06Qoo`8002Qoo`0037oo0P003Goo0g`06Goo1@00
8Woo0`?P0P000`?P6Woo0g`0J7oo0P00:7oo000<Ool2000>Ool2O00HOol4000TOol30n0200030n0J
Ool2O01YOol2000XOol000aoo`8000ioo`9l01Ioo`@002Ioo`<3h0<00083h1Yoo`=l06Qoo`8002Qo
o`0037oo0P003Woo0W`057oo1@00:7oo0`?P0P000`?P6Goo0W`0JGoo0P00:7oo000<Ool2000>Ool2
O00COol4000ZOol30n0200030n0IOol2O01YOol2000XOol000aoo`8000ioo`9l015oo`@002aoo`<3
h08000<3h1Qoo`=l06Uoo`8002Qoo`0037oo0P003Woo0g`03Woo1@00;Goo0`?P0`000P?P67oo0W`0
JWoo0P00:7oo000<Ool2000@Ool00g`0Oomoo`0:Ool5000_Ool40n0200030n0FOol3O01ZOol2000X
Ool000aoo`80011oo`9l00Yoo`@0039oo`<3h08000<3h1Ioo`9l06]oo`8002Qoo`0037oo0P004Goo
0W`01goo1000=7oo0`?P0P000`?P5Woo0W`0Jgoo0P00:7oo000<Ool2000BOol00g`0Oomoo`03Ool5
000eOol30n0300020n0EOol3O01[Ool2000XOol000aoo`80019oo`9l00=oo`@003Moo`@3h08000<3
h1Aoo`9l06aoo`8002Qoo`0037oo0P004goo00=l07oo00000`00>Woo0`?P0P000`?P4goo0g`0K7oo
0P00:7oo000<Ool2000COol2O003000kOol30n0200030n02O00@Ool3O01]Ool2000XOol000aoo`80
019oo`800003O00007oo03]oo`04O003h0?P0n0200030n03O00>Ool3O01^Ool2000XOol000aoo`80
011oo`@0009l03]oo`9l00<3h0<000<3h0=l00eoo`9l06moo`8002Qoo`0037oo0P003Woo1@000Woo
00=l07ooOol0>Goo0g`00`?P0P000`?P0g`03Goo00=l07ooOol0KWoo0P00:7oo000<Ool2000=Ool4
0004Ool2O00jOol3O0030n0200030n04O00;Ool2O01`Ool2000XOol000aoo`8000]oo`@000Moo`9l
03Qoo`Al00<3h08000<3h0Al00Yoo`9l075oo`8002Qoo`0037oo0P002Goo1@0027oo0g`0=goo17`0
0`?P0`000`?P0g`02Woo00=l07ooOol0L7oo0P00:7oo000<Ool20007Ool5000;Ool3O00fOol5O003
0n0200030n02O00:Ool2O01bOol2000XOol000aoo`8000Ioo`@000ioo`=l03Eoo`El00<3h08000<3
h09l00Uoo`=l079oo`8002Qoo`0037oo0P0017oo10004Goo0W`0=Woo17`00`?P0P000`?P0W`027oo
0g`0Lgoo0P00:7oo000<Ool20002Ool5000BOol4O00eOol3O0030n0300030n07Ool4O01dOol2000X
Ool000aoo`800003Ool00000008001Eoo`Al03Aoo`=l00@3h0030003h0?P0083h0Ioo`Al07Eoo`80
02Qoo`0037oo1@006Goo0g`0=7oo0g`020?P1Goo0g`0Mgoo0P00:7oo000<Ool4000KOol3O00dOol2
O0080n04Ool3O01hOol2000XOol000aoo`8001ioo`=l03Eoo`T3h09oo`=l07Uoo`8002Qoo`0037oo
0P007goo17`0<goo2@?P17`0NWoo0P00:7oo000<Ool2000POol4O00cOol80n03O01kOol2000XOol0
00aoo`80029oo`=l039oo`X3h7aoo`8002Qoo`0037oo0P008goo17`0<7oo2`?PNgoo0P00:7oo000<
Ool2000TOol4O00^Ool=0n1jOol2000XOol000aoo`8002Ioo`Al02]oo`h3h7Yoo`8002Qoo`0037oo
0P009goo1G`0:Goo1P?P0P001P?PNWoo0P00:7oo000<Ool2000YOol6O00UOol00g`00n03h0040n06
00030n1iOol2000XOol000aoo`8002]oo`Il0003Ooml07oo01]oo`03O01oog`0009l00H3h0/007Qo
o`8002Qoo`0037oo0P00;Woo27`00Woo00=l07ooOol03goo00=l07ooO0001g`01P?P3`00M7oo0P00
:7oo000<Ool2000_Ool<O00<Ool;O002Ool70n0B001`Ool2000XOol000aoo`8003AooaUl00Moo``3
h14006aoo`8002Qoo`0037oo0P00>Goo3g`03Goo3P?P00=oo`0000003`00J7oo0P00:7oo000<Ool2
001FOol<0n06OolA001TOol2000XOol000aoo`8005Qoo`T3h0]ooa00065oo`8002Qoo`0037oo0P00
FGoo1P?P4Goo4000GGoo0P00:7oo000<Ool2001dOol@001IOol2000XOol000aoo`8007Qooa0005Eo
o`8002Qoo`0037oo0P00Ngoo4@00DGoo0P00:7oo000<Ool2001oOolA001=Ool2000XOol000aoo`80
08=ooa4000Aoo`H07cmoo`8002Qoo`0037oo0P00Qgoo4@001`0O?Woo0P00:7oo000<Ool2002;OolA
000401lmOol2000XOol000aoo`8008moo`l000807ceoo`8002Qoo`0037ooX0000P0O?`00:7oo000<
OonH00000`0O00000004000U01lM000XOol00:Aoo`D07`8002D07dEoo`00YGoo:`0OAGoo002UOol[
01m5Ool00:MoobT07dEoo`00ZGoo9`0OAGoo002YOolW01m5Ool00:UoobL07dEoo`00ZGoo9`0OAGoo
002YOolW01m5Ool00:UoobL07dEoo`00ZGoo9`0OAGoo002YOolW01m5Ool00?mooaIoo`00ogoo5Woo
003oOolFOol00?mooaIoo`00ogoo5Woo003oOolFOol00?mooaIoo`00ogoo5Woo003oOolFOol00?mo
oaIoo`00ogoo5Woo003oOolFOol00?mooaIoo`00\
\>"],
  ImageRangeCache->{{{0, 276}, {170, 0}} -> {-6.05309, -1.00006, 0.0764717, 
  0.0764717}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Output Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " numerical output functions return expressions that evaluate to numbers or \
vectors, such as the distance between two points, the angle between two \
lines, or the coordinates of a point. These functions take point, vector, and \
axis objects as arguments, identical in structure to the geometry objects \
used when building constraints. When local point numbers are used, the local \
coordinates are taken from the current body objects, as specified with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nEach of the output functions are demonstrated in the context of the \
quick-return mechanism model defined in the previous subsection."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global coordinates ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the dependent variables associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". If the current solution method setting is ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (the default) ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Th",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " representing the origin location and rotation angle of the body. If the \
current solution method setting is ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ei",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ej",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"],
  "\n\n",
  StyleBox["Distance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the distance between the two points.\n\n",
  StyleBox["Angle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the direction angle of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", with respect to the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis.\n\n",
  StyleBox["Rotation[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global rotation angle of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["EulerParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of 2D Euler parameters ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ei",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ej",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["EulerParameters[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of 2D Euler parameters ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ei",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Ej",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " associated with ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " ",
  StyleBox["{Cos[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Sin[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["]}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Output functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["IncludedAngle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the positive angle between the two vectors.\n \n",
  StyleBox["IntersectionPoint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the point of intersection of the two axes. \n \n",
  StyleBox["PointToLineDistance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", measured perpendicular to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["ProjectOnLine[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is in the direction of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["ProjectOnLine[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " orthogonally projected onto ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["More complex output functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to convert a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object into the global coordinates of the point."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the global coordinates of point 2 on the drive arm."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[Point[drivearm, 2]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X3 - 9\ Sin[Th3], Y3 + 9\ Cos[Th3]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " assumes a point object if only the arguments of ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are given. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[drivearm, 2]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X3 - 9\ Sin[Th3], Y3 + 9\ Cos[Th3]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This gets a numerical result from the output of ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(% /. SolveMech[.3]\), 
    \(%% /. SolveMech[.4]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-1.05510583810579494`\), 8.93793889386110507`}\)], "Output"],

Cell[BoxData[
    \({\(-3.03987260931660152`\), 8.47107871047877125`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to find the absolute distance between any two points in \
space. The points can be on one body or on two different bodies."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the distance from the center of the crank to point 2 on the slider. \
"], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Distance[Point[crank, 1], Point[slider, 2]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\@\(\((\(-X2\) + X4 + 3\ Cos[Th4])\)\^2 + 
        \((\(-Y2\) + Y4 + 3\ Sin[Th4])\)\^2\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Here is the numerical result. ", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(% /. SolveMech[.1]\), 
    \(%% /. SolveMech[.2]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(11.9016023282781201`\)], "Output"],

Cell[BoxData[
    \(10.2441006893209474`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the length of the line from the center of the crank to the drive \
pin. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Distance[Point[crank, 1], Point[crank, 2]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(3\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that it was not necessary to apply a solution rule to the last example \
to get a numerical result because the dimension being measured is not a \
function of the coordinates of each body."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the minimum distance between the crank axis and the center line of \
the drive arm."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(PointToLineDistance[Point[crank, 1], Line[drivearm, 1, 2]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(1\/9\ 
      \((9\ \((\(-X2\) + X3)\)\ Cos[Th3] - 9\ \((Y2 - Y3)\)\ Sin[Th3])\)\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(% /. SolveMech[.2]\), 
    \(%% /. SolveMech[.25]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.586169910058775034`\)], "Output"],

Cell[BoxData[
    \(1.1480684567009507`*^-16\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that the distance is zero when the crank has turned 1/4 turn, and the \
drive arm is pointed straight up, through the axis of the crank."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the direction angle of the center line of the connecting rod."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Angle[Line[drivearm, 2, slider, 1]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ArcTan[\(-X3\) + X4 + 9\ Sin[Th3], \(-Y3\) + Y4 - 9\ Cos[Th3]]\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result in degrees. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% /. SolveMech[.3]\)\/Degree\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(12.2637521432348339`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function simply returns the angular coordinate of the specified body."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is theta of the drive arm."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rotation[drivearm]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Th3\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This returns the intersection of the connecting rod axis and a vertical line \
through the crank axis."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntersectionPoint[Line[drivearm, 2, slider, 1], Line[ground, 0, {0, 1}]]
         /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.`, 9.16729002669237225`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["ProjectOnLine",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to find the projection of a point on one body onto a \
line located on another body (or bodies). "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This projects the crank's drive pin onto the connecting rod."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProjectOnLine[Point[crank, 2], Line[drivearm, 2, slider, 1]] /. 
      LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-1.15798884008182922`\), 8.91557494495656044`}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Vector Algebra Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " vector algebra functions perform many common vector algebra operations \
such as cross and dot products of vectors. These functions can be used to \
build more complicated functions that are not provided by ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The output functions take point, vector, and axis objects as arguments, \
identical in structure to the geometry objects used when building constraint \
objects. When local point numbers are used, the local coordinates are taken \
from the current body objects, as specified with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nEach of the vector algebra functions are demonstrated in the context \
of the quick-return mechanism model defined at the beginning of this \
section."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Direction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global direction vector of the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Magnitude[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the magnitude or length of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Unit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a unit vector in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Cross[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the cross product of the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["RotationMatrix[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 2D rotation matrix associated with ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " ",
  StyleBox["{{Cos[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["], -Sin[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]}, {Sin[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["], Cos[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["RotationMatrix[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the rotation matrix associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". Note that ",
  StyleBox["RotationMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " differentiates between ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " and ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " by assuming that ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " is an integer.\n\n",
  StyleBox["PointToLocal[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the local coordinates of the ",
  StyleBox["point",
    FontSlant->"Italic"],
  " relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Vector algebra functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to convert ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " vector objects into 2D vectors in global coordinates. Note that ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s definition of ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not interfere with its use as a built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " symbol."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the direction vector of the connecting rod."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Direction[Line[drivearm, 2, slider, 1]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-X3\) + X4 + 9\ Sin[Th3], \(-Y3\) + Y4 - 9\ Cos[Th3]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. SolveMech[.45]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({4.62875582992817413`, 1.89066640814976771`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Several ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " output functions are textbook vector algebra functions that are capable \
of dealing with normal 2D vectors or ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " line objects interchangeably."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can return the length of the line from one end of the connecting rod to \
the other."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Magnitude[Line[drivearm, 2, slider, 1]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(5.`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also works with simple vectors."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Magnitude[{9, 12}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(15\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Unit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also works with vectors or line objects. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Unit[{3, 5}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({3\/\@34, 5\/\@34}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The cross product of two vectors in 2D space is a scalar."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cross[Line[drivearm, 2, slider, 1], {0, 3}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(3\ \((\(-X3\) + X4 + 9\ Sin[Th3])\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. SolveMech[.5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(13.345753178056896`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a 2D rotation matrix that will rotate a vector on the slider into \
global coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(RotationMatrix[slider]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{Cos[Th4], \(-Sin[Th4]\)}, {Sin[Th4], Cos[Th4]}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"The global coordinates of a point specified in a local reference frame are \
equal to the coordinates of the origin of the reference frame plus the local \
coordinates of the point, rotated into the global reference frame."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a calculation of the global coordinates of the local point {3, 8} on \
the slider."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[slider, 0] + RotationMatrix[slider].{3, 8}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X4 + 3\ Cos[Th4] - 8\ Sin[Th4], Y4 + 8\ Cos[Th4] + 3\ Sin[Th4]}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function performs effectively the same calculation, directly."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[slider, {3, 8}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X4 + 3\ Cos[Th4] - 8\ Sin[Th4], Y4 + 8\ Cos[Th4] + 3\ Sin[Th4]}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.81812259383789296`, 18.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["PointToLocal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function converts the global point back to local coordinates. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(PointToLocal[slider, %] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({3.`, 8.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Two constant matrices that are commonly used in 2D vector algebra are also \
defined by ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 2D orthogonal rotation matrix ",
  StyleBox["{{0, -1}, {1, 0}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that rotates a vector pi/2 in the counterclockwise sense.\n\n",
  StyleBox["IMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 2D identity matrix ",
  StyleBox["{{1, 0}, {0, 1}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Constant utilities."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Coordinate Conversions"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PolarToXY",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["XYToPolar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are two conversion functions that do not accept ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " geometry objects as arguments. These functions only accept 2D vectors of \
the form {",
  StyleBox["x, y",
    FontSlant->"Italic"],
  "}."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PolarToXY[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["angle",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the Cartesian coordinates of a point specified in polar \
coordinates by ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " and ",
  StyleBox["angle",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["XYToPolar[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the polar coordinates of a point specified in Cartesian \
coordinates by ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Coordinate conversions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This converts a polar coordinate pair to Cartesian coordinates."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(PolarToXY[{4, \[Pi]\/3}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2, 2\ \@3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["This converts it back.", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(XYToPolar[%]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({4, \[Pi]\/3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["This converts a 2D vector to polar coordinates. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(XYToPolar[Location[slider, 2]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({10.3895050389274845`, 1.29610790807680963`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3.2  3D Output Functions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Numerical output from a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model can be generated with output functions that are defined in the \
auxiliary package ",
  StyleBox["Graf3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This package is autoloaded after the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " main package has been loaded if any of the output functions are called. \
Each output function returns a symbolic expression that represents the \
quantity being sought, in terms of the model's dependent variables ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Z3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ei4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on. To achieve a numerical result, the dependent variables must \
be replaced with numbers, typically by applying a solution rule returned by ",
  
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". More complicated and specific output functions can easily be defined by \
the user, making use of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s basic output functions and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in vector algebra functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " output functions, a 3D model is developed that can be measured. The model \
is a spatial slider-crank mechanism consisting of two moving bodies, the \
crank and the slider. A real slider-crank mechanism would have a fourth body, \
the connecting rod between the crank and the slider.\n\nThe motion of the \
slider-crank mechanism is driven by the rotation of the crank, which forces \
the slider to reciprocate in a straight track that is parallel to the axis of \
the crank. The crank is attached to the slider via a connecting rod that is \
modeled by a distance constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the complete 3D slider-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!  
%%Creator: Mathematica  
%%AspectRatio: .83498   
MathPictureStart  
%% Graphics3D  
/Courier findfont 10  scalefont  setfont  
% Scaling calculations  
-0.0177149 0.992893 -0.0316522 0.992893 [  
[ 0 0 0 0 ]  
[ 1 .83498 0 0 ]  
] MathScale  
% Start of Graphics  
1 setlinecap  
1 setlinejoin  
newpath  
[ ] 0 setdash  
0 g  
0 0 m  
1 0 L  
1 .83498 L  
0 .83498 L  
closepath  
clip  
newpath  
p  
.002 w  
.67169 .36171 m  
.68339 .81015 L  
s  
.68339 .81015 m  
.97518 .70072 L  
s  
.97518 .70072 m  
.94115 .1703 L  
s  
.94115 .1703 m  
.67169 .36171 L  
s  
.05344 .26268 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.02482 .75387 L  
s  
.02482 .75387 m  
.05344 .26268 L  
s  
.67169 .36171 m  
.68339 .81015 L  
s  
.68339 .81015 m  
.02482 .75387 L  
s  
.02482 .75387 m  
.05344 .26268 L  
s  
.05344 .26268 m  
.67169 .36171 L  
s  
.94115 .1703 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.97518 .70072 L  
s  
.97518 .70072 m  
.94115 .1703 L  
s  
P  
p  
.008 w  
.69732 .39447 m  
.70802 .75843 L  
s  
P  
p  
.002 w  
.75376 .47515 m .7838 .39367 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.74515 .56635 m .75376 .47515 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.7838 .39367 m .75376 .47515 L .73819 .47292 L p  
.761 .71 .804 r  
F P  
s  
P  
p  
.002 w  
.75376 .47515 m .74515 .56635 L .7295 .56435 L p  
.785 .634 .694 r  
F P  
s  
P  
p  
.002 w  
.7295 .56435 m .73819 .47292 L .75376 .47515 L p  
.785 .634 .694 r  
F P  
s  
P  
p  
.002 w  
.73819 .47292 m .76808 .39119 L .7838 .39367 L p  
.761 .71 .804 r  
F P  
s  
P  
p  
.002 w  
.76006 .64706 m .74515 .56635 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.73819 .47292 m .76808 .39119 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.74515 .56635 m .76006 .64706 L .74414 .64524 L p  
.785 .531 .553 r  
F P  
s  
P  
p  
.002 w  
.74414 .64524 m .7295 .56435 L .74515 .56635 L p  
.785 .531 .553 r  
F P  
s  
P  
p  
.002 w  
.7295 .56435 m .73819 .47292 L p  
.79168 .5407 L .291 .2 .577 r  
F P  
s  
P  
p  
.8421 .60457 m .81306 .5942 L .79168 .5407 L .291 .2 .577 r  
F  
P  
p  
.81306 .5942 m .7295 .56435 L .79168 .5407 L .291 .2 .577 r  
F  
P  
p  
.83102 .624 m .7295 .56435 L .8421 .60457 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.82317 .63779 m .83908 .65079 L p  
.82295 .63817 L .556 .521 .772 r  
F P  
s  
P  
p  
.79136 .6007 m .77466 .61645 L .7295 .56435 L .291 .2 .577 r  
F  
P  
p  
.81674 .61561 m .79987 .6225 L .79136 .6007 L .291 .2 .577 r  
F  
P  
p  
.79987 .6225 m .79392 .62492 L .79136 .6007 L .291 .2 .577 r  
F  
P  
p  
.79392 .62492 m .74414 .64524 L .77466 .61645 L .291 .2 .577 r  
F  
P  
p  
.79392 .62492 m .77466 .61645 L .79136 .6007 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.83959 .64786 m .83908 .65079 L .82317 .63779 L p  
0 .336 .815 r  
F P  
s  
P  
p  
.81688 .62746 m .80311 .63083 L .81674 .61561 L .291 .2 .577 r  
F  
P  
p  
.80311 .63083 m .74414 .64524 L .79987 .6225 L .291 .2 .577 r  
F  
P  
p  
.80311 .63083 m .79987 .6225 L .81674 .61561 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.74414 .64524 m .73584 .59938 L p  
.77466 .61645 L .291 .2 .577 r  
F P  
s  
P  
p  
.81659 .64934 m .74414 .64524 L .81688 .62746 L .291 .2 .577 r  
F  
P  
p  
.81713 .64839 m .81688 .62746 L .83102 .624 L .291 .2 .577 r  
F  
P  
p  
.81659 .64934 m .81688 .62746 L .81713 .64839 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.79628 .69766 m .76006 .64706 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.83207 .66062 m .82264 .67165 L .81735 .66731 L p  
.683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.73584 .59938 m .7295 .56435 L p  
.77466 .61645 L .291 .2 .577 r  
F P  
s  
P  
p  
.83207 .66062 m .81735 .66731 L .81713 .64901 L .683 .512 .648 r  
F  
P  
p  
.83959 .64786 m .82317 .63779 L .83188 .64162 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.83203 .64169 m .83959 .64786 L p  
.83188 .64162 L 0 .336 .815 r  
F P  
s  
P  
p  
.002 w  
.81713 .64839 m .83207 .66062 L p  
.81713 .64901 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.83908 .65079 m .83207 .66062 L .81713 .64839 L p  
.556 .521 .772 r  
F P  
s  
P  
p  
.83908 .65079 m .81713 .64839 L .82295 .63817 L .556 .521 .772 r  
F  
P  
p  
.002 w  
.83585 .65124 m .83959 .64786 L .83203 .64169 L p  
.785 .445 .412 r  
F P  
s  
P  
p  
.002 w  
.83959 .64786 m .83908 .65079 L p  
.82355 .66893 L .748 .959 .661 r  
F P  
s  
P  
p  
.002 w  
.82264 .67165 m .81999 .67407 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.82788 .66271 m .83959 .64786 L .82355 .66893 L .748 .959 .661 r  
F  
P  
p  
.002 w  
.81735 .66731 m .82264 .67165 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.002 w  
.76006 .64706 m .79628 .69766 L .77996 .69593 L p  
.716 .298 .252 r  
F P  
s  
P  
p  
.002 w  
.77996 .69593 m .74414 .64524 L .76006 .64706 L p  
.716 .298 .252 r  
F P  
s  
P  
p  
.002 w  
.77996 .69593 m .74414 .64524 L p  
.83639 .65046 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.83207 .66062 m .82264 .67165 L .81999 .67407 L p  
.748 .959 .661 r  
F P  
s  
P  
p  
.82152 .67186 m .83207 .66062 L .81999 .67407 L .748 .959 .661 r  
F  
P  
p  
.81533 .68077 m .77996 .69593 L .83639 .65046 L .291 .2 .577 r  
F  
P  
p  
.81999 .67407 m .81622 .6775 L .81983 .67366 L .784 .448 .419 r  
F  
P  
p  
.002 w  
.81973 .67341 m .81622 .6775 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.002 w  
.83908 .65079 m .83207 .66062 L p  
.81622 .6775 L .748 .959 .661 r  
F P  
s  
P  
p  
.002 w  
.83319 .65365 m .83959 .64786 L p  
.81622 .6775 L .748 .959 .661 r  
F P  
s  
P  
p  
.88027 .65294 m .81533 .68077 L .83639 .65046 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.81999 .67407 m .81622 .6775 L p  
.82152 .67186 L .748 .959 .661 r  
F P  
s  
P  
p  
.81622 .6775 m .82788 .66271 L .82355 .66893 L .748 .959 .661 r  
F  
P  
p  
.84789 .63391 m .83552 .65041 L .83102 .624 L .291 .2 .577 r  
F  
P  
p  
.88027 .65294 m .83639 .65046 L .84789 .63391 L .291 .2 .577 r  
F  
P  
p  
.83639 .65046 m .83552 .65041 L .84789 .63391 L .291 .2 .577 r  
F  
P  
p  
.83552 .65041 m .81659 .64934 L .82746 .63025 L .291 .2 .577 r  
F  
P  
p  
.83552 .65041 m .82746 .63025 L .83102 .624 L .291 .2 .577 r  
F  
P  
p  
.002 w  
.32291 .27727 m .45723 .29939 L .45704 .36613 L p  
.788 .589 .632 r  
F P  
s  
P  
p  
.39943 .32159 m .45704 .36613 L .43092 .3337 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.37648 .31276 m .39876 .32752 L p  
.39943 .32159 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.39876 .32752 m .45704 .36613 L p  
.39943 .32159 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.40728 .31295 m .39943 .32159 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39943 .32159 m .40728 .31295 L .43416 .33495 L p  
.683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.32291 .27727 m .37648 .31276 L p  
.39943 .32159 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.41255 .30254 m .40728 .31295 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.40003 .31632 m .40557 .31022 L .3997 .31925 L .89 .969 .83 r  
F  
P  
p  
.40557 .31022 m .41255 .30254 L .40723 .30946 L .89 .969 .83 r  
F  
P  
p  
.40557 .31022 m .40723 .30946 L .3997 .31925 L .89 .969 .83 r  
F  
P  
p  
.32291 .27727 m .39943 .32159 L .39989 .31749 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.43416 .33495 m .40728 .31295 L p  
.43564 .33514 L .556 .521 .772 r  
F P  
s  
P  
p  
.002 w  
.40728 .31295 m .41255 .30254 L .45558 .33766 L p  
.556 .521 .772 r  
F P  
s  
P  
p  
.45723 .29939 m .47554 .34133 L .46664 .35326 L .173 .096 .522 r  
F  
P  
p  
.002 w  
.45708 .35031 m .45723 .29939 L p  
.46664 .35326 L .173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.47849 .34809 m .4753 .35078 L p  
.47554 .34133 L .173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.4753 .35078 m .47081 .35455 L p  
.47554 .34133 L .173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.47081 .35455 m .45704 .36613 L p  
.46664 .35326 L .173 .096 .522 r  
F P  
s  
P  
p  
.47554 .34133 m .47081 .35455 L .46664 .35326 L .173 .096 .522 r  
F  
P  
p  
.83188 .64162 m .4806 .35756 L .83203 .64169 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.45704 .36613 m .45708 .35031 L p  
.46664 .35326 L .173 .096 .522 r  
F P  
s  
P  
p  
.43303 .33481 m .47081 .35455 L .46322 .34613 L .481 .626 .915 r  
F  
P  
p  
.43416 .33495 m .46322 .34613 L .45558 .33766 L .481 .626 .915 r  
F  
P  
p  
.43303 .33481 m .46322 .34613 L .43416 .33495 L .481 .626 .915 r  
F  
P  
p  
.4357 .33514 m .40728 .31295 L .45558 .33766 L .556 .521 .772 r  
F  
P  
p  
.002 w  
.45704 .36613 m .47081 .35455 L p  
.43303 .33481 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.45723 .29939 m .47849 .28027 L .47849 .34809 L p  
.173 .096 .522 r  
F P  
s  
P  
p  
.002 w  
.34206 .25731 m .32291 .27727 L .45723 .29939 L p  
.584 .802 .982 r  
F P  
s  
P  
p  
.002 w  
.45723 .29939 m .47849 .28027 L .34206 .25731 L p  
.584 .802 .982 r  
F P  
s  
P  
p  
.002 w  
.47849 .34809 m .47849 .28027 L p  
.43517 .29479 L .789 .589 .63 r  
F P  
s  
P  
p  
.49093 .37839 m .43564 .33514 L .49082 .37823 L .556 .521 .772 r  
F  
P  
p  
.43564 .33514 m .40728 .31295 L .4357 .33514 L .556 .521 .772 r  
F  
P  
p  
.43564 .33514 m .4357 .33514 L .82317 .63779 L .556 .521 .772 r  
F  
P  
p  
.43092 .3337 m .43167 .33463 L .43303 .33481 L .481 .626 .915 r  
F  
P  
p  
.43167 .33463 m .45704 .36613 L .43303 .33481 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.41077 .29792 m .41255 .30254 L p  
.40003 .31632 L .89 .969 .83 r  
F P  
s  
P  
p  
.32291 .27727 m .39989 .31749 L .40045 .31257 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.45704 .36613 m .32146 .34526 L .32291 .27727 L p  
.788 .589 .632 r  
F P  
s  
P  
p  
.39017 .32717 m .40045 .31257 L .40003 .31632 L .89 .969 .83 r  
F  
P  
p  
.40045 .31257 m .41077 .29792 L .40003 .31632 L .89 .969 .83 r  
F  
P  
p  
.40045 .31257 m .43303 .33481 L .45558 .33766 L .481 .626 .915 r  
F  
P  
p  
.39989 .31749 m .43303 .33481 L .40045 .31257 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.43416 .33495 m .47485 .36825 L p  
.39943 .32159 L .683 .512 .648 r  
F P  
s  
P  
p  
.47454 .38035 m .39943 .32159 L .47485 .36825 L .683 .512 .648 r  
F  
P  
p  
.002 w  
.47081 .35455 m .47849 .34809 L p  
.45558 .33766 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.45558 .33766 m .82317 .63779 L p  
.4357 .33514 L .556 .521 .772 r  
F P  
s  
P  
p  
.002 w  
.81713 .64839 m .43416 .33495 L p  
.82295 .63817 L .556 .521 .772 r  
F P  
s  
P  
p  
.82295 .63817 m .43416 .33495 L .43564 .33514 L .556 .521 .772 r  
F  
P  
p  
.39989 .31749 m .39943 .32159 L .43092 .3337 L .481 .626 .915 r  
F  
P  
p  
.39017 .32717 m .40003 .31632 L .3997 .31925 L .89 .969 .83 r  
F  
P  
p  
.002 w  
.39804 .32312 m .39017 .32717 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39943 .32159 m .39804 .32312 L p  
.3997 .31925 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39804 .32312 m .39943 .32159 L p  
.81713 .64839 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.81735 .66731 m .39804 .32312 L p  
.81713 .64901 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.81622 .6775 m .39017 .32717 L p  
.81742 .6675 L .784 .448 .419 r  
F P  
s  
P  
p  
.002 w  
.39017 .32717 m .39804 .32312 L .81735 .66731 L p  
.784 .448 .419 r  
F P  
s  
P  
p  
.81742 .6675 m .39017 .32717 L .81735 .66731 L .784 .448 .419 r  
F  
P  
p  
.81713 .64901 m .39804 .32312 L .81713 .64839 L .683 .512 .648 r  
F  
P  
p  
.32291 .27727 m .34557 .28758 L .34077 .32642 L .481 .626 .915 r  
F  
P  
p  
.34557 .28758 m .40045 .31257 L .38881 .31527 L .481 .626 .915 r  
F  
P  
p  
.34557 .28758 m .38881 .31527 L .34077 .32642 L .481 .626 .915 r  
F  
P  
p  
.39017 .32717 m .39121 .32509 L .39147 .32531 L .89 .969 .83 r  
F  
P  
p  
.002 w  
.36269 .32987 m .34077 .32642 L p  
.38436 .3163 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.47485 .36825 m .81713 .64839 L p  
.47454 .38035 L .683 .512 .648 r  
F P  
s  
P  
p  
.002 w  
.8166 .67472 m .82363 .66482 L .42755 .34008 L p  
.553 .52 .773 r  
F P  
s  
P  
p  
.40045 .31257 m .3912 .3168 L .38881 .31527 L .481 .626 .915 r  
F  
P  
p  
.39121 .32509 m .40289 .30189 L .39147 .32531 L .89 .969 .83 r  
F  
P  
p  
.002 w  
.40289 .30189 m .41077 .29792 L p  
.39147 .32531 L .89 .969 .83 r  
F P  
s  
P  
p  
.40045 .31257 m .45558 .33766 L .41899 .33459 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.39353 .31218 m .40289 .30189 L p  
.39017 .32717 L .89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.39017 .32717 m .38826 .32267 L .39353 .31218 L p  
.89 .969 .83 r  
F P  
s  
P  
p  
.002 w  
.38826 .32267 m .44949 .373 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.002 w  
.44949 .373 m .8166 .67472 L p  
.42951 .34302 L .553 .52 .773 r  
F P  
s  
P  
p  
.42951 .34302 m .42173 .33635 L .44949 .373 L .553 .52 .773 r  
F  
P  
p  
.40045 .31257 m .41899 .33459 L .3912 .3168 L .481 .626 .915 r  
F  
P  
p  
.8166 .67472 m .42755 .34008 L .42173 .33635 L .553 .52 .773 r  
F  
P  
p  
.002 w  
.3912 .3168 m .38826 .32267 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.4806 .35756 m .4695 .34858 L .48062 .35757 L 0 .336 .815 r  
F  
P  
p  
.4695 .34858 m .46171 .34228 L .46947 .34855 L 0 .336 .815 r  
F  
P  
p  
.4695 .34858 m .46947 .34855 L .48062 .35757 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.47849 .34809 m .46702 .34629 L p  
.45558 .33766 L .481 .626 .915 r  
F P  
s  
P  
p  
.46452 .3388 m .45826 .33817 L .46981 .34673 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.82317 .63779 m .47355 .35234 L p  
.83188 .64162 L 0 .336 .815 r  
F P  
s  
P  
p  
.002 w  
.47355 .35234 m .45558 .33766 L p  
.47223 .35111 L 0 .336 .815 r  
F P  
s  
P  
p  
.83188 .64162 m .47355 .35234 L .47223 .35111 L 0 .336 .815 r  
F  
P  
p  
.46171 .34228 m .46183 .34238 L .48062 .35757 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.46702 .34629 m .46981 .34673 L p  
.46659 .34588 L .789 .589 .63 r  
F P  
s  
P  
p  
.45826 .33817 m .46659 .34588 L .46981 .34673 L .789 .589 .63 r  
F  
P  
p  
.48062 .35757 m .46943 .34852 L .48584 .35918 L 0 .336 .815 r  
F  
P  
p  
.46943 .34852 m .41255 .30254 L .45625 .33631 L 0 .336 .815 r  
F  
P  
p  
.4695 .34858 m .45558 .33766 L .45446 .33642 L 0 .336 .815 r  
F  
P  
p  
.47223 .35111 m .45558 .33766 L .4695 .34858 L 0 .336 .815 r  
F  
P  
p  
.45558 .33766 m .45595 .33794 L .44075 .33642 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.46702 .34629 m .42755 .34008 L p  
.44075 .33642 L .481 .626 .915 r  
F P  
s  
P  
p  
.002 w  
.38826 .32267 m .39017 .32717 L .47849 .39979 L p  
0 .319 .803 r  
F P  
s  
P  
p  
.002 w  
.47849 .39979 m .81622 .6775 L p  
.45416 .37731 L 0 .319 .803 r  
F P  
s  
P  
p  
.45416 .37731 m .38826 .32267 L .47849 .39979 L 0 .319 .803 r  
F  
P  
p  
.44075 .33642 m .42755 .34008 L .41734 .33446 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.40289 .30189 m .39353 .31218 L .42755 .34008 L p  
.683 .511 .647 r  
F P  
s  
P  
p  
.002 w  
.42755 .34008 m .39353 .31218 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.46171 .34228 m .41255 .30254 L .46183 .34238 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.45558 .33766 m .41255 .30254 L p  
.45446 .33642 L 0 .336 .815 r  
F P  
s  
P  
p  
.43933 .32416 m .42705 .33505 L .45826 .33817 L .789 .589 .63 r  
F  
P  
p  
.4447 .32561 m .45826 .33817 L .46452 .3388 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.46981 .34673 m .47849 .34809 L p  
.46456 .33096 L .789 .589 .63 r  
F P  
s  
P  
p  
.43517 .29479 m .45814 .32923 L .46456 .33096 L .789 .589 .63 r  
F  
P  
p  
.45814 .32923 m .46981 .34673 L .46456 .33096 L .789 .589 .63 r  
F  
P  
p  
.48584 .35918 m .41255 .30254 L .4447 .32561 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.41255 .30254 m .41077 .29792 L .4447 .32561 L p  
0 .336 .815 r  
F P  
s  
P  
p  
.83188 .64162 m .47223 .35111 L .4695 .34858 L 0 .336 .815 r  
F  
P  
p  
.46943 .34852 m .45625 .33631 L .48584 .35918 L 0 .336 .815 r  
F  
P  
p  
.82295 .63817 m .49093 .37839 L .82317 .63779 L .556 .521 .772 r  
F  
P  
p  
.49093 .37839 m .49082 .37823 L .82317 .63779 L .556 .521 .772 r  
F  
P  
p  
.4806 .35756 m .48062 .35757 L .83203 .64169 L 0 .336 .815 r  
F  
P  
p  
.002 w  
.48584 .35918 m .83203 .64169 L p  
.48062 .35757 L 0 .336 .815 r  
F P  
s  
P  
p  
.002 w  
.83203 .64169 m .4447 .32561 L p  
.83585 .65124 L .785 .445 .412 r  
F P  
s  
P  
p  
.002 w  
.4447 .32561 m .41077 .29792 L p  
.44379 .32536 L .785 .445 .412 r  
F P  
s  
P  
p  
.44316 .32519 m .41077 .29792 L .42561 .32047 L .785 .445 .412 r  
F  
P  
p  
.002 w  
.41077 .29792 m .40289 .30189 L .42561 .32047 L p  
.785 .445 .412 r  
F P  
s  
P  
p  
.43933 .32416 m .45826 .33817 L .4447 .32561 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.83319 .65365 m .83585 .65124 L p  
.44379 .32536 L .785 .445 .412 r  
F P  
s  
P  
p  
.44316 .32519 m .44379 .32536 L .41077 .29792 L .785 .445 .412 r  
F  
P  
p  
.83319 .65365 m .44379 .32536 L .44316 .32519 L .785 .445 .412 r  
F  
P  
p  
.002 w  
.47849 .28027 m .34206 .25731 L .3413 .29777 L p  
.789 .589 .63 r  
F P  
s  
P  
p  
.002 w  
.3413 .29777 m .34077 .32642 L p  
.38842 .31045 L .789 .589 .63 r  
F P  
s  
P  
p  
.42561 .32047 m .42705 .33505 L .43933 .32416 L .789 .589 .63 r  
F  
P  
p  
.42572 .32159 m .40289 .30189 L .42755 .34008 L .683 .511 .647 r  
F  
P  
p  
.002 w  
.42755 .34008 m .46702 .34629 L p  
.42711 .33558 L .789 .589 .63 r  
F P  
s  
P  
p  
.424 .33474 m .42755 .34008 L .42711 .33558 L .789 .589 .63 r  
F  
P  
p  
.45595 .33794 m .46702 .34629 L .44075 .33642 L .481 .626 .915 r  
F  
P  
p  
.424 .33474 m .46702 .34629 L .46659 .34588 L .789 .589 .63 r  
F  
P  
p  
.45826 .33817 m .424 .33474 L .46659 .34588 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.82363 .66482 m .83319 .65365 L .42561 .32047 L p  
.683 .511 .647 r  
F P  
s  
P  
p  
.002 w  
.42561 .32047 m .40289 .30189 L p  
.42572 .32159 L .683 .511 .647 r  
F P  
s  
P  
p  
.82363 .66482 m .42561 .32047 L .42572 .32159 L .683 .511 .647 r  
F  
P  
p  
.48175 .36991 m .42572 .32159 L .42755 .34008 L .683 .511 .647 r  
F  
P  
p  
.42346 .29871 m .3413 .29777 L .38842 .31045 L .789 .589 .63 r  
F  
P  
p  
.47849 .28027 m .42235 .28743 L .42346 .29871 L .789 .589 .63 r  
F  
P  
p  
.42235 .28743 m .3413 .29777 L .42346 .29871 L .789 .589 .63 r  
F  
P  
p  
.4107 .30299 m .43933 .32416 L .4447 .32561 L .789 .589 .63 r  
F  
P  
p  
.83585 .65124 m .4447 .32561 L .44379 .32536 L .785 .445 .412 r  
F  
P  
p  
.42492 .31351 m .42561 .32047 L .43933 .32416 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.42561 .32047 m .83319 .65365 L p  
.44316 .32519 L .785 .445 .412 r  
F P  
s  
P  
p  
.002 w  
.39353 .31218 m .3912 .3168 L p  
.42173 .33635 L .553 .52 .773 r  
F P  
s  
P  
p  
.4107 .30299 m .38356 .31208 L .42705 .33505 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.81622 .6775 m .8166 .67472 L .44949 .373 L p  
0 .319 .803 r  
F P  
s  
P  
p  
.002 w  
.44949 .373 m .38826 .32267 L p  
.45416 .37731 L 0 .319 .803 r  
F P  
s  
P  
p  
.81622 .6775 m .44949 .373 L .45416 .37731 L 0 .319 .803 r  
F  
P  
p  
.41834 .33418 m .41899 .33459 L .4084 .33371 L .481 .626 .915 r  
F  
P  
p  
.41834 .33418 m .4084 .33371 L .36269 .32987 L .481 .626 .915 r  
F  
P  
p  
.3912 .3168 m .41834 .33418 L .36269 .32987 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.42755 .34008 m .36269 .32987 L p  
.41734 .33446 L .481 .626 .915 r  
F P  
s  
P  
p  
.424 .33474 m .40616 .33296 L .42755 .34008 L .789 .589 .63 r  
F  
P  
p  
.38797 .31829 m .36269 .32987 L .38436 .3163 L .481 .626 .915 r  
F  
P  
p  
.002 w  
.34077 .32642 m .41105 .33748 L p  
.40616 .33296 L .789 .589 .63 r  
F P  
s  
P  
p  
.002 w  
.41105 .33748 m .42755 .34008 L p  
.40616 .33296 L .789 .589 .63 r  
F P  
s  
P  
p  
.38881 .31527 m .38797 .31829 L .38436 .3163 L .481 .626 .915 r  
F  
P  
p  
.3912 .3168 m .38797 .31829 L .38881 .31527 L .481 .626 .915 r  
F  
P  
p  
.38356 .31208 m .34077 .32642 L .40616 .33296 L .789 .589 .63 r  
F  
P  
p  
.38356 .31208 m .40616 .33296 L .42705 .33505 L .789 .589 .63 r  
F  
P  
p  
.4107 .30299 m .42705 .33505 L .42492 .31351 L .789 .589 .63 r  
F  
P  
p  
.43517 .29479 m .41774 .30063 L .46452 .3388 L .789 .589 .63 r  
F  
P  
p  
.41774 .30063 m .4107 .30299 L .4447 .32561 L .789 .589 .63 r  
F  
P  
p  
.41774 .30063 m .4447 .32561 L .46452 .3388 L .789 .589 .63 r  
F  
P  
p  
.002 w  
.42755 .34008 m .82363 .66482 L p  
.48175 .36991 L .683 .511 .647 r  
F P  
s  
P  
p  
.83102 .624 m .81688 .62746 L .81674 .61561 L .291 .2 .577 r  
F  
P  
p  
.88027 .65294 m .83102 .624 L .8421 .60457 L .291 .2 .577 r  
F  
P  
p  
.008 w  
.3973 .29852 m  
.42113 .30241 L  
s  
P  
p  
.008 w  
.42113 .30241 m  
.43532 .30473 L  
s  
P  
p  
.008 w  
.43532 .30473 m  
.44888 .30694 L  
s  
P  
p  
.008 w  
.44888 .30694 m  
.48067 .31213 L  
s  
P  
p  
.008 w  
.48067 .31213 m  
.49912 .31514 L  
s  
P  
p  
.008 w  
.49912 .31514 m  
.75347 .35666 L  
s  
P  
p  
.008 w  
.58716 .35543 m  
.72318 .37705 L  
s  
P  
p  
.008 w  
.47849 .33815 m  
.58716 .35543 L  
s  
P  
p  
.008 w  
.10888 .30305 m  
.24902 .32482 L  
s  
P  
p  
.008 w  
.24902 .32482 m  
.32165 .3361 L  
s  
P  
p  
.008 w  
.48952 .36218 m  
.69732 .39447 L  
s  
P  
p  
.002 w  
.7838 .39367 m .82922 .34103 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.008 w  
.7188 .38001 m  
.73637 .36817 L  
s  
P  
p  
.008 w  
.69732 .39447 m  
.7188 .38001 L  
s  
P  
p  
.002 w  
.82922 .34103 m .7838 .39367 L .76808 .39119 L p  
.684 .784 .926 r  
F P  
s  
P  
p  
.002 w  
.76808 .39119 m .81317 .33834 L .82922 .34103 L p  
.684 .784 .926 r  
F P  
s  
P  
p  
.002 w  
.76808 .39119 m .81317 .33834 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.008 w  
.73637 .36817 m  
.81197 .31727 L  
s  
P  
p  
.008 w  
.70802 .75843 m  
.8401 .70485 L  
s  
P  
p  
.008 w  
.8344 .30217 m  
.90769 .25282 L  
s  
P  
p  
.008 w  
.81197 .31727 m  
.8344 .30217 L  
s  
P  
p  
.002 w  
.34077 .32642 m .32146 .34526 L .32291 .27727 L p  
.481 .626 .915 r  
F P  
s  
P  
p  
.008 w  
.12518 .28199 m  
.3203 .313 L  
s  
P  
p  
.008 w  
.34338 .28972 m  
.3973 .29852 L  
s  
P  
p  
.002 w  
.34206 .25731 m .32291 .27727 L .32146 .34526 L p  
.092 .025 .48 r  
F P  
s  
P  
p  
.008 w  
.3203 .313 m  
.32214 .3133 L  
s  
P  
p  
.002 w  
.32146 .34526 m .34077 .32642 L .34206 .25731 L p  
.092 .025 .48 r  
F P  
s  
P  
p  
.008 w  
.14434 .25723 m  
.34338 .28972 L  
s  
P  
p  
.008 w  
.2432 .12945 m  
.10888 .30305 L  
s  
P  
p  
.002 w  
.82922 .34103 m .87989 .33275 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.87989 .33275 m .82922 .34103 L .81317 .33834 L p  
.26 .723 .95 r  
F P  
s  
P  
p  
.002 w  
.81317 .33834 m .8634 .32993 L .87989 .33275 L p  
.26 .723 .95 r  
F P  
s  
P  
p  
.002 w  
.81317 .33834 m .8634 .32993 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.89742 .65492 m .84638 .7023 L .79628 .69766 L p  
.297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.79628 .69766 m .84638 .7023 L .8296 .70052 L p  
0 .527 .718 r  
F P  
s  
P  
p  
.002 w  
.8296 .70052 m .77996 .69593 L .79628 .69766 L p  
0 .527 .718 r  
F P  
s  
P  
p  
.002 w  
.88027 .65294 m .8296 .70052 L .77996 .69593 L p  
.291 .2 .577 r  
F P  
s  
P  
p  
.008 w  
.65191 .49173 m  
.67062 .49431 L  
s  
P  
p  
.008 w  
.67062 .49431 m  
.69855 .49816 L  
s  
P  
p  
.008 w  
.69855 .49816 m  
.74087 .504 L  
s  
P  
p  
.008 w  
.74087 .504 m  
.77547 .50878 L  
s  
P  
p  
.008 w  
.77547 .50878 m  
.82119 .51509 L  
s  
P  
p  
.002 w  
.87989 .33275 m .92231 .37563 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.92231 .37563 m .87989 .33275 L .8634 .32993 L p  
.668 .175 .07 r  
F P  
s  
P  
p  
.002 w  
.8634 .32993 m .90539 .37284 L .92231 .37563 L p  
.668 .175 .07 r  
F P  
s  
P  
p  
.002 w  
.8634 .32993 m .90539 .37284 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.82363 .66482 m .83319 .65365 L p  
.81622 .6775 L .748 .959 .661 r  
F P  
s  
P  
p  
.002 w  
.81622 .6775 m .8166 .67472 L .82363 .66482 L p  
.748 .959 .661 r  
F P  
s  
P  
p  
.5 0 0 r  
.03 w  
.82788 .66271 Mdot  
P  
p  
.008 w  
.90769 .25282 m  
.91445 .36768 L  
s  
P  
p  
.008 w  
.90769 .25282 m  
.2432 .12945 L  
s  
P  
p  
.002 w  
.84638 .7023 m .89742 .65492 L .88027 .65294 L p  
.656 .821 .962 r  
F P  
s  
P  
p  
.002 w  
.88027 .65294 m .8296 .70052 L .84638 .7023 L p  
.656 .821 .962 r  
F P  
s  
P  
p  
.008 w  
.8401 .70485 m  
.84638 .7023 L  
s  
P  
p  
.008 w  
.84638 .7023 m  
.93209 .66753 L  
s  
P  
p  
.002 w  
.92231 .37563 m .94287 .46156 L p  
.89742 .65492 L .297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.94287 .46156 m .92231 .37563 L .90539 .37284 L p  
.796 .517 .515 r  
F P  
s  
P  
p  
.002 w  
.90539 .37284 m .92564 .45897 L .94287 .46156 L p  
.796 .517 .515 r  
F P  
s  
P  
p  
.002 w  
.90539 .37284 m .92564 .45897 L p  
.88027 .65294 L .291 .2 .577 r  
F P  
s  
P  
p  
.002 w  
.94287 .46156 m .93369 .56573 L .89742 .65492 L p  
.297 .205 .579 r  
F P  
s  
P  
p  
.002 w  
.89742 .65492 m .93369 .56573 L .91637 .56345 L p  
.769 .734 .82 r  
F P  
s  
P  
p  
.008 w  
.92706 .58203 m  
.93209 .66753 L  
s  
P  
p  
.002 w  
.91637 .56345 m .88027 .65294 L .89742 .65492 L p  
.769 .734 .82 r  
F P  
s  
P  
p  
.002 w  
.92564 .45897 m .91637 .56345 L .88027 .65294 L p  
.291 .2 .577 r  
F P  
s  
P  
p  
.008 w  
.92214 .49843 m  
.92604 .56472 L  
s  
P  
p  
.002 w  
.93369 .56573 m .94287 .46156 L .92564 .45897 L p  
.798 .644 .69 r  
F P  
s  
P  
p  
.002 w  
.92564 .45897 m .91637 .56345 L .93369 .56573 L p  
.798 .644 .69 r  
F P  
s  
P  
p  
.002 w  
.05344 .26268 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.02482 .75387 L  
s  
.02482 .75387 m  
.05344 .26268 L  
s  
.94115 .1703 m  
.21801 .02482 L  
s  
.21801 .02482 m  
.19619 .61574 L  
s  
.19619 .61574 m  
.97518 .70072 L  
s  
.97518 .70072 m  
.94115 .1703 L  
s  
P  
p  
P  
% End of Graphics  
MathPictureEnd  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 235},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000ja000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000mOol3003JOol003aoo`80
009oo`D00=Eoo`00?7oo0P001goo1@00d7oo000kOol00`00Ool0000<Ool5003;Ool003Yoo`04001o
ogoo000AOol50036Ool003Yoo`04001oogoo000FOol50031Ool003Uoo`05001oogooOol0000KOol5
002lOol003Qoo`03001oogoo009oo`03001oogoo01ioo`D00;Moo`00>7oo00<007ooOol00Woo00<0
07ooOol08goo1@00/Woo000gOol00`00Oomoo`03Ool00`00Oomoo`0XOol5002]Ool003Ioo`03001o
ogoo00Aoo`03001oogoo02eoo`@00:Uoo`00=Goo00<007ooOol01Goo00<007ooOol0<Goo1@00Y7oo
000eOol00`00Oomoo`05Ool00`00Oomoo`0fOol5002OOol003Aoo`03001oogoo00Ioo`03001oogoo
03]oo`D009Yoo`00<goo00<007ooOol01Woo00<007ooOol0@Goo1@00UGoo000cOol00`00Oomoo`06
Ool00`00Oomoo`16Ool5002@Ool0039oo`03001oogoo00Moo`03001oogoo04]oo`D008]oo`00<Goo
00<007ooOol027oo00<007ooOol0D7oo1@00QWoo000aOol00`00Oomoo`08Ool00`00Oomoo`1EOol5
0021Ool0031oo`03001oogoo00Uoo`03001oogoo05Yoo`D007aoo`00;goo00<007ooOol02Woo00<0
07ooOol0Ggoo1@00Mgoo000_Ool00`00Oomoo`0:Ool00`00Oomoo`1TOol5001bOol002ioo`03001o
ogoo00]oo`03001oogoo06Uoo`D006eoo`00;Goo00<007ooOol037oo00<007ooOol0KWoo1@00J7oo
000]Ool00`00Oomoo`0<Ool00`00Oomoo`1cOol5001SOol002aoo`03001oogoo00eoo`03001oogoo
07Qoo`D005ioo`00:goo00<007ooOol03Woo00<007ooOol0OGoo1@00FGoo000ZOol00`00Oomoo`0?
Ool00`00Oomoo`22Ool5001DOol002Yoo`03001oogoo00moo`03001oogoo08Moo`D004moo`00:Goo
00<007ooOol047oo00<007ooOol017oo0P00QWoo1@00BWoo000XOol00`00Oomoo`0AOol00`00Oomo
o`04Ool70026Ool50015Ool002Qoo`03001oogoo015oo`03001oogoo00=oo`d008Ioo`@0045oo`00
9goo00<007ooOol04Woo00<007ooOol00goo0P001Woo2`00Q7oo1@00?7oo000VOol00`00Oomoo`0C
Ool00`00Oomoo`02Ool2000<Ool;0024Ool5000gOol002Ioo`03001oogoo01=oo`04001oogooOol3
000BOol;0023Ool5000bOol002Eoo`03001oogoo01Aoo`03001oogoo00<001Qoo`/008=oo`D002eo
o`0097oo00<007ooOol05Goo00<007oo00000P007goo2`00PWoo1@00:7oo000TOol00`00Oomoo`0E
Ool01000Ool000009Goo2`00PWoo1@008goo000SOol00`00Oomoo`0FOol3000/Ool;0021Ool5000N
Ool0029oo`03001oogoo01Moo`<0035oo`/0085oo`D001Uoo`008Woo00<007ooOol05Woo0`00>7oo
2`00P7oo1@0057oo000QOol00`00Oomoo`0FOol3000nOol;0020Ool3000AOol0021oo`03001oogoo
01Moo`8004Eoo`/007Yoo`<0015oo`007goo00<007ooOol05goo0`00BWoo2`00M7oo00@007ooOol0
015oo`007goo00<007ooOol05Woo1000D7oo2`00KGoo00D007ooOomoo`00015oo`007Woo00<007oo
Ool05Woo0`0000=oo`00Ool0E7oo2`00IWoo0P0017oo00<007ooOol03goo000MOol00`00Oomoo`0G
Ool20002Ool00`00Oomoo`1IOol:001POol00`00Oomoo`04Ool00`00Oomoo`0?Ool001eoo`03001o
ogoo01Ioo`8000=oo`03001oogoo05ioo`/005Qoo`8000Moo`03001oogoo00moo`0077oo00<007oo
Ool05Woo0`000goo00<007ooOol0Hgoo2`00DWoo00<007ooOol01goo00<007ooOol03goo000KOol0
0`00Oomoo`0FOol30004Ool00`00Oomoo`1YOol;001;Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool0
01]oo`03001oogoo01Eoo`<000Eoo`03001oogoo06ioo`/004Aoo`8000aoo`03001oogoo00ioo`00
6Woo00<007ooOol05Woo0P001Woo00<007ooOol0M7oo2`00?Goo00<007ooOol037oo00<007ooOol0
3Woo000IOol00`00Oomoo`0FOol20007Ool00`00Oomoo`1iOol;000fOol2000?Ool00`00Oomoo`0>
Ool001Uoo`03001oogoo01Eoo`<000Moo`03001oogoo07moo`/002moo`03001oogoo00moo`03001o
ogoo00ioo`0067oo00<007ooOol05Goo0`0027oo00<007ooOol0Q7oo2`00:Goo00<007ooOol047oo
00<007ooOol03Woo000GOol00`00Oomoo`0EOol30009Ool00`00Oomoo`2:Ool;000QOol2000COol0
0`00Oomoo`0>Ool001Moo`03001oogoo01Eoo`8000Yoo`03001oogoo08moo`/001]oo`03001oogoo
01=oo`03001oogoo00ioo`005Woo00<007ooOol05Goo0P002goo00<007ooOol0UGoo2`004goo0P00
5Woo00<007ooOol03Woo000EOol00`00Oomoo`0EOol3000;Ool00`00Oomoo`2JOol;000=Ool00`00
Oomoo`0FOol00`00Oomoo`0>Ool001Aoo`03001oogoo01Eoo`<000aoo`03001oogoo0:1oo`/000Eo
o`8001Uoo`03001oogoo00ioo`0057oo00<007ooOol057oo0`003Goo00<007ooOol0YGoo2`006goo
00<007ooOol03Woo000COol00`00Oomoo`0EOol2000>Ool00`00Oomoo`2[Ool;000EOol00`00Oomo
o`0>Ool0019oo`03001oogoo01Eoo`8000moo`03001oogoo0:aoo`80009oo`/0011oo`03001oogoo
00ioo`004Woo00<007ooOol057oo0`003goo00<007ooOol0Zgoo00<007ooOol027oo2`002Woo00<0
07ooOol03Woo000AOol00`00Oomoo`0DOol3000@Ool00`00Oomoo`2YOol2000@Ool70009Ool00`00
Oomoo`0>Ool0011oo`03001oogoo01Aoo`<0015oo`03001oogoo0:Qoo`03001oogoo019oo`D000Uo
o`03001oogoo00ioo`0047oo00<007ooOol057oo200037oo00<007ooOol08Woo1000PGoo00<007oo
Ool04Woo1P002Woo00<007ooOol03Goo000?Ool4000COol?0006Ool00`00Oomoo`0QOol20003IU@6
001iOol2000COol40002Ool2000:Ool00`00Oomoo`0=Ool000moo`04001oogooOol6000<Ool30007
Ool=000ROol00`0020l00009IU@6001bOol00`00Oomoo`0BOol40003Ool2000:Ool00`00Oomoo`0=
Ool000moo`03001oogoo00Moo`H000Eoo`<000ioo``001]oo`8000883`03001VE6ID00eVE0L006Uo
o`8001=oo`@000Eoo`8000Yoo`03001oogoo00eoo`003goo00<007ooOol03Goo1`0057oo3P004goo
00<000P?20l00PP?00<006IDIU@056ID1P00HWoo00<007ooOol04Woo10001Woo0P002Woo00<007oo
Ool03Goo000?Ool00`00Oomoo`0AOol8000?Ool00`00Oomoo`04Ool=000<Ool00`0020l83`0320l0
0`00IUAVE00JIU@6001KOol00`00Oomoo`0BOol30008Ool2000:Ool00`00Oomoo`0=Ool000moo`03
001oogoo011oo`<000Ioo`H000Uoo`03001oogoo00]oo``000Ioo`0300083`P?00<83`03001VE6ID
021VE0@005Eoo`8001=oo`@000Uoo`8000Yoo`03001oogoo00eoo`003goo00<007ooOol03goo2@00
1goo1`000Woo00<007ooOol04Goo3@001@P?00<006IDIU@08fID00<007ooOol0DWoo00<007ooOol0
4Woo10002Woo0P002Woo00<007ooOol03Goo000?Ool00`00Oomoo`0>OolA0007Ool6000FOol=000U
IU@00`00Oomoo`1@Ool2000COol4000<Ool2000:Ool00`00Oomoo`0=Ool000moo`03001oogoo00io
o`8000Qoo`h0009oo`04001oogooOol6000FOol>000NIU@00`00Oomoo`1?Ool00`00Oomoo`0BOol4
000=Ool2000:Ool00`00Oomoo`0=Ool000ioo`03001oogoo00ioo`80011oo`h000Eoo`H0011oo`03
00083`P?00883a4001IVE003001oogoo04ioo`03001oogoo015oo`@000moo`8000Yoo`03001oogoo
00eoo`003Woo00<007ooOol037oo10005goo3P0017oo1P002Woo00<000P?20l00PP?00<006IDIU@0
1VID3`003fID00<007ooOol0C7oo0P004goo100047oo0P002Woo00<007ooOol03Goo000>Ool00`00
Oomoo`0<Ool7000FOol00`00Oomoo`02Ool>0003Ool70003Ool00`0020l83`0220l2000>IU@;000<
IU@00`00Oomoo`1;Ool00`00Oomoo`0AOol4000BOol2000:Ool00`00Oomoo`0=Ool000ioo`03001o
ogoo00eoo``0011oo`03001oogoo00Uoo`h000=oo`@000@83`8001EVE0T000MVE003001oogoo04Uo
o`80019oo`D001=oo`8000Yoo`03001oogoo00eoo`003Woo00<007ooOol04goo30002Woo00<007oo
Ool047oo3P0010P?0P006FID3@00BWoo00<007ooOol04Goo10005Goo0P002Woo00<007ooOol03Goo
000>Ool00`00Oomoo`0IOol;0005Ool00`00Oomoo`0GOol7000420l00`00IUAVE00LIU@?0013Ool0
0`00Oomoo`0@Ool4000HOol20009Ool00`00Oomoo`0=Ool000ioo`03001oogoo01moo`/001moo`03
00083`P?00883`03001VE6ID02AVE0d003]oo`80019oo`@001Uoo`8000Uoo`03001oogoo00eoo`00
3Woo00<007ooOol097oo30006Goo00<000P?20l00PP?00<006IDIU@096ID00<007ooOol00goo3@00
=7oo00<007ooOol047oo10006goo0P002Woo00<007ooOol037oo000>Ool00`00Oomoo`0YOol<000D
Ool00`0020l83`0220l00`00IUAVE00FIU@00`00ILeVE00;IU@00`00Oomoo`0:Ool=000[Ool2000B
Ool4000LOol2000:Ool00`00Oomoo`0<Ool000ioo`03001oogoo02Uoo`03001oogoo00Aoo``000eo
o`0300083`P?00883`03001VE6ID01IVE003EQ@00000009Uc@UVE003001oogoo011oo`d002Aoo`03
001oogoo011oo`@001ioo`8000Yoo`03001oogoo00aoo`003Woo00<007ooOol0:Goo00<007ooOol0
2Goo3P001Woo00D000P?20l83`0000AVE0H000mVE0=F5004001UcFG=ILd7IU@2000HOol=000KOol2
000BOol4000?Ool5000;Ool2000:Ool00`00Oomoo`0<Ool000ioo`03001oogoo02Uoo`03001oogoo
011oo`h000883`03001VE6ID00UVE0L000QVE0AF5005001UcFG=ILd00004IU@200000goo00000004
000HOol=000DOol00`00Oomoo`0AOol3000:Ool700049=840008Ool2000:Ool00`00Oomoo`0<Ool0
00ioo`03001oogoo02Uoo`03001oogoo01Moo`L0000320l006ID015VE0L0009VE0EF5005001UcFG=
ILd00003IU@800000goo00000004000IOol=000<Ool00`00Oomoo`0@Ool40007Ool4000<9=801000
E:9DXP001goo0P002Woo00<007ooOol037oo000>Ool00`00Oomoo`0YOol00`00Oomoo`0MOol2000F
IU@200000dHH000000020005EQ@01@00ILeUcFG=00000fID3@0000=oo`0000001@0067oo3@0017oo
0P004Woo10001goo00<002CB9=803bCB00@005BRE:8000Ioo`8000Yoo`03001oogoo00aoo`003Woo
00<007ooOol0:Goo00<007ooOol07Goo10005FID0P000dHH00=F5000EQ@015HD0P0000=UcFID0000
0VID00<007ooOol017oo2`000goo1P006Goo3@003goo100027oo00<002CB9=804BCB00@005BRE:80
00Eoo`8000Yoo`03001oogoo00aoo`003Woo00<007ooOol0:Goo00<007ooOol08Goo1P0046ID0`00
0dHH0P001EHD00@006G=ILeUc@8000aoo`/000=oo`H001Uoo`d000Qoo`@000Qoo`03000TdRCB01<T
dP04001DXUBR0004Ool2000:Ool00`00Oomoo`0<Ool000ioo`03001oogoo02Uoo`03001oogoo02Mo
o`H000]VE0030001F@0000A66003001F55HD00=F5005001UcFG=ILd0000AOol<0003Ool6000COol0
0`00Oomoo`04Ool@000:Ool00`009=8TdP0D9=801000E:9DXP000goo0P002Woo00<007ooOol037oo
000=Ool00`00Oomoo`0ZOol00`00Oomoo`0]Ool70005IU@30004AQP00`00EQAF5003EQ@01@00ILeU
cFG=00005Woo3@000Woo1P0037oo00<007ooOol02goo2@002Woo00<002CB9=805RCB00@005BRE:80
009oo`8000Yoo`03001oogoo00aoo`003Goo00<007ooOol0:Woo00<007ooOol0=7oo1P0000=VE000
00000dHH0P001EHD00D006G=ILeUc@0001]oo`d0009oo`H000Aoo`80019oo`@000Yoo`03000TdRCB
01PTdP05001DXUBR001oo`02000:Ool00`00Oomoo`0<Ool000eoo`03001oogoo02Yoo`03001oogoo
03Yoo`@000=66003EQ@005HD00AF50800003ILd0000000H001]oo`d00003Ool000000080019oo`@0
00]oo`03000TdRCB01XTdP03001DXUBR00<000Yoo`03001oogoo00aoo`003Goo00<007ooOol0:Woo
00<007ooOol0?Goo0`000dHH0P001EHD00<006G=000030006goo3P003goo10002goo00<002CB9=80
72CB00<005BRE:800P002Woo00<007ooOol037oo000=Ool00`00Oomoo`0YOol00`00Oomoo`0oOol0
0`000ET00004AQP00`00EQAF5003EQ@01@00ILeUcFG=00000goo3@006goo3@001goo100037oo00<0
02CB9=807RCB00<005BRE:800P002Goo00<007ooOol037oo000=Ool00`00Oomoo`0YOol00`00Oomo
o`10Ool00`000ET00004AQP00`00EQAF5003EQ@01@00ILeUcFG=000027oo3@006Goo00<007ooOol0
400037oo00<002CB9=8082CB10002Goo00<007ooOol037oo000=Ool00`00Oomoo`0YOol00`00Oomo
o`12Ool00`000EU66003AQP00`00EQAF5003EQ@20002ILd00`00Oomoo`0<Ool=000BOol00`00Oomo
o`06Ool8000=Ool00`009=8TdP0Q9=800`00IQ0000020009Ool00`00Oomoo`0;Ool000eoo`03001o
ogoo02Uoo`03001oogoo04=oo`<000966003EQ@0000000EF5003001UcFG=0080019oo`d000aoo`03
001oogoo00Qoo`D000ioo`03000TdRCB024TdP05001V46H@IQ000009Ool00`00Oomoo`0;Ool000eo
o`03001oogoo02Uoo`03001oogoo04Aoo`030001F@0000966003EQA6600000EF5005001UcFG=ILd0
000HOol=0005Ool00`00Oomoo`07Ool4000?Ool00`009=8TdP0S9=801000IQ1V40002Goo00<007oo
Ool02goo000=Ool00`00Oomoo`0YOol00`00Oomoo`15Ool00`000ET00004AQP00`00EQAF5003EQ@0
1@00ILeUcFG=00007Goo3@0027oo0`0047oo00<002CB9=8092CB00D006H@IQ1V400000Qoo`03001o
ogoo00]oo`003Goo00<007ooOol0:Goo00<007ooOol0AWoo00<0005I0ET014HH00<005HDEQ@00eHD
00D006G=ILeUc@0002=ooa00011oo`03000TdRCB02DTdP05001V46H@IQ000008Ool00`00Oomoo`0;
Ool000eoo`03001oogoo02Uoo`03001oogoo04Qoo`030ET004HH00=66003001F55HD00=F5080009U
c@03001oogoo02Eoo`X0015oo`03000TdRCB02DTdP05001V46H@IQ000008Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02Uoo`03001oogoo04Uoo`030ET0000000=6608000EF5003001UcFG=008002Eo
o`03001oogoo00Aoo`80015oo`03000TdRCB02HTdP05001V46H@IQ000008Ool00`00Oomoo`0;Ool0
00eoo`03001oogoo02Uoo`03001oogoo04Yoo`030001F@0000966003EQA6600000EF5005001UcFG=
ILd0000TOol00`00Oomoo`04Ool2000AOol00`009=8TdP0W9=801@00IQ1V46H@00001goo00<007oo
Ool02goo000=Ool00`00Oomoo`0YOol00`00Oomoo`1;Ool00`000ET00002AQP00eHDAQP00005EQ@0
1@00ILeUcFG=00008goo00<007ooOol017oo0P004Goo00<002CB9=809bCB00D006H@IQ1V400000Mo
o`03001oogoo00]oo`003Goo00<007ooOol0:Goo00<007ooOol0C7oo0P0000<1FDHHAQP00THH00<0
05HDEQ@00eHD00D006G=ILeUc@00029oo`03001oogoo00Aoo`80011oo`03000TdRCB02PTdP05001V
46H@IQ000007Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Uoo`03001oogoo04ioo`8000A66080
00AF5080009Uc@80021oo`03001oogoo00Aoo`80011oo`03000TdRCB02PTdP05001V46H@IQ000007
Ool00`00Oomoo`0;Ool000eoo`03001oogoo02Uoo`03001oogoo04moo`<000A66003001F55HD00=F
5005001UcFG=ILd0000OOol00`00Oomoo`04Ool2000@Ool00`009=8TdP0X9=800`00IQ1V4002IQ00
0`00Oomoo`04Ool00`00Oomoo`0;Ool000aoo`03001oogoo02Yoo`03001oogoo051oo`030001F@00
00A66003001F55HD00=F5005001UcFG=ILd0000NOol00`00Oomoo`04Ool2000?Ool00`009=8TdP0Z
9=801@00IQ1V46H@00001Woo00<007ooOol02goo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1AOol3
0002AQP00eHDAQP00005EQ@01@00ILeUcFG=00007Goo00<007ooOol017oo0P003goo00<002CB9=80
:RCB00D006H@IQ1V400000Ioo`03001oogoo00]oo`0037oo00<007ooOol0:Woo00<007ooOol0Dgoo
00L0005IAQQ665HDAQP00005EQ@01@00ILeUcFG=000077oo00<007ooOol017oo0P003goo00<002CB
9=80:RCB00D006H@IQ1V400000Ioo`03001oogoo00]oo`0037oo00<007ooOol0:Woo00<007ooOol0
E7oo0P0014HH0P0015HD0P000VG=0P006Woo00<007ooOol017oo0P003Woo00<002CB9=80:bCB00<0
06H@IQ000VH@00<007ooOol00goo00<007ooOol02goo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1E
Ool30004AQP00`00EQAF5003EQ@01@00ILeUcFG=00006Goo00<007ooOol017oo0P003Woo00<002CB
9=80;2CB00D006H@IQ1V400000Eoo`03001oogoo00]oo`0037oo00<007ooOol0:Woo00<007ooOol0
EWoo00<0005I000014HH00<005HDEQ@00eHD00D006G=ILeUc@0001Qoo`03001oogoo00Aoo`8000eo
o`03000TdRCB02dTdP05001V46H@IQ000006Ool00`00Oomoo`0:Ool000aoo`03001oogoo02Yoo`03
001oogoo05Moo`8000030EU664HH00966003001F55HD00=F5005001UcFG=ILd0000HOol00`00Oomo
o`03Ool2000=Ool00`009=8TdP0]9=801@00IQ1V46H@00001Woo00<007ooOol02Woo000<Ool00`00
Oomoo`0ZOol00`00Oomoo`1IOol20002AQP00eHDAQP00005EQ@20002ILd2000FOol00`00Oomoo`03
Ool2000=Ool00`009=8TdP0]9=800`00IQ1V4002IQ000`00Oomoo`03Ool00`00Oomoo`0:Ool000ao
o`03001oogoo02Yoo`03001oogoo05Yoo`<00003AQP004HH008000EF5005001UcFG=ILd0000EOol0
0`00Oomoo`03Ool2000<Ool00`009=8TdP0^9=800`00IQ1V4002IQ000`00Oomoo`03Ool00`00Oomo
o`0:Ool000aoo`03001oogoo02Yoo`03001oogoo05]oo`030001F@0000A66003001F55HD00=F5005
001UcFG=ILd0000DOol00`00Oomoo`03Ool2000<Ool00`009=8TdP0_9=801@00IQ1V46H@00001Goo
00<007ooOol02Woo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1LOol30004AQP00`00EQAF5003EQ@0
1@00ILeUcFG=00004goo00<007ooOol00goo0P0037oo00<002CB9=80;bCB00<006H@IQ000VH@1Goo
00<007ooOol02Woo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1NOol00`000EU66003AQP00`00EQAF
5003EQ@01000ILeUcFG=0P004Goo00<007ooOol00goo0P002goo00<002CB9=80<2CB0`000VH@00<0
07ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0ZOol00`00Oomoo`1OOol20004AQP20004
EQ@20003ILd00`00Oomoo`0>Ool00`00Oomoo`03Ool2000;Ool00`009=8TdP0`9=800`00IYIVUP03
0004Ool00`00Oomoo`0:Ool000aoo`03001oogoo02Yoo`03001oogoo061oo`<00005AQP004HHAQP0
0005EQ@01@00ILeUcFG=00003goo00<007ooOol00goo0P002goo00<002CB9=80<2CB00<006JFIYH0
0VJF00<007ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0YOol00`00Oomoo`1ROol30004
AQP00`00EQAF5003EQ@01@00ILeUcFG=00003Woo00<007ooOol00goo0P002Woo00<002CB9=80<BCB
00<006JFIYH00VJF00<007ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0YOol00`00Oomo
o`1TOol20004AQP00`00EQAF5003EQ@01@00ILeUcFG=00003Goo00<007ooOol00goo0P002Woo00<0
02CB9=80<BCB00<006JFIYH00VJF00<007ooOol00Woo00<007ooOol02Woo000<Ool00`00Oomoo`0Y
Ool00`00Oomoo`1UOol00`000EU66003AQP00`00EQAF5003EQ@01000ILeUcFG=0P002goo00<007oo
Ool00goo0P002Woo00<002CB9=80<BCB00<006JFIYH00VJF00<007ooOol00Woo00<007ooOol02Woo
000;Ool00`00Oomoo`0ZOol00`00Oomoo`1VOol20004AQP20004EQ@20003ILd00`00Oomoo`08Ool0
0`00Oomoo`03Ool2000:Ool00`009=8TdP0a9=800`00IYIVUP02IYH00`00Oomoo`02Ool00`00Oomo
o`0:Ool000]oo`03001oogoo02Yoo`03001oogoo06Moo`<000A66003001F55HD00=F5005001UcFG=
ILd00009Ool00`00Oomoo`03Ool2000:Ool00`009=8TdP0a9=800`00IYIVUP02IYH00`00Oomoo`02
Ool00`00Oomoo`0:Ool000]oo`03001oogoo02Yoo`03001oogoo06Qoo`<00005AQP004HHAQP00005
EQ@01`00ILeUcFG=001oo`0000Ioo`03001oogoo00=oo`8000Yoo`03000TdRCB030TdP03001VUVJF
00=VUP03001oogoo009oo`03001oogoo00Yoo`002goo00<007ooOol0:Woo00<007ooOol0JWoo0P00
14HH00<005HDEQ@00eHD00@006G=ILeUc@T000Eoo`8000Uoo`03000TdRCB034TdP03001VUVJF009V
UP03001oogoo00=oo`03001oogoo00Yoo`002goo00<007ooOol0:Woo00<007ooOol0Jgoo0P0014HH
0P0015HD0P000fG=3P002Goo00<002CB9=80<BCB00<006JFIYH00VJF00<007ooOol00goo00<007oo
Ool02Woo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1/Ool30004AQP00`00EQAF5003EQ@01@00ILeU
cFG=00000goo3P0017oo00<002CB9=80<2CB0P0016JF00<007ooOol017oo00<007ooOol02Goo000;
Ool00`00Oomoo`0ZOol00`00Oomoo`1]Ool30004AQP00`00EQAF5003EQ@01@00ILeUcFG=00000goo
00<007ooOol00goo3P00<BCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo000;Ool0
0`00Oomoo`0ZOol00`00Oomoo`1_Ool20004AQP00`00EQAF5003EQ@01@00ILeUcFG=00000Woo00<0
07ooOol00goo0P001Goo3`00:BCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo000;
Ool00`00Oomoo`0ZOol00`00Oomoo`1`Ool010000EU660000THH00<005HDEQ@00eHD00@006G=ILeU
c@<000Eoo`8000Uoo`03000TdP0000l0028TdP03001VUVJF009VUP03001oogoo00Aoo`03001oogoo
00Uoo`002goo00<007ooOol0:Woo00<007ooOol0LGoo0P0014HH0P0015HD0P000fG=00<007ooOol0
0goo0P002Goo00<002CB9=8022CB3P006bCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol0
2Goo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1bOol30004AQP00`00EQAF5003EQ@01@00ILeUcFG=
00001Goo0P0027oo00<002CB9=803bCB1`006bCB00<006JFIYH00VJF00<007ooOol017oo00<007oo
Ool02Goo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1dOol20004AQP00`00EQAF5003EQ@01@00ILeU
cFG=000017oo0P001goo00<002CB9=80<RCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol0
2Goo000;Ool00`00Oomoo`0ZOol00`00Oomoo`1eOol20004AQP00`00EQAF5003EQ@01000ILeUcFG=
0P000Woo0P001goo00<002CB9=80<RCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo
000;Ool00`00Oomoo`0ZOol00`00Oomoo`1fOol00`000EU66003AQP20004EQ@00`00ILeUc@02ILd0
1000Ool000001goo00<002CB9=80<RCB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol02Goo
000;Ool00`00Oomoo`0ZOol00`00Oomoo`1gOol200000dHH00166002AQP00`00EQAF5002EQ@20003
ILd30007Ool00`009=8TdP0b9=800`00IYIVUP02IYH00`00Oomoo`04Ool00`00Oomoo`09Ool000]o
o`03001oogoo02Yoo`03001oogoo07Uoo`8000A66003001F55HD00=F5004001UcFG=ILd20007Ool0
0`009=8TdP0b9=800`00IYIVUP02IYH00`00Oomoo`04Ool00`00Oomoo`09Ool000]oo`03001oogoo
02Yoo`03001oogoo07Yoo`8000A66003001F55HD00=F5004001UcFG=ILd20006Ool00`009=8TdP0a
9=800`00IYIVUP03IYH00`00Oomoo`04Ool00`00Oomoo`09Ool000Yoo`03001oogoo02]oo`03001o
ogoo07]oo`8000A66003001F55HD00=F5003001UcFG=009Uc@03001oogoo00=oo`03000TdRCB034T
dP03001VUVJF009VUP03001oogoo00Eoo`03001oogoo00Uoo`002Woo00<007ooOol0:goo00<007oo
Ool0O7oo0P0014HH0P0015HD0P000fG=00<007ooOol00Woo00<002CB9=80<BCB00<006JFIYH00VJF
00<007ooOol01Goo00<007ooOol02Goo000:Ool00`00Oomoo`0[Ool00`00Oomoo`1mOol20005AQP0
0`00EQAF5003EQ@01@00ILeUcFG=00000goo00<002CB9=80<BCB00<006JFIYH00VJF00<007ooOol0
1Goo00<007ooOol02Goo000:Ool00`00Oomoo`0[Ool00`00Oomoo`1oOol200001FG=AQQ664HH0000
1EHD00L006G=ILeUc@00Ool0000d9=800`00IYIVUP02IYH00`00Oomoo`05Ool00`00Oomoo`09Ool0
00Yoo`03001oogoo02]oo`03001oogoo081oo`8000A66003001F55HD00=F5004001UcFG=ILd2000d
9=800`00IYIVUP02IYH00`00Oomoo`06Ool00`00Oomoo`08Ool000Yoo`03001oogoo02]oo`03001o
ogoo085oo`030001FDHH00=6608000AF5003001UcFG=009Uc@03000TdRCB034TdP03001VUVJF009V
UP03001oogoo00Ioo`03001oogoo00Qoo`002Woo00<007ooOol0:goo00<007ooOol0PWoo0P001DHH
00<005HDEQ@00UHD0P000fG=00<002CB9=80<2CB0`000VJF00<007ooOol01Woo00<007ooOol027oo
000:Ool00`00Oomoo`0[Ool00`00Oomoo`22Ool01000Ool0000014HH00<005HDEQ@00eHD00D006G=
ILeUc@00034TdP03001RnP0000<000Qoo`03001oogoo00Qoo`002Woo00<007ooOol0:Woo00<007oo
Ool0Pgoo00<007ooOol00P0014HH00<005HDEQ@00eHD00@006G=ILeUc@8002hTdP03001RnV;j0080
0003H_X007oo00Moo`03001oogoo00Qoo`002Woo00<007ooOol0:Woo00<007ooOol0Pgoo00@007oo
Oomoo`8000A66003001F55HD00=F5003001UcFG=009Uc@03000TdRCB02/TdP03001RnV;j009RnP03
001oogoo00Moo`03001oogoo00Qoo`002Woo00<007ooOol0:Woo00<007ooOol0Pgoo00<007ooOol0
0Woo00<0005IAQP00dHH0P0015HD00<006G=ILd00VG=00<002CB9=80:BCB00<006;jH_X00f;j00<0
07ooOol01goo00<007ooOol027oo000:Ool00`00Oomoo`0ZOol00`00Oomoo`23Ool00`00Oomoo`04
Ool00`00AQQ66003AQP00`00EQAF5002EQ@20003ILd00`009=8TdP0X9=800`00H_YRnP02H_X00`00
Oomoo`08Ool00`00Oomoo`08Ool000Yoo`03001oogoo02Yoo`03001oogoo08=oo`03001oogoo00Ao
o`<000A66003001F55HD00=F5005001UcFG=ILd0000Y9=801000H_YRnV;j0P002Woo00<007ooOol0
27oo000:Ool00`00Oomoo`0ZOol00`00Oomoo`23Ool00`00Oomoo`04Ool40004AQP00`00EQAF5003
EQ@01000ILeUcFG=0P009RCB00<006;jH_X00V;j0`002Goo00<007ooOol027oo000:Ool00`00Oomo
o`0ZOol00`00Oomoo`24Ool00`00Oomoo`03Ool200000goo00000004AQP00`00EQAF5003EQ@00`00
ILeUc@02ILd00`009=8TdP0S9=800`00H_YRnP02H_X30009Ool00`00Oomoo`08Ool000Yoo`03001o
ogoo02Yoo`03001oogoo08Aoo`03001oogoo00=oo`8000=oo`03001664HH0096608000AF5003001U
cFG=009Uc@03000TdRCB024TdP03001RnV;j009RnP04001oo`000009Ool00`00Oomoo`08Ool000Yo
o`03001oogoo02Yoo`03001oogoo08Aoo`03001oogoo00=oo`8000Aoo`03001664HH00=66003001F
55HD009F508000=Uc@03000TdRCB020TdP03001RnV;j009RnP04001oo`000009Ool00`00Oomoo`08
Ool000Uoo`03001oogoo02]oo`03001oogoo08Aoo`03001oogoo00=oo`8000Eoo`8000A66003001F
55HD00=F5004001UcFG=ILd2000P9=800`00H_YRnP02H_X01000Ool000002Goo00<007ooOol027oo
0009Ool00`00Oomoo`0[Ool00`00Oomoo`24Ool00`00Oomoo`03Ool20006Ool20004AQP00`00EQAF
5003EQ@00`00ILeUc@02ILd00`009=8TdP0L9=800`00H_YRnP02H_X00`00Oomoo`020009Ool00`00
Oomoo`08Ool000Uoo`03001oogoo02]oo`03001oogoo08Aoo`03001oogoo00=oo`8000Moo`8000A6
608000AF5003001UcFG=009Uc@03000TdRCB01/TdP03001RnV;j009RnP03001oogoo008000Uoo`03
001oogoo00Qoo`002Goo00<007ooOol0:goo00<007ooOol0Q7oo00<007ooOol00goo0P0027oo0P00
1DHH00<005HDEQ@00UHD0P000fG=00<002CB9=806BCB00<006;jH_X00V;j00@007ooOomoo`8000Uo
o`03001oogoo00Qoo`002Goo00<007ooOol0:goo1@00PWoo00<007ooOol00goo0P002Goo0`0014HH
00<005HDEQ@00eHD00@006G=ILeUc@8001TTdP03001RnV;j009RnP04001oogooOol2000:Ool00`00
Oomoo`07Ool000Uoo`03001oogoo02Yoo`03001oogoo00=oo`T007Uoo`03001oogoo00=oo`8000Uo
o`04000TdP000004AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0F9=801@00H_YRnV;j
000017oo0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0XOol2000?Ool9001`Ool00`00Oomo
o`03Ool20009Ool00`009=8TdP020004AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0D
9=800`00H_YRnP02H_X00`00Oomoo`02Ool2000:Ool00`00Oomoo`07Ool000Uoo`03001oogoo02Mo
o`03001oogoo01Qoo`T006Moo`03001oogoo00=oo`8000Uoo`03000TdRCB008TdP030EU664HH0096
608000AF5003001UcFG=009Uc@03000TdRCB01<TdP03001RnV;j009RnP03001oogoo009oo`8000Yo
o`03001oogoo00Moo`002Goo00<007ooOol09Woo00<007ooOol08Woo2@00GWoo00<007ooOol00goo
0P002Goo00<002CB9=800bCB00<004HHAQP00dHH00<005HDEQ@00UHD0P000fG=00<002CB9=804BCB
00<006;jH_X00V;j00<007ooOol00goo0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0UOol0
0`00Oomoo`0/Ool9001EOol00`00Oomoo`03Ool20009Ool200059=820004AQP00`00EQAF5003EQ@0
1000ILeUcFG=0P004BCB00<006;jH_X00V;j00<007ooOol00goo0P002Woo00<007ooOol01goo0009
Ool00`00Oomoo`0TOol00`00Oomoo`0fOol:001;Ool00`00Oomoo`03Ool2000:Ool00`009=8TdP04
9=820004AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0>9=801@00H_YRnV;j00001Woo
0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0ROol20013Ool90012Ool00`00Oomoo`04Ool2
0009Ool00`009=8TdP069=800`00AQQ66002AQP20004EQ@00`00ILeUc@02ILd00`009=8TdP0<9=80
0`00H_YRnP02H_X00`00Oomoo`04Ool2000:Ool00`00Oomoo`07Ool000Uoo`03001oogoo025oo`03
001oogoo04aoo`T003Uoo`03001oogoo00Aoo`8000Uoo`<000LTdP03001664HH00=66003001F55HD
009F5003001UcFG=009Uc@hTdP05001RnV;jH_X00007Ool2000:Ool00`00Oomoo`07Ool000Uoo`03
001oogoo021oo`03001oogoo05Ioo`T0031oo`03001oogoo00Aoo`8000Yoo`03000TdRCB00LTdP03
001664HH00=66003001F55HD009F5080009Uc@dTdP03001RnV;j009RnP03001oogoo00Eoo`8000Yo
o`03001oogoo00Moo`002Goo00<007ooOol07goo00<007ooOol0H7oo2@009goo00<007ooOol017oo
0P002Woo00<002CB9=8022CB0P0014HH00<005HDEQ@00eHD00<006G=000032CB0P000f;j27oo0P00
2Woo00<007ooOol01goo0009Ool00`00Oomoo`0MOol2001/Ool9000NOol00`00Oomoo`04Ool2000;
Ool00`009=8TdP089=820004AQP01`00EQAF55HD?01F500000`TdP03001CGU=N00<000Qoo`8000Yo
o`03001oogoo00Moo`002Goo00<007ooOol077oo00<007ooOol0MGoo2@005Goo00<007ooOol017oo
0P0037oo00<002CB9=802BCB00<004HHAQP00THH00<003`0?0000c`02bCB00<005=NDeh00U=N00<0
07ooOol01goo0P002Woo00<007ooOol01goo0009Ool00`00Oomoo`0KOol00`00Oomoo`1oOol9000<
Ool00`00Oomoo`04Ool2000<Ool00`009=8TdP0:9=800`00AQQ66002AQP5?00:9=800`00DeiCGP02
Deh00`00Oomoo`08Ool2000:Ool00`00Oomoo`07Ool000Qoo`03001oogoo01]oo`03001oogoo08Uo
o`T000=oo`03001oogoo00Aoo`8000eoo`03000TdRCB00XTdP03001664HH00Ll00PTdP03001CGU=N
009CGP03001oogoo00Uoo`8000Yoo`03001oogoo00Moo`0027oo00<007ooOol06Goo0P00UGoo2@00
00=oo`0000003Woo00<002CB9=802RCB0P0000=663`0?0000c`022CB00<005=NDeh00U=N00<007oo
Ool027oo1@002Goo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00`00Oomoo`2HOol00`00Oomo
o`03Ool90008Ool00`009=8TdP0<9=800`00?00l0003?0079=800`00DeiCGP02Deh00`00Oomoo`07
Ool7000:Ool00`00Oomoo`06Ool000Qoo`03001oogoo01Moo`03001oogoo09Uoo`03001oogoo00Ao
o`8000Ioo`X000hTdP03000TdS`000LTdP8000ACGP03001oogoo00Eoo`H000ioo`03001oogoo00Io
o`0027oo00<007ooOol05Woo00<007ooOol0VWoo00<007ooOol017oo0P003goo2P003RCB00<005=N
Deh00U=N0P001Goo1`0047oo00<007ooOol01Woo0008Ool00`00Oomoo`0EOol00`00Oomoo`2KOol0
0`00Oomoo`04Ool2000@Ool00`009=8TdP069=8900049=800`00DeiCGP02Deh00`00Oomoo`03Ool6
000COol00`00Oomoo`06Ool000Qoo`03001oogoo01=oo`8009ioo`03001oogoo00Aoo`80015oo`03
000TdRCB00hTdPT000=oo`H001Ioo`03001oogoo00Ioo`0027oo00<007ooOol04Woo00<007ooOol0
WWoo00<007ooOol017oo0P004Woo00<002CB9=800RCB00<002CB9=802RCB00<005=NDeh00U=N00<0
07oo000020005Woo00<007ooOol01Woo0008Ool00`00Oomoo`0AOol00`00Oomoo`2OOol00`00Oomo
o`04Ool2000BOol010009=8TdUTX3BCB00<005=NDeh00U=N1`001Goo2@003Goo00<007ooOol01Woo
0008Ool00`00Oomoo`0@Ool00`00Oomoo`2POol00`00Oomoo`04Ool2000COol700089=801000DeiC
GU=N1P004Goo2@0017oo00<007ooOol01Woo0008Ool00`00Oomoo`0>Ool2002SOol00`00Oomoo`04
Ool2000JOol@000LOol50008Ool000Qoo`03001oogoo00eoo`03001oogoo0:=oo`03001oogoo00Ao
o`80029oo`D0021oo`8000Yoo`0027oo00<007ooOol037oo00<007ooOol0Y7oo00<007ooOol017oo
0P007goo1P007goo0`0037oo0008Ool00`00Oomoo`0;Ool00`00Oomoo`2UOol00`00Oomoo`04Ool2
000MOol6000NOol3000?Ool000Qoo`03001oogoo00Uoo`800:Qoo`03001oogoo00Aoo`8001Yoo`H0
01moo`80019oo`0027oo00<007ooOol027oo00<007ooOol0Z7oo00<007ooOol017oo0P0067oo1P00
7Woo0`0057oo0008Ool00`00Oomoo`07Ool00`00Oomoo`2YOol00`00Oomoo`04Ool2000EOol6000N
Ool3000GOol000Moo`03001oogoo00Moo`03001oogoo0:Yoo`03001oogoo00Aoo`8001=oo`H001io
o`8001Yoo`001goo00<007ooOol01Woo00<007ooOol0Zgoo00<007ooOol017oo0P0047oo1P007Woo
0`0077oo0007Ool00`00Oomoo`04Ool2002^Ool00`00Oomoo`04Ool2000>Ool6000MOol3000OOol0
00Moo`03001oogoo00=oo`03001oogoo0:ioo`03001oogoo00Aoo`8000]oo`H001ioo`80029oo`00
1goo00<007ooOol00Woo00<007ooOol0/7oo00<007ooOol00goo0P002Goo1P007Goo0`0097oo0007
Ool01@00Oomoogoo0000/goo00<007ooOol00goo0P001Woo1P007Goo0`009goo0007Ool01000Ool0
0000]7oo00<007ooOol00goo0P0017oo1P007Goo0P00:Woo0007Ool2002fOol00`00Oomoo`03Ool2
00000goo00000004000MOol3000/Ool000Moo`H00;9oo`03001oogoo00=oo`L001eoo`8002moo`00
3Goo3000YWoo00<007ooOol00goo10007Goo0`00<Goo000IOol;002KOol00`00Oomoo`03Ool2000L
Ool3000dOol002Aoo``008moo`03001oogoo01moo`8003Moo`00<7oo2`00Q7oo00<007ooOol077oo
0`00>Goo000kOol<001hOol00`00Oomoo`0IOol3000lOol004Moo`/006eoo`03001oogoo01Moo`80
03moo`00DWoo3000HGoo00<007ooOol057oo0`00@Goo001NOol;001FOol00`00Oomoo`0AOol30014
Ool006Uoo``004Yoo`03001oogoo00moo`8004Moo`00MGoo2`00?goo00<007ooOol037oo0`00BGoo
0020Ool<000cOol00`00Oomoo`09Ool3001<Ool008aoo`/002Qoo`03001oogoo00Moo`8004moo`00
Ugoo300077oo00<007ooOol017oo0`00DGoo002SOol;000AOol01000Oomoogoo0`00E7oo002^Ool<
0005Ool01000Ool00000Egoo002jOol7001IOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {234, 0}} -> {0.0164822, 0.0318746, 0.00359387,
   0.00359387}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three body objects are defined for the slider-crank mechanism model. Note \
that the zeroth point is used in this model to avoid repeatedly defining a \
point at coordinates {0, 0, 0}."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground (body 1) has four points defined in its body object.\nP1 and P2 \
are two points to define the rotational axis of the crank.\nP3 and P4 are two \
points that are used in conjunction with the origin of the ground body to \
define the translation axis and reference direction of the slider. P4 is also \
used with the local origin to define a reference direction for the crank's \
rotation."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The crank (body 2) has two points defined in its body object.\nP1 is a point \
that is used with the crank's local origin to define its rotational axis.\nP2 \
is the attachment point of the connecting rod, and also a reference for the \
crank's rotation."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider (body 3) has two points defined in its body object.\nP0 is the \
attachment point of the connecting rod on the slider.\nP1 is used with the \
slider's local origin to define its translation axis.\nP2 is used with the \
slider's local origin to define a reference direction for the translational \
joint."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are all the bodies in the slider-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0243858 0.975432 0.023828 0.975432 [
[ 0 0 0 0 ]
[ 1 .95538 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95538 L
0 .95538 L
closepath
clip
newpath
p
.002 w
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
.35924 .54199 m
.08326 .27146 L
s
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
.35924 .54199 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
P
p
.004 w
.58741 .3819 m
.57441 .35539 L
s
P
p
.004 w
.56214 .37048 m
.58741 .3819 L
s
P
p
.004 w
.58741 .3819 m
.57484 .37709 L
s
P
p
.004 w
.58717 .36191 m
.58741 .3819 L
s
P
p
.002 w
.44518 .28058 m .47149 .31174 L .59783 .26641 L p
.668 .736 .901 r
F P
s
P
p
.002 w
.59937 .32142 m .47078 .3663 L .47149 .31174 L p
.537 .314 .524 r
F P
s
P
p
.004 w
.55171 .33806 m
.58741 .3819 L
s
P
p
.002 w
.47149 .31174 m .59783 .26641 L .59937 .32142 L p
.537 .314 .524 r
F P
s
P
p
.002 w
.44518 .28058 m .47149 .31174 L .47078 .3663 L p
.966 .687 .456 r
F P
s
P
p
.002 w
.59783 .26641 m .57295 .23378 L .44518 .28058 L p
.668 .736 .901 r
F P
s
P
p
.002 w
.47078 .3663 m .44399 .33545 L .44518 .28058 L p
.966 .687 .456 r
F P
s
P
p
.002 w
.57295 .23378 m .44518 .28058 L .44399 .33545 L p
.531 .305 .517 r
F P
s
P
p
.004 w
.52132 .30075 m
.53414 .31648 L
s
P
p
.002 w
.44399 .33545 m .47078 .3663 L .59937 .32142 L p
.664 .741 .907 r
F P
s
P
p
.002 w
.57406 .2891 m .59937 .32142 L .59783 .26641 L p
.974 .683 .407 r
F P
s
P
p
.002 w
.59783 .26641 m .57295 .23378 L .57406 .2891 L p
.974 .683 .407 r
F P
s
P
p
.004 w
.58615 .27756 m
.65251 .25383 L
s
P
p
.002 w
.59937 .32142 m .57406 .2891 L .44399 .33545 L p
.664 .741 .907 r
F P
s
P
p
.004 w
.52132 .30075 m
.52134 .30789 L
s
P
p
.002 w
.44399 .33545 m .57406 .2891 L .57295 .23378 L p
.531 .305 .517 r
F P
s
P
p
.004 w
.5214 .32846 m
.52166 .41468 L
s
P
p
.004 w
.63231 .27213 m
.65251 .25383 L
s
P
p
.004 w
.65251 .25383 m
.62537 .25237 L
s
P
p
.004 w
.65251 .25383 m
.62619 .27449 L
s
P
p
.004 w
.61918 .25457 m
.65251 .25383 L
s
P
p
.004 w
.52865 .3995 m
.52166 .41468 L
s
P
p
.004 w
.52166 .41468 m
.50843 .39571 L
s
P
p
.004 w
.52166 .41468 m
.53481 .38671 L
s
P
p
.004 w
.51447 .38288 m
.52166 .41468 L
s
P
p
.002 w
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
P
p
p
/Courier findfont 10 scalefont setfont
[(x)] .65251 .25383 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(y)] .58741 .3819 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(z)] .52166 .41468 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(3)] .52132 .30075 1.3 1.3 Mshowa
P
p
/Times-Bold findfont 12 scalefont setfont
[(Slider)] .61683 .6742 0 0 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0243858 0.975432 0.023828 0.975432 [
[ 0 0 0 0 ]
[ 1 .95538 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95538 L
0 .95538 L
closepath
clip
newpath
p
.002 w
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
.35924 .54199 m
.08326 .27146 L
s
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
.35924 .54199 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
P
p
.002 w
.50748 .29205 m .51871 .29271 L .35896 .72112 L p
.811 .787 .83 r
F P
s
P
p
.002 w
.35896 .72112 m .34829 .72182 L .50748 .29205 L p
.811 .787 .83 r
F P
s
P
p
.002 w
.37045 .72609 m .35896 .72112 L .51871 .29271 L p
.65 .602 .788 r
F P
s
P
p
.002 w
.35896 .72112 m .34829 .72182 L p
.37259 .73996 L .751 .401 .39 r
F P
s
P
p
.002 w
.37045 .72609 m .35896 .72112 L p
.37259 .73996 L .751 .401 .39 r
F P
s
P
p
.002 w
.51871 .29271 m .53142 .29804 L .37045 .72609 L p
.65 .602 .788 r
F P
s
P
p
.002 w
.37611 .73388 m .37045 .72609 L .53142 .29804 L p
.395 .324 .659 r
F P
s
P
p
.002 w
.37259 .73996 m .37611 .73388 L .37045 .72609 L p
.751 .401 .39 r
F P
s
P
p
.002 w
.50428 .29649 m .50748 .29205 L .34829 .72182 L p
.841 .901 .486 r
F P
s
P
p
.002 w
.34829 .72182 m .34465 .72785 L .50428 .29649 L p
.841 .901 .486 r
F P
s
P
p
.002 w
.34829 .72182 m .34465 .72785 L p
.37259 .73996 L .751 .401 .39 r
F P
s
P
p
.002 w
.53142 .29804 m .53828 .30498 L .37611 .73388 L p
.395 .324 .659 r
F P
s
P
p
.002 w
.37259 .73996 m .37611 .73388 L .53828 .30498 L p
.82 .887 .46 r
F P
s
P
p
.002 w
.51109 .30348 m .50428 .29649 L .34465 .72785 L p
.388 .318 .657 r
F P
s
P
p
.002 w
.34465 .72785 m .35026 .7357 L p
.37259 .73996 L .751 .401 .39 r
F P
s
P
p
.002 w
.34465 .72785 m .35026 .7357 L .51109 .30348 L p
.388 .318 .657 r
F P
s
P
p
.002 w
.35026 .7357 m .36187 .74073 L .37259 .73996 L p
.751 .401 .39 r
F P
s
P
p
.002 w
.36187 .74073 m .37259 .73996 L .53524 .30949 L p
.812 .791 .832 r
F P
s
P
p
.002 w
.53828 .30498 m .53524 .30949 L .37259 .73996 L p
.82 .887 .46 r
F P
s
P
p
.002 w
.52396 .30888 m .51109 .30348 L .35026 .7357 L p
.649 .602 .789 r
F P
s
P
p
.002 w
.35026 .7357 m .36187 .74073 L .52396 .30888 L p
.649 .602 .789 r
F P
s
P
p
.002 w
.53524 .30949 m .52396 .30888 L .36187 .74073 L p
.812 .791 .832 r
F P
s
P
p
.002 w
.51871 .29271 m .50748 .29205 L p
.53524 .30949 L .729 .292 .212 r
F P
s
P
p
.002 w
.53142 .29804 m .51871 .29271 L p
.53524 .30949 L .729 .292 .212 r
F P
s
P
p
.002 w
.53524 .30949 m .53828 .30498 L .53142 .29804 L p
.729 .292 .212 r
F P
s
P
p
.002 w
.50748 .29205 m .50428 .29649 L p
.53524 .30949 L .729 .292 .212 r
F P
s
P
p
.002 w
.50428 .29649 m .51109 .30348 L p
.53524 .30949 L .729 .292 .212 r
F P
s
P
p
.002 w
.51109 .30348 m .52396 .30888 L .53524 .30949 L p
.729 .292 .212 r
F P
s
P
p
.002 w
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
P
p
p
/Times-Bold findfont 12 scalefont setfont
[(Connecting Rod)] .6348 .66907 0 0 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0243858 0.975432 0.023828 0.975432 [
[ 0 0 0 0 ]
[ 1 .95538 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95538 L
0 .95538 L
closepath
clip
newpath
p
.002 w
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
.35924 .54199 m
.08326 .27146 L
s
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
.35924 .54199 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
P
p
.008 w
.3394 .88254 m
.35396 .57272 L
s
P
p
.008 w
.35396 .57272 m
.88418 .40401 L
s
P
p
.008 w
.14298 .37015 m
.35396 .57272 L
s
P
p
.004 w
.28184 .48547 m
.26817 .46088 L
s
P
p
.004 w
.25623 .47526 m
.28184 .48547 L
s
P
p
.004 w
.28184 .48547 m
.26658 .48207 L
s
P
p
.004 w
.27858 .4676 m
.28184 .48547 L
s
P
p
.004 w
.2072 .41308 m
.28184 .48547 L
s
P
p
.008 w
.21038 .43486 m
.77245 .23632 L
s
P
p
.008 w
.10454 .69935 m
.3394 .88254 L
s
P
p
.004 w
.2072 .41308 m
.19663 .52423 L
s
P
p
.004 w
.3238 .37138 m
.2072 .41308 L
s
P
p
.008 w
.28893 .66835 m
.43778 .62308 L
s
P
p
.008 w
.88418 .40401 m
.71938 .15667 L
s
P
p
.008 w
.17527 .40116 m
.74486 .19491 L
s
P
p
.004 w
.30756 .38764 m
.3238 .37138 L
s
P
p
.004 w
.3238 .37138 m
.30079 .36908 L
s
P
p
.004 w
.3238 .37138 m
.29934 .39072 L
s
P
p
.004 w
.29251 .37204 m
.3238 .37138 L
s
P
p
.008 w
.14298 .37015 m
.10454 .69935 L
s
P
p
.008 w
.71938 .15667 m
.14298 .37015 L
s
P
p
.004 w
.20678 .50873 m
.19663 .52423 L
s
P
p
.004 w
.19663 .52423 m
.18712 .50537 L
s
P
p
.004 w
.19663 .52423 m
.21053 .49739 L
s
P
p
.004 w
.19075 .49398 m
.19663 .52423 L
s
P
p
.002 w
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
P
p
[({0,10,12})] .28893 .66835 .5 -1.6 Mshowa
[(P1)] .28893 .66835 1.3 .9 Mshowa
[({10,10,12})] .43778 .62308 -0.5 1.6 Mshowa
[(P2)] .43778 .62308 -1.3 -0.9 Mshowa
p
/Times-Bold findfont 12 scalefont setfont
[(Ground)] .64309 .70202 0 0 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(x)] .3238 .37138 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(y)] .28184 .48547 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(z)] .19663 .52423 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(1)] .2072 .41308 1.3 1.3 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0243858 0.975432 0.023828 0.975432 [
[ 0 0 0 0 ]
[ 1 .95538 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95538 L
0 .95538 L
closepath
clip
newpath
p
.002 w
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
.35924 .54199 m
.08326 .27146 L
s
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
.35924 .54199 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.34141 .93099 L
s
.34141 .93099 m
.35924 .54199 L
s
P
p
.002 w
.35517 .67052 m .36345 .74973 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.002 w
.3266 .59269 m .35517 .67052 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.002 w
.36345 .74973 m .35517 .67052 L .36894 .66639 L p
.597 .435 .633 r
F P
s
P
p
.002 w
.35517 .67052 m .3266 .59269 L .34034 .58835 L p
.633 .551 .744 r
F P
s
P
p
.002 w
.34034 .58835 m .36894 .66639 L .35517 .67052 L p
.633 .551 .744 r
F P
s
P
p
.002 w
.36894 .66639 m .37743 .74575 L .36345 .74973 L p
.597 .435 .633 r
F P
s
P
p
.002 w
.36894 .66639 m .37743 .74575 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.002 w
.34034 .58835 m .36894 .66639 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.002 w
.28402 .53378 m .3266 .59269 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.002 w
.3266 .59269 m .28402 .53378 L .2979 .5292 L p
.658 .667 .848 r
F P
s
P
p
.002 w
.2979 .5292 m .34034 .58835 L .3266 .59269 L p
.658 .667 .848 r
F P
s
P
p
.002 w
.2979 .5292 m .34034 .58835 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.002 w
.36345 .74973 m .34875 .81201 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.002 w
.34875 .81201 m .36345 .74973 L .37743 .74575 L p
.521 .25 .445 r
F P
s
P
p
.002 w
.37743 .74575 m .36307 .80808 L .34875 .81201 L p
.521 .25 .445 r
F P
s
P
p
.002 w
.37743 .74575 m .36307 .80808 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.002 w
.2368 .50876 m .28402 .53378 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.002 w
.28402 .53378 m .2368 .50876 L .25098 .50398 L p
.65 .834 .971 r
F P
s
P
p
.002 w
.25098 .50398 m .2979 .5292 L .28402 .53378 L p
.65 .834 .971 r
F P
s
P
p
.002 w
.25098 .50398 m .2979 .5292 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.004 w
.34004 .70266 m
.35178 .72332 L
s
P
p
.004 w
.34952 .7097 m
.35178 .72332 L
s
P
p
.002 w
.34875 .81201 m .31303 .8404 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.004 w
.33906 .72265 m
.35178 .72332 L
s
P
p
.002 w
.31303 .8404 m .34875 .81201 L .36307 .80808 L p
.19 0 0 r
F P
s
P
p
.002 w
.36307 .80808 m .32774 .83642 L .31303 .8404 L p
.19 0 0 r
F P
s
P
p
.002 w
.36307 .80808 m .32774 .83642 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.004 w
.28893 .66835 m
.35178 .72332 L
s
P
p
.002 w
.1968 .52705 m .2368 .50876 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.002 w
.2368 .50876 m .1968 .52705 L .21136 .52215 L p
0 0 0 r
F P
s
P
p
.002 w
.21136 .52215 m .25098 .50398 L .2368 .50876 L p
0 0 0 r
F P
s
P
p
.002 w
.21136 .52215 m .25098 .50398 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.004 w
.28893 .66835 m
.39226 .63692 L
s
P
p
.002 w
.31303 .8404 m .26412 .82382 L p
.18272 .67527 L .938 .685 .528 r
F P
s
P
p
.002 w
.26412 .82382 m .31303 .8404 L .32774 .83642 L p
.58 .865 .995 r
F P
s
P
p
.002 w
.32774 .83642 m .27917 .81967 L .26412 .82382 L p
.58 .865 .995 r
F P
s
P
p
.002 w
.32774 .83642 m .27917 .81967 L p
.19788 .67058 L .94 .685 .525 r
F P
s
P
p
.004 w
.28218 .7729 m
.28893 .66835 L
s
P
p
.004 w
.37756 .64915 m
.39226 .63692 L
s
P
p
.004 w
.39226 .63692 m
.37169 .63311 L
s
P
p
.004 w
.39226 .63692 m
.37085 .65357 L
s
P
p
.004 w
.36494 .63742 m
.39226 .63692 L
s
P
p
.002 w
.18272 .67527 m .17614 .58762 L .1968 .52705 L p
.938 .685 .528 r
F P
s
P
p
.002 w
.1968 .52705 m .17614 .58762 L .19106 .58275 L p
.46 .159 .366 r
F P
s
P
p
.002 w
.19106 .58275 m .21136 .52215 L .1968 .52705 L p
.46 .159 .366 r
F P
s
P
p
.004 w
.28218 .7729 m
.29022 .757 L
s
P
p
.002 w
.19788 .67058 m .19106 .58275 L .21136 .52215 L p
.94 .685 .525 r
F P
s
P
p
.004 w
.28218 .7729 m
.29395 .74849 L
s
P
p
.004 w
.27686 .74594 m
.28218 .7729 L
s
P
p
.002 w
.26412 .82382 m .21557 .76323 L .18272 .67527 L p
.938 .685 .528 r
F P
s
P
p
.002 w
.21557 .76323 m .26412 .82382 L .27917 .81967 L p
.643 .681 .871 r
F P
s
P
p
.002 w
.27917 .81967 m .23078 .75882 L .21557 .76323 L p
.643 .681 .871 r
F P
s
P
p
.002 w
.27917 .81967 m .23078 .75882 L .19788 .67058 L p
.94 .685 .525 r
F P
s
P
p
.002 w
.17614 .58762 m .18272 .67527 L .19788 .67058 L p
.575 .408 .618 r
F P
s
P
p
.002 w
.19788 .67058 m .19106 .58275 L .17614 .58762 L p
.575 .408 .618 r
F P
s
P
p
.002 w
.18272 .67527 m .21557 .76323 L .23078 .75882 L p
.62 .546 .749 r
F P
s
P
p
.002 w
.23078 .75882 m .19788 .67058 L .18272 .67527 L p
.62 .546 .749 r
F P
s
P
p
.002 w
.71035 .02439 m
.92212 .35985 L
s
.92212 .35985 m
.97561 .77104 L
s
.97561 .77104 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.08326 .27146 m
.02439 .69198 L
s
.02439 .69198 m
.74143 .46587 L
s
.74143 .46587 m
.71035 .02439 L
s
.71035 .02439 m
.08326 .27146 L
s
P
p
[({8,0,0})] .40735 .63234 -0.4 1.6 Mshowa
[(P1)] .40735 .63234 -1.9 -0.9 Mshowa
[({0,8,0})] .36041 .73087 -1.3 .9 Mshowa
[(P2)] .36041 .73087 -2.6 -1.6 Mshowa
p
/Courier findfont 10 scalefont setfont
[(x)] .39226 .63692 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(y)] .35178 .72332 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(z)] .28218 .7729 -1.3 -1.3 Mshowa
P
p
/Courier findfont 10 scalefont setfont
[(2)] .28893 .66835 1.3 1.3 Mshowa
P
p
/Times-Bold findfont 12 scalefont setfont
[(Crank)] .43017 .33334 0 0 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{460, 460},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007<0001c1000`40O003h00OogoocGoo003o003<
0001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomo
o`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo
00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoo
b7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<0
07ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40
005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo
0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool0
0003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`2ROol2
003HOol20019Ool10001Ool00003001oogoo0:1oo`800003Ool000000=Eoo`800003Ool0000004Qo
o`40005oo`0000<007ooOol0WGoo0`000goo0P00dWoo0`000goo0P00B7oo0@000Goo00000`00Oomo
o`2KOol20006Ool00`00Ool0003?Ool20006Ool00`00Ool00017Ool10001Ool00003001oogoo09Qo
o`<000Qoo`04001oogoo003;Ool30008Ool01000Oomoo`00AWoo0@000Goo00000`00Oomoo`2FOol2
000;Ool01000Oomoo`00bGoo0P002goo00@007ooOol004Ioo`40005oo`0000<007ooOol0Tgoo0`00
3Goo00D007ooOomoo`000<Eoo`<000eoo`05001oogooOol00015Ool10001Ool00003001oogoo091o
o`<0015oo`04001oogoo0032Ool3000AOol01000Oomoo`00AGoo0@000Goo00000`00Oomoo`2>Ool2
000DOol01@00Oomoogoo0000_goo0P0057oo00D007ooOomoo`0004Aoo`40005oo`0000<007ooOol0
Rgoo0`005Woo00<007ooOol00Woo00<007ooOol0^Goo0`005Woo00<007ooOol00Woo00<007ooOol0
@Goo0@000Goo00000`00Oomoo`29Ool2000IOol00`00Oomoo`02Ool00`00Oomoo`2gOol2000IOol0
0`00Oomoo`02Ool00`00Oomoo`11Ool10001Ool00003001oogoo08Ioo`<001]oo`03001oogoo00=o
o`03001oogoo0;=oo`<001]oo`03001oogoo00=oo`03001oogoo041oo`40005oo`0000<007ooOol0
Q7oo0P007Woo00<007ooOol017oo00<007ooOol0/7oo0P007Woo00<007ooOol017oo00<007ooOol0
?goo0@000Goo00000`00Oomoo`21Ool3000POol00`00Oomoo`04Ool00`00Oomoo`2]Ool3000POol0
0`00Oomoo`04Ool00`00Oomoo`0oOol10001Ool00003001oogoo07moo`8002=oo`03001oogoo00Eo
o`03001oogoo0:Yoo`8002=oo`03001oogoo00Eoo`03001oogoo03ioo`40005oo`0000<007ooOol0
O7oo0`009Goo00<007ooOol01Goo00<007ooOol0Ygoo0`009Goo00<007ooOol01Goo00<007ooOol0
?Woo0@000Goo00000`00Oomoo`1jOol2000XOol00`00Oomoo`06Ool00`00Oomoo`2TOol2000XOol0
0`00Oomoo`06Ool00`00Oomoo`0mOol10001Ool00003001oogoo07Moo`<002Yoo`03001oogoo00Mo
o`03001oogoo0:1oo`<002Yoo`03001oogoo00Moo`03001oogoo03aoo`40005oo`0000<007ooOol0
MGoo0P00;Goo00<007ooOol01goo00<007ooOol0WWoo0P00;Goo00<007ooOol01goo00<007ooOol0
?7oo0@000Goo00000`00Oomoo`1bOol3000_Ool00`00Oomoo`08Ool00`00Oomoo`2JOol3000_Ool0
0`00Oomoo`08Ool00`00Oomoo`0kOol10001Ool00003001oogoo06moo`<0039oo`03001oogoo00Uo
o`03001oogoo09Ioo`<0039oo`03001oogoo00Uoo`03001oogoo03Yoo`40005oo`0000<007ooOol0
KGoo0P00=Woo00<007ooOol027oo00<007ooOol0U7oo0P00=Woo00<007ooOol027oo00<007ooOol0
>Woo0@000Goo00000`00Oomoo`1ZOol3000hOol00`00Oomoo`09Ool00`00Oomoo`2@Ool3000hOol0
0`00Oomoo`09Ool00`00Oomoo`0iOol10001Ool00003001oogoo06Qoo`8003]oo`03001oogoo00Uo
o`03001oogoo08ioo`8003]oo`03001oogoo00Uoo`03001oogoo03Uoo`40005oo`0000<007ooOol0
IGoo0`00?Goo00<007ooOol02Woo00<007ooOol0RWoo0`00?Goo00<007ooOol02Woo00<007ooOol0
>7oo0@000Goo00000`00Oomoo`1SOol20010Ool00`00Oomoo`0;Ool00`00Oomoo`27Ool20010Ool0
0`00Oomoo`0;Ool00`00Oomoo`0gOol10001Ool00003001oogoo061oo`<0049oo`03001oogoo00]o
o`03001oogoo08Aoo`<0049oo`03001oogoo00]oo`03001oogoo03Moo`40005oo`0000<007ooOol0
GWoo0P00AGoo00<007ooOol037oo00<007ooOol0PGoo0P00AGoo00<007ooOol037oo00<007ooOol0
=Woo0@000Goo00000`00Oomoo`1KOol30017Ool00`00Oomoo`0=Ool00`00Oomoo`1mOol30017Ool0
0`00Oomoo`0=Ool00`00Oomoo`0eOol10001Ool00003001oogoo05Uoo`8004Yoo`03001oogoo00eo
o`03001oogoo07]oo`8004Yoo`03001oogoo00eoo`03001oogoo03Eoo`40005oo`0000<007ooOol0
EWoo0`00C7oo00<007ooOol03Woo00<007ooOol0Mgoo0`00C7oo00<007ooOol03Woo00<007ooOol0
=7oo0@000Goo00000`00Oomoo`1DOol2001?Ool00`00Oomoo`0?Ool00`00Oomoo`1dOol2001?Ool0
0`00Oomoo`0?Ool00`00Oomoo`0cOol10001Ool00003001oogoo055oo`<0055oo`03001oogoo00mo
o`03001oogoo075oo`<0055oo`03001oogoo00moo`03001oogoo03=oo`40005oo`0000<007ooOol0
Cgoo0P00E7oo00<007ooOol047oo00<007ooOol0KWoo0P00E7oo00<007ooOol047oo00<007ooOol0
<Woo0@000Goo00000`00Oomoo`1<Ool3001FOol00`00Oomoo`0@Ool00`00Oomoo`1[Ool3001FOol0
0`00Oomoo`0@Ool00`00Oomoo`0bOol10001Ool00003001oogoo04Uoo`<005Yoo`03001oogoo011o
o`03001oogoo06Moo`<005Yoo`03001oogoo011oo`03001oogoo035oo`40005oo`0000<007ooOol0
Agoo0P00GGoo00<007ooOol04Goo00<007ooOol0I7oo0P00GGoo00<007ooOol04Goo00<007ooOol0
<7oo0@000Goo00000`00Oomoo`14Ool3001OOol00`00Oomoo`0AOol00`00Oomoo`1QOol3001OOol0
0`00Oomoo`0AOol00`00Oomoo`0`Ool10001Ool00003001oogoo049oo`80069oo`03001oogoo019o
o`03001oogoo05ioo`80069oo`03001oogoo019oo`03001oogoo02moo`40005oo`0000<007ooOol0
?goo0`00I7oo00<007ooOol04goo00<007ooOol0FWoo0`00I7oo00<007ooOol04goo00<007ooOol0
;Woo0@000Goo00000`00Oomoo`0mOol2001WOol00`00Oomoo`0COol00`00Oomoo`1HOol2001WOol0
0`00Oomoo`0COol00`00Oomoo`0^Ool10001Ool00003001oogoo03Yoo`<006Uoo`03001oogoo01Ao
o`03001oogoo05Aoo`<006Uoo`03001oogoo01Aoo`03001oogoo02eoo`40005oo`0000<007ooOol0
>7oo0P00K7oo00<007ooOol057oo00<007ooOol0DWoo0P00K7oo00<007ooOol057oo00<007ooOol0
;Goo0@000Goo00000`00Oomoo`0eOol3001^Ool00`00Oomoo`0EOol00`00Oomoo`1>Ool3001^Ool0
0`00Oomoo`0EOol00`00Oomoo`0/Ool10001Ool00003001oogoo03=oo`80075oo`03001oogoo01Io
o`03001oogoo04]oo`80075oo`03001oogoo01Ioo`03001oogoo02]oo`40005oo`0000<007ooOol0
<7oo0`00Lgoo00<007ooOol05Woo00<007ooOol0B7oo0`00Lgoo00<007ooOol05Woo00<007ooOol0
:goo0@000Goo00000`00Oomoo`0^Ool2001DOol2000POol00`00Oomoo`0GOol00`00Oomoo`15Ool2
001fOol00`00Oomoo`0GOol00`00Oomoo`0ZOol10001Ool00003001oogoo02]oo`<005=oo`<00003
@C00000001moo`03001oogoo01Qoo`03001oogoo045oo`<007Qoo`03001oogoo01Qoo`03001oogoo
02Uoo`40005oo`0000<007ooOol0:7oo0`00E7oo0P00144`0P007goo00<007ooOol067oo00<007oo
Ool0?Woo0`00Ngoo00<007ooOol067oo00<007ooOol0:Goo0@000Goo00000`00Oomoo`0VOol2001D
Ool30006@C000`00OZd0000OOol00`00Oomoo`0HOol00`00Oomoo`0kOol2001oOol00`00Oomoo`0H
Ool00`00Oomoo`0XOol10001Ool00003001oogoo02=oo`<005=oo`<000U1<004001n[Gj]0006Ool8
000@Ool00`00Oomoo`0IOol00`00Oomoo`0gOol30021Ool00`00Oomoo`0IOol00`00Oomoo`0WOol1
0001Ool00003001oogoo025oo`80059oo`@000a1<005001n[Gj]OZd00008Ool4000AOol00`00Oomo
o`0IOol00`00Oomoo`0eOol20024Ool00`00Oomoo`0IOol00`00Oomoo`0WOol10001Ool00003001o
ogoo01ioo`<0059oo`<00003@C00044`00a1<005001n[Gj]OZd00006Ool20002Ool00`00Oomoo`0@
Ool00`00Oomoo`0JOol00`00Oomoo`0aOol30026Ool00`00Oomoo`0JOol00`00Oomoo`0VOol10001
Ool00003001oogoo01aoo`8005=oo`8000=1<0030011<44`00a1<003001n[Gj]009n[@03001oogoo
00<0009oo`8001=oo`03001oogoo01Yoo`03001oogoo02moo`8008Uoo`03001oogoo01Yoo`03001o
ogoo02Ioo`40005oo`0000<007ooOol06Woo0P00DWoo0`001T4`00<0044`@C002d4`00<007j]OZd0
0Wj]0`0017oo0P0057oo00<007ooOol06goo00<007ooOol0;7oo0P00Rgoo00<007ooOol06goo00<0
07ooOol09Goo0@000Goo00000`00Oomoo`0JOol2001?Ool30007@C000`00@C00000=@C000`00OZen
[@030005Ool00`00Oomoo`0DOol00`00Oomoo`0LOol00`00Oomoo`0[Ool2002;Ool00`00Oomoo`0L
Ool00`00Oomoo`0TOol10001Ool00003001oogoo01Yoo`03001oo`0004aoo`8000]1<0030011<44`
00a1<003001n[Gj]009n[@03001oogoo00]oo`04001oogoo000;Ool00`00Oomoo`0LOol00`00Oomo
o`0[Ool00`00Ool0002:Ool00`00Oomoo`0LOol00`00Oomoo`0TOol10001Ool00003001oogoo01Yo
o`04001oogoo001;Ool00`00@C11<00I@C000`00OZen[@02OZd00`00Oomoo`0<Ool2000<Ool00`00
Oomoo`0MOol00`00Oomoo`0ZOol01000Oomoo`00RGoo00<007ooOol07Goo00<007ooOol08goo0@00
0Goo00000`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`18Ool00`00@C11<00H@C020004OZd0
0`00Oomoo`0<Ool2000<Ool00`00Oomoo`0NOol00`00Oomoo`0XOol00`00Oomoo`02Ool00`00Oomo
o`1FOol00`00Oomoo`0]Ool00`00Oomoo`0NOol00`00Oomoo`0ROol10001Ool00003001oogoo01Uo
o`03001oogoo00=oo`03001oogoo04Moo`030011<44`01E1<0<0009Fo@05001n[Gj]OZd0000=Ool0
1000Oomoo`002goo00<007ooOol07Woo00<007ooOol0:7oo00<007ooOol00goo00<007ooOol0E7oo
00<005dVGBH00P00;7oo00<007ooOol07Woo00<007ooOol08Woo0@000Goo00000`00Oomoo`0IOol0
0`00Oomoo`04Ool00`00Oomoo`16Ool00`00@C11<00C@C020006E_d01@00OZen[Gj]00006goo00<0
07ooOol07goo00<007ooOol09goo00<007ooOol017oo00<007ooOol0Dgoo00<005dVGBH00UdV0P00
:Woo00<007ooOol07goo00<007ooOol08Goo0@000Goo00000`00Oomoo`0IOol00`00Oomoo`05Ool0
0`00Oomoo`15Ool00`00@C11<00@@C030009E_d01000OZen[@006goo00<007ooOol07goo00<007oo
Ool09goo00<007ooOol01Goo00<007ooOol0DGoo00@0035E000000AM9P03001oogoo02Moo`03001o
ogoo01moo`03001oogoo025oo`40005oo`0000<007ooOol06Goo00<007ooOol01Woo00<007ooOol0
A7oo00<0044`@C003D4`0`0035Km00@007j]OZd001aoo`03001oogoo01moo`03001oogoo02Ioo`03
001oogoo00Ioo`03001oogoo051oo`04000aE@00DWT5000ZOol00`00Oomoo`0OOol00`00Oomoo`0P
Ool10001Ool00003001oogoo01Uoo`03001oogoo00Moo`03001oogoo04=oo`030011<44`00Y1<0<0
011Fo@03001n[@0001aoo`03001oogoo021oo`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo
04moo`8000=BN@04001W>VLj000ZOol00`00Oomoo`0POol00`00Oomoo`0OOol10001Ool00003001o
ogoo01Uoo`03001oogoo00Qoo`03001oogoo049oo`030011<44`00M1<0<001AFo@8001aoo`03001o
ogoo021oo`03001oogoo02Eoo`03001oogoo00Qoo`03001oogoo04eoo`03000aE@00009BN@04001W
>VLjIcX[Ool00`00Oomoo`0POol00`00Oomoo`0OOol10001Ool00003001oogoo01Qoo`03001oogoo
00Yoo`03001oogoo045oo`030011<44`00E1<08001QFo@03001oogoo01Yoo`03001oogoo025oo`03
001oogoo02=oo`03001oogoo00Yoo`03001oogoo04aoo`03000aE@00009BN@04001W>VLj000[Ool0
0`00Oomoo`0QOol00`00Oomoo`0NOol10001Ool00003001oogoo01Qoo`03001oogoo00]oo`03001o
ogoo041oo`030011<44`0091<0<000UFo@03001FoEKm00YFo@<001ioo`03001oogoo029oo`03001o
ogoo029oo`03001oogoo00]oo`03001oogoo04Yoo`03000aE@0000=BN@03001W>VLj02aoo`03001o
ogoo029oo`03001oogoo01eoo`40005oo`0000<007ooOol067oo00<007ooOol037oo00<007ooOol0
?goo00<0044`00000P0035Km00<005KmE_d025Km0P008Goo00<007ooOol08Woo00<007ooOol08Woo
00<007ooOol037oo00<007ooOol0BGoo00<0035E00000U9i00@006LjIcX002aoo`03001oogoo029o
o`03001oogoo01eoo`40005oo`0000<007ooOol067oo00<007ooOol03Goo00<007ooOol0?Woo0P00
3eKm00<005KmE_d01EKm0`008goo00<007ooOol08goo00<007ooOol08Goo00<007ooOol03Goo00<0
07ooOol0B7oo0P000e9i00@006LjIcX002aoo`03001oogoo02=oo`03001oogoo01aoo`40005oo`00
00<007ooOol067oo00<007ooOol03Woo00<007ooOol0?Woo00<005KmE_d03EKm00<005KmE_d00UKm
0`009Woo00<007ooOol08goo00<007ooOol08Goo00<007ooOol03Woo00<007ooOol0AWoo00<0035E
00000U9i00@006LjIcYW>Reoo`03001oogoo02=oo`03001oogoo01aoo`40005oo`0000<007ooOol0
67oo00<007ooOol03goo00<007ooOol0?Woo00<005KmE_d035Km00<005Km00000P000goo00<007oo
Ool08goo00<007ooOol097oo00<007ooOol087oo00<007ooOol03goo00<007ooOol0AGoo00<0035E
00000U9i00@006LjIcX002eoo`03001oogoo02Aoo`03001oogoo01]oo`40005oo`0000<007ooOol0
67oo00<007ooOol047oo00<007ooOol0?Woo00<005KmE_d02UKm0`001Woo00<007ooOol08goo00<0
07ooOol09Goo00<007ooOol07goo00<007ooOol047oo00<007ooOol0A7oo0P000e9i00@006LjIcX0
02eoo`03001oogoo02Eoo`03001oogoo01Yoo`40005oo`0000<007ooOol05goo00<007ooOol04Woo
00<007ooOol0?Goo00<005KmE_d025Km0P0000=oo`00Ool01goo00<007oo00008Woo00<007ooOol0
9Goo00<007ooOol07Woo00<007ooOol04Woo00<007ooOol0@Woo00<0035E00000U9i00@006LjIcX0
02ioo`03001oogoo02Eoo`03001oogoo01Yoo`40005oo`0000<007ooOol05goo00<007ooOol04goo
00<007ooOol0?Goo00<005KmE_d015Km0`000goo00<007ooOol01goo0P008Woo00<007ooOol09Goo
0P007goo00<007ooOol04goo00<007ooOol0@Goo00<0035E00000U9i00@006LjIcX002ioo`03001o
ogoo02Eoo`8001]oo`40005oo`0000<007ooOol05goo00<007ooOol057oo00<007ooOol0?Goo00<0
05KmE_d00`001Woo00<007ooOol027oo0P0000=oo`00Ool07Woo00<007ooOol08Woo0`0000=oo`00
Ool07Woo00<007ooOol057oo00<007ooOol0?goo00<0035E00000e9i00<006LjIcX0;goo00<007oo
Ool08Woo0`0000=oo`00Ool06Woo0@000Goo00000`00Oomoo`0GOol00`00Oomoo`0EOol00`00Oomo
o`0mOol20009Ool00`00Oomoo`09Ool00`00Ool0000OOol00`00Oomoo`0OOol30004Ool00`00Oomo
o`0MOol00`00Oomoo`0EOol00`00Oomoo`0nOol00`00<ED00002DWT01000IcYW>P00;goo00<007oo
Ool07goo0`0017oo00<007ooOol06Goo0@000Goo00000`00Oomoo`0GOol00`00Oomoo`0FOol00`00
Oomoo`17Ool00`00Oomoo`05Ool20002Ool3000POol00`00Oomoo`0KOol30007Ool00`00Oomoo`0M
Ool00`00Oomoo`0FOol00`00Oomoo`0mOol20003DWT01000IcYW>P00<7oo00<007ooOol06goo0`00
1goo00<007ooOol06Goo0@000Goo00000`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`16Ool0
0`00Oomoo`07Ool5000POol00`00Oomoo`0HOol3000;Ool00`00Oomoo`0LOol00`00Oomoo`0GOol0
0`00Oomoo`0kOol00`00<ED00002DWT01000IcYW>P00<Goo00<007ooOol067oo0`002goo00<007oo
Ool067oo0@000Goo00000`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`13Ool00`00Ool0000<
Ool2000POol00`00Oomoo`0EOol3000>Ool00`00Oomoo`0LOol00`00Oomoo`0HOol00`00Oomoo`0j
Ool00`00<ED00002DWT01000IcYW>P00<Goo00<007ooOol05Goo0`003Woo00<007ooOol067oo0@00
0Goo00000`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`12Ool00`00Ool00002Ool00`00Oomo
o`0YOol00`00Oomoo`0BOol3000AOol00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`0iOol2
0003DWT00`00IcYW>P0bOol00`00Oomoo`0BOol3000AOol00`00Oomoo`0HOol10001Ool00003001o
ogoo01Ioo`03001oogoo01]oo`03001oogoo049oo`800003Ool007oo02]oo`03001oogoo00ioo`@0
01Aoo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo03Moo`03000aE@00009BN@04001W>VLj
000bOol00`00Oomoo`0>Ool4000DOol00`00Oomoo`0HOol10001Ool00003001oogoo01Ioo`03001o
ogoo01aoo`03001oogoo03moo`06001oo`00001oo`00;7oo00<007ooOol02goo0`0067oo00<007oo
Ool06goo00<007ooOol077oo00<007ooOol0=Woo00<0035E00000U9i00@006LjIcX0039oo`03001o
ogoo00]oo`<001Qoo`03001oogoo01Qoo`40005oo`0000<007ooOol05Woo00<007ooOol07Goo00<0
07ooOol0?goo10003Woo0P007Goo00<007ooOol027oo0`006goo00<007ooOol06goo00<007ooOol0
7Goo00<007ooOol0=Goo0P000e9i00<006Lj0000<goo00<007ooOol027oo0`006goo00<007ooOol0
67oo0@000Goo00000`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0nOol4000?Ool00`00Oomo
o`0KOol00`00Oomoo`05Ool3000NOol00`00Oomoo`0KOol00`00Oomoo`0NOol00`00Oomoo`0cOol0
0`00<ED00002DWT01000IcYW>P00<goo00<007ooOol01Goo0`007Woo00<007ooOol067oo0@000Goo
00000`00Oomoo`0FOol00`00Oomoo`0OOol2000oOol2000@Ool00`00Oomoo`0KOol00`00Oomoo`02
Ool3000QOol00`00Oomoo`0KOol00`00Oomoo`0OOol2000cOol20003DWT01000IcYW>P00<goo00<0
07ooOol00Woo0`008Goo00<007ooOol067oo0@000Goo00000`00Oomoo`0FOol00`00Oomoo`0QOol0
0`00Oomoo`0mOol00`00Oomoo`0=Ool00`00Ool0000LOol00`00Ool00002000UOol00`00Oomoo`0J
Ool00`00Oomoo`0QOol00`00Oomoo`0_Ool00`00<ED00002DWT01000IcYW>P00=7oo00<007oo0000
0P009Goo00<007ooOol05goo0@000Goo00000`00Oomoo`0EOol00`00Oomoo`0SOol00`00Oomoo`1<
Ool00`00Ool0000KOol3000XOol00`00Oomoo`0IOol00`00Oomoo`0SOol00`00Oomoo`0^Ool00`00
<ED00002DWT01000IcYW>P00<goo0`00:7oo00<007ooOol05goo0@000Goo00000`00Oomoo`0EOol0
0`00Oomoo`0TOol00`00Oomoo`1:Ool200000goo0000000GOol300000goo001oo`0XOol00`00Oomo
o`0IOol00`00Oomoo`0TOol00`00Oomoo`0]Ool20003DWT00`00IcX0000aOol300000goo001oo`0X
Ool00`00Oomoo`0GOol10001Ool00003001oogoo01Eoo`03001oogoo02Eoo`03001oogoo069oo`<0
00Aoo`03001oogoo02Moo`03001oogoo01Uoo`03001oogoo02Eoo`03001oogoo02]oo`03000aE@00
009BN@04001W>VLj000^Ool30004Ool00`00Oomoo`0WOol00`00Oomoo`0GOol10001Ool00003001o
ogoo01Eoo`03001oogoo02Ioo`03001oogoo05ioo`<000Moo`03001oogoo02Moo`03001oogoo01Uo
o`03001oogoo02Ioo`03001oogoo02Yoo`03000aE@00009BN@04001W>VLj000[Ool30007Ool00`00
Oomoo`0WOol00`00Oomoo`0GOol10001Ool00003001oogoo01Eoo`03001oogoo02Moo`03001oogoo
05Yoo`<000]oo`03001oogoo02Ioo`03001oogoo01Uoo`03001oogoo02Moo`03001oogoo02Uoo`80
00=BN@03001W>P0002Uoo`<000]oo`03001oogoo02Ioo`03001oogoo01Moo`40005oo`0000<007oo
Ool05Goo00<007ooOol0:7oo00<007ooOol0>7oo10006Woo0`003Woo00<007ooOol09Woo00<007oo
Ool06Goo00<007ooOol0:7oo00<007ooOol09goo00<0035E00000U9i00@006LjIcX002Ioo`<000io
o`03001oogoo02Ioo`03001oogoo01Moo`40005oo`0000<007ooOol05Goo00<007ooOol0:Goo00<0
07ooOol0>7oo00<007oo00005goo0`004Goo00<007ooOol09goo00<007ooOol067oo00<007ooOol0
:Goo00<007ooOol09Woo0P000e9i00@006LjIcX002=oo`<0015oo`03001oogoo02Moo`03001oogoo
01Ioo`40005oo`0000<007ooOol057oo00<007ooOol0:goo00<007ooOol0=Woo00<007oo000057oo
100057oo00<007ooOol09goo00<007ooOol05goo00<007ooOol0:goo00<007ooOol097oo00<0035E
00000U9i00@006LjIcX0021oo`@001Aoo`03001oogoo02Moo`03001oogoo01Ioo`40005oo`0000<0
07ooOol057oo00<007ooOol0;7oo00<007ooOol0=Goo100047oo0`0067oo00<007ooOol09goo00<0
07ooOol05goo00<007ooOol0;7oo00<007ooOol08goo00<0035E00000U9i00@006LjIcX001eoo`<0
01Qoo`03001oogoo02Moo`03001oogoo01Ioo`40005oo`0000<007ooOol057oo00<007ooOol0;Goo
00<007ooOol0AGoo0`006goo00<007ooOol09goo00<007ooOol05goo00<007ooOol0;Goo00<007oo
Ool08Woo0P000e9i00<006Lj00006goo0`006goo00<007ooOol09goo00<007ooOol05Woo0@000Goo
00000`00Oomoo`0DOol00`00Oomoo`0^Ool00`00Oomoo`11Ool3000MOol2000YOol00`00Oomoo`0G
Ool00`00Oomoo`0^Ool00`00Oomoo`0POol00`00<ED00002DWT01000IcYW>P0067oo0`007Goo0P00
:Goo00<007ooOol05Woo0@000Goo00000`00Oomoo`0DOol00`00Oomoo`0_Ool00`00Oomoo`0mOol3
000MOol30002Ool00`00Oomoo`0VOol00`00Oomoo`0GOol00`00Oomoo`0_Ool00`00Oomoo`0OOol0
0`00<ED00002DWT01000IcYW>P005Goo0`007Goo0`000Woo00<007ooOol09Woo00<007ooOol05Woo
0@000Goo00000`00Oomoo`0DOol00`00Oomoo`0`Ool00`00Oomoo`0iOol3000MOol30006Ool00`00
Oomoo`0UOol00`00Oomoo`0GOol00`00Oomoo`0`Ool00`00Oomoo`0NOol20003DWT00`00IcX0000C
Ool3000MOol30006Ool00`00Oomoo`0UOol00`00Oomoo`0FOol10001Ool00003001oogoo01Aoo`03
001oogoo035oo`03001oogoo03Eoo`<001eoo`<000Uoo`03001oogoo02Eoo`03001oogoo01Moo`03
001oogoo035oo`03001oogoo01aoo`03000aE@00009BN@04001W>VLj000@Ool3000MOol30009Ool0
0`00Oomoo`0UOol00`00Oomoo`0FOol10001Ool00003001oogoo01=oo`03001oogoo03=oo`03001o
ogoo035oo`<001aoo`@000eoo`03001oogoo02Eoo`03001oogoo01Eoo`03001oogoo03=oo`03001o
ogoo01]oo`8000=BN@03001W>P0000ioo`<001aoo`@000eoo`03001oogoo02Eoo`03001oogoo01Eo
o`40005oo`0000<007ooOol04goo00<007ooOol0=7oo00<007ooOol0;Goo0`0077oo0`004Woo00<0
07ooOol097oo00<007ooOol05Goo00<007ooOol0=7oo00<007ooOol06Woo0P000U9i00@006LjIcX0
00]oo`<001aoo`<0019oo`03001oogoo02Aoo`03001oogoo01Eoo`40005oo`0000<007ooOol04goo
00<007ooOol0=Goo00<007ooOol0:Goo0`0077oo0`005Woo00<007ooOol08goo00<007ooOol05Goo
00<007ooOol0=Goo00<007ooOol067oo00<0035E00000U9i00@006LjIcX000Qoo`<001aoo`<001Io
o`03001oogoo02=oo`03001oogoo01Eoo`40005oo`0000<007ooOol04goo00<007ooOol0=Woo00<0
07ooOol09Goo0`0077oo0`006Goo00<007ooOol08goo00<007ooOol05Goo00<007ooOol0=Woo00<0
07ooOol05goo0P000e9i00<006Lj00001Woo0`0077oo0`006Goo00<007ooOol08goo00<007ooOol0
5Goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`0gOol00`00Oomoo`0QOol3000LOol3000MOol0
0`00Oomoo`0ROol00`00Oomoo`0EOol00`00Oomoo`0gOol00`00Oomoo`0EOol00`00<ED00002DWT0
1000IcYW>P000goo0`0077oo0`007Goo00<007ooOol08Woo00<007ooOol05Goo0@000Goo00000`00
Oomoo`0COol00`00Oomoo`0hOol00`00Oomoo`0MOol3000LOol3000QOol00`00Oomoo`0QOol00`00
Oomoo`0EOol00`00Oomoo`0hOol00`00Oomoo`0DOol00`00<ED00002DWT00`00IcYW>P04000LOol3
000QOol00`00Oomoo`0QOol00`00Oomoo`0EOol10001Ool00003001oogoo01=oo`03001oogoo03Uo
o`03001oogoo01Qoo`@001aoo`<002Eoo`03001oogoo021oo`03001oogoo01Eoo`03001oogoo03Uo
o`03001oogoo01=oo`8000=BN@04001W>P00000LOol3000UOol00`00Oomoo`0POol00`00Oomoo`0E
Ool10001Ool00003001oogoo01=oo`03001oogoo03Yoo`03001oogoo01Aoo`<001aoo`@002Qoo`03
001oogoo025oo`03001oogoo01Aoo`03001oogoo03Yoo`03001oogoo015oo`03000aE@00009BN@04
001W>VLj000IOol4000XOol00`00Oomoo`0QOol00`00Oomoo`0DOol10001Ool00003001oogoo019o
o`03001oogoo03aoo`03001oogoo011oo`<001aoo`<002eoo`03001oogoo021oo`03001oogoo01=o
o`03001oogoo03aoo`03001oogoo011oo`8000=BN@03001W>P0001Moo`<002eoo`03001oogoo021o
o`03001oogoo01Aoo`40005oo`0000<007ooOol04Woo00<007ooOol0?Goo00<007ooOol037oo0`00
77oo0`00<Goo00<007ooOol07goo00<007ooOol04goo00<007ooOol0?Goo00<007ooOol037oo1@00
0U9i00@006LjIcX001Aoo`<0035oo`03001oogoo01moo`03001oogoo01Aoo`40005oo`0000<007oo
Ool04Woo00<007ooOol0?Woo00<007ooOol027oo0`0077oo0`00=Goo00<007ooOol07Woo00<007oo
Ool04goo00<007ooOol0?Woo00<007ooOol027oo0`000Woo00<0035E00000U9i00@006LjIcX0015o
o`<003Eoo`03001oogoo01ioo`03001oogoo01Aoo`40005oo`0000<007ooOol04Woo00<007ooOol0
?goo00<007ooOol017oo0`0077oo0`00>7oo00<007ooOol07Woo00<007ooOol04goo00<007ooOol0
?goo00<007ooOol017oo0`001Goo0P000e9i00<006Lj00003goo0`00>7oo00<007ooOol07Woo00<0
07ooOol057oo0@000Goo00000`00Oomoo`0BOol00`00Oomoo`10Ool00`00Oomoo`03000LOol3000l
Ool00`00Oomoo`0MOol00`00Oomoo`0COol00`00Oomoo`10Ool00`00Oomoo`030007Ool00`00<ED0
0002DWT01000IcYW>P0037oo0`00?7oo00<007ooOol07Goo00<007ooOol057oo0@000Goo00000`00
Oomoo`0BOol00`00Oomoo`11Ool2000LOol30010Ool00`00Oomoo`0LOol00`00Oomoo`0COol00`00
Oomoo`11Ool2000:Ool00`00<ED00002DWT01000IcX000002Goo0`00@7oo00<007ooOol077oo00<0
07ooOol057oo0@000Goo00000`00Oomoo`0BOol00`00Oomoo`11Ool00`00Oomoo`0GOol40014Ool0
0`00Oomoo`0KOol00`00Oomoo`0COol00`00Oomoo`11Ool00`00Oomoo`09Ool20003DWT00`00IcX0
0006Ool40014Ool00`00Oomoo`0KOol00`00Oomoo`0DOol10001Ool00003001oogoo015oo`03001o
ogoo049oo`03001oogoo01Aoo`<004Qoo`03001oogoo01aoo`03001oogoo015oo`03001oogoo049o
o`03001oogoo00Qoo`03000aE@00009BN@04001W>VLj0003Ool30018Ool00`00Oomoo`0LOol00`00
Oomoo`0COol10001Ool00003001oogoo015oo`03001oogoo049oo`03001oogoo015oo`<004aoo`03
001oogoo01]oo`03001oogoo015oo`03001oogoo049oo`03001oogoo00Qoo`03000aE@00009BN@03
001W>P0000@004aoo`03001oogoo01]oo`03001oogoo01=oo`40005oo`0000<007ooOol04Goo00<0
07ooOol0@Woo00<007ooOol03Woo0`00D7oo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol0
@Woo00<007ooOol027oo0P000e9i1000D7oo00<007ooOol06Woo00<007ooOol04goo0@000Goo0000
0`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`0;Ool3001DOol00`00Oomoo`0IOol00`00Oomo
o`0AOol00`00Oomoo`12Ool00`00Oomoo`07Ool01000<ED0059i0`0000=W>P00Ool0DGoo00<007oo
Ool06Goo00<007ooOol04goo0@000Goo00000`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`08
Ool3001HOol00`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`12Ool00`00Oomoo`07Ool40000
159i001W>P00E7oo00<007ooOol067oo00<007ooOol04goo0@000Goo00000`00Oomoo`0AOol00`00
Oomoo`12Ool00`00Oomoo`05Ool3001KOol00`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`12
Ool00`00Oomoo`05Ool40002DWT01000IcYW>P00E7oo00<007ooOol067oo00<007ooOol04goo0@00
0Goo00000`00Oomoo`0AOol00`00Oomoo`12Ool01000Oomoogoo1000Ggoo00<007ooOol05goo00<0
07ooOol04Goo00<007ooOol0@Woo00@007ooOomoo`@00004Ool0035E0002DWT01000IcX00000EGoo
00<007ooOol05goo00<007ooOol04goo0@000Goo00000`00Oomoo`0@Ool00`00Oomoo`13Ool4001T
Ool00`00Oomoo`0GOol00`00Oomoo`0?Ool00`00Oomoo`13Ool40005Ool20003DWT00`00IcX0001G
Ool00`00Oomoo`0GOol00`00Oomoo`0BOol10001Ool00003001oogoo011oo`03001oogoo045oo`<0
06Qoo`03001oogoo01Ioo`03001oogoo00moo`03001oogoo045oo`<000Moo`03000aE@00009BN@04
001W>VLj001HOol00`00Oomoo`0FOol00`00Oomoo`0BOol10001Ool00003001oogoo011oo`03001o
ogoo03ioo`<00003Ool007oo06Qoo`03001oogoo01Ioo`03001oogoo00moo`03001oogoo03ioo`<0
0003Ool007oo00Moo`03000aE@00009BN@04001W>P00001HOol00`00Oomoo`0FOol00`00Oomoo`0B
Ool10001Ool00003001oogoo011oo`03001oogoo03]oo`<000Aoo`03001oogoo06Qoo`03001oogoo
01Eoo`03001oogoo00moo`03001oogoo03]oo`<000Aoo`03001oogoo00Ioo`8000=BN@03001W>P00
05Yoo`03001oogoo01Eoo`03001oogoo019oo`40005oo`0000<007ooOol047oo00<007ooOol0>7oo
0`001goo00<007ooOol0JGoo00<007ooOol057oo00<007ooOol03goo00<007ooOol0>7oo0`001goo
00<007ooOol01Goo00<0035E00000U9i00@006Lj000005]oo`03001oogoo01Aoo`03001oogoo019o
o`40005oo`0000<007ooOol047oo00<007ooOol0=Goo0`002Woo00<007ooOol0JWoo00<007ooOol0
4goo00<007ooOol03goo00<007ooOol0=Goo0`002Woo00<007ooOol01Goo0P000e9i00<006Lj0000
GGoo00<007ooOol04goo00<007ooOol04Woo0@000Goo00000`00Oomoo`0@Ool00`00Oomoo`0aOol4
000=Ool00`00Oomoo`1ZOol00`00Oomoo`0COol00`00Oomoo`0?Ool00`00Oomoo`0aOol4000=Ool0
0`00Oomoo`05Ool20002DWT01000IcYW>P00GGoo00<007ooOol04goo00<007ooOol04Woo0@000Goo
00000`00Oomoo`0?Ool00`00Oomoo`0_Ool3000AOol00`00Oomoo`1[Ool00`00Oomoo`0BOol00`00
Oomoo`0>Ool00`00Oomoo`0_Ool3000AOol00`00Oomoo`04Ool00`00<ED00002DWT01000IcX00000
GWoo00<007ooOol04Woo00<007ooOol04Woo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0/Ool3
000DOol00`00Oomoo`1/Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0/Ool3000DOol0
0`00Oomoo`04Ool20003DWT00`00IcX0001POol00`00Oomoo`0BOol00`00Oomoo`0AOol10001Ool0
0003001oogoo00moo`03001oogoo02Uoo`<001Moo`03001oogoo06eoo`03001oogoo015oo`03001o
ogoo00eoo`03001oogoo02Uoo`<001Moo`03001oogoo00=oo`03000aE@00009BN@04001W>VLj001Q
Ool00`00Oomoo`0AOol00`00Oomoo`0AOol10001Ool00003001oogoo00moo`03001oogoo02Ioo`<0
01Yoo`03001oogoo06eoo`03001oogoo015oo`03001oogoo00eoo`03001oogoo02Ioo`<001Yoo`03
001oogoo00=oo`03000aE@00009BN@04001W>P00001QOol00`00Oomoo`0AOol00`00Oomoo`0AOol1
0001Ool00003001oogoo00moo`03001oogoo02=oo`<001eoo`03001oogoo06ioo`03001oogoo011o
o`03001oogoo00eoo`03001oogoo02=oo`<001eoo`03001oogoo00=oo`8000=BN@03001W>P0006=o
o`03001oogoo011oo`03001oogoo015oo`40005oo`0000<007ooOol03goo00<007ooOol087oo0`00
87oo00<007ooOol0Kgoo00<007ooOol03goo00<007ooOol03Goo00<007ooOol087oo0`0087oo00<0
07ooOol00Woo00<0035E00000U9i00@006Lj000003eoo`@002=oo`03001oogoo00moo`03001oogoo
015oo`40005oo`0000<007ooOol03goo00<007ooOol077oo10008goo00<007ooOol0L7oo00<007oo
Ool03Woo00<007ooOol03Goo00<007ooOol077oo10008goo00<007ooOol00Woo0P000e9i00<006Lj
0000?Goo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol03Woo00<007ooOol04Goo0@000Goo
00000`00Oomoo`0>Ool00`00Oomoo`0JOol3000WOol00`00Oomoo`1`Ool00`00Oomoo`0>Ool00`00
Oomoo`0<Ool00`00Oomoo`0JOol3000WOol00`00Oomoo`02Ool01C5E001BNE9i00000VLj00<007oo
Ool0>goo1P008goo00<007ooOol03Woo00<007ooOol04Goo0@000Goo00000`00Oomoo`0>Ool00`00
Oomoo`0GOol3000ZOol00`00Oomoo`1aOol00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`0G
Ool3000ZOol01`00Oomoogoo000aE@00009BN@04001W>P000009Ool40003Ool30002Ool300000goo
0000000400001Goo00000000Ool00`000goo0P000goo2P0000=oo`0000001P0017oo100000Eoo`00
000007oo00<000=oo`D000eoo`03001oogoo00ioo`03001oogoo011oo`40005oo`0000<007ooOol0
3Woo00<007ooOol057oo0`00;Goo00<007ooOol09goo00<007oo00000P000Woo200000=oo`000000
0`0000Aoo`000000009oo`@002aoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo01Aoo`<0
02eoo`04001oogooOol20003DWT00`00IcX00009Ool20003Ool01@00Ool00000Ool00P000Woo0P00
00=oo`0000000Woo0P0000Aoo`00001oo`80009oo`06001oo`00001oo`000Woo0P000Woo0P000Woo
0P0000Eoo`00001oo`0000Uoo`80009oo`800004Ool00000Ool2000017oo000007oo0P003goo00<0
07ooOol03Goo00<007ooOol047oo0@000Goo00000`00Oomoo`0>Ool00`00Oomoo`0AOol3000`Ool0
0`00Oomoo`0WOol20002Ool20002Ool20002Ool2000017oo000007oo0P0000=oo`0000000Woo00<0
07ooOol00P00;Woo00<007ooOol037oo00<007ooOol02goo00<007ooOol04Goo0`00<7oo00H007oo
Oomooc5E0002DWT01000IcYW>P0027oo0P001Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo
0P0000Aoo`00001oo`8000Aoo`8000Aoo`80009oo`80009oo`800003Ool00000009oo`<000Ioo`80
0003Ool00000009oo`800004Ool00000Ool200000goo0000000@Ool00`00Oomoo`0<Ool00`00Oomo
o`0@Ool10001Ool00003001oogoo00ioo`03001oogoo00ioo`<003=oo`03001oogoo02Moo`04001o
ogooOol20002Ool20002Ool2000017oo000007oo0P0000=oo`0000001Goo0P00;Woo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol03Woo0`00<goo00H007ooOol0035E0002DWT01000IcX00000
27oo0P001Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000Aoo`00001oo`D00003Ool0
000000Aoo`80009oo`80009oo`800004Ool00000Ool200000goo00000005Ool200000goo00000002
Ool2000017oo000007oo0P0000=oo`00000047oo00<007ooOol037oo00<007ooOol047oo0@000Goo
00000`00Oomoo`0>Ool00`00Oomoo`0;Ool3000fOol00`00Oomoo`0ZOol30002Ool20002Ool20000
17oo000007oo0P0000=oo`0000000`000Woo0P00;goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol02goo0`00=Woo00<007ooOol00P000e9i00<006Lj00002Goo0P001Woo0P0000=oo`000000
0Woo0P0000=oo`0000000Woo0P0000Aoo`00001oo`800004Ool00000Ool2000017oo001oogoo0P00
0Woo0P000Woo0P0000Aoo`00001oo`800003Ool0000000Eoo`@000=oo`800004Ool00000Ool20000
0goo0000000AOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool10001Ool00003001oogoo00ioo`03001o
ogoo00Moo`@003Uoo`03001oogoo02Qoo`@000=oo`80009oo`800004Ool00000Ool2000017oo0000
07oo0P000Woo0P0000=oo`00Ool0;Goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol01goo
1000>Goo00D007oo000aE@00009BN@04001W>P000009Ool20007Ool30002Ool50002Ool50003Ool3
0003Ool300000goo0000000500000goo000000030003Ool50004Ool20002Ool20002Ool30003Ool4
000BOol00`00Oomoo`0:Ool00`00Oomoo`0@Ool10001Ool00003001oogoo00eoo`03001oogoo00Eo
o`<003eoo`03001oogoo02Moo`<000Eoo`800004Ool000000002Ool40002Ool30002Ool5000_Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool3000mOol01000Ool000000e9i00<006Lj
00002Woo0P0017oo00<007ooOol087oo00<007ooOol057oo0P000Woo0P002Woo0P004goo00<007oo
Ool02Goo00<007ooOol047oo0@000Goo00000`00Oomoo`0=Ool00`00Oomoo`02Ool30010Ool00`00
Oomoo`0WOol20003Ool00`00Oomoo`020008Ool2000lOol00`00Oomoo`08Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool30010Ool01000OolaE@000U9i00@006LjIcX000]oo`80009oo`80029oo`03001o
ogoo0080019oo`80009oo`8000Yoo`8001Aoo`03001oogoo00Qoo`03001oogoo011oo`40005oo`00
00<007ooOol03Goo00<007oo00000P00@Woo00<007ooOol0:7oo0P000Woo0P000Woo0P000Woo0P00
17oo0P00?7oo00<007ooOol02Goo00<007ooOol02Goo00<007oo00000P00@Woo00D007oo000aE@00
009BN@04001W>P00000<Ool300000goo001oo`0TOol2000AOol6000:Ool3000DOol00`00Oomoo`09
Ool00`00Oomoo`0?Ool10001Ool00003001oogoo00eoo`8004Eoo`03001oogoo02Uoo`<00003Ool0
07oo00<0009oo`8000=oo`<003eoo`03001oogoo00Qoo`03001oogoo00Uoo`8004Eoo`04001oo`00
0003DWT00`00IcX0001bOol00`00Oomoo`08Ool00`00Oomoo`0?Ool10001Ool00003001oogoo00io
o`03001oogoo04=oo`03001oogoo07Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo04=o
o`04001ooc5E0002DWT01000IcX00000Lgoo00<007ooOol01goo00<007ooOol03goo0@000Goo0000
0`00Oomoo`0?Ool20013Ool00`00Oomoo`1kOol00`00Oomoo`06Ool00`00Oomoo`0;Ool20013Ool2
00001S5EDWUBNE9i001W>P8007Aoo`03001oogoo00Ioo`03001oogoo00moo`40005oo`0000<007oo
Ool04Goo00<007ooOol0@7oo00<007ooOol0Ngoo00<007ooOol01Woo00<007ooOol03Goo00<007oo
Ool0@7oo00<0035E00000e9i00<006Lj0000MGoo00<007ooOol01Woo00<007ooOol03goo0@000Goo
00000`00Oomoo`0BOol00`00Oomoo`0oOol00`00Oomoo`1lOol00`00Oomoo`05Ool00`00Oomoo`0>
Ool00`00Oomoo`0oOol00`00<ED00002DWT01000IcX00000MWoo00<007ooOol01Goo00<007ooOol0
3goo0@000Goo00000`00Oomoo`0COol2000oOol00`00Oomoo`1mOol00`00Oomoo`04Ool00`00Oomo
o`0?Ool2000oOol20003DWT00`00IcX0001hOol00`00Oomoo`04Ool00`00Oomoo`0?Ool10001Ool0
0003001oogoo01Eoo`03001oogoo03aoo`03001oogoo07ioo`03001oogoo00Aoo`03001oogoo011o
o`03001oogoo03aoo`05<ED0059iDWT00002IcX00`00Oomoo`1gOol00`00Oomoo`04Ool00`00Oomo
o`0>Ool10001Ool00003001oogoo01Ioo`03001oogoo03]oo`03001oogoo07ioo`03001oogoo00Ao
o`03001oogoo015oo`03001oogoo03Yoo`03000aEE9i009BN@04001W>P00001iOol00`00Oomoo`04
Ool00`00Oomoo`0>Ool10001Ool00003001oogoo01Moo`8003]oo`03001oogoo07moo`03001oogoo
00=oo`03001oogoo019oo`8003Yoo`8000=BN@03001W>P0007]oo`03001oogoo00=oo`03001oogoo
00ioo`40005oo`0000<007ooOol06Goo00<007ooOol0>7oo00<007ooOol0P7oo00<007ooOol00Woo
00<007ooOol057oo00<007ooOol0>7oo0P0000=BN@00IcX00P00O7oo00<007ooOol00Woo00<007oo
Ool03Woo0@000Goo00000`00Oomoo`0JOol00`00Oomoo`0gOol00`00Oomoo`21Ool01@00Oomoogoo
00005goo00<007ooOol0=goo00<007oo00000`00OWoo00D007ooOomoo`00011oo`40005oo`0000<0
07ooOol06goo0P00=goo00<007ooOol0PGoo00D007ooOomoo`0001Qoo`8003Moo`03001oogoo085o
o`05001oogooOol0000@Ool10001Ool00003001oogoo01eoo`03001oogoo03Aoo`03001oogoo089o
o`04001oogoo000JOol00`00Oomoo`0dOol00`00Oomoo`22Ool01000Oomoo`0047oo0@000Goo0000
0`00Oomoo`0NOol00`00Oomoo`0cOol00`00Oomoo`23Ool00`00Ool0000KOol00`00Oomoo`0cOol0
0`00Oomoo`23Ool00`00Ool0000@Ool10001Ool00003001oogoo01moo`8003=oo`03001oogoo08Ao
o`03001oo`0001]oo`8003=oo`03001oogoo08Aoo`03001oo`0000moo`40005oo`0000<007ooOol0
8Goo00<007ooOol0<7oo00<007ooOol0Q7oo00<007oo00007Goo00<007ooOol0<7oo00<007ooOol0
Q7oo00<007oo00003goo0@000Goo00000`00Oomoo`0ROol00`00Oomoo`0_Ool00`00Oomoo`25Ool2
000NOol00`00Oomoo`0_Ool00`00Oomoo`25Ool2000?Ool10001Ool00003001oogoo02=oo`8002mo
o`03001oogoo08Eoo`8001moo`8002moo`03001oogoo08Eoo`8000moo`40005oo`0000<007ooOol0
9Goo00<007ooOol0;7oo00<007ooOol0PGoo10008goo00<007ooOol0;7oo00<007ooOol0PGoo1000
4Goo0@000Goo00000`00Oomoo`0VOol00`00Oomoo`0[Ool00`00Oomoo`1mOol4000XOol00`00Oomo
o`0[Ool00`00Oomoo`1mOol4000EOol10001Ool00003001oogoo02Moo`8002]oo`03001oogoo07Uo
o`@002eoo`8002]oo`03001oogoo07Uoo`@001Uoo`40005oo`0000<007ooOol0:Goo00<007ooOol0
9goo00<007ooOol0MWoo1000<goo00<007ooOol09goo00<007ooOol0MWoo10007Goo0@000Goo0000
0`00Oomoo`0ZOol00`00Oomoo`0VOol00`00Oomoo`1bOol4000hOol00`00Oomoo`0VOol00`00Oomo
o`1bOol4000QOol10001Ool00003001oogoo02]oo`8002Ioo`03001oogoo06ioo`@003eoo`8002Io
o`03001oogoo06ioo`@002Eoo`40005oo`0000<007ooOol0;Goo00<007ooOol08goo00<007ooOol0
JWoo1000@goo00<007ooOol08goo00<007ooOol0JWoo1000:Goo0@000Goo00000`00Oomoo`0^Ool0
0`00Oomoo`0ROol00`00Oomoo`1VOol40018Ool00`00Oomoo`0ROol00`00Oomoo`1VOol4000]Ool1
0001Ool00003001oogoo02moo`80029oo`03001oogoo069oo`@004eoo`80029oo`03001oogoo069o
o`@0035oo`40005oo`0000<007ooOol0<Goo00<007ooOol07goo00<007ooOol0GWoo1000Dgoo00<0
07ooOol07goo00<007ooOol0GWoo1000=Goo0@000Goo00000`00Oomoo`0bOol00`00Oomoo`0NOol0
0`00Oomoo`1JOol4001HOol00`00Oomoo`0NOol00`00Oomoo`1JOol4000iOol10001Ool00003001o
ogoo03=oo`8001ioo`03001oogoo05Ioo`@005eoo`8001ioo`03001oogoo05Ioo`@003eoo`40005o
o`0000<007ooOol0=Goo00<007ooOol06goo00<007ooOol0DWoo1000Hgoo00<007ooOol06goo00<0
07ooOol0DWoo1000@Goo0@000Goo00000`00Oomoo`0fOol00`00Oomoo`0JOol00`00Oomoo`1>Ool4
001XOol00`00Oomoo`0JOol00`00Oomoo`1>Ool40015Ool10001Ool00003001oogoo03Moo`8001Yo
o`03001oogoo04Yoo`@006eoo`8001Yoo`03001oogoo04Yoo`@004Uoo`40005oo`0000<007ooOol0
>Goo00<007ooOol05goo00<007ooOol0AWoo1000Lgoo00<007ooOol05goo00<007ooOol0AWoo1000
CGoo0@000Goo00000`00Oomoo`0jOol00`00Oomoo`0FOol00`00Oomoo`12Ool4001hOol00`00Oomo
o`0FOol00`00Oomoo`12Ool4001AOol10001Ool00003001oogoo03]oo`8001Ioo`03001oogoo03io
o`@007eoo`8001Ioo`03001oogoo03ioo`@005Eoo`40005oo`0000<007ooOol0?Goo00<007ooOol0
4goo00<007ooOol0>Woo1000Pgoo00<007ooOol04goo00<007ooOol0>Woo1000FGoo0@000Goo0000
0`00Oomoo`0nOol00`00Oomoo`0BOol00`00Oomoo`0fOol40028Ool00`00Oomoo`0BOol00`00Oomo
o`0fOol4001MOol10001Ool00003001oogoo03moo`80019oo`03001oogoo039oo`@008eoo`80019o
o`03001oogoo039oo`@0065oo`40005oo`0000<007ooOol0@Goo00<007ooOol03goo00<007ooOol0
;Woo1000Tgoo00<007ooOol03goo00<007ooOol0;Woo1000IGoo0@000Goo00000`00Oomoo`12Ool0
0`00Oomoo`0>Ool00`00Oomoo`0ZOol4002HOol00`00Oomoo`0>Ool00`00Oomoo`0ZOol4001YOol1
0001Ool00003001oogoo04=oo`8000ioo`03001oogoo02Ioo`@009eoo`8000ioo`03001oogoo02Io
o`@006eoo`40005oo`0000<007ooOol0AGoo00<007ooOol02Woo00<007ooOol08goo1000Xgoo00<0
07ooOol02Woo00<007ooOol08goo1000LGoo0@000Goo00000`00Oomoo`16Ool00`00Oomoo`09Ool0
0`00Oomoo`0OOol4002XOol00`00Oomoo`09Ool00`00Oomoo`0OOol4001eOol10001Ool00003001o
ogoo04Moo`8000Uoo`03001oogoo01]oo`@00:eoo`8000Uoo`03001oogoo01]oo`@007Uoo`40005o
o`0000<007ooOol0BGoo00<007ooOol01Woo00<007ooOol05goo1000/goo00<007ooOol01Woo00<0
07ooOol05goo1000OGoo0@000Goo00000`00Oomoo`1:Ool00`00Oomoo`05Ool00`00Oomoo`0COol4
002hOol00`00Oomoo`05Ool00`00Oomoo`0COol40021Ool10001Ool00003001oogoo04]oo`8000Eo
o`03001oogoo00moo`@00;eoo`8000Eoo`03001oogoo00moo`@008Eoo`40005oo`0000<007ooOol0
CGoo00<007ooOol00Woo00<007ooOol02goo1000`goo00<007ooOol00Woo00<007ooOol02goo1000
RGoo0@000Goo00000`00Oomoo`1>Ool01@00Oomoogoo00002Goo1000b7oo00D007ooOomoo`0000Uo
o`@008eoo`40005oo`0000<007ooOol0Cgoo0P0000=oo`00Ool017oo1000cGoo0P0000=oo`00Ool0
17oo1000TGoo0@000Goo00000`00Oomoo`1AOol200000goo00000002003COol200000goo00000002
002EOol10001Ool00003001oogoo059oo`800=Qoo`8009Uoo`40005oo`0000<007ooOol0ogoob7oo
0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007oo
Ool0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005o
o`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?mo
olQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003
001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool1
0001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomo
o`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo
00000`00Oomoo`2ROol2003HOol20019Ool10001Ool00003001oogoo0:1oo`800003Ool000000=Eo
o`800003Ool0000004Qoo`40005oo`0000<007ooOol0WGoo0`000goo0P00dWoo0`000goo0P00B7oo
0@000Goo00000`00Oomoo`2KOol20006Ool00`00Ool0003?Ool20006Ool00`00Ool00017Ool10001
Ool00003001oogoo09Qoo`<000Qoo`04001oogoo003;Ool30008Ool01000Oomoo`00AWoo0@000Goo
00000`00Oomoo`2FOol2000;Ool01000Oomoo`00bGoo0P002goo00@007ooOol004Ioo`40005oo`00
00<007ooOol0Tgoo0`003Goo00D007ooOomoo`000<Eoo`<000eoo`05001oogooOol00015Ool10001
Ool00003001oogoo091oo`<0015oo`04001oogoo0032Ool3000AOol01000Oomoo`00AGoo0@000Goo
00000`00Oomoo`2>Ool2000DOol01@00Oomoogoo0000_goo0P0057oo00D007ooOomoo`0004Aoo`40
005oo`0000<007ooOol0Rgoo0`005Woo00<007ooOol00Woo00<007ooOol0^Goo0`005Woo00<007oo
Ool00Woo00<007ooOol0@Goo0@000Goo00000`00Oomoo`29Ool2000IOol00`00Oomoo`02Ool00`00
Oomoo`2gOol2000IOol00`00Oomoo`02Ool00`00Oomoo`11Ool10001Ool00003001oogoo08Ioo`<0
01]oo`03001oogoo00=oo`03001oogoo0;=oo`<001]oo`03001oogoo00=oo`03001oogoo041oo`40
005oo`0000<007ooOol0Q7oo0P007Woo00<007ooOol017oo00<007ooOol0/7oo0P007Woo00<007oo
Ool017oo00<007ooOol0?goo0@000Goo00000`00Oomoo`21Ool3000POol00`00Oomoo`04Ool00`00
Oomoo`2]Ool3000POol00`00Oomoo`04Ool00`00Oomoo`0oOol10001Ool00003001oogoo07moo`80
02=oo`03001oogoo00Eoo`03001oogoo0:Yoo`8002=oo`03001oogoo00Eoo`03001oogoo03ioo`40
005oo`0000<007ooOol0O7oo0`009Goo00<007ooOol01Goo00<007ooOol0Ygoo0`009Goo00<007oo
Ool01Goo00<007ooOol0?Woo0@000Goo00000`00Oomoo`1jOol2000XOol00`00Oomoo`06Ool00`00
Oomoo`2TOol2000XOol00`00Oomoo`06Ool00`00Oomoo`0mOol10001Ool00003001oogoo07Moo`<0
02Yoo`03001oogoo00Moo`03001oogoo0:1oo`<002Yoo`03001oogoo00Moo`03001oogoo03aoo`40
005oo`0000<007ooOol0MGoo0P00;Goo00<007ooOol01goo00<007ooOol0WWoo0P00;Goo00<007oo
Ool01goo00<007ooOol0?7oo0@000Goo00000`00Oomoo`1bOol3000_Ool00`00Oomoo`08Ool00`00
Oomoo`2JOol3000_Ool00`00Oomoo`08Ool00`00Oomoo`0kOol10001Ool00003001oogoo06moo`<0
039oo`03001oogoo00Uoo`03001oogoo09Ioo`<0039oo`03001oogoo00Uoo`03001oogoo03Yoo`40
005oo`0000<007ooOol0KGoo0P00=Woo00<007ooOol027oo00<007ooOol0U7oo0P00=Woo00<007oo
Ool027oo00<007ooOol0>Woo0@000Goo00000`00Oomoo`1ZOol3000hOol00`00Oomoo`09Ool00`00
Oomoo`2@Ool3000hOol00`00Oomoo`09Ool00`00Oomoo`0iOol10001Ool00003001oogoo06Qoo`80
03]oo`03001oogoo00Uoo`03001oogoo08ioo`8003]oo`03001oogoo00Uoo`03001oogoo03Uoo`40
005oo`0000<007ooOol0IGoo0`00?Goo00<007ooOol02Woo00<007ooOol0RWoo0`00?Goo00<007oo
Ool02Woo00<007ooOol0>7oo0@000Goo00000`00Oomoo`1SOol20010Ool00`00Oomoo`0;Ool00`00
Oomoo`27Ool20010Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol10001Ool00003001oogoo061oo`<0
049oo`03001oogoo00]oo`03001oogoo08Aoo`<0049oo`03001oogoo00]oo`03001oogoo03Moo`40
005oo`0000<007ooOol0GWoo0P00AGoo00<007ooOol037oo00<007ooOol0PGoo0P00AGoo00<007oo
Ool037oo00<007ooOol0=Woo0@000Goo00000`00Oomoo`1KOol30017Ool00`00Oomoo`0=Ool00`00
Oomoo`1mOol30017Ool00`00Oomoo`0=Ool00`00Oomoo`0eOol10001Ool00003001oogoo05Uoo`80
04Uoo`8000moo`03001oogoo07]oo`8004Yoo`03001oogoo00eoo`03001oogoo03Eoo`40005oo`00
00<007ooOol0EWoo0`00B7oo0`0000=oo`0000003goo00<007ooOol0Mgoo0`00C7oo00<007ooOol0
3Woo00<007ooOol0=7oo0@000Goo00000`00Oomoo`1DOol20019Ool20004Ool2000@Ool00`00Oomo
o`1dOol2001?Ool00`00Oomoo`0?Ool00`00Oomoo`0cOol10001Ool00003001oogoo055oo`<004Qo
o`<000Ioo`03001oo`0000moo`03001oogoo075oo`<0055oo`03001oogoo00moo`03001oogoo03=o
o`40005oo`0000<007ooOol0Cgoo0P00B7oo0`002Goo00@007ooOol000moo`03001oogoo06ioo`80
05Aoo`03001oogoo011oo`03001oogoo039oo`40005oo`0000<007ooOol0C7oo0`00B7oo0P0037oo
00@007ooOol000moo`03001oogoo06]oo`<005Ioo`03001oogoo011oo`03001oogoo039oo`40005o
o`0000<007ooOol0BGoo0`00B7oo0`003goo00@007ooOol000moo`03001oogoo06Moo`<005Yoo`03
001oogoo011oo`03001oogoo035oo`40005oo`0000<007ooOol0Agoo0P00B7oo0`004Woo00D007oo
Oomoo`0000moo`03001oogoo06Aoo`8005eoo`03001oogoo015oo`03001oogoo031oo`40005oo`00
00<007ooOol0A7oo0`00B7oo0P005Goo00<007ooOol00P003goo00<007ooOol0HGoo0`00Ggoo00<0
07ooOol04Goo00<007ooOol0<7oo0@000Goo00000`00Oomoo`12Ool20018Ool3000GOol30002Ool0
0`00Oomoo`0=Ool00`00Oomoo`1NOol2001ROol00`00Oomoo`0BOol00`00Oomoo`0_Ool10001Ool0
0003001oogoo03moo`<004Moo`<001Qoo`<000Eoo`03001oogoo00eoo`03001oogoo05Yoo`<006Ao
o`03001oogoo01=oo`03001oogoo02ioo`40005oo`0000<007ooOol0?Goo0P00B7oo0P0067oo0`00
0Woo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0F7oo0P00Igoo00<007ooOol04goo00<0
07ooOol0;Woo0@000Goo00000`00Oomoo`0jOol30017Ool3000GOol30005Ool00`00Oomoo`04Ool0
0`00Oomoo`0=Ool00`00Oomoo`1DOol3001YOol00`00Oomoo`0DOol00`00Oomoo`0]Ool10001Ool0
0003001oogoo03Qoo`8004Moo`<001Moo`<000Qoo`03001oogoo00Eoo`03001oogoo00aoo`03001o
ogoo059oo`8006aoo`03001oogoo01Aoo`03001oogoo02eoo`40005oo`0000<007ooOol0=Goo0`00
Agoo0P0067oo0P002goo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol0CWoo0`00KWoo00<0
07ooOol05Goo00<007ooOol0;7oo0@000Goo00000`00Oomoo`0cOol20017Ool3000GOol3000=Ool0
0`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`1;Ool2001aOol00`00Oomoo`0FOol00`00Oomo
o`0[Ool10001Ool00003001oogoo031oo`<004Ioo`<001Moo`<0011oo`03001oogoo00Moo`03001o
ogoo00aoo`03001oogoo04Qoo`<007=oo`03001oogoo01Ioo`03001oogoo02]oo`40005oo`0000<0
07ooOol0;Woo0P00Agoo0P005goo0`004goo00<007ooOol01Woo0P003goo00<007ooOol0AGoo0P00
MWoo00<007ooOol05goo00<007ooOol0:Woo0@000Goo00000`00Oomoo`0[Ool30016Ool3000GOol2
000FOol00`00Oomoo`03Ool30002Ool00`00Oomoo`0=Ool00`00Oomoo`11Ool3001hOol00`00Oomo
o`0HOol00`00Oomoo`0YOol10001Ool00003001oogoo02Qoo`<004Ioo`<001Moo`<001Qoo`04001o
ogooOol20006Ool00`00Oomoo`0<Ool00`00Oomoo`0nOol3001kOol00`00Oomoo`0HOol00`00Oomo
o`0YOol10001Ool00003001oogoo02Ioo`8004Moo`8001Moo`<001aoo`<000Qoo`03001oogoo00eo
o`03001oogoo03]oo`8007moo`03001oogoo01Qoo`03001oogoo02Qoo`40005oo`0000<007ooOol0
8goo0`00AWoo0`005Woo0`0077oo10002goo00<007ooOol03Goo00<007ooOol0=goo0`00PGoo00<0
07ooOol06Goo00<007ooOol09goo0@000Goo00000`00Oomoo`0QOol20016Ool3000GOol2000LOol3
0003Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0eOol20024Ool00`00Oomoo`0IOol0
0`00Oomoo`0WOol10001Ool00003001oogoo01ioo`<004Ioo`8001Moo`<001]oo`<000Ioo`03001o
ogoo00Yoo`03001oogoo00eoo`03001oogoo035oo`<008Ioo`03001oogoo01Yoo`03001oogoo02Io
o`40005oo`0000<007ooOol077oo0P00AWoo0`005Woo0`0077oo0P002Goo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol0;goo0P00RGoo00<007ooOol06Woo00<007ooOol09Woo0@000Goo0000
0`00Oomoo`0JOol20015Ool3000FOol3000LOol3000;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool0
0`00Oomoo`0/Ool2002;Ool00`00Oomoo`0KOol00`00Oomoo`0UOol10001Ool00003001oogoo01Yo
o`80049oo`<001Moo`8001aoo`<000ioo`03001oogoo00aoo`03001oogoo00eoo`03001oogoo02]o
o`8008]oo`03001oogoo01aoo`03001oogoo02Aoo`40005oo`0000<007ooOol06Woo00<007oo0000
?goo0P005goo0`006goo0`004Goo00<007ooOol03Goo00<007ooOol037oo00<007ooOol0:goo00<0
07oo0000RWoo00<007ooOol077oo00<007ooOol097oo0@000Goo00000`00Oomoo`0JOol01000Oomo
o`00>goo0`005Woo0`0077oo0P0057oo00<007ooOol03Woo00<007ooOol037oo00<007ooOol0:Woo
00@007ooOol008Uoo`03001oogoo01eoo`03001oogoo02=oo`40005oo`0000<007ooOol06Goo00<0
07ooOol00Woo00<007ooOol0=Goo0`005Woo0`0077oo0`005Woo00<007ooOol03Woo00<007ooOol0
3Goo00<007ooOol0:7oo00<007ooOol00Woo00<007ooOol0QWoo00<007ooOol07Woo00<007ooOol0
8Woo0@000Goo00000`00Oomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`0bOol2000GOol2000LOol3
000IOol00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0XOol00`00Oomoo`03Ool00`00Oomo
o`25Ool00`00Oomoo`0NOol00`00Oomoo`0ROol10001Ool00003001oogoo01Uoo`03001oogoo00Ao
o`03001oogoo02ioo`<001Ioo`<001]oo`<001aoo`03001oogoo011oo`03001oogoo00aoo`03001o
ogoo02Moo`03001oogoo00Aoo`03001oogoo08Aoo`03001oogoo01moo`03001oogoo025oo`40005o
o`0000<007ooOol06Goo00<007ooOol01Goo00<007ooOol0:Woo0`005Woo0`0077oo0P007goo00<0
07ooOol047oo00<007ooOol037oo00<007ooOol09goo00<007ooOol01Goo00<007ooOol0Pgoo00<0
07ooOol07goo00<007ooOol08Goo0@000Goo00000`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomo
o`0WOol2000FOol3000LOol3000QOol00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`0VOol0
0`00Oomoo`06Ool00`00Oomoo`22Ool00`00Oomoo`0POol00`00Oomoo`0POol10001Ool00003001o
ogoo01Uoo`03001oogoo00Moo`03001oogoo02=oo`<001Eoo`<001aoo`<002Eoo`03001oogoo015o
o`03001oogoo00aoo`03001oogoo02Eoo`03001oogoo00Moo`03001oogoo089oo`03001oogoo021o
o`03001oogoo01moo`40005oo`0000<007ooOol06Goo00<007ooOol027oo00<007ooOol07goo0`00
5Woo0P0077oo0`00:7oo00<007ooOol04Goo00<007ooOol037oo00<007ooOol09Goo00<007ooOol0
27oo00<007ooOol0<Goo10000Woo10000Woo200000=oo`000000100000Aoo`000000035oo`03001o
ogoo021oo`03001oogoo01moo`40005oo`0000<007ooOol067oo00<007ooOol02Woo00<007ooOol0
77oo0P005Woo0`006goo0`00:goo00<007ooOol04Woo00<007ooOol037oo00<007ooOol08goo00<0
07ooOol02Woo00<007ooOol0;goo0P000goo00<007ooOol00P000Woo0P0000=oo`0000000Woo0P00
00=oo`0000000Woo0P0000=oo`000000<Woo00<007ooOol08Goo00<007ooOol07Woo0@000Goo0000
0`00Oomoo`0HOol00`00Oomoo`0;Ool00`00Oomoo`0HOol3000EOol3000LOol2000^Ool00`00Oomo
o`0COol00`00Oomoo`0<Ool00`00Oomoo`0ROol00`00Oomoo`0;Ool00`00Oomoo`0]Ool20007Ool2
0003Ool01000Ool000000Woo0P0000=oo`0000000Woo0P0000=oo`000000<Woo00<007ooOol08Woo
00<007ooOol07Goo0@000Goo00000`00Oomoo`0HOol00`00Oomoo`0<Ool00`00Oomoo`0DOol3000E
Ool3000LOol3000`Ool00`00Oomoo`0COol00`00Oomoo`0<Ool00`00Oomoo`0ROol00`00Oomoo`0<
Ool00`00Oomoo`0/Ool20007Ool20004Ool30002Ool200000goo00000002Ool4000cOol00`00Oomo
o`0ROol00`00Oomoo`0MOol10001Ool00003001oogoo01Qoo`03001oogoo00eoo`03001oogoo015o
o`8001Ioo`8001aoo`<003=oo`03001oogoo01Aoo`03001oogoo00aoo`03001oogoo025oo`03001o
ogoo00eoo`03001oogoo02]oo`8000Moo`800005Ool00000001oo`020002Ool200000goo00000002
Ool200000goo001oo`0bOol00`00Oomoo`0SOol00`00Oomoo`0LOol10001Ool00003001oogoo01Qo
o`03001oogoo00ioo`03001oogoo00eoo`<001Eoo`<001]oo`<003Ioo`03001oogoo01Eoo`03001o
ogoo00]oo`03001oogoo025oo`03001oogoo00ioo`03001oogoo02Yoo`8000Ioo`D00004Ool00000
0002Ool50003Ool2000017oo00000000<Goo00<007ooOol08goo00<007ooOol077oo0@000Goo0000
0`00Oomoo`0HOol00`00Oomoo`0?Ool00`00Oomoo`09Ool3000EOol3000LOol2000iOol00`00Oomo
o`0EOol00`00Oomoo`0<Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`0YOol20004Ool0
0`00Oomoo`0BOol2000eOol00`00Oomoo`0TOol00`00Oomoo`0KOol10001Ool00003001oogoo01Qo
o`03001oogoo011oo`03001oogoo00Ioo`8001Eoo`<001aoo`<003]oo`03001oogoo01Ioo`03001o
ogoo00aoo`03001oogoo01moo`03001oogoo011oo`03001oogoo02Uoo`80009oo`8001Aoo`8003Eo
o`03001oogoo02Eoo`03001oogoo01Yoo`40005oo`0000<007ooOol05goo00<007ooOol04Woo00<0
07ooOol00Woo0`005Goo0P0077oo0`00?Woo00<007ooOol05goo00<007ooOol02goo00<007ooOol0
7Woo00<007ooOol04Woo00<007ooOol0:Goo0`0000=oo`00Ool04Woo0`00=Goo00<007ooOol09Goo
00<007ooOol06Woo0@000Goo00000`00Oomoo`0GOol00`00Oomoo`0COol4000EOol3000KOol30011
Ool00`00Oomoo`0GOol00`00Oomoo`0;Ool2000OOol00`00Oomoo`0COol00`00Oomoo`1hOol00`00
Oomoo`0UOol2000KOol10001Ool00003001oogoo01Moo`03001oogoo019oo`<001Aoo`<001]oo`<0
04Aoo`03001oogoo01Qoo`03001oogoo00Moo`<00003Ool007oo01ioo`03001oogoo01Aoo`03001o
ogoo07Moo`03001oogoo029oo`<00003Ool007oo01Yoo`40005oo`0000<007ooOol05goo00<007oo
Ool03goo0`000goo1@0037oo0`001Woo0`004goo0P00Agoo00<007ooOol06Goo00<007ooOol00goo
0`0017oo00<007ooOol07Goo00<007ooOol05Goo00<007ooOol0MWoo00<007ooOol07goo0`0017oo
00<007ooOol06Goo0@000Goo00000`00Oomoo`0GOol00`00Oomoo`0=Ool20007Ool2000<Ool20008
Ool7000=Ool30019Ool00`00Oomoo`0IOol00`00Oomoo`030007Ool00`00Oomoo`0MOol00`00Oomo
o`0FOol00`00Oomoo`1eOol00`00Oomoo`0LOol30007Ool00`00Oomoo`0IOol10001Ool00003001o
ogoo01Moo`03001oogoo00eoo`8000Qoo`03001oogoo00Moo`<000aoo`@000]oo`<004eoo`03001o
ogoo01Qoo`<000]oo`03001oogoo01aoo`03001oogoo01Moo`03001oogoo07Eoo`03001oogoo01Qo
o`<000]oo`03001oogoo01Qoo`40005oo`0000<007ooOol05goo00<007ooOol03Goo00<007oo0000
1goo0P001Goo0`003Goo0P0000=oo`0000002Goo0`00D7oo00<007ooOol05Goo0`000Woo00<007oo
Ool02Goo00<007ooOol077oo00<007ooOol067oo00<007ooOol0M7oo00<007ooOol05Goo0`003Woo
00<007ooOol067oo0@000Goo00000`00Oomoo`0FOol00`00Oomoo`0>Ool01000Oomoo`001Woo00@0
07oo001oo`<000eoo`<0009oo`8000Qoo`8005=oo`03001oogoo019oo`<000Eoo`03001oogoo00Uo
o`03001oogoo01]oo`03001oogoo01Yoo`03001oogoo07=oo`03001oogoo019oo`<0015oo`03001o
ogoo01Qoo`40005oo`0000<007ooOol05Woo00<007ooOol03Woo00D007ooOomoo`0000Aoo`800003
Ool0000000eoo`<000Aoo`03001oogoo00Eoo`<005Eoo`03001oogoo00ioo`@000Uoo`03001oogoo
00Qoo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo079oo`03001oogoo00ioo`@001Aoo`03
001oogoo01Qoo`40005oo`0000<007ooOol05Woo00<007ooOol03Goo00<007ooOol00goo00@007oo
Oomoo`<0009oo`03001oogoo00Moo`<000aoo`<005Qoo`03001oogoo00]oo`<000ioo`03001oogoo
00Moo`03001oogoo01]oo`03001oogoo01aoo`03001oogoo075oo`03001oogoo00]oo`<001Qoo`03
001oogoo01Qoo`40005oo`0000<007ooOol05Woo00<007ooOol03Goo00<007ooOol017oo0`001Woo
00<007ooOol00goo0`0037oo0`000Woo00@007ooOol005Eoo`03001oogoo00Qoo`<0015oo`03001o
ogoo00Moo`03001oogoo01]oo`03001oogoo01eoo`03001oogoo071oo`03001oogoo00Qoo`<001]o
o`03001oogoo01Qoo`40005oo`0000<007ooOol05Woo00<007ooOol03Goo00<007ooOol01Goo00<0
07ooOol01Woo00<007ooOol00P003Goo0P001Woo0P00EWoo00<007ooOol01Goo0`0057oo0P0027oo
00<007ooOol06goo00<007ooOol07Woo00<007ooOol0Kgoo00<007ooOol01Goo0`007Woo00<007oo
Ool067oo0@000Goo00000`00Oomoo`0FOol00`00Oomoo`0=Ool00`00Oomoo`06Ool00`00Oomoo`05
Ool3000<Ool30008Ool2001FOol00`00Oomoo`02Ool3000DOol3000:Ool00`00Oomoo`0KOol00`00
Oomoo`0OOol2001_Ool00`00Oomoo`02Ool3000QOol00`00Oomoo`0HOol10001Ool00003001oogoo
01Ioo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo009oo`8000=oo`03001oogoo00Ioo`<0
00Yoo`04001oogoo001EOol00`00Ool00002000DOol3000>Ool00`00Oomoo`0JOol00`00Oomoo`0Q
Ool00`00Oomoo`1/Ool00`00Ool00002000UOol00`00Oomoo`0GOol10001Ool00003001oogoo01Eo
o`03001oogoo00ioo`03001oogoo00Qoo`04001oogooOol20004Ool00`00Oomoo`02Ool3001UOol3
000DOol3000AOol00`00Oomoo`0IOol00`00Oomoo`0SOol00`00Oomoo`1ZOol3000XOol00`00Oomo
o`0GOol10001Ool00003001oogoo01Eoo`03001oogoo00ioo`03001oogoo00Uoo`800004Ool007oo
0004Ool4001UOol300000goo001oo`0@Ool4000DOol00`00Oomoo`0IOol00`00Oomoo`0TOol00`00
Oomoo`1VOol300000goo001oo`0XOol00`00Oomoo`0GOol10001Ool00003001oogoo01Eoo`03001o
ogoo00ioo`03001oogoo00]oo`80009oo`03001oogoo00<006Aoo`<000Aoo`03001oogoo00aoo`<0
01Qoo`03001oogoo01Uoo`03001oogoo02Eoo`03001oogoo069oo`<000Aoo`03001oogoo02Moo`03
001oogoo01Moo`40005oo`0000<007ooOol05Goo00<007ooOol03Woo00<007ooOol037oo00<007oo
Ool00`000goo00<007ooOol0GWoo0`001goo00<007ooOol02Goo0`006goo00<007ooOol06Goo00<0
07ooOol09Woo00<007ooOol0GWoo0`001goo00<007ooOol09goo00<007ooOol05goo0@000Goo0000
0`00Oomoo`0EOol00`00Oomoo`0=Ool00`00Oomoo`0=Ool30002Ool00`00Oomoo`02Ool00`00Oomo
o`1JOol3000:Ool00`00Oomoo`06Ool3000NOol00`00Oomoo`0IOol00`00Oomoo`0WOol00`00Oomo
o`1JOol3000:Ool00`00Oomoo`0WOol00`00Oomoo`0GOol10001Ool00003001oogoo01Eoo`03001o
ogoo00eoo`03001oogoo00aoo`04001oogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`1FOol3000>
Ool00`00Oomoo`02Ool3000QOol00`00Oomoo`0IOol00`00Oomoo`0XOol00`00Oomoo`1FOol3000>
Ool00`00Oomoo`0VOol00`00Oomoo`0GOol10001Ool00003001oogoo01Eoo`03001oogoo00eoo`03
001oogoo00aoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`1BOol3000AOol00`00
Ool00002000UOol00`00Oomoo`0HOol00`00Oomoo`0YOol00`00Oomoo`1BOol3000AOol00`00Oomo
o`0WOol00`00Oomoo`0FOol10001Ool00003001oogoo01Aoo`03001oogoo00ioo`03001oogoo00ao
o`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`1=Ool4000COol3000XOol00`00Oomo
o`0GOol00`00Oomoo`0[Ool00`00Oomoo`1=Ool4000DOol00`00Oomoo`0WOol00`00Oomoo`0FOol1
0001Ool00003001oogoo01Aoo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo00=oo`05001o
ogooOol00004Ool00`00Oomoo`19Ool3000COol400000goo001oo`0XOol00`00Oomoo`0GOol00`00
Oomoo`0/Ool00`00Oomoo`19Ool3000HOol00`00Oomoo`0WOol00`00Oomoo`0FOol10001Ool00003
001oogoo01Aoo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo00Aoo`05001oogooOol00002
Ool00`00Ool00017Ool3000COol30005Ool00`00Oomoo`0WOol00`00Oomoo`0GOol00`00Oomoo`0]
Ool00`00Oomoo`15Ool3000KOol00`00Oomoo`0WOol00`00Oomoo`0FOol10001Ool00003001oogoo
01Aoo`03001oogoo00ioo`03001oogoo00aoo`03001oogoo00Eoo`07001oogooOol007oo00000Woo
00<007ooOol0@Goo0`004goo0`0027oo00<007ooOol09goo00<007ooOol05goo00<007ooOol0;Woo
00<007ooOol0@Goo0`007Woo00<007ooOol09goo00<007ooOol05Woo0@000Goo00000`00Oomoo`0D
Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool02000Oomoogoo001oo`00Ool2000o
Ool3000COol3000:Ool2000YOol00`00Oomoo`0GOol00`00Oomoo`0_Ool00`00Oomoo`0mOol3000P
Ool2000YOol00`00Oomoo`0FOol10001Ool00003001oogoo01Aoo`03001oogoo00ioo`03001oogoo
00aoo`03001oogoo00Moo`04001oogooOol2000017oo001oo`00>goo0`004goo0`002Woo0`000Woo
00<007ooOol09Woo00<007ooOol05goo00<007ooOol0<7oo00<007ooOol0>Goo0`0087oo0`000Woo
00<007ooOol09Woo00<007ooOol05Woo0@000Goo00000`00Oomoo`0DOol00`00Oomoo`0=Ool00`00
Oomoo`0=Ool00`00Oomoo`08Ool3000017oo000000000Woo00<007ooOol0=Goo0`004goo0`002Goo
10001Woo00<007ooOol09Goo00<007ooOol05goo00<007ooOol0<Goo00<007ooOol0=Goo0`007goo
10001Woo00<007ooOol09Goo00<007ooOol05Woo0@000Goo00000`00Oomoo`0COol00`00Oomoo`0>
Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Ool000030003Ool00`00Oomoo`0aOol3000COol3
0009Ool3000:Ool00`00Oomoo`0VOol00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomoo`0aOol3
000OOol3000:Ool00`00Oomoo`0VOol00`00Oomoo`0EOol10001Ool00003001oogoo01=oo`03001o
ogoo00ioo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo008000Aoo`03001oogoo02eoo`<0
01=oo`<000Uoo`<000ioo`03001oogoo02Eoo`03001oogoo01Eoo`03001oogoo03Aoo`03001oogoo
02eoo`<001moo`<000ioo`03001oogoo02Eoo`03001oogoo01Eoo`40005oo`0000<007ooOol04goo
00<007ooOol03Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0:Goo
0`004Woo10002Goo0`004Woo00<007ooOol097oo00<007ooOol05Goo00<007ooOol0=Goo00<007oo
Ool0:Goo0`007goo0`004Woo00<007ooOol097oo00<007ooOol05Goo0@000Goo00000`00Oomoo`0C
Ool00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`06
Ool00`00Oomoo`0UOol3000BOol3000:Ool3000FOol00`00Oomoo`0SOol00`00Oomoo`0EOol00`00
Oomoo`0fOol00`00Oomoo`0UOol3000OOol3000FOol00`00Oomoo`0SOol00`00Oomoo`0EOol10001
Ool00003001oogoo01=oo`03001oogoo00ioo`03001oogoo00Yoo`05001oo`00Ool0000>Ool00`00
Oomoo`06Ool00`00Oomoo`0QOol3000BOol30009Ool4000IOol00`00Oomoo`0SOol00`00Oomoo`0E
Ool00`00Oomoo`0gOol00`00Oomoo`0QOol3000NOol4000IOol00`00Oomoo`0SOol00`00Oomoo`0E
Ool10001Ool00003001oogoo01=oo`03001oogoo00ioo`03001oogoo00Yoo`<00003Ool007oo00io
o`04001oo`000005Ool00`00Oomoo`0MOol3000BOol30009Ool3000NOol00`00Oomoo`0ROol00`00
Oomoo`0EOol00`00Oomoo`0XOol2000>Ool00`00Oomoo`0MOol3000NOol3000NOol00`00Oomoo`0R
Ool00`00Oomoo`0EOol10001Ool00003001oogoo01=oo`03001oogoo00ioo`03001oogoo00Yoo`D0
011oo`03001oo`0000Ioo`03001oogoo01Qoo`@0019oo`<000Uoo`<0029oo`03001oogoo025oo`03
001oogoo01Eoo`03001oogoo02Eoo`<0009j/08000eoo`03001oogoo01Qoo`@001ioo`<0029oo`03
001oogoo025oo`03001oogoo01Eoo`40005oo`0000<007ooOol04goo00<007ooOol03Woo00<007oo
Ool02goo0`004Woo0P001goo00<007ooOol057oo0`004goo0`002Goo0`009Woo00<007ooOol08Goo
00<007ooOol057oo00<007ooOol08goo0`001WZ`0P0037oo00<007ooOol057oo0`007goo0`009Woo
00<007ooOol08Goo00<007ooOol057oo0@000Goo00000`00Oomoo`0BOol00`00Oomoo`0>Ool00`00
Oomoo`0<Ool3000BOol30007Ool00`00Oomoo`0@Ool3000COol30009Ool3000YOol00`00Oomoo`0Q
Ool00`00Oomoo`0COol00`00Oomoo`0ROol3000:N[02000;Ool00`00Oomoo`0@Ool3000OOol3000Y
Ool00`00Oomoo`0QOol00`00Oomoo`0DOol10001Ool00003001oogoo019oo`03001oogoo00ioo`03
001oogoo00eoo`03001oogoo015oo`04001oo`000007Ool00`00Oomoo`0<Ool3000BOol40008Ool4
000]Ool00`00Oomoo`0POol00`00Oomoo`0COol00`00Oomoo`0POol3000>N[02000:Ool00`00Oomo
o`0<Ool3000NOol4000]Ool00`00Oomoo`0POol00`00Oomoo`0DOol10001Ool00003001oogoo019o
o`03001oogoo00ioo`03001oogoo021oo`800004Ool000000007Ool00`00Oomoo`08Ool3000BOol3
0009Ool3000bOol00`00Oomoo`0OOol00`00Oomoo`0COol00`00Oomoo`0NOol200000cR[001j/00@
N[020009Ool00`00Oomoo`08Ool3000NOol3000bOol00`00Oomoo`0OOol00`00Oomoo`0DOol10001
Ool00003001oogoo019oo`03001oogoo00ioo`03001oogoo02Ioo`03001oogoo00Eoo`03001oogoo
00Aoo`<0019oo`<000Uoo`<003Ioo`03001oogoo01ioo`03001oogoo01=oo`03001oogoo01ioo`8h
Z`03001j/7Z`019j/003001oogoo00Moo`03001oogoo00Aoo`<001ioo`<003Ioo`03001oogoo01io
o`03001oogoo01Aoo`40005oo`0000<007ooOol04Woo00<007ooOol03Woo00<007ooOol09goo00<0
07ooOol01Goo00<007ooOol00`004Woo0`002Goo0`00>Woo00<007ooOol07Goo00<007ooOol04goo
00<007ooOol07Goo00@003R[>:/001Aj/003001oogoo00Qoo`03001oogoo00<001ioo`<003Yoo`03
001oogoo01eoo`03001oogoo01Aoo`40005oo`0000<007ooOol04Woo00<007ooOol03Woo00<007oo
Ool0:7oo00<007ooOol01Goo0P004Woo0`002Goo0`00?Goo00<007ooOol07Goo00<007ooOol04goo
00<007ooOol07Goo00@003R[>:/001Ej/003001oogoo00Qoo`8001ioo`<003eoo`03001oogoo01eo
o`03001oogoo01Aoo`40005oo`0000<007ooOol04Woo00<007ooOol03Woo00<007ooOol0:Goo00<0
07ooOol017oo00<007ooOol03Woo0`0027oo1000@Goo00<007ooOol077oo00<007ooOol04goo00<0
07ooOol077oo00@003R[>:/001Mj/003001oogoo00Moo`03001oogoo01Uoo`@0045oo`03001oogoo
01aoo`03001oogoo01Aoo`40005oo`0000<007ooOol04Goo00<007ooOol03goo00<007ooOol03Woo
100067oo00<007ooOol00goo00<007ooOol02goo0`0027oo0`00AWoo00<007ooOol077oo00<007oo
Ool04Goo00<007ooOol07Goo00@003R[>:/001Mj/003001oogoo00Moo`03001oogoo01Ioo`<004Io
o`03001oogoo01aoo`03001oogoo01=oo`40005oo`0000<007ooOol04Goo00<007ooOol03Woo00<0
07ooOol047oo00<007oo00006Goo00<007ooOol00Woo00<007ooOol01goo100027oo0`00BWoo00<0
07ooOol06goo00<007ooOol04Goo00<007ooOol07Goo00@003R[>:/001Qj/003001oogoo00Ioo`03
001oogoo01=oo`<004Yoo`03001oogoo01]oo`03001oogoo01=oo`40005oo`0000<007ooOol04Goo
00<007ooOol03Woo00<007ooOol03goo00<007oo00006goo00D007ooOomoo`0000Ioo`<000Uoo`<0
04eoo`03001oogoo01]oo`03001oogoo015oo`03001oogoo01aoo`05000hZcR[>:/0000IN[000`00
Oomoo`05Ool00`00Oomoo`0@Ool3001=Ool00`00Oomoo`0KOol00`00Oomoo`0COol10001Ool00003
001oogoo015oo`03001oogoo00ioo`03001oogoo00moo`@001]oo`04001oogoo0003Ool300000goo
001oo`06Ool30003Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0^Ool00`00Oomoo`0J
Ool00`00Oomoo`0AOol00`00Oomoo`0LOol01000>:/hZ`006gZ`00<007ooOol017oo00<007ooOol0
3Goo0`00DGoo00<007ooOol06Woo00<007ooOol04goo0@000Goo00000`00Oomoo`0AOol00`00Oomo
o`0>Ool00`00Oomoo`0_Ool00`00Ool000030003Ool00`00Oomoo`0600000goo001oo`03Ool00`00
Oomoo`050002Ool00`00Oomoo`02Ool00`00Oomoo`05000017oo000000000goo00<007ooOol0;Woo
00<007ooOol06Goo00<007ooOol04Goo00<007ooOol077oo00@003R[>:/001]j/003001oogoo00Ao
o`03001oogoo00Uoo`@005Eoo`03001oogoo01Uoo`03001oogoo01=oo`40005oo`0000<007ooOol0
4Goo00<007ooOol03Woo00<007ooOol0<7oo0P001Woo00<007oo00000`000goo00<007oo000017oo
00D007ooOomoo`0000=oo`03001oo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00
Oomoo`0_Ool00`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`0KOol01@00>:/hZcR[000077Z`
00<007ooOol00goo00@007ooOol000Eoo`@000Uoo`03001oogoo00Ioo`03001oogoo04Aoo`03001o
ogoo01Qoo`03001oogoo01=oo`40005oo`0000<007ooOol04Goo00<007ooOol03Woo00<007ooOol0
<7oo0P001Goo0`000goo00L007ooOomoo`00Ool00008Ool01`00Oomoogoo001oo`0000Qoo`03001o
ogoo009oo`03001oogoo009oo`80035oo`03001oogoo01Moo`03001oogoo015oo`03001oogoo01]o
o`04000hZcR[000NN[000`00Oomoo`02Ool00`00Ool00003Ool30003Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`14Ool00`00Oomoo`0GOol00`00
Oomoo`0COol10001Ool00003001oogoo011oo`03001oogoo00moo`03001oogoo031oo`80009oo`<0
0003Ool007oo00=oo`07001oogooOol007oo000027oo00L007ooOomoo`00Ool00008Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0`Ool00`00Oomoo`0HOol00`00Oomoo`0?Ool00`00Oomo
o`0KOol00`00>:/hZ`02000NN[000`00Oomoo`02Ool00`00Ool0000400000goo001oo`03Ool01P00
Oomoo`00Ool000Aoo`06001oogoo001oo`000goo00<007ooOol0A7oo00<007ooOol067oo00<007oo
Ool04Woo0@000Goo00000`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0`Ool40004Ool00`00
Oomoo`02Ool01`00Oomoogoo001oo`0000Qoo`07001oogooOol007oo000027oo00L007ooOomoo`00
Ool00003Ool00`00Oomoo`0aOol00`00Oomoo`0GOol00`00Oomoo`0?Ool00`00Oomoo`0KOol30000
0dVc001j/00NN[001000Oomoogoo0`000goo00<007oo00001goo00<007oo00001goo00<007oo0000
0goo0P00AWoo00<007ooOol05goo00<007ooOol04Woo0@000Goo00000`00Oomoo`0@Ool00`00Oomo
o`0?Ool00`00Oomoo`0]Ool40008Ool00`00Oomoo`020004Ool00`00Oomoo`06Ool20004Ool00`00
Oomoo`06Ool20004Ool01@00Oomoogoo0000=Goo00<007ooOol05Woo00<007ooOol03goo00<007oo
Ool06goo00D004VcBK=9/`0001mj/0@0009oo`03001oogoo009oo`03001oogoo00Ioo`03001oo`00
00Moo`03001oo`0000=oo`03001oogoo04Ioo`03001oogoo01Ioo`03001oogoo019oo`40005oo`00
00<007ooOol047oo00<007ooOol03Woo00<007ooOol0:goo0`000goo00<007ooOol0J7oo00<007oo
Ool05Goo00<007ooOol03goo00<007ooOol06goo00D004VcBK=9/`0001aj/0<00004N[0007oo0002
Ool01`00Oomoogoo001oo`0000Moo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo04Moo`03
001oogoo01Eoo`03001oogoo019oo`40005oo`0000<007ooOol047oo00<007ooOol03Woo00<007oo
Ool0:7oo0`001Woo00<007ooOol0J7oo00<007ooOol05Goo00<007ooOol03goo00<007ooOol06goo
00D004VcBK=9/`0001Uj/0<000Aj/003001oo`0000=oo`05001oogooOol00009Ool00`00Oomoo`07
Ool01@00Oomoogoo0000BWoo00<007ooOol05Goo00<007ooOol04Woo0@000Goo00000`00Oomoo`0@
Ool00`00Oomoo`0>Ool00`00Oomoo`0UOol30009Ool00`00Oomoo`1YOol00`00Oomoo`0DOol00`00
Oomoo`0?Ool00`00Oomoo`0KOol01@00BK=9/dVc00005WZ`0`001gZ`00<007oo0000Jgoo00<007oo
Ool057oo00<007ooOol04Woo0@000Goo00000`00Oomoo`0@Ool00`00Oomoo`0>Ool00`00Oomoo`0R
Ool3000<Ool00`00Oomoo`1ZOol00`00Oomoo`0COol00`00Oomoo`0?Ool00`00Oomoo`0LOol01000
BK=9/`004gZ`0`002gZ`0P00K7oo00<007ooOol04goo00<007ooOol04Woo0@000Goo00000`00Oomo
o`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0NOol4000?Ool00`00Oomoo`1[Ool00`00Oomoo`0BOol0
0`00Oomoo`0>Ool00`00Oomoo`0MOol01000BK=9/`003gZ`10003WZ`0P00KGoo00<007ooOol04Woo
00<007ooOol04Woo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0KOol3000C
Ool00`00Oomoo`1[Ool00`00Oomoo`0COol00`00Oomoo`0=Ool00`00Oomoo`0MOol01000BK=9/`00
37Z`0`004WZ`0P00KGoo00<007ooOol04goo00<007ooOol04Goo0@000Goo00000`00Oomoo`0?Ool0
0`00Oomoo`0?Ool00`00Oomoo`0HOol3000FOol00`00Oomoo`0>Ool2001LOol00`00Oomoo`0BOol0
0`00Oomoo`0=Ool00`00Oomoo`0MOol01000BK=9/`002GZ`0`000gZ`0`0047Z`00<007ooOol0K7oo
00<007ooOol04Woo00<007ooOol04Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00
Oomoo`0EOol3000HOol2000=Ool3001OOol00`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`0M
Ool01@00BK=9/dVc00001GZ`0`001WZ`00<007Z`N[0047Z`00<007ooOol0KGoo00<007ooOol04Goo
00<007ooOol04Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0BOol30002
Ool30002Ool5000?Ool2000:Ool3001SOol00`00Oomoo`0@Ool00`00Oomoo`0=Ool00`00Oomoo`0M
Ool01@00BK=9/dVc00000WZ`0`002WZ`00<007Z`N[0047Z`00<007ooOol00`00JWoo00<007ooOol0
47oo00<007ooOol04Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool4
0006Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool20006Ool40009Ool30003Ool3001EOol00`00Oomo
o`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0MOol00`00BK=9/`04000=N[000`00N[1j/00@N[000`00
Ool00006001XOol00`00Oomoo`0?Ool00`00Oomoo`0AOol10001Ool00003001oogoo00moo`03001o
ogoo00ioo`03001oogoo00aoo`<000Yoo`<000=oo`03001oogoo00moo`8000=oo`<000ioo`03001o
ogoo009oo`03001oogoo05Eoo`03001oogoo00moo`03001oogoo00eoo`03001oogoo01eoo`<00003
BK<007Z`00ej/003001j/000015j/004001oogooOol4001YOol00`00Oomoo`0?Ool00`00Oomoo`0A
Ool10001Ool00003001oogoo00ioo`03001oogoo00moo`03001oogoo00Uoo`<000eoo`04001oogoo
0002Ool00`00Oomoo`0?Ool5000AOol30003Ool00`00Oomoo`1EOol00`00Oomoo`0>Ool00`00Oomo
o`0<Ool00`00Oomoo`0KOol40003BK<00`00N[1j/00=N[000`00N[1j/00@N[060009Ool30002Ool5
001IOol00`00Oomoo`0>Ool00`00Oomoo`0AOol10001Ool00003001oogoo00ioo`03001oogoo00mo
o`03001oogoo00Ioo`<0011oo`04001oogoo0002Ool00`00Oomoo`0>Ool3000DOol01000Oomoo`00
0Woo00<007ooOol0EWoo00<007ooOol03Woo00<007ooOol02goo00<007ooOol067oo0`000goo00D0
04VcBK=9/`0001mj/0<00004N[0007oo000<Ool00`00Oomoo`03Ool00`00Oomoo`1JOol00`00Oomo
o`0>Ool00`00Oomoo`0@Ool10001Ool00003001oogoo00ioo`03001oogoo00moo`03001oogoo00=o
o`<0019oo`@0009oo`8000eoo`<00003Ool0000001Aoo`08001oogoo001oo`00Ool005Qoo`03001o
ogoo00eoo`03001oogoo00]oo`03001oogoo01Eoo`<000Moo`040019/dVc000LN[030004N[000`00
Oomoo`0<Ool30003Ool00`00Oomoo`1KOol00`00Oomoo`0=Ool00`00Oomoo`0@Ool10001Ool00003
001oogoo00ioo`03001oogoo00moo`03001oo`0000<002Ioo`@000Aoo`8001=oo`@000=oo`03001o
ogoo05Moo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo015oo`@000Yoo`040019/dVc000H
N[040008N[000`00Oomoo`0;Ool01000Oomoo`000Woo00<007ooOol0Fgoo00<007ooOol03Goo00<0
07ooOol047oo0@000Goo00000`00Oomoo`0>Ool00`00Oomoo`0>Ool3000WOol30008Ool2001eOol0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0>Ool3000>Ool01000BK=9/`005GZ`0`0037Z`
00<007ooOol017oo00@007ooOol000=oo`04001oogoo0002Ool00`00Oomoo`1LOol00`00Oomoo`0<
Ool00`00Oomoo`0@Ool10001Ool00003001oogoo00ioo`03001oogoo00]oo`<00003Ool007oo02Eo
o`8000]oo`8007Ioo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`<0015oo`040019
/`00000CN[02000?N[000`00Oomoo`05Ool20003Ool40002Ool2001OOol00`00Oomoo`0;Ool00`00
Oomoo`0@Ool10001Ool00003001oogoo00ioo`03001oogoo00Qoo`<000Aoo`03001oogoo035oo`80
07Moo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Qoo`<001Aoo`800003CSL007Z`019j
/08000mj/003001oogoo00Eoo`8006]oo`03001oogoo00Yoo`03001oogoo011oo`40005oo`0000<0
07ooOol03Goo00<007ooOol01Woo0`001Woo00<007ooOol0<Woo0P00N7oo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol01Woo0`005goo00D004hgCSM>=`00019j/003001j/00000ij/003001o
ogoo00Aoo`04001oogoo001[Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool10001Ool00003001oogoo
00eoo`03001oogoo009oo`@000Uoo`03001oogoo039oo`8007Qoo`03001oogoo00Uoo`03001oogoo
00Yoo`03001oogoo009oo`@001]oo`04001>=dhg000BN[000`00N[1j/002000<N[000`00Oomoo`1c
Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool10001Ool00003001oogoo00eoo`03001oo`00008000eo
o`03001oogoo039oo`03001oogoo02aoo`@0009oo`@0009oo`<000Aoo`P00005Ool00000001oo`05
000WOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Ool00002000OOol01000CSM>=`004WZ`00<0
07Z`N[000WZ`00<007Z`N[002WZ`00<007ooOol0Lgoo00<007ooOol02Goo00<007ooOol03goo0@00
0Goo00000`00Oomoo`0=Ool2000@Ool00`00Oomoo`0bOol00`00Oomoo`0[Ool20002Ool20002Ool2
0002Ool200000goo00000002Ool200000goo00000002Ool2000017oo000007oo0P0000=oo`000000
:Goo00<007ooOol027oo00<007ooOol02Goo0P008Woo00D004hgCSM>=`00015j/003001j/7Z`00=j
/003001j/7Z`00Uj/003001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo059oo`03001oogoo00Qoo`03001oogoo00moo`40005oo`0000<007ooOol03Woo00<0
07ooOol03Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol00goo00<007ooOol0:Woo0P000goo0P000Woo0P000Woo0P0000=oo`0000000Woo0P0000=o
o`0000000Woo0P0000Aoo`00001oo`800003Ool0000002Yoo`03001oogoo00Moo`03001oogoo00Yo
o`03001oogoo025oo`04001>=dhg000AN[000`00N[1j/004N[000`00N[1j/008N[000`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`1BOol00`00Oomoo`07Ool00`00Oomoo`0?Ool10001Ool00003
001oogoo00moo`8000moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00D0009oo`03001oogoo009oo`03001oogoo00D00004Ool000000003Ool00`00Oomoo`02Ool00`00
Oomoo`0ZOol20002Ool400000goo00000002Ool200000goo00000002Ool200000goo00000002Ool2
000017oo000007oo0P0000=oo`000000:Woo00<007ooOol01goo00<007ooOol02goo0P008Goo00D0
04hgCSM>=`00011j/003001j/7Z`00Ej/004001j/7Z`0006N[000`00Oomoo`02Ool01`00Oomoogoo
001oo`0000Aoo`06001oogoo001oo`0017oo00H007ooOol007oo0003Ool00`00Oomoo`1BOol00`00
Oomoo`07Ool00`00Oomoo`0?Ool10001Ool00003001oogoo015oo`03001oogoo00eoo`8000Aoo`07
001oogooOol007oo000017oo00D007ooOomoo`0000=oo`03001oo`0000Aoo`05001oogooOol00003
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol20007Ool200001Goo00000000Ool0
0P000Woo0P0000=oo`0000000Woo0P0000Aoo`00001oo`800003Ool0000002]oo`03001oogoo00Io
o`03001oogoo00eoo`03001oogoo01moo`04001>=dhg000@N[000`00N[1j/006N[001000N[1j/000
1GZ`00@007ooOomoo`8000=oo`03001oo`0000Moo`03001oo`0000Moo`03001oo`0000=oo`8005Ao
o`03001oogoo00Ioo`03001oogoo00moo`40005oo`0000<007ooOol04Woo00<007ooOol03Woo00<0
07ooOol00P000goo00<007oo000027oo00L007ooOomoo`00Ool00008Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool20003Ool00`00Oomoo`0ZOol20006Ool5000017oo000000000Woo0`0000Aoo`00001o
o`D000=oo`@002aoo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo01ioo`04001>=dhg000@
N[000`00N[1j/007N[040004N[000`00Oomoo`02Ool01`00Oomoogoo001oo`0000Qoo`03001oogoo
00Ioo`03001oo`0000=oo`03001oogoo05Aoo`03001oogoo00Eoo`03001oogoo00moo`40005oo`00
00<007ooOol04goo0P003goo00@007ooOol000=oo`03001oo`0000Qoo`07001oogooOol007oo0000
27oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0:Woo0P0017oo00<0
07ooOol06goo0P00;Goo00<007ooOol017oo00<007ooOol03goo0P007Woo00D004hgCSM>=`0000mj
/003001j/7Z`00Uj/08000Aj/003001oogoo009oo`07001oogooOol007oo00001goo00<007oo0000
1goo00<007oo00000goo00<007ooOol0EGoo00<007ooOol017oo00<007ooOol03goo0@000Goo0000
0`00Oomoo`0EOol00`00Oomoo`0=Ool30003Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000Qo
o`07001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol0:goo0P000Woo0P007Goo0P00
;Goo00<007ooOol01Goo00<007ooOol047oo00<007ooOol077oo00@004hgCSL000ij/003001j/7Z`
00]j/08000=j/003001oogoo00=oo`05001oogooOol00009Ool00`00Oomoo`07Ool01@00Oomoogoo
0000F7oo00<007ooOol01Goo00<007ooOol03Woo0@000Goo00000`00Oomoo`0FOol00`00Oomoo`0>
Ool20003Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`06Ool20004Ool01@00Oomoogoo00001Goo
00<007ooOol0;7oo0`0000=oo`00Ool06goo0`00;Woo00<007ooOol017oo00<007ooOol04Goo00<0
07ooOol06goo00@004hgCSL000ij/003001j/7Z`00Uj/0@000=j/003001oogoo07Uoo`03001oogoo
00Aoo`03001oogoo00ioo`40005oo`0000<007ooOol05goo0P003goo00<007ooOol0:7oo0P00PGoo
00<007ooOol00goo00<007ooOol04Woo0P006goo00D004hgCSM>=`0000ej/003001j/7Z`015j/003
001oogoo07Uoo`03001oogoo00=oo`03001oogoo00ioo`40005oo`0000<007ooOol06Goo00<007oo
Ool03Goo00<007ooOol09goo0P00PWoo00<007ooOol00Woo00<007ooOol057oo00<007ooOol06Goo
00@004hgCSL000ej/003001j/7Z`015j/003001oogoo07Yoo`03001oogoo009oo`03001oogoo00io
o`40005oo`0000<007ooOol06Woo00<007ooOol03Goo0P009goo0P00Pgoo00D007ooOomoo`0001Mo
o`03001oogoo01Qoo`05001>=dhgCSL0000<N[000`00N[1j/00=N[020002N[000`00Oomoo`1kOol0
1@00Oomoogoo000047oo0@000Goo00000`00Oomoo`0KOol2000?Ool00`00Oomoo`0TOol20023Ool0
1@00Oomoogoo000067oo0P006Goo00@004hgCSL000aj/003001j/7Z`00ij/004001j/7Z`001mOol0
1@00Oomoogoo000047oo0@000Goo00000`00Oomoo`0MOol00`00Oomoo`0=Ool00`00Oomoo`0SOol2
0024Ool01000Oomoo`006Woo00<007ooOol05Woo00@004hgCSL000Yj/005001j/000N[00000>N[00
1000N[1j/000OWoo00@007ooOol0011oo`40005oo`0000<007ooOol07Woo00<007ooOol03Goo00<0
07ooOol08Woo0P00QGoo00<007oo00006goo00<007ooOol05Goo00D004hgCSM>=`0000Uj/005001j
/000N[00000=N[001@00N[0007Z`0000Ogoo00<007oo000047oo0@000Goo00000`00Oomoo`0OOol2
000>Ool2000ROol20026Ool00`00Ool0000KOol2000FOol01000CSL000002WZ`0`003WZ`00D007Z`
001j/000081oo`03001oo`0000moo`40005oo`0000<007ooOol08Goo00<007ooOol03Goo00<007oo
Ool07goo0P00QWoo00<007oo00007Goo00<007ooOol04goo0P000U:k00<007Z`N[001gZ`0`003GZ`
0P0000=j/0000000PGoo00<007oo00003goo0@000Goo00000`00Oomoo`0ROol00`00Oomoo`0=Ool0
0`00Oomoo`0NOol20027Ool2000NOol00`00Oomoo`0COol01@00D[]B^e:k00002GZ`00<007Z`N[00
47Z`00<007ooOol00goo0`000goo0`00M7oo0P003goo0@000Goo00000`00Oomoo`0SOol2000>Ool2
000NOol20027Ool2000OOol2000DOol01000D[]B^`002GZ`00<007Z`N[0047Z`00<007ooOol017oo
00<007ooOol00Woo00<007ooOol0M7oo0P003goo0@000Goo00000`00Oomoo`0UOol00`00Oomoo`0=
Ool00`00Oomoo`0KOol20023Ool4000SOol00`00Oomoo`0AOol01@00D[]B^e:k00006gZ`00<007oo
Ool017oo0`000goo00<007ooOol0Kgoo10004Goo0@000Goo00000`00Oomoo`0VOol00`00Oomoo`0=
Ool00`00Oomoo`0JOol2001oOol4000XOol00`00Oomoo`0AOol01@00D[]B^e:k00006GZ`00<007oo
Ool01Goo00@007ooOol0009oo`03001oogoo06]oo`@001Eoo`40005oo`0000<007ooOol09goo0P00
3Woo00<007ooOol06Goo0P00Ngoo1000;Goo0P004Woo00D005:kD[]B^`0001Qj/003001oogoo00Eo
o`08001oogoo001oo`00Ool006Qoo`@001Uoo`40005oo`0000<007ooOol0:Goo00<007ooOol037oo
0P006Goo00<007ooOol0MWoo1000<goo00<007ooOol047oo00@005:kD[/001Qj/003001oogoo00Ao
o`@000=oo`03001oogoo06=oo`@001eoo`40005oo`0000<007ooOol0:Woo00<007ooOol03Goo00<0
07ooOol05Woo00<007ooOol0LWoo1000>7oo00<007ooOol03goo00D005:kD[]B^`0001Mj/003001o
ogoo06eoo`@0025oo`40005oo`0000<007ooOol0:goo0P003Woo00<007ooOol05Goo00<007ooOol0
KWoo1000?Goo0P0047oo00D005:kD[]B^`0000Ej/0@000aj/003001oogoo06Yoo`@002Eoo`40005o
o`0000<007ooOol0;Goo00<007ooOol037oo00<007ooOol057oo00<007ooOol0JWoo1000@goo00<0
07ooOol03Woo00D005:kD[]B^`0000Ej/003001j/00000aj/003001oogoo06Ioo`@002Uoo`40005o
o`0000<007ooOol0;Woo00<007ooOol037oo0P0057oo00<007ooOol0IWoo1000B7oo00<007ooOol0
3Woo00D005:kD[]B^`0000=j/003001j/00000ej/003001oogoo069oo`@002eoo`40005oo`0000<0
07ooOol0;goo0P003Woo00<007ooOol04Goo00<007ooOol0HWoo1000CGoo0P003goo00@005:kD[/0
00=j/0@000]j/003001oogoo05moo`@0035oo`40005oo`0000<007ooOol0<Goo00<007ooOol037oo
00<007ooOol047oo00<007ooOol0GWoo1000Dgoo00<007ooOol037oo00D005:kD[]B^`0000mj/080
05ioo`@003Eoo`40005oo`0000<007ooOol0<Woo00<007ooOol037oo0P0047oo00<007ooOol0FWoo
1000F7oo00<007ooOol037oo00<005:kD[/00`0037Z`00<007ooOol0FWoo1000>Goo0@000Goo0000
0`00Oomoo`0cOol2000>Ool00`00Oomoo`0=Ool00`00Oomoo`1FOol4001MOol2000=Ool20003Bgl3
0008N[02001HOol4000mOol10001Ool00003001oogoo03Eoo`03001oogoo00aoo`03001oogoo00]o
o`8005Aoo`@006=oo`03001oogoo00aoo`<000=;O`@0009j/0800003Ool007oo05=oo`@0045oo`40
005oo`0000<007ooOol0=Woo00<007ooOol037oo00<007ooOol02Woo0P00D7oo1000J7oo00<007oo
Ool03Woo10000d]o0P000goo00<007ooOol0CWoo1000AGoo0@000Goo00000`00Oomoo`0gOol2000=
Ool2000:Ool2001<Ool4001]Ool2000BOol30005Ool00`00Oomoo`1:Ool40019Ool10001Ool00003
001oogoo03Uoo`03001oogoo00aoo`03001oogoo00Moo`8004Qoo`@007=oo`03001oogoo01Moo`03
001oogoo04Ioo`@004eoo`40005oo`0000<007ooOol0>Woo00<007ooOol037oo00<007ooOol01Woo
0P00A7oo1000N7oo00<007ooOol05Woo00<007ooOol0@Woo1000DGoo0@000Goo00000`00Oomoo`0k
Ool2000=Ool00`00Oomoo`05Ool20010Ool4001mOol2000FOol00`00Oomoo`0nOol4001EOol10001
Ool00003001oogoo03eoo`03001oogoo00]oo`8000Eoo`8003aoo`@008=oo`03001oogoo01=oo`03
001oogoo03Yoo`@005Uoo`40005oo`0000<007ooOol0?Woo00<007ooOol037oo00<007ooOol00Woo
0P00>7oo1000R7oo00<007ooOol04Woo00<007ooOol0=Woo1000GGoo0@000Goo00000`00Oomoo`0o
Ool2000=Ool01000Oomoogoo0P00=7oo1000SGoo0P004Woo00<007ooOol0<Woo1000HGoo0@000Goo
00000`00Oomoo`11Ool00`00Oomoo`0;Ool200000goo0000000`Ool4002COol00`00Oomoo`0?Ool0
0`00Oomoo`0^Ool4001UOol10001Ool00003001oogoo049oo`03001oogoo00aoo`<002aoo`@009Qo
o`03001oogoo00ioo`03001oogoo02Yoo`@006Uoo`40005oo`0000<007ooOol0@goo0P003Goo0P00
:7oo1000WGoo0P003Woo00<007ooOol09Woo1000KGoo0@000Goo00000`00Oomoo`15Ool00`00Oomo
o`0:Ool00`00Oomoo`0SOol4002SOol00`00Oomoo`0:Ool00`00Oomoo`0SOol4001aOol10001Ool0
0003001oogoo04Ioo`03001oogoo00Uoo`03001oogoo01moo`@00:Qoo`03001oogoo00Uoo`03001o
ogoo01moo`@007Eoo`40005oo`0000<007ooOol0Agoo0P002Goo00<007ooOol06goo1000[Goo0P00
2Goo00<007ooOol06goo1000NGoo0@000Goo00000`00Oomoo`19Ool00`00Oomoo`06Ool00`00Oomo
o`0GOol4002cOol00`00Oomoo`06Ool00`00Oomoo`0GOol4001mOol10001Ool00003001oogoo04Yo
o`03001oogoo00Eoo`03001oogoo01=oo`@00;Qoo`03001oogoo00Eoo`03001oogoo01=oo`@0085o
o`40005oo`0000<007ooOol0Bgoo0P001Goo00<007ooOol03goo1000_Goo0P001Goo00<007ooOol0
3goo1000QGoo0@000Goo00000`00Oomoo`1=Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool40033Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool40029Ool10001Ool00003001oogoo04ioo`05001oogooOol0
0009Ool40038Ool01@00Oomoogoo00002Goo1000SGoo0@000Goo00000`00Oomoo`1?Ool200000goo
001oo`04Ool4003=Ool200000goo001oo`04Ool4002AOol10001Ool00003001oogoo055oo`800003
Ool0000000800==oo`800003Ool00000008009Eoo`40005oo`0000<007ooOol0DWoo0P00f7oo0P00
VGoo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<0
07ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40
005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo
0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool0
0003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8
Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00
Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@00
0Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`00o`00c0000Goo
0000\
\>"],
  ImageRangeCache->{{{0, 459}, {459, 0}} -> {-0.0521105, -0.0521105, 
  0.00458436, 0.00458436}, {{11.3125, 229.5}, {447.625, 229.5}} ->
   {-0.0781591, -0.100606, 0.0046987, 0.0046987}, {{229.5, 447.625}, {447.625,
   229.5}} -> {-1.10367, -0.100768, 0.00470004, 0.00470004}, {{11.3125, 
  229.5}, {229.5, 11.3125}} -> {-0.0781591, -1.12566, 0.0046987, 0.0046987},
   {{229.5, 447.625}, {229.5, 11.3125}} -> {-1.10367, -1.12611, 0.00470004, 
  0.00470004}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are names for each of the body numbers in the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(slider = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are body objects for each body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bd[ground] = 
      Body[ground, 
        PointList \[Rule] {{0, 10, 12}, {10, 10, 12}, {1, 0, 0}, {0, 1, 0}}]; 
    \)\), 
    \(bd[crank] = 
      Body[crank, \n\t\tPointList \[Rule] {{8, 0, 0}, {0, 8, 0}}, \n\t\t
        InitialGuess \[Rule] {{0, 10, 12}, {1, 0, 0, 0}}]; \n
    bd[slider] = 
      Body[slider, \n\t\tPointList \[Rule] {{1, 0, 0}, {0, 1, 0}}, \n\t\t
        InitialGuess \[Rule] {{20, 0, 0}, {1, 0, 0, 0}}]; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This incorporates the body properties into the current model."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[Array[bd, 3]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four constraints are used to model the slider-crank mechanism."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of the crank to be coincident with its pivot \
axis on the ground. This leaves only one degree of freedom for the crank, \
rotation about its axis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the angular relationship between a line on the \
ground body and a line on the crank. This driving constraint is used to \
rotate the crank."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the crank and the slider replaces the pseudo \
connecting rod, which is 30 units long."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint between the slider and the ground leaves only one degree of \
freedom for the slider; horizontal translation along a track on the ground \
body. This constraint references two ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects that are constrained to be parallel and coincident, ",
  StyleBox["and",
    FontSlant->"Italic"],
  " the reference directions of the two axes are constrained to be coplanar."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraints for the slider-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(cs[1] = Revolute5[1, \n\t\tLine[ground, 1, 2], Line[crank, 0, 1]]; \n
    \(cs[2] = 
      ProjectedAngle1[2, Line[crank, 0, 2], Line[ground, 0, 4], 
        Line[ground, 0, 3], 2\ N[\[Pi]]\ T]; \)\), 
    \(cs[3] = 
      RelativeDistance1[3, \n\t\tPoint[crank, 2], Point[slider, 0], 30.0]; \n
    \(cs[4] = Translate5[4, Axis[ground, 0, 3, 4], Axis[slider, 0, 1, 2]]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This incorporates the constraints into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 4]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 10.`\), ",", \(Z2 \[Rule] 11.9999999999999996`\), ",", 
        \(Eo2 \[Rule] 0.987688340595137859`\), ",", 
        \(Ei2 \[Rule] 0.156434465040230907`\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 19.5064013716724993`\), ",", 
        \(Y3 \[Rule] 0\), ",", \(Z3 \[Rule] 0\), ",", \(Eo3 \[Rule] 1.`\), 
        ",", \(Ei3 \[Rule] 0\), ",", \(Ej3 \[Rule] 0\), ",", 
        \(Ek3 \[Rule] 0\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the slider-crank model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83498 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0177149 0.992893 -0.0316522 0.992893 [
[ 0 0 0 0 ]
[ 1 .83498 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .83498 L
0 .83498 L
closepath
clip
newpath
p
.002 w
.67169 .36171 m
.68339 .81015 L
s
.68339 .81015 m
.97518 .70072 L
s
.97518 .70072 m
.94115 .1703 L
s
.94115 .1703 m
.67169 .36171 L
s
.05344 .26268 m
.21801 .02482 L
s
.21801 .02482 m
.19619 .61574 L
s
.19619 .61574 m
.02482 .75387 L
s
.02482 .75387 m
.05344 .26268 L
s
.67169 .36171 m
.68339 .81015 L
s
.68339 .81015 m
.02482 .75387 L
s
.02482 .75387 m
.05344 .26268 L
s
.05344 .26268 m
.67169 .36171 L
s
.94115 .1703 m
.21801 .02482 L
s
.21801 .02482 m
.19619 .61574 L
s
.19619 .61574 m
.97518 .70072 L
s
.97518 .70072 m
.94115 .1703 L
s
P
p
.008 w
.69732 .39447 m
.70802 .75843 L
s
P
p
.002 w
.74831 .60102 m .74754 .51159 L .76951 .42383 L p
.297 .205 .579 r
F P
s
P
p
.002 w
.76951 .42383 m .74754 .51159 L .73196 .50945 L p
.774 .681 .76 r
F P
s
P
p
.002 w
.74754 .51159 m .74831 .60102 L .73258 .59911 L p
.788 .599 .645 r
F P
s
P
p
.002 w
.73258 .59911 m .73196 .50945 L .74754 .51159 L p
.788 .599 .645 r
F P
s
P
p
.002 w
.73196 .50945 m .75388 .42145 L .76951 .42383 L p
.774 .681 .76 r
F P
s
P
p
.002 w
.73258 .59911 m .73196 .50945 L .75388 .42145 L p
.291 .2 .577 r
F P
s
P
p
.002 w
.35065 .25875 m .33136 .27866 L .46534 .30072 L p
.584 .802 .982 r
F P
s
P
p
.002 w
.46534 .30072 m .48672 .28166 L .35065 .25875 L p
.584 .802 .982 r
F P
s
P
p
.002 w
.33136 .27866 m .46534 .30072 L .46521 .36738 L p
.788 .589 .632 r
F P
s
P
p
.008 w
.46523 .35841 m
.69732 .39447 L
s
P
p
.46611 .30377 m .48561 .34671 L .47848 .35237 L .178 .1 .524 r
F
P
p
.467 .30449 m .48561 .34671 L .46611 .30377 L .178 .1 .524 r
F
P
p
.002 w
.46526 .34106 m .46534 .30072 L p
.47848 .35237 L .178 .1 .524 r
F P
s
P
p
.002 w
.76951 .42383 m .80976 .35751 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.93798 .42328 m .94102 .52398 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.90726 .35246 m .93798 .42328 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.8598 .33003 m .90726 .35246 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.80976 .35751 m .8598 .33003 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.80976 .35751 m .76951 .42383 L .75388 .42145 L p
.727 .755 .874 r
F P
s
P
p
.002 w
.75388 .42145 m .79387 .35489 L .80976 .35751 L p
.727 .755 .874 r
F P
s
P
p
.002 w
.75388 .42145 m .79387 .35489 L p
.77097 .44614 L .291 .2 .577 r
F P
s
P
p
.73258 .59911 m .75252 .43276 L .77097 .44614 L .291 .2 .577 r
F
P
p
.75252 .43276 m .75388 .42145 L .77097 .44614 L .291 .2 .577 r
F
P
p
.002 w
.46522 .36291 m .46526 .34106 L p
.47848 .35237 L .178 .1 .524 r
F P
s
P
p
.002 w
.46521 .36738 m .46522 .36291 L p
.47999 .35366 L .178 .1 .524 r
F P
s
P
p
.002 w
.48679 .3494 m .48082 .35437 L p
.47999 .35366 L .178 .1 .524 r
F P
s
P
p
.002 w
.48082 .35437 m .46521 .36738 L p
.47999 .35366 L .178 .1 .524 r
F P
s
P
p
.002 w
.89826 .53668 m .89636 .53716 L p
.89228 .5342 L .569 .005 0 r
F P
s
P
p
.002 w
.81527 .70567 m .77228 .67194 L .74831 .60102 L p
.297 .205 .579 r
F P
s
P
p
.002 w
.86755 .68944 m .81527 .70567 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.91455 .62307 m .86755 .68944 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.94102 .52398 m .91455 .62307 L p
.74831 .60102 L .297 .205 .579 r
F P
s
P
p
.002 w
.74831 .60102 m .77228 .67194 L .75621 .67017 L p
.773 .466 .467 r
F P
s
P
p
.002 w
.75621 .67017 m .73258 .59911 L .74831 .60102 L p
.773 .466 .467 r
F P
s
P
p
.73258 .59911 m .89238 .53427 L .8973 .62098 L .291 .2 .577 r
F
P
p
.002 w
.89216 .53411 m .89826 .53668 L p
.89228 .5342 L .569 .005 0 r
F P
s
P
p
.48561 .34671 m .48679 .3494 L .46522 .36291 L .178 .1 .524 r
F
P
p
.002 w
.90539 .52585 m .89826 .53668 L .89216 .53411 L p
.657 .405 .528 r
F P
s
P
p
.002 w
.91072 .50249 m .91054 .51174 L .89048 .50339 L p
.44 .561 .881 r
F P
s
P
p
.77304 .56074 m .86501 .47353 L .88329 .50691 L .291 .2 .577 r
F
P
p
.86501 .47353 m .87066 .46818 L .87456 .48017 L .291 .2 .577 r
F
P
p
.86501 .47353 m .87456 .48017 L .88329 .50691 L .291 .2 .577 r
F
P
p
.91072 .50249 m .89048 .50339 L .90054 .49848 L .44 .561 .881 r
F
P
p
.87066 .46818 m .92085 .42059 L .90135 .49808 L .291 .2 .577 r
F
P
p
.91072 .50249 m .90054 .49848 L .90058 .49846 L .44 .561 .881 r
F
P
p
.87066 .46818 m .89358 .49051 L .88329 .50691 L .291 .2 .577 r
F
P
p
.89358 .49051 m .90135 .49808 L .89048 .50339 L .291 .2 .577 r
F
P
p
.89358 .49051 m .89048 .50339 L .88329 .50691 L .291 .2 .577 r
F
P
p
.002 w
.48676 .32056 m .48679 .34578 L p
.46721 .30467 L .178 .1 .524 r
F P
s
P
p
.002 w
.48679 .34578 m .48679 .3494 L p
.48561 .34671 L .178 .1 .524 r
F P
s
P
p
.46534 .30072 m .48679 .34578 L .48561 .34671 L .178 .1 .524 r
F
P
p
.002 w
.89051 .34964 m .92085 .42059 L p
.87066 .46818 L .291 .2 .577 r
F P
s
P
p
.77304 .56074 m .85362 .41594 L .87066 .46818 L .291 .2 .577 r
F
P
p
.85362 .41594 m .89051 .34964 L .87066 .46818 L .291 .2 .577 r
F
P
p
.74963 .57218 m .89051 .34964 L .77304 .56074 L .291 .2 .577 r
F
P
p
.77304 .56074 m .88329 .50691 L .88694 .51812 L .291 .2 .577 r
F
P
p
.88253 .53648 m .88694 .51812 L .89223 .53433 L .291 .2 .577 r
F
P
p
.77304 .56074 m .88694 .51812 L .88253 .53648 L .291 .2 .577 r
F
P
p
.002 w
.91054 .51174 m .90539 .52585 L .88694 .51812 L p
.594 .495 .712 r
F P
s
P
p
.91054 .51174 m .88694 .51812 L .89035 .50394 L .594 .495 .712 r
F
P
p
.002 w
.88694 .51812 m .90539 .52585 L p
.88712 .51865 L .657 .405 .528 r
F P
s
P
p
.002 w
.90077 .49837 m .91072 .50249 L p
.90058 .49846 L .44 .561 .881 r
F P
s
P
p
.002 w
.89048 .50339 m .91054 .51174 L p
.89035 .50394 L .594 .495 .712 r
F P
s
P
p
.90539 .52585 m .89216 .53411 L .88712 .51865 L .657 .405 .528 r
F
P
p
.88329 .50691 m .90077 .49837 L .89223 .53433 L .291 .2 .577 r
F
P
p
.002 w
.8598 .33003 m .80976 .35751 L .79387 .35489 L p
.529 .806 .997 r
F P
s
P
p
.002 w
.79387 .35489 m .8435 .32725 L .8598 .33003 L p
.529 .806 .997 r
F P
s
P
p
.002 w
.8435 .32725 m .89051 .34964 L p
.73258 .59911 L .291 .2 .577 r
F P
s
P
p
.002 w
.79387 .35489 m .8435 .32725 L p
.73258 .59911 L .291 .2 .577 r
F P
s
P
p
.002 w
.46521 .36738 m .48082 .35437 L p
.47158 .35239 L .57 .807 .989 r
F P
s
P
p
.002 w
.46521 .36738 m .32999 .34657 L .33136 .27866 L p
.788 .589 .632 r
F P
s
P
p
.002 w
.43545 .34464 m .40041 .32985 L p
.43663 .3449 L .569 .005 0 r
F P
s
P
p
.002 w
.40041 .32985 m .40734 .32972 L .45031 .34783 L p
.569 .005 0 r
F P
s
P
p
.43216 .35608 m .46075 .35007 L .45894 .34968 L .57 .807 .989 r
F
P
p
.44202 .34605 m .40041 .32985 L .45031 .34783 L .569 .005 0 r
F
P
p
.45311 .3477 m .40734 .32972 L .47197 .34522 L .657 .405 .528 r
F
P
p
.002 w
.48679 .34578 m .48676 .326 L p
.47776 .3377 L .789 .589 .63 r
F P
s
P
p
.002 w
.4652 .32645 m .41918 .3073 L p
.46345 .32488 L .44 .561 .881 r
F P
s
P
p
.002 w
.47255 .34447 m .41509 .32039 L p
.47164 .34223 L .594 .495 .712 r
F P
s
P
p
.45311 .3477 m .47197 .34522 L .47071 .34687 L .657 .405 .528 r
F
P
p
.002 w
.47071 .34687 m .47372 .34734 L p
.47255 .34447 L .789 .589 .63 r
F P
s
P
p
.002 w
.47372 .34734 m .48679 .3494 L p
.47255 .34447 L .789 .589 .63 r
F P
s
P
p
.002 w
.40734 .32972 m .41509 .32039 L .47751 .34655 L p
.657 .405 .528 r
F P
s
P
p
.43663 .3449 m .40041 .32985 L .44202 .34605 L .569 .005 0 r
F
P
p
.4203 .33482 m .40734 .32972 L .42025 .33479 L .657 .405 .528 r
F
P
p
.43216 .35608 m .45894 .34968 L .43017 .34962 L .57 .807 .989 r
F
P
p
.45894 .34968 m .47071 .34687 L .45031 .34783 L .57 .807 .989 r
F
P
p
.45894 .34968 m .45031 .34783 L .41316 .34958 L .57 .807 .989 r
F
P
p
.46521 .36738 m .47372 .34734 L .43216 .35608 L .57 .807 .989 r
F
P
p
.4203 .33482 m .42025 .33479 L .88694 .51812 L .657 .405 .528 r
F
P
p
.88712 .51865 m .4203 .33482 L .88694 .51812 L .657 .405 .528 r
F
P
p
.002 w
.89216 .53411 m .40734 .32972 L p
.88712 .51865 L .657 .405 .528 r
F P
s
P
p
.002 w
.41509 .32039 m .40734 .32972 L p
.39837 .3206 L .931 .873 .758 r
F P
s
P
p
.002 w
.40734 .32972 m .40041 .32985 L .39837 .3206 L p
.931 .873 .758 r
F P
s
P
p
.002 w
.39837 .3206 m .40041 .32985 L .43545 .34464 L p
.432 .559 .883 r
F P
s
P
p
.41316 .34958 m .45031 .34783 L .34944 .32779 L .57 .807 .989 r
F
P
p
.002 w
.41509 .32039 m .41918 .3073 L .4652 .32645 L p
.594 .495 .712 r
F P
s
P
p
.002 w
.46534 .30072 m .48672 .28166 L .48676 .32056 L p
.178 .1 .524 r
F P
s
P
p
.46534 .30072 m .48676 .32056 L .46721 .30467 L .178 .1 .524 r
F
P
p
.46534 .30072 m .467 .30449 L .46611 .30377 L .178 .1 .524 r
F
P
p
.48672 .28166 m .45172 .29341 L .46001 .31374 L .789 .589 .63 r
F
P
p
.002 w
.41918 .3073 m .41724 .29802 L .44741 .31052 L p
.44 .561 .881 r
F P
s
P
p
.47773 .31826 m .46001 .31374 L .4652 .32645 L .789 .589 .63 r
F
P
p
.47773 .31826 m .4652 .32645 L .47382 .33417 L .789 .589 .63 r
F
P
p
.45702 .31913 m .41918 .3073 L .44741 .31052 L .44 .561 .881 r
F
P
p
.002 w
.44741 .31052 m .41724 .29802 L p
.44624 .31022 L .552 0 0 r
F P
s
P
p
.4716 .34214 m .41509 .32039 L .4652 .32645 L .594 .495 .712 r
F
P
p
.47382 .33417 m .4652 .32645 L .47177 .34255 L .789 .589 .63 r
F
P
p
.002 w
.48679 .3494 m .48679 .34578 L p
.47255 .34447 L .789 .589 .63 r
F P
s
P
p
.47776 .3377 m .47255 .34447 L .48679 .34578 L .789 .589 .63 r
F
P
p
.002 w
.48676 .326 m .48676 .32056 L p
.47609 .3362 L .789 .589 .63 r
F P
s
P
p
.47609 .3362 m .47688 .33691 L .48676 .326 L .789 .589 .63 r
F
P
p
.47773 .31826 m .47177 .34255 L .48676 .32056 L .789 .589 .63 r
F
P
p
.47177 .34255 m .47255 .34447 L .48676 .326 L .789 .589 .63 r
F
P
p
.47164 .34223 m .41509 .32039 L .4716 .34214 L .594 .495 .712 r
F
P
p
.002 w
.41918 .3073 m .41509 .32039 L p
.39837 .3206 L .931 .873 .758 r
F P
s
P
p
.002 w
.41724 .29802 m .41918 .3073 L p
.39837 .3206 L .931 .873 .758 r
F P
s
P
p
.002 w
.41033 .29799 m .41724 .29802 L p
.39837 .3206 L .931 .873 .758 r
F P
s
P
p
.002 w
.39837 .3206 m .40249 .30736 L .41033 .29799 L p
.931 .873 .758 r
F P
s
P
p
.002 w
.41033 .29799 m .40249 .30736 L .42196 .31549 L p
.655 .402 .524 r
F P
s
P
p
.4652 .32645 m .42229 .31507 L .47177 .34255 L .789 .589 .63 r
F
P
p
.42229 .31507 m .42196 .31549 L .47177 .34255 L .789 .589 .63 r
F
P
p
.42228 .31629 m .40249 .30736 L .42931 .33361 L .592 .494 .712 r
F
P
p
.42196 .31549 m .42371 .3198 L .47177 .34255 L .789 .589 .63 r
F
P
p
.47609 .3362 m .47177 .34255 L .47688 .33691 L .789 .589 .63 r
F
P
p
.89035 .50394 m .47164 .34223 L .89048 .50339 L .594 .495 .712 r
F
P
p
.47164 .34223 m .4716 .34214 L .89048 .50339 L .594 .495 .712 r
F
P
p
.002 w
.4652 .32645 m .89048 .50339 L p
.4716 .34214 L .594 .495 .712 r
F P
s
P
p
.002 w
.47372 .34734 m .47071 .34687 L p
.45894 .34968 L .57 .807 .989 r
F P
s
P
p
.46075 .35007 m .47372 .34734 L .45894 .34968 L .57 .807 .989 r
F
P
p
.002 w
.48679 .3494 m .47372 .34734 L p
.47158 .35239 L .57 .807 .989 r
F P
s
P
p
.002 w
.48082 .35437 m .48679 .3494 L p
.47158 .35239 L .57 .807 .989 r
F P
s
P
p
.002 w
.47751 .34655 m .88694 .51812 L p
.45311 .3477 L .657 .405 .528 r
F P
s
P
p
.002 w
.88694 .51812 m .47751 .34655 L p
.89035 .50394 L .594 .495 .712 r
F P
s
P
p
.89035 .50394 m .47751 .34655 L .48095 .34582 L .594 .495 .712 r
F
P
p
.90077 .49837 m .90121 .49867 L .89223 .53433 L .291 .2 .577 r
F
P
p
.002 w
.90766 .50315 m .91072 .50249 L .90077 .49837 L p
.552 0 0 r
F P
s
P
p
.002 w
.92085 .42059 m .92197 .46011 L p
.89223 .53433 L .291 .2 .577 r
F P
s
P
p
.002 w
.90539 .52585 m .89826 .53668 L p
.89713 .53485 L .957 .948 .699 r
F P
s
P
p
.89966 .52723 m .90539 .52585 L .89713 .53485 L .957 .948 .699 r
F
P
p
.89223 .53433 m .92197 .46011 L .89809 .53196 L .291 .2 .577 r
F
P
p
.002 w
.91054 .51174 m .90539 .52585 L p
.89335 .52875 L .957 .948 .699 r
F P
s
P
p
.002 w
.91072 .50249 m .91054 .51174 L p
.89335 .52875 L .957 .948 .699 r
F P
s
P
p
.002 w
.90577 .50356 m .91072 .50249 L p
.89335 .52875 L .957 .948 .699 r
F P
s
P
p
.002 w
.92197 .46011 m .9237 .52156 L p
.89809 .53196 L .291 .2 .577 r
F P
s
P
p
.002 w
.89826 .53668 m .89636 .53716 L p
.89713 .53485 L .957 .948 .699 r
F P
s
P
p
.002 w
.9237 .52156 m .91581 .55128 L p
.89636 .53716 L .291 .2 .577 r
F P
s
P
p
.89238 .53427 m .89809 .53196 L .89636 .53716 L .291 .2 .577 r
F
P
p
.89809 .53196 m .9237 .52156 L .89636 .53716 L .291 .2 .577 r
F
P
p
.002 w
.91581 .55128 m .8973 .62098 L p
.89238 .53427 L .291 .2 .577 r
F P
s
P
p
.002 w
.89636 .53716 m .89326 .53794 L p
.89228 .5342 L .569 .005 0 r
F P
s
P
p
.002 w
.89326 .53794 m .89335 .52875 L p
.89713 .53485 L .957 .948 .699 r
F P
s
P
p
.002 w
.89636 .53716 m .89326 .53794 L p
.89713 .53485 L .957 .948 .699 r
F P
s
P
p
.89335 .52875 m .89966 .52723 L .89713 .53485 L .957 .948 .699 r
F
P
p
.002 w
.89335 .52875 m .89855 .51445 L .42196 .31549 L p
.592 .494 .712 r
F P
s
P
p
.002 w
.42196 .31549 m .40249 .30736 L p
.42228 .31629 L .592 .494 .712 r
F P
s
P
p
.89335 .52875 m .42196 .31549 L .42228 .31629 L .592 .494 .712 r
F
P
p
.002 w
.40249 .30736 m .39837 .3206 L .42931 .33361 L p
.592 .494 .712 r
F P
s
P
p
.42196 .31549 m .40273 .30988 L .41995 .31803 L .789 .589 .63 r
F
P
p
.46345 .32488 m .41918 .3073 L .45702 .31913 L .44 .561 .881 r
F
P
p
.42917 .30635 m .41033 .29799 L .42196 .31549 L .655 .402 .524 r
F
P
p
.42229 .31507 m .42173 .31492 L .42196 .31549 L .789 .589 .63 r
F
P
p
.42173 .31492 m .40273 .30988 L .42196 .31549 L .789 .589 .63 r
F
P
p
.42196 .31549 m .41995 .31803 L .42371 .3198 L .789 .589 .63 r
F
P
p
.47177 .34255 m .47071 .34687 L .47255 .34447 L .789 .589 .63 r
F
P
p
.47177 .34255 m .40273 .30988 L .47071 .34687 L .789 .589 .63 r
F
P
p
.002 w
.43848 .3418 m .47071 .34687 L p
.40273 .30988 L .789 .589 .63 r
F P
s
P
p
.43848 .3418 m .39837 .3206 L .43545 .34464 L .432 .559 .883 r
F
P
p
.002 w
.47071 .34687 m .43848 .3418 L p
.45031 .34783 L .57 .807 .989 r
F P
s
P
p
.73258 .59911 m .77304 .56074 L .89223 .53433 L .291 .2 .577 r
F
P
p
.002 w
.49539 .36684 m .89216 .53411 L p
.50101 .37165 L .569 .005 0 r
F P
s
P
p
.89228 .5342 m .50101 .37165 L .89216 .53411 L .569 .005 0 r
F
P
p
.002 w
.89326 .53794 m .50258 .37299 L p
.89228 .5342 L .569 .005 0 r
F P
s
P
p
.89228 .5342 m .50258 .37299 L .50101 .37165 L .569 .005 0 r
F
P
p
.002 w
.89326 .53794 m .89335 .52875 L .44165 .3388 L p
.432 .559 .883 r
F P
s
P
p
.002 w
.44165 .3388 m .39837 .3206 L p
.44107 .33935 L .432 .559 .883 r
F P
s
P
p
.89326 .53794 m .44165 .3388 L .44107 .33935 L .432 .559 .883 r
F
P
p
.002 w
.43848 .3418 m .43223 .34081 L p
.43739 .34282 L .57 .807 .989 r
F P
s
P
p
.45031 .34783 m .43848 .3418 L .43739 .34282 L .57 .807 .989 r
F
P
p
.002 w
.43223 .34081 m .3772 .33215 L p
.42489 .34238 L .57 .807 .989 r
F P
s
P
p
.45031 .34783 m .43223 .34081 L .42489 .34238 L .57 .807 .989 r
F
P
p
.002 w
.42931 .33361 m .44165 .3388 L p
.42228 .31629 L .592 .494 .712 r
F P
s
P
p
.002 w
.47751 .34655 m .47255 .34447 L p
.48095 .34582 L .594 .495 .712 r
F P
s
P
p
.48095 .34582 m .47255 .34447 L .47164 .34223 L .594 .495 .712 r
F
P
p
.47071 .34687 m .47197 .34522 L .47751 .34655 L .657 .405 .528 r
F
P
p
.002 w
.44165 .3388 m .89335 .52875 L p
.46239 .33438 L .592 .494 .712 r
F P
s
P
p
.46239 .33438 m .42228 .31629 L .44165 .3388 L .592 .494 .712 r
F
P
p
.45172 .29341 m .43469 .29914 L .44741 .31052 L .789 .589 .63 r
F
P
p
.46001 .31374 m .44741 .31052 L .4652 .32645 L .789 .589 .63 r
F
P
p
.45172 .29341 m .44741 .31052 L .46001 .31374 L .789 .589 .63 r
F
P
p
.44624 .31022 m .41724 .29802 L .44244 .30925 L .552 0 0 r
F
P
p
.002 w
.41724 .29802 m .41033 .29799 L .42949 .30595 L p
.552 0 0 r
F P
s
P
p
.44244 .30925 m .41724 .29802 L .42949 .30595 L .552 0 0 r
F
P
p
.002 w
.42949 .30595 m .41033 .29799 L p
.42917 .30635 L .655 .402 .524 r
F P
s
P
p
.43469 .29914 m .40273 .30988 L .42229 .31507 L .789 .589 .63 r
F
P
p
.4348 .29923 m .42229 .31507 L .4652 .32645 L .789 .589 .63 r
F
P
p
.43469 .29914 m .42229 .31507 L .4348 .29923 L .789 .589 .63 r
F
P
p
.49654 .33802 m .46345 .32488 L .50245 .33333 L .44 .561 .881 r
F
P
p
.46345 .32488 m .45702 .31913 L .50245 .33333 L .44 .561 .881 r
F
P
p
.002 w
.44741 .31052 m .50245 .33333 L p
.45702 .31913 L .44 .561 .881 r
F P
s
P
p
.002 w
.50245 .33333 m .90077 .49837 L p
.49654 .33802 L .44 .561 .881 r
F P
s
P
p
.90058 .49846 m .49654 .33802 L .90077 .49837 L .44 .561 .881 r
F
P
p
.90058 .49846 m .49533 .33899 L .49654 .33802 L .44 .561 .881 r
F
P
p
.90054 .49848 m .49533 .33899 L .90058 .49846 L .44 .561 .881 r
F
P
p
.002 w
.89048 .50339 m .62791 .39415 L p
.89732 .50005 L .44 .561 .881 r
F P
s
P
p
.002 w
.62791 .39415 m .49533 .33899 L p
.89732 .50005 L .44 .561 .881 r
F P
s
P
p
.90054 .49848 m .89732 .50005 L .49533 .33899 L .44 .561 .881 r
F
P
p
.002 w
.89855 .51445 m .90577 .50356 L .42949 .30595 L p
.655 .402 .524 r
F P
s
P
p
.89855 .51445 m .42949 .30595 L .42917 .30635 L .655 .402 .524 r
F
P
p
.50384 .33446 m .44624 .31022 L .50971 .33923 L .552 0 0 r
F
P
p
.44624 .31022 m .44244 .30925 L .50971 .33923 L .552 0 0 r
F
P
p
.002 w
.49533 .33899 m .4652 .32645 L p
.49654 .33802 L .44 .561 .881 r
F P
s
P
p
.49654 .33802 m .4652 .32645 L .46345 .32488 L .44 .561 .881 r
F
P
p
.002 w
.42196 .31549 m .89855 .51445 L p
.42917 .30635 L .655 .402 .524 r
F P
s
P
p
.002 w
.48676 .32056 m .48672 .28166 L p
.47773 .31826 L .789 .589 .63 r
F P
s
P
p
.002 w
.42949 .30595 m .50971 .33923 L p
.44244 .30925 L .552 0 0 r
F P
s
P
p
.48672 .28166 m .46001 .31374 L .47773 .31826 L .789 .589 .63 r
F
P
p
.002 w
.50245 .33333 m .44741 .31052 L p
.50384 .33446 L .552 0 0 r
F P
s
P
p
.50384 .33446 m .44741 .31052 L .44624 .31022 L .552 0 0 r
F
P
p
.43058 .33475 m .39837 .3206 L .43848 .3418 L .432 .559 .883 r
F
P
p
.002 w
.34944 .32779 m .43848 .3418 L p
.40273 .30988 L .789 .589 .63 r
F P
s
P
p
.44107 .33935 m .43058 .33475 L .43848 .3418 L .432 .559 .883 r
F
P
p
.002 w
.3772 .33215 m .34944 .32779 L p
.45031 .34783 L .57 .807 .989 r
F P
s
P
p
.50101 .37165 m .43663 .3449 L .49539 .36684 L .569 .005 0 r
F
P
p
.43663 .3449 m .44202 .34605 L .49539 .36684 L .569 .005 0 r
F
P
p
.002 w
.45031 .34783 m .49539 .36684 L p
.44202 .34605 L .569 .005 0 r
F P
s
P
p
.002 w
.50258 .37299 m .43545 .34464 L p
.50101 .37165 L .569 .005 0 r
F P
s
P
p
.50101 .37165 m .43545 .34464 L .43663 .3449 L .569 .005 0 r
F
P
p
.002 w
.43545 .34464 m .89326 .53794 L p
.44107 .33935 L .432 .559 .883 r
F P
s
P
p
.42567 .35386 m .43017 .34962 L .41316 .34958 L .57 .807 .989 r
F
P
p
.43216 .35608 m .43017 .34962 L .42567 .35386 L .57 .807 .989 r
F
P
p
.73258 .59911 m .74963 .57218 L .77304 .56074 L .291 .2 .577 r
F
P
p
.90077 .49837 m .90135 .49808 L .90121 .49867 L .291 .2 .577 r
F
P
p
.002 w
.90577 .50356 m .90766 .50315 L p
.50245 .33333 L .552 0 0 r
F P
s
P
p
.002 w
.90077 .49837 m .50245 .33333 L p
.90766 .50315 L .552 0 0 r
F P
s
P
p
.90577 .50356 m .50245 .33333 L .50384 .33446 L .552 0 0 r
F
P
p
.002 w
.50971 .33923 m .90577 .50356 L p
.50384 .33446 L .552 0 0 r
F P
s
P
p
.008 w
.53627 .34734 m
.72318 .37705 L
s
P
p
.008 w
.48894 .31348 m
.50463 .31604 L
s
P
p
.008 w
.50463 .31604 m
.73809 .35415 L
s
P
p
.008 w
.73809 .35415 m
.75347 .35666 L
s
P
p
.008 w
.84953 .29198 m
.90769 .25282 L
s
P
p
.008 w
.83783 .29986 m
.84953 .29198 L
s
P
p
.008 w
.72953 .37278 m
.83783 .29986 L
s
P
p
.008 w
.70366 .3902 m
.72953 .37278 L
s
P
p
.008 w
.69732 .39447 m
.70366 .3902 L
s
P
p
.008 w
.70802 .75843 m
.79024 .72508 L
s
P
p
.002 w
.77228 .67194 m .81527 .70567 L .79876 .70394 L p
.597 .076 0 r
F P
s
P
p
.002 w
.79876 .70394 m .75621 .67017 L .77228 .67194 L p
.597 .076 0 r
F P
s
P
p
.002 w
.79876 .70394 m .75621 .67017 L .73258 .59911 L p
.291 .2 .577 r
F P
s
P
p
.008 w
.79024 .72508 m
.82304 .71177 L
s
P
p
.002 w
.85061 .68759 m .79876 .70394 L p
.73258 .59911 L .291 .2 .577 r
F P
s
P
p
.002 w
.8973 .62098 m .85061 .68759 L p
.73258 .59911 L .291 .2 .577 r
F P
s
P
p
.002 w
.34944 .32779 m .32999 .34657 L .46521 .36738 L p
.57 .807 .989 r
F P
s
P
p
.002 w
.48672 .28166 m .35065 .25875 L .34944 .32779 L p
.789 .589 .63 r
F P
s
P
p
.008 w
.46474 .30953 m
.48894 .31348 L
s
P
p
.008 w
.44728 .30668 m
.46474 .30953 L
s
P
p
.008 w
.44011 .30551 m
.44728 .30668 L
s
P
p
.002 w
.35065 .25875 m .33136 .27866 L .32999 .34657 L p
.098 .029 .483 r
F P
s
P
p
.008 w
.35203 .29113 m
.44011 .30551 L
s
P
p
.008 w
.12518 .28199 m
.32878 .31435 L
s
P
p
.008 w
.32878 .31435 m
.33064 .31465 L
s
P
p
.008 w
.10888 .30305 m
.30898 .33413 L
s
P
p
.008 w
.30898 .33413 m
.33018 .33743 L
s
P
p
.002 w
.32999 .34657 m .34944 .32779 L .35065 .25875 L p
.098 .029 .483 r
F P
s
P
p
.008 w
.14434 .25723 m
.35203 .29113 L
s
P
p
.008 w
.2432 .12945 m
.10888 .30305 L
s
P
p
.002 w
.90726 .35246 m .8598 .33003 L .8435 .32725 L p
.422 0 0 r
F P
s
P
p
.002 w
.8435 .32725 m .89051 .34964 L .90726 .35246 L p
.422 0 0 r
F P
s
P
p
.002 w
.81527 .70567 m .86755 .68944 L .85061 .68759 L p
.377 .789 .98 r
F P
s
P
p
.002 w
.85061 .68759 m .79876 .70394 L .81527 .70567 L p
.377 .789 .98 r
F P
s
P
p
.008 w
.65191 .49173 m
.66683 .49379 L
s
P
p
.008 w
.66683 .49379 m
.68699 .49657 L
s
P
p
.008 w
.68699 .49657 m
.72877 .50233 L
s
P
p
.008 w
.72877 .50233 m
.74129 .50406 L
s
P
p
.008 w
.74129 .50406 m
.82119 .51509 L
s
P
p
.008 w
.90769 .25282 m
.2432 .12945 L
s
P
p
.002 w
.93798 .42328 m .90726 .35246 L .89051 .34964 L p
.777 .43 .398 r
F P
s
P
p
.002 w
.89051 .34964 m .92085 .42059 L .93798 .42328 L p
.777 .43 .398 r
F P
s
P
p
.008 w
.90769 .25282 m
.91454 .36924 L
s
P
p
.002 w
.86755 .68944 m .91455 .62307 L .8973 .62098 L p
.723 .787 .903 r
F P
s
P
p
.008 w
.82304 .71177 m
.8633 .69544 L
s
P
p
.008 w
.91251 .67547 m
.93209 .66753 L
s
P
p
.002 w
.8973 .62098 m .85061 .68759 L .86755 .68944 L p
.723 .787 .903 r
F P
s
P
p
.008 w
.8633 .69544 m
.91251 .67547 L
s
P
p
.002 w
.94102 .52398 m .93798 .42328 L .92085 .42059 L p
.802 .602 .631 r
F P
s
P
p
.002 w
.91455 .62307 m .94102 .52398 L .9237 .52156 L p
.785 .699 .769 r
F P
s
P
p
.008 w
.92678 .57728 m
.93209 .66753 L
s
P
p
.008 w
.92354 .52219 m
.92358 .52293 L
s
P
p
.002 w
.9237 .52156 m .8973 .62098 L .91455 .62307 L p
.785 .699 .769 r
F P
s
P
p
.002 w
.92085 .42059 m .9237 .52156 L .94102 .52398 L p
.802 .602 .631 r
F P
s
P
p
.002 w
.89335 .52875 m .89855 .51445 L .90577 .50356 L p
.957 .948 .699 r
F P
s
P
p
.002 w
.05344 .26268 m
.21801 .02482 L
s
.21801 .02482 m
.19619 .61574 L
s
.19619 .61574 m
.02482 .75387 L
s
.02482 .75387 m
.05344 .26268 L
s
.94115 .1703 m
.21801 .02482 L
s
.21801 .02482 m
.19619 .61574 L
s
.19619 .61574 m
.97518 .70072 L
s
.97518 .70072 m
.94115 .1703 L
s
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{327, 273},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005700014A000`40O003h00OogooB7oo003oOom8
Ool00?moodQoo`00ogooB7oo003oOom8Ool00?moodQoo`00ogooB7oo003oOom8Ool00?moodQoo`00
Agoo0`00oGoo0016Ool20002Ool5003hOol004Ioo`8000Moo`D00?=oo`00AGoo00<007oo000037oo
1@00kWoo0014Ool01000Oomoo`004Goo1@00jGoo0013Ool01@00Oomoogoo00005Woo1@00i7oo0013
Ool01@00Oomoogoo00006goo1@00ggoo0012Ool00`00Oomoo`02Ool00`00Oomoo`0NOol5003JOol0
045oo`03001oogoo00=oo`03001oogoo02=oo`D00=Eoo`00@Goo00<007ooOol00goo00<007ooOol0
:7oo1@00d7oo0010Ool00`00Oomoo`04Ool00`00Oomoo`0]Ool5003;Ool003moo`03001oogoo00Eo
o`03001oogoo039oo`D00<Ioo`00?goo00<007ooOol01Goo00<007ooOol0=goo1@00`Goo000nOol0
0`00Oomoo`06Ool00`00Oomoo`0lOol5002lOol003eoo`03001oogoo00Ioo`03001oogoo049oo`D0
0;Moo`00?7oo00<007ooOol01goo00<007ooOol0Agoo1@00/Woo000lOol00`00Oomoo`07Ool00`00
Oomoo`1<Ool5002]Ool003]oo`03001oogoo00Qoo`03001oogoo055oo`D00:Qoo`00>Woo00<007oo
Ool02Goo00<007ooOol0EWoo1@00Xgoo000jOol00`00Oomoo`09Ool00`00Oomoo`1KOol5002NOol0
03Uoo`03001oogoo00Yoo`03001oogoo061oo`D009Uoo`00>7oo00<007ooOol02goo00<007ooOol0
IGoo1@00U7oo000hOol00`00Oomoo`0;Ool00`00Oomoo`1ZOol5002?Ool003Moo`03001oogoo00ao
o`03001oogoo06moo`D008Yoo`00=Woo00<007ooOol03Goo00<007ooOol0M7oo1@00QGoo000eOol0
0`00Oomoo`0>Ool00`00Oomoo`1iOol50020Ool003Eoo`03001oogoo00ioo`03001oogoo07ioo`D0
07]oo`00=7oo00<007ooOol03goo00<007ooOol0Pgoo1@00MWoo000cOol00`00Oomoo`0@Ool00`00
Oomoo`28Ool5001aOol003=oo`03001oogoo011oo`03001oogoo08eoo`D006aoo`00<Woo00<007oo
Ool04Goo00<007ooOol0TWoo1@00Igoo000aOol00`00Oomoo`0BOol00`00Oomoo`2GOol5001ROol0
035oo`03001oogoo019oo`03001oogoo09aoo`D005eoo`00<7oo00<007ooOol04goo00<007ooOol0
1Goo0P00VWoo1@00F7oo000_Ool00`00Oomoo`0DOol00`00Oomoo`05Ool7002JOol5001COol002io
o`03001oogoo01Eoo`03001oogoo00Aoo`d009Yoo`D004ioo`00;Woo00<007ooOol05Goo00<007oo
Ool017oo0P001Woo2`00VGoo1@00BGoo000]Ool00`00Oomoo`0FOol00`00Oomoo`03Ool2000<Ool;
002IOol50014Ool002aoo`03001oogoo01Moo`03001oogoo009oo`<0019oo`/009Qoo`D003moo`00
;7oo00<007ooOol05goo00@007ooOomoo`<001Qoo`/009Qoo`D003Yoo`00:goo00<007ooOol067oo
00<007ooOol00`007goo2P00V7oo1@00=Goo000ZOol00`00Oomoo`0IOol00`00Oomoo`02000UOol;
002GOol5000`Ool002Yoo`03001oogoo01Qoo`03001oogoo008002]oo`/009Moo`D002]oo`00:Goo
00<007ooOol06Goo00<007oo00000P00<Goo2`00UWoo1@009Woo000XOol00`00Oomoo`0JOol4000g
Ool;002FOol5000QOol002Moo`03001oogoo01]oo`<003ioo`X009Ioo`D001aoo`009goo00<007oo
Ool06goo0P00A7oo2`00UGoo1@005goo000VOol00`00Oomoo`0KOol30019Ool;002EOol3000DOol0
02Eoo`03001oogoo01]oo`<0051oo`/008moo`<001Aoo`009Goo00<007ooOol06Woo1000EGoo2`00
RGoo00@007ooOol001Aoo`0097oo00<007ooOol06goo0P0000=oo`00Ool0FWoo2P00Pgoo00D007oo
Oomoo`0001Aoo`008goo00<007ooOol06goo0P000Woo00<007ooOol0GWoo2`00Ngoo0P0017oo00<0
07ooOol04Woo000SOol00`00Oomoo`0JOol30002Ool00`00Oomoo`1SOol;001eOol00`00Oomoo`04
Ool00`00Oomoo`0BOol0029oo`03001oogoo01Yoo`<000=oo`03001oogoo06Uoo`X006ioo`8000Mo
o`03001oogoo019oo`008Goo00<007ooOol06Woo0`0017oo00<007ooOol0KWoo2`00Igoo00<007oo
Ool01goo00<007ooOol04Woo000POol00`00Oomoo`0KOol20005Ool00`00Oomoo`1cOol;001POol2
000;Ool00`00Oomoo`0AOol0021oo`03001oogoo01Yoo`8000Ioo`03001oogoo07Uoo`/005Uoo`03
001oogoo00]oo`03001oogoo015oo`007goo00<007ooOol06Woo0`001Woo00<007ooOol0OWoo2`00
Dgoo00<007ooOol037oo00<007ooOol04Goo000NOol00`00Oomoo`0JOol30007Ool00`00Oomoo`24
Ool:001<Ool2000?Ool00`00Oomoo`0AOol001ioo`03001oogoo01Yoo`8000Qoo`03001oogoo08Uo
o`/004Eoo`03001oogoo00moo`03001oogoo015oo`007Goo00<007ooOol06Woo0P002Goo00<007oo
Ool0SWoo2`00?Woo0P004Woo00<007ooOol04Goo000LOol00`00Oomoo`0JOol30009Ool00`00Oomo
o`2DOol;000gOol00`00Oomoo`0BOol00`00Oomoo`0AOol001aoo`03001oogoo01Uoo`<000Yoo`03
001oogoo09Uoo`/0035oo`03001oogoo01=oo`03001oogoo015oo`006goo00<007ooOol06Goo0`00
2goo00<007ooOol0Wgoo2P00:Woo0P005Woo00<007ooOol04Goo000JOol00`00Oomoo`0JOol2000<
Ool00`00Oomoo`2TOol;000SOol00`00Oomoo`0FOol00`00Oomoo`0AOol001Uoo`03001oogoo01Yo
o`8000eoo`03001oogoo0:Uoo`/001aoo`8001Uoo`03001oogoo015oo`006Goo00<007ooOol06Goo
0`003Goo00<007ooOol0[goo2`005Goo00<007ooOol06Goo00<007ooOol04Goo000HOol00`00Oomo
o`0IOol3000>Ool00`00Oomoo`2dOol;000>Ool2000LOol00`00Oomoo`0AOol001Moo`03001oogoo
01Yoo`8000moo`03001oogoo0;Yoo`X000Qoo`03001oogoo01aoo`03001oogoo015oo`005goo00<0
07ooOol06Goo0P003goo00<007ooOol0`7oo2`0000=oo`00Ool07Woo00<007ooOol04Goo000FOol0
0`00Oomoo`0IOol3000?Ool00`00Oomoo`35Ool;000LOol00`00Oomoo`0AOol001Eoo`03001oogoo
01Uoo`<0011oo`03001oogoo0<Uoo`03001oo`0000X001Moo`03001oogoo011oo`005Goo00<007oo
Ool067oo0`004Goo00<007ooOol0agoo0P001goo2`004Woo00<007ooOol047oo000DOol00`00Oomo
o`0IOol2000BOol00`00Oomoo`36Ool00`00Oomoo`0=Ool;000<Ool00`00Oomoo`0@Ool001=oo`03
001oogoo01Qoo`<001=oo`03001oogoo0<Aoo`8001Eoo`L000]oo`03001oogoo011oo`004Woo00<0
07ooOol06Goo20003Woo00<007ooOol0`goo00<007ooOol05goo1@002goo00<007ooOol047oo000B
Ool00`00Oomoo`0HOol?0008Ool00`00Oomoo`0[Ool4002COol00`00Oomoo`0GOol6000;Ool00`00
Oomoo`0@Ool0015oo`@001Moo`<000Moo``0009oo`03001oogoo02Yoo`8000=VE0H008]oo`8001Qo
o`@0009oo`8000]oo`03001oogoo011oo`004Goo00@007ooOomoo`H0015oo`8000ioo``002Qoo`03
000<3`0000UVE0H008Aoo`03001oogoo01Moo`@000=oo`8000]oo`03001oogoo011oo`004Goo00<0
07ooOol01goo1P002Woo0P005Goo30008Goo00@000`?30l000mVE0H007aoo`8001Qoo`@000Eoo`80
00]oo`03001oogoo011oo`004Goo00<007ooOol03Goo1P000goo0`005goo00@007ooOomoo``001Yo
o`05000<3``?30l0000EIU@7001dOol00`00Oomoo`0GOol40006Ool2000;Ool00`00Oomoo`0@Ool0
015oo`03001oogoo01=oo`L001Ioo`03001oogoo00Moo``001=oo`03000<3``?008<3`03001VE6ID
01YVE0H006eoo`03001oogoo01Ioo`@000Qoo`8000]oo`03001oogoo011oo`004Goo00<007ooOol0
4goo10000goo1P0047oo00<007ooOol03Goo300037oo00<000`?30l00``?00<006IDIU@086ID1P00
IGoo0P0067oo10002Goo0P002goo00<007ooOol047oo000AOol00`00Oomoo`0COol80005Ool6000:
Ool00`00Oomoo`0COol<0006Ool00`0030l<3`0330l00`00IUAVE00VIU@4001POol00`00Oomoo`0F
Ool4000;Ool2000;Ool00`00Oomoo`0@Ool0015oo`03001oogoo01=oo`h000Eoo`L000=oo`03001o
ogoo01Uoo`d000D<3`03001VE6ID02IVE004BcmVE6ID001NOol2000HOol4000<Ool2000;Ool00`00
Oomoo`0@Ool0015oo`03001oogoo019oo`<000Ioo``000Ioo`H001moo`d002EVE003BcmVE6ID00=V
E003001oogoo05]oo`03001oogoo01Ioo`@000ioo`8000]oo`03001oogoo011oo`0047oo00<007oo
Ool04Woo0`003Goo30000goo00<007ooOol01P007goo30007FID00=;?fIDIU@01VID00<007ooOol0
FGoo0P0067oo10003goo0P002goo00<007ooOol047oo000@Ool00`00Oomoo`0BOol2000DOol<0006
Ool6000IOol00`0030l<3`0230l=000DIU@00d/oIUAVE009IU@00`00Oomoo`1HOol00`00Oomoo`0F
Ool4000BOol2000;Ool00`00Oomoo`0?Ool0011oo`03001oogoo015oo`8001]oo``000Ioo`L0019o
o`03000<3``?008<3`03001VE6ID00AVE0`000]VE003001VE6ID00aVE003001oogoo05Moo`03001o
ogoo01Ioo`@001=oo`8000]oo`03001oogoo00moo`0047oo00<007ooOol03goo10007Woo00<007oo
Ool030001goo1P0037oo00<000`?30l00P`?00<006IDIU@02VID300056ID00<007ooOol0EGoo0P00
5goo10005Goo0P002goo00<007ooOol03goo000@Ool00`00Oomoo`0?Ool8000JOol00`00Oomoo`06
Ool<0007Ool60006Ool00`0030l<3`0230l00`00IUAVE00@IU@;00000fID0000000<IU@00`00Oomo
o`1DOol00`00Oomoo`0FOol4000FOol2000;Ool00`00Oomoo`0?Ool0011oo`03001oogoo011oo`d0
01Aoo`03001oogoo00aoo``000Moo`L000@<3`03001VE6ID019VE004DI1VE6IDIU@=0007IU@00`00
Oomoo`1BOol2000GOol4000HOol2000;Ool00`00Oomoo`0?Ool0011oo`03001oogoo01Moo`d000eo
o`03001oogoo019oo``000Moo`03000<3``?008<3`03001VE6ID01MVE0=AT0d000=VE003001oogoo
055oo`03001oogoo01Ioo`@001Uoo`8000]oo`03001oogoo00moo`0047oo00<007ooOol07Goo3@00
1goo00<007ooOol067oo3@001@`?00<006IDIU@05VID1U6@0`0016ID200017oo0P00C7oo00<007oo
Ool05Goo10006goo0P002goo00<007ooOol03goo000@Ool00`00Oomoo`0TOol>000POol7000530l0
0`00IUAVE00EIU@20007DI030006IU@?0015Ool2000GOol4000LOol2000;Ool00`00Oomoo`0?Ool0
011oo`03001oogoo02Yoo`h0021oo`03000<3``?00<<3`03001VE6ID01IVE003BOH0000000QAT0<0
00IVE18003ioo`03001oogoo01Eoo`@001ioo`8000]oo`03001oogoo00moo`0047oo00<007ooOol0
<7oo3P006Woo00<000`?30l00``?00<006IDIU@05VID0dWf0P00256@0`0016ID00<007ooOol02Goo
3000=Woo0P005goo10007goo0P002goo00<007ooOol03goo000@Ool00`00Oomoo`0`Ool00`00Oomo
o`05Ool=000COol00`0030l<3`0330l00`00IUAVE00FIU@5BOH30007DI0400000fID001oo`0@Ool<
000_Ool00`00Oomoo`0EOol4000QOol2000;Ool00`00Oomoo`0?Ool0011oo`03001oogoo031oo`03
001oogoo00]oo`d000eoo`03000<3``?00<<3`<001MVE0M9mP8000QAT0@001Ioo``002Moo`8001Mo
o`@000aoo`<001=oo`8000]oo`03001oogoo00moo`0047oo00<007ooOol0<7oo00<007ooOol04Woo
3@001Woo00<000`?30l00P`?00@004/oBcm;?`H0015VE0U9mP<000MAT0@001Yoo``0021oo`03001o
ogoo01Eoo`@000aoo`80008TdPH000ioo`8000]oo`03001oogoo00moo`0047oo00<007ooOol0<7oo
00<007ooOol067oo3P000``?00<004/oBcl01T/o20002fID00<004WfBOH02DWf0P00256@10007Goo
2`006Woo00<007ooOol05Goo10002goo0P001RCB0P000S@00P003Goo0P002Woo00<007ooOol03goo
000@Ool00`00Oomoo`0`Ool00`00Oomoo`0NOol8000230l00`00Bcm;?`0<Bcl200000d/o00000004
0006IU@2000;BOH20008DI020002A004000MOol;000BOol2000GOol3000;Ool2000:9=820002=002
000;Ool2000:Ool00`00Oomoo`0?Ool0011oo`03001oogoo031oo`03001oogoo02Eoo`03000<3`00
01E;?`T00003IU@f?3Hl008000Y9mP<000MAT0<00003A00007oo00L001]oo``000]oo`03001oogoo
01Eoo`@000]oo`03000TdRCB00`TdP<00003=000000000Uoo`8000Yoo`03001oogoo00moo`0047oo
00<007ooOol0<7oo00<007ooOol09Goo0P0074/o1@0013Hl00<004WfBOH02DWf0P00256@0P000T@0
1Woo1P006goo30000goo0P005goo10002Woo0P004RCB0P0000<d000000001goo0P002goo00<007oo
Ool03Woo000?Ool00`00Oomoo`0aOol00`00Oomoo`0UOol4000NBcl20005=S`00`00BOI9mP09BOH3
0007DI0200000d@0001oo`09Ool6000KOol<000DOol4000:Ool2000F9=8200000c@000000005Ool2
000;Ool00`00Oomoo`0>Ool000moo`03001oogoo035oo`03001oogoo02Uoo`H001Y;?`8000Df?080
00]9mP8000MAT0T000Uoo`L001Yoo``000eoo`@000Uoo`8001XTdPD000=oo`8000]oo`03001oogoo
00ioo`003goo00<007ooOol0<Goo00<007ooOol0;goo1P005T/o0P001SHl00<004WfBOH02DWf0P00
1e6@3P002Goo1P004goo00<007ooOol017oo2`001Woo10002Goo0P007BCB00<0066/HJ`00`0000=o
o`0000002goo00<007ooOol03Woo000?Ool00`00Oomoo`0aOol00`00Oomoo`0eOol6000BBcl30005
=S`2000:BOH30007DI0300000d@00000000<0008Ool6000<Ool00`00Oomoo`0;Ool>0009Ool00`00
9=8TdP0N9=801P00HJaQ[66/001oo`8000]oo`03001oogoo00ioo`003goo00<007ooOol0<Goo00<0
07ooOol0>goo1`003T/o0P001CHl0P002dWf0P00256@0P0000=40000Ool00goo3P001goo1P0017oo
0P004goo1`002Woo00<002CB9=807bCB00<0066/HJ`00V6/0`002goo00<007ooOol03Woo000?Ool0
0`00Oomoo`0aOol00`00Oomoo`12Ool6000:Bcl30004=S`2000;BOH20008DI020002A009Ool=0007
Ool4000GOol4000;Ool00`009=8TdP0P9=801000HJaQ[66/0`002goo00<007ooOol03Woo000?Ool0
0`00Oomoo`0aOol00`00Oomoo`18Ool60004Bcl00`00Oomoo`020005=S`2000:BOH30007DI030000
0d@0001oo`0<Ool=0003Ool00`00Oomoo`0COol4000<Ool00`009=8TdP0Q9=800`00HJaQ[002HJ`2
000;Ool00`00Oomoo`0>Ool000moo`03001oogoo035oo`03001oogoo04ioo`@000Eoo`8000Df?080
00]9mP8000QAT0800003A00007oo011oo`h0015oo`@000eoo`03000TdRCB024TdP03001Q[66/009Q
[08000]oo`03001oogoo00ioo`003goo00<007ooOol0<Goo00<007ooOol0FGoo0`0013Hl0`002TWf
0`001e6@0`0000=40000Ool057oo3P0027oo10003Woo00<002CB9=808bCB00@0066/HJaQ[08000]o
o`03001oogoo00ioo`003goo00<007ooOol0<Goo00<007ooOol0G7oo0P001CHl0P002dWf0P00256@
0P0000=40000Ool05Goo00@007ooOomooa8000ioo`03000TdRCB02@TdP03001Q[66/009Q[08000Yo
o`03001oogoo00ioo`003goo00<007ooOol0<Goo00<007ooOol0GWoo0P001CHl0P002dWf0P00256@
0P0000=40000Ool04goo00<007ooOol027oo2@0047oo00<002CB9=809BCB00D0066/HJaQ[00000]o
o`03001oogoo00ioo`003goo00<007ooOol0<Goo00<007ooOol0H7oo0`0013Hl0`002TWf0`001e6@
0`0000=40000000047oo00<007ooOol037oo100047oo00<002CB9=809RCB00<0066/HJ`00V6/00<0
07ooOol027oo00<007ooOol03Woo000?Ool00`00Oomoo`0aOol00`00Oomoo`1SOol20005=S`2000;
BOH20008DI0200000d@0000000050009Ool00`00Oomoo`0;Ool3000BOol00`009=8TdP0W9=801@00
HJaQ[66/00002Woo00<007ooOol03Woo000?Ool00`00Oomoo`0aOol00`00Oomoo`1UOol30004=S`2
000;BOH30007DI0>0003Ool00`00Oomoo`09Ool4000BOol00`009=8TdP0X9=800`00HJaQ[002HJ`0
0`00Oomoo`07Ool00`00Oomoo`0>Ool000moo`03001oogoo035oo`03001oogoo06Qoo`8000@f?0<0
00]9mP8000QAT0800003A00007oo00`000Qoo`@0019oo`03000TdRCB02TTdP03001Q[66/009Q[003
001oogoo00Qoo`03001oogoo00eoo`003goo00<007ooOol0<Goo00<007ooOol0JWoo0P001CHl0P00
2dWf0P00256@0P0000=40000Ool017oo400057oo00<002CB9=80:RCB00<0066/HJ`00V6/00<007oo
Ool01goo00<007ooOol03Goo000?Ool00`00Oomoo`0aOol00`00Oomoo`1/Ool30004=S`3000:BOH3
0007DI050005Ool00`00Oomoo`09000DOol00`009=8TdP0[9=800`00HJaQ[002HJ`00`00Oomoo`07
Ool00`00Oomoo`0=Ool000moo`03001oogoo035oo`03001oogoo06moo`8000Df?08000]9mP8000QA
T0800003A00007oo009oo`03001oogoo00Ioo`8001Eoo`03000TdRCB02`TdP03001Q[66/009Q[003
001oogoo00Ioo`03001oogoo00eoo`003Woo00<007ooOol0<Woo00<007ooOol0LGoo0`0013Hl0P00
2dWf0P00256@0P0000A40000000000Qoo`8001Aoo`03000TdRCB02dTdP03001Q[66/009Q[003001o
ogoo00Ioo`03001oogoo00eoo`003Woo00<007ooOol0<Woo00<007ooOol0M7oo0P0013Hl0`002TWf
0`001e6@1@001goo0P0057oo00<002CB9=80;BCB00<0066/HJ`00V6/00<007ooOol01Woo00<007oo
Ool03Goo000>Ool00`00Oomoo`0aOol00`00Oomoo`1gOol20005=S`2000;BOH20008DI0200000d@0
001oo`04Ool2000COol00`009=8TdP0_9=800`00HJaQ[002HJ`00`00Oomoo`05Ool00`00Oomoo`0=
Ool000ioo`03001oogoo035oo`03001oogoo07Uoo`<000@f?0<000Y9mP<000MAT0D0009oo`80019o
o`03000TdRCB030TdP03001Q[66/009Q[003001oogoo00Eoo`03001oogoo00eoo`003Woo00<007oo
Ool0<Goo00<007ooOol0O7oo0P001CHl0P002dWf0P00256@1P004Woo00<002CB9=80<BCB00<0066/
HJ`00V6/00<007ooOol017oo00<007ooOol03Goo000>Ool00`00Oomoo`0aOol00`00Oomoo`1nOol2
0005=S`2000;BOH20008DI0200000d@00000000@Ool00`009=8TdP0b9=800`00HJaQ[002HJ`00`00
Oomoo`04Ool00`00Oomoo`0=Ool000ioo`03001oogoo035oo`03001oogoo081oo`<000@f?0<000Y9
mP<000MAT0D000ioo`03000TdRCB03<TdP03001Q[66/009Q[003001oogoo00=oo`03001oogoo00eo
o`003Woo00<007ooOol0<Goo00<007ooOol0Pgoo0P001CHl0P002dWf0P00256@1@002Woo00<002CB
9=80=2CB1P001Goo00<007ooOol03Goo000>Ool00`00Oomoo`0aOol00`00Oomoo`25Ool30004=S`3
000:BOH30007DI050008Oolg9=800`00IWAVM002IW@00`00Oomoo`03Ool00`00Oomoo`0=Ool000io
o`03001oogoo035oo`03001oogoo08Qoo`8000Df?08000]9mP8000QAT0@000Eoo`03000TdRCB03DT
dP03001VM6Id009VM003001oogoo00=oo`03001oogoo00eoo`003Woo00<007ooOol0<Goo00<007oo
Ool0RWoo0P001CHl0P002dWf0P00256@1@000Woo00<002CB9=80=BCB00<006IdIW@00VId00<007oo
Ool00goo00<007ooOol03Goo000>Ool00`00Oomoo`0aOol00`00Oomoo`2<Ool30004=S`3000:BOH3
0007DI06000g9=800`00IWAVM002IW@00`00Oomoo`03Ool00`00Oomoo`0=Ool000ioo`03001oogoo
035oo`03001oogoo08moo`8000Df?08000]9mP8000QAT0D003DTdP03001VM6Id009VM003001oogoo
00Aoo`03001oogoo00aoo`003Woo00<007ooOol0<Goo00<007ooOol0TGoo0P001CHl0P002dWf0P00
256@1@00<bCB00<006IdIW@00VId00<007ooOol017oo00<007ooOol037oo000>Ool00`00Oomoo`0a
Ool00`00Oomoo`2COol30004=S`3000:BOH30008DI04000a9=800`00IWAVM002IW@00`00Oomoo`04
Ool00`00Oomoo`0<Ool000ioo`03001oogoo035oo`03001oogoo09Ioo`8000Df?08000]9mP8000QA
T0D002hTdP03001VM6Id009VM003001oogoo00Aoo`03001oogoo00aoo`003Woo00<007ooOol0<Goo
00<007ooOol0UWoo00<007oo00000P0013Hl0`002TWf0`001e6@1@00;2CB00<006IdIW@00VId00<0
07ooOol017oo00<007ooOol037oo000>Ool00`00Oomoo`0aOol00`00Oomoo`2FOol00`00Oomoo`02
Ool20005=S`2000;BOH20008DI05000Y9=800`00IWAVM002IW@00`00Oomoo`04Ool00`00Oomoo`0<
Ool000eoo`03001oogoo039oo`03001oogoo09Ioo`03001oogoo00Aoo`8000Df?08000]9mP8000QA
T0800003A000000002LTdP03001VM6Id009VM003001oogoo00Aoo`03001oogoo00aoo`003Goo00<0
07ooOol0<Woo00<007ooOol0UWoo00<007ooOol01Goo100013Hl0`002TWf0`001e6@1@009BCB00<0
06IdIW@00VId00<007ooOol017oo00<007ooOol037oo000=Ool00`00Oomoo`0bOol00`00Oomoo`2F
Ool00`00Oomoo`05Ool20002Ool20005=S`2000;BOH20008DI05000R9=800`00IWAVM002IW@00`00
Oomoo`04Ool00`00Oomoo`0<Ool000eoo`03001oogoo039oo`03001oogoo09Ioo`03001oogoo00Eo
o`8000Aoo`<000@f?0<000Y9mP<000MAT0D0020TdP03001VM6Id009VM003001oogoo00Aoo`03001o
ogoo00aoo`003Goo00<007ooOol0<Woo00<007ooOol0UWoo00<007ooOol01Goo0P001goo0P001CHl
0P002dWf0P00256@1@007BCB00<006IdIW@00VId00<007ooOol017oo00<007ooOol037oo000=Ool0
0`00Oomoo`0bOol00`00Oomoo`2FOol00`00Oomoo`05Ool20009Ool20005=S`2000;BOH20008DI02
00000d@00000000K9=800`00IWAVM002IW@00`00Oomoo`04Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo039oo`03001oogoo09Ioo`03001oogoo00Eoo`8000]oo`<000@f?0<000Y9mP<000MAT0D001TT
dP8000AVM003001oogoo00=oo`03001oogoo00aoo`003Goo00<007ooOol0<Woo00<007ooOol0UWoo
00<007ooOol01Goo0P002goo00<002CB9=800P001CHl0P002dWf0P00256@1@005RCB0P0016Id00<0
07ooOol00goo00<007ooOol037oo000=Ool00`00Oomoo`0bOol00`00Oomoo`2FOol00`00Oomoo`05
Ool2000;Ool00`009=8TdP029=820005=S`2000;BOH20008DI05000D9=820004IW@00`00Oomoo`03
Ool00`00Oomoo`0<Ool000eoo`03001oogoo039oo`03001oogoo09Ioo`03001oogoo00Eoo`8000]o
o`03000TdRCB00@TdP<000@f?0<000Y9mP<000QAT0D0014TdP8000AVM003001oogoo00=oo`03001o
ogoo00aoo`003Goo00<007ooOol0<Woo00<007ooOol0UWoo00<007ooOol01Goo0P002goo00<002CB
9=801bCB0P001CHl0P002dWf0P00256@0P0000=4000000003bCB0P0016Id00<007ooOol017oo00<0
07ooOol02goo000=Ool00`00Oomoo`0aOol00`00Oomoo`2DOol200000goo001oo`06Ool2000:Ool0
0`009=8TdP0:9=830004=S`3000:BOH30007DI05000=9=820004IW@00`00Oomoo`04Ool00`00Oomo
o`0;Ool000eoo`03001oogoo035oo`03001oogoo08moo``000Aoo`8000Yoo`03000TdRCB00dTdP80
00Df?08000]9mP8000QAT0D000/TdP03001VM6Id009VM003001oogoo00Aoo`03001oogoo00]oo`00
3Goo00<007ooOol0<Goo00<007ooOol0Sgoo4`002Goo00<002CB9=803bCB0P001CHl0P002dWf0P00
256@1@002BCB00<006IdIW@00VId00<007ooOol017oo00<007ooOol02goo000=Ool00`00Oomoo`0a
Ool00`00Oomoo`2GOol01000Oomoogoo3`0000Eoo`009=8TdV:h010TdP<000@f?0<000Y9mP<000QA
T0@000LTdP03001VM6Id009VM003001oogoo00Aoo`03001oogoo00]oo`003Goo00<007ooOol0<Goo
00<007ooOol0Ugoo00<007ooOol01Goo0P0000=oo`0000002P0000=R^2CB9=804BCB0P001CHl0P00
2dWf0P00256@0P0000=400009=8012CB00<006IdIW@00VId00<007ooOol017oo00<007ooOol02goo
000=Ool00`00Oomoo`0aOol00`00Oomoo`2GOol00`00Oomoo`05Ool20008Ool=000>9=820005=S`3
000:BOH30007DI0200059=800`00IWAVM002IW@00`00Oomoo`04Ool00`00Oomoo`0;Ool000aoo`03
001oogoo039oo`03001oogoo09Moo`03001oogoo00Eoo`8000Uoo`03000TdRCB018000LTdP<000Df
?08000]9mP8000EAT003000TdRCB00@TdP03001VM6Id009VM003001oogoo00Aoo`03001oogoo00]o
o`0037oo00<007ooOol0<Woo00<007ooOol0Ugoo00<007ooOol01Goo0P002Goo00<002CB9=802BCB
4@000RCB0P001CHl0P002dWf0P000U6@00<007_F9=801BCB00<006IdIW@00VId00<007ooOol017oo
00<007ooOol02goo000<Ool00`00Oomoo`0bOol00`00Oomoo`2GOol00`00Oomoo`05Ool20009Ool0
0`009=8TdP0B9=8900039=830004=S`3000:BOH200000g_F9=8TdP059=800`00IWAVM002IW@00`00
Oomoo`04Ool00`00Oomoo`0;Ool000aoo`03001oogoo039oo`03001oogoo09Moo`03001oogoo00Io
o`8000Qoo`03000TdRCB01XTdP03000TdRCB00@TdP8000Df?08000U9mP03001keRCB00HTdP03001V
M6Id009VM003001oogoo00Aoo`03001oogoo00]oo`0037oo00<007ooOol0<Woo00<007ooOol0Ugoo
00<007ooOol01Woo0P0027oo00<002CB9=808bCB0P001CHl0`001TWf00<007_F9=801RCB0`000VId
00<007ooOol017oo00<007ooOol02goo000<Ool00`00Oomoo`0bOol00`00Oomoo`2GOol00`00Oomo
o`06Ool20008Ool00`009=8TdP0U9=830005=S`20003BOH00`00NmHTdP079=800`00I]QVf0030006
Ool00`00Oomoo`0;Ool000aoo`03001oogoo039oo`03001oogoo09Moo`03001oogoo00Ioo`8000Qo
o`04000TdRCBIW@W9=820005=S`200000dWf001keP079=800`00I]QVf003I]P00`00Oomoo`04Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo039oo`03001oogoo09Qoo`03001oogoo00Eoo`8000Qoo`03
000TdRCB02XTdP<000@f?0800003NmHTdRCB00DTdP03001Vf6KH009Vf003001oogoo00Eoo`03001o
ogoo00]oo`0037oo00<007ooOol0<Woo00<007ooOol0V7oo00<007ooOol01Goo0P0027oo00<002CB
9=80;BCB0P000cHl00<007_F9=801RCB00<006KHI]P00VKH00<007ooOol01Woo00<007ooOol02Woo
000<Ool00`00Oomoo`0bOol00`00Oomoo`2HOol00`00Oomoo`05Ool20008Ool00`009=8TdP0_9=82
00000cHl000000069=820004I]P00`00Oomoo`06Ool00`00Oomoo`0:Ool000aoo`03001oogoo039o
o`03001oogoo09Qoo`03001oogoo00Eoo`8000Qoo`03000TdRCB034TdP8000LTdP03001Vf6KH00=V
f003001oogoo00Ioo`03001oogoo00Yoo`0037oo00<007ooOol0<Woo00<007ooOol0V7oo00<007oo
Ool01Goo0P0027oo00<002CB9=80>RCB00<006KHI]P00VKH00<007ooOol01goo00<007ooOol02Woo
000<Ool00`00Oomoo`0bOol00`00Oomoo`2HOol00`00Oomoo`05Ool20008Ool00`009=8TdP0j9=80
0`00I]QVf002I]P00`00Oomoo`07Ool00`00Oomoo`0:Ool000aoo`03001oogoo039oo`03001oogoo
09Qoo`03001oogoo00Eoo`8000Qoo`03000TdRCB03TTdP8000AVf003001oogoo00Moo`03001oogoo
00Yoo`0037oo00<007ooOol0<Woo00<007ooOol0V7oo00<007ooOol01Goo0P0027oo00<002CBIW@0
>BCB00<006KHI]P00fKH00<007ooOol01goo00<007ooOol02Woo000<Ool00`00Oomoo`0bOol00`00
Oomoo`2HOol00`00Oomoo`05Ool20008Ool00`009=8TdP0i9=800`00I]QVf002I]P00`00Oomoo`08
Ool00`00Oomoo`0:Ool000aoo`03001oogoo039oo`03001oogoo09Qoo`03001oogoo00Eoo`8000Qo
o`03000TdRCB03PTdP8000AVf003001oogoo00Qoo`03001oogoo00Yoo`0037oo00<007ooOol0<Woo
00<007ooOol0V7oo00<007ooOol01Goo0P0027oo00<002CB9=80>2CB00<006KHI]P00fKH00<007oo
Ool027oo00<007ooOol02Woo000;Ool00`00Oomoo`0cOol00`00Oomoo`2HOol00`00Oomoo`05Ool2
0008Ool00`009=8TdP0h9=800`00I]QVf003I]P00`00Oomoo`08Ool00`00Oomoo`0:Ool000]oo`03
001oogoo03=oo`03001oogoo09Qoo`03001oogoo00Eoo`8000Qoo`03000TdRCB03PTdP03001Vf6KH
009Vf003001oogoo00Uoo`03001oogoo00Yoo`002goo00<007ooOol0<goo00<007ooOol0V7oo00<0
07ooOol01Goo0P0027oo00<002CB9=80=bCB0P0016KH00<007ooOol02Goo00<007ooOol02Woo000;
Ool00`00Oomoo`0cOol00`00Oomoo`2HOol00`00Oomoo`05Ool20008Ool00`009=8TdP0g9=800`00
I]QVf003I]P00`00Oomoo`09Ool00`00Oomoo`0:Ool000]oo`03001oogoo039oo`03001oogoo09Uo
o`03001oogoo00Eoo`8000Qoo`03001VM2CB03LTdP03001Vf6KH00=Vf003001oogoo00Uoo`03001o
ogoo00Yoo`002goo00<007ooOol0<Woo00<007ooOol0VGoo00<007ooOol01Goo0P0027oo00<002CB
9=80=bCB00<006KHI]P00VKH0P002goo00<007ooOol02Woo000;Ool00`00Oomoo`0bOol00`00Oomo
o`2IOol00`00Oomoo`05Ool20008Ool00`009=8TdP0f9=820004I]P3000;Ool00`00Oomoo`09Ool0
00]oo`03001oogoo039oo`03001oogoo09Uoo`03001oogoo00Eoo`8000Qoo`03000TdRCB03HTdP03
001Vf6KH00=Vf0<000]oo`03001oogoo00Uoo`002goo00<007ooOol0<Woo00<007ooOol0VGoo00<0
07ooOol01Goo0P0027oo00<002CB9=80=RCB00<006KHI]P00fKH0`002goo00<007ooOol02Goo000;
Ool00`00Oomoo`0bOol00`00Oomoo`2IOol00`00Oomoo`05Ool20008Ool00`009=8TdP0f9=800`00
I]QVf002I]P01000Ool000002goo00<007ooOol02Goo000;Ool00`00Oomoo`0bOol00`00Oomoo`2I
Ool00`00Oomoo`05Ool20008Ool00`009=8TdP0e9=800`00I]QVf003I]P01000Ool000002goo00<0
07ooOol02Goo000;Ool00`00Oomoo`0bOol00`00Oomoo`2IOol00`00Oomoo`05Ool20008Ool00`00
9=8TdP0e9=800`00I]QVf003I]P01000Ool000002goo00<007ooOol02Goo000;Ool00`00Oomoo`0b
Ool00`00Oomoo`2IOol00`00Oomoo`05Ool20008Ool00`009=8TdP0e9=800`00I]QVf003I]P01000
Ool000002goo00<007ooOol02Goo000;Ool00`00Oomoo`0bOol00`00Oomoo`2IOol00`00Oomoo`05
Ool20008Ool00`009=8TdP0e9=800`00I]QVf002I]P00`00Oomoo`02000;Ool00`00Oomoo`09Ool0
00]oo`03001oogoo039oo`03001oogoo09Uoo`03001oogoo00Eoo`8000Uoo`03000TdRCB03<TdP03
001Vf6KH00=Vf003001oogoo008000]oo`03001oogoo00Uoo`002goo00<007ooOol0<Woo00<007oo
Ool0VGoo00<007ooOol01Goo0P002Goo00<002CB9=80<bCB00<006KHI]P00fKH00<007ooOol00P00
2goo00<007ooOol02Goo000;Ool00`00Oomoo`0bOol00`00Oomoo`2IOol00`00Oomoo`05Ool20009
Ool00`009=8TdP0c9=800`00I]QVf003I]P00`00Oomoo`02000;Ool00`00Oomoo`09Ool000]oo`03
001oogoo039oo`D009Moo`03001oogoo00Eoo`8000Yoo`03000TdRCB038TdP03001Vf6KH00=Vf0=o
o`8000]oo`03001oogoo00Uoo`002Woo00<007ooOol0<Woo00<007ooOol00goo2@00SWoo00<007oo
Ool01Goo0P002Woo00<002CB9=80<BCB00<006KHI]P016KH0goo0P002goo00<007ooOol02Goo000:
Ool00`00Oomoo`0`Ool2000?Ool90025Ool00`00Oomoo`05Ool2000:Ool00`009=8TdP0a9=870003
Ool2000;Ool00`00Oomoo`09Ool000Yoo`03001oogoo02moo`03001oogoo01Qoo`T007aoo`03001o
ogoo00Eoo`8000]oo`03000TdRCB02lTdP03001O?5ll00=O?003001oogoo009oo`8000]oo`03001o
ogoo00Uoo`002Woo00<007ooOol0;Woo00<007ooOol08Woo2@00Lgoo00<007ooOol01Goo0P002goo
00<002CB9=80;bCB00<005llGc`00ell00<007ooOol00Woo0P002goo00<007ooOol02Goo000:Ool0
0`00Oomoo`0]Ool00`00Oomoo`0/Ool9001ZOol00`00Oomoo`05Ool2000;Ool00`009=8TdP0^9=80
0`00GcaO?003Gc`00`00Oomoo`03Ool2000<Ool00`00Oomoo`08Ool000Yoo`03001oogoo02]oo`80
03Qoo`T0065oo`03001oogoo00Eoo`8000aoo`03000TdRCB02`TdP03001O?5ll00=O?003001oogoo
00Aoo`8000aoo`03001oogoo00Qoo`002Woo00<007ooOol0:Woo00<007ooOol0@Goo2@00F7oo00<0
07ooOol01Goo0P0037oo00<002CB9=80:bCB00<005llGc`00ell00<007ooOol01Goo0P0037oo00<0
07ooOol027oo000:Ool00`00Oomoo`0YOol00`00Oomoo`1;Ool9001?Ool00`00Oomoo`06Ool2000<
Ool00`009=8TdP0Z9=800`00GcaO?003Gc`00`00Oomoo`05Ool2000<Ool00`00Oomoo`08Ool000Yo
o`03001oogoo02Qoo`03001oogoo05Eoo`T004Moo`03001oogoo00Eoo`8000aoo`03000TdRCB02TT
dP03001O?5ll00=O?003001oogoo00Ioo`8000aoo`03001oogoo00Qoo`002Woo00<007ooOol09Woo
0P00HGoo2@00?Woo00<007ooOol01Goo0P0037oo00<002CB9=80:2CB00<005llGc`00ell00<007oo
Ool01goo0P0037oo00<007ooOol027oo000:Ool00`00Oomoo`0UOol00`00Oomoo`1ZOol9000eOol0
0`00Oomoo`05Ool2000=Ool00`009=8TdP0W9=800`00GcaO?002Gc`00`00Oomoo`08Ool2000<Ool0
0`00Oomoo`08Ool000Yoo`03001oogoo02Aoo`03001oogoo07Aoo`T002aoo`03001oogoo00Eoo`80
00eoo`03000TdRCB02HTdP03001O?5ll00=O?003001oogoo00Qoo`8000aoo`03001oogoo00Qoo`00
2Woo00<007ooOol08goo00<007ooOol0OWoo2@008goo00<007ooOol01Goo0P003Goo00<002CB9=80
9BCB00<005llGc`00ell00<007ooOol02Goo0P0037oo00<007ooOol027oo000:Ool00`00Oomoo`0Q
Ool2002:Ool:000IOol00`00Oomoo`05Ool2000>Ool00`009=8TdP0S9=800`00GcaO?003Gc`00`00
Oomoo`0:Ool2000<Ool00`00Oomoo`08Ool000Yoo`03001oogoo021oo`03001oogoo09Aoo`T0011o
o`03001oogoo00Eoo`8000ioo`03000TdRCB02<TdP03001O?5ll00=O?003001oogoo00Yoo`8000ao
o`03001oogoo00Qoo`002Woo00<007ooOol07goo00<007ooOol0WWoo2@001goo00<007ooOol01Goo
0P003Woo00<002CB9=808RCB00<005llGc`00ell00<007ooOol02goo0P0037oo00<007ooOol027oo
000:Ool00`00Oomoo`0NOol00`00Oomoo`2XOol90006Ool2000?Ool00`009=8TdP0P9=800`00GcaO
?003Gc`00`00Oomoo`0;Ool4000;Ool00`00Oomoo`08Ool000Yoo`03001oogoo01aoo`800;9oo`03
001oo`0000P000ioo`03000TdRCB020TdP03001O?5ll009O?003001oogoo00Yoo`H000]oo`03001o
ogoo00Qoo`002Goo00<007ooOol077oo00<007ooOol0/Woo00<007ooOol01Goo0P0000=oo`000000
1`001Woo00<002CB9=807RCB00<005llGc`00ell00<007ooOol027oo1@003Woo00<007ooOol027oo
0009Ool00`00Oomoo`0KOol00`00Oomoo`2cOol00`00Oomoo`05Ool2000:Ool9000M9=800`00GcaO
?003Gc`00`00Oomoo`06Ool6000@Ool00`00Oomoo`08Ool000Uoo`03001oogoo01Yoo`03001oogoo
0;Aoo`03001oogoo00Eoo`8001=oo`T001<TdP03001O?5ll00=O?003001oogoo00Eoo`H001=oo`03
001oogoo00Moo`002Goo00<007ooOol06Goo00<007ooOol0]Goo00<007ooOol01Goo0P0057oo00<0
02CB9=801BCB2@002RCB00<005llGc`00Ull00<007ooOol00goo1P005Woo00<007ooOol01goo0009
Ool00`00Oomoo`0GOol2002hOol00`00Oomoo`05Ool2000EOol00`009=8TdP0=9=8<0003Gc`00`00
Oomoo`07000HOol00`00Oomoo`07Ool000Uoo`03001oogoo01Ioo`03001oogoo0;Qoo`03001oogoo
00Eoo`8001Ioo`80018TdP<00003<cl0000000/001]oo`03001oogoo00Moo`002Goo00<007ooOol0
5Goo00<007ooOol0^Goo00<007ooOol01Goo0P0067oo00<002CB9=8032CB0`0013<o4P005Woo00<0
07ooOol01goo0009Ool00`00Oomoo`0DOol00`00Oomoo`2jOol00`00Oomoo`05Ool2000IOol00`00
9=8TdP099=820004<cl300000goo00000005000:Ool9000=Ool00`00Oomoo`07Ool000Uoo`03001o
ogoo019oo`800;eoo`03001oogoo00Eoo`8001Yoo`8000HTdP<000<c?`<0009oo`H001Ioo`T000Ao
o`03001oogoo00Moo`002Goo00<007ooOol04Goo00<007ooOol0_Goo00<007ooOol01Goo0P0077oo
00<002CB9=800`000S<o10000Woo1P008Woo1@002Goo0009Ool00`00Oomoo`0@Ool00`00Oomoo`2n
Ool00`00Oomoo`05Ool2000MOol70004Ool6000TOol3000;Ool000Uoo`03001oogoo00moo`03001o
ogoo0;moo`03001oogoo00Eoo`8002Eoo`H002Eoo`8000ioo`002Goo00<007ooOol03Goo0P00`Woo
00<007ooOol01Goo0P008goo1P0097oo0`0047oo0009Ool00`00Oomoo`0<Ool00`00Oomoo`32Ool0
0`00Oomoo`05Ool2000QOol5000TOol3000COol000Uoo`03001oogoo00]oo`03001oogoo0<=oo`03
001oogoo00Eoo`8001ioo`H002Aoo`8001Ioo`002Goo00<007ooOol02Woo00<007ooOol0a7oo00<0
07ooOol01Goo0P0077oo1P008goo0`0067oo0009Ool00`00Oomoo`08Ool20037Ool00`00Oomoo`05
Ool2000JOol5000SOol3000KOol000Uoo`03001oogoo00Moo`03001oogoo0<Moo`03001oogoo00Eo
o`8001Qoo`D0029oo`<001ioo`0027oo00<007ooOol01goo00<007ooOol0b7oo00<007ooOol01Goo
0P005Goo1P008Woo0P008Goo0008Ool00`00Oomoo`06Ool00`00Oomoo`39Ool00`00Oomoo`05Ool2
000COol6000QOol3000SOol000Qoo`03001oogoo00Aoo`800<aoo`03001oogoo00Eoo`80011oo`H0
025oo`<002Ioo`0027oo00<007ooOol00goo00<007ooOol0c7oo00<007ooOol01Goo0P003Woo1P00
8Goo0P00:Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`3=Ool00`00Oomoo`05Ool2000;Ool6000Q
Ool3000[Ool000Qoo`05001oogooOol0003@Ool00`00Oomoo`05Ool20009Ool6000POol3000^Ool0
00Qoo`04001oo`00003AOol00`00Oomoo`05Ool20006Ool6000POol3000aOol000Qoo`800==oo`03
001oogoo00Eoo`8000Aoo`H0021oo`8003Aoo`0027oo1P00d7oo00<007ooOol017oo0P0000=oo`00
0000100087oo0`00=Woo000>Ool<0034Ool00`00Oomoo`04Ool7000OOol3000iOol001Yoo``00;Qo
o`03001oogoo00Aoo`@0021oo`8003aoo`009Woo3000[7oo00<007ooOol017oo0P007goo0`00?Woo
000bOol<002POol00`00Oomoo`0ROol30011Ool003ioo``009Aoo`03001oogoo01moo`<004Aoo`00
BWoo3000R7oo00<007ooOol07Goo0P00Agoo001FOol<001lOol00`00Oomoo`0JOol30019Ool0069o
o``0071oo`03001oogoo01Moo`<004aoo`00KWoo2`00IGoo00<007ooOol05Goo0P00Cgoo001iOol<
001IOol00`00Oomoo`0BOol3001AOol008Eoo``004eoo`03001oogoo00moo`<005Aoo`00TGoo3000
@Goo00<007ooOol037oo0`00Egoo002MOol<000eOol00`00Oomoo`0:Ool2001JOol00:Uoo``002Uo
o`03001oogoo00Moo`<005aoo`00]Goo30007Goo00<007ooOol017oo0`00Ggoo0031Ool<000AOol0
0`00Oomoo`02Ool2001ROol00<eoo``000Eoo`03001oo`00008006Aoo`00fGoo1`00Igoo003oOom8
Ool00?moodQoo`00ogooB7oo003oOom8Ool00?moodQoo`00ogooB7oo003oOom8Ool00?moodQoo`00
\
\>"],
  ImageRangeCache->{{{0, 326}, {272, 0}} -> {0.0174599, 0.0318746, 0.00309178,
   0.00309178}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Output Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " numerical output functions return expressions that evaluate to numbers or \
vectors, such as the distance between two points, the angle between two \
lines, or the coordinates of a point. These functions take ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " point, vector, and axis objects as arguments, identical in structure to \
the geometry objects used when building constraints. When local point numbers \
are used, the local coordinates are taken from the current body objects, as \
specified with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nEach of the output functions is demonstrated in the context of the \
quick-return mechanism model defined in the previous subsection."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global coordinates ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" Eo",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ei",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ej",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ek",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifying the global location and orientation of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Distance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["poi",
    FontSlant->"Italic"],
  StyleBox["nt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["p",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["oint2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the distance between the two points.\n\n",
  StyleBox["Rotation[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The angle and axis imply that body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " has been rotated ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about the specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with respect to the global coordinate system.\n\n",
  StyleBox["EulerParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of Euler parameters ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Eo",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ei",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ej",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ek",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["EulerParameters[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, ",
    FontSlant->"Italic"],
  StyleBox["vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of Euler parameters\n",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Eo",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ei",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ej",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Ek",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " associated with a rotation of ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["IncludedAngle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vec",
    FontSlant->"Italic"],
  StyleBox["tor1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vect",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["or2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the positive angle between the two ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["IntersectionPoint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ax",
    FontSlant->"Italic"],
  StyleBox["is1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["a",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["xis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the point of intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and a plane that is specified by ",
  StyleBox["axis2.",
    FontSlant->"Italic"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Output functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointToLineDistance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["po",
    FontSlant->"Italic"],
  StyleBox["int",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["a",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["xis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", measured perpendicular to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["PointToPlaneDistance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["poi",
    FontSlant->"Italic"],
  StyleBox["nt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["a",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["xis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the perpendicular distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to a plane that is normal to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The axis is typically a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. \n\n",
  StyleBox["ProjectedAngle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vect",
    FontSlant->"Italic"],
  StyleBox["or1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vec",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["tor3",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the counterclockwise angle measured from the direction of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " to the direction of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", as projected on a plane that is normal to ",
  StyleBox["vector3.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["ProjectOnLine[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vect",
    FontSlant->"Italic"],
  StyleBox["or1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vec",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["tor2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the vector component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is in the direction of ",
  StyleBox["vector2.",
    FontSlant->"Italic"],
  " \n\n",
  StyleBox["ProjectOnLine[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["poi",
    FontSlant->"Italic"],
  StyleBox["nt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axi",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the location of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", projected orthogonally onto ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["ProjectOnPlane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vec",
    FontSlant->"Italic"],
  StyleBox["tor1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vect",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["or2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the vector component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is orthogonal to ",
  StyleBox["vector2.",
    FontSlant->"Italic"],
  " \n\n",
  StyleBox["ProjectOnPlane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["po",
    FontSlant->"Italic"],
  StyleBox["int",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axi",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["s",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the location of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", projected orthogonally onto a plane that is specified by ",
  StyleBox["axis.",
    FontSlant->"Italic"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["More output functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to convert a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " point object into the global coordinates of the point."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the global coordinates of the attachment point of the connecting \
rod on the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[Point[crank, 2]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({16\ \((Ei2\ Ej2 - Ek2\ Eo2)\) + X2, 
      16\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\) + Y2, 
      16\ \((Ej2\ Ek2 + Ei2\ Eo2)\) + Z2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " assumes a point object if only the arguments of ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are given."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[crank, 2]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({16\ \((Ei2\ Ej2 - Ek2\ Eo2)\) + X2, 
      16\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\) + Y2, 
      16\ \((Ej2\ Ek2 + Ei2\ Eo2)\) + Z2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(% /. SolveMech[.25] // Chop\), 
    \(%% /. SolveMech[.4] // Chop\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 10.0000000000000022`, 20.`}\)], "Output"],

Cell[BoxData[
    \({0, 3.52786404499981909`, 16.7022820183394493`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to find the absolute distance between any two points in \
space. The two points can be on one body or two different bodies."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the distance from a point on the axis of the crank to the origin of \
the slider."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Distance[Point[crank, 1], Point[slider, 0]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\[Sqrt]\((
        \((\(-16\)\ \((\(-\(1\/2\)\) + Ei2\^2 + Eo2\^2)\) - X2 + X3)\)\^2 + 
          \((\(-16\)\ \((Ei2\ Ej2 + Ek2\ Eo2)\) - Y2 + Y3)\)\^2 + 
          \((\(-16\)\ \((Ei2\ Ek2 - Ej2\ Eo2)\) - Z2 + Z3)\)\^2)\)\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(% /. SolveMech[.3]\), 
    \(%% /. SolveMech[.2]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(20.5939579294871055`\)], "Output"],

Cell[BoxData[
    \(19.0891327487326485`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the length of the line from the center of the crank to the drive \
pin."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Distance[Point[crank, 0], Point[crank, 2]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(8\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that it was not necessary to apply a solution rule to the last example \
to get a numerical result because the dimension that was measured was a \
constant."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the minimum distance between the crank axis and the center line of \
the connecting rod."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(PointToLineDistance[Point[crank, 0], Line[crank, 2, slider, 0]] /. 
      SolveMech[.25]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(5.96284793999944007`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the angle between the connecting rod and the crank axis. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(IncludedAngle[Line[crank, 2, slider, 0], Vector[crank, 1]] /. 
      SolveMech[.3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.775575456052875455`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now convert the previous result to degrees."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\/Degree\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(44.4372003257638237`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The measure of an angle in 3D space requires a reference frame for \
measurement. ",
  StyleBox["ProjectedAngle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " allows the plane of projection of the angle to be specified."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the angle of a line on the crank, relative to a line on the ground, \
as viewed looking down the crank axis. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ProjectedAngle[Vector[crank, 2], Vector[ground, 4], Line[ground, 1, 2]]
      \)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ArcTan[16000\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\), 
      16000\ \((Ej2\ Ek2 + Ei2\ Eo2)\)]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now get a numerical result at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.35."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. SolveMech[.35]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(2.19911485751285518`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This angle should be equal to 35/100 of a turn, since that is what we have \
specified with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(%\/\(2\ \[Pi]\)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.350000000000000044`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This finds the intersection of the connecting rod axis and a horizontal \
plane through the crank axis."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntersectionPoint[Line[crank, 2, slider, 0], 
        Plane[ground, 1, 2, {0, 14, 12}]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({8.07162435010265078`, 3.4415411371372202`, 12}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The angular orientation of a body in 3D space can be uniquely specified by \
a single rotation about a fixed axis. ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angle and axis associated with the current spatial \
orientation of a body. See Section 4.2 for more examples on the angular \
orientation of 3D bodies."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This finds the angle and axis of rotation of the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rotation[crank]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2\ ArcCos[Eo2], {Ei2\/\@\(1 - Eo2\^2\), Ej2\/\@\(1 - Eo2\^2\), 
        Ek2\/\@\(1 - Eo2\^2\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. SolveMech[.35]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.19911485751285518`, {1.`, 0.`, 0.`}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Vector Algebra Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " vector algebra functions perform many common vector algebra operations, \
such as cross and dot products of vectors. These functions can be used to \
build more complicated functions that are not provided by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These functions take point, vector, and axis objects as arguments, just \
like the output functions described in the previous section. When local point \
numbers are used, the local coordinates are taken from the current body \
objects, as specified with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nEach of the vector algebra functions is demonstrated in the context \
of the slider-crank mechanism model defined at the beginning of this \
section."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Direction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["poi",
    FontSlant->"Italic"],
  StyleBox["nt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the vector from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2.",
    FontSlant->"Italic"],
  "\n\n",
  StyleBox["Direction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global direction vector of the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Magnitude[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the magnitude or length of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Unit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a unit vector in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Cross[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vecto",
    FontSlant->"Italic"],
  StyleBox["r1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["vec",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["tor2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the cross product of the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["RotationMatrix[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["a",
    FontSlant->"Italic"],
  StyleBox["ng",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["ve",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["ctor",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 3D rotation matrix representing a rotation of ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about the specified ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["RotationMatrix[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the matrix associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["SkewSym[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the skew symmetric matrix associated with the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SkewSym[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox[".",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " is equal to ",
  StyleBox["Cross[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",\n\n",
  StyleBox["PointToLocal[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bn",
    FontSlant->"Italic"],
  StyleBox["um",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["po",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["int",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", relative to the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Vector algebra functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to convert ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " vector objects into 3D vectors in global coordinates."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the direction vector of the connecting rod."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Direction[Line[crank, 2, slider, 0]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-16\)\ \((Ei2\ Ej2 - Ek2\ Eo2)\) - X2 + X3, 
      \(-16\)\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\) - Y2 + Y3, 
      \(-16\)\ \((Ej2\ Ek2 + Ei2\ Eo2)\) - Z2 + Z3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. SolveMech[.4]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({24.6695754049362703`, \(-3.52786404500042038`\), 
      \(-16.7022820183397868`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Several ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " output functions are textbook vector algebra functions that are capable \
of dealing with normal 3D vectors or ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " vector/axis objects interchangeably."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can return the length of the line from one end of the connecting rod to \
the other."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Magnitude[Line[crank, 2, slider, 0]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(29.9999999999999911`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the length of a simple 3D vector. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Magnitude[{1, \(-12\), 13}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\@314\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Unit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also works with vectors or vector objects."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Unit[{3, 5, \(-1\)}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({3\/\@35, \@\(5\/7\), \(-\(1\/\@35\)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The cross product of two vectors is found with the ",
  StyleBox["Cross",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the cross product of a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object and a vector."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Cross[Line[crank, 2, slider, 0], {0, 3, 2}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2\ \((\(-16\)\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\) - Y2 + Y3)\) + 
        3\ \((16\ \((Ej2\ Ek2 + Ei2\ Eo2)\) + Z2 - Z3)\), 
      2\ \((16\ \((Ei2\ Ej2 - Ek2\ Eo2)\) + X2 - X3)\), 
      3\ \((\(-16\)\ \((Ei2\ Ej2 - Ek2\ Eo2)\) - X2 + X3)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now get a numerical result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. SolveMech[.5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({31.9999999987513294`, \(-54.8452368035533943`\), 82.2678552053301004`}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the 3D rotation matrix associated with the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(RotationMatrix[crank] /. SolveMech[.4]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.999999999999999822`, 0.`, 0.`}, {0.`, \(-0.809016994374947451`\), 
        \(-0.587785252292473181`\)}, {0.`, 0.587785252292473181`, 
        \(-0.809016994374947451`\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the skew symmetric matrix operator."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SkewSym[{a, b, c}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, \(-c\), b}, {c, 0, \(-a\)}, {\(-b\), a, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"The global coordinates of a point specified in a local reference frame are \
equal to the coordinates of the origin of the reference frame plus the local \
coordinates of the point, rotated into the global reference frame."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a calculation of the global coordinates of the local point {3, 8} on \
the slider."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[crank, 0] + RotationMatrix[crank].{3, 8, \(-4\)} /. 
      LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.99999999999999911`, 5.87900505417031293`, 19.9383499958395731`}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function performs effectively the same calculation."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Location[crank, {3, 8, \(-4\)}] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.99999999999999911`, 5.87900505417031293`, 19.9383499958395731`}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["PointToLocal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function converts the global point back to local coordinates. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(PointToLocal[crank, %] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.99999999999999857`, 8.`, \(-3.99999999999999822`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["IMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 3D identity matrix\n",
  StyleBox["{{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Courier"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A constant utility."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Coordinate Conversions"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following four conversion functions will not accept ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " geometry objects as arguments. These functions only accept 3D vectors of \
the form {",
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  "}."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CylindricalToXYZ[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["angle",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["altitude",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the Cartesian coordinates of a point specified in cylindrical \
coordinates by ",
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["angle",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["altitude",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["XYZToCylindrical[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the cylindrical coordinates of a point specified in Cartesian \
coordinates ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["z",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["SphericalToXYZ[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ra",
    FontSlant->"Italic"],
  StyleBox["dius",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["baseangle",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["alti",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["tudeangle",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the Cartesian coordinates of a point specified in spherical \
coordinates by ",
  StyleBox["radius",
    FontSlant->"Italic"],
  ", ",
  StyleBox["baseangle",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["altitudeangle",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["XYZToSpherical[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the spherical coordinates of a point specified in Cartesian \
coordinates ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["z",
    FontSlant->"Italic"],
  ".\n\nEach of these functions accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify the ",
  StyleBox["XYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["YZX",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["ZXY",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " right-handed coordinate systems. The default setting is ",
  StyleBox["XYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Coordinate conversions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This converts a cylindrical coordinate triplet to Cartesian coordinates."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CylindricalToXYZ[{4, \[Pi]\/3, 2}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2, 2\ \@3, 2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell["This converts it back.", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(XYZToCylindrical[%]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({4, \[Pi]\/3, 2}\)], "Output"]
}, Open  ]],

Cell[TextData["This converts a 3D vector to polar coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(XYZToCylindrical[Location[crank, 2]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({3.52786404500041994`, 1.57079632679489655`, 16.7022820183397868`}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3.3  Plots and Graphs"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section discusses various methods for generating plots of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output. Because ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " uses a numerical technique to solve the kinematic equations that make up \
a mechanism model, it is generally not possible to generate analytic \
expressions that represent geometric quantities in a model that are to be \
plotted. The best that can be done is to generate a series of discreet \
solutions to the mechanism model, and then use the solutions to create lists \
of numbers that are plotted using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s built-in data plotting routines such as ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or interpolated using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The quick-return mechanism model that was developed in Section 3.1 is used \
here to demonstrate all of the plotting techniques in this chapter. The model \
is redefined as follows in abbreviated form.\n\nNote that a parameter ",
  StyleBox["crankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has been added to the model to allow the position of the drive pin on the \
crank to be easily changed."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the entire quick-return model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(drivearm = 3; \)\), 
    \(\(slider = 4; \)\), 
    \(crankarm =. \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      Body[ground, 
        PointList \[Rule] {{0, 0}, {0, 5}, {\(-5\), 10}, {12, 10}}], \n\t
      Body[crank, PointList \[Rule] {{0, 0}, {crankarm, 0}}, 
        InitialGuess \[Rule] {{0, 5}, 0}], \n\t
      Body[drivearm, PointList \[Rule] {{0, 0}, {0, 9}}, 
        InitialGuess \[Rule] {{0, 0}, \(-0.5\)}], \n\t
      Body[slider, PointList \[Rule] {{0, 0}, {3, 0}}, 
        InitialGuess \[Rule] {{9, 10}, 0}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRevolute2[1, Point[ground, 2], Point[crank, 1]], \n\t
      RotationLock1[2, crank, 2.0  \[Pi]\ T], \n\t
      Revolute2[3, Point[ground, 1], Point[drivearm, 1]], \n\t
      PointOnLine1[4, Point[crank, 2], Line[drivearm, 1, 2]], \n\t
      RelativeDistance1[5, \n\t\tPoint[drivearm, 2], Point[slider, 1], 5.0], 
      \n\tTranslate2[6, Line[ground, 3, 4], Line[slider, 1, 2]]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["A graphic of the quick-return mechanism."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!  
%%Creator: Mathematica  
%%AspectRatio: .61905   
MathPictureStart  
%% Graphics  
/Courier findfont 10  scalefont  setfont  
% Scaling calculations  
0.285714 0.047619 0.047619 0.047619 [  
[ 0 0 0 0 ]  
[ 1 .61905 0 0 ]  
] MathScale  
% Start of Graphics  
1 setlinecap  
1 setlinejoin  
newpath  
[ ] 0 setdash  
0 g  
p  
P  
0 0 m  
1 0 L  
1 .61905 L  
0 .61905 L  
closepath  
clip  
newpath  
p  
p  
p  
.01 w  
.04762 .52381 m  
.85714 .52381 L  
.85714 .04762 L  
.04762 .04762 L  
.04762 .52381 L  
.04762 .42857 L  
.28571 .28571 L  
.04762 .14286 L  
s  
P  
P  
p  
1 0 0 r  
.01 w  
newpath  
.28571 .28571 .19048 0 365.73 arc  
s  
.32986 .14985 m  
.32986 .14985 .02857 0 365.73 arc  
F  
.28571 .28571 m  
.28571 .28571 .02857 0 365.73 arc  
F  
P  
p  
p  
0 1 0 r  
.004 w  
.28571 .04762 m  
.28571 .04762 .02857 0 365.73 arc  
F  
.45562 .44107 m  
.45562 .44107 .02857 0 365.73 arc  
F  
.2726 .05328 m  
.29883 .04196 L  
.46873 .43541 L  
.4425 .44674 L  
F  
P  
p  
.02 w  
.28571 .04762 Mdot  
.45562 .44107 Mdot  
P  
p  
.02 w  
.32986 .14985 Mdot  
P  
p  
.01 w  
.32347 .13505 m  
.43674 .39736 L  
s  
P  
P  
p  
p  
0 0 1 r  
.004 w  
.67888 .52381 m  
.67888 .52381 .01905 0 365.73 arc  
F  
.67888 .57143 m  
.67888 .52381 L  
.82173 .52381 L  
.82173 .57143 L  
F  
P  
.018 w  
.45562 .44107 m  
.67888 .52381 L  
s  
P  
P  
% End of Graphics  
MathPictureEnd  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{305, 189},
  ImageMargins->{{35, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004a0000_A000`40O003h00Oogoo<Woo003oOolb
Ool00?mooc9oo`00ogoo<Woo003oOolbOol00?mooc9oo`00ogoo<Woo001DOol50n3HOol0055oo`/3
h=Eoo`00DGoo30?Pe7oo001@Ool>0n3COol004moo`l3h==oo`00Cgoo40?PdWoo001>Ool80n000`00
0n03h0060n3BOol000eood4000L3h0<000L3h:L002]oo`003Goo@@001P?P1@001P?PY`00:goo000=
Oom100070n0300070n2W000[Ool000eoo`<003ioo`P3h0030003h0?P00H3h:Aoo`<002]oo`003Goo
0`00?Woo40?PYGoo0`00:goo000=Ool3000oOol?0n2UOol3000[Ool000eoo`<0041oo`h3h:Eoo`<0
02]oo`003Goo0`00@7oo3P?PYGoo0`00:goo000=Ool30012Ool<0n2UOol3000[Ool000eoo`<004=o
o``3h:Aoo`<002]oo`003Goo0`00AWoo2@?PY7oo0`00:goo000=Ool30016Ool:0n2SOol3000[Ool0
00eoo`<004Ioo`X3h:=oo`<002]oo`003Goo0`00Agoo2P?PXWoo0`00:goo000=Ool30013Ool4O00:
0n2ROol3000[Ool000eoo`<003]oo`el00T3h003O01oogoo09moo`<002]oo`003Goo0`00>7oo47`0
2P?P0g`0WWoo0`00:goo000=Ool3000aOolCO005Ool90n09O02HOol3000[Ool000eoo`<0031oo`al
00eoo`X3h0]l09Eoo`<002]oo`003Goo0`00;goo2W`047oo2P?P00=oog`0O00027`0UGoo0`00:goo
000=Ool3000]Ool6O00GOol:0n06Ool6O02COol3000[Ool000eoo`<002]oo`Il01Uoo`X3h0Qoo`Ml
091oo`<002]oo`003Goo0`00:Goo27`06Woo2@?P2Goo27`0SWoo0`00:goo000=Ool3000XOol6O00M
Ool:0n09Ool8O02=Ool3000[Ool000eoo`<002Ioo`Il021oo`T3h003O01oogoo00Yoo`Il08]oo`<0
02]oo`003Goo0`0097oo1W`08Woo2P?P0g`02goo1W`0RGoo0`00:goo000=Ool3000ROol7O00TOol9
0n04O00;Ool6O028Ool3000[Ool000eoo`<0025oo`Il02Ioo`@3h0<000<3h0Al00aoo`Il08Ioo`<0
02]oo`003Goo0`0087oo1G`09goo00=l00?P0n000P?P0`000`?P17`03Woo17`0QWoo0`00:goo000=
Ool3000OOol5O00XOol2O0030n0400020n05O00>Ool4O025Ool3000[Ool000eoo`@001eoo`Al02Uo
o`=l00@3h0<000<3h0Al00moo`Al08Aoo`<002]oo`003Goo1P006Woo17`0:Woo17`00`?P10000P?P
17`047oo17`0Pgoo0`00:goo000=Ool8000GOol4O00[Ool4O0030n0400030n03O00AOol4O022Ool3
000[Ool000eoo`T001Eoo`Al02aoo`El00030n00000000<000<3h0Al015oo`Al085oo`<002]oo`00
3Goo0`000Woo1P004Woo17`0;Woo17`00P?P1@000`?P0W`04goo17`0P7oo0`00:goo000=Ool30004
Ool6000?Ool4O00_Ool4O0030n0400030n02O00DOol4O01oOol3000[Ool000eoo`<000Eoo`L000ao
o`Al035oo`Al00<3h0@000<3h003O01oogoo01=oo`Al07ioo`<002]oo`003Goo0`001goo1P002Woo
17`0<Woo17`010?P0`000`?P5goo1G`0O7oo0`00:goo000=Ool30009Ool60007Ool4O00cOol5O003
0n0400020n0HOol4O01lOol3000[Ool000eoo`<000]oo`H000Eoo`Al03Eoo`=l00@3h0<000<3h1Qo
o`=l07aoo`<002]oo`003Goo0`0037oo1P0017oo0g`0=goo0g`00`?P0`000`?P67oo17`0Ngoo0`00
:goo000=Ool3000>Ool600000gooO01l0002O00jOol30n0400030n0GOol4O01kOol3000[Ool000eo
o`<0011oo`@000El03]oo`<3h0<000<3h1Qoo`El07Uoo`<002]oo`003Goo0`004Goo0P0017`0?Goo
0`?P10000`?P67oo17`0NGoo0`00:goo000=Ool3000COol4O002000kOol40n0300030n0IOol3O01i
Ool3000[Ool000eoo`<001=oo`=l00D003Yoo`<3h0@00083h1Uoo`Al07Qoo`<002]oo`003Goo0`00
4Woo17`01P00>Goo10?P0`000`?P67oo17`0N7oo0`00:goo000=Ool3000AOol5O002Ool6000hOol3
0n0300030n0IOol5O01fOol3000[Ool000eoo`<0011oo`Al00Ioo`H003Ioo`<3h0@000<3h1Uoo`Al
07Ioo`<002]oo`003Goo0`0047oo17`01goo1P00=Woo0`?P0`000`?P6Woo0g`0MWoo0`00:goo000=
Ool3000@Ool3O00:Ool6000dOol30n0400030n0IOol4O01eOol3000[Ool000eoo`<0011oo`=l00ao
o`H0039oo`@3h0<000<3h1Yoo`=l07Eoo`<002]oo`003Goo0`003goo17`03Goo1P00<Woo0`?P1000
0P?P6Woo17`0M7oo0`00:goo000=Ool3000?Ool3O00@Ool6000`Ool40n0300030n0JOol3O01dOol3
000[Ool000eoo`<000ioo`Al019oo`H002moo`<3h0<000<3h1Yoo`=l07Aoo`<002]oo`003Goo0`00
3Woo0g`057oo1P00;Woo0`?P10000`?P6Goo17`0Lgoo0`00:goo000=Ool3000>Ool3O00FOol6000]
Ool30n0300030n0JOol3O01cOol3000[Ool000eoo`<000eoo`Al01Qoo`H002]oo`<3h0@000<3h1Uo
o`=l07=oo`<002]oo`003Goo0`003Goo0g`06Woo1P00:goo0`?P0`000`?P6Goo0g`0Lgoo0`00:goo
000=Ool3000=Ool3O00LOol6000YOol30n0400020n0IOol3O01cOol3000[Ool000eoo`<000eoo`=l
01ioo`H002Moo`@3h0<000<3h1Qoo`=l07=oo`<002]oo`003Goo0`003Goo0g`07goo1P009goo0`?P
0`000`?P67oo17`0LWoo0`00:goo000=Ool3000=Ool3O00QOol6000UOol30n0400030n0HOol3O01b
Ool3000[Ool000eoo`<000aoo`Al02=oo`H002Aoo`<3h0<000<3h1Qoo`=l079oo`<002]oo`003Goo
0`0037oo0g`09Goo1P008goo0`?P10000`?P5goo17`0LGoo0`00:goo000=Ool3000<Ool3O00WOol6
000ROol30n0300030n0HOol3O01aOol3000[Ool000eoo`<000aoo`=l02Uoo`H000Eoo`Ml01Aoo`<3
h0@000<3h1Moo`=l075oo`<002]oo`003Goo0`0037oo0g`0:Woo1`0000=oog`0O0002G`04Woo10?P
0`000`?P5goo0g`0LGoo0`00:goo000=Ool3000<Ool3O00/Ool5000=O00BOol30n0300030n0GOol3
O01aOol3000[Ool000eoo`<000aoo`=l02ioo`8000ml015oo`<3h0@000<3h1Ioo`=l075oo`<002]o
o`003Goo0`0037oo0g`0<7oo47`04Goo0`?P0`000`?P5Woo0g`0LGoo0`00:goo000=Ool3000<Ool3
O00_OolAO00AOol30n0400030n0EOol3O01aOol3000[Ool000eoo`<000aoo`=l02mooa5l019oo`<3
h0<000<3h1Eoo`=l075oo`<002]oo`003Goo0`0037oo0g`0;goo4G`04Woo0`?P10000`?P57oo0g`0
LGoo0`00:goo000=Ool3000<Ool3O00_OolAO00COol30n0300030n0DOol3O01aOol3000[Ool000eo
o`<000aoo`=l02mooa5l01=oo`<3h0<000<3h1Aoo`=l075oo`<002]oo`003Goo0`0037oo0g`0;goo
4G`04goo0`?P10000`?P4goo0g`0LGoo0`00:goo000=Ool3000<Ool3O00^Ool2000?O00EOol30n03
00030n0COol3O01aOol3000[Ool000eoo`<000aoo`=l02aoo`D000el01Ioo`<3h0@000<3h19oo`=l
075oo`<002]oo`003Goo0`0037oo0g`0:goo1P0037`067oo0`?P0`000`?P4Woo0g`0LGoo0`00:goo
000=Ool3000<Ool3O00YOol60004Ool9O00IOol30n0400030n0AOol3O01aOol3000[Ool000eoo`<0
00aoo`=l02Moo`H000Moo`Ml01]oo`<3h0<000<3h15oo`=l075oo`<002]oo`003Goo0`0037oo0g`0
9Woo1P002Goo17`07Goo0`?P0`000`?P4Goo0g`0LGoo0`00:goo000=Ool3000<Ool3O00TOol6000/
Ool30n0400030n0?Ool4O01aOol3000[Ool000eoo`<000aoo`Al029oo`D002moo`<3h0<000<3h0mo
o`=l079oo`<002]oo`003Goo0`003Goo0g`087oo1P00<7oo0`?P10000`?P3Woo0g`0LWoo0`00:goo
000=Ool3000=Ool3O00NOol6000cOol30n0300030n0=Ool4O01bOol3000[Ool000eoo`<000eoo`=l
01eoo`H003Aoo`<3h0@000<3h0aoo`=l07=oo`<002]oo`003Goo0`003Goo0g`06goo1P00=goo0`?P
0`000`?P37oo0g`0Lgoo0`00:goo000=Ool3000=Ool4O00HOol6000iOol30n0300030n0<Ool3O01c
Ool3000[Ool000eoo`<000ioo`=l01Moo`H003]oo`83h0@000<3h0]oo`=l07=oo`<002]oo`003Goo
0`003Woo0g`05Goo1P00?Goo0`?P0`000`?P2Woo17`0Lgoo0`00:goo000=Ool3000>Ool4O00BOol6
000oOol30n0400030n09Ool3O01dOol3000[Ool000eoo`<000moo`=l015oo`H0045oo`<3h0<000<3
h0Uoo`=l07Aoo`<002]oo`003Goo0`003goo0g`03goo1P00@goo0`?P10000`?P1goo17`0M7oo0`00
:goo000=Ool3000?Ool4O00=Ool50016Ool30n0300030n07Ool3O01eOol3000[Ool000eoo`<0011o
o`=l00]oo`H004Moo`<3h0<000@3h0Ioo`=l07Eoo`<002]oo`003Goo0`0047oo17`027oo1P00BWoo
0P?P10000`?P1Goo17`0MGoo0`00:goo000=Ool3000AOol3O007Ool6001;Ool30n0300030n05Ool3
O01fOol3000[Ool000eoo`<0015oo`Al00Aoo`H004eoo`<3h0@000<3h0=oo`Al07Ioo`<002]oo`00
3Goo0`004Woo17`000=oo`0000001000D7oo0`?P0`000`?P0Woo17`0Mgoo0`00:goo000=Ool3000C
Ool3O006001AOol30n0400030n0017ooO01l07`0N7oo0`00:goo000=Ool3000COol4O003001DOol3
0n0300030n04O01hOol3000[Ool000eoo`<0019oo`8000=l0003001oogoo05Aoo`<3h0<000@3h09l
07Uoo`<002]oo`003Goo0`004Goo0`0017`0Egoo0P?P10000`?P0W`0NGoo0`00:goo000=Ool3000?
Ool60004O01FOol30n0300030n000g`0Oomoo`1hOol3000[Ool000eoo`<000ioo`D000=oo`=l05Mo
o`83h0@000<3h7Yoo`<002]oo`003Goo0`0037oo1P0017oo17`0EWoo0`?P0`000`?PNWoo0`00:goo
000=Ool3000:Ool60006Ool4O01FOol30n0300040n1iOol3000[Ool000eoo`<000Uoo`H000Qoo`El
05Eoo`T3h7Uoo`<002]oo`003Goo0`001goo1P002goo17`0EGoo2P?PN7oo0`00:goo000=Ool30005
Ool6000>Ool4O01DOol00g`00n03h0070n1hOol3000[Ool000eoo`<000Aoo`H0011oo`Al059oo`9l
00T3h7Qoo`<002]oo`003Goo0`000Woo1P004Woo17`0DGoo17`02`?PMGoo0`00:goo000=Ool30000
0goo00000003000EOol4O01?Ool5O00=0n1cOol3000[Ool000eoo`P001Moo`Al04eoo`Al009oo`h3
h79oo`<002]oo`003Goo1P006Woo1G`0B7oo1W`00goo3`?PLGoo0`00:goo000=Ool5000LOol6O015
Ool6O003Ool70n000`000n03h0060n1aOol3000[Ool000eoo`<001moo`Il04=oo`Ml00=oo`H3h0@0
00H3h75oo`<002]oo`003Goo0`0087oo1g`0@7oo1G`01Woo1P?P1`0010?PL7oo0`00:goo000=Ool3
000SOol4O00oOol4O007Ool70n0:00000`?POomoo`1^Ool3000[Ool000eoo`<002Aoo`El03Yoo`Il
00Qoo`L3h0`006moo`<002]oo`003Goo0`009Goo1W`0=goo1W`02Goo20?P3P00K7oo0`00:goo000=
Ool3000VOol6O00eOol7O00:Ool80n0?001ZOol3000[Ool000eoo`<002Moo`Ml035oo`Il00ioo`/3
h0h006Moo`<002]oo`003Goo0`00:Woo1g`0;7oo1W`04Goo3@?P3P00I7oo0`00:goo000=Ool3000[
Ool8O00WOol9O00AOol=0n02Ool>001ROol3000[Ool000eoo`<002eoo`Ul025oo`Ul01Eoo`/3h0Io
o`h005moo`<002]oo`003Goo0`00<7oo2G`06goo2W`067oo2@?P2Goo3P00GGoo0`00:goo000=Ool3
000bOol<O00AOol<O00MOol50n0>Ool>001JOol3000[Ool000eoo`<003Eoob=l03Ioo`h005Moo`<0
02]oo`003Goo0`00>7oo7G`0>goo3P00EGoo0`00:goo000=Ool3000mOolCO013Ool>001BOol3000[
Ool000eoo`<009Eoo`l004moo`<002]oo`003Goo0`00V7oo3P00CGoo0`00:goo000=Ool3002KOol>
001:Ool3000[Ool000eoo`<009eoo`h004Qoo`<002]oo`003Goo0`00X7oo3P00AGoo0`00:goo000=
Ool3002SOol>0012Ool3000[Ool000eoo`<00:Eoo`h0041oo`<002]oo`003Goo0`00Z7oo3P00?Goo
0`00:goo000=Ool3002ZOol>0002Ool701lbOol3000[Ool000eoo`<00:eoo`h000L07c5oo`<002]o
o`003Goo0`00/7oo3P001@0O<7oo0`00:goo000=Ool3002bOol>000301l`Ool3000[Ool000eool@0
00<07c8002]oo`003Gooa0000`0O<P00:goo000=Oonk000201l7000X01l=000[Ool00<Qoo`D07`@0
02P07cQoo`00bGoo1P0O00<0000O01l09`0O>7oo003:Ool_01lhOol00<]oobh07cQoo`00cWoo:`0O
>7oo003>Ool[01lhOol00<ioob/07cQoo`00cWoo:`0O>7oo003>Ool[01lhOol00<ioob/07cQoo`00
cWoo:`0O>7oo003>Ool[01lhOol00<ioob/07cQoo`00ogoo<Woo003oOolbOol00?mooc9oo`00ogoo
<Woo003oOolbOol00?mooc9oo`00ogoo<Woo003oOolbOol00?mooc9oo`00ogoo<Woo003oOolbOol0
0?mooc9oo`00ogoo<Woo003oOolbOol00001\
\>"],
  ImageRangeCache->{{{0, 304}, {188, 0}} -> {-6.01078, -1.00006, 0.06915, 
  0.06915}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Data Plots"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To generate a data plot, we must first generate some data. ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to return 20 solution points as the crank is rotated through a \
full turn, with the crank arm length set to three units."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This generates a list of 20 solutions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(crankarm = 3; \)\), 
    \(First[positiontable = SolveMech[{0, 1}, 20]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] \(-1.99382649809073146`*^-31\), 
      Y2 \[Rule] 5.`, Th2 \[Rule] 3.20845139736365814`*^-21, 
      X3 \[Rule] \(-4.18759374189735655`*^-21\), Y3 \[Rule] 0.`, 
      Th3 \[Rule] \(-0.540419500270584141`\), 
      X4 \[Rule] 9.07904619162365378`, Y4 \[Rule] 10.`, Th4 \[Rule] 0.`}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Since the primary function of the quick return mechanism is to reciprocate \
the slider, the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " position of the slider is plotted as a function of time. Each solution \
rule returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " contains a rule specifying the value of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so a list of {",
  StyleBox["x, y",
    FontSlant->"Italic"],
  "} pairs for ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can easily be obtained with one replacement operation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here is a plot of slider position versus time."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{T, X4} /. positiontable, PlotJoined \[Rule] True]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0794076 0.0549056 [
[.21429 .06691 -9 -9 ]
[.21429 .06691 9 0 ]
[.40476 .06691 -9 -9 ]
[.40476 .06691 9 0 ]
[.59524 .06691 -9 -9 ]
[.59524 .06691 9 0 ]
[.78571 .06691 -9 -9 ]
[.78571 .06691 9 0 ]
[.97619 .06691 -3 -9 ]
[.97619 .06691 3 0 ]
[.01131 .18922 -6 -4.5 ]
[.01131 .18922 0 4.5 ]
[.01131 .29903 -6 -4.5 ]
[.01131 .29903 0 4.5 ]
[.01131 .40884 -6 -4.5 ]
[.01131 .40884 0 4.5 ]
[.01131 .51865 -6 -4.5 ]
[.01131 .51865 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .07941 m
.21429 .08566 L
s
[(0.2)] .21429 .06691 0 1 Mshowa
.40476 .07941 m
.40476 .08566 L
s
[(0.4)] .40476 .06691 0 1 Mshowa
.59524 .07941 m
.59524 .08566 L
s
[(0.6)] .59524 .06691 0 1 Mshowa
.78571 .07941 m
.78571 .08566 L
s
[(0.8)] .78571 .06691 0 1 Mshowa
.97619 .07941 m
.97619 .08566 L
s
[(1)] .97619 .06691 0 1 Mshowa
.125 Mabswid
.07143 .07941 m
.07143 .08316 L
s
.11905 .07941 m
.11905 .08316 L
s
.16667 .07941 m
.16667 .08316 L
s
.2619 .07941 m
.2619 .08316 L
s
.30952 .07941 m
.30952 .08316 L
s
.35714 .07941 m
.35714 .08316 L
s
.45238 .07941 m
.45238 .08316 L
s
.5 .07941 m
.5 .08316 L
s
.54762 .07941 m
.54762 .08316 L
s
.64286 .07941 m
.64286 .08316 L
s
.69048 .07941 m
.69048 .08316 L
s
.7381 .07941 m
.7381 .08316 L
s
.83333 .07941 m
.83333 .08316 L
s
.88095 .07941 m
.88095 .08316 L
s
.92857 .07941 m
.92857 .08316 L
s
.25 Mabswid
0 .07941 m
1 .07941 L
s
.02381 .18922 m
.03006 .18922 L
s
[(2)] .01131 .18922 1 0 Mshowa
.02381 .29903 m
.03006 .29903 L
s
[(4)] .01131 .29903 1 0 Mshowa
.02381 .40884 m
.03006 .40884 L
s
[(6)] .01131 .40884 1 0 Mshowa
.02381 .51865 m
.03006 .51865 L
s
[(8)] .01131 .51865 1 0 Mshowa
.125 Mabswid
.02381 .10686 m
.02756 .10686 L
s
.02381 .13431 m
.02756 .13431 L
s
.02381 .16177 m
.02756 .16177 L
s
.02381 .21667 m
.02756 .21667 L
s
.02381 .24412 m
.02756 .24412 L
s
.02381 .27158 m
.02756 .27158 L
s
.02381 .32648 m
.02756 .32648 L
s
.02381 .35394 m
.02756 .35394 L
s
.02381 .38139 m
.02756 .38139 L
s
.02381 .43629 m
.02756 .43629 L
s
.02381 .46375 m
.02756 .46375 L
s
.02381 .4912 m
.02756 .4912 L
s
.02381 .05195 m
.02756 .05195 L
s
.02381 .0245 m
.02756 .0245 L
s
.02381 .54611 m
.02756 .54611 L
s
.02381 .57356 m
.02756 .57356 L
s
.02381 .60101 m
.02756 .60101 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .5779 m
.07393 .54601 L
.12406 .50295 L
.17419 .45127 L
.22431 .39377 L
.27444 .33303 L
.32456 .27117 L
.37469 .20984 L
.42481 .15045 L
.47494 .09482 L
.52506 .04664 L
.57519 .01472 L
.62531 .01897 L
.67544 .09636 L
.72556 .28716 L
.77569 .50521 L
.82581 .58961 L
.87594 .60332 L
.92607 .5971 L
.97619 .5779 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo0009Ool0
0`00Oomoo`3oOol=Ool000Uoo`03001oogoo0?moo`eoo`002Goo00<007ooOol0ogoo3Goo0009Ool0
0`00Oomoo`3oOol=Ool000Uoo`03001oogoo09Eoo`L0071oo`002Goo00<007ooOol0Tgoo0P001goo
2000J7oo0009Ool00`00Oomoo`2BOol00`00Oomoo`0?Ool00`00Oomoo`1UOol000Uoo`80095oo`80
019oo`03001oogoo06Eoo`002Goo00<007ooOol0Sgoo00<007ooOol04goo00<007ooOol0I7oo0009
Ool00`00Oomoo`2=Ool2000GOol00`00Oomoo`1SOol000Uoo`03001oogoo08]oo`8001Uoo`03001o
ogoo06=oo`002Goo00<007ooOol0;7oo00<007ooOol00Woo00@007ooOomoo`<002Uoo`03001oogoo
009oo`03001oogoo009oo`<001aoo`03001oogoo00Qoo`03001oogoo009oo`04001oogooOol20007
Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol50006Ool000Uo
o`03001oogoo02]oo`03001oo`0000Moo`03001oogoo02Qoo`03001oo`0000Uoo`03001oogoo01Uo
o`8000Yoo`03001oo`0000Moo`03001oo`0000Ioo`03001oogoo01moo`03001oo`0000Moo`03001o
o`0002eoo`03001oogoo00Ioo`002Goo00<007ooOol0:goo00<007oo000027oo00<007ooOol09goo
00<007oo00001goo10006Goo00<007ooOol02Woo00<007oo00001goo00<007oo00001goo00<007oo
Ool07Woo00<007oo00001goo00<007oo0000;Goo00<007ooOol01Woo0009Ool00`00Oomoo`0[Ool0
0`00Ool00008Ool00`00Oomoo`0WOol00`00Ool00007Ool00`00Ool0000IOol00`00Oomoo`0;Ool0
0`00Ool00007Ool20009Ool00`00Oomoo`0MOol00`00Ool00008Ool00`00Oomoo`0/Ool00`00Oomo
o`06Ool000Uoo`8002aoo`03001oo`0000Moo`03001oo`0002Qoo`03001oo`0000Qoo`8001Qoo`03
001oogoo00aoo`03001oo`0000Moo`03001oogoo00Qoo`03001oogoo01eoo`03001oo`0000Moo`03
001oo`0002eoo`03001oogoo00Ioo`002Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol0
:7oo00<007ooOol027oo00<007ooOol05Goo00<007ooOol03Woo00<007ooOol01goo0P002Goo00<0
07ooOol07Goo00<007ooOol01goo00<007ooOol0:goo0P0027oo0009Ool00`00Oomoo`23Ool00`00
Oomoo`0UOol00`00Oomoo`1NOol000Uoo`03001oogoo089oo`03001oogoo02Ioo`03001oogoo05io
o`002Goo00<007ooOol0PGoo00<007ooOol0:7oo00<007ooOol0GGoo0009Ool00`00Oomoo`20Ool0
0`00Oomoo`0ZOol00`00Oomoo`1LOol000Uoo`03001oogoo07moo`03001oogoo02]oo`03001oogoo
05aoo`000Wooo`005`000009Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool01000Oomoo`003Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01Goo0009Ool00`00Oomoo`0b
Ool00`00Oomoo`0aOol00`00Oomoo`0COol00`00Oomoo`0LOol00`00Oomoo`0AOol00`00Oomoo`0M
Ool00`00Oomoo`0bOol00`00Oomoo`05Ool000Uoo`03001oogoo07]oo`03001oogoo039oo`03001o
ogoo05Uoo`002Goo00<007ooOol0NWoo00<007ooOol0<goo00<007ooOol0FGoo0009Ool00`00Oomo
o`1iOol00`00Oomoo`0eOol00`00Oomoo`1HOol000Uoo`03001oogoo07Qoo`03001oogoo03Ioo`03
001oogoo05Qoo`002Goo00<007ooOol0Mgoo00<007ooOol0>7oo00<007ooOol0Egoo0009Ool2001g
Ool00`00Oomoo`0iOol00`00Oomoo`1GOol000Uoo`03001oogoo07Ioo`03001oogoo03Uoo`03001o
ogoo05Moo`002Goo00<007ooOol0MGoo00<007ooOol0>Woo00<007ooOol0Egoo0009Ool00`00Oomo
o`1dOol00`00Oomoo`0lOol00`00Oomoo`1FOol000Uoo`03001oogoo07=oo`03001oogoo03eoo`03
001oogoo05Ioo`002Goo00<007ooOol0LWoo00<007ooOol0?Woo00<007ooOol0EWoo0009Ool00`00
Oomoo`1aOol00`00Oomoo`0oOol00`00Oomoo`1FOol000Uoo`80075oo`03001oogoo045oo`03001o
ogoo05Eoo`002Goo00<007ooOol0Kgoo00<007ooOol0@Woo00<007ooOol0EGoo0009Ool00`00Oomo
o`1_Ool00`00Oomoo`12Ool00`00Oomoo`1EOol000Uoo`03001oogoo06ioo`03001oogoo04=oo`03
001oogoo05Eoo`002Goo00<007ooOol0KGoo00<007ooOol0AGoo00<007ooOol0E7oo0009Ool00`00
Oomoo`1/Ool00`00Oomoo`16Ool00`00Oomoo`1DOol000Uoo`03001oogoo06]oo`03001oogoo04Mo
o`03001oogoo05Aoo`002Goo00<007ooOol0JWoo00<007ooOol0BGoo00<007ooOol0Dgoo0009Ool2
001ZOol00`00Oomoo`1:Ool00`00Oomoo`1COol000Uoo`03001oogoo06Qoo`03001oogoo04]oo`03
001oogoo05=oo`002Goo00<007ooOol0J7oo00<007ooOol0Bgoo00<007ooOol0Dgoo0009Ool00`00
Oomoo`1WOol00`00Oomoo`1=Ool00`00Oomoo`1BOol000Uoo`03001oogoo06Ioo`03001oogoo04io
o`03001oogoo059oo`000Woo0`0017oo00<007ooOol0IGoo00<007ooOol0Cgoo00<007ooOol0DWoo
0002Ool00`00Oomoo`04Ool00`00Oomoo`1TOol00`00Oomoo`1@Ool00`00Oomoo`1BOol000=oo`03
001oogoo00=oo`<006=oo`03001oogoo059oo`03001oogoo055oo`000goo00<007ooOol00goo00<0
07ooOol0HWoo00<007ooOol0Dgoo00<007ooOol0DGoo0002Ool00`00Ool00004Ool00`00Oomoo`1Q
Ool00`00Oomoo`1DOol00`00Oomoo`1AOol000=oo`03001oogoo00=oo`03001oogoo065oo`03001o
ogoo05Eoo`03001oogoo051oo`002Goo00<007ooOol0H7oo00<007ooOol0EWoo00<007ooOol0D7oo
0009Ool00`00Oomoo`1OOol00`00Oomoo`1GOol00`00Oomoo`1@Ool000Uoo`03001oogoo05ioo`03
001oogoo05Qoo`03001oogoo051oo`002Goo00<007ooOol0GGoo00<007ooOol0FWoo00<007ooOol0
Cgoo0009Ool2001MOol00`00Oomoo`1KOol00`00Oomoo`1?Ool000Uoo`03001oogoo05aoo`03001o
ogoo05]oo`03001oogoo04moo`002Goo00<007ooOol0Fgoo00<007ooOol0G7oo00<007ooOol0Cgoo
0009Ool00`00Oomoo`1JOol00`00Oomoo`1NOol00`00Oomoo`1>Ool000Uoo`03001oogoo05Uoo`03
001oogoo05moo`03001oogoo04ioo`002Goo00<007ooOol0F7oo00<007ooOol0H7oo00<007ooOol0
CWoo0009Ool00`00Oomoo`1GOol00`00Oomoo`1QOol00`00Oomoo`1>Ool000Uoo`03001oogoo05Mo
o`03001oogoo069oo`03001oogoo04eoo`002Goo0P00Egoo00<007ooOol0Hgoo00<007ooOol0CGoo
0009Ool00`00Oomoo`1EOol00`00Oomoo`1TOol00`00Oomoo`1=Ool000Uoo`03001oogoo05Aoo`03
001oogoo06Ioo`03001oogoo04aoo`002Goo00<007ooOol0Dgoo00<007ooOol0Igoo00<007ooOol0
C7oo0009Ool00`00Oomoo`1BOol00`00Oomoo`1XOol00`00Oomoo`1<Ool000Uoo`03001oogoo059o
o`03001oogoo06Qoo`03001oogoo04aoo`002Goo00<007ooOol0DGoo00<007ooOol0JWoo00<007oo
Ool0Bgoo0009Ool2001AOol00`00Oomoo`1[Ool00`00Oomoo`1;Ool000Uoo`03001oogoo04moo`03
001oogoo06aoo`03001oogoo04]oo`002Goo00<007ooOol0CWoo00<007ooOol0KGoo00<007ooOol0
Bgoo0009Ool00`00Oomoo`1>Ool00`00Oomoo`1^Ool00`00Oomoo`1:Ool000Uoo`03001oogoo04eo
o`03001oogoo06moo`03001oogoo04Yoo`002Goo00<007ooOol0C7oo00<007ooOol0L7oo00<007oo
Ool0BWoo0003Ool30003Ool00`00Oomoo`1;Ool00`00Oomoo`1aOol00`00Oomoo`1:Ool000Aoo`03
001oogoo009oo`03001oogoo04Yoo`03001oogoo07=oo`03001oogoo04Uoo`000Woo10000goo0`00
BGoo00<007ooOol0M7oo00<007ooOol0BGoo0002Ool00`00Ool00004Ool00`00Oomoo`19Ool00`00
Oomoo`1dOol00`00Oomoo`19Ool000=oo`8000Aoo`03001oogoo04Qoo`03001oogoo07Eoo`03001o
ogoo04Uoo`0017oo00<007ooOol00Woo00<007ooOol0Agoo00<007ooOol0Mgoo00<007ooOol0B7oo
0009Ool00`00Oomoo`16Ool00`00Oomoo`1hOol00`00Oomoo`18Ool000Uoo`03001oogoo04Eoo`03
001oogoo07Uoo`03001oogoo04Qoo`002Goo00<007ooOol0A7oo00<007ooOol0NWoo00<007ooOol0
B7oo0009Ool20015Ool00`00Oomoo`1kOol00`00Oomoo`17Ool000Uoo`03001oogoo04=oo`03001o
ogoo07aoo`03001oogoo04Moo`002Goo00<007ooOol0@Woo00<007ooOol0OGoo00<007ooOol0Agoo
0009Ool00`00Oomoo`11Ool00`00Oomoo`1nOol00`00Oomoo`17Ool000Uoo`03001oogoo041oo`03
001oogoo07moo`03001oogoo04Moo`002Goo00<007ooOol0@7oo00<007ooOol0P7oo00<007ooOol0
AWoo0009Ool00`00Oomoo`0oOol00`00Oomoo`21Ool00`00Oomoo`16Ool000Uoo`03001oogoo03io
o`03001oogoo089oo`03001oogoo04Ioo`002Goo0P00?Woo00<007ooOol0Pgoo00<007ooOol0AWoo
0009Ool00`00Oomoo`0lOol00`00Oomoo`25Ool00`00Oomoo`15Ool000Uoo`03001oogoo03]oo`03
001oogoo08Ioo`03001oogoo04Eoo`002Goo00<007ooOol0>goo00<007ooOol0QWoo00<007ooOol0
AGoo0009Ool00`00Oomoo`0jOol00`00Oomoo`27Ool00`00Oomoo`15Ool000Uoo`03001oogoo03Uo
o`03001oogoo08Uoo`03001oogoo04Aoo`002Goo00<007ooOol0>7oo00<007ooOol0RWoo00<007oo
Ool0A7oo0009Ool2000hOol00`00Oomoo`2;Ool00`00Oomoo`14Ool000Uoo`03001oogoo03Ioo`03
001oogoo08aoo`03001oogoo04Aoo`002Goo00<007ooOol0=Woo00<007ooOol0S7oo00<007ooOol0
A7oo0009Ool00`00Oomoo`0eOol00`00Oomoo`2>Ool00`00Oomoo`13Ool000Uoo`03001oogoo03Ao
o`03001oogoo08moo`03001oogoo04=oo`002Goo00<007ooOol0<goo00<007ooOol0T7oo00<007oo
Ool0@goo0002Ool20005Ool00`00Oomoo`0bOol00`00Oomoo`2AOol00`00Oomoo`13Ool0009oo`03
001oo`0000Aoo`03001oogoo035oo`03001oogoo09=oo`03001oogoo049oo`000Woo00<007oo0000
17oo0`00<7oo00<007ooOol0U7oo00<007ooOol0@Woo0002Ool20005Ool00`00Oomoo`0`Ool00`00
Oomoo`2DOol00`00Oomoo`12Ool0009oo`03001oogoo00Aoo`03001oogoo02moo`03001oogoo09Eo
o`03001oogoo049oo`000goo0P0017oo00<007ooOol0;Woo00<007ooOol0UWoo00<007ooOol0@Woo
0009Ool00`00Oomoo`0]Ool00`00Oomoo`2HOol00`00Oomoo`11Ool000Uoo`03001oogoo02aoo`03
001oogoo09Uoo`03001oogoo045oo`002Goo00<007ooOol0:goo00<007ooOol0VWoo00<007ooOol0
@Goo0009Ool00`00Oomoo`0ZOol00`00Oomoo`2KOol00`00Oomoo`11Ool000Uoo`8002Yoo`03001o
ogoo09eoo`03001oogoo041oo`002Goo00<007ooOol0:Goo00<007ooOol0WGoo00<007ooOol0@7oo
0009Ool00`00Oomoo`0XOol00`00Oomoo`2NOol00`00Oomoo`10Ool000Uoo`03001oogoo02Moo`03
001oogoo09moo`03001oogoo041oo`002Goo00<007ooOol09Woo00<007ooOol0XGoo00<007ooOol0
?goo0009Ool00`00Oomoo`0UOol00`00Oomoo`2ROol00`00Oomoo`0oOol000Uoo`03001oogoo02Ao
o`03001oogoo0:=oo`03001oogoo03moo`002Goo0P0097oo00<007ooOol0Y7oo00<007ooOol0?goo
0009Ool00`00Oomoo`0ROol00`00Oomoo`2UOol00`00Oomoo`0oOol000Uoo`03001oogoo025oo`03
001oogoo0:Moo`03001oogoo03ioo`002Goo00<007ooOol087oo00<007ooOol0Z7oo00<007ooOol0
?Woo0009Ool00`00Oomoo`0OOol00`00Oomoo`2YOol00`00Oomoo`0nOol000Uoo`03001oogoo01mo
o`03001oogoo0:Uoo`03001oogoo03ioo`002Goo00<007ooOol07Woo00<007ooOol0Zgoo00<007oo
Ool0?Goo0009Ool00`00Oomoo`0MOol00`00Oomoo`2/Ool00`00Oomoo`0mOol000Uoo`8001eoo`03
001oogoo0:eoo`03001oogoo03eoo`002Goo00<007ooOol06goo00<007ooOol0[Woo00<007ooOol0
?Goo0009Ool00`00Oomoo`0JOol00`00Oomoo`2`Ool00`00Oomoo`0lOol000Uoo`03001oogoo01Uo
o`03001oogoo0;5oo`03001oogoo03aoo`002Goo00<007ooOol067oo00<007ooOol0/Woo00<007oo
Ool0?7oo0003Ool00`00Oomoo`03Ool00`00Oomoo`0GOol00`00Oomoo`2dOol00`00Oomoo`0kOol0
009oo`03001oo`0000Aoo`03001oogoo01Eoo`800;Moo`03001oogoo03]oo`000Woo00<007oo0000
17oo0`0057oo00<007ooOol0^7oo00<007ooOol0>Woo0003Ool00`00Oomoo`03Ool00`00Oomoo`0C
Ool00`00Oomoo`2iOol00`00Oomoo`0jOol0009oo`03001oo`0000Aoo`03001oogoo019oo`03001o
ogoo0;]oo`03001oogoo03Uoo`000goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol0_7oo
00<007ooOol0>Goo0009Ool00`00Oomoo`0@Ool00`00Oomoo`2nOol00`00Oomoo`0hOol000Uoo`03
001oogoo00ioo`800<9oo`03001oogoo03Moo`002Goo00<007ooOol03Goo00<007ooOol0`Woo00<0
07ooOol0=goo0009Ool00`00Oomoo`0<Ool00`00Oomoo`34Ool00`00Oomoo`0fOol000Uoo`8000ao
o`03001oogoo0<Eoo`03001oogoo03Ioo`002Goo00<007ooOol02Goo0P00bGoo00<007ooOol0=Goo
0009Ool00`00Oomoo`08Ool00`00Oomoo`39Ool00`00Oomoo`0eOol000Uoo`03001oogoo00Ioo`80
0<eoo`03001oogoo03Aoo`002Goo00<007ooOol01Goo00<007ooOol0cGoo00<007ooOol0=7oo0009
Ool00`00Oomoo`03Ool2003AOol00`00Oomoo`0cOol000Uoo`04001oogooOol2003DOol00`00Oomo
o`0bOol000Uoo`04001oogoo003FOol00`00Oomoo`0bOol000Uoo`<00=Qoo`03001oogoo035oo`00
2Goo00<007ooOol0f7oo00<007ooOol0:7oo0P001goo0009Ool00`00Oomoo`3IOol00`00Oomoo`0T
Ool30009Ool000Uoo`03001oogoo0=Uoo`03001oogoo029oo`8000aoo`002Goo00<007ooOol0fWoo
0P007goo0`003Woo0009Ool00`00Oomoo`3LOol4000HOol3000AOol000Uoo`03001oogoo0>1oo`<0
011oo`D001Aoo`002Goo0P00i7oo10001Goo1`006Goo0009Ool00`00Oomoo`3WOol5000POol000Uo
o`03001oogoo0?moo`eoo`002Goo00<007ooOol0ogoo3Goo0009Ool00`00Oomoo`3oOol=Ool000Uo
o`03001oogoo0?moo`eoo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0359458, -1.49076, 0.00380269,
   0.0659607}}]
}, Open  ]],

Cell[TextData[
"More complicated functions can also be plotted in this manner."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of connecting rod angle versus time."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{T, Angle[Line[drivearm, 2, slider, 1]]} /. positiontable, 
      PlotJoined \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.288967 1.50159 [
[.21429 -0.00115 -9 -9 ]
[.21429 -0.00115 9 0 ]
[.40476 -0.00115 -9 -9 ]
[.40476 -0.00115 9 0 ]
[.59524 -0.00115 -9 -9 ]
[.59524 -0.00115 9 0 ]
[.78571 -0.00115 -9 -9 ]
[.78571 -0.00115 9 0 ]
[.97619 -0.00115 -3 -9 ]
[.97619 -0.00115 3 0 ]
[.01131 .16151 -18 -4.5 ]
[.01131 .16151 0 4.5 ]
[.01131 .31167 -18 -4.5 ]
[.01131 .31167 0 4.5 ]
[.01131 .46183 -18 -4.5 ]
[.01131 .46183 0 4.5 ]
[.01131 .61199 -18 -4.5 ]
[.01131 .61199 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01135 m
.21429 .0176 L
s
[(0.2)] .21429 -0.00115 0 1 Mshowa
.40476 .01135 m
.40476 .0176 L
s
[(0.4)] .40476 -0.00115 0 1 Mshowa
.59524 .01135 m
.59524 .0176 L
s
[(0.6)] .59524 -0.00115 0 1 Mshowa
.78571 .01135 m
.78571 .0176 L
s
[(0.8)] .78571 -0.00115 0 1 Mshowa
.97619 .01135 m
.97619 .0176 L
s
[(1)] .97619 -0.00115 0 1 Mshowa
.125 Mabswid
.07143 .01135 m
.07143 .0151 L
s
.11905 .01135 m
.11905 .0151 L
s
.16667 .01135 m
.16667 .0151 L
s
.2619 .01135 m
.2619 .0151 L
s
.30952 .01135 m
.30952 .0151 L
s
.35714 .01135 m
.35714 .0151 L
s
.45238 .01135 m
.45238 .0151 L
s
.5 .01135 m
.5 .0151 L
s
.54762 .01135 m
.54762 .0151 L
s
.64286 .01135 m
.64286 .0151 L
s
.69048 .01135 m
.69048 .0151 L
s
.7381 .01135 m
.7381 .0151 L
s
.83333 .01135 m
.83333 .0151 L
s
.88095 .01135 m
.88095 .0151 L
s
.92857 .01135 m
.92857 .0151 L
s
.25 Mabswid
0 .01135 m
1 .01135 L
s
.02381 .16151 m
.03006 .16151 L
s
[(0.3)] .01131 .16151 1 0 Mshowa
.02381 .31167 m
.03006 .31167 L
s
[(0.4)] .01131 .31167 1 0 Mshowa
.02381 .46183 m
.03006 .46183 L
s
[(0.5)] .01131 .46183 1 0 Mshowa
.02381 .61199 m
.03006 .61199 L
s
[(0.6)] .01131 .61199 1 0 Mshowa
.125 Mabswid
.02381 .04138 m
.02756 .04138 L
s
.02381 .07141 m
.02756 .07141 L
s
.02381 .10145 m
.02756 .10145 L
s
.02381 .13148 m
.02756 .13148 L
s
.02381 .19154 m
.02756 .19154 L
s
.02381 .22157 m
.02756 .22157 L
s
.02381 .25161 m
.02756 .25161 L
s
.02381 .28164 m
.02756 .28164 L
s
.02381 .3417 m
.02756 .3417 L
s
.02381 .37173 m
.02756 .37173 L
s
.02381 .40176 m
.02756 .40176 L
s
.02381 .4318 m
.02756 .4318 L
s
.02381 .49186 m
.02756 .49186 L
s
.02381 .52189 m
.02756 .52189 L
s
.02381 .55192 m
.02756 .55192 L
s
.02381 .58196 m
.02756 .58196 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42289 m
.07393 .28674 L
.12406 .16688 L
.17419 .07724 L
.22431 .02528 L
.27444 .01472 L
.32456 .04624 L
.37469 .11771 L
.42481 .2237 L
.47494 .35406 L
.52506 .4893 L
.57519 .58932 L
.62531 .57554 L
.67544 .35006 L
.72556 .03413 L
.77569 .17195 L
.82581 .49253 L
.87594 .60332 L
.92607 .54753 L
.97619 .42289 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo0013Ool0
0`00Oomoo`02Ool01000Oomoogoo0`009Goo00<007ooOol00Woo00<007ooOol00Woo0`009Goo00<0
07ooOol00Woo00@007ooOomoo`8002Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Mo
o`D000Qoo`00@Woo00<007oo00001goo00<007ooOol097oo00<007oo00002Goo00<007ooOol08goo
00<007oo00001goo00<007oo000097oo00<007oo00001goo00<007oo0000:Woo00<007ooOol027oo
0012Ool00`00Ool00008Ool00`00Oomoo`0SOol00`00Ool00007Ool4000TOol00`00Ool00007Ool0
0`00Ool0000TOol00`00Ool00007Ool00`00Ool0000ZOol00`00Oomoo`08Ool0049oo`03001oo`00
00Qoo`03001oogoo02=oo`03001oo`0000Moo`03001oo`0002Eoo`03001oo`0000Moo`8002Eoo`03
001oo`0000Qoo`03001oogoo02Uoo`03001oogoo00Qoo`00@Woo00<007oo00001goo00<007oo0000
97oo00<007oo000027oo0P009Goo00<007oo00001goo00<007ooOol097oo00<007oo00001goo00<0
07oo0000:Woo00<007ooOol027oo0013Ool00`00Oomoo`07Ool00`00Oomoo`0TOol00`00Oomoo`08
Ool00`00Oomoo`0TOol00`00Oomoo`07Ool2000UOol00`00Oomoo`07Ool00`00Oomoo`0XOol2000:
Ool00?mooaUoo`00ogoo6Goo003oOolIOol001Moo`03001oogoo0?ioo`005goo00<007ooOol0oWoo
000GOol00`00Oomoo`3nOol0015oool000D000=oo`005goo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo100027oo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01goo000GOol00`00Oomoo`0eOol6
0004Ool2002mOol001Moo`03001oogoo035oo`@000aoo`800;]oo`005goo00<007ooOol0<7oo00<0
07ooOol047oo00<007ooOol0^7oo000GOol00`00Oomoo`0_Ool00`00Oomoo`0BOol2002hOol001Mo
o`03001oogoo02ioo`03001oogoo01Eoo`03001oogoo06Yoo`03001oogoo04Qoo`005goo0P00;Woo
00<007ooOol05goo0P00JWoo00<007ooOol0B7oo000GOol00`00Oomoo`0/Ool00`00Oomoo`0JOol2
001XOol20019Ool001Moo`03001oogoo02]oo`03001oogoo01eoo`03001oogoo06Eoo`8004Uoo`00
5goo00<007ooOol0:Woo00<007ooOol07goo00<007ooOol0Hgoo00<007oo0000BGoo000GOol00`00
Oomoo`0ZOol00`00Oomoo`0OOol00`00Oomoo`1SOol01000Oomoo`00B7oo000GOol00`00Oomoo`0Y
Ool00`00Oomoo`0QOol00`00Oomoo`1ROol01000Oomoo`00B7oo000GOol00`00Oomoo`0XOol00`00
Oomoo`0SOol00`00Oomoo`1QOol01@00Oomoogoo0000Agoo000GOol00`00Oomoo`0WOol00`00Oomo
o`0UOol00`00Oomoo`1POol01@00Oomoogoo0000Agoo000GOol2000WOol00`00Oomoo`0VOol00`00
Oomoo`1POol01@00Oomoogoo0000Agoo000GOol00`00Oomoo`0UOol00`00Oomoo`0XOol00`00Oomo
o`1NOol00`00Oomoo`03Ool00`00Oomoo`14Ool001Moo`03001oogoo02Aoo`03001oogoo02Yoo`03
001oogoo05eoo`03001oogoo00=oo`03001oogoo04Aoo`005goo00<007ooOol08goo00<007ooOol0
:goo00<007ooOol0GGoo00<007ooOol00goo00<007ooOol0A7oo000GOol00`00Oomoo`0SOol00`00
Oomoo`0/Ool00`00Oomoo`1LOol00`00Oomoo`04Ool00`00Oomoo`13Ool001Moo`03001oogoo029o
o`03001oogoo02ioo`03001oogoo05]oo`03001oogoo00Aoo`03001oogoo04=oo`005goo00<007oo
Ool08Woo00<007ooOol0;goo00<007ooOol0FWoo00<007ooOol01Goo00<007ooOol0@Woo000GOol0
0`00Oomoo`0QOol00`00Oomoo`0`Ool00`00Oomoo`1IOol00`00Oomoo`06Ool00`00Oomoo`12Ool0
01Moo`80029oo`03001oogoo035oo`03001oogoo05Qoo`03001oogoo00Ioo`03001oogoo049oo`00
5goo00<007ooOol087oo00<007ooOol0<goo00<007ooOol0Egoo00<007ooOol01goo00<007ooOol0
@Goo000GOol00`00Oomoo`0OOol00`00Oomoo`0eOol00`00Oomoo`1FOol00`00Oomoo`07Ool00`00
Oomoo`11Ool001Moo`03001oogoo01moo`03001oogoo03Eoo`03001oogoo05Ioo`03001oogoo00Mo
o`03001oogoo045oo`005goo00<007ooOol07Woo00<007ooOol0=goo00<007ooOol0EGoo00<007oo
Ool027oo00<007ooOol0@7oo000GOol00`00Oomoo`0NOol00`00Oomoo`0gOol00`00Oomoo`1DOol0
0`00Oomoo`09Ool00`00Oomoo`10Ool001Moo`03001oogoo01eoo`03001oogoo03Uoo`03001oogoo
05=oo`03001oogoo00Yoo`03001oogoo03moo`005goo00<007ooOol07Goo00<007ooOol0>Goo00<0
07ooOol0Dgoo00<007ooOol02Woo00<007ooOol0?goo000GOol2000MOol00`00Oomoo`0kOol00`00
Oomoo`1BOol00`00Oomoo`0:Ool00`00Oomoo`0oOol001Moo`03001oogoo01aoo`03001oogoo03]o
o`03001oogoo059oo`03001oogoo00]oo`03001oogoo03ioo`005goo00<007ooOol06goo00<007oo
Ool0?Goo00<007ooOol0DGoo00<007ooOol02goo00<007ooOol0?Woo000GOol00`00Oomoo`0JOol0
0`00Oomoo`0nOol00`00Oomoo`1AOol00`00Oomoo`0;Ool00`00Oomoo`0nOol001Moo`03001oogoo
01Yoo`03001oogoo03moo`03001oogoo04moo`03001oogoo00eoo`03001oogoo03eoo`005goo00<0
07ooOol06Goo00<007ooOol0@7oo00<007ooOol0Cgoo00<007ooOol03Goo00<007ooOol0?Goo0007
Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo00<007ooOol06Goo00<007ooOol0@Goo00<007oo
Ool0CWoo00<007ooOol03Woo00<007ooOol0?7oo0006Ool00`00Ool00009Ool00`00Oomoo`02Ool0
0`00Oomoo`0HOol00`00Oomoo`12Ool00`00Oomoo`1>Ool00`00Oomoo`0>Ool00`00Oomoo`0lOol0
00Ioo`03001oo`0000Qoo`03001oogoo00=oo`<001Qoo`03001oogoo04=oo`03001oogoo04eoo`03
001oogoo00ioo`03001oogoo03aoo`001Woo00<007oo00002Goo00<007ooOol00Woo00<007ooOol0
5goo00<007ooOol0A7oo00<007ooOol0CGoo00<007ooOol03goo00<007ooOol0>goo0006Ool00`00
Ool00007Ool00`00Ool00004Ool00`00Oomoo`0GOol00`00Oomoo`14Ool00`00Oomoo`1<Ool00`00
Oomoo`0@Ool00`00Oomoo`0kOol000Moo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo01Io
o`03001oogoo04Ioo`03001oogoo04]oo`03001oogoo011oo`03001oogoo03]oo`005goo00<007oo
Ool05Woo00<007ooOol0AWoo00<007ooOol0Bgoo00<007ooOol047oo00<007ooOol0>goo000GOol0
0`00Oomoo`0EOol00`00Oomoo`18Ool00`00Oomoo`1:Ool00`00Oomoo`0@Ool00`00Oomoo`0kOol0
01Moo`03001oogoo01Eoo`03001oogoo04Qoo`03001oogoo04Yoo`03001oogoo015oo`03001oogoo
03Yoo`005goo0P005Goo00<007ooOol0BWoo00<007ooOol0BGoo00<007ooOol04Goo00<007ooOol0
>Woo000GOol00`00Oomoo`0DOol00`00Oomoo`1:Ool00`00Oomoo`18Ool00`00Oomoo`0BOol00`00
Oomoo`0jOol001Moo`03001oogoo01Aoo`03001oogoo04]oo`03001oogoo04Moo`03001oogoo019o
o`03001oogoo03Yoo`005goo00<007ooOol04goo00<007ooOol0C7oo00<007ooOol0Agoo00<007oo
Ool04Woo00<007ooOol0>Woo000GOol00`00Oomoo`0COol00`00Oomoo`1=Ool00`00Oomoo`16Ool0
0`00Oomoo`0BOol00`00Oomoo`0jOol001Moo`03001oogoo019oo`03001oogoo04ioo`03001oogoo
04Ioo`03001oogoo01=oo`03001oogoo03Uoo`005goo00<007ooOol04Woo00<007ooOol0Cgoo00<0
07ooOol0AGoo00<007ooOol04goo00<007ooOol0>Goo000GOol00`00Oomoo`0BOol00`00Oomoo`1?
Ool00`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`0iOol001Moo`80019oo`03001oogoo055o
o`03001oogoo04=oo`03001oogoo01Aoo`03001oogoo03Uoo`005goo00<007ooOol04Goo00<007oo
Ool0DGoo00<007ooOol0@goo00<007ooOol057oo00<007ooOol0>Goo000GOol00`00Oomoo`0@Ool0
0`00Oomoo`1BOol00`00Oomoo`13Ool00`00Oomoo`0DOol00`00Oomoo`0iOol001Moo`03001oogoo
011oo`03001oogoo05=oo`03001oogoo049oo`03001oogoo01Eoo`03001oogoo03Qoo`005goo00<0
07ooOol03goo00<007ooOol0E7oo00<007ooOol0@Woo00<007ooOol05Goo00<007ooOol0>7oo000G
Ool00`00Oomoo`0?Ool00`00Oomoo`1EOol00`00Oomoo`10Ool00`00Oomoo`0FOol00`00Oomoo`0h
Ool001Moo`03001oogoo00moo`03001oogoo05Eoo`03001oogoo041oo`03001oogoo01Ioo`03001o
ogoo03Qoo`005goo00<007ooOol03Woo00<007ooOol0EWoo00<007ooOol0@7oo00<007ooOol05Woo
00<007ooOol0>7oo000GOol2000?Ool00`00Oomoo`1GOol00`00Oomoo`0oOol00`00Oomoo`0FOol0
0`00Oomoo`0hOol001Moo`03001oogoo00eoo`03001oogoo05Qoo`03001oogoo03moo`03001oogoo
01Ioo`03001oogoo03Qoo`005goo00<007ooOol03Goo00<007ooOol0FGoo00<007ooOol0?Woo00<0
07ooOol05goo00<007ooOol0=goo000GOol00`00Oomoo`0=Ool00`00Oomoo`1IOol00`00Oomoo`0n
Ool00`00Oomoo`0GOol00`00Oomoo`0gOol001Moo`03001oogoo00aoo`03001oogoo05Yoo`03001o
ogoo03eoo`03001oogoo01Qoo`03001oogoo03Moo`005goo00<007ooOol037oo00<007ooOol0Fgoo
00<007ooOol0?7oo00<007ooOol067oo00<007ooOol0=goo000GOol00`00Oomoo`0;Ool00`00Oomo
o`1LOol00`00Oomoo`0lOol00`00Oomoo`0HOol00`00Oomoo`0gOol001Moo`03001oogoo00]oo`03
001oogoo05eoo`03001oogoo03]oo`03001oogoo01Qoo`03001oogoo03Moo`005goo0P002goo00<0
07ooOol0GWoo00<007ooOol0>goo00<007ooOol06Goo00<007ooOol0=Woo000GOol00`00Oomoo`0:
Ool00`00Oomoo`1NOol00`00Oomoo`0kOol00`00Oomoo`0IOol00`00Oomoo`0fOol001Moo`03001o
ogoo00Yoo`03001oogoo05moo`03001oogoo03Uoo`03001oogoo01Yoo`03001oogoo03Ioo`005goo
00<007ooOol02Goo00<007ooOol0H7oo00<007ooOol0>Goo00<007ooOol06Woo00<007ooOol0=Woo
000GOol00`00Oomoo`09Ool00`00Oomoo`1POol00`00Oomoo`0iOol00`00Oomoo`0JOol00`00Oomo
o`0fOol000Moo`03001oogoo009oo`03001oogoo009oo`<000=oo`03001oogoo00Uoo`03001oogoo
065oo`03001oogoo03Qoo`03001oogoo01Yoo`03001oogoo03Ioo`001Woo00<007oo00002Goo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol0HWoo00<007ooOol0>7oo00<007ooOol06Woo00<0
07ooOol0=Woo0006Ool00`00Ool00007Ool40003Ool30008Ool00`00Oomoo`1SOol00`00Oomoo`0g
Ool00`00Oomoo`0KOol00`00Oomoo`0eOol000Ioo`03001oo`0000Moo`03001oo`0000Aoo`03001o
ogoo00Moo`03001oogoo06Aoo`03001oogoo03Ioo`03001oogoo01aoo`03001oogoo03Eoo`001Woo
00<007oo000027oo0P0017oo00<007ooOol01goo00<007ooOol0I7oo00<007ooOol0=Woo00<007oo
Ool077oo00<007ooOol0=Goo0007Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`1UOol00`00Oomoo`0eOol00`00Oomoo`0LOol00`00Oomoo`0eOol001Moo`03001oogoo
00Ioo`03001oogoo06Ioo`03001oogoo03Eoo`03001oogoo01aoo`03001oogoo03Eoo`005goo00<0
07ooOol01Woo00<007ooOol0Igoo00<007ooOol0=7oo00<007ooOol077oo00<007ooOol0=Goo000G
Ool00`00Oomoo`06Ool00`00Oomoo`1WOol00`00Oomoo`0dOol00`00Oomoo`0MOol00`00Oomoo`0d
Ool001Moo`03001oogoo00Eoo`03001oogoo06Qoo`03001oogoo03=oo`03001oogoo01ioo`03001o
ogoo03Aoo`005goo0P001Woo00<007ooOol0JGoo00<007ooOol0<Woo00<007ooOol07Woo00<007oo
Ool0=7oo000GOol00`00Oomoo`04Ool00`00Oomoo`1ZOol00`00Oomoo`0bOol00`00Oomoo`0NOol0
0`00Oomoo`0dOol001Moo`03001oogoo00Aoo`03001oogoo06]oo`03001oogoo035oo`03001oogoo
01ioo`03001oogoo03Aoo`005goo00<007ooOol017oo00<007ooOol0Jgoo00<007ooOol0<Goo00<0
07ooOol07Woo00<007ooOol0=7oo000GOol00`00Oomoo`03Ool00`00Oomoo`1/Ool00`00Oomoo`0a
Ool00`00Oomoo`0OOol00`00Oomoo`0cOol001Moo`03001oogoo00=oo`03001oogoo06eoo`03001o
ogoo02moo`03001oogoo021oo`03001oogoo03=oo`005goo00<007ooOol00goo00<007ooOol0KGoo
00<007ooOol0;goo00<007ooOol087oo00<007ooOol0<goo000GOol00`00Oomoo`02Ool00`00Oomo
o`1^Ool00`00Oomoo`0_Ool00`00Oomoo`0POol00`00Oomoo`0cOol001Moo`8000=oo`03001oogoo
06moo`03001oogoo02ioo`03001oogoo021oo`03001oogoo03=oo`005goo00D007ooOomoo`00079o
o`03001oogoo02eoo`03001oogoo025oo`03001oogoo03=oo`005goo00D007ooOomoo`0007=oo`03
001oogoo02aoo`03001oogoo025oo`03001oogoo03=oo`005goo00D007ooOomoo`0007=oo`03001o
ogoo02aoo`03001oogoo029oo`03001oogoo039oo`005goo00@007ooOol007Aoo`03001oogoo02ao
o`03001oogoo029oo`03001oogoo039oo`005goo00@007ooOol007Eoo`03001oogoo02]oo`03001o
ogoo029oo`03001oogoo039oo`005goo00@007ooOol007Eoo`03001oogoo02Yoo`03001oogoo02=o
o`03001oogoo039oo`005goo00<007oo0000MWoo00<007ooOol0:Woo00<007ooOol08goo00<007oo
Ool0<Woo000GOol3001gOol00`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomoo`0bOol001Moo`80
07Qoo`03001oogoo02Uoo`03001oogoo02Aoo`03001oogoo035oo`005goo0P00NGoo00<007ooOol0
9goo00<007ooOol09Goo00<007ooOol0<Goo000GOol2001iOol00`00Oomoo`0WOol00`00Oomoo`0U
Ool00`00Oomoo`0aOol001Moo`03001oogoo07Qoo`03001oogoo02Moo`03001oogoo02Eoo`03001o
ogoo035oo`005goo00<007ooOol0NGoo00<007ooOol09Woo00<007ooOol09Goo00<007ooOol09goo
00<007ooOol01goo000GOol00`00Oomoo`1iOol00`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomo
o`0WOol00`00Oomoo`07Ool001Moo`8007Yoo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo
02Ioo`03001oogoo00Qoo`005goo00<007ooOol0NWoo00<007ooOol097oo00<007ooOol09goo00<0
07ooOol09Goo00<007ooOol027oo000GOol00`00Oomoo`1jOol00`00Oomoo`0TOol00`00Oomoo`0W
Ool00`00Oomoo`0TOol00`00Oomoo`09Ool001Moo`03001oogoo07]oo`03001oogoo02=oo`03001o
ogoo02Moo`03001oogoo02Aoo`03001oogoo00Uoo`005goo00<007ooOol0Ngoo00<007ooOol08Woo
00<007ooOol0:7oo00<007ooOol097oo00<007ooOol02Goo000GOol00`00Oomoo`1kOol00`00Oomo
o`0ROol00`00Oomoo`0XOol00`00Oomoo`0SOol00`00Oomoo`0:Ool000Moo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo07aoo`03001oogoo025oo`03001oogoo02Qoo`03
001oogoo02=oo`03001oogoo00Yoo`001Woo00<007oo00001goo00<007oo000017oo00<007ooOol0
O7oo00<007ooOol08Goo00<007ooOol0:Goo00<007ooOol08Goo00<007ooOol02goo0006Ool00`00
Ool00009Ool00`00Oomoo`02Ool3001lOol00`00Oomoo`0QOol00`00Oomoo`0YOol00`00Oomoo`0Q
Ool00`00Oomoo`0;Ool000Ioo`03001oo`0000Moo`8000Eoo`03001oogoo07eoo`03001oogoo01mo
o`03001oogoo02Yoo`03001oogoo025oo`03001oogoo00]oo`001Woo00<007oo00001goo00<007oo
Ool017oo00<007ooOol0OGoo00<007ooOol07goo00<007ooOol0:Woo00<007ooOol087oo00<007oo
Ool037oo0007Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`1nOol00`00Oomoo`0NOol00`00Oomo
o`0ZOol00`00Oomoo`0POol00`00Oomoo`0<Ool001Moo`03001oogoo07ioo`03001oogoo01ioo`03
001oogoo02Yoo`03001oogoo01moo`03001oogoo00eoo`005goo00<007ooOol0OWoo00<007ooOol0
7Woo00<007ooOol0:goo00<007ooOol07Woo00<007ooOol03Goo000GOol00`00Oomoo`1oOol00`00
Oomoo`0LOol00`00Oomoo`0/Ool00`00Oomoo`0MOol00`00Oomoo`0>Ool001Moo`03001oogoo07mo
o`03001oogoo01aoo`03001oogoo02aoo`03001oogoo01eoo`03001oogoo00ioo`005goo0P00P7oo
00<007ooOol077oo00<007ooOol0;7oo00<007ooOol07Goo00<007ooOol03Woo000GOol00`00Oomo
o`20Ool00`00Oomoo`0KOol00`00Oomoo`0/Ool00`00Oomoo`0LOol00`00Oomoo`0?Ool001Moo`03
001oogoo081oo`03001oogoo01Yoo`03001oogoo02ioo`03001oogoo01]oo`03001oogoo00moo`00
5goo00<007ooOol0PGoo00<007ooOol06Goo00<007ooOol0;Woo00<007ooOol06Woo00<007ooOol0
47oo000GOol00`00Oomoo`21Ool00`00Oomoo`0IOol00`00Oomoo`0_Ool00`00Oomoo`0IOol00`00
Oomoo`0@Ool001Moo`03001oogoo089oo`03001oogoo01Qoo`03001oogoo02moo`03001oogoo01Uo
o`03001oogoo011oo`005goo00<007ooOol0PWoo00<007ooOol067oo00<007ooOol0<7oo00<007oo
Ool05goo00<007ooOol04Goo000GOol00`00Oomoo`23Ool00`00Oomoo`0FOol00`00Oomoo`0aOol0
0`00Oomoo`0GOol00`00Oomoo`0AOol001Moo`8008Aoo`03001oogoo01Ioo`03001oogoo039oo`03
001oogoo01Eoo`03001oogoo019oo`005goo00<007ooOol0Q7oo00<007ooOol05Goo00<007ooOol0
<Woo00<007ooOol05Goo00<007ooOol04Woo000GOol00`00Oomoo`24Ool00`00Oomoo`0EOol00`00
Oomoo`0bOol00`00Oomoo`0EOol00`00Oomoo`0BOol001Moo`03001oogoo08Eoo`03001oogoo01=o
o`03001oogoo03Aoo`03001oogoo01=oo`03001oogoo01=oo`005goo00<007ooOol0QGoo00<007oo
Ool04goo00<007ooOol0=7oo00<007ooOol04goo00<007ooOol04goo000GOol00`00Oomoo`26Ool0
0`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`0AOol00`00Oomoo`0DOol001Moo`03001oogoo
08Ioo`03001oogoo019oo`03001oogoo03Eoo`03001oogoo015oo`03001oogoo01Aoo`005goo0P00
R7oo00<007ooOol04Goo00<007ooOol0=Woo00<007ooOol03goo00<007ooOol05Goo000GOol00`00
Oomoo`27Ool00`00Oomoo`0@Ool00`00Oomoo`0gOol00`00Oomoo`0>Ool00`00Oomoo`0FOol001Mo
o`03001oogoo08Qoo`03001oogoo00moo`03001oogoo03Qoo`03001oogoo00aoo`03001oogoo01Mo
o`005goo00<007ooOol0R7oo00<007ooOol03goo00<007ooOol0>7oo00<007ooOol037oo00<007oo
Ool05goo000GOol00`00Oomoo`29Ool00`00Oomoo`0>Ool00`00Oomoo`0iOol00`00Oomoo`0:Ool0
0`00Oomoo`0HOol001Moo`03001oogoo08Uoo`03001oogoo00eoo`03001oogoo03Yoo`03001oogoo
00Uoo`03001oogoo01Uoo`005goo00<007ooOol0RWoo00<007ooOol037oo00<007ooOol0>Woo00<0
07ooOol027oo00<007ooOol06Woo000GOol00`00Oomoo`2:Ool00`00Oomoo`0:Ool3000mOol00`00
Oomoo`06Ool00`00Oomoo`0KOol001Moo`8008aoo`03001oogoo00Eoo`@0041oo`03001oogoo00Eo
o`03001oogoo01aoo`005goo00<007ooOol0Rgoo00@007ooOomoo`@004Eoo`03001oogoo00=oo`03
001oogoo01eoo`005goo00<007ooOol0S7oo0`00BGoo00<007ooOol00Woo00<007ooOol07Woo000G
Ool00`00Oomoo`3IOol01@00Oomoogoo000087oo000GOol00`00Oomoo`3IOol01000Oomoo`008Goo
000GOol00`00Oomoo`3JOol2000ROol000Moo`03001oogoo009oo`04001oogooOol20005Ool00`00
Oomoo`3JOol00`00Oomoo`0QOol000Ioo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0?io
o`001Woo00<007oo00001goo00<007oo000017oo0`00oWoo0006Ool00`00Ool00007Ool20005Ool0
0`00Oomoo`3nOol000Ioo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo0?ioo`001goo00<0
07ooOol01goo0P00ogoo1Woo003oOolIOol00001\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0972471, 0.168487, 0.00406185,
   0.00257622}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To create a series of plots while varying the value of crank arm, the ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used in conjunction with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to generate a nested list of solutions. Note that at each invocation of ",
  
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the value of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is taken from 0 to 1, which takes the angular coordinate of the crank ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " from 0 to 2 pi. This requires the value of ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to jump from 2 pi back to 0 in one step at each new invocation of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is a rather large single step for the numerical solution method. \
To avoid possible numerical difficulties, the initial guesses are reset with \
",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at each invocation of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This generates a nested list of solutions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(positiontable = 
      Table[SetGuess[]; SolveMech[{0, 1}, 20], {crankarm, 1.5, 3., 0.75}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "To generate a series of plots a rather obtuse invocation of ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This shows a plot of slider position at varying values of ",
  StyleBox["crankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      \((ListPlot[#1, PlotJoined \[Rule] True, 
              DisplayFunction \[Rule] Identity]&)\)/@
        \(({T, X4} /. positiontable)\), 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0794076 0.0549056 [
[.21429 .06691 -9 -9 ]
[.21429 .06691 9 0 ]
[.40476 .06691 -9 -9 ]
[.40476 .06691 9 0 ]
[.59524 .06691 -9 -9 ]
[.59524 .06691 9 0 ]
[.78571 .06691 -9 -9 ]
[.78571 .06691 9 0 ]
[.97619 .06691 -3 -9 ]
[.97619 .06691 3 0 ]
[.01131 .18922 -6 -4.5 ]
[.01131 .18922 0 4.5 ]
[.01131 .29903 -6 -4.5 ]
[.01131 .29903 0 4.5 ]
[.01131 .40884 -6 -4.5 ]
[.01131 .40884 0 4.5 ]
[.01131 .51865 -6 -4.5 ]
[.01131 .51865 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .07941 m
.21429 .08566 L
s
[(0.2)] .21429 .06691 0 1 Mshowa
.40476 .07941 m
.40476 .08566 L
s
[(0.4)] .40476 .06691 0 1 Mshowa
.59524 .07941 m
.59524 .08566 L
s
[(0.6)] .59524 .06691 0 1 Mshowa
.78571 .07941 m
.78571 .08566 L
s
[(0.8)] .78571 .06691 0 1 Mshowa
.97619 .07941 m
.97619 .08566 L
s
[(1)] .97619 .06691 0 1 Mshowa
.125 Mabswid
.07143 .07941 m
.07143 .08316 L
s
.11905 .07941 m
.11905 .08316 L
s
.16667 .07941 m
.16667 .08316 L
s
.2619 .07941 m
.2619 .08316 L
s
.30952 .07941 m
.30952 .08316 L
s
.35714 .07941 m
.35714 .08316 L
s
.45238 .07941 m
.45238 .08316 L
s
.5 .07941 m
.5 .08316 L
s
.54762 .07941 m
.54762 .08316 L
s
.64286 .07941 m
.64286 .08316 L
s
.69048 .07941 m
.69048 .08316 L
s
.7381 .07941 m
.7381 .08316 L
s
.83333 .07941 m
.83333 .08316 L
s
.88095 .07941 m
.88095 .08316 L
s
.92857 .07941 m
.92857 .08316 L
s
.25 Mabswid
0 .07941 m
1 .07941 L
s
.02381 .18922 m
.03006 .18922 L
s
[(2)] .01131 .18922 1 0 Mshowa
.02381 .29903 m
.03006 .29903 L
s
[(4)] .01131 .29903 1 0 Mshowa
.02381 .40884 m
.03006 .40884 L
s
[(6)] .01131 .40884 1 0 Mshowa
.02381 .51865 m
.03006 .51865 L
s
[(8)] .01131 .51865 1 0 Mshowa
.125 Mabswid
.02381 .10686 m
.02756 .10686 L
s
.02381 .13431 m
.02756 .13431 L
s
.02381 .16177 m
.02756 .16177 L
s
.02381 .21667 m
.02756 .21667 L
s
.02381 .24412 m
.02756 .24412 L
s
.02381 .27158 m
.02756 .27158 L
s
.02381 .32648 m
.02756 .32648 L
s
.02381 .35394 m
.02756 .35394 L
s
.02381 .38139 m
.02756 .38139 L
s
.02381 .43629 m
.02756 .43629 L
s
.02381 .46375 m
.02756 .46375 L
s
.02381 .4912 m
.02756 .4912 L
s
.02381 .05195 m
.02756 .05195 L
s
.02381 .0245 m
.02756 .0245 L
s
.02381 .54611 m
.02756 .54611 L
s
.02381 .57356 m
.02756 .57356 L
s
.02381 .60101 m
.02756 .60101 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .48527 m
.07393 .46839 L
.12406 .44312 L
.17419 .41175 L
.22431 .37637 L
.27444 .33895 L
.32456 .30142 L
.37469 .2658 L
.42481 .23433 L
.47494 .20981 L
.52506 .19598 L
.57519 .19762 L
.62531 .21995 L
.67544 .26594 L
.72556 .33087 L
.77569 .39888 L
.82581 .45156 L
.87594 .48137 L
.92607 .49092 L
.97619 .48527 L
s
.02381 .53847 m
.07393 .51221 L
.12406 .47651 L
.17419 .43366 L
.22431 .38598 L
.27444 .33568 L
.32456 .2848 L
.37469 .23525 L
.42481 .18911 L
.47494 .1492 L
.52506 .12009 L
.57519 .10965 L
.62531 .13043 L
.67544 .19777 L
.72556 .31494 L
.77569 .44136 L
.82581 .52045 L
.87594 .55058 L
.92607 .55275 L
.97619 .53847 L
s
.02381 .5779 m
.07393 .54601 L
.12406 .50295 L
.17419 .45127 L
.22431 .39377 L
.27444 .33303 L
.32456 .27117 L
.37469 .20984 L
.42481 .15045 L
.47494 .09482 L
.52506 .04664 L
.57519 .01472 L
.62531 .01897 L
.67544 .09636 L
.72556 .28716 L
.77569 .50521 L
.82581 .58961 L
.87594 .60332 L
.92607 .5971 L
.97619 .5779 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo0009Ool0
0`00Oomoo`3oOol=Ool000Uoo`03001oogoo0?moo`eoo`002Goo00<007ooOol0ogoo3Goo0009Ool0
0`00Oomoo`3oOol=Ool000Uoo`03001oogoo09Eoo`L0071oo`002Goo00<007ooOol0Tgoo0P001goo
2000J7oo0009Ool00`00Oomoo`2BOol00`00Oomoo`0?Ool00`00Oomoo`1UOol000Uoo`80095oo`80
019oo`03001oogoo06Eoo`002Goo00<007ooOol0Sgoo00<007ooOol04goo00<007ooOol0I7oo0009
Ool00`00Oomoo`2=Ool2000GOol00`00Oomoo`1SOol000Uoo`03001oogoo08]oo`8001Uoo`03001o
ogoo06=oo`002Goo00<007ooOol0;7oo00<007ooOol00Woo00@007ooOomoo`<002Uoo`03001oogoo
009oo`03001oogoo009oo`<001aoo`03001oogoo00Qoo`03001oogoo009oo`04001oogooOol20007
Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol50006Ool000Uo
o`03001oogoo02]oo`03001oo`0000Moo`03001oogoo02Qoo`03001oo`0000Uoo`03001oogoo01Uo
o`8000Yoo`03001oo`0000Moo`03001oo`0000Ioo`03001oogoo01moo`03001oo`0000Moo`03001o
o`0002eoo`03001oogoo00Ioo`002Goo00<007ooOol0:goo00<007oo000027oo00<007ooOol09goo
00<007oo00001goo10006Goo00<007ooOol02Woo00<007oo00001goo00<007oo00001goo00<007oo
Ool07Woo00<007oo00001goo00<007oo0000;Goo00<007ooOol01Woo0009Ool00`00Oomoo`0[Ool0
0`00Ool00008Ool00`00Oomoo`0WOol00`00Ool00007Ool00`00Ool0000IOol00`00Oomoo`0;Ool0
0`00Ool00007Ool20009Ool00`00Oomoo`0MOol00`00Ool00008Ool00`00Oomoo`0/Ool00`00Oomo
o`06Ool000Uoo`8002aoo`03001oo`0000Moo`03001oo`0002Qoo`03001oo`0000Qoo`8001Qoo`03
001oogoo00aoo`03001oo`0000Moo`03001oogoo00Qoo`03001oogoo01eoo`03001oo`0000Moo`03
001oo`0002eoo`03001oogoo00Ioo`002Goo00<007ooOol0;7oo00<007ooOol01goo00<007ooOol0
:7oo00<007ooOol027oo00<007ooOol05Goo00<007ooOol03Woo00<007ooOol01goo0P002Goo00<0
07ooOol07Goo00<007ooOol01goo00<007ooOol0:goo0P0027oo0009Ool00`00Oomoo`23Ool00`00
Oomoo`0UOol00`00Oomoo`1NOol000Uoo`03001oogoo089oo`03001oogoo02Ioo`03001oogoo05io
o`002Goo00<007ooOol0PGoo00<007ooOol0:7oo00<007ooOol0GGoo0009Ool00`00Oomoo`20Ool0
0`00Oomoo`0ZOol00`00Oomoo`1LOol000Uoo`03001oogoo07moo`03001oogoo02]oo`03001oogoo
05aoo`000Wooo`005`000009Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool01000Oomoo`003Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01Goo0009Ool00`00Oomoo`0b
Ool00`00Oomoo`0aOol00`00Oomoo`0COol00`00Oomoo`0LOol00`00Oomoo`0AOol00`00Oomoo`0M
Ool00`00Oomoo`0bOol00`00Oomoo`05Ool000Uoo`03001oogoo07]oo`03001oogoo039oo`03001o
ogoo05Uoo`002Goo00<007ooOol0NWoo00<007ooOol0<goo00<007ooOol0FGoo0009Ool00`00Oomo
o`1iOol00`00Oomoo`0eOol00`00Oomoo`1HOol000Uoo`03001oogoo07Qoo`03001oogoo03Ioo`03
001oogoo05Qoo`002Goo00<007ooOol0Mgoo00<007ooOol0>7oo00<007ooOol0Egoo0009Ool2001g
Ool00`00Oomoo`0JOol4000KOol00`00Oomoo`1GOol000Uoo`03001oogoo07Ioo`03001oogoo01Io
o`@000Aoo`8001Uoo`03001oogoo05Moo`002Goo00<007ooOol0MGoo00<007ooOol04Woo1@002Woo
0P005goo00<007ooOol0Egoo0009Ool00`00Oomoo`1dOol00`00Oomoo`0@Ool3000AOol3000EOol0
0`00Oomoo`1FOol000Uoo`03001oogoo07=oo`03001oogoo00moo`8001Moo`8001=oo`03001oogoo
05Ioo`002Goo00<007ooOol0LWoo00<007ooOol03Woo0P006goo0P004Goo00<007ooOol0EWoo0009
Ool00`00Oomoo`1aOol00`00Oomoo`0>Ool00`00Oomoo`0MOol2000?Ool00`00Oomoo`1FOol000Uo
o`80075oo`03001oogoo00eoo`80029oo`03001oogoo00eoo`03001oogoo05Eoo`002Goo00<007oo
Ool0Kgoo00<007ooOol03Goo00<007ooOol08Woo00<007ooOol03Goo00<007ooOol0EGoo0009Ool0
0`00Oomoo`1_Ool00`00Oomoo`0;Ool2000VOol00`00Oomoo`0<Ool00`00Oomoo`1EOol000Uoo`03
001oogoo06ioo`03001oogoo00Yoo`8002Uoo`03001oogoo00]oo`03001oogoo05Eoo`002Goo00<0
07ooOol0KGoo00<007ooOol02Woo00<007ooOol0:Woo00<007ooOol02goo00<007ooOol0E7oo0009
Ool00`00Oomoo`1/Ool00`00Oomoo`0:Ool00`00Oomoo`0[Ool00`00Oomoo`0;Ool00`00Oomoo`1D
Ool000Uoo`03001oogoo06]oo`03001oogoo00Uoo`8002moo`03001oogoo00Yoo`03001oogoo05Ao
o`002Goo00<007ooOol0JWoo00<007ooOol02Goo00<007ooOol0<7oo00<007ooOol02Woo00<007oo
Ool0Dgoo0009Ool2001ZOol00`00Oomoo`09Ool00`00Oomoo`0bOol00`00Oomoo`09Ool00`00Oomo
o`1COol000Uoo`03001oogoo06Qoo`03001oogoo00Uoo`03001oogoo03=oo`03001oogoo00Uoo`03
001oogoo05=oo`002Goo00<007ooOol0J7oo00<007ooOol01goo0P00=goo00<007ooOol027oo00<0
07ooOol0Dgoo0009Ool00`00Oomoo`1WOol00`00Oomoo`07Ool00`00Oomoo`0hOol00`00Oomoo`08
Ool00`00Oomoo`1BOol000Uoo`03001oogoo06Ioo`03001oogoo00Moo`03001oogoo03Yoo`03001o
ogoo00Moo`03001oogoo059oo`000Woo0`0017oo00<007ooOol0IGoo00<007ooOol01Woo0P00?Goo
00<007ooOol01goo00<007ooOol0DWoo0002Ool00`00Oomoo`04Ool00`00Oomoo`1TOol00`00Oomo
o`06Ool00`00Oomoo`0nOol00`00Oomoo`06Ool00`00Oomoo`1BOol000=oo`03001oogoo00=oo`<0
06=oo`03001oogoo00Ioo`03001oogoo041oo`03001oogoo00Ioo`03001oogoo055oo`000goo00<0
07ooOol00goo00<007ooOol0HWoo00<007ooOol01Woo00<007ooOol0@Woo00<007ooOol01Goo00<0
07ooOol0DGoo0002Ool00`00Ool00004Ool00`00Oomoo`1QOol00`00Oomoo`06Ool00`00Oomoo`0I
Ool8000ROol00`00Oomoo`05Ool00`00Oomoo`1AOol000=oo`03001oogoo00=oo`03001oogoo065o
o`03001oogoo00Eoo`03001oogoo01Moo`<000Qoo`T001Yoo`03001oogoo00Eoo`03001oogoo051o
o`002Goo00<007ooOol0H7oo00<007ooOol01Goo00<007ooOol057oo100057oo0P0067oo00<007oo
Ool01Goo00<007ooOol0D7oo0009Ool00`00Oomoo`1OOol00`00Oomoo`05Ool00`00Oomoo`0BOol3
000JOol2000GOol00`00Oomoo`04Ool00`00Oomoo`1@Ool000Uoo`03001oogoo05ioo`03001oogoo
00Eoo`03001oogoo015oo`8001moo`<001Aoo`03001oogoo00Aoo`03001oogoo051oo`002Goo00<0
07ooOol0GGoo00<007ooOol017oo0P004Woo0P0097oo0P004goo00<007ooOol017oo00<007ooOol0
Cgoo0009Ool2001MOol00`00Oomoo`04Ool00`00Oomoo`0@Ool2000XOol2000AOol00`00Oomoo`04
Ool00`00Oomoo`1?Ool000Uoo`03001oogoo05aoo`03001oogoo00=oo`03001oogoo00moo`8002ao
o`80011oo`03001oogoo00=oo`03001oogoo04moo`002Goo00<007ooOol0Fgoo00<007ooOol00goo
00<007ooOol03Woo0P00<7oo00<007ooOol03Goo00<007ooOol00goo00<007ooOol0Cgoo0009Ool0
0`00Oomoo`1JOol00`00Oomoo`03Ool00`00Oomoo`0=Ool2000cOol00`00Oomoo`0<Ool00`00Oomo
o`04Ool00`00Oomoo`1>Ool000Uoo`03001oogoo05Uoo`03001oogoo00=oo`03001oogoo00aoo`80
03Ioo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo04ioo`002Goo00<007ooOol0F7oo00<0
07ooOol00goo00<007ooOol02goo0P00>Goo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
CWoo0009Ool00`00Oomoo`1GOol00`00Oomoo`03Ool00`00Oomoo`0:Ool2000lOol00`00Oomoo`0;
Ool00`00Oomoo`02Ool00`00Oomoo`1>Ool000Uoo`03001oogoo05Moo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo03eoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo04eoo`002Goo
0P00Egoo00<007ooOol00Woo00<007ooOol02Goo0P00@Goo0P002goo00<007ooOol00Woo00<007oo
Ool0CGoo0009Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`13Ool0
0`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`1=Ool000Uoo`03001oogoo05Aoo`03001oogoo
009oo`03001oogoo00Qoo`8004Moo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo04aoo`00
2Goo00<007ooOol0Dgoo00<007ooOol00Woo00<007ooOol01goo0P00BWoo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol0C7oo0009Ool00`00Oomoo`1BOol00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`1;Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`1<Ool000Uoo`03001o
ogoo059oo`05001oogooOol00008Ool2001?Ool00`00Oomoo`06Ool01@00Oomoogoo0000CWoo0009
Ool00`00Oomoo`1AOol01@00Oomoogoo000027oo00<007ooOol0D7oo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol0Bgoo0009Ool2001AOol01@00Oomoogoo00001goo0P00E7oo00<007ooOol0
1Goo00D007ooOomoo`0004eoo`002Goo00<007ooOol0Cgoo00D007ooOomoo`0000Moo`03001oogoo
05Eoo`03001oogoo00Aoo`05001oogooOol0001=Ool000Uoo`03001oogoo04ioo`05001oogooOol0
0006Ool2001HOol00`00Oomoo`05Ool01000Oomoo`00CGoo0009Ool00`00Oomoo`1>Ool01000Oomo
o`001Woo00<007ooOol0FGoo00<007ooOol017oo00D007ooOomoo`0004aoo`002Goo00<007ooOol0
CGoo00@007ooOol000Eoo`8005eoo`03001oogoo00=oo`05001oogooOol0001<Ool000Uoo`03001o
ogoo04aoo`04001oogoo0004Ool2001POol00`00Oomoo`03Ool01000Oomoo`00C7oo0003Ool30003
Ool00`00Oomoo`1;Ool01000Oomoo`0017oo00<007ooOol0H7oo00<007ooOol00goo00@007ooOol0
04aoo`0017oo00<007ooOol00Woo00<007ooOol0BWoo00@007ooOol000=oo`8006Aoo`03001oogoo
00=oo`04001oogoo001;Ool0009oo`@000=oo`<004Uoo`04001oogoo0003Ool00`00Oomoo`1UOol0
0`00Oomoo`02Ool01000Oomoo`00Bgoo0002Ool00`00Ool00004Ool00`00Oomoo`19Ool00`00Ool0
0003Ool00`00Oomoo`1WOol00`00Oomoo`02Ool00`00Ool0001;Ool000=oo`8000Aoo`03001oogoo
04Qoo`03001oo`00009oo`8006]oo`07001oogooOol007oo0000Bgoo0004Ool00`00Oomoo`02Ool0
0`00Oomoo`17Ool00`00Ool00002Ool00`00Oomoo`1[Ool00`00Oomoo`02Ool00`00Ool0001:Ool0
00Uoo`03001oogoo04Ioo`03001oo`00009oo`03001oogoo06eoo`07001oogooOol007oo0000BWoo
0009Ool00`00Oomoo`15Ool00`00Ool00002Ool00`00Oomoo`1_Ool01P00Oomoo`00Ool004Yoo`00
2Goo00<007ooOol0A7oo00@007oo001oo`8007=oo`03001oogoo008004Yoo`002Goo0P00AGoo0P00
00=oo`00Ool0M7oo00H007ooOol007oo0019Ool000Uoo`03001oogoo04=oo`800003Ool007oo07Io
o`03001oogoo008004Uoo`002Goo00<007ooOol0@Woo1000NGoo00@007oo000004Uoo`002Goo00<0
07ooOol0@Goo0`00O7oo0`00BGoo0009Ool00`00Oomoo`10Ool3001nOol20019Ool000Uoo`03001o
ogoo041oo`8007moo`<004Qoo`002Goo00<007ooOol0?goo00<007ooOol0P7oo0P00B7oo0009Ool0
0`00Oomoo`0nOol00`00Oomoo`22Ool00`00Oomoo`16Ool000Uoo`8003eoo`8008Eoo`8004Moo`00
2Goo00<007ooOol0>goo0P00Qgoo00<007ooOol0AGoo0009Ool00`00Oomoo`0iOol30028Ool20016
Ool000Uoo`03001oogoo03Qoo`04001oo`000028Ool30015Ool000Uoo`03001oogoo03Moo`04001o
o`000029Ool200000goo001oo`13Ool000Uoo`03001oogoo03Eoo`800003Ool0000008]oo`04001o
ogoo0013Ool000Uoo`03001oogoo03Aoo`03001oogoo008008aoo`800003Ool007oo049oo`002Goo
0P00<goo0P000Woo0P00SGoo0P000Woo00<007ooOol0@7oo0009Ool00`00Oomoo`0aOol01000Oomo
ogoo0P00SWoo00<007oo00000Woo00<007ooOol0?goo0009Ool00`00Oomoo`0`Ool01`00Oomoogoo
001oo`0008ioo`03001oo`0000=oo`03001oogoo03ioo`002Goo00<007ooOol0;Woo0P000goo00<0
07oo0000T7oo0P000goo00<007ooOol0?Woo0009Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00
Ool0002AOol00`00Ool00003Ool00`00Oomoo`0mOol000Uoo`03001oogoo02]oo`8000Aoo`03001o
o`00099oo`03001oo`0000Aoo`03001oogoo03aoo`000Woo0P001Goo00<007ooOol0:Woo00<007oo
Ool00goo00<007oo0000Tgoo00@007ooOol000Aoo`03001oogoo03]oo`000Woo00<007oo000017oo
00<007ooOol0:Goo00<007ooOol00goo00<007oo0000UGoo00<007oo00001Goo00<007ooOol0>Woo
0002Ool00`00Ool00004Ool3000WOol20005Ool00`00Ool0002FOol00`00Ool00006Ool00`00Oomo
o`0iOol0009oo`8000Eoo`03001oogoo02Ioo`03001oogoo00=oo`80009oo`03001oogoo09Aoo`04
001oogoo0005Ool00`00Oomoo`0iOol0009oo`03001oogoo00Aoo`03001oogoo02Aoo`8000Eoo`05
001oogooOol0002GOol01000Oomoo`001Woo00<007ooOol0>7oo0003Ool20004Ool00`00Oomoo`0S
Ool00`00Oomoo`04Ool01@00Oomoogoo0000V7oo00D007ooOomoo`0000Ioo`03001oogoo03Moo`00
2Goo00<007ooOol08Goo0P001Woo00D007ooOomoo`0009Yoo`04001oogoo0007Ool00`00Oomoo`0f
Ool000Uoo`03001oogoo021oo`03001oogoo00Eoo`05001oogooOol0002KOol01000Oomoo`0027oo
00<007ooOol0=Goo0009Ool00`00Oomoo`0OOol00`00Oomoo`05Ool01@00Oomoogoo0000W7oo00D0
07ooOomoo`0000Qoo`03001oogoo03Aoo`002Goo00<007ooOol07Goo0P001goo00D007ooOomoo`00
09eoo`05001oogooOol00009Ool00`00Oomoo`0cOol000Uoo`8001eoo`03001oogoo00Ioo`05001o
ogooOol0002OOol01@00Oomoogoo00002Goo00<007ooOol0<Woo0009Ool00`00Oomoo`0JOol20008
Ool00`00Oomoo`02Ool00`00Oomoo`2MOol01@00Oomoogoo00002Goo00<007ooOol0<Woo0009Ool0
0`00Oomoo`0IOol00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`2NOol00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`0aOol000Uoo`03001oogoo01Moo`8000Uoo`03001oogoo009oo`03
001oogoo09moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo031oo`002Goo00<007ooOol0
5Goo0P002Woo00<007ooOol00Woo00<007ooOol0XGoo00<007ooOol00Woo00<007ooOol027oo00<0
07ooOol0;goo0009Ool00`00Oomoo`0COol2000:Ool20004Ool00`00Oomoo`2ROol00`00Oomoo`02
Ool00`00Oomoo`09Ool2000_Ool000Uoo`03001oogoo015oo`8000]oo`03001oogoo00=oo`03001o
ogoo0:=oo`03001oogoo00=oo`03001oogoo00Yoo`8002eoo`002Goo0P0047oo0P0037oo00<007oo
Ool00goo00<007ooOol0Y7oo00<007ooOol017oo00<007ooOol02goo0P00:goo0009Ool00`00Oomo
o`0=Ool2000=Ool00`00Oomoo`03Ool00`00Oomoo`2UOol00`00Oomoo`04Ool00`00Oomoo`0=Ool0
0`00Oomoo`0XOol000Uoo`03001oogoo00Yoo`<000ioo`03001oogoo00=oo`03001oogoo0:Moo`03
001oogoo00Aoo`03001oogoo00eoo`8002Qoo`002Goo00<007ooOol01Woo100047oo00<007ooOol0
0goo00<007ooOol0Z7oo00<007ooOol017oo00<007ooOol03goo0P009Woo0009Ool00`00Oomoo`03
Ool3000COol00`00Oomoo`03Ool00`00Oomoo`2YOol00`00Oomoo`05Ool00`00Oomoo`0@Ool2000T
Ool000Uoo`03001oo`0000<001Aoo`8000Ioo`03001oogoo0:Uoo`03001oogoo00Eoo`03001oogoo
019oo`<0025oo`002Goo0P005goo00<007ooOol01Goo00<007ooOol0Zgoo00<007ooOol01Goo00<0
07ooOol057oo10004Woo10001goo0009Ool00`00Oomoo`0EOol00`00Oomoo`05Ool00`00Oomoo`2/
Ool00`00Oomoo`06Ool00`00Oomoo`0GOol50006Ool7000;Ool000Uoo`8001Aoo`8000Moo`03001o
ogoo0:eoo`03001oogoo00Ioo`03001oogoo01aoo`H0019oo`002Goo00<007ooOol04Woo00<007oo
Ool01Woo00<007ooOol0[Woo00<007ooOol01goo00<007ooOol0<goo0009Ool00`00Oomoo`0@Ool2
0008Ool00`00Oomoo`2`Ool00`00Oomoo`06Ool00`00Oomoo`0cOol000Uoo`03001oogoo00moo`03
001oogoo00Moo`03001oogoo0;5oo`03001oogoo00Moo`03001oogoo039oo`002Goo00<007ooOol0
3Woo00<007ooOol01goo00<007ooOol0/Woo00<007ooOol027oo00<007ooOol0<Goo0003Ool00`00
Oomoo`03Ool00`00Oomoo`0<Ool20009Ool00`00Oomoo`2dOol00`00Oomoo`07Ool00`00Oomoo`0a
Ool0009oo`03001oo`0000Aoo`03001oogoo00]oo`03001oogoo00Moo`800;Moo`03001oogoo00Qo
o`03001oogoo031oo`000Woo00<007oo000017oo0`002Goo0P002Goo00<007ooOol0^7oo00<007oo
Ool01goo00<007ooOol0<7oo0003Ool00`00Oomoo`03Ool00`00Oomoo`07Ool2000:Ool00`00Oomo
o`2iOol00`00Oomoo`08Ool00`00Oomoo`0_Ool0009oo`03001oo`0000Aoo`03001oogoo00Eoo`80
00]oo`03001oogoo0;]oo`03001oogoo00Qoo`8002moo`000goo00<007ooOol00goo00<007ooOol0
0goo0P0037oo00<007ooOol0_7oo00<007ooOol02Woo0P00;Goo0009Ool01000Oomoogoo0P003Goo
00<007ooOol0_Woo00<007ooOol02goo0P00:goo0009Ool01000Ool000003Goo0P00`Woo00<007oo
Ool037oo00<007ooOol0:7oo0009Ool2000>Ool00`00Oomoo`32Ool00`00Oomoo`0=Ool2000OOol2
0007Ool000Uoo`03001oogoo00aoo`03001oogoo0<Aoo`03001oogoo00ioo`8001Uoo`@000Uoo`00
2Goo0P0037oo00<007ooOol0aGoo00<007ooOol047oo0P0057oo0`003Goo0009Ool00`00Oomoo`09
Ool20039Ool00`00Oomoo`0AOol70009Ool4000@Ool000Uoo`03001oogoo00Qoo`03001oogoo0<Uo
o`03001oogoo01Qoo`T001Aoo`002Goo00<007ooOol01Woo0P00cGoo00<007ooOol0=7oo0009Ool0
0`00Oomoo`05Ool00`00Oomoo`3=Ool00`00Oomoo`0dOol000Uoo`03001oogoo00=oo`800=5oo`03
001oogoo03=oo`002Goo00@007ooOomoo`800=Aoo`03001oogoo039oo`002Goo00@007ooOol00=Io
o`03001oogoo039oo`002Goo0`00f7oo00<007ooOol0<Goo0009Ool00`00Oomoo`3HOol00`00Oomo
o`0XOol20007Ool000Uoo`03001oogoo0=Uoo`03001oogoo02Aoo`<000Uoo`002Goo00<007ooOol0
fGoo00<007ooOol08Woo0P0037oo0009Ool00`00Oomoo`3JOol2000OOol3000>Ool000Uoo`03001o
ogoo0=aoo`@001Qoo`<0015oo`002Goo00<007ooOol0h7oo0`0047oo1@0057oo0009Ool2003TOol4
0005Ool7000IOol000Uoo`03001oogoo0>Moo`D0021oo`002Goo00<007ooOol0ogoo3Goo0009Ool0
0`00Oomoo`3oOol=Ool000Uoo`03001oogoo0?moo`eoo`002Goo00<007ooOol0ogoo3Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0359458, -1.49076, 0.00380269,
   0.0659607}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Interpolation"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects can be used to improve the appearance of a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by smoothing out the data. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " provides a function that facilitates the creation of ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects, by assuming a dependence on time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TimeInterpolate[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["expr",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["rules2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["rulesn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns an interpolating function representing ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " as a function of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The expression ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " must evaluate to a number when subject to ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  ", and each of the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  " must contain a specification for time."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " interpolation utility."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Using the quick-return mechanism model that was defined in the last \
subsection, the plot of the connecting rod angle is reproduced using ",
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to create an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This generates a list of solutions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(crankarm = 3; \)\), 
    \(\(SetGuess[]; \)\), 
    \(\(positiontable = SolveMech[{0, 1}, 20]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "This generates an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeInterpolate[Angle[Line[drivearm, 2, slider, 1]], positiontable]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0, 1.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[
"Here is a plot of the connecting rod angle versus time."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[%[T], {T, 0, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.286842 1.49737 [
[.21429 .00013 -9 -9 ]
[.21429 .00013 9 0 ]
[.40476 .00013 -9 -9 ]
[.40476 .00013 9 0 ]
[.59524 .00013 -9 -9 ]
[.59524 .00013 9 0 ]
[.78571 .00013 -9 -9 ]
[.78571 .00013 9 0 ]
[.97619 .00013 -3 -9 ]
[.97619 .00013 3 0 ]
[.01131 .16237 -18 -4.5 ]
[.01131 .16237 0 4.5 ]
[.01131 .31211 -18 -4.5 ]
[.01131 .31211 0 4.5 ]
[.01131 .46184 -18 -4.5 ]
[.01131 .46184 0 4.5 ]
[.01131 .61158 -18 -4.5 ]
[.01131 .61158 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01263 m
.21429 .01888 L
s
[(0.2)] .21429 .00013 0 1 Mshowa
.40476 .01263 m
.40476 .01888 L
s
[(0.4)] .40476 .00013 0 1 Mshowa
.59524 .01263 m
.59524 .01888 L
s
[(0.6)] .59524 .00013 0 1 Mshowa
.78571 .01263 m
.78571 .01888 L
s
[(0.8)] .78571 .00013 0 1 Mshowa
.97619 .01263 m
.97619 .01888 L
s
[(1)] .97619 .00013 0 1 Mshowa
.125 Mabswid
.07143 .01263 m
.07143 .01638 L
s
.11905 .01263 m
.11905 .01638 L
s
.16667 .01263 m
.16667 .01638 L
s
.2619 .01263 m
.2619 .01638 L
s
.30952 .01263 m
.30952 .01638 L
s
.35714 .01263 m
.35714 .01638 L
s
.45238 .01263 m
.45238 .01638 L
s
.5 .01263 m
.5 .01638 L
s
.54762 .01263 m
.54762 .01638 L
s
.64286 .01263 m
.64286 .01638 L
s
.69048 .01263 m
.69048 .01638 L
s
.7381 .01263 m
.7381 .01638 L
s
.83333 .01263 m
.83333 .01638 L
s
.88095 .01263 m
.88095 .01638 L
s
.92857 .01263 m
.92857 .01638 L
s
.25 Mabswid
0 .01263 m
1 .01263 L
s
.02381 .16237 m
.03006 .16237 L
s
[(0.3)] .01131 .16237 1 0 Mshowa
.02381 .31211 m
.03006 .31211 L
s
[(0.4)] .01131 .31211 1 0 Mshowa
.02381 .46184 m
.03006 .46184 L
s
[(0.5)] .01131 .46184 1 0 Mshowa
.02381 .61158 m
.03006 .61158 L
s
[(0.6)] .01131 .61158 1 0 Mshowa
.125 Mabswid
.02381 .04258 m
.02756 .04258 L
s
.02381 .07253 m
.02756 .07253 L
s
.02381 .10247 m
.02756 .10247 L
s
.02381 .13242 m
.02756 .13242 L
s
.02381 .19232 m
.02756 .19232 L
s
.02381 .22226 m
.02756 .22226 L
s
.02381 .25221 m
.02756 .25221 L
s
.02381 .28216 m
.02756 .28216 L
s
.02381 .34205 m
.02756 .34205 L
s
.02381 .372 m
.02756 .372 L
s
.02381 .40195 m
.02756 .40195 L
s
.02381 .4319 m
.02756 .4319 L
s
.02381 .49179 m
.02756 .49179 L
s
.02381 .52174 m
.02756 .52174 L
s
.02381 .55169 m
.02756 .55169 L
s
.02381 .58163 m
.02756 .58163 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .42302 m
.06244 .31744 L
.10458 .21136 L
.14415 .12786 L
.18221 .06742 L
.20178 .04493 L
.21267 .03502 L
.22272 .02756 L
.23293 .02176 L
.23832 .0194 L
.24402 .01742 L
.24641 .01675 L
.24897 .01614 L
.25119 .0157 L
.25361 .01531 L
.25507 .01512 L
.25643 .01498 L
.25773 .01487 L
.2584 .01483 L
.25912 .01479 L
.25983 .01476 L
.26048 .01474 L
.26176 .01472 L
.26293 .01472 L
.26416 .01475 L
.26538 .01481 L
.26607 .01485 L
.26671 .01489 L
.26912 .01513 L
.27131 .01543 L
.27364 .01583 L
.27847 .01699 L
.2838 .01874 L
.29326 .02299 L
.30213 .02831 L
.32232 .04515 L
.34082 .06644 L
.38045 .12927 L
.41855 .20965 L
.45912 .3119 L
.49816 .41868 L
.51807 .47163 L
.53966 .52539 L
.54976 .54765 L
.56046 .56794 L
.57048 .58323 L
.57964 .59379 L
.58448 .59791 L
.58671 .59941 L
.58908 .6007 L
Mistroke
.5904 .60129 L
.59159 .60173 L
.59281 .6021 L
.59393 .60236 L
.59524 .60257 L
.59592 .60264 L
.59665 .60268 L
.59787 .60268 L
.59857 .60263 L
.59921 .60256 L
.60035 .60238 L
.60159 .60208 L
.60276 .60171 L
.60384 .60128 L
.60589 .60026 L
.60806 .59886 L
.61256 .59489 L
.61753 .58876 L
.62246 .58077 L
.62494 .57601 L
.62634 .57233 L
.62765 .56852 L
.63691 .53757 L
.65778 .4461 L
.67828 .32983 L
.69688 .19506 L
.70622 .13299 L
.7161 .07663 L
.72127 .05233 L
.72268 .04639 L
.7242 .0404 L
.72493 .03764 L
.72563 .03529 L
.72694 .03432 L
.72814 .03369 L
.72942 .0333 L
.73051 .03319 L
.73171 .0333 L
.733 .03369 L
.73373 .03403 L
.7344 .03441 L
.73562 .03531 L
.73691 .03652 L
.73948 .03967 L
.7419 .04356 L
.74644 .05312 L
.75133 .06651 L
.75663 .0844 L
.77499 .16898 L
.79445 .2921 L
Mistroke
.81588 .43328 L
.8209 .46404 L
.82567 .49168 L
.82831 .50254 L
.83118 .51352 L
.83621 .53114 L
.84601 .55972 L
.85525 .57992 L
.86021 .58819 L
.86558 .59514 L
.86795 .59757 L
.87045 .59972 L
.8728 .60134 L
.87494 .6025 L
.87622 .603 L
.87743 .6032 L
.87872 .6033 L
.87944 .60332 L
.88011 .6033 L
.88122 .60321 L
.88245 .60302 L
.88373 .60273 L
.88494 .60236 L
.8877 .6012 L
.89022 .59976 L
.89591 .59523 L
.90066 .5902 L
.90573 .58366 L
.91485 .56917 L
.93556 .52608 L
.97619 .42302 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo0013Ool0
0`00Oomoo`02Ool01000Oomoogoo0`009Goo00<007ooOol00Woo00<007ooOol00Woo0`009Goo00<0
07ooOol00Woo00@007ooOomoo`8002Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Mo
o`D000Qoo`00@Woo00<007oo00001goo00<007ooOol097oo00<007oo00002Goo00<007ooOol08goo
00<007oo00001goo00<007oo000097oo00<007oo00001goo00<007oo0000:Woo00<007ooOol027oo
0012Ool00`00Ool00008Ool00`00Oomoo`0SOol00`00Ool00007Ool4000TOol00`00Ool00007Ool0
0`00Ool0000TOol00`00Ool00007Ool00`00Ool0000ZOol00`00Oomoo`08Ool0049oo`03001oo`00
00Qoo`03001oogoo02=oo`03001oo`0000Moo`03001oo`0002Eoo`03001oo`0000Moo`8002Eoo`03
001oo`0000Qoo`03001oogoo02Uoo`03001oogoo00Qoo`00@Woo00<007oo00001goo00<007oo0000
97oo00<007oo000027oo0P009Goo00<007oo00001goo00<007ooOol097oo00<007oo00001goo00<0
07oo0000:Woo00<007ooOol027oo0013Ool00`00Oomoo`07Ool00`00Oomoo`0TOol00`00Oomoo`08
Ool00`00Oomoo`0TOol00`00Oomoo`07Ool2000UOol00`00Oomoo`07Ool00`00Oomoo`0XOol2000:
Ool00?mooaUoo`00ogoo6Goo000GOol00`00Oomoo`3nOol001Moo`03001oogoo0?ioo`005goo00<0
07ooOol0oWoo000GOol00`00Oomoo`3nOol0015oool000D000=oo`005goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol017oo10000Woo00<007ooOol0
10001Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007oo
Ool01goo000GOol00`00Oomoo`0cOol2000=Ool2002jOol001Moo`03001oogoo039oo`03001oogoo
00moo`03001oogoo0;Moo`005goo00<007ooOol0<Goo00<007ooOol04Goo00<007ooOol0]Woo000G
Ool00`00Oomoo`0_Ool2000EOol00`00Oomoo`1ZOol30018Ool001Moo`03001oogoo02ioo`03001o
ogoo01Ioo`8006Yoo`04001oogoo0017Ool001Moo`03001oogoo02aoo`8001]oo`03001oogoo06Mo
o`05001oogooOol00016Ool001Moo`8002aoo`03001oogoo01aoo`03001oogoo06Eoo`03001oogoo
009oo`03001oogoo04Aoo`005goo00<007ooOol0:Woo00<007ooOol07Woo00<007ooOol0I7oo00<0
07ooOol00Woo00<007ooOol0A7oo000GOol00`00Oomoo`0YOol00`00Oomoo`0POol00`00Oomoo`1S
Ool00`00Oomoo`03Ool00`00Oomoo`13Ool001Moo`03001oogoo02Qoo`03001oogoo025oo`03001o
ogoo06=oo`03001oogoo00=oo`03001oogoo04=oo`005goo00<007ooOol0:7oo00<007ooOol08Woo
00<007ooOol0HWoo00<007ooOol017oo00<007ooOol0@Woo000GOol00`00Oomoo`0WOol00`00Oomo
o`0TOol00`00Oomoo`1POol00`00Oomoo`05Ool00`00Oomoo`12Ool001Moo`03001oogoo02Ioo`03
001oogoo02Ioo`03001oogoo05moo`03001oogoo00Ioo`03001oogoo045oo`005goo0P009Woo00<0
07ooOol0:7oo00<007ooOol0GWoo00<007ooOol01Woo00<007ooOol0@Goo000GOol00`00Oomoo`0U
Ool00`00Oomoo`0XOol00`00Oomoo`1NOol00`00Oomoo`06Ool00`00Oomoo`11Ool001Moo`03001o
ogoo02Aoo`03001oogoo02Yoo`03001oogoo05eoo`03001oogoo00Moo`03001oogoo041oo`005goo
00<007ooOol08goo00<007ooOol0;7oo00<007ooOol0G7oo00<007ooOol01goo00<007ooOol0@7oo
000GOol00`00Oomoo`0SOol00`00Oomoo`0/Ool00`00Oomoo`1KOol00`00Oomoo`08Ool00`00Oomo
o`10Ool001Moo`03001oogoo029oo`03001oogoo02ioo`03001oogoo05Yoo`03001oogoo00Qoo`03
001oogoo041oo`005goo00<007ooOol08Woo00<007ooOol0;goo00<007ooOol0FGoo00<007ooOol0
2Goo00<007ooOol0?goo000GOol00`00Oomoo`0QOol00`00Oomoo`0`Ool00`00Oomoo`1IOol00`00
Oomoo`09Ool00`00Oomoo`0oOol001Moo`80025oo`03001oogoo039oo`03001oogoo05Qoo`03001o
ogoo00Uoo`03001oogoo03moo`005goo00<007ooOol087oo00<007ooOol0<goo00<007ooOol0EWoo
00<007ooOol02Woo00<007ooOol0?goo000GOol00`00Oomoo`0OOol00`00Oomoo`0eOol00`00Oomo
o`1EOol00`00Oomoo`0;Ool00`00Oomoo`0nOol001Moo`03001oogoo01ioo`03001oogoo03Ioo`03
001oogoo05Eoo`03001oogoo00]oo`03001oogoo03ioo`005goo00<007ooOol07Woo00<007ooOol0
=goo00<007ooOol0E7oo00<007ooOol02goo00<007ooOol0?Woo000GOol00`00Oomoo`0MOol00`00
Oomoo`0iOol00`00Oomoo`1COol00`00Oomoo`0;Ool00`00Oomoo`0nOol001Moo`03001oogoo01eo
o`03001oogoo03Uoo`03001oogoo059oo`03001oogoo00aoo`03001oogoo03ioo`005goo00<007oo
Ool077oo00<007ooOol0>goo00<007ooOol0DGoo00<007ooOol03Goo00<007ooOol0?Goo000GOol2
000MOol00`00Oomoo`0kOol00`00Oomoo`1AOol00`00Oomoo`0=Ool00`00Oomoo`0mOol001Moo`03
001oogoo01]oo`03001oogoo03eoo`03001oogoo051oo`03001oogoo00eoo`03001oogoo03eoo`00
5goo00<007ooOol06goo00<007ooOol0?Goo00<007ooOol0D7oo00<007ooOol03Goo00<007ooOol0
?Goo000GOol00`00Oomoo`0JOol00`00Oomoo`0oOol00`00Oomoo`1?Ool00`00Oomoo`0>Ool00`00
Oomoo`0lOol001Moo`03001oogoo01Yoo`03001oogoo03moo`03001oogoo04ioo`03001oogoo00mo
o`03001oogoo03aoo`005goo00<007ooOol06Goo00<007ooOol0@Goo00<007ooOol0CGoo00<007oo
Ool03goo00<007ooOol0?7oo0007Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo00<007ooOol0
6Goo00<007ooOol0@Goo00<007ooOol0CGoo00<007ooOol03goo00<007ooOol0?7oo0006Ool00`00
Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Oomoo`12Ool00`00Oomoo`1=Ool00`00
Oomoo`0@Ool00`00Oomoo`0kOol000Ioo`03001oo`0000Qoo`03001oogoo00=oo`<001Qoo`03001o
ogoo04=oo`03001oogoo04aoo`03001oogoo011oo`03001oogoo03]oo`001Woo00<007oo00002Goo
00<007ooOol00Woo00<007ooOol05goo00<007ooOol0A7oo00<007ooOol0C7oo00<007ooOol047oo
00<007ooOol0>goo0006Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0GOol00`00Oomo
o`15Ool00`00Oomoo`1;Ool00`00Oomoo`0@Ool00`00Oomoo`0kOol000Moo`03001oogoo00Moo`03
001oogoo00=oo`03001oogoo01Ioo`03001oogoo04Ioo`03001oogoo04]oo`03001oogoo011oo`03
001oogoo03]oo`005goo00<007ooOol05Woo00<007ooOol0Agoo00<007ooOol0BGoo00<007ooOol0
4Goo00<007ooOol0>goo000GOol00`00Oomoo`0EOol00`00Oomoo`18Ool00`00Oomoo`19Ool00`00
Oomoo`0BOol00`00Oomoo`0jOol001Moo`03001oogoo01Eoo`03001oogoo04Qoo`03001oogoo04Uo
o`03001oogoo019oo`03001oogoo03Yoo`005goo0P005Goo00<007ooOol0BWoo00<007ooOol0B7oo
00<007ooOol04Woo00<007ooOol0>Woo000GOol00`00Oomoo`0DOol00`00Oomoo`1:Ool00`00Oomo
o`18Ool00`00Oomoo`0BOol00`00Oomoo`0jOol001Moo`03001oogoo01=oo`03001oogoo04aoo`03
001oogoo04Moo`03001oogoo019oo`03001oogoo03Yoo`005goo00<007ooOol04goo00<007ooOol0
C7oo00<007ooOol0Agoo00<007ooOol04Woo00<007ooOol0>Woo000GOol00`00Oomoo`0BOol00`00
Oomoo`1>Ool00`00Oomoo`16Ool00`00Oomoo`0COol00`00Oomoo`0iOol001Moo`03001oogoo019o
o`03001oogoo04ioo`03001oogoo04Eoo`03001oogoo01Aoo`03001oogoo03Uoo`005goo00<007oo
Ool04Woo00<007ooOol0CWoo00<007ooOol0AGoo00<007ooOol057oo00<007ooOol0>Goo000GOol0
0`00Oomoo`0AOol00`00Oomoo`1@Ool00`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`0iOol0
01Moo`80019oo`03001oogoo051oo`03001oogoo04Aoo`03001oogoo01Aoo`03001oogoo03Uoo`00
5goo00<007ooOol047oo00<007ooOol0DWoo00<007ooOol0@goo00<007ooOol057oo00<007ooOol0
>Goo000GOol00`00Oomoo`0@Ool00`00Oomoo`1BOol00`00Oomoo`13Ool00`00Oomoo`0DOol00`00
Oomoo`0iOol001Moo`03001oogoo011oo`03001oogoo05=oo`03001oogoo049oo`03001oogoo01Eo
o`03001oogoo03Qoo`005goo00<007ooOol03goo00<007ooOol0E7oo00<007ooOol0@Goo00<007oo
Ool05Woo00<007ooOol0>7oo000GOol00`00Oomoo`0?Ool00`00Oomoo`1DOol00`00Oomoo`11Ool0
0`00Oomoo`0FOol00`00Oomoo`0hOol001Moo`03001oogoo00ioo`03001oogoo05Ioo`03001oogoo
041oo`03001oogoo01Ioo`03001oogoo03Qoo`005goo00<007ooOol03Woo00<007ooOol0EWoo00<0
07ooOol0@7oo00<007ooOol05Woo00<007ooOol0>7oo000GOol2000?Ool00`00Oomoo`1GOol00`00
Oomoo`0oOol00`00Oomoo`0FOol00`00Oomoo`0hOol001Moo`03001oogoo00eoo`03001oogoo05Qo
o`03001oogoo03moo`03001oogoo01Moo`03001oogoo03Moo`005goo00<007ooOol03Goo00<007oo
Ool0F7oo00<007ooOol0?goo00<007ooOol05goo00<007ooOol0=goo000GOol00`00Oomoo`0<Ool0
0`00Oomoo`1JOol00`00Oomoo`0mOol00`00Oomoo`0HOol00`00Oomoo`0gOol001Moo`03001oogoo
00aoo`03001oogoo05Yoo`03001oogoo03eoo`03001oogoo01Qoo`03001oogoo03Moo`005goo00<0
07ooOol037oo00<007ooOol0Fgoo00<007ooOol0?7oo00<007ooOol067oo00<007ooOol0=goo000G
Ool00`00Oomoo`0;Ool00`00Oomoo`1LOol00`00Oomoo`0lOol00`00Oomoo`0HOol00`00Oomoo`0g
Ool001Moo`03001oogoo00]oo`03001oogoo05eoo`03001oogoo03]oo`03001oogoo01Uoo`03001o
ogoo03Ioo`005goo0P0037oo00<007ooOol0GGoo00<007ooOol0>goo00<007ooOol06Goo00<007oo
Ool0=Woo000GOol00`00Oomoo`0:Ool00`00Oomoo`1NOol00`00Oomoo`0kOol00`00Oomoo`0IOol0
0`00Oomoo`0fOol001Moo`03001oogoo00Yoo`03001oogoo05moo`03001oogoo03Uoo`03001oogoo
01Yoo`03001oogoo03Ioo`005goo00<007ooOol02Goo00<007ooOol0H7oo00<007ooOol0>Goo00<0
07ooOol06Woo00<007ooOol0=Woo000GOol00`00Oomoo`09Ool00`00Oomoo`1QOol00`00Oomoo`0h
Ool00`00Oomoo`0JOol00`00Oomoo`0fOol000Moo`03001oogoo009oo`03001oogoo009oo`<000=o
o`03001oogoo00Uoo`03001oogoo065oo`03001oogoo03Qoo`03001oogoo01Yoo`03001oogoo03Io
o`001Woo00<007oo00002Goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0Hgoo00<007oo
Ool0=goo00<007ooOol06goo00<007ooOol0=Goo0006Ool00`00Ool00007Ool40003Ool30008Ool0
0`00Oomoo`1SOol00`00Oomoo`0gOol00`00Oomoo`0KOol00`00Oomoo`0eOol000Ioo`03001oo`00
00Moo`03001oo`0000Aoo`03001oogoo00Moo`03001oogoo06Aoo`03001oogoo03Moo`03001oogoo
01]oo`03001oogoo03Eoo`001Woo00<007oo000027oo0P0017oo00<007ooOol01goo00<007ooOol0
IGoo00<007ooOol0=Goo00<007ooOol077oo00<007ooOol0=Goo0007Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1UOol00`00Oomoo`0eOol00`00Oomoo`0LOol00`00
Oomoo`0eOol001Moo`03001oogoo00Ioo`03001oogoo06Ioo`03001oogoo03Eoo`03001oogoo01ao
o`03001oogoo03Eoo`005goo00<007ooOol01Woo00<007ooOol0Igoo00<007ooOol0=7oo00<007oo
Ool077oo00<007ooOol0=Goo000GOol00`00Oomoo`06Ool00`00Oomoo`1WOol00`00Oomoo`0dOol0
0`00Oomoo`0LOol00`00Oomoo`0eOol001Moo`03001oogoo00Eoo`03001oogoo06Qoo`03001oogoo
03Aoo`03001oogoo01eoo`03001oogoo03Aoo`005goo0P001Woo00<007ooOol0JGoo00<007ooOol0
<Woo00<007ooOol07Woo00<007ooOol0=7oo000GOol00`00Oomoo`04Ool00`00Oomoo`1ZOol00`00
Oomoo`0bOol00`00Oomoo`0NOol00`00Oomoo`0dOol001Moo`03001oogoo00Aoo`03001oogoo06]o
o`03001oogoo035oo`03001oogoo01ioo`03001oogoo03Aoo`005goo00<007ooOol017oo00<007oo
Ool0Jgoo00<007ooOol0<Goo00<007ooOol07Woo00<007ooOol0=7oo000GOol00`00Oomoo`03Ool0
0`00Oomoo`1/Ool00`00Oomoo`0aOol00`00Oomoo`0NOol00`00Oomoo`0dOol001Moo`03001oogoo
00=oo`03001oogoo06eoo`03001oogoo02moo`03001oogoo01moo`03001oogoo03Aoo`005goo00<0
07ooOol00goo00<007ooOol0KGoo00<007ooOol0;goo00<007ooOol087oo00<007ooOol0<goo000G
Ool00`00Oomoo`02Ool00`00Oomoo`1^Ool00`00Oomoo`0_Ool00`00Oomoo`0POol00`00Oomoo`0c
Ool001Moo`8000=oo`03001oogoo06moo`03001oogoo02ioo`03001oogoo021oo`03001oogoo03=o
o`005goo00D007ooOomoo`00079oo`03001oogoo02ioo`03001oogoo021oo`03001oogoo03=oo`00
5goo00D007ooOomoo`00079oo`03001oogoo02eoo`03001oogoo025oo`03001oogoo03=oo`005goo
00D007ooOomoo`0007=oo`03001oogoo02aoo`03001oogoo025oo`03001oogoo03=oo`005goo00@0
07ooOol007Aoo`03001oogoo02aoo`03001oogoo025oo`03001oogoo03=oo`005goo00@007ooOol0
07Aoo`03001oogoo02aoo`03001oogoo029oo`03001oogoo039oo`005goo00@007ooOol007Eoo`03
001oogoo02]oo`03001oogoo029oo`03001oogoo039oo`005goo00<007oo0000MWoo00<007ooOol0
:Woo00<007ooOol08goo00<007ooOol0<Woo000GOol3001gOol00`00Oomoo`0YOol00`00Oomoo`0S
Ool00`00Oomoo`0bOol001Moo`8007Qoo`03001oogoo02Uoo`03001oogoo02=oo`03001oogoo039o
o`005goo0P00N7oo00<007ooOol0:Goo00<007ooOol08goo00<007ooOol0<Woo000GOol2001iOol0
0`00Oomoo`0XOol00`00Oomoo`0SOol00`00Oomoo`0bOol001Moo`03001oogoo07Qoo`03001oogoo
02Moo`03001oogoo02Aoo`03001oogoo039oo`005goo00<007ooOol0N7oo00<007ooOol09goo00<0
07ooOol09Goo00<007ooOol09goo00<007ooOol01goo000GOol00`00Oomoo`1iOol00`00Oomoo`0V
Ool00`00Oomoo`0UOol00`00Oomoo`0WOol00`00Oomoo`07Ool001Moo`8007Yoo`03001oogoo02Io
o`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo00Qoo`005goo00<007ooOol0NGoo00<007oo
Ool09Woo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol027oo000GOol00`00Oomoo`1jOol0
0`00Oomoo`0TOol00`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomoo`09Ool001Moo`03001oogoo
07Yoo`03001oogoo02Aoo`03001oogoo02Ioo`03001oogoo02Eoo`03001oogoo00Uoo`005goo00<0
07ooOol0NWoo00<007ooOol097oo00<007ooOol09goo00<007ooOol097oo00<007ooOol02Goo000G
Ool00`00Oomoo`1kOol00`00Oomoo`0SOol00`00Oomoo`0WOol00`00Oomoo`0SOol00`00Oomoo`0:
Ool000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo07]oo`03001o
ogoo02=oo`03001oogoo02Moo`03001oogoo02=oo`03001oogoo00Yoo`001Woo00<007oo00001goo
00<007oo000017oo00<007ooOol0O7oo00<007ooOol08Goo00<007ooOol0:7oo00<007ooOol08Woo
00<007ooOol02goo0006Ool00`00Ool00009Ool00`00Oomoo`02Ool3001lOol00`00Oomoo`0QOol0
0`00Oomoo`0YOol00`00Oomoo`0QOol00`00Oomoo`0;Ool000Ioo`03001oo`0000Moo`8000Eoo`03
001oogoo07aoo`03001oogoo025oo`03001oogoo02Uoo`03001oogoo025oo`03001oogoo00]oo`00
1Woo00<007oo00001goo00<007ooOol017oo00<007ooOol0OGoo00<007ooOol087oo00<007ooOol0
:Goo00<007ooOol087oo00<007ooOol037oo0007Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`1m
Ool00`00Oomoo`0POol00`00Oomoo`0YOol00`00Oomoo`0POol00`00Oomoo`0<Ool001Moo`03001o
ogoo07eoo`03001oogoo01moo`03001oogoo02Yoo`03001oogoo01moo`03001oogoo00eoo`005goo
00<007ooOol0OWoo00<007ooOol07Woo00<007ooOol0:goo00<007ooOol07Woo00<007ooOol03Goo
000GOol00`00Oomoo`1nOol00`00Oomoo`0NOol00`00Oomoo`0[Ool00`00Oomoo`0MOol00`00Oomo
o`0>Ool001Moo`03001oogoo07moo`03001oogoo01eoo`03001oogoo02]oo`03001oogoo01eoo`03
001oogoo00ioo`005goo0P00P7oo00<007ooOol077oo00<007ooOol0;7oo00<007ooOol07Goo00<0
07ooOol03Woo000GOol00`00Oomoo`20Ool00`00Oomoo`0KOol00`00Oomoo`0/Ool00`00Oomoo`0L
Ool00`00Oomoo`0?Ool001Moo`03001oogoo081oo`03001oogoo01]oo`03001oogoo02eoo`03001o
ogoo01]oo`03001oogoo00moo`005goo00<007ooOol0P7oo00<007ooOol06goo00<007ooOol0;Goo
00<007ooOol06Woo00<007ooOol047oo000GOol00`00Oomoo`21Ool00`00Oomoo`0JOol00`00Oomo
o`0]Ool00`00Oomoo`0JOol00`00Oomoo`0@Ool001Moo`03001oogoo085oo`03001oogoo01Uoo`03
001oogoo02ioo`03001oogoo01Yoo`03001oogoo011oo`005goo00<007ooOol0PWoo00<007ooOol0
67oo00<007ooOol0;Woo00<007ooOol06Goo00<007ooOol04Goo000GOol00`00Oomoo`22Ool00`00
Oomoo`0HOol00`00Oomoo`0^Ool00`00Oomoo`0IOol00`00Oomoo`0AOol001Moo`8008Aoo`03001o
ogoo01Moo`03001oogoo02moo`03001oogoo01Moo`03001oogoo019oo`005goo00<007ooOol0Pgoo
00<007ooOol05goo00<007ooOol0;goo00<007ooOol05goo00<007ooOol04Woo000GOol00`00Oomo
o`23Ool00`00Oomoo`0FOol00`00Oomoo`0aOol00`00Oomoo`0FOol00`00Oomoo`0BOol001Moo`03
001oogoo08Aoo`03001oogoo01Eoo`03001oogoo035oo`03001oogoo01Eoo`03001oogoo01=oo`00
5goo00<007ooOol0Q7oo00<007ooOol05Goo00<007ooOol0<Goo00<007ooOol05Goo00<007ooOol0
4goo000GOol00`00Oomoo`25Ool00`00Oomoo`0DOol00`00Oomoo`0bOol00`00Oomoo`0COol00`00
Oomoo`0DOol001Moo`03001oogoo08Eoo`03001oogoo01=oo`03001oogoo03=oo`03001oogoo01=o
o`03001oogoo01Aoo`005goo0P00QWoo00<007ooOol04goo00<007ooOol0<goo00<007ooOol04Woo
00<007ooOol05Goo000GOol00`00Oomoo`26Ool00`00Oomoo`0BOol00`00Oomoo`0cOol00`00Oomo
o`0BOol00`00Oomoo`0EOol001Moo`03001oogoo08Ioo`03001oogoo019oo`03001oogoo03Aoo`03
001oogoo011oo`03001oogoo01Ioo`005goo00<007ooOol0Qgoo00<007ooOol047oo00<007ooOol0
=Goo00<007ooOol047oo00<007ooOol05Woo000GOol00`00Oomoo`27Ool00`00Oomoo`0@Ool00`00
Oomoo`0fOol00`00Oomoo`0>Ool00`00Oomoo`0GOol001Moo`03001oogoo08Qoo`03001oogoo00mo
o`03001oogoo03Ioo`03001oogoo00ioo`03001oogoo01Moo`005goo00<007ooOol0RGoo00<007oo
Ool03Goo00<007ooOol0>7oo00<007ooOol037oo00<007ooOol067oo000GOol00`00Oomoo`29Ool0
0`00Oomoo`0=Ool00`00Oomoo`0hOol00`00Oomoo`0<Ool00`00Oomoo`0HOol001Moo`8008]oo`03
001oogoo00]oo`03001oogoo03Yoo`03001oogoo00Yoo`03001oogoo01Uoo`005goo00<007ooOol0
Rgoo00<007ooOol02Goo00<007ooOol0>goo00<007ooOol02Woo00<007ooOol06Goo000GOol00`00
Oomoo`2<Ool00`00Oomoo`08Ool00`00Oomoo`0lOol00`00Oomoo`07Ool2000LOol001Moo`03001o
ogoo08eoo`03001oogoo00Ioo`03001oogoo03eoo`03001oogoo00Ioo`03001oogoo01aoo`005goo
00<007ooOol0SWoo00<007ooOol01Goo00<007ooOol0?Woo0P001Woo00<007ooOol077oo000GOol0
0`00Oomoo`2?Ool20002Ool30013Ool01000Oomoogoo0P007goo0007Ool00`00Oomoo`02Ool01000
Oomoogoo0P001Goo00<007ooOol0TGoo0`00AWoo0`008Goo0006Ool00`00Ool00007Ool00`00Ool0
0004Ool00`00Oomoo`3nOol000Ioo`03001oo`0000Moo`03001oo`0000Aoo`<00?ioo`001Woo00<0
07oo00001goo0P001Goo00<007ooOol0oWoo0006Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00
Oomoo`3nOol000Moo`03001oogoo00Moo`800?moo`Ioo`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0955846, 0.168461, 0.00405066,
   0.00257636}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3.4  2D Mechanism Images"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section demonstrates special ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions that are used to generate the mechanism images \
throughout this document. ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions return graphics primitives that are given as arguments \
to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function and displayed with the ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, just like the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives.\n\nThe primary utility of the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions is that they take their arguments in the form of local \
coordinates and automatically convert them to global. Thus, it is possible to \
create the image of a mechanism part using the same techniques as would be \
used with built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives, and then have the part be positioned properly with \
respect to the other parts of the mechanism automatically, as specified by a \
",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Graphics Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions closely parallel the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives. Each graphics function generates ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that represent points, lines, or polygons."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Vertex[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" ",
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pn",
    FontSlant->"Italic"],
  StyleBox["t1, pnt2, ..., pn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["tn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns point graphics primitives at each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point coordinate ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or a local point number.\n \n",
  StyleBox["Edge[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["pnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["pntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns line graphics primitives connecting each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n \n",
  StyleBox["Facet[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["pnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["pntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a polygon graphics primitive with vertices at each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Basic ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics function."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Box[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["pnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a rectangular box with two opposite corners at local points ",
  StyleBox["pnt1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The sides of the box are aligned with the local axes of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. \n \n",
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["ltdist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["rtdist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a rectangular bar spanning the two endpoints of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The left and right sides of the bar are placed ",
  StyleBox["ltdist",
    FontSlant->"Italic"],
  " and ",
  StyleBox["rtdist",
    FontSlant->"Italic"],
  " away from ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", respectively. ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.\n \n",
  StyleBox["Tangent[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["rad1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["rad2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a pair of lines tangent to two implied circles centered at ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " of radius ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  ", respectively. The tangent lines may represent a belt running between two \
pulleys. ",
  StyleBox["Tangent",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.\n \n",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates an ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon with ",
  StyleBox["segs",
    FontSlant->"Italic"],
  " sides and radius to vertices ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", centered at the specified ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options.\n\n",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rin",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["rout",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates an ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon with a hole of radius ",
  StyleBox["rin",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, rad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a disk of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["More 2D graphics functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for certain ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics function that specifies whether to draw the graphic element as a \
filled polygon or as a perimeter of lines. The default setting for all \
applicable functions is ",
  StyleBox["Faces->True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the start and end angles of the partial ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon. The default setting is ",
  StyleBox["Angle->{0, 2 Pi}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If the span of the two angles is less th",
  StyleBox["an 2 pi, t",
    FontFamily->"Times"],
  "he resulting wheel will be only a segment of a wheel."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Options for graphics functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions are analogous to the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Polygon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions. To demonstrate these functions, graphics objects are generated \
that are located on body 2, which is named ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(body2 = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a box with a diagonal and a couple of points."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics[{\n\t\t\tVertex[body2, {{.25, .75}, {.25, 1.25}}], 
          Edge[body2, {{0, 0}, {0, 1}, {1, 1}}], 
          Facet[body2, {{0, 0}, {1, 0}, {1, 1}}]}, \n\t\t
        AspectRatio \[Rule] Automatic, \n\t\tFrame \[Rule] True, \n\t\t
        PlotRange \[Rule] {{\(-1\), 2}, {0, 2}}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The coordinates of the graphic just created ",
  StyleBox["bdgraph",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are functions of the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " variables that locate ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[":",
    FontFamily->"Times"],
  " ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Therefore, these variables must be replaced with numeric values before \
the graphic can be displayed with ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This shows ",
  StyleBox["bdgraph",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rotated 0.5 radians counterclockwise."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] .5}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.333333 0 0.333333 [
[.16667 -0.0125 -12 -9 ]
[.16667 -0.0125 12 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -24 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .16667 -18 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .25 -24 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .41667 -24 -4.5 ]
[-0.0125 .41667 0 4.5 ]
[-0.0125 .5 -18 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .58333 -24 -4.5 ]
[-0.0125 .58333 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .66667 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(-0.5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(1.5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(0.25)] -0.0125 .08333 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0.5)] -0.0125 .16667 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0.75)] -0.0125 .25 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(1)] -0.0125 .33333 1 0 Mshowa
0 .41667 m
.00625 .41667 L
s
[(1.25)] -0.0125 .41667 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1.5)] -0.0125 .5 1 0 Mshowa
0 .58333 m
.00625 .58333 L
s
[(1.75)] -0.0125 .58333 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(2)] -0.0125 .66667 1 0 Mshowa
.125 Mabswid
0 .01667 m
.00375 .01667 L
s
0 .03333 m
.00375 .03333 L
s
0 .05 m
.00375 .05 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .11667 m
.00375 .11667 L
s
0 .13333 m
.00375 .13333 L
s
0 .15 m
.00375 .15 L
s
0 .18333 m
.00375 .18333 L
s
0 .2 m
.00375 .2 L
s
0 .21667 m
.00375 .21667 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .28333 m
.00375 .28333 L
s
0 .3 m
.00375 .3 L
s
0 .31667 m
.00375 .31667 L
s
0 .35 m
.00375 .35 L
s
0 .36667 m
.00375 .36667 L
s
0 .38333 m
.00375 .38333 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .45 m
.00375 .45 L
s
0 .46667 m
.00375 .46667 L
s
0 .48333 m
.00375 .48333 L
s
0 .51667 m
.00375 .51667 L
s
0 .53333 m
.00375 .53333 L
s
0 .55 m
.00375 .55 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .61667 m
.00375 .61667 L
s
0 .63333 m
.00375 .63333 L
s
0 .65 m
.00375 .65 L
s
.25 Mabswid
0 0 m
0 .66667 L
s
0 .66042 m
0 .66667 L
s
.16667 .66042 m
.16667 .66667 L
s
.33333 .66042 m
.33333 .66667 L
s
.5 .66042 m
.5 .66667 L
s
.66667 .66042 m
.66667 .66667 L
s
.83333 .66042 m
.83333 .66667 L
s
.125 Mabswid
.03333 .66292 m
.03333 .66667 L
s
.06667 .66292 m
.06667 .66667 L
s
.1 .66292 m
.1 .66667 L
s
.13333 .66292 m
.13333 .66667 L
s
.2 .66292 m
.2 .66667 L
s
.23333 .66292 m
.23333 .66667 L
s
.26667 .66292 m
.26667 .66667 L
s
.3 .66292 m
.3 .66667 L
s
.36667 .66292 m
.36667 .66667 L
s
.4 .66292 m
.4 .66667 L
s
.43333 .66292 m
.43333 .66667 L
s
.46667 .66292 m
.46667 .66667 L
s
.53333 .66292 m
.53333 .66667 L
s
.56667 .66292 m
.56667 .66667 L
s
.6 .66292 m
.6 .66667 L
s
.63333 .66292 m
.63333 .66667 L
s
.7 .66292 m
.7 .66667 L
s
.73333 .66292 m
.73333 .66667 L
s
.76667 .66292 m
.76667 .66667 L
s
.8 .66292 m
.8 .66667 L
s
.86667 .66292 m
.86667 .66667 L
s
.9 .66292 m
.9 .66667 L
s
.93333 .66292 m
.93333 .66667 L
s
.96667 .66292 m
.96667 .66667 L
s
.25 Mabswid
0 .66667 m
1 .66667 L
s
.99375 0 m
1 0 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .25 m
1 .25 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .41667 m
1 .41667 L
s
.99375 .5 m
1 .5 L
s
.99375 .58333 m
1 .58333 L
s
.125 Mabswid
.99625 .01667 m
1 .01667 L
s
.99625 .03333 m
1 .03333 L
s
.99625 .05 m
1 .05 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .11667 m
1 .11667 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .15 m
1 .15 L
s
.99625 .18333 m
1 .18333 L
s
.99625 .2 m
1 .2 L
s
.99625 .21667 m
1 .21667 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .28333 m
1 .28333 L
s
.99625 .3 m
1 .3 L
s
.99625 .31667 m
1 .31667 L
s
.99625 .35 m
1 .35 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .38333 m
1 .38333 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .45 m
1 .45 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .48333 m
1 .48333 L
s
.99625 .51667 m
1 .51667 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .55 m
1 .55 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .61667 m
1 .61667 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .65 m
1 .65 L
s
.25 Mabswid
1 0 m
1 .66667 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
.008 w
.28661 .25935 Mdot
.2067 .40561 Mdot
.5 Mabswid
.33333 0 m
.17352 .29253 L
.46605 .45234 L
s
.33333 0 m
.62586 .15981 L
.46605 .45234 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{270, 180},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000]1000`40O003h00Oogoo3goo003oOol?
Ool00?moo`moo`00?goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol0
7goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo1@007Woo1@000Woo00<007ooOol0
0Woo00<007ooOol07goo0`000goo000nOol00`00Ool00007Ool00`00Ool0000NOol00`00Ool0000O
Ool00`00Ool00007Ool00`00Ool0000QOol00`00Oomoo`0POol00`00Oomoo`06Ool00`00Ool0000P
Ool00`00Oomoo`03Ool003Uoo`<0009oo`03001oo`0000Uoo`03001oogoo01aoo`03001oo`0001mo
o`03001oo`0000Uoo`03001oogoo01moo`03001oogoo021oo`03001oogoo00Qoo`03001oogoo01mo
o`03001oogoo009oo`00?Woo00<007oo00001goo0P007goo00<007oo00007goo00<007oo00001goo
0P008Woo00<007ooOol087oo00<007ooOol01Woo0P008Woo00<007ooOol00Woo000nOol00`00Ool0
0007Ool00`00Oomoo`0NOol00`00Ool0000OOol00`00Ool00007Ool00`00Oomoo`0QOol00`00Oomo
o`0POol00`00Oomoo`06Ool00`00Oomoo`0POol00`00Ool00003Ool003moo`03001oogoo00Ioo`<0
01moo`03001oogoo01moo`03001oogoo00Ioo`<0021oo`80025oo`8000Qoo`<0025oo`03001oogoo
009oo`00ogoo3goo003oOol?Ool00?moo`moo`00ogoo3goo003oOol?Ool001Yooo4000=oo`006Woo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo
0`001Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool00Goo000JOol00`00Oomoo`0UOol00`00Oomoo`0TOol5000TOol00`00Oomoo`0UOol00`00Oomo
o`0UOol00`00Oomoo`0UOol00`00Oomoo`01Ool001Yoo`03001oogoo04]oo`03001oogoo00D009Yo
o`03001oogoo005oo`006Woo0P00C7oo00@007ooOomoo`H009Moo`8000=oo`006Woo00<007ooOol0
BWoo00<007ooOol00Woo2000UWoo00<007ooOol00Goo000JOol00`00Oomoo`1:Ool00`00Oomoo`02
Ool:002DOol00`00Oomoo`01Ool001Yoo`03001oogoo04Uoo`03001oogoo00Aoo`X009=oo`03001o
ogoo005oo`006Woo0P00BWoo00<007ooOol017oo3000T7oo0P000goo000JOol00`00Oomoo`18Ool0
0`00Oomoo`05Ool>002?Ool00`00Oomoo`01Ool001Yoo`03001oogoo04Qoo`03001oogoo00Eooa00
08eoo`03001oogoo005oo`006Woo00<007ooOol0Agoo00<007ooOol01goo4@00Rgoo00<007ooOol0
0Goo000JOol20017Ool00`00Oomoo`08OolC0028Ool20003Ool001Yoo`03001oogoo04Ioo`03001o
ogoo00Qooa@008Qoo`03001oogoo005oo`006Woo00<007ooOol0AGoo00<007ooOol02Woo5@00QWoo
00<007ooOol00Goo000JOol00`00Oomoo`15Ool00`00Oomoo`0:OolG0024Ool00`00Oomoo`01Ool0
01Yoo`8004Eoo`03001oogoo00]ooaT0085oo`8000=oo`006Woo00<007ooOol0A7oo00<007ooOol0
37oo6P00P7oo00<007ooOol00Goo0006Ool00`00Oomoo`02Ool01000Oomoogoo0`000goo00<007oo
Ool00Woo00<007ooOol0@goo00<007ooOol03Goo7000OWoo00<007ooOol00Goo0005Ool00`00Ool0
0007Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`13Ool00`00Oomoo`0=OolM001mOol0
0`00Oomoo`01Ool000Eoo`03001oo`0000Qoo`03001oogoo00=oo`04001oogooOol30012Ool00`00
Oomoo`0>OolO001iOol30003Ool000Eoo`03001oo`0000Qoo`04001oogooOol20004Ool00`00Oomo
o`12Ool00`00Oomoo`0?OolP001iOol00`00Oomoo`01Ool000Eoo`03001oo`0000Moo`03001oo`00
009oo`03001oogoo00=oo`03001oogoo045oo`03001oogoo011oob8007Moo`03001oogoo005oo`00
1Woo00<007ooOol01goo00@007ooOomoo`<000=oo`03001oogoo045oo`03001oogoo011oob@007Eo
o`03001oogoo005oo`006Woo0P00@Goo00<007ooOol04Woo9@00LWoo0P000goo000JOol00`00Oomo
o`0oOol00`00Oomoo`0COolW001aOol00`00Oomoo`01Ool001Yoo`03001oogoo03moo`03001oogoo
01=oobP0071oo`03001oogoo005oo`006Woo00<007ooOol0?Woo00<007ooOol057oo:P00KWoo00<0
07ooOol00Goo000JOol2000oOol00`00Oomoo`0EOol[001[Ool20003Ool001Yoo`03001oogoo03eo
o`03001oogoo01Ioobd006Yoo`03001oogoo005oo`006Woo00<007ooOol0?Goo00<007ooOol05Woo
;`00J7oo00<007ooOol00Goo000JOol00`00Oomoo`0lOol00`00Oomoo`0HOol`001VOol00`00Oomo
o`01Ool001Yoo`8003eoo`03001oogoo01Qooc4006Aoo`8000=oo`006Woo00<007ooOol0>goo00<0
07ooOol06Goo<`00Hgoo00<007ooOol00Goo000JOol00`00Oomoo`0kOol00`00Oomoo`0JOold001Q
Ool00`00Oomoo`01Ool001Yoo`03001oogoo03Yoo`03001oogoo01]oocH005moo`03001oogoo005o
o`006Woo0P00>Woo00<007ooOol077oo>000G7oo0P000goo000JOol00`00Oomoo`0iOol00`00Oomo
o`0LOolj001KOol00`00Oomoo`01Ool000]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo03Qoo`03001oogoo01ioocX005Yoo`03001oogoo005oo`002Woo00<007oo0000
1goo00<007oo00000goo00<007ooOol0>7oo00<007ooOol07Woo>P00FWoo00<007ooOol00Goo000:
Ool00`00Ool00009Ool01000Oomoogoo0`00=goo00<007ooOol07goo>@00FGoo0`000goo000:Ool0
0`00Ool00007Ool20004Ool00`00Oomoo`0gOol00`00Oomoo`0POolh001KOol00`00Oomoo`01Ool0
00Yoo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo03Ioo`03001oogoo025oocL005aoo`03
001oogoo005oo`002goo00<007ooOol01Woo0`000goo00<007ooOol0=Woo00<007ooOol08Goo=`00
G7oo00<007ooOol00Goo000JOol2000fOol00`00Oomoo`0SOole001LOol20003Ool001Yoo`03001o
ogoo03Eoo`03001oogoo02=oocD005eoo`03001oogoo005oo`006Woo00<007ooOol0=7oo00<007oo
Ool097oo=000GWoo00<007ooOol00Goo000JOol00`00Oomoo`0cOol00`00Oomoo`0UOold001NOol0
0`00Oomoo`01Ool001Yoo`8003Aoo`03001oogoo02Iooc8005ioo`8000=oo`006Woo00<007ooOol0
<Woo00<007ooOol09goo<P00Ggoo00<007ooOol00Goo000JOol00`00Oomoo`0bOol00`00Oomoo`0W
Oola001POol00`00Oomoo`01Ool001Yoo`03001oogoo035oo`03001oogoo02Uoobl0065oo`03001o
ogoo005oo`006Woo0P00<Woo00<007ooOol0:Goo;`00H7oo0P000goo000JOol00`00Oomoo`0`Ool0
0`00Oomoo`0ZOol^001ROol00`00Oomoo`01Ool001Yoo`03001oogoo031oo`03001oogoo02Yoobh0
069oo`03001oogoo005oo`006Woo00<007ooOol0;goo00<007ooOol0;7oo;000Hgoo00<007ooOol0
0Goo000JOol2000`Ool00`00Oomoo`0/Ool/001ROol20003Ool001Yoo`03001oogoo02ioo`03001o
ogoo02eoob/006Aoo`03001oogoo005oo`001Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0;Woo00<007ooOol0;Woo:P00I7oo00<007ooOol00Goo
0005Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000=oo`03001oogoo02eoo`03001oogoo02mo
obT006Eoo`03001oogoo005oo`001Goo00<007oo000027oo00<007ooOol00goo00@007ooOomoo`<0
02aoo`03001oogoo031oobT006=oo`<000=oo`001Goo00<007oo00002Goo00<007ooOol00P0017oo
00<007ooOol0;7oo00<007ooOol04goo00<007ooOol06goo9`00IWoo00<007ooOol00Goo0005Ool0
0`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`0[Ool00`00Oomoo`0bOolV
001WOol00`00Oomoo`01Ool000Ioo`03001oogoo00Ioo`<0009oo`<000=oo`03001oogoo02]oo`03
001oogoo039oobH006Moo`03001oogoo005oo`006Woo0P00:goo00<007ooOol0<goo9@00Igoo0P00
0goo000JOol00`00Oomoo`0ZOol00`00Oomoo`0dOolT001XOol00`00Oomoo`01Ool001Yoo`03001o
ogoo02Uoo`03001oogoo03Eoob<006Uoo`03001oogoo005oo`006Woo00<007ooOol0:Goo00<007oo
Ool0=Goo8`00JGoo00<007ooOol00Goo000JOol2000YOol00`00Oomoo`0gOolQ001YOol20003Ool0
01Yoo`03001oogoo02Qoo`03001oogoo03Moob4006Yoo`03001oogoo005oo`006Woo00<007ooOol0
9goo00<007ooOol0>7oo8000Jgoo00<007ooOol00Goo000JOol00`00Oomoo`0XOol2000iOolO001[
Ool00`00Oomoo`01Ool001Yoo`8002]oo`8003Mooah006]oo`8000=oo`006Woo00<007ooOol0;7oo
0P00=Goo7@00KGoo00<007ooOol00Goo000JOol00`00Oomoo`0^Ool2000cOolM001]Ool00`00Oomo
o`01Ool001Yoo`03001oogoo031oo`80039ooa/006ioo`03001oogoo005oo`006Woo0P00<goo00<0
07ooOol0;goo6`00KGoo0P000goo000JOol00`00Oomoo`0cOol2000_OolJ001_Ool00`00Oomoo`01
Ool001=oo`D0009oo`03001oogoo03Eoo`8002iooaT006moo`03001oogoo005oo`005Goo00<007oo
Ool00Woo00<007ooOol0=goo0P00;7oo6000L7oo00<007ooOol00Goo000EOol00`00Oomoo`02Ool3
000iOol2000ZOolH001^Ool30003Ool001Eoo`03001oogoo009oo`03001oogoo03]oo`8002QooaL0
075oo`03001oogoo005oo`005Goo00<007ooOol00Woo00<007ooOol0?Goo0P009goo5P00LGoo00<0
07ooOol00Goo000DOol20004Ool00`00Oomoo`0oOol00`00Oomoo`0TOolE001bOol00`00Oomoo`01
Ool001Yoo`80045oo`8002AooaD0075oo`8000=oo`006Woo00<007ooOol0@Woo0P008goo4`00Lgoo
00<007ooOol00Goo000JOol00`00Oomoo`14Ool2000QOolB001dOol00`00Oomoo`01Ool001Yoo`03
001oogoo04Ioo`8001mooa8007Aoo`03001oogoo005oo`006Woo0P00BGoo0P007Woo4000M7oo0P00
0goo000JOol00`00Oomoo`1:Ool00`00Oomoo`0KOol@001eOol00`00Oomoo`01Ool001Yoo`03001o
ogoo04]oo`8001]oo`l007Ioo`03001oogoo005oo`006Woo00<007ooOol0CGoo0P006Goo3`00MWoo
00<007ooOol00Goo000JOol2001@Ool2000HOol=001fOol20003Ool001Yoo`03001oogoo055oo`80
01Ioo`d007Moo`03001oogoo005oo`006Woo00<007ooOol0Dgoo0P0057oo3000N7oo00<007ooOol0
0Goo000JOol00`00Oomoo`1EOol00`00Oomoo`0BOol;001hOol00`00Oomoo`01Ool001Yoo`8002mo
o`03001oogoo02Eoo`80019oo`X007Qoo`8000=oo`006Woo00<007ooOol0F7oo0P0047oo2@00NWoo
00<007ooOol00Goo0004Ool50002Ool01000Oomoogoo0`000goo00<007ooOol00Woo00<007ooOol0
FWoo0P003goo2000NWoo00<007ooOol00Goo0006Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00
Ool00003Ool00`00Oomoo`1LOol2000=Ool7001kOol00`00Oomoo`01Ool000Ioo`03001oogoo00Mo
o`03001oogoo00=oo`04001oogooOol3001NOol2000;Ool7001iOol30003Ool000Ioo`03001oogoo
00Moo`04001oogooOol20004Ool00`00Oomoo`1POol20009Ool6001lOol00`00Oomoo`01Ool000Io
o`03001oogoo00Ioo`03001oo`00009oo`03001oogoo00=oo`03001oogoo069oo`03001oogoo00Mo
o`D007aoo`03001oogoo005oo`001Goo0P002Goo00@007ooOomoo`<000=oo`03001oogoo06=oo`80
00Moo`@007eoo`03001oogoo005oo`006Woo0P00IWoo0P001Goo1000O7oo0P000goo000JOol00`00
Oomoo`1WOol20004Ool2001nOol00`00Oomoo`01Ool001Yoo`03001oogoo06Uoo`80009oo`8007io
o`03001oogoo005oo`006Woo00<007ooOol0Jgoo0`00Ogoo00<007ooOol00Goo000JOol2001^Ool0
0`00Oomoo`1lOol20003Ool001Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo00<007ooOol0
kGoo00<007ooOol00Goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`800>eoo`8000=o
o`006Woo00<007ooOol0kGoo00<007ooOol00Goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool0
01Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo0P00kGoo0P000goo000JOol00`00Oomoo`3]
Ool00`00Oomoo`01Ool000Uoo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo0>eo
o`03001oogoo005oo`002goo00<007ooOol01Woo00<007oo00000goo00<007ooOol0kGoo00<007oo
Ool00Goo000;Ool00`00Oomoo`08Ool01000Oomoogoo0`00jgoo0`000goo000;Ool00`00Oomoo`06
Ool20004Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool000]oo`03001oogoo00Ioo`03001oogoo00=o
o`03001oogoo0>eoo`03001oogoo005oo`002Woo0P0027oo0`000goo00<007ooOol0kGoo00<007oo
Ool00Goo000JOol2003]Ool20003Ool001Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo00<0
07ooOol0kGoo00<007ooOol00Goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`800>eo
o`8000=oo`006Woo00<007ooOol0kGoo00<007ooOol00Goo000JOol00`00Oomoo`3]Ool00`00Oomo
o`01Ool001Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo0P00kGoo0P000goo000JOol00`00
Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo00<007oo
Ool0kGoo00<007ooOol00Goo000JOol2003]Ool20003Ool000Aoo`D0009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo0>eoo`03001oogoo005oo`001Woo00<007ooOol0
1goo00L007ooOomoo`00Ool00003Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool000Ioo`03001oogoo
00Moo`03001oogoo00=oo`04001oogooOol3003[Ool30003Ool000Ioo`03001oogoo00Qoo`03001o
ogoo008000Aoo`03001oogoo0>eoo`03001oogoo005oo`001Woo00<007ooOol01Woo00<007oo0000
0Woo00<007ooOol00goo00<007ooOol0kGoo00<007ooOol00Goo0005Ool20008Ool30002Ool30003
Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`800>eoo`8000=oo`006Woo00<007ooOol0kGoo
00<007ooOol00Goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`03001oogoo0>eoo`03
001oogoo005oo`006Woo0P00kGoo0P000goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yo
o`03001oogoo0>eoo`03001oogoo005oo`006Woo00<007ooOol0kGoo00<007ooOol00Goo000JOol2
003]Ool20003Ool001Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo00<007ooOol0kGoo00<0
07ooOol00Goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`800>eoo`8000=oo`006Woo
00<007ooOol0kGoo00<007ooOol00Goo000DOol30003Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool0
01Aoo`03001oogoo00=oo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo
02Eoo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo005oo`005Goo00<007ooOol00Wool@00
0goo000EOol00`00Oomoo`3fOol001Aoo`03001oo`000?Moo`005Goo00<007ooOol0mWoo003oOol?
Ool00?moo`moo`00ogoo3goo0000\
\>"],
  ImageRangeCache->{{{0, 269}, {179, 0}} -> {-1.33876, -0.170371, 0.0125518, 
  0.0125518}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This shows ",
  StyleBox["bdgraph",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rotated 1 radian and translated 1 unit to the right."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[bdgraph /. {X2 \[Rule] 1, Y2 \[Rule] 0, Th2 \[Rule] 1}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.333333 0 0.333333 [
[.16667 -0.0125 -12 -9 ]
[.16667 -0.0125 12 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -24 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .16667 -18 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .25 -24 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .41667 -24 -4.5 ]
[-0.0125 .41667 0 4.5 ]
[-0.0125 .5 -18 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .58333 -24 -4.5 ]
[-0.0125 .58333 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .66667 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(-0.5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(1.5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(0.25)] -0.0125 .08333 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0.5)] -0.0125 .16667 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0.75)] -0.0125 .25 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(1)] -0.0125 .33333 1 0 Mshowa
0 .41667 m
.00625 .41667 L
s
[(1.25)] -0.0125 .41667 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1.5)] -0.0125 .5 1 0 Mshowa
0 .58333 m
.00625 .58333 L
s
[(1.75)] -0.0125 .58333 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(2)] -0.0125 .66667 1 0 Mshowa
.125 Mabswid
0 .01667 m
.00375 .01667 L
s
0 .03333 m
.00375 .03333 L
s
0 .05 m
.00375 .05 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .11667 m
.00375 .11667 L
s
0 .13333 m
.00375 .13333 L
s
0 .15 m
.00375 .15 L
s
0 .18333 m
.00375 .18333 L
s
0 .2 m
.00375 .2 L
s
0 .21667 m
.00375 .21667 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .28333 m
.00375 .28333 L
s
0 .3 m
.00375 .3 L
s
0 .31667 m
.00375 .31667 L
s
0 .35 m
.00375 .35 L
s
0 .36667 m
.00375 .36667 L
s
0 .38333 m
.00375 .38333 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .45 m
.00375 .45 L
s
0 .46667 m
.00375 .46667 L
s
0 .48333 m
.00375 .48333 L
s
0 .51667 m
.00375 .51667 L
s
0 .53333 m
.00375 .53333 L
s
0 .55 m
.00375 .55 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .61667 m
.00375 .61667 L
s
0 .63333 m
.00375 .63333 L
s
0 .65 m
.00375 .65 L
s
.25 Mabswid
0 0 m
0 .66667 L
s
0 .66042 m
0 .66667 L
s
.16667 .66042 m
.16667 .66667 L
s
.33333 .66042 m
.33333 .66667 L
s
.5 .66042 m
.5 .66667 L
s
.66667 .66042 m
.66667 .66667 L
s
.83333 .66042 m
.83333 .66667 L
s
.125 Mabswid
.03333 .66292 m
.03333 .66667 L
s
.06667 .66292 m
.06667 .66667 L
s
.1 .66292 m
.1 .66667 L
s
.13333 .66292 m
.13333 .66667 L
s
.2 .66292 m
.2 .66667 L
s
.23333 .66292 m
.23333 .66667 L
s
.26667 .66292 m
.26667 .66667 L
s
.3 .66292 m
.3 .66667 L
s
.36667 .66292 m
.36667 .66667 L
s
.4 .66292 m
.4 .66667 L
s
.43333 .66292 m
.43333 .66667 L
s
.46667 .66292 m
.46667 .66667 L
s
.53333 .66292 m
.53333 .66667 L
s
.56667 .66292 m
.56667 .66667 L
s
.6 .66292 m
.6 .66667 L
s
.63333 .66292 m
.63333 .66667 L
s
.7 .66292 m
.7 .66667 L
s
.73333 .66292 m
.73333 .66667 L
s
.76667 .66292 m
.76667 .66667 L
s
.8 .66292 m
.8 .66667 L
s
.86667 .66292 m
.86667 .66667 L
s
.9 .66292 m
.9 .66667 L
s
.93333 .66292 m
.93333 .66667 L
s
.96667 .66292 m
.96667 .66667 L
s
.25 Mabswid
0 .66667 m
1 .66667 L
s
.99375 0 m
1 0 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .25 m
1 .25 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .41667 m
1 .41667 L
s
.99375 .5 m
1 .5 L
s
.99375 .58333 m
1 .58333 L
s
.125 Mabswid
.99625 .01667 m
1 .01667 L
s
.99625 .03333 m
1 .03333 L
s
.99625 .05 m
1 .05 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .11667 m
1 .11667 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .15 m
1 .15 L
s
.99625 .18333 m
1 .18333 L
s
.99625 .2 m
1 .2 L
s
.99625 .21667 m
1 .21667 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .28333 m
1 .28333 L
s
.99625 .3 m
1 .3 L
s
.99625 .31667 m
1 .31667 L
s
.99625 .35 m
1 .35 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .38333 m
1 .38333 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .45 m
1 .45 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .48333 m
1 .48333 L
s
.99625 .51667 m
1 .51667 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .55 m
1 .55 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .61667 m
1 .61667 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .65 m
1 .65 L
s
.25 Mabswid
1 0 m
1 .66667 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
.008 w
.50132 .2052 Mdot
.36108 .29525 Mdot
.5 Mabswid
.66667 0 m
.38618 .1801 L
.56628 .46059 L
s
.66667 0 m
.84677 .28049 L
.56628 .46059 L
F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{270, 180},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000]1000`40O003h00Oogoo3goo003oOol?
Ool00?moo`moo`00?goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol0
7goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07Woo1@007Woo1@000Woo00<007ooOol0
0Woo00<007ooOol07goo0`000goo000nOol00`00Ool00007Ool00`00Ool0000NOol00`00Ool0000O
Ool00`00Ool00007Ool00`00Ool0000QOol00`00Oomoo`0POol00`00Oomoo`06Ool00`00Ool0000P
Ool00`00Oomoo`03Ool003Uoo`<0009oo`03001oo`0000Uoo`03001oogoo01aoo`03001oo`0001mo
o`03001oo`0000Uoo`03001oogoo01moo`03001oogoo021oo`03001oogoo00Qoo`03001oogoo01mo
o`03001oogoo009oo`00?Woo00<007oo00001goo0P007goo00<007oo00007goo00<007oo00001goo
0P008Woo00<007ooOol087oo00<007ooOol01Woo0P008Woo00<007ooOol00Woo000nOol00`00Ool0
0007Ool00`00Oomoo`0NOol00`00Ool0000OOol00`00Ool00007Ool00`00Oomoo`0QOol00`00Oomo
o`0POol00`00Oomoo`06Ool00`00Oomoo`0POol00`00Ool00003Ool003moo`03001oogoo00Ioo`<0
01moo`03001oogoo01moo`03001oogoo00Ioo`<0021oo`80025oo`8000Qoo`<0025oo`03001oogoo
009oo`00ogoo3goo003oOol?Ool00?moo`moo`00ogoo3goo003oOol?Ool001Yooo4000=oo`006Woo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00goo
0`001goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool00Goo000JOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0ROol0
0`00Oomoo`02000VOol00`00Oomoo`0UOol00`00Oomoo`01Ool001Yoo`03001oogoo09Qoo`8000=o
o`8004ioo`03001oogoo005oo`006Woo0P00Ugoo0P001Goo0`00C7oo0P000goo000JOol00`00Oomo
o`2EOol00`00Oomoo`04Ool5001<Ool00`00Oomoo`01Ool001Yoo`03001oogoo09=oo`8000Moo`D0
04aoo`03001oogoo005oo`006Woo00<007ooOol0TWoo00<007ooOol01goo1P00Bgoo00<007ooOol0
0Goo000JOol2002AOol2000:Ool70019Ool20003Ool001Yoo`03001oogoo08moo`03001oogoo00Yo
o`L004Yoo`03001oogoo005oo`006Woo00<007ooOol0SGoo0P0037oo2@00BGoo00<007ooOol00Goo
000JOol00`00Oomoo`2<Ool00`00Oomoo`0<Ool:0018Ool00`00Oomoo`01Ool001Yoo`8008]oo`80
00moo`X004Moo`8000=oo`006Woo00<007ooOol0R7oo0P004Goo2`00Agoo00<007ooOol00Goo000J
Ool00`00Oomoo`27Ool00`00Oomoo`0@Ool<0017Ool00`00Oomoo`01Ool001Yoo`03001oogoo08Eo
o`8001=oo`d004Ioo`03001oogoo005oo`006Woo0P00QGoo00<007ooOol04goo3P00A7oo0P000goo
000JOol00`00Oomoo`22Ool2000FOol>0015Ool00`00Oomoo`01Ool000Ioo`03001oogoo009oo`04
001oogooOol30003Ool00`00Oomoo`02Ool00`00Oomoo`21Ool00`00Oomoo`0FOol?0014Ool00`00
Oomoo`01Ool000Eoo`03001oo`0000Moo`03001oogoo009oo`03001oo`0000=oo`03001oogoo07mo
o`8001Qooa4004=oo`03001oogoo005oo`001Goo00<007oo000027oo00<007ooOol00goo00@007oo
Oomoo`<007ioo`03001oogoo01Qooa40045oo`<000=oo`001Goo00<007oo000027oo00@007ooOomo
o`8000Aoo`03001oogoo07aoo`8001]ooa80049oo`03001oogoo005oo`001Goo00<007oo00001goo
00<007oo00000Woo00<007ooOol00goo00<007ooOol0NWoo0P007Goo4`00@Goo00<007ooOol00Goo
0006Ool00`00Oomoo`07Ool01000Oomoogoo0`000goo00<007ooOol0NGoo00<007ooOol077oo5000
@Goo00<007ooOol00Goo000JOol2001hOol2000OOolE000oOol20003Ool001Yoo`03001oogoo07Io
o`03001oogoo01mooaH003moo`03001oogoo005oo`006Woo00<007ooOol0M7oo0P008Woo5P00?goo
00<007ooOol00Goo000JOol00`00Oomoo`1cOol00`00Oomoo`0ROolG000nOol00`00Oomoo`01Ool0
01Yoo`80079oo`8002AooaP003eoo`8000=oo`006Woo00<007ooOol0L7oo00<007ooOol097oo6@00
?Goo00<007ooOol00Goo000JOol00`00Oomoo`1^Ool2000WOolJ000lOol00`00Oomoo`01Ool001Yo
o`03001oogoo06aoo`8002UooaX003aoo`03001oogoo005oo`006Woo0P00K7oo00<007ooOol0:Goo
6`00>Woo0P000goo000JOol00`00Oomoo`1YOol2000[OolM000jOol00`00Oomoo`01Ool001Yoo`03
001oogoo06Qoo`03001oogoo02]ooad003Yoo`03001oogoo005oo`006Woo00<007ooOol0IWoo0P00
;Woo7P00>Goo00<007ooOol00Goo000JOol2001VOol00`00Oomoo`0^OolO000gOol20003Ool001Yo
o`03001oogoo06=oo`80031oob0003Qoo`03001oogoo005oo`002goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol0HWoo00<007ooOol0<7oo8@00=goo00<007ooOol00Goo
000:Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`1POol2000cOolR000fOol00`00Oomo
o`01Ool000Yoo`03001oo`0000Uoo`04001oogooOol3001NOol2000eOolR000dOol30003Ool000Yo
o`03001oo`0000Moo`8000Aoo`03001oogoo05eoo`03001oogoo03Eoob<003Eoo`03001oogoo005o
o`002Woo00<007oo00001goo00<007ooOol00goo00<007ooOol0Fgoo0P00=goo9000=Goo00<007oo
Ool00Goo000;Ool00`00Oomoo`06Ool30003Ool00`00Oomoo`1JOol00`00Oomoo`0gOolU000dOol0
0`00Oomoo`01Ool001Yoo`8005aoo`03001oogoo03IoobH0039oo`8000=oo`006Woo00<007ooOol0
Fgoo00<007ooOol0=Woo9P00<goo00<007ooOol00Goo000JOol00`00Oomoo`1LOol00`00Oomoo`0d
OolX000bOol00`00Oomoo`01Ool001Yoo`03001oogoo05eoo`03001oogoo03=oobT0035oo`03001o
ogoo005oo`006Woo0P00GWoo00<007ooOol0<goo:@00<7oo0P000goo000JOol00`00Oomoo`1NOol0
0`00Oomoo`0DOol00`00Oomoo`0KOolZ000`Ool00`00Oomoo`01Ool001Yoo`03001oogoo05ioo`03
001oogoo039oob/002moo`03001oogoo005oo`006Woo00<007ooOol0Ggoo00<007ooOol0<7oo;000
;goo00<007ooOol00Goo000JOol2001QOol00`00Oomoo`0_Ool]000]Ool20003Ool001Yoo`03001o
ogoo061oo`03001oogoo02moobh002eoo`03001oogoo005oo`006Woo00<007ooOol0HGoo00<007oo
Ool0;Woo;P00;Goo00<007ooOol00Goo000JOol00`00Oomoo`1ROol00`00Oomoo`0/Ool`000/Ool0
0`00Oomoo`01Ool001Yoo`8006=oo`03001oogoo02aooc0002]oo`8000=oo`006Woo00<007ooOol0
Hgoo00<007ooOol0:goo<@00:goo00<007ooOol00Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1TOol00`00Oomoo`0ZOolb000ZOol00`00
Oomoo`01Ool000Eoo`03001oo`0000Qoo`07001oogooOol007oo00000goo00<007ooOol0I7oo00<0
07ooOol0:Woo<P00:Woo00<007ooOol00Goo0005Ool00`00Ool00008Ool00`00Oomoo`03Ool01000
Oomoogoo0`00IGoo00<007ooOol0:7oo=0009goo0`000goo0005Ool00`00Ool00009Ool00`00Oomo
o`020004Ool00`00Oomoo`1VOol00`00Oomoo`0WOole000XOol00`00Oomoo`01Ool000Eoo`03001o
o`0000Moo`03001oo`00009oo`03001oogoo00=oo`03001oogoo06Ioo`03001oogoo02MoocD002Qo
o`03001oogoo005oo`001Woo00<007ooOol01Woo0`000Woo0`000goo00<007ooOol0Igoo00<007oo
Ool09Woo=P009goo00<007ooOol00Goo000JOol2001XOol00`00Oomoo`0VOolg000UOol20003Ool0
01Yoo`03001oogoo06Qoo`03001oogoo02AoocP002Ioo`03001oogoo005oo`006Woo00<007ooOol0
JGoo00<007ooOol08goo>@009Goo00<007ooOol00Goo000JOol00`00Oomoo`1YOol00`00Oomoo`0S
Ooli000UOol00`00Oomoo`01Ool001Yoo`8006]oo`03001oogoo029oocP002Eoo`8000=oo`006Woo
00<007ooOol0Jgoo00<007ooOol087oo=`00:7oo00<007ooOol00Goo000JOol00`00Oomoo`1COol0
0`00Oomoo`0EOol00`00Oomoo`0POolf000YOol00`00Oomoo`01Ool001Yoo`03001oogoo06aoo`03
001oogoo01mooc@002]oo`03001oogoo005oo`006Woo0P00KWoo00<007ooOol07Woo<`00:goo0P00
0goo000JOol00`00Oomoo`1]Ool00`00Oomoo`0NOola000^Ool00`00Oomoo`01Ool001Yoo`03001o
ogoo06ioo`03001oogoo01aooc4002moo`03001oogoo005oo`006Woo00<007ooOol0Kgoo00<007oo
Ool06goo;`00<Goo00<007ooOol00Goo000JOol2001`Ool00`00Oomoo`0KOol]000bOol20003Ool0
01Yoo`03001oogoo071oo`03001oogoo01Yoob`003Aoo`03001oogoo005oo`004goo1@000Woo00<0
07ooOol0L7oo00<007ooOol06Goo:`00=Woo00<007ooOol00Goo000EOol00`00Oomoo`02Ool00`00
Oomoo`1aOol00`00Oomoo`0HOolZ000gOol00`00Oomoo`01Ool001Eoo`03001oogoo009oo`<0079o
o`03001oogoo01MoobP003Moo`<000=oo`005Goo00<007ooOol00Woo00<007ooOol0LWoo00<007oo
Ool05goo9`00>Woo00<007ooOol00Goo000EOol00`00Oomoo`02Ool00`00Oomoo`1cOol00`00Oomo
o`0FOolU000lOol00`00Oomoo`01Ool001Aoo`8000Aoo`03001oogoo07Aoo`03001oogoo01AoobD0
03eoo`03001oogoo005oo`006Woo0P00MGoo00<007ooOol057oo8`00?Woo0P000goo000JOol00`00
Oomoo`1eOol00`00Oomoo`0COolQ0011Ool00`00Oomoo`01Ool001Yoo`03001oogoo07Ioo`03001o
ogoo019oob00049oo`03001oogoo005oo`006Woo00<007ooOol0MWoo00<007ooOol04Woo7P00A7oo
00<007ooOol00Goo000JOol2001hOol00`00Oomoo`0@OolN0014Ool20003Ool001Yoo`03001oogoo
07Qoo`03001oogoo00mooa`004Moo`03001oogoo005oo`006Woo00<007ooOol0N7oo00<007ooOol0
3goo6`00B7oo00<007ooOol00Goo000JOol00`00Oomoo`1iOol00`00Oomoo`0>OolI001:Ool00`00
Oomoo`01Ool001Yoo`8007Yoo`03001oogoo00eooaT004Yoo`8000=oo`006Woo00<007ooOol0NWoo
00<007ooOol037oo5`00CGoo00<007ooOol00Goo000JOol00`00Oomoo`1kOol00`00Oomoo`0;OolE
001?Ool00`00Oomoo`01Ool001Yoo`03001oogoo07]oo`03001oogoo00]ooa@0051oo`03001oogoo
005oo`006Woo0P00OGoo00<007ooOol02Woo4P00DGoo0P000goo000JOol00`00Oomoo`1mOol00`00
Oomoo`08OolB001COol00`00Oomoo`01Ool000Aoo`D0009oo`04001oogooOol30003Ool00`00Oomo
o`02Ool00`00Oomoo`1mOol00`00Oomoo`08Ool@001EOol00`00Oomoo`01Ool000Ioo`03001oogoo
00Ioo`03001oogoo009oo`03001oo`0000=oo`03001oogoo07ioo`03001oogoo00Moo`l005Ioo`03
001oogoo005oo`001Woo00<007ooOol01goo00<007ooOol00goo00@007ooOomoo`<007moo`03001o
ogoo00Ioo`d005Ioo`<000=oo`001Woo00<007ooOol01goo00@007ooOomoo`8000Aoo`03001oogoo
07moo`03001oogoo00Eoo`d005Uoo`03001oogoo005oo`001Woo00<007ooOol01Woo00<007oo0000
0Woo00<007ooOol00goo00<007ooOol0P7oo00<007ooOol017oo2`00Fgoo00<007ooOol00Goo0005
Ool20009Ool01000Oomoogoo0`000goo00<007ooOol0PGoo00<007ooOol00goo2@00GGoo00<007oo
Ool00Goo000JOol20022Ool00`00Oomoo`03Ool8001MOol20003Ool001Yoo`03001oogoo089oo`03
001oogoo009oo`H0061oo`03001oogoo005oo`006Woo00<007ooOol0PWoo00@007ooOomoo`H0065o
o`03001oogoo005oo`006Woo00<007ooOol0Pgoo00<007ooOol01000Hgoo00<007ooOol00Goo000J
Ool20025Ool00`00Ool00002001SOol20003Ool001Yoo`03001oogoo08Aoo`03001oo`0006Ioo`03
001oogoo005oo`006Woo00<007ooOol0QGoo00<007ooOol0IGoo00<007ooOol00Goo000JOol00`00
Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`800>eoo`8000=oo`006Woo00<007ooOol0kGoo00<007oo
Ool00Goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`03001oogoo0>eoo`03001oogoo
005oo`006Woo0P00kGoo0P000goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool000Uoo`D0009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo0>eoo`03001oogoo005oo`002goo00<007oo
Ool01Woo00<007oo00000goo00<007ooOol0kGoo00<007ooOol00Goo000;Ool00`00Oomoo`08Ool0
1000Oomoogoo0`00jgoo0`000goo000;Ool00`00Oomoo`06Ool20004Ool00`00Oomoo`3]Ool00`00
Oomoo`01Ool000]oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo0>eoo`03001oogoo005o
o`002Woo0P0027oo0`000goo00<007ooOol0kGoo00<007ooOol00Goo000JOol2003]Ool20003Ool0
01Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo00<007ooOol0kGoo00<007ooOol00Goo000J
Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`800>eoo`8000=oo`006Woo00<007ooOol0kGoo
00<007ooOol00Goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`03001oogoo0>eoo`03
001oogoo005oo`006Woo0P00kGoo0P000goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yo
o`03001oogoo0>eoo`03001oogoo005oo`006Woo00<007ooOol0kGoo00<007ooOol00Goo000JOol2
003]Ool20003Ool000Aoo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo0>eoo`03001oogoo005oo`001Woo00<007ooOol01goo00L007ooOomoo`00Ool00003Ool0
0`00Oomoo`3]Ool00`00Oomoo`01Ool000Ioo`03001oogoo00Moo`03001oogoo00=oo`04001oogoo
Ool3003[Ool30003Ool000Ioo`03001oogoo00Qoo`03001oogoo008000Aoo`03001oogoo0>eoo`03
001oogoo005oo`001Woo00<007ooOol01Woo00<007oo00000Woo00<007ooOol00goo00<007ooOol0
kGoo00<007ooOol00Goo0005Ool20008Ool30002Ool30003Ool00`00Oomoo`3]Ool00`00Oomoo`01
Ool001Yoo`800>eoo`8000=oo`006Woo00<007ooOol0kGoo00<007ooOol00Goo000JOol00`00Oomo
o`3]Ool00`00Oomoo`01Ool001Yoo`03001oogoo0>eoo`03001oogoo005oo`006Woo0P00kGoo0P00
0goo000JOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Yoo`03001oogoo0>eoo`03001oogoo005o
o`006Woo00<007ooOol0kGoo00<007ooOol00Goo000JOol2003]Ool20003Ool001Yoo`03001oogoo
0>eoo`03001oogoo005oo`006Woo00<007ooOol0kGoo00<007ooOol00Goo000JOol00`00Oomoo`3]
Ool00`00Oomoo`01Ool001Yoo`800>eoo`8000=oo`006Woo00<007ooOol0kGoo00<007ooOol00Goo
000DOol30003Ool00`00Oomoo`3]Ool00`00Oomoo`01Ool001Aoo`03001oogoo00=oo`03001oogoo
02Eoo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo02Eoo`03001oogoo
02Eoo`03001oogoo005oo`005Goo00<007ooOol00Wool@000goo000EOol00`00Oomoo`3fOol001Ao
o`03001oo`000?Moo`005Goo00<007ooOol0mWoo003oOol?Ool00?moo`moo`00ogoo3goo0000\
\>"],
  ImageRangeCache->{{{0, 269}, {179, 0}} -> {-1.33876, -0.170371, 0.0125518, 
  0.0125518}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to the built-in ",
  StyleBox["Rectangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, with the exception that the sides of the ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic are aligned with the local coordinate system in which the graphic \
is located, instead of being aligned with the global coordinate system.\n\n\
The ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function also generates a rectangular box, but instead of specifying two \
points on two opposite corners, two points on two opposing sides of the \
rectangle are specified. The ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used with the ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to show only an outline of the bar. Unlike the ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts an axis object as its first argument, to allow the two endpoints \
of the bar to lie on two different bodies."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and a ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic spanning from ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the ground, with an ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic down the middle."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics[{\n\t\t\tBox[body2, {{0, 0}, {0.5, 1.0}}], \n\t\t\t
          RGBColor[1, 0, 0], \n\t\t\t
          Bar[Line[body2, {0.5, 1.0}, ground, {1.5, 1.5}], 0.2, 0.2, 
            Faces \[Rule] False], \n\t\t\t
          Edge[{Point[body2, {0.5, 1.0}], Point[ground, {1.5, 1.5}]}]}, \n\t\t
        AspectRatio \[Rule] Automatic, \n\t\tFrame \[Rule] True, \n\t\t
        PlotRange \[Rule] {{\(-1\), 2}, {0, 2}}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] .2, Th2 \[Rule] .1}]; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.333333 0 0.333333 [
[.16667 -0.0125 -12 -9 ]
[.16667 -0.0125 12 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -24 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .16667 -18 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .25 -24 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .41667 -24 -4.5 ]
[-0.0125 .41667 0 4.5 ]
[-0.0125 .5 -18 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .58333 -24 -4.5 ]
[-0.0125 .58333 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .66667 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(-0.5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(1.5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(0.25)] -0.0125 .08333 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0.5)] -0.0125 .16667 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0.75)] -0.0125 .25 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(1)] -0.0125 .33333 1 0 Mshowa
0 .41667 m
.00625 .41667 L
s
[(1.25)] -0.0125 .41667 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1.5)] -0.0125 .5 1 0 Mshowa
0 .58333 m
.00625 .58333 L
s
[(1.75)] -0.0125 .58333 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(2)] -0.0125 .66667 1 0 Mshowa
.125 Mabswid
0 .01667 m
.00375 .01667 L
s
0 .03333 m
.00375 .03333 L
s
0 .05 m
.00375 .05 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .11667 m
.00375 .11667 L
s
0 .13333 m
.00375 .13333 L
s
0 .15 m
.00375 .15 L
s
0 .18333 m
.00375 .18333 L
s
0 .2 m
.00375 .2 L
s
0 .21667 m
.00375 .21667 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .28333 m
.00375 .28333 L
s
0 .3 m
.00375 .3 L
s
0 .31667 m
.00375 .31667 L
s
0 .35 m
.00375 .35 L
s
0 .36667 m
.00375 .36667 L
s
0 .38333 m
.00375 .38333 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .45 m
.00375 .45 L
s
0 .46667 m
.00375 .46667 L
s
0 .48333 m
.00375 .48333 L
s
0 .51667 m
.00375 .51667 L
s
0 .53333 m
.00375 .53333 L
s
0 .55 m
.00375 .55 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .61667 m
.00375 .61667 L
s
0 .63333 m
.00375 .63333 L
s
0 .65 m
.00375 .65 L
s
.25 Mabswid
0 0 m
0 .66667 L
s
0 .66042 m
0 .66667 L
s
.16667 .66042 m
.16667 .66667 L
s
.33333 .66042 m
.33333 .66667 L
s
.5 .66042 m
.5 .66667 L
s
.66667 .66042 m
.66667 .66667 L
s
.83333 .66042 m
.83333 .66667 L
s
.125 Mabswid
.03333 .66292 m
.03333 .66667 L
s
.06667 .66292 m
.06667 .66667 L
s
.1 .66292 m
.1 .66667 L
s
.13333 .66292 m
.13333 .66667 L
s
.2 .66292 m
.2 .66667 L
s
.23333 .66292 m
.23333 .66667 L
s
.26667 .66292 m
.26667 .66667 L
s
.3 .66292 m
.3 .66667 L
s
.36667 .66292 m
.36667 .66667 L
s
.4 .66292 m
.4 .66667 L
s
.43333 .66292 m
.43333 .66667 L
s
.46667 .66292 m
.46667 .66667 L
s
.53333 .66292 m
.53333 .66667 L
s
.56667 .66292 m
.56667 .66667 L
s
.6 .66292 m
.6 .66667 L
s
.63333 .66292 m
.63333 .66667 L
s
.7 .66292 m
.7 .66667 L
s
.73333 .66292 m
.73333 .66667 L
s
.76667 .66292 m
.76667 .66667 L
s
.8 .66292 m
.8 .66667 L
s
.86667 .66292 m
.86667 .66667 L
s
.9 .66292 m
.9 .66667 L
s
.93333 .66292 m
.93333 .66667 L
s
.96667 .66292 m
.96667 .66667 L
s
.25 Mabswid
0 .66667 m
1 .66667 L
s
.99375 0 m
1 0 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .25 m
1 .25 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .41667 m
1 .41667 L
s
.99375 .5 m
1 .5 L
s
.99375 .58333 m
1 .58333 L
s
.125 Mabswid
.99625 .01667 m
1 .01667 L
s
.99625 .03333 m
1 .03333 L
s
.99625 .05 m
1 .05 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .11667 m
1 .11667 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .15 m
1 .15 L
s
.99625 .18333 m
1 .18333 L
s
.99625 .2 m
1 .2 L
s
.99625 .21667 m
1 .21667 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .28333 m
1 .28333 L
s
.99625 .3 m
1 .3 L
s
.99625 .31667 m
1 .31667 L
s
.99625 .35 m
1 .35 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .38333 m
1 .38333 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .45 m
1 .45 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .48333 m
1 .48333 L
s
.99625 .51667 m
1 .51667 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .55 m
1 .55 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .61667 m
1 .61667 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .65 m
1 .65 L
s
.25 Mabswid
1 0 m
1 .66667 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
.33333 .06667 m
.49917 .08331 L
.46589 .41497 L
.30006 .39833 L
F
1 0 0 r
.5 Mabswid
.45086 .47992 m
.48092 .35002 L
.84836 .43505 L
.8183 .56495 L
.45086 .47992 L
s
.46589 .41497 m
.83333 .5 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 188},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000_1000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00@Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol087oo00<007ooOol0
8Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07goo1@0087oo1@000Woo00<007ooOol0
0Woo00<007ooOol08Goo0`000goo0010Ool00`00Ool00007Ool00`00Ool0000POol00`00Ool0000R
Ool00`00Ool00007Ool00`00Ool0000ROol00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Ool0000R
Ool00`00Oomoo`03Ool003]oo`<0009oo`03001oo`0000Uoo`03001oogoo01ioo`03001oo`00029o
o`03001oo`0000Uoo`03001oogoo021oo`03001oogoo029oo`03001oogoo00Qoo`03001oogoo025o
o`03001oogoo009oo`00@7oo00<007oo00001goo0P008Goo00<007oo00008Woo00<007oo00001goo
0P008goo00<007ooOol08Woo00<007ooOol01Woo0P0097oo00<007ooOol00Woo0010Ool00`00Ool0
0007Ool00`00Oomoo`0POol00`00Ool0000ROol00`00Ool00007Ool00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Ool00003Ool0045oo`03001oogoo00Ioo`<0
025oo`03001oogoo029oo`03001oogoo00Ioo`<0025oo`8002=oo`8000Qoo`<002=oo`03001oogoo
009oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol001]ooo`000=oo`006goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol00Goo000KOol00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomo
o`0WOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03
001oogoo005oo`006goo0P00n7oo0P000goo000KOol00`00Oomoo`3hOol00`00Oomoo`01Ool001]o
o`03001oogoo0?Qoo`03001oogoo005oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000KOol0
0`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`800?Qoo`8000=oo`006goo00<007ooOol0n7oo00<0
07ooOol00Goo000KOol00`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03001o
ogoo005oo`006goo0P00n7oo0P000goo000KOol00`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`03
001oogoo0?Qoo`03001oogoo005oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000KOol2003h
Ool20003Ool001]oo`03001oogoo051oo`/009eoo`03001oogoo005oo`001Woo00<007ooOol00Woo
00@007ooOomoo`<000=oo`03001oogoo00=oo`03001oogoo051ooaD009=oo`03001oogoo005oo`00
1Goo00<007oo00001goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0D7oo8000R7oo00<0
07ooOol00Goo0005Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2001AOolZ001l
Ool30003Ool000Eoo`03001oo`0000Qoo`04001oogooOol20005Ool00`00Oomoo`1@OolZ001nOol0
0`00Oomoo`01Ool000Eoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo
051oobX007ioo`03001oogoo005oo`001Woo00<007ooOol01goo00@007ooOomoo`<000Aoo`03001o
ogoo051oobX007ioo`03001oogoo005oo`006goo0P00DGoo:P00OGoo0P000goo000KOol00`00Oomo
o`1@OolZ001nOol00`00Oomoo`01Ool001]oo`03001oogoo051oobX007ioo`03001oogoo005oo`00
6goo00<007ooOol0Cgoo:`00OWoo00<007ooOol00Goo000KOol2001@Ool[001mOol20003Ool001]o
o`03001oogoo04moob/007ioo`03001oogoo005oo`006goo00<007ooOol0Cgoo:`00OWoo00<007oo
Ool00Goo000KOol00`00Oomoo`1?OolZ001oOol00`00Oomoo`01Ool001]oo`03001oogoo04moobX0
07moo`03001oogoo005oo`006goo0P00D7oo:P00OWoo0P000goo000KOol00`00Oomoo`1?OolZ001o
Ool00`00Oomoo`01Ool001]oo`03001oogoo04moobX007moo`03001oogoo005oo`006goo00<007oo
Ool0Cgoo:P00Ogoo00<007ooOol00Goo000KOol2001?Ool[001nOol20003Ool001]oo`03001oogoo
04ioob/007moo`03001oogoo005oo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol0CWoo:`00Ogoo00<007ooOol00Goo000:Ool00`00Ool00007Ool00`00Ool00004
Ool00`00Oomoo`1>Ool[001oOol00`00Oomoo`01Ool000Yoo`03001oo`0000Uoo`03001oogoo009o
o`8004moobX007ioo`<000=oo`002Woo00<007oo00001goo0P001Goo00<007ooOol0CWoo:P00P7oo
00<007ooOol00Goo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`1>OolZ0020Ool0
0`00Oomoo`01Ool000]oo`03001oogoo00Ioo`<000Aoo`03001oogoo04ioobX0081oo`03001oogoo
005oo`006goo0P00Cgoo:P00Ogoo0P000goo000KOol00`00Oomoo`1>OolZ0020Ool00`00Oomoo`01
Ool001]oo`03001oogoo04ioobX0081oo`03001oogoo005oo`006goo00<007ooOol0CGoo:`00P7oo
00<007ooOol00Goo000KOol2001>Ool[001oOol20003Ool001]oo`03001oogoo04eoob/0081oo`03
001oogoo005oo`006goo00<007ooOol0CGoo:`00P7oo00<007ooOol00Goo000KOol00`00Oomoo`1=
OolZ0021Ool00`00Oomoo`01Ool001]oo`03001oogoo04eoobX0085oo`03001oogoo005oo`006goo
0P00CWoo:P00P7oo0P000goo000KOol00`00Oomoo`1=OolZ0021Ool00`00Oomoo`01Ool001]oo`03
001oogoo04eoobX0085oo`03001oogoo005oo`006goo00<007ooOol0CGoo:P00PGoo00<007ooOol0
0Goo000KOol2001=Ool[0020Ool20003Ool001]oo`03001oogoo04aoob/0085oo`03001oogoo005o
o`001Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool0C7oo:`00PGoo00<007ooOol00Goo0005Ool00`00Ool00008Ool01`00Oomoogoo001oo`0000Ao
o`03001oogoo04aoob/0085oo`03001oogoo005oo`001Goo00<007oo000027oo00<007ooOol00goo
00<007ooOol00Woo0P00CGoo:P00P7oo0`000goo0005Ool00`00Ool00009Ool00`00Oomoo`020005
Ool00`00Oomoo`1<OolZ0022Ool00`00Oomoo`01Ool000Eoo`03001oo`0000Moo`03001oo`00009o
o`03001oogoo00Aoo`03001oogoo04aoobX0089oo`03001oogoo005oo`001Woo00<007ooOol01Woo
0`000Woo0`0017oo00<007ooOol0C7oo:P00PWoo00<007ooOol00Goo000KOol2001=OolZ0021Ool2
0003Ool001]oo`03001oogoo04aoobX0089oo`03001oogoo005oo`006goo00<007ooOol0Bgoo:`00
PWoo00<007ooOol00Goo000KOol00`00Oomoo`1;Ool[0022Ool00`00Oomoo`01Ool001]oo`8004ao
ob/0085oo`8000=oo`006goo00<007ooOol0Bgoo:`00PWoo00<007ooOol00Goo000KOol00`00Oomo
o`1;OolZ0023Ool00`00Oomoo`01Ool001]oo`03001oogoo04]oobX008=oo`03001oogoo005oo`00
6goo0P00C7oo:P00PWoo0P000goo000KOol00`00Oomoo`1;OolZ0023Ool00`00Oomoo`01Ool001]o
o`03001oogoo04]oobX008=oo`03001oogoo005oo`006goo00<007ooOol0Bgoo:P00Pgoo00<007oo
Ool00Goo000KOol00`00Oomoo`1;OolZ0023Ool00`00Oomoo`01Ool001]oo`8004]oob/0089oo`80
00=oo`006goo00<007ooOol0BWoo:`00Pgoo00<007ooOol00Goo000COol50003Ool00`00Oomoo`1:
Ool[0023Ool00`00Oomoo`01Ool001Eoo`03001oogoo00=oo`03001oogoo04Yoob/008=oo`03001o
ogoo005oo`005Goo00<007ooOol00goo0P00Bgoo:P00PWoo0`000goo000EOol00`00Oomoo`03Ool0
0`00Oomoo`1:OolZ0024Ool00`00Oomoo`01Ool001Eoo`03001oogoo00=oo`03001oogoo04YoobX0
08Aoo`03001oogoo005oo`0057oo0P001Goo00<007ooOol0BWoo:P00Q7oo00<007ooOol00Goo000K
Ool2001;OolZ000017ooO01l07`0Ogoo0P000goo000KOol00`00Oomoo`1:OolZ000017ooO01oogoo
17`0O7oo00<007ooOol00Goo000KOol00`00Oomoo`19Ool[00000gooO01oo`05Ool4O01hOol00`00
Oomoo`01Ool001]oo`03001oogoo04Uoob/00003O01oogoo00Uoo`El07=oo`03001oogoo005oo`00
6goo0P00BWoo:`0000=l07ooOol03Woo17`0KWoo0P000goo000KOol00`00Oomoo`19Ool[00000g`0
Oomoo`0BOol5O01ZOol00`00Oomoo`01Ool001]oo`03001oogoo04UoobX00003Ooml07oo01Qoo`Al
06Ioo`03001oogoo005oo`006goo00<007ooOol0BGoo:P0000=oog`0Ool077oo17`0HWoo00<007oo
Ool00Goo000KOol2001:OolZ00000g`0Oomoo`0POol5O01LOol20003Ool001]oo`03001oogoo04Uo
obX00003O01oogoo02Eoo`Al05Uoo`03001oogoo005oo`006goo00<007ooOol0BGoo:P0000=l07oo
Ool0:Goo17`0EGoo00<007ooOol00Goo000KOol00`00Oomoo`19OolZ00000g`0Oomoo`0]Ool5O01@
Ool00`00Oomoo`01Ool001]oo`03001oogoo04QoobX00003O01oogoo03=oo`Al04aoo`03001oogoo
005oo`006goo0P00E7oo7`0000=l07ooOol0=goo1G`0AWoo0P000goo000KOol00`00Oomoo`1MOolE
00000g`0Oomoo`0lOol4O013Ool00`00Oomoo`01Ool000Aoo`D0009oo`04001oogooOol30003Ool0
0`00Oomoo`03Ool00`00Oomoo`1XOol:00000g`0Oomoo`10Ool4O00oOol00`00Oomoo`01Ool000Io
o`03001oogoo00Ioo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo079oo`=l04Aoo`El03Yo
o`03001oogoo005oo`001Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol00Woo0P00LWoo
00Al07ooOomoo`Al04Eoo`Al03Aoo`<000=oo`001Woo00<007ooOol01goo00@007ooOomoo`8000Eo
o`03001oogoo075oo`03O01oogoo00Eoo`Al04Eoo`El035oo`03001oogoo005oo`001Woo00<007oo
Ool01Woo00<007oo00000Woo00<007ooOol017oo00<007ooOol0LGoo00=l07ooOol02Goo17`0AWoo
17`0;Goo00<007ooOol00Goo0005Ool20009Ool01000Oomoogoo0`0017oo00<007ooOol0LGoo00=l
07ooOol03Goo17`0AWoo17`0:Goo00<007ooOol00Goo000KOol2001bOol00g`0Oomoo`0AOol4O016
Ool3O00UOol20003Ool001]oo`03001oogoo071oo`03O01oogoo01Ioo`El04=oo`03O01oogoo02Ao
o`03001oogoo005oo`006goo00<007ooOol0L7oo00=l07ooOol06goo17`0?goo00=l07ooOol097oo
00<007ooOol00Goo000KOol00`00Oomoo`1`Ool00g`0Oomoo`0OOol4O00jOol00g`0Oomoo`0UOol0
0`00Oomoo`01Ool001]oo`80075oo`03O01oogoo02=oo`Al03Ioo`03O01oogoo02Aoo`8000=oo`00
6goo00<007ooOol0Kgoo00=l07ooOol0:7oo17`0<Woo00=l07ooOol09Goo00<007ooOol00Goo000K
Ool00`00Oomoo`1_Ool00g`0Oomoo`0/Ool5O00]Ool00g`0Oomoo`0UOol00`00Oomoo`01Ool001]o
o`03001oogoo06moo`03O01oogoo035oo`Al02Uoo`03O01oogoo02Eoo`03001oogoo005oo`006goo
0P00L7oo00=l07ooOol0=Goo17`097oo00=l07ooOol09Goo0P000goo000KOol00`00Oomoo`1_Ool0
0g`0Oomoo`0iOol4O00POol00g`0Oomoo`0VOol00`00Oomoo`01Ool001]oo`03001oogoo06ioo`03
O01oogoo03ioo`Al01aoo`03O01oogoo02Ioo`03001oogoo005oo`006goo00<007ooOol0KWoo00=l
07ooOol0@Woo17`067oo00=l07ooOol09Woo00<007ooOol00Goo000KOol2001_Ool3O016Ool5O00B
Ool00g`0Oomoo`0VOol20003Ool001]oo`03001oogoo075oo`Al04Moo`Al00ioo`03O01oogoo02Mo
o`03001oogoo005oo`006goo00<007ooOol0MGoo17`0Agoo17`02Woo00=l07ooOol09goo00<007oo
Ool00Goo0009Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1iOol5O016Ool4
O006Ool00g`0Oomoo`0WOol00`00Oomoo`01Ool000]oo`03001oogoo00Ioo`03001oo`0000Aoo`03
001oogoo07ioo`Al04Ioo`Al009oo`03O01oogoo02Moo`03001oogoo005oo`002goo00<007ooOol0
27oo00<007ooOol00Woo0P00Pgoo1G`0AGoo0g`09goo0`000goo000;Ool00`00Oomoo`06Ool20005
Ool00`00Oomoo`27Ool4O012Ool00g`0Oomoo`0XOol00`00Oomoo`01Ool000]oo`03001oogoo00Io
o`03001oogoo00Aoo`03001oogoo08]oo`Al03ioo`03O01oogoo02Qoo`03001oogoo005oo`002Woo
0P0027oo0`0017oo00<007ooOol0Sgoo1G`0>Goo00=l07ooOol0:7oo00<007ooOol00Goo000KOol2
002EOol4O00eOol00g`0Oomoo`0WOol20003Ool001]oo`03001oogoo09Qoo`Al031oo`03O01oogoo
02Uoo`03001oogoo005oo`006goo00<007ooOol0W7oo1G`0:goo00=l07ooOol0:Goo00<007ooOol0
0Goo000KOol00`00Oomoo`2QOol4O00WOol00g`0Oomoo`0YOol00`00Oomoo`01Ool001]oo`800:Io
o`El029oo`03O01oogoo02Qoo`8000=oo`006goo00<007ooOol0ZWoo17`07Goo00=l07ooOol0:Woo
00<007ooOol00Goo000KOol00`00Oomoo`2^Ool4O00IOol00g`0Oomoo`0ZOol00`00Oomoo`01Ool0
01]oo`03001oogoo0;9oo`El01Aoo`03O01oogoo02Yoo`03001oogoo005oo`006goo0P00^7oo17`0
47oo00=l07ooOol0:Goo0P000goo000KOol00`00Oomoo`2kOol5O00;Ool00g`0Oomoo`0ZOol00`00
Oomoo`01Ool001]oo`03001oogoo0<1oo`Al00Ioo`03O01oogoo02]oo`03001oogoo005oo`006goo
00<007ooOol0a7oo17`00Woo00=l07ooOol0:goo00<007ooOol00Goo000KOol20039Ool3O00/Ool2
0003Ool001]oo`03001oogoo0?Qoo`03001oogoo005oo`006goo00<007ooOol0n7oo00<007ooOol0
0Goo0004Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3h
Ool00`00Oomoo`01Ool000Ioo`03001oogoo00Moo`07001oogooOol007oo000017oo00<007ooOol0
n7oo00<007ooOol00Goo0006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2003g
Ool30003Ool000Ioo`03001oogoo00Qoo`03001oogoo008000Eoo`03001oogoo0?Qoo`03001oogoo
005oo`001Woo00<007ooOol01Woo00<007oo00000Woo00<007ooOol017oo00<007ooOol0n7oo00<0
07ooOol00Goo0005Ool20008Ool30002Ool30004Ool00`00Oomoo`3hOol00`00Oomoo`01Ool001]o
o`800?Qoo`8000=oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000KOol00`00Oomoo`3hOol0
0`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03001oogoo005oo`006goo0P00n7oo0P000goo000K
Ool00`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03001oogoo005oo`006goo
00<007ooOol0n7oo00<007ooOol00Goo000KOol2003hOol20003Ool001]oo`03001oogoo0?Qoo`03
001oogoo005oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000KOol00`00Oomoo`3hOol00`00
Oomoo`01Ool001]oo`800?Qoo`8000=oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000DOol3
0004Ool00`00Oomoo`3hOol00`00Oomoo`01Ool001Aoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo005oo`00
5Goo00<007ooOol00gooo0000goo000EOol00`00Oomoo`3oOol3Ool001Aoo`03001oo`000?moo`Ao
o`005Goo00<007ooOol0ogoo0goo003oOolKOol00?mooa]oo`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {187, 0}} -> {-1.32453, -0.163798, 0.0119588, 
  0.0119588}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used here to generate an octagon with a hole in it. Note that \
the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon returned by ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is placed on the body that is referenced in the ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " argument, and is located with that body as such."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This generates an octagon on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics[{\n\t\t\t
          Wheel[Point[body2, {0, 1}], {.3, .8}, 8, Faces \[Rule] False]}, \n
        \t\tAspectRatio \[Rule] Automatic, \n\t\tFrame \[Rule] True, \n\t\t
        PlotRange \[Rule] {{\(-1\), 2}, {0, 2}}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] .2, Th2 \[Rule] \(-.1\)}]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.333333 0 0.333333 [
[.16667 -0.0125 -12 -9 ]
[.16667 -0.0125 12 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -9 -9 ]
[.83333 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .08333 -24 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .16667 -18 -4.5 ]
[-0.0125 .16667 0 4.5 ]
[-0.0125 .25 -24 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .41667 -24 -4.5 ]
[-0.0125 .41667 0 4.5 ]
[-0.0125 .5 -18 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .58333 -24 -4.5 ]
[-0.0125 .58333 0 4.5 ]
[-0.0125 .66667 -6 -4.5 ]
[-0.0125 .66667 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .66667 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.16667 0 m
.16667 .00625 L
s
[(-0.5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(1.5)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .08333 m
.00625 .08333 L
s
[(0.25)] -0.0125 .08333 1 0 Mshowa
0 .16667 m
.00625 .16667 L
s
[(0.5)] -0.0125 .16667 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(0.75)] -0.0125 .25 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(1)] -0.0125 .33333 1 0 Mshowa
0 .41667 m
.00625 .41667 L
s
[(1.25)] -0.0125 .41667 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1.5)] -0.0125 .5 1 0 Mshowa
0 .58333 m
.00625 .58333 L
s
[(1.75)] -0.0125 .58333 1 0 Mshowa
0 .66667 m
.00625 .66667 L
s
[(2)] -0.0125 .66667 1 0 Mshowa
.125 Mabswid
0 .01667 m
.00375 .01667 L
s
0 .03333 m
.00375 .03333 L
s
0 .05 m
.00375 .05 L
s
0 .06667 m
.00375 .06667 L
s
0 .1 m
.00375 .1 L
s
0 .11667 m
.00375 .11667 L
s
0 .13333 m
.00375 .13333 L
s
0 .15 m
.00375 .15 L
s
0 .18333 m
.00375 .18333 L
s
0 .2 m
.00375 .2 L
s
0 .21667 m
.00375 .21667 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .28333 m
.00375 .28333 L
s
0 .3 m
.00375 .3 L
s
0 .31667 m
.00375 .31667 L
s
0 .35 m
.00375 .35 L
s
0 .36667 m
.00375 .36667 L
s
0 .38333 m
.00375 .38333 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .45 m
.00375 .45 L
s
0 .46667 m
.00375 .46667 L
s
0 .48333 m
.00375 .48333 L
s
0 .51667 m
.00375 .51667 L
s
0 .53333 m
.00375 .53333 L
s
0 .55 m
.00375 .55 L
s
0 .56667 m
.00375 .56667 L
s
0 .6 m
.00375 .6 L
s
0 .61667 m
.00375 .61667 L
s
0 .63333 m
.00375 .63333 L
s
0 .65 m
.00375 .65 L
s
.25 Mabswid
0 0 m
0 .66667 L
s
0 .66042 m
0 .66667 L
s
.16667 .66042 m
.16667 .66667 L
s
.33333 .66042 m
.33333 .66667 L
s
.5 .66042 m
.5 .66667 L
s
.66667 .66042 m
.66667 .66667 L
s
.83333 .66042 m
.83333 .66667 L
s
.125 Mabswid
.03333 .66292 m
.03333 .66667 L
s
.06667 .66292 m
.06667 .66667 L
s
.1 .66292 m
.1 .66667 L
s
.13333 .66292 m
.13333 .66667 L
s
.2 .66292 m
.2 .66667 L
s
.23333 .66292 m
.23333 .66667 L
s
.26667 .66292 m
.26667 .66667 L
s
.3 .66292 m
.3 .66667 L
s
.36667 .66292 m
.36667 .66667 L
s
.4 .66292 m
.4 .66667 L
s
.43333 .66292 m
.43333 .66667 L
s
.46667 .66292 m
.46667 .66667 L
s
.53333 .66292 m
.53333 .66667 L
s
.56667 .66292 m
.56667 .66667 L
s
.6 .66292 m
.6 .66667 L
s
.63333 .66292 m
.63333 .66667 L
s
.7 .66292 m
.7 .66667 L
s
.73333 .66292 m
.73333 .66667 L
s
.76667 .66292 m
.76667 .66667 L
s
.8 .66292 m
.8 .66667 L
s
.86667 .66292 m
.86667 .66667 L
s
.9 .66292 m
.9 .66667 L
s
.93333 .66292 m
.93333 .66667 L
s
.96667 .66292 m
.96667 .66667 L
s
.25 Mabswid
0 .66667 m
1 .66667 L
s
.99375 0 m
1 0 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .16667 m
1 .16667 L
s
.99375 .25 m
1 .25 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .41667 m
1 .41667 L
s
.99375 .5 m
1 .5 L
s
.99375 .58333 m
1 .58333 L
s
.125 Mabswid
.99625 .01667 m
1 .01667 L
s
.99625 .03333 m
1 .03333 L
s
.99625 .05 m
1 .05 L
s
.99625 .06667 m
1 .06667 L
s
.99625 .1 m
1 .1 L
s
.99625 .11667 m
1 .11667 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .15 m
1 .15 L
s
.99625 .18333 m
1 .18333 L
s
.99625 .2 m
1 .2 L
s
.99625 .21667 m
1 .21667 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .28333 m
1 .28333 L
s
.99625 .3 m
1 .3 L
s
.99625 .31667 m
1 .31667 L
s
.99625 .35 m
1 .35 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .38333 m
1 .38333 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .45 m
1 .45 L
s
.99625 .46667 m
1 .46667 L
s
.99625 .48333 m
1 .48333 L
s
.99625 .51667 m
1 .51667 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .55 m
1 .55 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .6 m
1 .6 L
s
.99625 .61667 m
1 .61667 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .65 m
1 .65 L
s
.25 Mabswid
1 0 m
1 .66667 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
.5 Mabswid
.44403 .46163 m
.46611 .38835 L
.63195 .37171 L
.57306 .56713 L
s
.37659 .49784 m
.44403 .46163 L
.57306 .56713 L
.39323 .66367 L
s
.30331 .47575 m
.37659 .49784 L
.39323 .66367 L
.19782 .60478 L
s
.26711 .40832 m
.30331 .47575 L
.19782 .60478 L
.10128 .42496 L
s
.28919 .33504 m
.26711 .40832 L
.10128 .42496 L
.16017 .22954 L
s
.35663 .29883 m
.28919 .33504 L
.16017 .22954 L
.33999 .133 L
s
.42991 .32092 m
.35663 .29883 L
.33999 .133 L
.53541 .19189 L
s
.46611 .38835 m
.42991 .32092 L
.53541 .19189 L
.63195 .37171 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 188},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000_1000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00@Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol087oo00<007ooOol0
8Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol07goo1@0087oo1@000Woo00<007ooOol0
0Woo00<007ooOol08Goo0`000goo0010Ool00`00Ool00007Ool00`00Ool0000POol00`00Ool0000R
Ool00`00Ool00007Ool00`00Ool0000ROol00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Ool0000R
Ool00`00Oomoo`03Ool003]oo`<0009oo`03001oo`0000Uoo`03001oogoo01ioo`03001oo`00029o
o`03001oo`0000Uoo`03001oogoo021oo`03001oogoo029oo`03001oogoo00Qoo`03001oogoo025o
o`03001oogoo009oo`00@7oo00<007oo00001goo0P008Goo00<007oo00008Woo00<007oo00001goo
0P008goo00<007ooOol08Woo00<007ooOol01Woo0P0097oo00<007ooOol00Woo0010Ool00`00Ool0
0007Ool00`00Oomoo`0POol00`00Ool0000ROol00`00Ool00007Ool00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`06Ool00`00Oomoo`0ROol00`00Ool00003Ool0045oo`03001oogoo00Ioo`<0
025oo`03001oogoo029oo`03001oogoo00Ioo`<0025oo`8002=oo`8000Qoo`<002=oo`03001oogoo
009oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol001]ooo`000=oo`006goo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol00Goo000KOol00`00Oomoo`0VOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomo
o`0WOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03
001oogoo005oo`006goo0P00n7oo0P000goo000KOol00`00Oomoo`3hOol00`00Oomoo`01Ool001]o
o`03001oogoo0?Qoo`03001oogoo005oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000KOol0
0`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`800?Qoo`8000=oo`006goo00<007ooOol0n7oo00<0
07ooOol00Goo000KOol00`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03001o
ogoo005oo`006goo0P00n7oo0P000goo000KOol00`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`03
001oogoo0?Qoo`03001oogoo005oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000KOol2003h
Ool20003Ool001]oo`03001oogoo0?Qoo`03001oogoo005oo`001Woo00<007ooOol00Woo00@007oo
Oomoo`<000=oo`03001oogoo00=oo`03001oogoo0?Qoo`03001oogoo005oo`001Goo00<007oo0000
1goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0n7oo00<007ooOol00Goo0005Ool00`00
Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2003gOol30003Ool000Eoo`03001oo`0000Qo
o`04001oogooOol20005Ool00`00Oomoo`3hOol00`00Oomoo`01Ool000Eoo`03001oo`0000Moo`03
001oo`00009oo`03001oogoo00Aoo`03001oogoo0?Qoo`03001oogoo005oo`001Woo00<007ooOol0
1goo00@007ooOomoo`<000Aoo`03001oogoo0?Qoo`03001oogoo005oo`006goo0P00n7oo0P000goo
000KOol00`00Oomoo`3hOol00`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03001oogoo005oo`00
6goo00<007ooOol0n7oo00<007ooOol00Goo000KOol2003hOol20003Ool001]oo`03001oogoo0?Qo
o`03001oogoo005oo`006goo00<007ooOol0n7oo00<007ooOol00Goo000KOol00`00Oomoo`3hOol0
0`00Oomoo`01Ool001]oo`03001oogoo0?Qoo`03001oogoo005oo`006goo0P00Dgoo0P00Xgoo0P00
0goo000KOol00`00Oomoo`1@Ool300000goo00000002002POol00`00Oomoo`01Ool001]oo`03001o
ogoo04ioo`80009oo`03001oogoo00=oo`<009eoo`03001oogoo005oo`006goo00<007ooOol0C7oo
0P0017oo00<007ooOol01Woo1000VGoo00<007ooOol00Goo000KOol2001;Ool20006Ool00`00Oomo
o`0:Ool3002EOol20003Ool001]oo`03001oogoo04Qoo`8000Qoo`03001oogoo00eoo`@0099oo`03
001oogoo005oo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
AWoo0P002goo00<007ooOol047oo0`00Sgoo00<007ooOol00Goo000:Ool00`00Ool00007Ool00`00
Ool00004Ool00`00Oomoo`14Ool2000=Ool00`00Oomoo`0COol4002;Ool00`00Oomoo`01Ool000Yo
o`03001oo`0000Uoo`03001oogoo009oo`8004Aoo`03001oogoo00eoo`03001oogoo01Moo`<008Io
o`<000=oo`002Woo00<007oo00001goo0P001Goo00<007ooOol0@Goo0P0047oo00<007ooOol06Woo
1000Q7oo00<007ooOol00Goo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0oOol2
000BOol00`00Oomoo`0NOol30021Ool00`00Oomoo`01Ool000]oo`03001oogoo00Ioo`<000Aoo`03
001oogoo03eoo`8001Aoo`03001oogoo025oo`@007eoo`03001oogoo005oo`006goo0P00?7oo0P00
5Woo00<007ooOol09Goo0`00NGoo0P000goo000KOol00`00Oomoo`0iOol2000HOol00`00Oomoo`0X
Ool4001fOol00`00Oomoo`01Ool001]oo`03001oogoo03Moo`8001Yoo`03001oogoo02aoo`8007Ao
o`03001oogoo005oo`006goo00<007ooOol0=Goo0P0077oo00<007ooOol0;7oo00<007oo0000Lgoo
00<007ooOol00Goo000KOol2000eOol00`00Oomoo`0MOol00`00Oomoo`0ZOol01000Oomoo`00LWoo
0P000goo000KOol00`00Oomoo`0bOol2000POol00`00Oomoo`0ZOol01@00Oomoogoo0000LWoo00<0
07ooOol00Goo000KOol00`00Oomoo`0`Ool2000ROol00`00Oomoo`0YOol00`00Oomoo`02Ool00`00
Oomoo`1`Ool00`00Oomoo`01Ool001]oo`03001oogoo02ioo`8002Aoo`03001oogoo02Qoo`03001o
ogoo00Aoo`03001oogoo06moo`03001oogoo005oo`006goo00<007ooOol0;7oo0P009Woo00<007oo
Ool09goo00<007ooOol01Goo00<007ooOol0Kgoo00<007ooOol00Goo000KOol2000[Ool2000XOol0
0`00Oomoo`0VOol00`00Oomoo`07Ool00`00Oomoo`1]Ool20003Ool001]oo`03001oogoo02Qoo`80
02Yoo`03001oogoo02Eoo`03001oogoo00Qoo`03001oogoo06ioo`03001oogoo005oo`006goo00<0
07ooOol09Woo0P00;7oo00<007ooOol09Goo00<007ooOol02Goo00<007ooOol0KGoo00<007ooOol0
0Goo000KOol00`00Oomoo`0UOol00`00Oomoo`0/Ool00`00Oomoo`0TOol00`00Oomoo`0:Ool00`00
Oomoo`1]Ool00`00Oomoo`01Ool001]oo`8002Ioo`8002eoo`03001oogoo02=oo`03001oogoo00ao
o`03001oogoo06]oo`8000=oo`006goo00<007ooOol097oo00<007ooOol00P00;7oo00<007ooOol0
8Goo00<007ooOol03Goo00<007ooOol0K7oo00<007ooOol00Goo0006Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00
Oomoo`0YOol00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`1[Ool00`00Oomoo`01Ool000Eo
o`03001oo`0000Qoo`07001oogooOol007oo000017oo00<007ooOol097oo00<007ooOol00goo00<0
07ooOol0:7oo00<007ooOol087oo00<007ooOol03goo00<007ooOol0Jgoo00<007ooOol00Goo0005
Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2000TOol00`00Oomoo`05Ool00`00
Oomoo`0WOol00`00Oomoo`0OOol00`00Oomoo`0AOol00`00Oomoo`1XOol30003Ool000Eoo`03001o
o`0000Uoo`03001oogoo008000Eoo`03001oogoo02=oo`03001oogoo00Ioo`03001oogoo02Ioo`03
001oogoo01ioo`03001oogoo01=oo`03001oogoo06Uoo`03001oogoo005oo`001Goo00<007oo0000
1goo00<007oo00000Woo00<007ooOol017oo00<007ooOol08goo00<007ooOol01goo0P009Woo00<0
07ooOol07Goo00<007ooOol057oo00<007ooOol0JGoo00<007ooOol00Goo0006Ool00`00Oomoo`06
Ool30002Ool30004Ool00`00Oomoo`0SOol00`00Oomoo`09Ool00`00Oomoo`0SOol00`00Oomoo`0L
Ool00`00Oomoo`0FOol00`00Oomoo`1XOol00`00Oomoo`01Ool001]oo`8002=oo`03001oogoo00]o
o`03001oogoo029oo`03001oogoo01]oo`03001oogoo01Moo`03001oogoo06Moo`8000=oo`006goo
00<007ooOol08Woo00<007ooOol037oo00<007ooOol08Goo00<007ooOol06goo00<007ooOol067oo
00<007ooOol0Igoo00<007ooOol00Goo000KOol00`00Oomoo`0ROol00`00Oomoo`0=Ool2000QOol0
0`00Oomoo`0JOol00`00Oomoo`0IOol00`00Oomoo`1WOol00`00Oomoo`01Ool001]oo`03001oogoo
025oo`03001oogoo011oo`03001oogoo01moo`03001oogoo01Qoo`03001oogoo01]oo`03001oogoo
06Ioo`03001oogoo005oo`006goo0P008Woo00<007ooOol04Goo00<007ooOol07Woo00<007ooOol0
5goo00<007ooOol077oo00<007ooOol0IGoo0P000goo000KOol00`00Oomoo`0QOol00`00Oomoo`0B
Ool00`00Oomoo`0MOol00`00Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`1UOol00`00Oomoo`01
Ool001]oo`03001oogoo021oo`03001oogoo01Aoo`8001eoo`03001oogoo01Ioo`03001oogoo01io
o`03001oogoo06Eoo`03001oogoo005oo`006goo00<007ooOol087oo00<007ooOol05Woo00<007oo
Ool06Woo00<007ooOol05Goo00<007ooOol087oo00<007ooOol0I7oo00<007ooOol00Goo000KOol2
000QOol00`00Oomoo`0GOol00`00Oomoo`0IOol2000EOol00`00Oomoo`0QOol00`00Oomoo`1SOol2
0003Ool001]oo`03001oogoo01moo`03001oogoo01Uoo`03001oogoo01Ioo`80009oo`<0015oo`03
001oogoo02=oo`03001oogoo06=oo`03001oogoo005oo`006goo00<007ooOol07goo00<007ooOol0
6Woo00<007ooOol04goo0P001goo0`003Goo00<007ooOol097oo00<007ooOol0Hgoo00<007ooOol0
0Goo000KOol00`00Oomoo`0OOol00`00Oomoo`0KOol2000AOol2000<Ool30009Ool00`00Oomoo`0V
Ool00`00Oomoo`1ROol00`00Oomoo`01Ool001]oo`03001oogoo01moo`03001oogoo01eoo`03001o
ogoo00aoo`80015oo`<000Ioo`03001oogoo02Moo`03001oogoo065oo`03001oogoo005oo`006goo
0P007goo00<007ooOol07goo00<007ooOol02Goo0P005Woo0`000Woo00<007ooOol0:7oo00<007oo
Ool0H7oo0P000goo000KOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`06Ool2000KOol2
000/Ool00`00Oomoo`1POol00`00Oomoo`01Ool001=oo`D000=oo`03001oogoo01ioo`03001oogoo
025oo`8000Aoo`8001moo`03001oogoo02Uoo`03001oogoo061oo`03001oogoo005oo`005Goo00<0
07ooOol00goo00<007ooOol07Goo00<007ooOol097oo00@007oo0000025oo`03001oogoo02Yoo`03
001oogoo05moo`03001oogoo005oo`005Goo00<007ooOol00goo0P007Woo00<007ooOol09Goo00<0
07ooOol08Woo00<007ooOol0:Goo00<007ooOol0GGoo0`000goo000EOol00`00Oomoo`03Ool00`00
Oomoo`0MOol00`00Oomoo`0UOol00`00Oomoo`0ROol00`00Oomoo`0ZOol00`00Oomoo`1NOol00`00
Oomoo`01Ool001Eoo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo02Eoo`03001oogoo02Ao
o`03001oogoo02Uoo`03001oogoo05ioo`03001oogoo005oo`0057oo0P001Goo00<007ooOol077oo
00<007ooOol09Goo00<007ooOol09Goo00<007ooOol0:Goo00<007ooOol0GGoo00<007ooOol00Goo
000KOol2000MOol00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`0YOol00`00Oomoo`1LOol2
0003Ool001]oo`03001oogoo01aoo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo02Uoo`03
001oogoo05aoo`03001oogoo005oo`006goo00<007ooOol06goo00<007ooOol09Goo00<007ooOol0
9goo00<007ooOol0:Goo00<007ooOol0G7oo00<007ooOol00Goo000KOol00`00Oomoo`0KOol00`00
Oomoo`0UOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`1KOol00`00Oomoo`01Ool001]o
o`8001aoo`03001oogoo02Eoo`03001oogoo02Qoo`03001oogoo02Uoo`03001oogoo05Yoo`8000=o
o`006goo00<007ooOol06Woo00<007ooOol09Woo00<007ooOol0:Goo00<007ooOol09Goo1@00G7oo
00<007ooOol00Goo000KOol00`00Oomoo`0JOol00`00Oomoo`0UOol00`00Oomoo`0[Ool00`00Oomo
o`0LOol80004Ool00`00Oomoo`1JOol00`00Oomoo`01Ool001]oo`03001oogoo01Yoo`03001oogoo
02Eoo`03001oogoo02]oo`03001oogoo01Aoo`P000]oo`03001oogoo05]oo`03001oogoo005oo`00
6goo0P006Woo00<007ooOol09Woo00<007ooOol0;7oo00<007ooOol02goo20004goo00<007ooOol0
FWoo0P000goo000KOol00`00Oomoo`0IOol00`00Oomoo`0VOol00`00Oomoo`0/Ool00`00Oomoo`03
Ool8000KOol00`00Oomoo`1KOol00`00Oomoo`01Ool001]oo`03001oogoo01Uoo`03001oogoo02Eo
o`03001oogoo02ioo`D0029oo`03001oogoo05aoo`03001oogoo005oo`006goo00<007ooOol067oo
00<007ooOol09Woo00<007ooOol0;Woo00<007ooOol097oo00<007ooOol0G7oo00<007ooOol00Goo
000KOol00`00Oomoo`0HOol00`00Oomoo`0VOol00`00Oomoo`0]Ool00`00Oomoo`0UOol00`00Oomo
o`1LOol00`00Oomoo`01Ool001]oo`8001Uoo`03001oogoo02Ioo`03001oogoo02eoo`03001oogoo
02Eoo`03001oogoo05]oo`8000=oo`006goo00<007ooOol067oo00<007ooOol09Goo00<007ooOol0
;Woo00<007ooOol097oo00<007ooOol0GGoo00<007ooOol00Goo0004Ool50002Ool01000Oomoogoo
0`000goo00<007ooOol00goo00<007ooOol05goo00<007ooOol08Goo1P00;goo00<007ooOol09Goo
00<007ooOol0GGoo00<007ooOol00Goo0006Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool0
0004Ool00`00Oomoo`0GOol00`00Oomoo`0GOol:0006Ool00`00Oomoo`0/Ool00`00Oomoo`0UOol0
0`00Oomoo`1MOol00`00Oomoo`01Ool000Ioo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
009oo`8001Qoo`03001oogoo00aoo`/0011oo`03001oogoo02aoo`03001oogoo02Aoo`03001oogoo
05aoo`<000=oo`001Woo00<007ooOol01goo00@007ooOomoo`8000Eoo`03001oogoo01Ioo`03001o
ogoo00=oo`X001aoo`03001oogoo02Yoo`03001oogoo02Eoo`03001oogoo05ioo`03001oogoo005o
o`001Woo00<007ooOol01Woo00<007oo00000Woo00<007ooOol017oo00<007ooOol05Woo1P009Woo
00<007ooOol0:Woo00<007ooOol09Goo00<007ooOol0GWoo00<007ooOol00Goo0005Ool20009Ool0
1000Oomoogoo0`0017oo00<007ooOol05goo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0
97oo00<007ooOol0Ggoo00<007ooOol00Goo000KOol2000HOol00`00Oomoo`0YOol00`00Oomoo`0X
Ool00`00Oomoo`0UOol00`00Oomoo`1NOol20003Ool001]oo`03001oogoo01Qoo`03001oogoo02Uo
o`03001oogoo02Moo`03001oogoo02Eoo`03001oogoo05moo`03001oogoo005oo`006goo00<007oo
Ool067oo00<007ooOol0:Goo00<007ooOol09goo00<007ooOol097oo00<007ooOol0H7oo00<007oo
Ool00Goo000KOol00`00Oomoo`0IOol00`00Oomoo`0YOol00`00Oomoo`0UOol00`00Oomoo`0UOol0
0`00Oomoo`1POol00`00Oomoo`01Ool001]oo`8001Yoo`03001oogoo02Uoo`03001oogoo02Eoo`03
001oogoo02Eoo`03001oogoo05moo`8000=oo`006goo00<007ooOol06Woo00<007ooOol0:Goo00<0
07ooOol097oo00<007ooOol09Goo00<007ooOol0H7oo00<007ooOol00Goo000KOol00`00Oomoo`0J
Ool00`00Oomoo`0YOol00`00Oomoo`0SOol00`00Oomoo`0UOol00`00Oomoo`1QOol00`00Oomoo`01
Ool001]oo`03001oogoo01]oo`03001oogoo02Uoo`03001oogoo029oo`03001oogoo02Eoo`03001o
ogoo065oo`03001oogoo005oo`006goo0P0077oo00<007ooOol0:Goo00<007ooOol087oo0P0000=o
o`00Ool09Goo00<007ooOol0H7oo0P000goo000KOol00`00Oomoo`0LOol00`00Oomoo`0YOol00`00
Oomoo`0MOol20004Ool2000SOol00`00Oomoo`1ROol00`00Oomoo`01Ool001]oo`03001oogoo01ao
o`03001oogoo02Uoo`03001oogoo01]oo`8000Qoo`03001oogoo021oo`03001oogoo069oo`03001o
ogoo005oo`006goo00<007ooOol07Goo00<007ooOol0:Goo0P006Goo0P002goo00<007ooOol07goo
00<007ooOol0HWoo00<007ooOol00Goo000KOol2000NOol00`00Oomoo`0XOol00`00Oomoo`04000C
Ool2000>Ool00`00Oomoo`0MOol00`00Oomoo`1ROol20003Ool001]oo`03001oogoo01ioo`03001o
ogoo02Ioo`03001oogoo00Eoo`<000ioo`80015oo`03001oogoo01aoo`03001oogoo06=oo`03001o
ogoo005oo`006goo00<007ooOol07goo00<007ooOol097oo00<007ooOol02Goo100027oo0P0057oo
0P0077oo00<007ooOol0Hgoo00<007ooOol00Goo0009Ool50002Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0OOol00`00Oomoo`0TOol00`00Oomoo`0=Ool40002Ool2000HOol00`00Oomo
o`0IOol00`00Oomoo`1SOol00`00Oomoo`01Ool000]oo`03001oogoo00Ioo`03001oo`0000Aoo`03
001oogoo021oo`03001oogoo029oo`03001oogoo019oo`8001]oo`03001oogoo01Moo`03001oogoo
06Aoo`03001oogoo005oo`002goo00<007ooOol027oo00<007ooOol00Woo0P008Goo00<007ooOol0
8Goo00<007ooOol057oo00<007ooOol06Woo00<007ooOol05Woo00<007ooOol0HWoo0`000goo000;
Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`0QOol00`00Oomoo`0OOol00`00Oomoo`0EOol00`00
Oomoo`0KOol2000FOol00`00Oomoo`1TOol00`00Oomoo`01Ool000]oo`03001oogoo00Ioo`03001o
ogoo00Aoo`03001oogoo025oo`03001oogoo01ioo`03001oogoo01Ioo`03001oogoo01eoo`03001o
ogoo019oo`03001oogoo06Eoo`03001oogoo005oo`002Woo0P0027oo0`0017oo00<007ooOol08Woo
00<007ooOol077oo00<007ooOol05goo00<007ooOol07Woo00<007ooOol04Goo00<007ooOol0IGoo
00<007ooOol00Goo000KOol2000SOol00`00Oomoo`0LOol00`00Oomoo`0GOol00`00Oomoo`0OOol0
0`00Oomoo`0@Ool00`00Oomoo`1TOol20003Ool001]oo`03001oogoo02=oo`03001oogoo01Yoo`03
001oogoo01Uoo`03001oogoo01moo`8000moo`03001oogoo06Ioo`03001oogoo005oo`006goo00<0
07ooOol08goo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol08Goo00<007ooOol037oo00<0
07ooOol0IWoo00<007ooOol00Goo000KOol00`00Oomoo`0TOol00`00Oomoo`0GOol00`00Oomoo`0K
Ool00`00Oomoo`0ROol00`00Oomoo`0;Ool00`00Oomoo`1VOol00`00Oomoo`01Ool001]oo`8002Eo
o`03001oogoo01Ioo`03001oogoo01aoo`03001oogoo02=oo`03001oogoo00Uoo`03001oogoo06Io
o`8000=oo`006goo00<007ooOol09Goo00<007ooOol057oo00<007ooOol07Goo00<007ooOol097oo
00<007ooOol027oo00<007ooOol0Igoo00<007ooOol00Goo000KOol00`00Oomoo`0UOol00`00Oomo
o`0COol00`00Oomoo`0NOol00`00Oomoo`0UOol20008Ool00`00Oomoo`1WOol00`00Oomoo`01Ool0
01]oo`03001oogoo02Ioo`03001oogoo019oo`03001oogoo01ioo`03001oogoo02Moo`03001oogoo
00Eoo`03001oogoo06Moo`03001oogoo005oo`006goo0P00:7oo00<007ooOol047oo00<007ooOol0
7goo00<007ooOol0:7oo00<007ooOol00goo00<007ooOol0Igoo0P000goo000KOol00`00Oomoo`0W
Ool00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`1X
Ool00`00Oomoo`01Ool001]oo`03001oogoo02Qoo`03001oogoo00eoo`03001oogoo025oo`03001o
ogoo02Yoo`80009oo`03001oogoo06Qoo`03001oogoo005oo`006goo00<007ooOol0:7oo00<007oo
Ool037oo00<007ooOol08goo00<007ooOol0:goo0P00Jgoo00<007ooOol00Goo000KOol2000ZOol0
0`00Oomoo`0:Ool00`00Oomoo`0TOol00`00Oomoo`0/Ool00`00Oomoo`1XOol20003Ool001]oo`03
001oogoo02Uoo`03001oogoo00Yoo`03001oogoo02Aoo`03001oogoo02Yoo`8006aoo`03001oogoo
005oo`006goo00<007ooOol0:Woo00<007ooOol027oo00<007ooOol09Goo00<007ooOol0:7oo0P00
KWoo00<007ooOol00Goo0004Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`0ZOol00`00Oomoo`07Ool00`00Oomoo`0VOol00`00Oomoo`0VOol2001`Ool00`00
Oomoo`01Ool000Ioo`03001oogoo00Moo`07001oogooOol007oo000017oo00<007ooOol0:goo00<0
07ooOol01Goo00<007ooOol09goo00<007ooOol097oo0P00LWoo00<007ooOol00Goo0006Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2000/Ool00`00Oomoo`04Ool00`00Oomoo`0X
Ool00`00Oomoo`0SOol00`00Oomoo`1`Ool30003Ool000Ioo`03001oogoo00Qoo`03001oogoo0080
00Eoo`03001oogoo02aoo`03001oogoo009oo`03001oogoo02Uoo`03001oogoo025oo`8007Eoo`03
001oogoo005oo`001Woo00<007ooOol01Woo00<007oo00000Woo00<007ooOol017oo00<007ooOol0
;7oo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol07goo0P00Mgoo00<007ooOol00Goo0005
Ool20008Ool30002Ool30004Ool00`00Oomoo`0]Ool01000Oomoo`00;7oo00<007ooOol07Goo0P00
NGoo00<007ooOol00Goo000KOol2000^Ool00`00Ool0000]Ool00`00Oomoo`0KOol2001jOol20003
Ool001]oo`03001oogoo02ioo`8002ioo`03001oogoo01Uoo`03001oogoo07]oo`03001oogoo005o
o`006goo00<007ooOol0<7oo0`00:goo00<007ooOol05goo0P00OWoo00<007ooOol00Goo000KOol0
0`00Oomoo`0cOol4000WOol00`00Oomoo`0EOol20020Ool00`00Oomoo`01Ool001]oo`8003Qoo`<0
02Aoo`03001oogoo01=oo`80085oo`8000=oo`006goo00<007ooOol0>Woo0`008Goo00<007ooOol0
4Goo0P00Q7oo00<007ooOol00Goo000KOol00`00Oomoo`0mOol3000NOol00`00Oomoo`0@Ool00`00
Oomoo`24Ool00`00Oomoo`01Ool001]oo`03001oogoo041oo`@001Yoo`03001oogoo00ioo`8008Mo
o`03001oogoo005oo`006goo0P00AGoo0`005goo00<007ooOol037oo0P00R7oo0P000goo000KOol0
0`00Oomoo`17Ool3000DOol00`00Oomoo`0:Ool2002;Ool00`00Oomoo`01Ool001]oo`03001oogoo
04Yoo`@0011oo`03001oogoo00Qoo`8008eoo`03001oogoo005oo`006goo00<007ooOol0CWoo0`00
3Woo00<007ooOol01Woo00<007ooOol0SGoo00<007ooOol00Goo000KOol2001BOol3000;Ool00`00
Oomoo`04Ool2002?Ool20003Ool001]oo`03001oogoo05Aoo`<000Qoo`03001oogoo009oo`80099o
o`03001oogoo005oo`0057oo0`0017oo00<007ooOol0Egoo100017oo00<007ooOol00P00U7oo00<0
07ooOol00Goo000DOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Ool00002000017oo00000000
1goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0
1Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol00Goo000EOol00`00Oomoo`03Oool0003
Ool001Eoo`03001oogoo0?moo`=oo`0057oo00<007oo0000ogoo17oo000EOol00`00Oomoo`3oOol3
Ool00?mooa]oo`00ogoo6goo003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {187, 0}} -> {-1.32453, -0.163798, 0.0119588, 
  0.0119588}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Annotation Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three graphics functions are provided by ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifically for annotation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Arrow[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, leng",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["th",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates an arrow of specified ",
  StyleBox["length",
    FontSlant->"Italic"],
  " that emanates from the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and points in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["PointLabel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bn",
    FontSlant->"Italic"],
  StyleBox["um, lp",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["nt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a label specifying the local coordinates of ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["LocalAxes[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, size",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a local coordinate axes on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", labeled with the body number and the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " and ",
  StyleBox["y",
    FontSlant->"Italic"],
  " direction vectors. The length of each arm of the axes is specified by ",
  StyleBox["size",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Graphics functions for annotation."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["PointLabel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["LocalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to conveniently label points and bodies. The following input \
generates a triangle placed on body 2, with two of the points labeled with \
their body numbers and local coordinates. If ",
  StyleBox["PointLabel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is given a local point number as an argument instead of a coordinate \
pair, then it labels the point with its body number and its point number."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This generates a labeled triangle on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(body2 = 2; \)\), 
    \(\(bdgraph = 
      Graphics[{\n\t\t\tEdge[body2, {{0, 0}, {1, 0}, {1, 1}, {0, 0}}], \n
          \t\t\tArrow[Line[body2, {0.5, 0.5}, {1, 0}], 0.5], \n\t\t\t
          PointLabel[body2, {1, 1}], \n\t\t\tPointLabel[body2, {1, 0}], \n
          \t\t\tLocalAxes[body2, .3]}, \n\t\tAspectRatio \[Rule] Automatic, \n
        \t\tFrame \[Rule] True, \n\t\tPlotRange \[Rule] {{0, 2}, {0, 1.5}}]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[bdgraph /. {X2 \[Rule] .5, Y2 \[Rule] 0, Th2 \[Rule] .5}]; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.5 0 0.5 [
[.125 -0.0125 -12 -9 ]
[.125 -0.0125 12 0 ]
[.25 -0.0125 -9 -9 ]
[.25 -0.0125 9 0 ]
[.375 -0.0125 -12 -9 ]
[.375 -0.0125 12 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -12 -9 ]
[.625 -0.0125 12 0 ]
[.75 -0.0125 -9 -9 ]
[.75 -0.0125 9 0 ]
[.875 -0.0125 -12 -9 ]
[.875 -0.0125 12 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .1 -18 -4.5 ]
[-0.0125 .1 0 4.5 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .3 -18 -4.5 ]
[-0.0125 .3 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .7 -18 -4.5 ]
[-0.0125 .7 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .75 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .75 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.125 0 m
.125 .00625 L
s
[(0.25)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.5)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.75)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1.25)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(1.5)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(1.75)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(2)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .1 m
.00625 .1 L
s
[(0.2)] -0.0125 .1 1 0 Mshowa
0 .2 m
.00625 .2 L
s
[(0.4)] -0.0125 .2 1 0 Mshowa
0 .3 m
.00625 .3 L
s
[(0.6)] -0.0125 .3 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.8)] -0.0125 .4 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(1)] -0.0125 .5 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(1.2)] -0.0125 .6 1 0 Mshowa
0 .7 m
.00625 .7 L
s
[(1.4)] -0.0125 .7 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .125 m
.00375 .125 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .225 m
.00375 .225 L
s
0 .25 m
.00375 .25 L
s
0 .275 m
.00375 .275 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .375 m
.00375 .375 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .625 m
.00375 .625 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .725 m
.00375 .725 L
s
.25 Mabswid
0 0 m
0 .75 L
s
0 .74375 m
0 .75 L
s
.125 .74375 m
.125 .75 L
s
.25 .74375 m
.25 .75 L
s
.375 .74375 m
.375 .75 L
s
.5 .74375 m
.5 .75 L
s
.625 .74375 m
.625 .75 L
s
.75 .74375 m
.75 .75 L
s
.875 .74375 m
.875 .75 L
s
.125 Mabswid
.025 .74625 m
.025 .75 L
s
.05 .74625 m
.05 .75 L
s
.075 .74625 m
.075 .75 L
s
.1 .74625 m
.1 .75 L
s
.15 .74625 m
.15 .75 L
s
.175 .74625 m
.175 .75 L
s
.2 .74625 m
.2 .75 L
s
.225 .74625 m
.225 .75 L
s
.275 .74625 m
.275 .75 L
s
.3 .74625 m
.3 .75 L
s
.325 .74625 m
.325 .75 L
s
.35 .74625 m
.35 .75 L
s
.4 .74625 m
.4 .75 L
s
.425 .74625 m
.425 .75 L
s
.45 .74625 m
.45 .75 L
s
.475 .74625 m
.475 .75 L
s
.525 .74625 m
.525 .75 L
s
.55 .74625 m
.55 .75 L
s
.575 .74625 m
.575 .75 L
s
.6 .74625 m
.6 .75 L
s
.65 .74625 m
.65 .75 L
s
.675 .74625 m
.675 .75 L
s
.7 .74625 m
.7 .75 L
s
.725 .74625 m
.725 .75 L
s
.775 .74625 m
.775 .75 L
s
.8 .74625 m
.8 .75 L
s
.825 .74625 m
.825 .75 L
s
.85 .74625 m
.85 .75 L
s
.9 .74625 m
.9 .75 L
s
.925 .74625 m
.925 .75 L
s
.95 .74625 m
.95 .75 L
s
.975 .74625 m
.975 .75 L
s
.25 Mabswid
0 .75 m
1 .75 L
s
.99375 0 m
1 0 L
s
.99375 .1 m
1 .1 L
s
.99375 .2 m
1 .2 L
s
.99375 .3 m
1 .3 L
s
.99375 .4 m
1 .4 L
s
.99375 .5 m
1 .5 L
s
.99375 .6 m
1 .6 L
s
.99375 .7 m
1 .7 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .125 m
1 .125 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .225 m
1 .225 L
s
.99625 .25 m
1 .25 L
s
.99625 .275 m
1 .275 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .375 m
1 .375 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .625 m
1 .625 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .725 m
1 .725 L
s
.25 Mabswid
1 0 m
1 .75 L
s
0 0 m
1 0 L
1 .75 L
0 .75 L
closepath
clip
newpath
.5 Mabswid
.25 0 m
.68879 .23971 L
.44908 .6785 L
.25 0 L
s
.34954 .33925 m
.58943 .26887 L
s
.54555 .2449 m
.58943 .26887 L
.56546 .31275 L
s
gsave
.44908 .6785 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(<) show
67.812500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
72.375000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
76.937500 14.437500 moveto
(8) show
81.750000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
86.312500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
95.437500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
100.000000 14.437500 moveto
(<) show
104.812500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.68879 .23971 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(<) show
67.812500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
72.375000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
76.937500 14.437500 moveto
(8) show
81.750000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
86.312500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
95.437500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
100.000000 14.437500 moveto
(<) show
104.812500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.38164 .07191 -62.8124 -2.3402 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.17809 .13164 -62.8124 -2.3402 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.25 0 -62.8124 -2.3402 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
67.562500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.38164 .07191 m
.25 0 L
.17809 .13164 L
s
.3625 .04437 m
.38164 .07191 L
.34812 .07069 L
s
.17931 .09812 m
.17809 .13164 L
.20563 .1125 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{264, 198},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000480000aQ000`40O003h00Oogoo2Goo003oOol9
Ool00?moo`Uoo`00ogoo2Goo000ZOol00`00Oomoo`02Ool01000Oomoogoo0`000goo00<007ooOol0
3goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol04Goo1@004Woo1@000Woo00@007ooOomoo`<000=oo`03001o
ogoo00aoo`D0009oo`03001oogoo009oo`03001oogoo00eoo`D0009oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo019oo`<000=oo`00:Goo00<007oo00001goo00<007ooOol00Woo00<007oo
00003goo00<007oo00001goo00<007oo00003Woo00<007oo000027oo00L007ooOomoo`00Ool0000D
Ool00`00Oomoo`0DOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool0000?Ool00`00Oomoo`06
Ool00`00Ool0000@Ool00`00Oomoo`07Ool01`00Oomoogoo001oo`0001=oo`03001oogoo00=oo`00
:Goo00<007oo000027oo00<007ooOol00goo00<007ooOol03Goo00<007oo00002Goo00<007ooOol0
37oo00<007oo000027oo00<007ooOol00goo00<007ooOol04Woo00<007ooOol057oo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol03Goo00<007ooOol027oo00<007ooOol03Woo00<007ooOol0
1goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00Woo000YOol00`00Ool00008Ool01000
Oomoogoo0P0047oo00<007oo00001goo0P003goo00<007oo00002Goo00<007ooOol00P005Goo00<0
07ooOol057oo00<007ooOol01goo00@007ooOomoo`80011oo`03001oogoo00Ioo`80015oo`03001o
ogoo00Qoo`03001oogoo008001Eoo`03001oogoo009oo`00:Goo00<007oo00001goo00<007oo0000
0Woo00<007ooOol03goo00<007oo00001goo00<007ooOol03Woo00<007oo00001goo00<007oo0000
0Woo00<007ooOol057oo00<007ooOol057oo00<007ooOol01Woo00<007oo00000Woo00<007ooOol0
3goo00<007ooOol01Woo00<007ooOol047oo00<007ooOol01Woo00<007oo00000Woo00<007ooOol0
4goo00<007oo00000goo000ZOol00`00Oomoo`07Ool01000Oomoogoo0`0047oo00<007ooOol01Woo
0`003goo00<007ooOol01Woo0`000Woo0`004goo0P005Goo0P002Goo00@007ooOomoo`<000ioo`80
00Qoo`<000moo`8000Qoo`<0009oo`<001Aoo`03001oogoo009oo`00ogoo2Goo003oOol9Ool00?mo
o`Uoo`00ogoo2Goo003oOol9Ool001Aooo4000=oo`0057oo00<007ooOol00goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo10000goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Goo000DOol00`00Oomoo`0KOol0
0`00Oomoo`0JOol300000goo0000000IOol00`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`0K
Ool00`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomoo`01Ool001Aoo`03001oogoo03Moo`04001o
ogoo0003Ool2002]Ool00`00Oomoo`01Ool001Aoo`03001oogoo03Moo`04001oogoo0005Ool2002[
Ool00`00Oomoo`01Ool001Aoo`03001oogoo03Ioo`05001oogooOol00006Ool2002ZOol00`00Oomo
o`01Ool001Aoo`8003Moo`03001oogoo009oo`03001oogoo00Eoo`800:Moo`8000=oo`0057oo00<0
07ooOol0=Goo00<007ooOol00goo00<007ooOol01goo0P00YWoo00<007ooOol00Goo000DOol00`00
Oomoo`0eOol00`00Oomoo`02Ool3000:Ool2002TOol00`00Oomoo`01Ool001Aoo`03001oogoo03Ao
o`03001oogoo00=oo`<000aoo`800:9oo`03001oogoo005oo`0057oo00<007ooOol0=7oo00<007oo
Ool01Goo00<007ooOol02goo0`00X7oo00<007ooOol00Goo000DOol00`00Oomoo`0cOol00`00Oomo
o`06Ool00`00Oomoo`0=Ool20006Ool00`00Oomoo`2FOol00`00Oomoo`01Ool001Aoo`8003Aoo`03
001oogoo00Aoo`@0011oo`8000Eoo`03001oogoo09Aoo`8000=oo`0057oo00<007ooOol0<Woo00<0
07ooOol027oo00<007ooOol047oo0P000goo00<007ooOol0UGoo00<007ooOol00Goo000DOol00`00
Oomoo`0bOol00`00Oomoo`08Ool00`00Oomoo`0AOol30002Ool00`00Oomoo`2DOol00`00Oomoo`01
Ool001Aoo`03001oogoo035oo`03001oogoo00Uoo`03001oogoo01=oo`<00003Ool007oo09Aoo`03
001oogoo005oo`0057oo00<007ooOol0<7oo00<007ooOol02goo00<007ooOol057oo0P0000=oo`00
Ool0Tgoo00<007ooOol00Goo000DOol00`00Oomoo`0`Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool4
0002Ool2002DOol00`00Oomoo`01Ool001Aoo`80031oo`03001oogoo00aoo`03001oogoo01Aoo`H0
095oo`8000=oo`0057oo00<007ooOol0;goo00<007ooOol03Goo00<007ooOol06Goo0P00T7oo00<0
07ooOol00Goo000DOol00`00Oomoo`0^Ool00`00Oomoo`0>Ool00`00Oomoo`0KOol2002>Ool00`00
Oomoo`01Ool001Aoo`03001oogoo02ioo`03001oogoo00ioo`03001oogoo01eoo`03001oogoo08]o
o`03001oogoo005oo`001Goo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001oogoo02eoo`03
001oogoo00moo`03001oogoo01ioo`8008]oo`03001oogoo005oo`0017oo00<007oo00001goo00<0
07ooOol00goo00<007ooOol0;Goo00<007ooOol047oo00<007ooOol07goo0P00RGoo00<007ooOol0
0Goo0004Ool00`00Ool00008Ool00`00Oomoo`02Ool3000XOol01@00Oomoogoo00004goo00<007oo
Ool08Goo0P00QGoo0`000goo0004Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`0XOol0
1@00Oomoogoo00004goo00<007ooOol05Woo0P0000=oo`00Ool027oo0P00QGoo00<007ooOol00Goo
0004Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0XOol01000Oomoo`005Goo00<007oo
Ool05goo00<007ooOol02Woo00<007ooOol0PWoo00<007ooOol00Goo0005Ool00`00Oomoo`07Ool0
0`00Oomoo`02Ool00`00Oomoo`0XOol01000Oomoo`000goo00<007ooOol03goo00<007ooOol05Woo
00<007oo000037oo0P00PWoo00<007ooOol00Goo000DOol00`00Oomoo`0XOol00`00Ool00002Ool2
000BOol00`00Oomoo`0WOol20020Ool00`00Oomoo`01Ool001Aoo`03001oogoo02Qoo`05001oo`00
Ool0000EOol00`00Oomoo`0XOol2001nOol00`00Oomoo`01Ool001Aoo`8002Uoo`800003Ool007oo
01Eoo`03001oogoo02Yoo`8007]oo`8000=oo`0057oo00<007ooOol0:7oo0`005goo00<007ooOol0
;7oo0P00NWoo00<007ooOol00Goo000DOol00`00Oomoo`0XOol00`00Oomoo`0GOol00`00Oomoo`0^
Ool00`00Oomoo`1gOol00`00Oomoo`01Ool001Aoo`03001oogoo04=oo`03001oogoo02ioo`8007Mo
o`03001oogoo005oo`0057oo00<007ooOol0@goo00<007ooOol0<7oo0P00MGoo00<007ooOol00Goo
000DOol00`00Oomoo`13Ool00`00Oomoo`0bOol2001cOol00`00Oomoo`01Ool001Aoo`8004Eoo`03
001oogoo03=oo`80071oo`8000=oo`0057oo00<007ooOol0:Goo0P006Goo00<007ooOol0=Goo00<0
07ooOol0KWoo00<007ooOol00Goo000DOol00`00Oomoo`0ZOol00`00Oomoo`0GOol00`00Oomoo`0f
Ool2001^Ool00`00Oomoo`01Ool001Aoo`03001oogoo02Yoo`03001oogoo01Moo`03001oogoo03Qo
o`8006aoo`03001oogoo005oo`0057oo00<007ooOol0:Goo00<007oo00006Goo00<007ooOol0>Goo
0P00JWoo00<007ooOol00Goo000DOol00`00Oomoo`0YOol01000Ool0000067oo00<007ooOol0>goo
0P00J7oo00<007ooOol00Goo000DOol20016Ool00`00Oomoo`0mOol00`00Oomoo`1TOol20003Ool0
01Aoo`03001oogoo04Ioo`03001oogoo03eoo`8006Eoo`03001oogoo005oo`0057oo00<007ooOol0
AWoo00<007ooOol0?goo0P00Hgoo00<007ooOol00Goo000DOol00`00Oomoo`16Ool00`00Oomoo`11
Ool2001QOol00`00Oomoo`01Ool000Eoo`03001oogoo009oo`03001oogoo009oo`<0009oo`03001o
ogoo04Moo`03001oogoo049oo`8005moo`03001oogoo005oo`0017oo00<007oo00002Goo00D007oo
Oomoo`0004Uoo`03001oogoo04Aoo`03001oogoo05aoo`03001oogoo005oo`0017oo00<007oo0000
1goo10000Woo0`00Agoo00<007ooOol0AGoo0P00FWoo0`000goo0004Ool00`00Ool00007Ool00`00
Ool00003Ool00`00Oomoo`17Ool00`00Oomoo`17Ool2001JOol00`00Oomoo`01Ool000Aoo`03001o
o`0000Qoo`8000=oo`03001oogoo04Qoo`03001oogoo04Qoo`8005Qoo`03001oogoo005oo`001Goo
00<007ooOol027oo00D007ooOomoo`0004Yoo`03001oogoo04Yoo`8005Ioo`03001oogoo005oo`00
57oo00<007ooOol0B7oo00<007ooOol0C7oo0P00E7oo00<007ooOol00Goo000DOol00`00Oomoo`19
Ool00`00Oomoo`1=Ool00`00Oomoo`1AOol00`00Oomoo`01Ool001Aoo`8004Yoo`03001oogoo04io
o`8001Qoo`8001Aoo`80021oo`8000=oo`0057oo00<007ooOol0BGoo00<007ooOol0D7oo0P0047oo
00<007ooOol00goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol07goo00<007ooOol00Goo
000DOol00`00Oomoo`19Ool00`00Oomoo`1BOol20007Ool00`00Oomoo`0300000goo00000004Ool0
1000Oomoogoo0`0000=oo`00000027oo0`000Woo00<007ooOol07goo00<007ooOol00Goo000DOol0
0`00Oomoo`1:Ool00`00Oomoo`1COol20003Ool20003Ool20007Ool00`00Oomoo`03Ool00`00Oomo
o`0:Ool00`00Ool00003Ool00`00Oomoo`0NOol00`00Oomoo`01Ool001Aoo`03001oogoo04Yoo`03
001oogoo05Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo00Yoo`03001oo`00009oo`03001oogoo01moo`03001oogoo005oo`0057oo00<007ooOol0
BWoo00<007ooOol0<goo00<007ooOol07Woo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol02Woo00<007oo00000Woo00<007ooOol07goo00<007ooOol00Goo000DOol2001<
Ool00`00Oomoo`0cOol2000NOol00`00Oomoo`06Ool30007Ool20002Ool2000<Ool300000goo0000
000POol20003Ool001Aoo`03001oogoo04]oo`03001oogoo03Eoo`8001]oo`03001oogoo04Yoo`03
001oogoo005oo`0057oo00<007ooOol0Bgoo00<007ooOol0=goo00<007ooOol067oo00<007ooOol0
BWoo00<007ooOol00Goo000DOol00`00Oomoo`1<Ool00`00Oomoo`0gOol2000GOol00`00Oomoo`1;
Ool00`00Oomoo`01Ool001Aoo`03001oogoo04aoo`03001oogoo03Uoo`8001Eoo`03001oogoo04]o
o`03001oogoo005oo`0057oo00<007ooOol0C7oo00<007ooOol0>Woo0P004goo00<007ooOol0C7oo
00<007ooOol00Goo000DOol2001=Ool00`00Oomoo`0fOol5000DOol00`00Oomoo`1;Ool20003Ool0
01Aoo`03001oogoo04eoo`03001oogoo039oo`<000Aoo`03001oogoo015oo`03001oogoo04eoo`03
001oogoo005oo`0057oo00<007ooOol0CGoo00<007ooOol0;Woo10001Woo00<007ooOol04Woo00<0
07ooOol0CGoo00<007ooOol00Goo000DOol00`00Oomoo`1=Ool00`00Oomoo`0ZOol4000:Ool00`00
Oomoo`0AOol00`00Oomoo`1>Ool00`00Oomoo`01Ool000Eoo`03001oogoo009oo`04001oogooOol2
0004Ool00`00Oomoo`1>Ool00`00Oomoo`0VOol3000=Ool00`00Oomoo`0AOol00`00Oomoo`1?Ool0
0`00Oomoo`01Ool000Aoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo04ioo`03001oogoo
029oo`@0011oo`03001oogoo015oo`03001oogoo04moo`03001oogoo005oo`0017oo00<007oo0000
1goo00<007oo00000goo0`00CWoo00<007ooOol07goo0`004goo00<007ooOol04Goo00<007ooOol0
CWoo0`000goo0004Ool00`00Ool00007Ool20004Ool00`00Oomoo`1>Ool00`00Oomoo`0KOol4000F
Ool00`00Oomoo`0AOol00`00Oomoo`1@Ool00`00Oomoo`01Ool000Aoo`03001oo`0000Moo`03001o
ogoo00=oo`03001oogoo04moo`03001oogoo01Moo`<001Uoo`03001oogoo015oo`03001oogoo055o
o`03001oogoo005oo`001Goo00<007ooOol01goo0P000goo00<007ooOol0Cgoo00<007ooOol04goo
100077oo00<007ooOol04Goo00<007ooOol0DGoo00<007ooOol00Goo000DOol00`00Oomoo`1?Ool0
0`00Oomoo`0@Ool3000cOol00`00Oomoo`1BOol00`00Oomoo`01Ool001Aoo`03001oogoo051oo`03
001oogoo00]oo`@003Ioo`03001oogoo059oo`03001oogoo005oo`0057oo0P00DGoo00<007ooOol0
1goo1000>Goo00<007ooOol0DWoo0P000goo000DOol00`00Oomoo`1@Ool00`00Oomoo`04Ool3000m
Ool00`00Oomoo`1COol00`00Oomoo`01Ool001Aoo`03001oogoo055oo`03001oo`0000<003moo`03
001oogoo05Aoo`03001oogoo005oo`0057oo00<007ooOol0DGoo0P00@goo00<007ooOol0E7oo00<0
07ooOol00Goo000DOol00`00Oomoo`1AOol00`00Oomoo`11Ool00`00Oomoo`1EOol00`00Oomoo`01
Ool001Aoo`03001oogoo055oo`03001oogoo041oo`03001oogoo05Ioo`03001oogoo005oo`0057oo
0P00Dgoo00<007ooOol0?goo00<007ooOol0EGoo0P000goo000DOol00`00Oomoo`1BOol00`00Oomo
o`0nOol00`00Oomoo`1GOol00`00Oomoo`01Ool001Aoo`03001oogoo059oo`03001oogoo03ioo`03
001oogoo05Moo`03001oogoo005oo`0057oo00<007ooOol0Dgoo00<007ooOol0?7oo00<007ooOol0
F7oo00<007ooOol00Goo000DOol00`00Oomoo`1COol00`00Oomoo`0lOol00`00Oomoo`1HOol00`00
Oomoo`01Ool001Aoo`03001oogoo05=oo`03001oogoo03]oo`03001oogoo05Uoo`03001oogoo005o
o`0057oo0P00EGoo00<007ooOol0>Woo00<007ooOol0F7oo0P000goo000DOol00`00Oomoo`1DOol0
0`00Oomoo`0iOol00`00Oomoo`1JOol00`00Oomoo`01Ool001Aoo`03001oogoo05Aoo`03001oogoo
03Uoo`03001oogoo05Yoo`03001oogoo005oo`0057oo00<007ooOol0E7oo00<007ooOol0>7oo00<0
07ooOol0Fgoo00<007ooOol00Goo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`1EOol00`00Oomoo`0fOol00`00Oomoo`1LOol00`00Oomoo`01Ool000Aoo`03001o
o`0000Moo`03001oo`0000=oo`03001oogoo05Eoo`03001oogoo03Ioo`03001oogoo05aoo`03001o
ogoo005oo`0017oo00<007oo00001goo00<007oo00000goo0`00EGoo00<007ooOol0=Goo00<007oo
Ool0Fgoo0`000goo0004Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`1FOol00`00Oomo
o`0dOol00`00Oomoo`1MOol00`00Oomoo`01Ool000Aoo`03001oo`0000Moo`03001oo`0000=oo`03
001oogoo05Ioo`03001oogoo03=oo`03001oogoo05ioo`03001oogoo005oo`001Goo00<007ooOol0
1goo00<007ooOol00Woo00<007ooOol0EWoo00<007ooOol0<goo00<007ooOol0GWoo00<007ooOol0
0Goo000DOol00`00Oomoo`1FOol00`00Oomoo`0bOol00`00Oomoo`1OOol00`00Oomoo`01Ool001Ao
o`03001oogoo05Moo`03001oogoo035oo`03001oogoo05moo`03001oogoo005oo`0057oo0P00F7oo
00<007ooOol0<7oo00<007ooOol0Ggoo0P000goo000DOol00`00Oomoo`1GOol00`00Oomoo`0`Ool0
0`00Oomoo`1POol00`00Oomoo`01Ool001Aoo`03001oogoo05Qoo`03001oogoo02ioo`03001oogoo
065oo`03001oogoo005oo`0057oo00<007ooOol0F7oo00<007ooOol0;Goo00<007ooOol0HWoo00<0
07ooOol00Goo000DOol00`00Oomoo`1HOol00`00Oomoo`0]Ool00`00Oomoo`1ROol00`00Oomoo`01
Ool001Aoo`03001oogoo05Uoo`03001oogoo02]oo`03001oogoo06=oo`03001oogoo005oo`0057oo
0P00FWoo00<007ooOol0:goo00<007ooOol0HWoo0P000goo000DOol00`00Oomoo`1IOol00`00Oomo
o`0ZOol00`00Oomoo`1TOol00`00Oomoo`01Ool001Aoo`03001oogoo05Uoo`03001oogoo02Yoo`03
001oogoo06Aoo`03001oogoo005oo`0057oo00<007ooOol0FWoo00<007ooOol0:7oo00<007ooOol0
IGoo00<007ooOol00Goo000DOol00`00Oomoo`1JOol00`00Oomoo`0XOol00`00Oomoo`1UOol00`00
Oomoo`01Ool001Aoo`03001oogoo05Yoo`03001oogoo02Moo`03001oogoo06Ioo`03001oogoo005o
o`0057oo0P00G7oo00<007ooOol09Woo00<007ooOol0IGoo0P000goo000DOol00`00Oomoo`1KOol0
0`00Oomoo`0UOol00`00Oomoo`1WOol00`00Oomoo`01Ool001Aoo`03001oogoo05]oo`03001oogoo
02Eoo`03001oogoo06Moo`03001oogoo005oo`0057oo00<007ooOol0Fgoo00<007ooOol097oo00<0
07ooOol0J7oo00<007ooOol00Goo000=Ool50002Ool00`00Oomoo`1LOol00`00Oomoo`0ROol00`00
Oomoo`1YOol00`00Oomoo`01Ool000moo`03001oogoo009oo`03001oogoo05aoo`03001oogoo029o
o`03001oogoo06Uoo`03001oogoo005oo`003goo00<007ooOol00Woo0`00G7oo00<007ooOol08Goo
00<007ooOol0J7oo0`000goo000?Ool00`00Oomoo`02Ool00`00Oomoo`1MOol00`00Oomoo`0POol0
0`00Oomoo`1ZOol00`00Oomoo`01Ool000moo`03001oogoo009oo`03001oogoo05eoo`03001oogoo
01moo`03001oogoo06]oo`03001oogoo005oo`003Woo0P0017oo00<007ooOol0GGoo00<007ooOol0
7goo00<007ooOol0Jgoo00<007ooOol00Goo000DOol00`00Oomoo`1NOol00`00Oomoo`0MOol00`00
Oomoo`1/Ool00`00Oomoo`01Ool001Aoo`03001oogoo05ioo`03001oogoo01eoo`03001oogoo06ao
o`03001oogoo005oo`0057oo0P00Ggoo00<007ooOol077oo00<007ooOol0K7oo0P000goo000DOol0
0`00Oomoo`1NOol00`00Oomoo`0LOol00`00Oomoo`1]Ool00`00Oomoo`01Ool001Aoo`03001oogoo
05moo`03001oogoo01Yoo`03001oogoo06ioo`03001oogoo005oo`0057oo00<007ooOol0Ggoo00<0
07ooOol06Goo00<007ooOol0Kgoo00<007ooOol00Goo000DOol00`00Oomoo`1OOol00`00Oomoo`0I
Ool00`00Oomoo`1_Ool00`00Oomoo`01Ool001Aoo`03001oogoo061oo`03001oogoo01Moo`03001o
ogoo071oo`03001oogoo005oo`0057oo0P00HGoo00<007ooOol05goo00<007ooOol0Kgoo0P000goo
000DOol00`00Oomoo`1POol00`00Oomoo`0FOol00`00Oomoo`1aOol00`00Oomoo`01Ool001Aoo`03
001oogoo061oo`03001oogoo01Ioo`03001oogoo075oo`03001oogoo005oo`0057oo00<007ooOol0
HGoo00<007ooOol057oo00<007ooOol0LWoo00<007ooOol00Goo000DOol00`00Oomoo`1QOol00`00
Oomoo`0DOol00`00Oomoo`1bOol00`00Oomoo`01Ool001Aoo`03001oogoo065oo`03001oogoo01=o
o`03001oogoo07=oo`03001oogoo005oo`0057oo0P00Hgoo00<007ooOol04Woo00<007ooOol0LWoo
0P000goo000DOol00`00Oomoo`1ROol00`00Oomoo`0AOol00`00Oomoo`1dOol00`00Oomoo`01Ool0
01Aoo`03001oogoo069oo`03001oogoo011oo`03001oogoo07Eoo`03001oogoo005oo`0057oo00<0
07ooOol0Hgoo00<007ooOol03goo00<007ooOol0MGoo00<007ooOol00Goo0003Ool50002Ool01000
Oomoogoo0`000goo00<007ooOol0Hgoo00<007ooOol03Woo00<007ooOol0MWoo00<007ooOol00Goo
0005Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`1SOol00`00Oomoo`0>Ool00`00Oomo
o`1fOol00`00Oomoo`01Ool000Eoo`03001oogoo00Moo`03001oogoo009oo`<006=oo`03001oogoo
00eoo`03001oogoo07Eoo`<000=oo`001Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
I7oo00<007ooOol037oo00<007ooOol0Mgoo00<007ooOol00Goo0005Ool00`00Oomoo`06Ool00`00
Ool00003Ool00`00Oomoo`1TOol00`00Oomoo`0;Ool00`00Oomoo`1hOol00`00Oomoo`01Ool000Ao
o`8000Uoo`03001oogoo009oo`03001oogoo06Aoo`03001oogoo00]oo`03001oogoo07Qoo`03001o
ogoo005oo`0057oo00<007ooOol0IGoo00<007ooOol02Goo00<007ooOol0NGoo00<007ooOol00Goo
000DOol00`00Oomoo`1UOol00`00Oomoo`09Ool00`00Oomoo`1iOol00`00Oomoo`01Ool001Aoo`80
06Ioo`03001oogoo00Qoo`03001oogoo07Uoo`8000=oo`0057oo00<007ooOol0IGoo00<007ooOol0
27oo00<007ooOol0NWoo00<007ooOol00Goo000DOol00`00Oomoo`1VOol00`00Oomoo`06Ool00`00
Oomoo`1kOol00`00Oomoo`01Ool001Aoo`03001oogoo06Ioo`03001oogoo00Eoo`03001oogoo07ao
o`03001oogoo005oo`0057oo00<007ooOol0IWoo00<007ooOol01Goo00<007ooOol0O7oo00<007oo
Ool00Goo000DOol00`00Oomoo`1WOol00`00Oomoo`03Ool00`00Oomoo`1mOol00`00Oomoo`01Ool0
01Aoo`8006Qoo`03001oogoo00=oo`03001oogoo07aoo`8000=oo`0057oo00<007ooOol0Igoo00<0
07ooOol00Woo00<007ooOol0OWoo00<007ooOol00Goo000DOol00`00Oomoo`1XOol01@00Oomoogoo
0000P7oo00<007ooOol00Goo000DOol00`00Oomoo`1XOol01000Oomoo`003goo0P0057oo0P00FWoo
00<007ooOol00Goo000DOol00`00Oomoo`1XOol01000Oomoo`002Goo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol037oo00<007ooOol0F7oo00<007ooOol00Goo000DOol00`00Oomoo`1XOol0
0`00Ool00003Ool00`00Oomoo`0300000goo00000004Ool01000Oomoogoo0`0000=oo`0000001goo
0`000goo00<007ooOol0F7oo00<007ooOol00Goo000DOol2001ZOol200000goo00000003Ool20007
Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`1FOol20003Ool001Ao
o`03001oogoo06Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009o
o`03001oogoo00Yoo`03001oogoo009oo`03001oogoo05Qoo`03001oogoo005oo`0057oo00<007oo
Ool0Lgoo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007oo
Ool0F7oo00<007ooOol00Goo000DOol00`00Oomoo`1aOol30007Ool20002Ool2000;Ool20003Ool2
001JOol00`00Oomoo`01Ool000=oo`D0009oo`03001oogoo009oo`<0009oo`03001oogoo0>eoo`03
001oogoo005oo`001Goo00<007ooOol027oo00D007ooOomoo`000>moo`03001oogoo005oo`001Goo
00<007ooOol01Woo10000Woo0`00jgoo0`000goo0005Ool00`00Oomoo`06Ool00`00Ool00003Ool0
0`00Oomoo`3]Ool00`00Oomoo`01Ool000Eoo`03001oogoo00Moo`8000=oo`03001oogoo0>eoo`03
001oogoo005oo`0017oo0P002Woo00D007ooOomoo`000>moo`03001oogoo005oo`0057oo00<007oo
Ool0kGoo00<007ooOol00Goo000DOol00`00Oomoo`3]Ool00`00Oomoo`01Ool001Aoo`800>eoo`80
00=oo`0057oo00<007ooOol0kGoo00<007ooOol00Goo000DOol00`00Oomoo`3]Ool00`00Oomoo`01
Ool001Aoo`03001oogoo0>eoo`03001oogoo005oo`0057oo00<007ooOol06goo00<007ooOol06goo
00<007ooOol06goo00<007ooOol06goo00<007ooOol06goo00<007ooOol06goo00<007ooOol06goo
00<007ooOol06goo00<007ooOol00Goo000DOol00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`01Ool001Aooo4000=oo`00ogoo2Goo
003oOol9Ool00001\
\>"],
  ImageRangeCache->{{{0, 263}, {197, 0}} -> {-0.175631, -0.124389, 0.00836785,
   0.00836785}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LocusPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules1, rules2, ..., rulesn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives representing a series of line segments connecting the \
location of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", when subject to ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A function for plotting the locus of a moving point."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The nested list of rules required by ",
  StyleBox["LocusPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is of the form returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " when given a range of times at which to seek solutions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism Graphics"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The quick-return mechanism model that was developed in Section 3.1 is used \
to demonstrate the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions. The model is redefined as follows in abbreviated \
form."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["The complete quick-return model.", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(drivearm = 3; \)\), 
    \(\(slider = 4; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      Body[ground, 
        PointList \[Rule] {{0, 0}, {0, 5}, {\(-5\), 10}, {12, 10}}], \n\t
      Body[crank, PointList \[Rule] {{0, 0}, {3, 0}}, 
        InitialGuess \[Rule] {{0, 5}, 0}], \n\t
      Body[drivearm, PointList \[Rule] {{0, 0}, {0, 9}}, 
        InitialGuess \[Rule] {{0, 0}, \(-0.5\)}], \n\t
      Body[slider, PointList \[Rule] {{0, 0}, {3, 0}}, 
        InitialGuess \[Rule] {{9, 10}, 0}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRevolute2[1, Point[ground, 2], Point[crank, 1]], \n\t
      RotationLock1[2, crank, 2.0  \[Pi]\ T], \n\t
      Revolute2[3, Point[ground, 1], Point[drivearm, 1]], \n\t
      PointOnLine1[4, Point[crank, 2], Line[drivearm, 1, 2]], \n\t
      RelativeDistance1[5, \n\t\tPoint[drivearm, 2], Point[slider, 1], 5.0], 
      \n\tTranslate2[6, Line[ground, 3, 4], Line[slider, 1, 2]]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "To demonstrate the use of the graphics functions, the image of the \
quick-return mechanism that was displayed in the preceding sections is built. \
These images are generated with a mix of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions and built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Ground"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ground body of the quick-return mechanism is generated using ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions even though it does not move. This is done to take \
advantage of the easy referencing of local point coordinates that were \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Note that the ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function in the following graphic references points either by their {",
  StyleBox["x, y",
    FontSlant->"Italic"],
  "} coordinates or by their local point numbers interchangeably."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the ground body graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(groundgraphic = 
      Graphics[{\n\t\t\tThickness[.01], Point[{0, 0}], \n\t\t\t
          Edge[ground, {3, 
              4, {12, 0}, {\(-5\), 0}, {\(-5\), 10}, {\(-5\), 8}, 
              2, {\(-5\), 2}}]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The text that is shown with the ground body is generated entirely with the \
built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Text",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the ground body graphic annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(groundtext = 
      Graphics[{\n\t\t\tText["\<{0,0}\>", {0, 0}, {0, 1.8}], \n\t\t\t
          Text["\<P1\>", {0, 0}, {0, \(-1.8\)}], \n\t\t\t
          Text["\<{0,5}\>", {0, 5}, {\(-1.4\), 0}], \n\t\t\t
          Text["\<P2\>", {0, 5}, {3.0, 0}], \n\t\t\t
          Text["\<{-5,10}\>", {\(-5\), 10}, {\(-0.7\), \(-1.8\)}], \n\t\t\t
          Text["\<P3\>", {\(-5\), 10}, {\(-1.6\), 1.8}], \n\t\t\t
          Text["\<{12,10}\>", {12, 10}, {0.7, \(-1.8\)}], \n\t\t\t
          Text["\<P4\>", {12, 10}, {1.6, 1.8}], \n\t\t\t
          Text[FontForm["\<Ground\>", {"\<Times-Bold\>", 12}], \n
            \t\t\t\t{7, 5}]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot1 = 
      Show[{groundgraphic, groundtext}, 
        PlotRange \[Rule] {{\(-6\), 15}, {\(-2\), 12}}, 
        AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.0952381 0.047619 [
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
0 g
.008 w
.28571 .09524 Mdot
.01 w
.04762 .57143 m
.85714 .57143 L
.85714 .09524 L
.04762 .09524 L
.04762 .57143 L
.04762 .47619 L
.28571 .33333 L
.04762 .19048 L
s
gsave
.28571 .09524 -78 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.28571 .09524 -69 2 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P1) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.28571 .33333 -54.2 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.28571 .33333 -93 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P2) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.04762 .57143 -67.9 2 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
87.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 14.437500 moveto
(<) show
105.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.04762 .57143 -56.2 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P3) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.85714 .57143 -100.1 2 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
87.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 14.437500 moveto
(<) show
105.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.85714 .57143 -81.8 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P4) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.61905 .33333 -84 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ground) show
104.250000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{270.813, 180.5},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>0000]1000`40O003h00Oogoo3goo003oOol?
Ool00?moo`moo`00ogoo3goo003oOol?Ool00?moo`moo`00ogoo3goo003oOol?Ool0049oo`03001o
ogoo019oo`03001oogoo0;Aoo`00@Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol0/goo
0011Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomo
o`2cOol0045oo`07001oogooOol007oo00001Goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`2c
Ool0041oo`03001oogoo009oo`03001oo`0000Uoo`03001oo`0000Eoo`03001oogoo0;9oo`00@Goo
00L007ooOomoo`00Ool00009Ool00`00Ool00004Ool00`00Oomoo`2cOol0045oo`07001oogooOol0
07oo00002Goo00<007oo000017oo00<007ooOol0/goo0012Ool01@00Oomoogoo00002goo00<007oo
Ool00Woo00<007ooOol0]7oo003oOol?Ool00?moo`moo`00ogoo3goo003oOol?Ool00?moo`moo`00
ogoo3goo003oOol?Ool00?moo`moo`00ogoo3goo003oOol?Ool000aoom`002Ioo`0037oog0009Woo
000<Ool2003HOol2000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2003H
Ool2000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2003HOol2000VOol0
00aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2000iOol30002Ool5002EOol2000V
Ool000aoo`8003Yoo`03001oogoo00=oo`03001oogoo09Eoo`8002Ioo`0037oo0P00>Woo0`000goo
00<007ooOol0UGoo0P009Woo000<Ool2000jOol01000Oomoo`000Woo00<007ooOol0UGoo0P009Woo
000<Ool2000jOol01000Oomoo`000Woo00<007ooOol0UGoo0P009Woo000<Ool2000iOol40002Ool2
002GOol2000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2003HOol2000V
Ool000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2003HOol2000VOol000aoo`80
0=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool4003FOol2000VOol000aoo`D00=Eoo`8002Io
o`0037oo0P0000=oo`0000000P00dgoo0P009Woo000<Ool20002Ool5003AOol2000VOol000aoo`80
00Aoo`@00=1oo`8002Ioo`0037oo0P001Woo1000cWoo0P009Woo000<Ool20007Ool4003=Ool2000V
Ool000aoo`8000Uoo`@00<]oo`8002Ioo`0037oo0P002Woo1@00bGoo0P009Woo000<Ool2000<Ool4
0038Ool2000VOol000aoo`8000ioo`@00<Ioo`8002Ioo`0037oo0P003goo1@00a7oo0P009Woo000<
Ool2000AOol40033Ool2000VOol000aoo`8001=oo`@00<5oo`8002Ioo`0037oo0P0057oo1@00_goo
0P009Woo000<Ool2000FOol4002nOol2000VOol000aoo`8001Qoo`@00;aoo`8002Ioo`0037oo0P00
6Goo1@00^Woo0P009Woo000<Ool2000KOol4002iOol2000VOol000aoo`8001eoo`@00;Moo`8002Io
o`0037oo0P007Woo1000]Woo0P009Woo000<Ool2000POol4002dOol2000VOol000aoo`80025oo`D0
0;9oo`8002Ioo`0037oo0P008goo1000/Goo0P009Woo000<Ool2000UOol4002_Ool2000VOol000ao
o`8002Ioo`D00:eoo`8002Ioo`0037oo0P00:7oo1000[7oo0P009Woo000<Ool2000ZOol4002ZOol2
000VOol000aoo`8002]oo`D00:Qoo`8002Ioo`0037oo0P00;Goo1000Ygoo0P009Woo000<Ool2000_
Ool4002UOol2000VOol000aoo`80031oo`D00:=oo`8002Ioo`0037oo0P00<Woo1000XWoo0P009Woo
000<Ool2000dOol4002POol2000VOol000aoo`8003Eoo`@009moo`8002Ioo`0037oo0P00=goo1000
4Goo00<007ooOol04Woo00<007ooOol0M7oo0P009Woo000<Ool2000hOol5000>Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`1cOol2000VOol000aoo`80025oo`<000=oo`<0011oo`@000eo
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo025o
o`@0009oo`@0009oo`<000Aoo`P00005Ool00000001oo`05000]Ool2000VOol000aoo`80029oo`03
001oogoo009oo`03001oogoo019oo`@000]oo`07001oogooOol007oo00001Goo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`0POol20002Ool20002Ool20002Ool200000goo00000002Ool200000goo
00000002Ool2000017oo000007oo0P0000=oo`000000;Woo0P009Woo000<Ool2000ROol30003Ool0
0`00Oomoo`0BOol40009Ool00`00Oomoo`02Ool00`00Ool0000;Ool00`00Oomoo`03Ool00`00Oomo
o`0NOol20003Ool20002Ool20002Ool200000goo00000002Ool200000goo00000002Ool2000017oo
000007oo0P0000=oo`000000;Woo0P009Woo000<Ool2000ROol01000Oomoo`000Woo00<007ooOol0
4Goo10002goo00L007ooOomoo`00Ool00009Ool20005Ool00`00Oomoo`0OOol20002Ool400000goo
00000002Ool200000goo00000002Ool200000goo00000002Ool2000017oo000007oo0P0000=oo`00
0000;Woo0P009Woo000<Ool2000ROol02000Oomoo`00Ool007oo000@Ool4000=Ool01`00Oomoogoo
001oo`0000Uoo`03001oogoo00Aoo`03001oogoo01moo`8000Moo`800005Ool00000001oo`020002
Ool200000goo00000002Ool2000017oo000007oo0P0000=oo`000000;Woo0P009Woo000<Ool2000Q
Ool40003Ool00`00Oomoo`0=Ool5000?Ool01@00Oomoogoo00002Woo0`000goo00<007ooOol087oo
0P001Woo1@0000Aoo`000000009oo`<00004Ool00000Ool50003Ool4000^Ool2000VOol000aoo`80
03Moo`@004Uoo`8000Aoo`03001oogoo01]oo`8002ioo`8002Ioo`0037oo0P00=Goo1000C7oo0P00
0Woo0P007Goo0P00;Woo0P009Woo000<Ool2000cOol5001>Ool300000goo001oo`0KOol3000^Ool2
000VOol000aoo`80039oo`@00:9oo`8002Ioo`0037oo0P00<7oo1000Y7oo0P009Woo000<Ool2000^
Ool5002UOol2000VOol000aoo`8002aoo`D00:Moo`8002Ioo`0037oo0P00:goo1000ZGoo0P009Woo
000<Ool2000YOol4002[Ool2000VOol000aoo`8002Moo`D00:aoo`8002Ioo`0037oo0P009Woo1000
[Woo0P009Woo000<Ool2000TOol4002`Ool2000VOol000aoo`80029oo`D00;5oo`8002Ioo`0037oo
0P008Goo1000/goo0P009Woo000<Ool2000OOol4002eOol2000VOol000aoo`8001eoo`D00;Ioo`80
02Ioo`0037oo0P0077oo1000^7oo0P009Woo000<Ool2000JOol4002jOol2000VOol000aoo`8001Qo
o`D00;]oo`8002Ioo`0037oo0P005goo1000_Goo0P009Woo000<Ool2000EOol4002oOol2000VOol0
00aoo`8001=oo`D00<1oo`8002Ioo`0037oo0P004Woo1000`Woo0P009Woo000<Ool2000@Ool40034
Ool2000VOol000aoo`8000ioo`D00<Eoo`8002Ioo`0037oo0P0037oo1@00agoo0P009Woo000<Ool2
000;Ool40039Ool2000VOol000aoo`8000Uoo`@00<]oo`8002Ioo`0037oo0P001goo1@00c7oo0P00
9Woo000<Ool20006Ool4003>Ool2000VOol000aoo`8000Aoo`@00=1oo`8002Ioo`0037oo0P000Woo
1@00dGoo0P009Woo000<Ool200000goo00000002003COol2000VOol000aoo`D00=Eoo`8002Ioo`00
37oo1000eWoo0P009Woo000<Ool2003HOol2000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo
0P009Woo000<Ool2003HOol2000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<
Ool2003HOol2000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool20005Ool3
0003Ool2002iOol30004Ool30008Ool2000VOol000aoo`8000Ioo`03001oogoo00Aoo`03001oogoo
0;Moo`03001oogoo00Aoo`03001oogoo00Moo`8002Ioo`0037oo0P001Woo0`000goo00<007ooOol0
^7oo0`000Woo100027oo0P009Woo000<Ool20006Ool01000Oomoo`000goo00<007ooOol0]goo00P0
07ooOol007oo001oo`002Goo0P009Woo000<Ool20006Ool02000Oomoo`00Ool007oo002iOol01000
Oomoo`000Woo0P002Goo0P009Woo000<Ool20005Ool40003Ool00`00Oomoo`2gOol40004Ool00`00
Oomoo`07Ool2000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2003HOol2
000VOol000aoo`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2003HOol2000VOol000ao
o`800=Qoo`8002Ioo`0037oo0P00f7oo0P009Woo000<Ool2003HOol2000VOol000aoo`800=Qoo`80
02Ioo`0037oog0009Woo000<OooL000VOol00?moo`moo`00ogoo3goo003oOol?Ool00?moo`moo`00
ogoo3goo003oOol?Ool00?moo`moo`0037oo00<007ooOol07Woo00<007ooOol0UGoo00<007ooOol0
7Woo00<007ooOol09Goo000;Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`2COol00`00
Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0TOol000]oo`03001oogoo00Qoo`03001oogoo00=o
o`04001oogooOol50002Ool00`00Oomoo`04Ool00`00Oomoo`2COol00`00Oomoo`05000017oo0000
00001Goo00@007ooOomoo`D0009oo`03001oogoo00Aoo`03001oogoo02Aoo`002goo00@007ooOomo
o`@0009oo`03001oo`0000Eoo`03001oogoo009oo`07001oogooOol007oo00001Goo00<007ooOol0
Tgoo00<007ooOol00Woo00D007ooOomoo`0000Qoo`03001oogoo009oo`07001oogooOol007oo0000
1Goo00<007ooOol097oo000:Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool01`00Oomoogoo001oo`00
00Ioo`03001oogoo095oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Yoo`07001oogoo
Ool007oo00001Woo00<007ooOol08goo000;Ool00`00Oomoo`07Ool2000;Ool01`00Oomoogoo001o
o`0000Eoo`03001oogoo09=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`07001o
ogooOol007oo00001Goo00<007ooOol097oo000;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01`00
Oomoogoo001oo`0000Eoo`03001oogoo09=oo`03001oogoo009oo`07001oogooOol007oo00002goo
00L007ooOomoo`00Ool00005Ool00`00Oomoo`0TOol000aoo`03001oogoo00Ioo`<000Uoo`8000Ao
o`03001oogoo00=oo`03001oogoo09Eoo`03001oogoo008000Aoo`03001oogoo00Uoo`8000Aoo`03
001oogoo00=oo`03001oogoo02Eoo`00ogoo3goo003oOol?Ool00?moo`moo`00ogoo3goo003oOol?
Ool00?moo`moo`00ogoo3goo003oOol?Ool00?moo`moo`00\
\>"],
  ImageRangeCache->{{{0, 269.813}, {179.5, 0}} -> {-6.02209, -2.00007, 
  0.0779957, 0.0779957}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Crank"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The crank graphic uses only built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics functions, with the exception of the ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to plot two local points on the crank, the coordinates of which \
are defined in a body object. Note the use of the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function inside of the ",
  StyleBox["Disk",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " primitives. This places the disks at the correct global coordinates when \
the crank moves."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the crank body graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(crankgraphic = 
      Graphics[{\n\t\t\tThickness[.01], \n
          \t\t\t{RGBColor[1, .6, .6], Disk[Location[crank, 1], 4.0]}, \n
          \t\t\t{RGBColor[1, .4, .4], Disk[Location[crank, 2], .6], \n\t\t\t\t
            Disk[Location[crank, 1], .6]}, \n
          \t\t\t{PointSize[.02], Vertex[crank, {1, 2}]}}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The text that is displayed with the crank graphic also uses the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to specify the global coordinates of the text so that the text \
moves with the crank."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the crank graphic annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cranktext = 
      Graphics[{\n\t\t\tText["\<{0,0}\>", Location[crank, 1], {0, 2.4}], \n
          \t\t\tText["\<P1\>", Location[crank, 1], {0, \(-2.4\)}], \n\t\t\t
          Text["\<{3,0}\>", Location[crank, 2], {0, 2.4}], \n\t\t\t
          Text["\<P2\>", Location[crank, 2], {0, \(-2.4\)}], \n\t\t\t
          Text[FontForm["\<Crank\>", {"\<Times-Bold\>", 12}], \n
            \t\t\t\t{7, 5}]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Because the coordinates of some of the elements in ",
  StyleBox["crankgraphic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["cranktext",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are now functions of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " dependent variables ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule must be applied before they can be displayed. Note the use \
of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the following input."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot2 = 
      Show[{crankgraphic, cranktext} /. SolveMech[0], 
        PlotRange \[Rule] {{\(-6\), 15}, {\(-1\), 12}}, 
        AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
1 .6 .6 r
.28571 .28571 m
.28571 .28571 .19048 0 365.73 arc
F
1 .4 .4 r
.42857 .28571 m
.42857 .28571 .02857 0 365.73 arc
F
.28571 .28571 m
.28571 .28571 .02857 0 365.73 arc
F
0 g
.02 w
.28571 .28571 Mdot
.42857 .28571 Mdot
gsave
.28571 .28571 -78 -29.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.28571 .28571 -69 6.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P1) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42857 .28571 -78 -29.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.42857 .28571 -69 6.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P2) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.61905 .28571 -79.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Crank) show
95.750000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00
ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00
ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo0019Ool=OW?3Ool0045ooaenLk]oo`00?goo8Wic
^7oo000lOolWOW>fOol003YoobanLk=oo`00=goo<Gic/Goo000eOoleOW>_Ool003AoocQnLjeoo`00
<goo>Wic[7oo000aOolnOW>ZOol0031ood1nLjUoo`00;Woo@gicZ7oo000/Oom7OW>VOol002]oodUn
LjEoo`00:WooBgicY7oo000ZOom<OW>SOol002UoodinLj9oo`00:7ooD7icXGoo000WOomAOW>QOol0
02Iooe=nLj1oo`009GooEGicWgoo000UOomFOW>NOol002AooeQnLieoo`0097ooFGicW7oo000SOomJ
OW>LOol0029ooe]nLiaoo`008WooG7icVgoo000QOomMOW>KOol0025ooeinLiYoo`0087ooH7icVGoo
000POolUOW<00`00OW=nL`0BOW<00`00OW=nL`0@OW<00`00OW=nL`0AOW<00goo001oo`2EOol0021o
obAnL`03001nLgic00QnL`03001nLgic00UnL`03001nLgic00inL`03001nLgic00QnL`03001nLgic
00MnL`9oo`03001oogoo09=oo`007goo9Gic00<007icOW<00Wic00<007icOW<00gic00<007icOW<0
0gic00<007icOW<00gic00<007icOW<03Wic00@007icOW=nL`8000EnL`03001nLgic00=nL`04001n
LgicOW<2Ool00`00Oomoo`2COol001moobEnL`07001nLgicOW<007ic00001Gic00L007icOW=nL`00
OW<00004OW<00`00OW=nL`0>OW<00`00OW=nL`03OW<00`00OW=nL`03OW<01`00OW=nLgic001nL`00
00=nL`03Ool007oo09Aoo`007Woo9Gic00<007icOW<00Wic00<007ic00002Gic00<007ic00001Gic
00<007icOW<037ic00<007icOW<00gic00<007icOW<027ic00<007ic00000gic0Woo00<007ooOol0
TWoo000NOolVOW<01`00OW=nLgic001nL`0000UnL`03001nL`0000AnL`03001nLgic00inL`03001n
Lgic00=nL`03001nLgic00MnL`03001nL`0000=nL`03Ool007oo09Aoo`007Woo9Wic00L007icOW=n
L`00OW<00009OW<00`00OW<00004OW<00`00OW=nL`0>OW<01`00OW=nLgic001nL`0000UnL`03001n
L`0000=nL`03Ool007oo09Aoo`007Goo:7ic00D007icOW=nL`0000]nL`03001nLgic009nL`03001n
Lgic011nL`05001nLgicOW<0000;OW<00`00OW=nL`02OW<00`00Oomoo`2DOol001eoofInLiIoo`00
77ooIgicUWoo000LOomXOW>EOol001aoofQnLiEoo`006gooJGicUGoo000KOomYOW>EOol001]oofUn
LiEoo`006goo<Wic1Gf<8gic1Gf<2gicU7oo000KOol_OW<;OH`MOW<;OH`8OW>DOol001]oobmnL`am
S1anL`amS0MnLiAoo`006goo;Wic3Wf<6Wic3Wf<1WicU7oo000KOol]OW<?OH`IOW<?OH`6OW>DOol0
01YoobinL`mmS1UnL`mmS0InLaYoo`@0009oo`@0009oo`P00003Ool0000000@00004Ool00000001K
Ool001YoobinLa1mS1QnL`mmS0InLaUoo`8000=oo`03001oogoo0080009oo`800003Ool00000009o
o`800003Ool00000009oo`800003Ool0000005aoo`006Woo;Wic1Wf<0P0027f<67ic1Wf<0P001gf<
1Wic67oo0P001goo0P000goo00@007oo0000009oo`800003Ool00000009oo`800003Ool0000005ao
o`006Woo;Wic1Gf<10001gf<67ic1Gf<10001gf<1Gic67oo0P001goo0P0017oo0`000Woo0P0000=o
o`0000000Woo1000GGoo000JOol^OW<5OH`40006OH`IOW<5OH`40006OH`6OW<HOol20007Ool20000
1Goo00000000Ool00P000Woo0P0000=oo`0000000Woo0P0000=oo`00Ool0G7oo000JOol^OW<6OH`2
0007OH`IOW<6OH`20007OH`6OW<HOol20006Ool5000017oo000000000Woo1@000goo0P0000Aoo`00
000005]oo`006goo;Wic3Wf<6Wic3Wf<1Wic67oo0P0017oo00<007ooOol04Woo0P00Ggoo000KOol_
OW<<OH`LOW<<OH`7OW<IOol20002Ool2000DOol2001OOol001]oobmnL`]mS1enL`]mS0QnLaYoo`<0
0003Ool007oo019oo`<005moo`006goo<7ic2Gf<7gic2Gf<2GicU7oo000KOolaOW<7OH`QOW<6OH`:
OW>EOol001]oofUnLiEoo`006gooJGicUGoo000KOomYOW>EOol001aoofQnLiEoo`0077ooIgicUWoo
000MOomVOW>FOol001eoofInLiIoo`007Goo;Gic0`000Wic1@007Wic0`000gic0`001gicUgoo000N
Ool]OW<00`00OW=nL`03OW<00`00OW=nL`0OOW<00`00OW=nL`02OW<00`00OW=nL`07OW>GOol001io
obenL`<000=nL`03001nLgic01mnL`<000=nL`03001nLgic00InLiMoo`007Woo;Gic00@007icOW<0
009nL`03001nLgic01mnL`04001nLgic0002OW<00`00OW=nL`06OW>GOol001moobanL`04001nLgic
0002OW<00`00OW=nL`0OOW<02000OW=nL`00OW<007ic0007OW>GOol001moob]nL`@0009nL`80021n
L`@000=nL`03001nLgic00EnLiQoo`0087ooHGicV7oo000POomPOW>IOol0025ooemnLiUoo`008Goo
GWicVWoo000QOomMOW>KOol0029ooeanLi]oo`008WooFgicW7oo000SOomJOW>LOol002AooeQnLieo
o`009GooEWicWWoo000UOomEOW>OOol002IooeAnLimoo`009gooDWicX7oo000WOomAOW>QOol002Qo
oe1nLj5oo`00:GooCWicXWoo000ZOom;OW>TOol002]oodUnLjEoo`00;7ooAgicYWoo000]Oom5OW>W
Ool002iood=nLjQoo`00<7oo@7icZGoo000aOolnOW>ZOol003=oocUnLjeoo`00=Goo=Gic[goo000f
OolcOW>`Ool003Mooc5nLk5oo`00>Woo;7ic/goo000lOolWOW>fOol003moob9nLkQoo`00@Goo7Gic
^goo0016OolCOW?0Ool004ioo`=nLlQoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003o
OolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYo
o`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003o
OolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYo
o`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003o
OolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-6.02038, -1.00006, 0.0751456, 
  0.0751456}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Drive Arm"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The drive arm graphic uses mostly built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics functions. Note how the ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function are called using local points 1 and 2, while the ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is called with explicit local point coordinate",
  StyleBox["s {0, 2} and {0, 8}. Most ",
    FontFamily->"Times"],
  StyleBox["Mech",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " functions attempt to interpret integers as local point numbers and \
resolve them into coordinates.",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the drive arm graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(drivearmgraphic = 
      Graphics[{\n
          \t\t\t{RGBColor[0, 1, 0], \n\t\t\t\tDisk[Location[ground, 1], 0.6], 
            \n\t\t\t\tDisk[Location[drivearm, 2], 0.6], \n\t\t\t\t
            Bar[Line[drivearm, 1, 2], 0.3, 0.3]}, PointSize[.02], 
          Vertex[drivearm, {1, 2}], Thickness[.01], \n\t\t\t
          Edge[drivearm, {{0, 2}, {0, 8}}]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The text that was displayed with the drive arm graphic also used the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to specify the global coordinates of the text so that the text \
moves with the drive arm."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the drive arm graphic annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(drivearmtext = 
      Graphics[{\n\t\t\tText["\<{0,0}\>", Location[drivearm, 1], {1.6, 0}], \n
          \t\t\tText["\<P1\>", Location[drivearm, 1], {\(-2.6\), 0}], \n\t\t\t
          Text["\<{0,9}\>", Location[drivearm, 2], {1.6, 0}], \n\t\t\t
          Text["\<P2\>", Location[drivearm, 2], {\(-2.6\), 0}], \n\t\t\t
          Text[FontForm["\<Drive Arm\>", {"\<Times-Bold\>", 12}], {7, 5}]}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Like the crank graphic, the coordinates in the drive arm graphic are \
functions of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " dependent variables. Thus, a solution rule must be applied to display the \
graphic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot3 = 
      Show[{drivearmgraphic, drivearmtext} /. SolveMech[0], 
        PlotRange \[Rule] {{\(-6\), 15}, {\(-1\), 12}}, 
        AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
0 1 0 r
.28571 .04762 m
.28571 .04762 .02857 0 365.73 arc
F
.50621 .41512 m
.50621 .41512 .02857 0 365.73 arc
F
.27346 .05497 m
.29796 .04027 L
.51846 .40777 L
.49396 .42247 L
F
0 g
.02 w
.28571 .04762 Mdot
.50621 .41512 Mdot
.01 w
.33471 .12929 m
.48171 .37428 L
s
gsave
.28571 .04762 -105.2 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.28571 .04762 -48.2 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P1) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.50621 .41512 -105.2 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(9) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.50621 .41512 -48.2 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P2) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.61905 .28571 -91.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Drive) show
96.187500 14.437500 moveto
(Arm) show
119.812500 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo001<Ool70n36Ool004Yoo`/3
h<Aoo`00BGoo3@?P`goo000YOol00`00Oomoo`0BOol00`00Oomoo`07Ool?0n32Ool002Qoo`03001o
ogoo00Qoo`03001oogoo00Uoo`03001oogoo00Ioo`l3h<9oo`00:7oo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Woo40?P1Woo0`000Woo1@00/Goo
000XOol01`00Oomoogoo001oo`0000Eoo`07001oogooOol007oo000017oo00<007ooOol01Woo1P?P
0P0020?P1goo00<007ooOol00goo00<007ooOol0/Goo000WOol00`00Oomoo`02Ool00`00Ool00009
Ool00`00Ool00005Ool00`00Oomoo`05Ool50n0400070n07Ool30003Ool00`00Oomoo`2aOol002Qo
o`07001oogooOol007oo00002Goo00<007oo000017oo00<007ooOol01Woo1@?P10001P?P27oo00@0
07ooOol0009oo`03001oogoo0;5oo`00:7oo00L007ooOomoo`00Ool00009Ool00`00Ool00004Ool0
0`00Oomoo`06Ool60n0200070n08Ool01000Oomoo`000Woo00<007ooOol0/Goo000YOol01@00Oomo
ogoo00002goo00<007ooOol00Woo00<007ooOol01goo3`?P1goo10000Woo0P00/goo0019Ool>0n32
Ool004Yoo`h3h<5oo`00Bgoo3@?P`Goo001<Ool=0n30Ool004ioo``3h;moo`00DGoo2@?P_goo001A
Ool:0n2nOol0059oo`T3h;ioo`00Dgoo2@?P_Goo001COol:0n2lOol005Aoo`T3h;aoo`00E7oo2P?P
^goo001EOol90n2kOol005Ioo`T3h;Yoo`00EWoo2P?P^Goo001GOol90n2iOol005Moo`X3h;Qoo`00
F7oo2@?P^7oo001IOol40n000`000n03h0020n2gOol005Uoo`@3h0030003h0?P00<3h;Ioo`00FWoo
0`?P0P0010?P]Woo001JOol40n0200040n2eOol005]oo`@3h0030003h0?P00<3h;Aoo`00G7oo0`?P
0P0010?P]7oo001LOol40n000`000n03h0030n2cOol005eoo`<3h08000@3h;=oo`00GGoo10?P0P00
10?P/Woo001NOol40n000`000n03h0030n2aOol005moo`<3h08000@3h;5oo`00Ggoo10?P00<000?P
0n000`?P/7oo001POol30n0200040n2`Ool0061oo`@3h08000@3h:moo`00HGoo10?P00<000?P0n00
0`?P[Woo001ROol30n0200040n2^Ool0069oo`@3h0030003h0?P00<3h:eoo`00Hgoo0`?P0P0010?P
[Goo001SOol40n0200040n2/Ool006Aoo`@3h0030003h0?P00<3h:]oo`00IGoo0`?P0P0010?PZgoo
001UOol40n000`000n03h0030n2ZOol006Ioo`<3h08000@3h:Yoo`00IWoo10?P0P0010?PZGoo001W
Ool40n000`000n03h0030n2XOol006Qoo`<3h08000@3h:Qoo`00J7oo10?P00<000?P0n000`?PYgoo
001YOol30n0200040n2WOol006Uoo`@3h08000@3h:Ioo`00JWoo10?P00<000?P0n000`?PYGoo001[
Ool30n0200040n2UOol006]oo`@3h0030003h0?P00<3h:Aoo`00K7oo0`?P0P001@?PXgoo001/Ool4
0n0200040n2SOol006eoo`@3h0030003h0?P00<3h:9oo`00KWoo0`?P0P0010?PXWoo001^Ool40n00
0`000n03h0030n2QOol006moo`<3h08000D3h:1oo`00Kgoo10?P0P0010?PX7oo001`Ool40n000`00
0n03h0030n2OOol0075oo`<3h08000@3h9moo`00LGoo10?P00<000?P0n000`?PWWoo001bOol30n02
00050n0DOol60003Ool400000goo0000000200000goo00000003Ool30006Ool300000goo00000006
00001Goo00000000Ool00P0000Aoo`000000055oo`00LWoo10?P0P0010?P5Goo0P000Woo0P000goo
0P000goo0P000Woo0P000Woo0P000Woo00<007ooOol017oo00@007ooOomoo`80009oo`8000=oo`80
0004Ool00000Ool2001BOol007=oo`@3h0030003h0?P00<3h1Aoo`8000=oo`80009oo`8000=oo`80
0006Ool00000Ool007oo0P002Goo00@007ooOomoo`80009oo`8000=oo`800004Ool00000Ool2001B
Ool007Aoo`<3h08000@3h1Aoo`8000=oo`80009oo`8000=oo`800006Ool00000Ool007oo1@001goo
10000goo0P000goo0P0000Aoo`00001oo`80059oo`00M7oo10?P00<000?P0n000`?P4goo0P000goo
0P000Woo0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool200000goo00000007Ool01000Ool00000
0goo0P0000=oo`00Ool00P0000Aoo`00001oo`80059oo`00MGoo0`?P0P001@?P4Woo0P000goo0P00
00=oo`0000002@0000Aoo`00001oo`<000Qoo`04001oo`000002Ool:00000goo0000001COol007Eo
o`@3h08000@3h19oo`8000=oo`8001aoo`8006=oo`00MWoo10?P00<000?P0n000`?P4Goo0P000Woo
0P0027oo0P004goo0P00Hgoo001gOol30n0200040n0@Ool60009Ool2000DOol00`00Oomoo`1QOol0
07Moo`@3h0030003h0?P00<3h9Qoo`00N7oo0`?P0P001@?PUgoo001hOol40n0200040n2GOol007Uo
o`@3h0030003h0?P00<3h9Ioo`00NWoo0`?P0P001@?PUGoo001jOol40n000`000n03h0030n2EOol0
07]oo`<3h08000D3h9Aoo`00Ngoo10?P0P0010?PU7oo001lOol40n000`000n03h0030n2COol007eo
o`<3h08000D3h99oo`00OGoo10?P00<000?P0n000`?PTWoo001nOol30n0200050n2AOol007ioo`@3
h08000@3h95oo`00Ogoo10?P00<000?P0n000`?PT7oo0020Ool30n0200050n2?Ool0081oo`@3h003
0003h0?P00<3h8moo`00PGoo0`?P0P001@?PSWoo0021Ool40n0200040n2>Ool0089oo`@3h0030003
h0?P00<3h8eoo`00Pgoo0`?P00<000?P0n0010?PS7oo0023Ool:0n2<Ool008Aoo`X3h8]oo`00Q7oo
2P?PRgoo0025Ool=0n27Ool008Ioo`d3h8Ioo`00QWoo3P?PQGoo001WOol00`00Oomoo`0BOol00`00
Oomoo`07Ool?0n24Ool006Ioo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Ioo`l3h8Ao
o`00IWoo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo0P001Goo00<007ooOol01Woo
3`?P1goo0`000goo0`00M7oo001VOol01`00Oomoogoo001oo`0000Eoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00Eoo`L3h08000L3h0Qoo`03001oogoo009oo`03001oogoo07Aoo`00IGoo
00<007ooOol00Woo00<007oo00002Woo0P001Goo00<007ooOol017oo1P?P10001P?P27oo0`000goo
00<007ooOol0Lgoo001VOol01`00Oomoogoo001oo`0000Uoo`03001oo`0000Aoo`03001oogoo00Eo
o`H3h0@000H3h0Qoo`04001oogoo0002Ool00`00Oomoo`1cOol006Ioo`07001oogooOol007oo0000
2Goo00<007oo000017oo00<007ooOol01Woo1P?P0P001`?P27oo00P007ooOol007oo001oo`00M7oo
001WOol01@00Oomoogoo00002goo0P000goo00<007ooOol027oo3P?P1goo10000goo00<007ooOol0
Lgoo0027Ool=0n25Ool008Moo``3h8Ioo`00RGoo2@?PQgoo002:Ool60n29Ool00?mooaYoo`00ogoo
6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol0
0?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo
6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol0
0?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo
6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol0
0?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo
6Woo003oOolJOol00?mooaYoo`00\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-6.02038, -1.00006, 0.0751456, 
  0.0751456}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Slider"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The slider graphic uses just one built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitive and one ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the slider graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(slidergraphic = 
      Graphics[{\n
          \t\t\t{RGBColor[.5, .5, 1], Disk[Location[slider, 1], 0.4], 
            Bar[Line[slider, 1, 2], 1, 0]}, Vertex[slider, {1, 2}]}]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the slider annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(slidertext = 
      Graphics[{\n\t\t\tText["\<{0,0}\>", Location[slider, 1], {0, 2.0}], \n
          \t\t\tText["\<P1\>", Location[slider, 1], {2.0, \(-1.8\)}], \n\t\t\t
          Text["\<{3,0}\>", Location[slider, 2], {0, 2.0}], \n\t\t\t
          Text["\<P2\>", Location[slider, 2], {\(-2.0\), \(-1.8\)}], \n\t\t\t
          Text[FontForm["\<Slider\>", {"\<Times-Bold\>", 12}], {10.5, 7}]}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot4 = 
      Show[{slidergraphic, slidertext} /. SolveMech[0], 
        PlotRange \[Rule] {{\(-6\), 15}, {\(-1\), 12}}, 
        AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
.5 .5 1 r
.71805 .52381 m
.71805 .52381 .01905 0 365.73 arc
F
.71805 .57143 m
.71805 .52381 L
.86091 .52381 L
.86091 .57143 L
F
0 g
.008 w
.71805 .52381 Mdot
.86091 .52381 Mdot
gsave
.71805 .52381 -78 -26.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.71805 .52381 -85 2 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P1) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.86091 .52381 -78 -26.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
87.000000 14.437500 moveto
(<) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.86091 .52381 -53 2 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P2) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.78571 .38095 -79 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Slider) show
94.312500 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280.938, 173.875},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00<aoo`03001oo`000080009oo`P0
0003Ool0000000<00004Ool000000002Ool4000]Ool00<aoo`80009oo`80009oo`80009oo`800004
Ool00000Ool200000goo00000002Ool00`00Oomoo`02000^Ool00<aoo`04001oogooOol20002Ool2
0002Ool2000017oo000007oo0P0000=oo`0000001Goo0P00;Woo003?Ool30002Ool20002Ool20000
17oo000007oo0P0000=oo`0000000`000Woo0P00;Woo003=Ool40003Ool20002Ool2000017oo0000
07oo0P0000Aoo`00001oo`80009oo`800003Ool007oo02]oo`00c7oo0`001Goo0P0000Aoo`000000
009oo`@0009oo`<0009oo`D002aoo`00c7oo0P000goo00<007ooOol00P0027oo0P00>7oo003<Ool2
0002Ool20002Ool20002Ool20004Ool2000hOol00<eoo`<00003Ool007oo00<0009oo`8000=oo`<0
03Qoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo
003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00;eo
o`03001oogoo019oo`03001oogoo011oo`03001oogoo019oo`03001oogoo01]oo`00_7oo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool06Woo002lOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
0`00Oomoo`0>Ool01000Oomoogoo0P001Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
6Woo002lOol01`00Oomoogoo001oo`0000Eoo`07001oogooOol007oo000017oo00<007ooOol03Woo
00<007ooOol00goo00<007ooOol00goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0JOol00;]o
o`03001oogoo009oo`03001oo`0000Uoo`03001oo`0000Eoo`03001oogoo00aoo`03001oogoo00=o
o`03001oogoo00Qoo`03001oo`0000Eoo`03001oogoo01Uoo`00_7oo00L007ooOomoo`00Ool00009
Ool00`00Ool00004Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Ool00004
Ool00`00Oomoo`0JOol00;aoo`07001oogooOol007oo00002Goo00<007oo000017oo00<007ooOol0
3Woo00L007ooOomoo`00Ool00009Ool00`00Ool00004Ool00`00Oomoo`0JOol00;eoo`05001oogoo
Ool0000;Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo00002goo00<007ooOol00Woo
00<007ooOol06goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo
003oOolIOol00<Eoo`Lmodaoo`00aGoo23goBgoo0034Ool9?Om;Ool00<Aoo`XmodYoo`00`goo1Cgo
00<003go?Ol00cgo8Woo00<007ooOol09Goo0033Ool]?OlXOol00<=oobdmobQoo`00a7oo;3go:7oo
0034Ool/?OlXOol00<IoobXmobQoo`00b7oo:3go:7oo0038OolX?OlXOol00<QoobPmobQoo`00b7oo
:3go:7oo0038OolX?OlXOol00;9oo`<0009oo`D000aoobPmo`Yoo`<000=oo`<001Eoo`00/goo00<0
07ooOol00goo00<007ooOol037oo:3go2goo00<007ooOol00Woo00<007ooOol05Goo002cOol30003
Ool00`00Oomoo`0<OolX?Ol;Ool30003Ool00`00Oomoo`0DOol00;=oo`04001oogoo0002Ool00`00
Oomoo`0oOol01000Oomoo`000Woo00<007ooOol057oo002cOol01000Oomoo`000Woo00<007ooOol0
?goo00P007ooOol007oo001oo`005Goo002bOol40002Ool20010Ool40003Ool00`00Oomoo`0DOol0
0?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo
6Goo003oOolIOol00?mooaUoo`00\
\>"],
  ImageRangeCache->{{{0, 279.938}, {172.875, 0}} -> {-6.02563, -1.00006, 
  0.0752, 0.0752}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Connecting Rod"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The connecting rod graphic is nothing more than a line connecting two points \
on two different bodies."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the connecting rod graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(conrodgraphic = 
      Graphics[{\n\t\t\tThickness[.018], \n\t\t\t
          Line[{Location[drivearm, 2], \n\t\t\t\t\tLocation[slider, 1]}]}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "To show the complete quick-return mechanism, all of the graphics objects \
are combined and displayed subject to a single ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the complete mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.15."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{groundgraphic, crankgraphic, drivearmgraphic, slidergraphic, 
          conrodgraphic} /. SolveMech[.15], 
      PlotRange \[Rule] {{\(-6\), 15}, {\(-1\), 12}}, 
      AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
0 g
.008 w
.28571 .04762 Mdot
.01 w
.04762 .52381 m
.85714 .52381 L
.85714 .04762 L
.04762 .04762 L
.04762 .52381 L
.04762 .42857 L
.28571 .28571 L
.04762 .14286 L
s
1 .6 .6 r
.28571 .28571 m
.28571 .28571 .19048 0 365.73 arc
F
1 .4 .4 r
.36968 .40129 m
.36968 .40129 .02857 0 365.73 arc
F
.28571 .28571 m
.28571 .28571 .02857 0 365.73 arc
F
0 g
.02 w
.28571 .28571 Mdot
.36968 .40129 Mdot
0 1 0 r
.28571 .04762 m
.28571 .04762 .02857 0 365.73 arc
F
.38472 .4646 m
.38472 .4646 .02857 0 365.73 arc
F
.27181 .05092 m
.29961 .04432 L
.39861 .4613 L
.37082 .4679 L
F
0 g
.28571 .04762 Mdot
.38472 .4646 Mdot
.01 w
.30771 .14028 m
.37372 .41827 L
s
.5 .5 1 r
.61533 .52381 m
.61533 .52381 .01905 0 365.73 arc
F
.61533 .57143 m
.61533 .52381 L
.75819 .52381 L
.75819 .57143 L
F
0 g
.008 w
.61533 .52381 Mdot
.75819 .52381 Mdot
.018 w
.38472 .4646 m
.61533 .52381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo001<Ool70n36Ool004Yoo`/3
h<Aoo`00BGoo3@?P`goo0018Ool?0n32Ool004Qoo`l3h<9oo`00B7oo40?P`Goo0018Ool60n020008
0n31Ool000aooc`000D3h0@000L3h9P002Uoo`0037oo?0001@?P10001P?PV@00:Goo000<Ool2000j
Ool60n0200070n2GOol2000YOol000aoo`8003Yoo`l3h9Moo`8002Uoo`0037oo0P00>goo3P?PUgoo
0P00:Goo000<Ool2000lOol<0n2HOol2000YOol000aoo`8003eoo`/3h9Qoo`8002Uoo`0037oo0P00
?Woo2P?PV7oo0P00:Goo000<Ool20010Ool90n2GOol2000YOol000aoo`80041oo`T3h9Moo`8002Uo
o`0037oo0P00@Goo20?PUgoo0P00:Goo000<Ool20011Ool80n2GOol2000YOol000aoo`80045oo`T3
h9Ioo`8002Uoo`0037oo0P00@Goo2@?PUWoo0P00:Goo000<Ool2000kOol7OW<80n2FOol2000YOol0
00aoo`8003=oo`mnL`P3h0InLi1oo`8002Uoo`0037oo0P00<Goo4Gic20?P2GicSGoo0P00:Goo000<
Ool2000^OolDOW<90n0:OW>;Ool2000YOol000aoo`8002aooaInL`T3h0enLhQoo`8002Uoo`0037oo
0P00:Goo6Wic20?P3gicQWoo0P00:Goo000<Ool2000WOolLOW<80n0AOW>4Ool2000YOol000aoo`80
02IooaenL`T3h19nLh9oo`8002Uoo`0037oo0P009Goo7Wic2@?P4gicPGoo0P00:Goo000<Ool2000S
OolQOW<80n0EOW=oOol2000YOol000aoo`80029oob9nL`P3h1InLgioo`8002Uoo`0037oo0P0087oo
97ic10?P00<000?P0n000P?P5WicOGoo0P00:Goo000<Ool4000LOolVOW<30n0300030n0HOW=kOol2
000YOol000aoo`D001YoobQnL`<3h08000<3h1UnLgYoo`8002Uoo`0037oo0P0000=oo`0000000P00
5goo:Gic0`?P0P000`?P6WicNGoo0P00:Goo000<Ool20002Ool5000EOolYOW<30n0200030n0KOW=h
Ool2000YOol000aoo`8000Aoo`@001=oobYnL`<3h0<000<3h1]nLgMoo`8002Uoo`0037oo0P001Woo
100047oo:gic10?P0P000`?P77icMWoo0P00:Goo000<Ool20007Ool5000=Ool]OW<30n0200030n0L
OW=fOol2000YOol000aoo`8000Uoo`@000]oobinL`<3h08000<3h1enLgEoo`8002Uoo`0037oo0P00
2goo100027oo;gic0`?P0P0010?P7GicM7oo0P00:Goo000<Ool2000<Ool50006Ool_OW<30n030003
0n0NOW=cOol2000YOol000aoo`8000ioo`@000Aooc5nL`<3h08000<3h1mnLg9oo`8002Uoo`0037oo
0P0047oo10000Woo<Gic0`?P0P000`?P87icLGoo0P00:Goo000<Ool2000AOol4000bOW<30n020004
0n0OOW=aOol2000YOol000aoo`8001=oo`03001nLgic035nL`<3h0<000<3h1mnLg5oo`8002Uoo`00
37oo0P0057oo=7ic0`?P0P000`?P87icL7oo0P00:Goo000<Ool2000COoleOW<30n0200030n0POW=`
Ool2000YOol000aoo`8001=oocEnL`<3h08000@3h21nLfmoo`8002Uoo`0037oo0P004Woo=Wic0`?P
0`000`?P8GicKWoo0P00:Goo000<Ool2000BOolgOW<30n0200030n0ROW=]Ool2000YOol000aoo`80
019oocMnL`<3h08000<3h29nLfeoo`8002Uoo`0037oo0P004Goo>7ic0`?P0P000`?P8WicKGoo0P00
:Goo000<Ool2000AOolhOW<30n0300030n0ROW=/Ool2000YOol000aoo`80011oocUnL`@3h08000<3
h29nLfaoo`8002Uoo`0037oo0P0047oo>Wic0`?P0P000`?P8WicK7oo0P00:Goo000<Ool2000@Oolj
OW<30n0200030n0ROW=/Ool2000YOol000aoo`8000mooc]nL`<3h08000@3h25nLfaoo`8002Uoo`00
37oo0P003goo>gic0`?P0`000`?P8WicJgoo0P00:Goo000<Ool2000>OolmOW<30n0200030n0ROW=[
Ool2000YOol000aoo`8000ioocenL`<3h08000<3h2=nLfYoo`8002Uoo`0037oo0P003Woo?Gic0`?P
0P0010?P8WicJWoo0P00:Goo000<Ool2000=OolnOW<30n0300030n0ROW=ZOol2000YOol000aoo`80
00eoocmnL`<3h08000<3h29nLfYoo`8002Uoo`0037oo0P003Goo?gic0`?P0P000`?P8WicJWoo0P00
:Goo000<Ool2000=OolbOW<5OH`8OW<30n0200030n0SOW=YOol2000YOol000aoo`8000eoobmnL`]m
S0EnL`<3h0<000<3h29nLfUoo`8002Uoo`0037oo0P003Goo;gic37f<17ic10?P0P000`?P8WicJGoo
0P00:Goo000<Ool2000=Ool^OW<>OH`4OW<30n0200030n0ROW=YOol2000YOol000aoo`8000eooben
L`mmS0AnL`<3h08000<3h29nLfUoo`8002Uoo`0037oo0P0037oo;Wic3gf<17ic0`?P0P0010?P8Gic
JGoo0P00:Goo000<Ool2000<Ool^OW<@OH`3OW<30n0300030n0QOW=YOol2000YOol000aoo`8000ao
obinL`ImS08000QmS0AnL`<3h08000<3h25nLfUoo`8002Uoo`0037oo0P0037oo;Wic1Gf<10001gf<
17ic0`?P0P000`?P8GicJGoo0P00:Goo000<Ool2000<Ool^OW<5OH`40006OH`5OW<30n0200040n0P
OW=YOol2000YOol000aoo`8000aoobinL`ImS08000MmS0EnL`<3h0<000<3h21nLfUoo`8002Uoo`00
37oo0P003Goo;Wic3Wf<1Wic0`?P0P000`?P87icJGoo0P00:Goo000<Ool2000=Ool_OW<<OH`7OW<3
0n0200030n0POW=YOol2000YOol000aoo`8000eoobmnL`]mS0QnL`<3h08000<3h21nLfUoo`8002Uo
o`0037oo0P003Goo<7ic2Gf<2Gic0`?P0`000`?P7gicJGoo0P00:Goo000<Ool2000=OolaOW<7OH`:
OW<40n0200030n0NOW=ZOol2000YOol000aoo`8000eood=nL`<3h08000<3h1inLfYoo`8002Uoo`00
37oo0P003Goo@gic0`?P0P000`?P7WicJWoo0P00:Goo000<Ool2000=Oom3OW<30n0300030n0MOW=Z
Ool2000YOol000aoo`8000iood9nL`@3h08000<3h1enLfYoo`8002Uoo`0037oo0P003Woo@gic0`?P
0P000`?P77icJgoo0P00:Goo000<Ool2000?Oom2OW<30n0200030n0LOW=[Ool2000YOol000aoo`80
00mood9nL`<3h08000@3h1]nLf]oo`8002Uoo`0037oo0P003goo@Wic0`?P0`000`?P6WicK7oo0P00
:Goo000<Ool2000@Oom2OW<30n0200030n0JOW=/Ool2000YOol000aoo`80011ood9nL`<3h08000<3
h1YnLfaoo`8002Uoo`0037oo0P0047oo@Wic0`?P0P0010?P6GicK7oo0P00:Goo000<Ool2000AOom1
OW<30n0300030n0IOW=/Ool2000YOol000aoo`80015ood9nL`<3h08000<3h1QnLfeoo`8002Uoo`00
37oo0P004Woo@Gic0`?P0P000`?P67icKGoo0P00:Goo000<Ool2000BOom1OW<30n0200030n0GOW=^
Ool2000YOol000aoo`8001=ood1nL`<3h0<000<3h1InLfioo`8002Uoo`0037oo0P004goo@7ic10?P
0P000`?P5GicKgoo0P00:Goo000<Ool2000COom1OW<30n0200030n000gf<OW=nL`0AOW=`Ool2000Y
Ool000aoo`8001=oo`03001nLgic03inL`<3h08000<3h09mS19nLg1oo`8002Uoo`0037oo0P004Goo
0`00?gic00AmS0?P0n03h0<000<3h09mS11nLg5oo`8002Uoo`0037oo0P0047oo100000=oogicOW<0
>gic0Wf<10?P0P000`?P0gf<3gicLGoo0P00:Goo000<Ool2000>Ool40004OollOW<3OH`30n020003
0n04OH`=OW=bOol2000YOol000aoo`8000aoo`D000IoocYnL`AmS0<3h08000<3h0AmS0anLg=oo`80
02Uoo`0037oo0P002goo100027oo>Wic17f<0`?P0P0010?P0gf<2gicM7oo0P00:Goo000<Ool20009
Ool4000;OoliOW<4OH`30n0300030n03OH`;OW=dOol2000YOol000aoo`8000Moo`D000eoocQnL`Em
S0<3h08000<3h0=mS0YnLgEoo`8002Uoo`0037oo0P001Woo10003goo>Gic17f<0`?P0P000`?P0gf<
2GicMWoo0P00:Goo000<Ool20004Ool4000BOoliOW<3OH`30n0200030n02OH`:OW=fOol2000YOol0
00aoo`80009oo`D001AoocQnL`=mS0<3h0<000<3h003OHanLgic00MnLgMoo`8002Uoo`0037oo0P00
00=oo`0000000P005goo=gic0gf<10?P00<000?P0n000P?P27icNGoo0P00:Goo000<Ool5000JOolh
OW<2OH`80n07OW=jOol2000YOol000aoo`@001aoocQnL`03OH`3h0?P00H3h0InLg]oo`8002Uoo`00
37oo0P007goo>7ic2@?P17icO7oo0P00:Goo000<Ool2000POolgOW<90n03OW=mOol2000YOol000ao
o`80029oocInL`P3h09nLgioo`8002Uoo`0037oo0P008goo=Gic2P?POWoo0P00:Goo000<Ool2000U
OolcOW<;0n1mOol2000YOol000aoo`8002Mooc1nL`d3h7aoo`8002Uoo`0037oo0P00:7oo;Wic3`?P
Ngoo0P00:Goo000<Ool2000YOol]OW<50n0500050n1kOol2000YOol000aoo`8002aoobYnL`D3h0T0
00030n1oogoo07Uoo`8002Uoo`0037oo0P00;Woo9gic1P?P3@00N7oo0P00:Goo000<Ool2000aOolR
OW<2Ool60n0@001eOol2000YOol000aoo`8003=ooaenL`Eoo`H3h1@0075oo`8002Uoo`0037oo0P00
>7oo4gic2goo1P?P0P0000<3h00000004P00KGoo0P00:Goo000<Ool20010Ool3OW<DOol<0n0D001Y
Ool2000YOol000aoo`8005Moo`d3h0=ooa@006Eoo`8002Uoo`0037oo0P00Egoo30?P1goo5000HWoo
0P00:Goo000<Ool2001IOol90n0<OolD001NOol2000YOol000aoo`8005Yoo`H3h19ooa@005Yoo`80
02Uoo`0037oo0P00MWoo5000EWoo0P00:Goo000<Ool2001jOolD001BOol2000YOol000aoo`8007eo
oaD004ioo`8002Uoo`0037oo0P00PGoo5000Bgoo0P00:Goo000<Ool20025OolD00000goo?Olmo`06
?OlnOol2000YOol000aoo`8008Uooa@000Hmoceoo`8002Uoo`0037oo0P00SGoo50000Sgo?Goo0P00
:Goo000<Ool2002AOol@0002?OlmOol2000YOol000aooj<0008mocl002Uoo`0037ooX`009Cgo7000
:Goo002WOol3?Ol5000U?Om5Ool00:Qoob`modEoo`00Z7oo;3goAGoo002ZOolZ?Om5Ool00:aoobPm
odEoo`00[7oo:3goAGoo002/OolX?Om5Ool00:aoobPmodEoo`00[7oo:3goAGoo002/OolX?Om5Ool0
0:aoobPmodEoo`00[7oo:3goAGoo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYo
o`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003o
OolJOol00001\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-6.02038, -1.00006, 0.0751456, 
  0.0751456}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.55."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{groundgraphic, crankgraphic, drivearmgraphic, slidergraphic, 
          conrodgraphic} /. SolveMech[.55], 
      PlotRange \[Rule] {{\(-6\), 15}, {\(-1\), 12}}, 
      AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
0 g
.008 w
.28571 .04762 Mdot
.01 w
.04762 .52381 m
.85714 .52381 L
.85714 .04762 L
.04762 .04762 L
.04762 .52381 L
.04762 .42857 L
.28571 .28571 L
.04762 .14286 L
s
1 .6 .6 r
.28571 .28571 m
.28571 .28571 .19048 0 365.73 arc
F
1 .4 .4 r
.14985 .24157 m
.14985 .24157 .02857 0 365.73 arc
F
.28571 .28571 m
.28571 .28571 .02857 0 365.73 arc
F
0 g
.02 w
.28571 .28571 Mdot
.14985 .24157 Mdot
0 1 0 r
.28571 .04762 m
.28571 .04762 .02857 0 365.73 arc
F
.03982 .39863 m
.03982 .39863 .02857 0 365.73 arc
F
.27401 .03942 m
.29741 .05582 L
.05152 .40683 L
.02812 .39044 L
F
0 g
.28571 .04762 Mdot
.03982 .39863 Mdot
.01 w
.23107 .12562 m
.06714 .35963 L
s
.5 .5 1 r
.24236 .52381 m
.24236 .52381 .01905 0 365.73 arc
F
.24236 .57143 m
.24236 .52381 L
.38521 .52381 L
.38521 .57143 L
F
0 g
.008 w
.24236 .52381 Mdot
.38521 .52381 Mdot
.018 w
.03982 .39863 m
.24236 .52381 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo001<Ool70n36Ool004Yoo`/3
h<Aoo`00BGoo3@?P`goo0018Ool?0n32Ool004Qoo`l3h<9oo`00B7oo40?P`Goo0018Ool60n020008
0n31Ool000aooc`000D3h0@000L3h9P002Uoo`0037oo?0001@?P10001P?PV@00:Goo000<Ool2000j
Ool60n0200070n2GOol2000YOol000aoo`8003Yoo`l3h9Moo`8002Uoo`0037oo0P00>Woo3`?PUgoo
0P00:Goo000<Ool2000jOol>0n2HOol2000YOol000aoo`8003Uoo`h3h9Uoo`8002Uoo`0037oo0P00
>7oo3@?PVgoo0P00:Goo000<Ool2000hOol;0n2MOol2000YOol000aoo`8003Moo`X3h9moo`8002Uo
o`0037oo0P00=Woo2P?PX7oo0P00:Goo000<Ool2000eOol:0n2QOol2000YOol000aoo`8003Eoo`T3
h:9oo`8002Uoo`0037oo0P00=7oo2P?PXWoo0P00:Goo000<Ool2000cOol:0n0;OW>HOol2000YOol0
00aoo`8003=oo`T3h1AnLi1oo`8002Uoo`0037oo0P00<Goo00=nL`?P0n0020?P5gicSGoo0P00:Goo
000<Ool2000^Ool3OW<:0n0JOW>;Ool2000YOol000aoo`8002aoo`EnL`T3h1inLhQoo`8002Uoo`00
37oo0P00:Goo1gic2P?P87icQWoo0P00:Goo000<Ool2000WOol8OW<:0n0SOW>4Ool2000YOol000ao
o`8002Ioo`UnL`<3h0030003h0?P00<3h2InLh9oo`8002Uoo`0037oo0P009Goo2Gic10?P00<000?P
0n000P?P:7icPGoo0P00:Goo000<Ool2000SOol:OW<40n0200040n0ZOW=oOol2000YOol000aoo`80
029oo`YnL`@3h08000@3h2anLgioo`8002Uoo`0037oo0P0087oo37ic10?P00<000?P0n000P?P;Wic
OGoo0P00:Goo000<Ool4000LOol=OW<40n0200040n0`OW=kOol2000YOol000aoo`D001Yoo`enL`@3
h08000@3h39nLgYoo`8002Uoo`0037oo0P0000=oo`0000000P005goo3Wic0`?P0P0010?P=7icNGoo
0P00:Goo000<Ool20002Ool5000EOol=OW<40n000`000n03h0020n0fOW=hOol2000YOol000aoo`80
00Aoo`@001=oo`enL`@3h08000@3h3MnLgMoo`8002Uoo`0037oo0P001Woo100047oo3Wic0`?P0P00
10?P>GicMWoo0P00:Goo000<Ool20007Ool5000=Ool>OW<40n000`000n03h0020n0jOW=fOol2000Y
Ool000aoo`8000Uoo`@000]oo`inL`@3h08000@3h3]nLgEoo`8002Uoo`0037oo0P002goo100027oo
3gic0`?P0P0010?P?GicM7oo0P00:Goo000<Ool2000<Ool50006Ool>OW<40n000`000n03h0020n0o
OW=cOol2000YOol000aoo`8000ioo`@000Aoo`inL`@3h08000@3h41nLg9oo`8002Uoo`0037oo0P00
47oo10000Woo3Gic10?P0P0010?P@WicLGoo0P00:Goo000<Ool2000AOol4000>OW<40n000`000n03
h0020n13OW=aOol2000YOol000aoo`8001=oo`03001nLgic00anL`@3h08000<3h4AnLg5oo`8002Uo
o`0037oo0P0057oo3Gic10?P0P0010?PAGicL7oo0P00:Goo000<Ool2000COol>OW<30n0200040n16
OW=`Ool2000YOol000aoo`8001=oo`enL`@3h0030003h0?P0083h4QnLfmoo`8002Uoo`0037oo0P00
4Woo3Gic10?P0P0010?PBGicKWoo0P00:Goo000<Ool2000BOol=OW<30n0200040n1;OW=]Ool2000Y
Ool000aoo`80019oo`anL`@3h0030003h0?P0083h4anLfeoo`8002Uoo`0037oo0P004Goo37ic10?P
0P0010?PC7icKGoo0P00:Goo000<Ool2000AOol7OW<4OH`40n0200040n1>OW=/Ool2000YOol000ao
o`80011oo`InL`ImS0@3h0030003h0?P0083h4mnLfaoo`8002Uoo`0037oo0P0047oo1Wic1Gf<10?P
0P000`?PD7icK7oo0P00:Goo000<Ool2000@Ool5OW<5OH`40n0200040n1@OW=/Ool2000YOol000ao
o`8000moo`EnL`ImS0@3h0030003h0?P0083h55nLfaoo`8002Uoo`0037oo0P003goo1Gic1Gf<10?P
0P000`?P00=mS7icOW<0D7icJgoo0P00:Goo000<Ool2000>Ool6OW<4OH`40n0200040n02OHaAOW=[
Ool2000YOol000aoo`8000ioo`InL`AmS0<3h08000@3h0=mS59nLfYoo`8002Uoo`0037oo0P003Woo
1Wic0gf<10?P00<000?P0n000P?P17f<DWicJWoo0P00:Goo000<Ool2000=Ool7OW<2OH`40n020003
0n04OHaCOW=ZOol2000YOol000aoo`8000eoo`MnL`9mS0<3h08000@3h0AmS5=nLfYoo`8002Uoo`00
37oo0P003Goo27ic10?P00<000?P0n000P?P1Gf<DgicJWoo0P00:Goo000<Ool2000=Ool7OW<40n02
00030n05OH`MOW<5OH`cOW=YOol2000YOol000aoo`8000eoo`InL`@3h08000@3h0AmS1]nL`]mS31n
LfUoo`8002Uoo`0037oo0P003Goo1Wic10?P00<000?P0n000P?P0gf<7Gic37f<;gicJGoo0P00:Goo
000<Ool2000=Ool5OW<40n0200030n02OH`NOW<>OH`^OW=YOol2000YOol000aoo`8000eoo`AnL`@3
h08000@3h1mnL`mmS2inLfUoo`8002Uoo`0037oo0P0037oo1Gic10?P00<000?P0n000P?P87ic3gf<
;WicJGoo0P00:Goo000<Ool2000<Ool4OW<40n0200030n0QOW<@OH`]OW=YOol2000YOol000aoo`80
00aoo`=nL`@3h08000<3h29nL`ImS08000QmS2enLfUoo`8002Uoo`0037oo0P0037oo0gic0`?P0P00
10?P8Wic1Gf<10001gf<;GicJGoo0P00:Goo000<Ool2000<Ool2OW<40n000`000n03h0020n0SOW<5
OH`40006OH`^OW=YOol2000YOol000aoo`8000aoo`03OW<3h0?P0083h08000<3h2AnL`ImS08000Mm
S2inLfUoo`8002Uoo`0037oo0P003Goo0`?P0P0010?P9Gic3Wf<;WicJGoo0P00:Goo000<Ool2000<
Ool40n000`000n03h0020n0WOW<<OH`_OW=YOol2000YOol000aoo`8000]oo`@3h08000<3h2QnL`]m
S31nLfUoo`8002Uoo`0037oo0P002Woo10?P0P0010?P:Gic2Gf<<GicJGoo0P00:Goo000<Ool2000:
Ool40n000`000n03h0020n0[OW<7OH`aOW=ZOol2000YOol000aoo`8000Uoo`@3h08000<3h6AnLfYo
o`8002Uoo`0037oo0P0027oo10?P0P000`?PIGicJWoo0P00:Goo000<Ool20008Ool40n000`000n03
h0020n1UOW=ZOol2000YOol000aoo`8000Moo`@3h08000<3h6InLfYoo`8002Uoo`0037oo0P001Woo
10?P0P000`?PIWicJgoo0P00:Goo000<Ool20006Ool30n0200040n1VOW=[Ool2000YOol000aoo`80
00Eoo`@3h0030003h0?P0083h003OomnLgic06AnLf]oo`8002Uoo`0037oo0P0017oo10?P0P000`?P
0WooIGicK7oo0P00:Goo000<Ool20004Ool30n0200030n04OomTOW=/Ool2000YOol000aoo`8000=o
o`@3h0030003h0?P0083h0AoofAnLfaoo`8002Uoo`0037oo0P000Woo10?P0P000`?P1GooI7icK7oo
0P00:Goo000<Ool200000goo0n03h0020n0200030n07OomSOW=/Ool2000YOol000aoo`800003Ool3
h0?P0083h0030003h0?P0083h0Moof9nLfeoo`8002Uoo`0037oo0P001@?P00@000?P0n03h0Uoof5n
Lfeoo`8002Uoo`0037oo00<000?P0n001`?P2WooH7icKWoo0P00:Goo000<Ool00`000n03h0070n0;
OomOOW=^Ool2000YOol000Moo`h3h0aooeinLfmoo`8002Uoo`001Woo3P?P3GooGGicL7oo0P00:Goo
0005Ool>0n0>Ool00`00OW=nL`1JOW=`Ool2000YOol000Aoo`l3h0aoo`<005]nLg5oo`8002Uoo`00
17oo3`?P2goo100000=oogicOW<0F7icLGoo0P00:Goo0003Ool70n0300060n09Ool40004OomHOW=b
Ool2000YOol000=oo`H3h0H000@3h0Moo`D000IooeInLg=oo`8002Uoo`000goo1@?P20000`?P1Woo
100027ooEGicM7oo0P00:Goo0003Ool50n0:00000`?POomoo`02Ool4000;OomDOW=dOol2000YOol0
00=oo`L3h0X00003Ool0000000<000eooe9nLgEoo`8002Uoo`000goo2@?P30003gooDGicMWoo0P00
:Goo0004Ool90n0:000AOom@OW=fOol2000YOol000Eoo`X3h0T0015oodinLgMoo`8002Uoo`001goo
2@?P2P0047ooBgicNGoo0P00:Goo0008Ool60n0300000goo00000008000?Oom9OW=jOol2000YOol0
00Uoo`<3h0@000Aoo`T000moodMnLg]oo`8002Uoo`0037oo0P001goo2P003WooAGicO7oo0P00:Goo
000<Ool20009Ool:000=Oom3OW=mOol2000YOol000aoo`8000]oo`T000iood1nLgioo`8002Uoo`00
37oo0P0037oo2P003Goo?WicOgoo0P00:Goo000<Ool2000>Ool9000>OoliOW>2Ool2000YOol000ao
o`80011oo`T000ioocEnLhAoo`8002Uoo`0037oo0P004Goo2P003Goo<gicQGoo0P00:Goo000<Ool2
000COol9000=OolaOW>6Ool2000YOol000aoo`8001Aoo`X000ioobanLhQoo`8002Uoo`0037oo0P00
5Woo2P003Woo9gicRgoo0P00:Goo000<Ool2000HOol9000@OolROW>=Ool2000YOol000aoo`8001Uo
o`X0011ooaenLi1oo`8002Uoo`0037oo0P006goo2@0057oo4gicUGoo0P00:Goo000<Ool2000MOol9
000JOol3OW>MOol2000YOol000aoo`8001ioo`X00;Qoo`8002Uoo`0037oo0P0087oo2@00]goo0P00
:Goo000<Ool2000QOol:002eOol2000YOol000aoo`8002=oo`X00;=oo`8002Uoo`0037oo0P009Goo
2@00/Woo0P00:Goo000<Ool2000VOol:002`Ool2000YOol000aoo`8002Qoo`T00:moo`8002Uoo`00
37oo0P00:Woo2@00[Goo0P00:Goo000<Ool2000[Ool:0005?OnVOol2000YOol000aoo`8002eoo`T0
00DmojEoo`8002Uoo`0037oo0P00;Woo2P000cgoYGoo0P00:Goo000<Ool2000`Ool:00000cgoOomo
o`2SOol2000YOol000aooc80008mo`P00003?Ol000000:D002Uoo`0037oo<P000cgo1P0093goQ@00
:Goo000nOol5?Ol3000U?On^Ool003moob`mojioo`00@7oo:cgo[Woo0011OolZ?On^Ool004AoobLm
ojioo`00A7oo9cgo[Woo0014OolW?On^Ool004AoobLmojioo`00A7oo9cgo[Woo0014OolW?On^Ool0
04AoobLmojioo`00A7oo9cgo[Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYo
o`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003o
OolJOol00001\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-6.02038, -1.00006, 0.0751456, 
  0.0751456}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This was used to generate the array of four graphics objects in Section \
3.1."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[GraphicsArray[{{plot1, plot2}, {plot3, plot4}}], 
      Frame \[Rule] True]; \)\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3.5  3D Mechanism Images"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section demonstrates the special ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions that are used to generate the mechanism images \
throughout this document. ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions return graphics primitives that are given as arguments \
to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function and displayed with the ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, just like the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives.\n\nThe primary utility of the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions is that they take their arguments in the form of local \
coordinates and automatically convert them to global. Thus, it is possible to \
create the image of a mechanism part using the same techniques as would be \
used with built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives, and then have the part be positioned properly with \
respect to the other parts of the mechanism automatically, as specified by a \
",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Graphics Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The elementary ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions closely parallel the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives. Each graphics function generates ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that represent points, lines, or polygons. The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " compound graphics functions generate more complex shapes, such as spheres \
and cylinders."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Vertex[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns point graphics primitives at each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point coordinate ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or a local point number.\n\n",
  StyleBox["Edge[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns line graphics primitives connecting each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Facet[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a polygon graphics primitive with vertices at each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Box[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a cuboid with two opposite corners at local points ",
  StyleBox["pnt1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["pnt2",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The sides of the cuboid are aligned with the local axes of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.\n\n",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a planar ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon with ",
  StyleBox["segs",
    FontSlant->"Italic"],
  " sides and radius to vertices ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", centered at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The plane of the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon is normal to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rin, rout",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates an ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon with a hole of radius ",
  StyleBox["rin",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Basic 3D graphics functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a cylindrical bar with radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " and ",
  StyleBox["segs",
    FontSlant->"Italic"],
  " sides, spanning the endpoints of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". Setting ",
  StyleBox["segs ",
    FontSlant->"Italic"],
  "= 4 generates a rectangular bar\nsqrt(2) ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " across a face.\n\n",
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rad1, rad2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a conical bar of radius ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  " at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and radius ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  " at the end of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options.\n\n",
  StyleBox["Sphere[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a sphere with ",
  StyleBox["segs",
    FontSlant->"Italic"],
  " segments, of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", centered at the origin of the ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The polar axis of the sphere points in the direction of the ",
  StyleBox["axis.\n\n",
    FontSlant->"Italic"],
  StyleBox["Sphere[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["circsegs, polarsegs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a sphere with ",
  StyleBox["circsegs",
    FontSlant->"Italic"],
  " segments around the equator and ",
  StyleBox["polarsegs",
    FontSlant->"Italic"],
  " segments looping over the poles. ",
  StyleBox["Sphere",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options.\n\n",
  StyleBox["Torus[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, majrad, minrad, segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a torus with ",
  StyleBox["segs",
    FontSlant->"Italic"],
  " segments, centered at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The major axis of the torus points in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Torus[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, majrad, minrad, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["majsegs, minsegs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a torus with different numbers of major and minor axis \
segments. ",
  StyleBox["Torus",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["More 3D graphics functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for certain ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics function that specifies whether to draw the graphic element as a \
filled polygon or as a perimeter of lines. The default setting for all \
applicable functions is ",
  StyleBox["Faces->True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for revolved ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic functions that is used to specify the start and end angles of \
revolution of the revolved shape. The default setting is ",
  StyleBox["Angle->{0, 2 Pi}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If the span of the two angles is less than 2 pi, the resulting revolved \
object will be only a section of a full revolved object.\n\n",
  StyleBox["Ends",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether to generate facets to close the ends of the bar, \
or to leave the ends open like a hollow pipe. The default setting is\n",
  StyleBox["Ends->True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Options for graphics functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions are analogous to the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Polygon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics primitives. To demonstrate these functions, graphics objects are \
generated on body 2, which is named ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech3D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(body2 = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a pyramid with a filled floor."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics3D[{\n\t\t\t
          Vertex[body2, {{\(-.5\), \(-.5\), 2}, {.5, .5, 2}}], \n\t\t\t
          Edge[body2, {{\(-1\), \(-1\), 0}, {0, 0, 2}, {1, \(-1\), 0}}], \n
          \t\t\tEdge[body2, {{\(-1\), 1, 0}, {0, 0, 2}, {1, 1, 0}}], \n\t\t\t
          Facet[body2, {{\(-1\), \(-1\), 0}, {1, \(-1\), 0}, {1, 1, 0}, \n
              \t\t\t\t\t{\(-1\), 1, 0}}]}, \n\t\t
        PlotRange 
          \[Rule] {{\(-1.5\), 1.5}, {\(-1.5\), 1.5}, {\(-.5\), 2.5}}]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The coordinates of the graphic just created ",
  StyleBox["bdgraph",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are functions of the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " variables that locate ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ": ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Z2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Eo2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ei2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ej2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Ek2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Therefore, these variables must be replaced with numeric values before \
trying to ",
  StyleBox["Show",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the graphic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is ",
  StyleBox["bdgraph",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " located coincidentally with the local origin."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] 0, Z2 \[Rule] 0, Eo2 \[Rule] 1, 
          Ei2 \[Rule] 0, Ej2 \[Rule] 0, Ek2 \[Rule] 0}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 2.22045e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.80458 .46635 m .44896 .582 L .23068 .35518 L p .668 .734 .899 r
F P
0 g
s
.44896 .582 m
.52632 .77472 L
s
.23068 .35518 m .62121 .20447 L .80458 .46635 L p .668 .734 .899 r
F P
0 g
s
.52632 .77472 m
.80458 .46635 L
s
.23068 .35518 m
.52632 .77472 L
s
.01 w
.68469 .79935 Mdot
.5 Mabswid
.52632 .77472 m
.62121 .20447 L
s
.01 w
.36246 .74925 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{211, 228},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003C0000i1000`40O003h00OS7oo0P00AGoo002:
Ool200000goo00000014Ool008Qoo`8000=oo`8004Aoo`00QGoo0`001Goo00<007oo0000@goo0023
Ool20008Ool00`00Ool00013Ool0081oo`<000Yoo`04001oogoo0012Ool007ioo`8000eoo`05001o
ogooOol00011Ool007aoo`8000moo`05001oogooOol00011Ool007Uoo`<0015oo`03001oogoo009o
o`03001oogoo03ioo`00Mgoo0P005Goo00D007ooOomoo`00041oo`00MGoo0P005goo00<007ooOol0
0Woo00<007ooOol0?Goo001bOol3000IOol00`00Oomoo`03Ool00`00Oomoo`0lOol0071oo`8001ao
o`03001oogoo00=oo`03001oogoo03aoo`00KWoo0P007Woo00<007ooOol017oo00<007ooOol0>goo
001[Ool3000POol00`00Oomoo`05Ool00`00Oomoo`0jOol006Uoo`8002=oo`03001oogoo00Eoo`03
001oogoo03Yoo`00IWoo0`009Goo00<007ooOol01Woo00<007ooOol0>Goo001TOol2000XOol00`00
Oomoo`06Ool00`00Oomoo`0iOol0069oo`8002Yoo`03001oogoo00Moo`03001oogoo03Qoo`00Ggoo
0`00;7oo00<007ooOol027oo00<007ooOol0=goo001MOol2000_Ool00`00Oomoo`08Ool00`00Oomo
o`0gOol005]oo`80035oo`03001oogoo00Uoo`03001oogoo03Ioo`00F7oo0`00<goo00<007ooOol0
2Goo00<007ooOol0=Woo001FOol2000fOol00`00Oomoo`0:Ool00`00Oomoo`0eOol005Aoo`8003Qo
o`03001oogoo00]oo`03001oogoo03Aoo`00DGoo0`00>Woo00<007ooOol02goo00<007ooOol0=7oo
001?Ool2000mOol00`00Oomoo`0<Ool00`00Oomoo`0cOol004aoo`<0041oo`03001oogoo00]oo`03
001oogoo03=oo`00BWoo0P00@goo00<007ooOol037oo00<007ooOol0<Woo0018Ool20015Ool00`00
Oomoo`0=Ool00`00Oomoo`0aOol004Eoo`<004Moo`03001oogoo00eoo`03001oogoo035oo`00@goo
0P00BWoo00<007ooOol03Woo00<007ooOol0<7oo0011Ool2001<Ool00`00Oomoo`0>Ool00`00Oomo
o`0`Ool003ioo`<004ioo`03001oogoo00moo`03001oogoo02moo`00?7oo0P00DGoo00<007ooOol0
47oo00<007ooOol0;Woo000jOol2001COol00`00Oomoo`0@Ool00`00Oomoo`0^Ool003Moo`<005Eo
o`03001oogoo015oo`03001oogoo02eoo`00=Goo0P00F7oo00<007ooOol04Woo00<007ooOol0;7oo
000bOol3001JOol00`00Oomoo`0BOol00`00Oomoo`0/Ool0031oo`8005eoo`03001oogoo01=oo`03
001oogoo02]oo`00;Woo0P00Ggoo00<007ooOol04goo00<007ooOol0:goo000[Ool3001QOol00`00
Oomoo`0DOol00`00Oomoo`0ZOol002Uoo`8006Aoo`03001oogoo01Eoo`03001oogoo02Uoo`009goo
0P00F7oo0P0037oo00<007ooOol05Goo00<007ooOol0:Goo000TOol3001HOol200000eKl0000000<
Ool00`00Oomoo`0EOol00`00Oomoo`0XOol0029oo`8005Qoo`<000=Fo08000aoo`03001oogoo01Eo
o`03001oogoo02Qoo`0087oo0P00F7oo0P001EKl00@005KlE_`000]oo`03001oogoo01Ioo`03001o
ogoo02Moo`007Goo0`00Egoo0`001eKl00D005KlE_aFo00000Yoo`03001oogoo01Moo`03001oogoo
02Ioo`006goo0P00Egoo0`002UKl00D005KlE_aFo00000Yoo`03001oogoo01Moo`03001oogoo02Io
o`0067oo0`00Egoo0P003EKl00<005KlE_`00UKl00<007ooOol01goo00<007ooOol067oo00<007oo
Ool09Goo000FOol2001GOol3000?E_`00`00E_aFo003E_`00`00Oomoo`06Ool00`00Oomoo`0HOol0
0`00Oomoo`0UOol001Aoo`8005Moo`80019Fo003001Fo5Kl00AFo003001oogoo00Eoo`03001oogoo
01Uoo`03001oogoo02Aoo`004Woo0P00EWoo0`004eKl00<005KlE_`01EKl00<007ooOol01Goo00<0
07ooOol06Woo00<007ooOol08goo000BOol2001DOol2000FE_`00`00E_aFo006E_`00`00Oomoo`04
Ool00`00Oomoo`0JOol00`00Oomoo`0SOol0019oo`03001oo`00051oo`<001QFo003001Fo5Kl00MF
o003001oogoo00=oo`03001oogoo01]oo`03001oogoo029oo`004Woo00@007ooOol004aoo`<001]F
o003001Fo5Kl00MFo003001oogoo00=oo`03001oogoo01aoo`03001oogoo025oo`004Goo00<007oo
Ool00Woo00<007ooOol0Agoo0P007UKl00<005KlE_`025Kl00<007ooOol00Woo00<007ooOol077oo
00<007ooOol08Goo000AOol00`00Oomoo`03Ool00`00Oomoo`13Ool3000PE_`00`00E_aFo009E_`0
1@00Oomoogoo00007goo00<007ooOol087oo000AOol00`00Oomoo`04Ool00`00Oomoo`10Ool2000R
E_`00`00E_aFo00:E_`01@00Oomoogoo00007goo00<007ooOol087oo000AOol00`00Oomoo`05Ool0
0`00Oomoo`0lOol3000TE_`00`00E_aFo00;E_`01000Oomoo`0087oo00<007ooOol07goo000AOol0
0`00Oomoo`06Ool00`00Oomoo`0iOol2000WE_`00`00E_aFo00<E_`00`00Ool0000QOol00`00Oomo
o`0NOol0015oo`03001oogoo00Moo`03001oogoo03Eoo`<002UFo003001Fo5Kl00aFo003001oo`00
025oo`03001oogoo01ioo`0047oo00<007ooOol02Goo00<007ooOol0<Woo0P00;5Kl00<005KlE_`0
3EKl00<007oo00008Goo00<007ooOol07Goo000@Ool00`00Oomoo`0:Ool00`00Oomoo`0^Ool3000^
E_`00`00E_aFo00>E_`2000QOol00`00Oomoo`0MOol0011oo`03001oogoo00]oo`03001oogoo02Yo
o`<0031Fo003001Fo5Kl011Fo003001oogoo021oo`03001oogoo01aoo`0047oo00<007ooOol037oo
00<007ooOol09goo0P00<eKl00<005KlE_`045Kl00<007ooOol08Goo00<007ooOol06goo000@Ool0
0`00Oomoo`0=Ool00`00Oomoo`0SOol3000eE_`00`00E_aFo00@E_`2000ROol00`00Oomoo`0KOol0
011oo`03001oogoo00ioo`03001oogoo021oo`8003QFo003001Fo5Kl011Fo003001Fo000029oo`03
001oogoo01Yoo`0047oo00<007ooOol03goo00<007ooOol077oo0`00>UKl00<005KlE_`045Kl00<0
05Kl00008Woo00<007ooOol06Woo000?Ool00`00Oomoo`0AOol00`00Oomoo`0IOol2000mE_`00`00
E_aFo00@E_`01000E_aFo0008Woo00<007ooOol06Goo000?Ool00`00Oomoo`0BOol00`00Oomoo`0E
Ool3000nE_`00`00E_aFo00AE_`01@00E_aFo5Kl00008Woo00<007ooOol067oo000?Ool00`00Oomo
o`0COol00`00Oomoo`0AOol30011E_`00`00E_aFo00AE_`01@00E_aFo5Kl00008Woo00<007ooOol0
67oo000?Ool00`00Oomoo`0DOol00`00Oomoo`0>Ool20014E_`00`00E_aFo00AE_`00`00E_aFo002
E_`00`00Oomoo`0POol00`00Oomoo`0GOol000moo`03001oogoo01Eoo`03001oogoo00Yoo`<004IF
o003001Fo5Kl015Fo003001Fo5Kl00=Fo003001oogoo01moo`03001oogoo01Moo`003goo00<007oo
Ool05Woo00<007ooOol01goo0P00BEKl00<005KlE_`04EKl00<005KlE_`00eKl00<007ooOol087oo
00<007ooOol05Woo000>Ool00`00Oomoo`0HOol00`00Oomoo`04Ool2001;E_`00`00E_aFo00AE_`0
0`00E_aFo004E_`00`00Oomoo`0POol00`00Oomoo`0EOol000ioo`03001oogoo01Uoo`03001oogoo
00Aoo`03001Fo5Kl04QFo003001Fo5Kl019Fo003001Fo5Kl00EFo003001oogoo01moo`03001oogoo
01Eoo`003Woo00<007ooOol06Woo00<007ooOol00goo0P00BEKl00<005KlE_`04UKl00<005KlE_`0
1EKl00<007ooOol087oo00<007ooOol057oo000>Ool00`00Oomoo`0KOol00`00Oomoo`03Ool20018
E_`00`00E_aFo00BE_`00`00E_aFo006E_`00`00Oomoo`0POol00`00Oomoo`0COol000ioo`03001o
ogoo01aoo`03001oogoo00=oo`8004MFo003001Fo5Kl019Fo003001Fo5Kl00MFo003001oogoo01mo
o`03001oogoo01=oo`003Woo00<007ooOol07Goo00<007ooOol00goo0P00AUKl00<005KlE_`04eKl
00<005KlE_`01eKl00<007ooOol07goo00<007ooOol04Woo000>Ool00`00Oomoo`0NOol00`00Oomo
o`02Ool00`00Ool00015E_`00`00E_aFo00CE_`00`00E_aFo007E_`00`00Oomoo`0OOol00`00Oomo
o`0BOol000eoo`03001oogoo021oo`03001oogoo009oo`03001oo`0004=Fo003001Fo5Kl01AFo003
001Fo5Kl00QFo003001oogoo01moo`03001oogoo015oo`003Goo00<007ooOol08Goo00<007ooOol0
0Woo00<007oo0000@UKl00<005KlE_`055Kl00<005KlE_`02EKl00<007ooOol07goo00<007ooOol0
47oo000=Ool00`00Oomoo`0ROol01@00Oomoogoo00000Woo00<005KlE_`0?eKl00<005KlE_`055Kl
00<005KlE_`02EKl00<007ooOol07goo00<007ooOol047oo000=Ool00`00Oomoo`0SOol01@00Oomo
ogoo00000Woo00<005KlE_`0?UKl00<005KlE_`055Kl00<005KlE_`02UKl00<007ooOol07goo00<0
07ooOol03goo000=Ool00`00Oomoo`0TOol01@00Oomoogoo00000Woo00<005KlE_`0?EKl00<005Kl
E_`055Kl00<005KlE_`02eKl00<007ooOol07Woo00<007ooOol03goo000=Ool00`00Oomoo`0TOol0
1@00Oomoogoo00000goo00<005KlE_`0?5Kl00<005KlE_`055Kl00<005KlE_`02eKl00<007ooOol0
7Woo0P0047oo000<Ool00`00Oomoo`0VOol01@00Oomoogoo00000goo00<005KlE_`0>UKl00<005Kl
E_`05EKl00<005KlE_`035Kl00<007ooOol06Woo0`0000=oo`00Ool03goo000<Ool00`00Oomoo`0W
Ool01@00Oomoogoo00000goo00<005KlE_`0>EKl00<005KlE_`05EKl00<005KlE_`03EKl00<007oo
Ool05Woo0`0017oo00<007ooOol03Woo000<Ool00`00Oomoo`0XOol01@00Oomoogoo00000goo00<0
05KlE_`0>5Kl00<005KlE_`05EKl00<005KlE_`03EKl00<007ooOol04goo0`001goo00<007ooOol0
3Woo000<Ool00`00Oomoo`0YOol01000Oomoo`0017oo00<005KlE_`0=eKl00<005KlE_`05EKl00<0
05KlE_`03UKl00<007ooOol03goo0`002goo00<007ooOol03Goo000<Ool00`00Oomoo`0ZOol01000
Oomoo`0017oo00<005KlE_`0=UKl00<005KlE_`05EKl00<005KlE_`03eKl00<007ooOol02goo0`00
3Woo00<007ooOol03Goo000<Ool00`00Oomoo`0[Ool01000Oomoo`0017oo00<005KlE_`0=EKl00<0
05KlE_`05EKl00<005KlE_`045Kl00<007ooOol01goo0`004Goo00<007ooOol03Goo000<Ool00`00
Oomoo`0/Ool00`00Ool00005Ool00`00E_aFo00cE_`00`00E_aFo00FE_`00`00E_aFo00@E_`00`00
Oomoo`04Ool3000DOol00`00Oomoo`0=Ool000]oo`03001oogoo02ioo`03001oo`0000Eoo`03001F
o5Kl039Fo003001Fo5Kl01IFo003001Fo5Kl015Fo003001oogoo00<001Moo`03001oogoo00eoo`00
2goo00<007ooOol0;goo00<007oo00001Goo00<005KlE_`0<EKl00<005KlE_`05UKl00<005KlE_`0
4UKl0P006Woo00<007ooOol03Goo000;Ool00`00Oomoo`0`Ool20006Ool00`00E_aFo00`E_`00`00
E_aFo00GE_`00`00E_aFo00AE_`00`00Oomoo`0IOol00`00Oomoo`0=Ool000]oo`03001oogoo035o
o`8000Ioo`03001Fo5Kl02mFo003001Fo5Kl01MFo003001Fo5Kl015Fo08001Yoo`03001oogoo00eo
o`002goo00<007ooOol0<Woo0P001Goo00<005KlE_`0;eKl00<005KlE_`05eKl00<005KlE_`03UKl
100077oo00<007ooOol037oo000;Ool00`00Oomoo`0cOol20005Ool00`00E_aFo00]E_`00`00E_aF
o00HE_`00`00E_aFo00;E_`30002Ool00`00Oomoo`0KOol00`00Oomoo`0<Ool000Yoo`03001oogoo
03Eoo`03001oogoo00Aoo`03001Fo5Kl02aFo003001Fo5Kl01QFo003001Fo5Kl00QFo0<000Aoo`03
001oogoo01aoo`03001oogoo00aoo`002Woo00<007ooOol0=Woo00<007ooOol017oo00<005KlE_`0
:eKl00<005KlE_`065Kl00<005KlE_`01EKl0`001Woo00<007ooOol07Goo00<007ooOol037oo000:
Ool00`00Oomoo`0gOol00`00Oomoo`04Ool00`00E_aFo00ZE_`00`00E_aFo00HE_`00`00E_aFo002
E_`30009Ool00`00Oomoo`0MOol00`00Oomoo`0<Ool000Yoo`03001oogoo03Moo`8000Ioo`03001F
o5Kl02UFo003001Fo5Kl01QFo0D000]oo`03001oogoo01ioo`03001oogoo00aoo`002Woo00<007oo
Ool0>7oo0P001Woo00<005KlE_`0:5Kl00<005KlE_`05UKl0`003Woo00<007ooOol07goo00<007oo
Ool037oo000:Ool00`00Oomoo`0iOol20006Ool00`00E_aFo00VE_`00`00E_aFo00DE_`30002Ool0
0`00Oomoo`0;Ool00`00Oomoo`0QOol00`00Oomoo`0;Ool000Yoo`03001oogoo03Yoo`8000Ioo`03
001Fo5Kl02EFo003001Fo5Kl015Fo0<000Eoo`03001oogoo00Yoo`03001oogoo029oo`03001oogoo
00]oo`002Goo00<007ooOol0>goo00<007oo00001Woo00<005KlE_`095Kl00<005KlE_`03UKl0`00
27oo00<007ooOol02Goo00<007ooOol08goo00<007ooOol02goo0009Ool00`00Oomoo`0lOol00`00
Ool00006Ool00`00E_aFo00SE_`00`00E_aFo00;E_`3000;Ool00`00Oomoo`08Ool00`00Oomoo`0T
Ool00`00Oomoo`0;Ool000Uoo`03001oogoo03eoo`03001oo`0000Ioo`03001Fo5Kl029Fo003001F
o5Kl00QFo0<000ioo`03001oogoo00Moo`03001oogoo02Eoo`03001oogoo00]oo`002Goo00<007oo
Ool0?Goo00@007ooOol000Ioo`03001Fo5Kl025Fo003001Fo5Kl00EFo0<0015oo`03001oogoo00Io
o`03001oogoo02Ioo`03001oogoo00]oo`002Goo00<007ooOol0?Woo00@007ooOol000Ioo`03001F
o5Kl01mFo003001Fo5Kl00=Fo0<001Aoo`03001oogoo00Ioo`03001oogoo02Ioo`03001oogoo00]o
o`002Goo00<007ooOol0?goo00@007ooOol000Ioo`03001Fo5Kl01iFo003001Fo5Kl00<001Moo`03
001oogoo00Eoo`03001oogoo02Moo`03001oogoo00]oo`0027oo00<007ooOol0@7oo00D007ooOomo
o`0000Ioo`03001Fo5Kl01eFo0<001Yoo`03001oogoo00Aoo`03001oogoo02Uoo`03001oogoo00Yo
o`0027oo00<007ooOol0@Goo00D007ooOomoo`0000Ioo`03001Fo5Kl01UFo0@001eoo`03001oogoo
009oo`03001oogoo02Yoo`03001oogoo00Yoo`0027oo00<007ooOol0@Woo00D007ooOomoo`0000Io
o`03001Fo5Kl01AFo0@000=oo`03001oogoo01]oo`05001oogooOol0000]Ool00`00Oomoo`0:Ool0
00Qoo`03001oogoo04=oo`05001oogooOol00006Ool00`00E_aFo00@E_`30007Ool00`00Oomoo`0K
Ool01000Oomoo`00;Woo00<007ooOol02Woo0008Ool00`00Oomoo`13Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00E_aFo00<E_`30009Ool00`00Oomoo`0LOol00`00Ool0000_Ool00`00Oomoo`0:
Ool000Qoo`03001oogoo04Aoo`03001oogoo009oo`03001oogoo00Aoo`03001Fo5Kl00QFo0<000ao
o`03001oogoo01aoo`80031oo`03001oogoo00Yoo`0027oo00<007ooOol0AGoo00<007ooOol00Woo
00<007ooOol017oo00<005KlE_`015Kl0`003goo00<007ooOol077oo00<007ooOol0;goo00<007oo
Ool02Woo0007Ool00`00Oomoo`16Ool00`00Oomoo`03Ool00`00Oomoo`03000017oo001Fo5Kl0`00
4Woo00<007ooOol06goo0P00<Woo00<007ooOol02Goo0007Ool00`00Oomoo`17Ool00`00Oomoo`03
Ool20005Ool2000EOol00`00Oomoo`0KOol2000bOol00`00Oomoo`09Ool000Moo`03001oogoo04Qo
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo01Yoo`<0039oo`03001o
ogoo00Uoo`001goo00<007ooOol0BGoo00D007ooOomoo`0000Moo`03001oogoo019oo`03001oogoo
01Uoo`<0009oo`03001oogoo02moo`03001oogoo00Uoo`001goo00<007ooOol0BGoo00D007ooOomo
o`0000Moo`03001oogoo019oo`03001oogoo01Eoo`D000Eoo`03001oogoo02ioo`03001oogoo00Uo
o`001goo00<007ooOol0BWoo00@007ooOol000Qoo`03001oogoo015oo`03001oogoo019oo`<000=o
o`03001oogoo00Aoo`03001oogoo02ioo`03001oogoo00Uoo`001Woo00<007ooOol0C7oo00<007oo
000027oo00<007ooOol04Goo00<007ooOol03goo0`001Goo00<007ooOol01Woo00<007ooOol0;Goo
00<007ooOol02Goo0006Ool00`00Oomoo`1<Ool00`00Ool00008Ool00`00Oomoo`0AOol00`00Oomo
o`0<Ool30007Ool00`00Oomoo`08Ool00`00Oomoo`0/Ool00`00Oomoo`09Ool000Ioo`03001oogoo
04eoo`8000Uoo`03001oogoo011oo`03001oogoo00Uoo`<000Uoo`03001oogoo00Yoo`03001oogoo
02aoo`03001oogoo00Qoo`001Woo00<007ooOol0CWoo00<007ooOol01goo00<007ooOol03goo00<0
07ooOol01Woo10002goo00<007ooOol037oo00<007ooOol0:goo00<007ooOol027oo0006Ool00`00
Oomoo`1>Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool3000?Ool00`00Oomoo`0<
Ool00`00Oomoo`0[Ool00`00Oomoo`08Ool000Ioo`03001oogoo04ioo`8000Uoo`03001oogoo00io
o`03001oogoo00<0015oo`03001oogoo00ioo`03001oogoo02Yoo`03001oogoo00Qoo`001Woo00<0
07ooOol0CWoo00<007oo000027oo00<007ooOol03Woo0`004goo00<007ooOol047oo00<007ooOol0
:Goo00<007ooOol027oo0005Ool00`00Oomoo`1?Ool01000Oomoo`0027oo00<007ooOol02Woo1000
57oo00<007ooOol04Woo00<007ooOol0:7oo00<007ooOol027oo0005Ool00`00Oomoo`1?Ool01000
Oomoo`0027oo00<007ooOol01Woo10000goo00<007ooOol04Goo00<007ooOol057oo00<007ooOol0
9goo00<007ooOol027oo0005Ool00`00Oomoo`1?Ool01@00Oomoogoo00001goo00<007ooOol00goo
0`001Woo00<007ooOol04Goo00<007ooOol05Goo00<007ooOol0:7oo00<007ooOol01goo0005Ool0
0`00Oomoo`1?Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Ool000020009Ool00`00Oomoo`0@
Ool00`00Oomoo`0GOol00`00Oomoo`0WOol00`00Oomoo`07Ool000Eoo`03001oogoo04moo`03001o
ogoo009oo`03001oogoo00Aoo`<000aoo`03001oogoo00moo`03001oogoo01Uoo`03001oogoo02Io
o`03001oogoo00Moo`001Goo00<007ooOol0Cgoo00<007ooOol00goo00<007oo00000`000Woo00<0
07ooOol02Woo00<007ooOol03Woo00<007ooOol06goo00<007ooOol09Goo00<007ooOol01goo0004
Ool00`00Oomoo`1?Ool00`00Oomoo`03Ool30006Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00
Oomoo`0LOol00`00Oomoo`0TOol00`00Oomoo`07Ool000Aoo`03001oogoo04moo`03001oogoo00<0
009oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo01eoo`03001oogoo
02Aoo`03001oogoo00Moo`0017oo00<007ooOol0Cgoo0`001Woo00<007ooOol017oo00<007ooOol0
27oo00<007ooOol03Goo00<007ooOol07goo00<007ooOol08goo00<007ooOol01goo0004Ool00`00
Oomoo`1<Ool40009Ool00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`0Q
Ool00`00Oomoo`0ROol00`00Oomoo`07Ool000Aoo`03001oogoo04Qoo`@000=oo`03001oogoo00Qo
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00]oo`03001oogoo02=oo`03001oogoo029o
o`03001oogoo00Ioo`0017oo00<007ooOol0AGoo0`001goo00<007ooOol027oo00<007ooOol00goo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol09Goo00<007ooOol08Goo00<007ooOol01Woo
0004Ool00`00Oomoo`12Ool3000:Ool00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`0QOol00`00Oomoo`06Ool000=oo`03001oogoo
041oo`<000eoo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo02Qoo`03001oogoo021oo`03001oogoo00Ioo`000goo00<007ooOol0?7oo100047oo00<0
07ooOol02Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol027oo00<007ooOol0:Woo00<0
07ooOol07goo00<007ooOol01Woo0003Ool00`00Oomoo`0iOol3000DOol00`00Oomoo`0;Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`00Oomoo`0NOol00`00
Oomoo`06Ool000=oo`03001oogoo03Ioo`<001Moo`03001oogoo00aoo`05001oogooOol00006Ool0
0`00Oomoo`07Ool00`00Oomoo`0]Ool00`00Oomoo`0MOol00`00Oomoo`06Ool000=oo`03001oogoo
03=oo`<001Yoo`03001oogoo00eoo`04001oogoo0006Ool00`00Oomoo`06Ool00`00Oomoo`0^Ool0
0`00Oomoo`0NOol00`00Oomoo`05Ool000=oo`03001oogoo031oo`<001eoo`03001oogoo00eoo`05
001oogooOol00005Ool00`00Oomoo`05Ool00`00Oomoo`0`Ool00`00Oomoo`0MOol00`00Oomoo`05
Ool0009oo`03001oogoo02eoo`@0021oo`03001oogoo00ioo`04001oogoo0005Ool00`00Oomoo`04
Ool00`00Oomoo`0bOol00`00Oomoo`0LOol00`00Oomoo`05Ool0009oo`03001oogoo02Yoo`<002Ao
o`03001oogoo00moo`03001oo`0000Aoo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo01]o
o`03001oogoo00Eoo`000Woo00<007ooOol09goo0`009goo00<007ooOol03goo00@007ooOol000=o
o`03001oogoo00=oo`03001oogoo03Ioo`03001oogoo01Yoo`03001oogoo00Eoo`000Woo00<007oo
Ool097oo0`00:Woo00<007ooOol047oo00<007oo00000goo00<007ooOol00Woo00<007ooOol0=goo
00<007ooOol06Woo00<007ooOol01Goo0002Ool00`00Oomoo`0QOol3000]Ool00`00Oomoo`0AOol0
0`00Ool00002Ool01@00Oomoogoo0000>goo00<007ooOol06Goo00<007ooOol01Goo0002Ool00`00
Oomoo`0MOol4000UOol00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Ool00002Ool01000Oomoo`00
?Goo00<007ooOol06Goo00<007ooOol017oo0002Ool00`00Oomoo`0JOol3000dOol00`00Oomoo`0B
Ool20002Ool01000Oomoo`00?Woo00<007ooOol067oo00<007ooOol017oo00000goo001oo`0IOol3
000gOol00`00Oomoo`0COol30002Ool00`00Oomoo`0nOol00`00Oomoo`0GOol00`00Oomoo`04Ool0
0003Ool007oo01Ioo`<003Yoo`03001oogoo01Aoo`800003Ool007oo041oo`03001oogoo01Moo`03
001oogoo00Aoo`0000=oo`00Ool04Woo1000?Goo00<007ooOol057oo0`00@goo00<007ooOol05Woo
00<007ooOol017oo00000goo001oo`0?Ool30011Ool00`00Oomoo`0EOol00`00Oomoo`13Ool00`00
Oomoo`0EOol00`00Oomoo`04Ool00003Ool007oo00aoo`<004Aoo`03001oogoo05aoo`03001oogoo
01Aoo`03001oogoo00Aoo`0000=oo`00Ool02Goo0`00Agoo00<007ooOol0GGoo00<007ooOol04goo
00<007ooOol017oo00000`00Oomoo`06Ool3001:Ool00`00Oomoo`1NOol00`00Oomoo`0COol00`00
Oomoo`03Ool00003001oogoo009oo`@004eoo`03001oogoo05ioo`03001oogoo01=oo`03001oogoo
00=oo`0000<007oo00000P00DGoo00<007ooOol0=Woo00<007ooOol09Woo00<007ooOol04Woo00<0
07ooOol00goo0002001DOol00`00Oomoo`1POol00`00Oomoo`0AOol00`00Oomoo`03Ool00003Ool0
000005=oo`03001oogoo065oo`03001oogoo011oo`03001oogoo00=oo`000goo00<007ooOol0D7oo
00<007ooOol0HWoo00<007ooOol03goo00<007ooOol00goo0004Ool2001@Ool00`00Oomoo`1ROol0
0`00Oomoo`0?Ool00`00Oomoo`03Ool000Ioo`03001oogoo04eoo`03001oogoo06=oo`03001oogoo
00moo`03001oogoo009oo`001goo00<007ooOol0C7oo00<007ooOol0I7oo00<007ooOol03Woo00<0
07ooOol00Woo0008Ool2001;Ool00`00Oomoo`1VOol00`00Oomoo`0=Ool00`00Oomoo`02Ool000Yo
o`03001oogoo04Qoo`03001oogoo06Moo`03001oogoo00aoo`03001oogoo009oo`002goo0P00B7oo
00<007ooOol0Igoo00<007ooOol037oo00<007ooOol00Woo000=Ool00`00Oomoo`15Ool00`00Oomo
o`1XOol00`00Oomoo`0;Ool00`00Oomoo`02Ool000ioo`8004Eoo`03001oogoo06Uoo`03001oogoo
00Yoo`03001oogoo009oo`0047oo00<007ooOol0@Woo00<007ooOol0JWoo00<007ooOol02Goo00<0
07ooOol00Woo000AOol20012Ool00`00Oomoo`1[Ool00`00Oomoo`09Ool00`00Oomoo`01Ool001=o
o`03001oogoo03moo`03001oogoo06]oo`03001oogoo00Uoo`03001oogoo005oo`0057oo00<007oo
Ool0?Woo00<007ooOol0K7oo00<007ooOol027oo00<007ooOol00Goo000EOol2000nOol00`00Oomo
o`1]Ool00`00Oomoo`07Ool00`00Oomoo`01Ool001Moo`03001oogoo03]oo`03001oogoo06ioo`03
001oogoo00Ioo`03001oogoo005oo`0067oo0P00>goo00<007ooOol0Kgoo00<007ooOol01Goo00<0
07ooOol00Goo000JOol00`00Oomoo`0hOol00`00Oomoo`1_Ool00`00Oomoo`05Ool00`00Oomoo`01
Ool001]oo`8003Qoo`03001oogoo071oo`03001oogoo00Eoo`40005oo`5oo`007Goo00<007ooOol0
=Goo00<007ooOol0LGoo00<007ooOol017oo0@000Goo0Goo000NOol2000eOol00`00Oomoo`1bOol0
0`00Oomoo`03Ool10001Ool1Ool0021oo`03001oogoo039oo`03001oogoo07=oo`03001oogoo009o
o`40005oo`5oo`008Goo0P00<Woo00<007ooOol0Lgoo00<007ooOol00Woo0@000Goo0Goo000SOol0
0`00Oomoo`0_Ool00`00Oomoo`1dOol01@00Oomoogoo00000Woo000TOol00`00Oomoo`0^Ool00`00
Oomoo`1eOol01000Oomoo`000Woo000UOol2000^Ool00`00Oomoo`1fOol00`00Ool00002Ool002Mo
o`03001oogoo02]oo`03001oogoo07Moo`03001oo`00005oo`00:7oo0P00:goo00<007ooOol0Mgoo
00<007oo00000Goo000ZOol00`00Oomoo`0XOol00`00Oomoo`1hOol20001Ool002]oo`8002Qoo`03
001oogoo07Moo`<0005oo`00;Goo00<007ooOol09Goo00<007ooOol0Lgoo100017oo000^Ool2000U
Ool00`00Oomoo`1^Ool50008Ool0031oo`03001oogoo029oo`03001oogoo06Yoo`@000eoo`00<Goo
00<007ooOol08Goo00<007ooOol0IGoo1@004Goo000bOol2000QOol00`00Oomoo`1QOol4000FOol0
03Aoo`03001oogoo01ioo`03001oogoo05aoo`D001Yoo`00=Goo0P007Woo00<007ooOol0F7oo1000
7goo000gOol00`00Oomoo`0KOol00`00Oomoo`1DOol4000SOol003Qoo`8001]oo`03001oogoo04mo
o`D002Moo`00>Woo00<007ooOol067oo00<007ooOol0Bgoo1000;7oo000kOol2000GOol00`00Oomo
o`17Ool5000`Ool003eoo`03001oogoo01Aoo`03001oogoo04=oo`@003Eoo`00?Woo00<007ooOol0
4goo00<007ooOol0?Woo1@00>Goo000oOol2000COol00`00Oomoo`0jOol4000nOol0045oo`03001o
ogoo011oo`03001oogoo03Eoo`D0049oo`00@Woo0P0047oo00<007ooOol0<Goo1000Agoo0014Ool0
0`00Oomoo`0=Ool00`00Oomoo`0/Ool5001;Ool004Eoo`8000eoo`03001oogoo02Qoo`@0051oo`00
Agoo00<007ooOol02Woo00<007ooOol08goo1@00E7oo0018Ool2000:Ool00`00Oomoo`0OOol4001I
Ool004Yoo`03001oogoo00Moo`03001oogoo01]oo`@005eoo`00Bgoo0P001goo00<007ooOol05Woo
1@00HGoo001=Ool00`00Oomoo`04Ool00`00Oomoo`0BOol4001VOol004ioo`03001oogoo00=oo`03
001oogoo00eoo`D006Yoo`00Cgoo0P000goo00<007ooOol02Goo1000Kgoo001AOol01000Oomoo`00
1Woo1@00Lgoo001BOol30002Ool4001hOol005Aoo`<007aoo`00\
\>"],
  ImageRangeCache->{{{0, 210}, {227, 0}} -> {0.0468363, -4.65453*^-06, 
  0.00410091, 0.00410091}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To show the pyramid in another orientation, a set of four Euler parameters \
are fabricated that represent the desired angular orientation. Normally, ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions are used in conjunction with a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule that contains the values of the Euler parameters needed, \
but in this case they are generated explicitly.\n\nThe pyramid is now rotated \
0.5 radians about the global ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis. The ",
  StyleBox["EulerParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function returns the Euler parameters required for this rotation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"These Euler parameters represent a rotation of 0.5 radians about the {0, 0, \
1} axis."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(EulerParameters[{.5, {0, 0, 1}}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.9689124217106448`, 0, 0, 0.24740395925452292`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Now the parameters are turned into rules for ",
  StyleBox["Eo2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ei2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ej2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Ek2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ang = Thread[EulerParameters[2] \[Rule] %]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({Eo2 \[Rule] 0.9689124217106448`, Ei2 \[Rule] 0, Ej2 \[Rule] 0, 
      Ek2 \[Rule] 0.24740395925452292`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is ",
  StyleBox["bdgraph",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rotated 0.5 radians about the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      \(bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] 0, Z2 \[Rule] 0}\) /. ang]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 2.22045e-016 1.16608 [
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
.5 Mabswid
.72228 .54106 m .32885 .5402 L .29841 .26287 L p .668 .734 .899 r
F P
0 g
s
.29841 .26287 m .75572 .26403 L .72228 .54106 L p .668 .734 .899 r
F P
0 g
s
.52632 .77472 m
.72228 .54106 L
s
.32885 .5402 m
.52632 .77472 L
s
.01 w
.6399 .83455 Mdot
.5 Mabswid
.52632 .77472 m
.75572 .26403 L
s
.29841 .26287 m
.52632 .77472 L
s
.01 w
.40269 .7096 Mdot
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 229},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D0000iA000`40O003h00OS7oo0P00AWoo002:
Ool200000goo00000015Ool008Qoo`8000=oo`8004Eoo`00QGoo0`001Goo00<007oo0000A7oo0023
Ool20008Ool00`00Ool00014Ool0085oo`8000Yoo`04001oogoo0013Ool007ioo`<000aoo`05001o
ogooOol00012Ool007aoo`8000moo`05001oogooOol00012Ool007Yoo`80015oo`03001oogoo009o
o`03001oogoo03moo`00Mgoo0`0057oo00<007ooOol00Woo00<007ooOol0?Woo001eOol2000GOol0
0`00Oomoo`02Ool00`00Oomoo`0nOol007=oo`8001Uoo`03001oogoo00=oo`03001oogoo03eoo`00
L7oo0`006goo00<007ooOol00goo00<007ooOol0?Goo001^Ool2000NOol00`00Oomoo`04Ool00`00
Oomoo`0lOol006]oo`<0021oo`03001oogoo00Eoo`03001oogoo03]oo`00JGoo0P008goo00<007oo
Ool01Goo00<007ooOol0>goo001WOol2000UOol00`00Oomoo`06Ool00`00Oomoo`0jOol006Aoo`<0
02Moo`03001oogoo00Ioo`03001oogoo03Yoo`00HWoo0P00:Woo00<007ooOol01goo00<007ooOol0
>Goo001POol2000/Ool00`00Oomoo`08Ool00`00Oomoo`0hOol005eoo`<002ioo`03001oogoo00Qo
o`03001oogoo03Qoo`00Fgoo0P00<Goo00<007ooOol02Goo00<007ooOol0=goo001IOol2000cOol0
0`00Oomoo`09Ool00`00Oomoo`0gOol005Ioo`<003Eoo`03001oogoo00Yoo`03001oogoo03Ioo`00
E7oo0P00>7oo00<007ooOol02goo00<007ooOol0=Goo001BOol2000jOol00`00Oomoo`0;Ool00`00
Oomoo`0eOol004moo`<003aoo`03001oogoo00aoo`03001oogoo03Aoo`00CGoo0P00@7oo00<007oo
Ool037oo00<007ooOol0<goo001;Ool20012Ool00`00Oomoo`0<Ool00`00Oomoo`0cOol004Qoo`<0
04Aoo`03001oogoo00eoo`03001oogoo039oo`00AWoo0P00Agoo00<007ooOol03Goo00<007ooOol0
<Woo0014Ool20019Ool00`00Oomoo`0>Ool00`00Oomoo`0aOol0045oo`<004]oo`03001oogoo00mo
o`03001oogoo031oo`00?goo0P00CWoo00<007ooOol03goo00<007ooOol0<7oo000mOol2001@Ool0
0`00Oomoo`0@Ool00`00Oomoo`0_Ool003Yoo`<0059oo`03001oogoo011oo`03001oogoo02moo`00
>7oo0P00EGoo00<007ooOol04Goo00<007ooOol0;Woo000fOol2001GOol00`00Oomoo`0BOol00`00
Oomoo`0]Ool003=oo`<005Uoo`03001oogoo019oo`03001oogoo02eoo`00<Goo0P00G7oo00<007oo
Ool04goo00<007ooOol0;7oo000^Ool3001NOol00`00Oomoo`0DOol00`00Oomoo`0[Ool002aoo`80
065oo`03001oogoo01Aoo`03001oogoo02]oo`00:Woo0P00Hgoo00<007ooOol05Goo00<007ooOol0
:Woo000WOol3001UOol00`00Oomoo`0EOol00`00Oomoo`0ZOol002Eoo`8006Uoo`03001oogoo01Eo
o`03001oogoo02Uoo`008goo0P00Jgoo00<007ooOol05Woo00<007ooOol0:7oo000POol3001]Ool0
0`00Oomoo`0FOol00`00Oomoo`0XOol001ioo`80071oo`03001oogoo01Moo`03001oogoo02Moo`00
77oo0P00LWoo00<007ooOol05goo00<007ooOol09goo000IOol3001dOol00`00Oomoo`0HOol00`00
Oomoo`0VOol001Moo`8007Moo`03001oogoo01Uoo`03001oogoo02Eoo`005Goo0P00NGoo00<007oo
Ool06Goo00<007ooOol09Goo000COol2001kOol00`00Oomoo`0JOol00`00Oomoo`0TOol001=oo`80
07]oo`03001oogoo01]oo`03001oogoo02=oo`004goo00<007oo0000NWoo00<007ooOol06goo00<0
07ooOol08goo000COol01000Oomoo`00NGoo00<007ooOol077oo00<007ooOol08Woo000BOol00`00
Oomoo`02Ool00`00Oomoo`0UOomQ000?Ool00`00Oomoo`0ROol0019oo`03001oogoo00=oo`03001o
ogoo02Aoo`03001Fo5Kl04iFo003001Fo5Kl00aFo003001oogoo00ioo`03001oogoo025oo`004Woo
00<007ooOol017oo00<007ooOol08goo0P00CeKl00<005KlE_`02eKl0P004Goo00<007ooOol087oo
000BOol00`00Oomoo`05Ool00`00Oomoo`0ROol2001?E_`00`00E_aFo00;E_`2000AOol00`00Oomo
o`0POol0019oo`03001oogoo00Ioo`03001oogoo025oo`03001Fo00004iFo003001Fo5Kl00YFo003
001Fo000019oo`03001oogoo01moo`004Woo00<007ooOol01goo00<007ooOol08Goo0P00CUKl00<0
05KlE_`02UKl0P004goo00<007ooOol07goo000AOol00`00Oomoo`09Ool00`00Oomoo`0POol00`00
E_`0001>E_`00`00E_aFo008E_`00`00E_`0000DOol00`00Oomoo`0NOol0015oo`03001oogoo00Yo
o`03001oogoo01moo`03001Fo00004iFo003001Fo5Kl00QFo003001Fo00001Eoo`03001oogoo01eo
o`004Goo00<007ooOol02goo00<007ooOol07Woo00@005KlE_`004eFo003001Fo5Kl00MFo004001F
o5Kl000EOol00`00Oomoo`0MOol0015oo`03001oogoo00aoo`03001oogoo01eoo`04001Fo5Kl001=
E_`00`00E_aFo007E_`01000E_aFo0005Woo00<007ooOol077oo000AOol00`00Oomoo`0=Ool00`00
Oomoo`0LOol01000E_aFo000CEKl00<005KlE_`01eKl00@005KlE_`001Ioo`03001oogoo01aoo`00
4Goo00<007ooOol03Woo00<007ooOol06goo00D005KlE_aFo00004aFo003001Fo5Kl00IFo005001F
o5KlE_`0000GOol00`00Oomoo`0KOol0011oo`03001oogoo011oo`03001oogoo01Yoo`05001Fo5Kl
E_`0001<E_`00`00E_aFo006E_`01@00E_aFo5Kl000067oo00<007ooOol06Woo000@Ool00`00Oomo
o`0AOol00`00Oomoo`0IOol00`00E_aFo002E_`00`00E_aFo019E_`00`00E_aFo005E_`01@00E_aF
o5Kl00006Goo00<007ooOol06Woo000@Ool00`00Oomoo`0AOol00`00Oomoo`0IOol00`00E_aFo002
E_`00`00E_aFo019E_`00`00E_aFo005E_`01@00E_aFo5Kl00006Woo00<007ooOol06Goo000@Ool0
0`00Oomoo`0BOol00`00Oomoo`0IOol00`00E_aFo002E_`00`00E_aFo018E_`00`00E_aFo004E_`0
0`00E_aFo002E_`00`00Oomoo`0IOol00`00Oomoo`0HOol0011oo`03001oogoo01=oo`03001oogoo
01Qoo`03001Fo5Kl009Fo003001Fo5Kl04QFo003001Fo5Kl00AFo003001Fo5Kl009Fo003001oogoo
01Uoo`03001oogoo01Qoo`0047oo00<007ooOol057oo00<007ooOol05goo00<005KlE_`00eKl00<0
05KlE_`0AeKl00<005KlE_`00eKl00<005KlE_`00eKl00<007ooOol06Woo00<007ooOol05goo000?
Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00E_aFo003E_`00`00E_aFo017E_`00`00E_aFo003
E_`00`00E_aFo003E_`00`00Oomoo`0JOol00`00Oomoo`0GOol000moo`03001oogoo01Moo`03001o
ogoo01Eoo`03001Fo5Kl00AFo003001Fo5Kl04IFo003001Fo5Kl009Fo003001Fo5Kl00AFo003001o
ogoo01]oo`03001oogoo01Ioo`003goo00<007ooOol067oo00<007ooOol057oo00<005KlE_`015Kl
00<005KlE_`0AUKl00<005KlE_`00UKl00<005KlE_`015Kl00<007ooOol077oo00<007ooOol05Goo
000?Ool00`00Oomoo`0IOol00`00Oomoo`0COol00`00E_aFo004E_`00`00E_aFo016E_`00`00E_aF
o002E_`00`00E_aFo003E_`00`00Oomoo`0MOol00`00Oomoo`0EOol000moo`03001oogoo01Yoo`03
001oogoo019oo`03001Fo5Kl00EFo003001Fo5Kl04EFo005001Fo5KlE_`00006E_`00`00Oomoo`0N
Ool00`00Oomoo`0DOol000moo`03001oogoo01]oo`03001oogoo015oo`03001Fo5Kl00EFo003001F
o5Kl04EFo005001Fo5KlE_`00006E_`00`00Oomoo`0NOol00`00Oomoo`0DOol000ioo`03001oogoo
01eoo`03001oogoo011oo`03001Fo5Kl00IFo003001Fo5Kl04EFo003001Fo00000MFo003001oogoo
01moo`03001oogoo01=oo`003Woo00<007ooOol07Woo00<007ooOol047oo00<005KlE_`01EKl00<0
05KlE_`0AEKl00<005Kl00001eKl00<007ooOol087oo00<007ooOol04Woo000>Ool00`00Oomoo`0O
Ool00`00Oomoo`0?Ool00`00E_aFo006E_`00`00E_aFo014E_`20008E_`00`00Oomoo`0POol00`00
Oomoo`0BOol000ioo`03001oogoo021oo`03001oogoo00ioo`03001Fo5Kl00IFo003001Fo5Kl04AF
o08000QFo003001oogoo025oo`03001oogoo015oo`003Woo00<007ooOol08Goo00<007ooOol03Goo
00<005KlE_`01eKl00<005KlE_`0@eKl00<005KlE_`01eKl00<007ooOol08Woo00<007ooOol047oo
000>Ool00`00Oomoo`0ROol00`00Oomoo`0<Ool00`00E_aFo007E_`00`00E_aFo013E_`00`00E_aF
o006E_`00`00Oomoo`0SOol00`00Oomoo`0@Ool000eoo`03001oogoo02Aoo`03001oogoo00]oo`03
001Fo5Kl00MFo003001Fo5Kl04=Fo003001Fo5Kl00IFo003001oogoo02Aoo`03001oogoo00moo`00
3Goo00<007ooOol09Goo00<007ooOol02Woo00<005KlE_`025Kl00<005KlE_`0@EKl0P0025Kl00<0
07ooOol097oo00<007ooOol03goo000=Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00E_aFo008
E_`00`00E_aFo011E_`20008E_`00`00Oomoo`0TOol2000@Ool000eoo`03001oogoo02Moo`03001o
ogoo00Qoo`03001Fo5Kl00UFo003001Fo5Kl03mFo003001Fo00000QFo003001oogoo025oo`<00003
Ool007oo00moo`003Goo00<007ooOol0:7oo00<007ooOol027oo00<005KlE_`025Kl00<005KlE_`0
?eKl00<005Kl000025Kl00<007ooOol07Woo0`0017oo00<007ooOol03Woo000=Ool00`00Oomoo`0Y
Ool00`00Oomoo`07Ool00`00E_aFo009E_`00`00E_aFo00mE_`01000E_aFo00025Kl00<007ooOol0
6goo0`001goo00<007ooOol03Woo000=Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00E_aFo009
E_`00`00E_aFo00mE_`01000E_aFo00025Kl00<007ooOol067oo0`002goo00<007ooOol03Goo000<
Ool00`00Oomoo`0/Ool00`00Oomoo`05Ool00`00E_aFo00:E_`00`00E_aFo00kE_`01@00E_aFo5Kl
000025Kl00<007ooOol05Goo0`003Woo00<007ooOol03Goo000<Ool00`00Oomoo`0]Ool00`00Oomo
o`04Ool00`00E_aFo00:E_`00`00E_aFo00kE_`01@00E_aFo5Kl00001eKl00<007ooOol04goo0`00
4Goo00<007ooOol03Goo000<Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool00`00E_aFo00:E_`00`00
E_aFo00kE_`01@00E_aFo5Kl00001eKl00<007ooOol047oo0`0057oo00<007ooOol03Goo000<Ool0
0`00Oomoo`0_Ool00`00Oomoo`02Ool00`00E_aFo00;E_`00`00E_aFo00iE_`00`00E_aFo002E_`0
0`00E_aFo005E_`00`00Oomoo`0=Ool3000GOol00`00Oomoo`0=Ool000aoo`03001oogoo031oo`05
001oogooOol0000=E_`00`00E_aFo00iE_`00`00E_aFo003E_`00`00E_aFo004E_`00`00Oomoo`09
Ool4000JOol00`00Oomoo`0=Ool000aoo`03001oogoo035oo`04001oogoo000>E_`00`00E_aFo00g
E_`00`00E_aFo004E_`00`00E_aFo004E_`00`00Oomoo`06Ool3000NOol00`00Oomoo`0=Ool000]o
o`03001oogoo03=oo`03001oo`0000iFo003001Fo5Kl03MFo003001Fo5Kl00AFo003001Fo5Kl00AF
o003001oogoo00=oo`<0025oo`03001oogoo00eoo`002goo00<007ooOol0=7oo00<007oo00003UKl
00<005KlE_`0=EKl00<005KlE_`01EKl00<005KlE_`015Kl00<007ooOol00`009Goo00<007ooOol0
37oo000;Ool00`00Oomoo`0eOol2000>E_`00`00E_aFo00eE_`00`00E_aFo005E_`00`00E_aFo004
E_`3000XOol00`00Oomoo`0<Ool000]oo`03001oogoo03Ioo`03001Fo5Kl00eFo003001Fo5Kl03=F
o003001Fo5Kl00IFo003001Fo5Kl00=Fo003001oogoo02Uoo`03001oogoo00aoo`002goo00<007oo
Ool0=Woo00<005KlE_`03EKl00<005KlE_`0<eKl00<005KlE_`01UKl00<005KlE_`00eKl00<007oo
Ool0:Goo00<007ooOol037oo000;Ool00`00Oomoo`0fOol00`00E_aFo00>E_`00`00E_aFo00aE_`0
0`00E_aFo007E_`00`00E_aFo003E_`00`00Oomoo`0YOol00`00Oomoo`0<Ool000Yoo`03001oogoo
03Moo`03001Fo5Kl00iFo003001Fo5Kl035Fo003001Fo5Kl00MFo003001Fo5Kl00=Fo003001oogoo
02Uoo`03001oogoo00aoo`002Woo00<007ooOol0=goo00<005KlE_`03UKl00<005KlE_`0<EKl00<0
05KlE_`01eKl00<005KlE_`00eKl00<007ooOol0:Goo00<007ooOol037oo000:Ool00`00Oomoo`0g
Ool00`00E_aFo00?E_`00`00E_aFo00_E_`00`00E_aFo008E_`00`00E_aFo003E_`00`00Oomoo`0Z
Ool00`00Oomoo`0;Ool000Yoo`03001oogoo03Moo`03001Fo5Kl00mFo003001Fo5Kl02mFo003001F
o5Kl00QFo003001Fo5Kl00=Fo003001oogoo02Yoo`03001oogoo00]oo`002Woo00<007ooOol0=goo
00<005KlE_`045Kl00<005KlE_`0;EKl00<005KlE_`02EKl00<005KlE_`00eKl00<007ooOol0:Woo
00<007ooOol02goo000:Ool00`00Oomoo`0hOol00`00E_aFo00?E_`00`00E_aFo00]E_`00`00E_aF
o009E_`00`00E_aFo002E_`00`00Oomoo`0[Ool00`00Oomoo`0;Ool000Uoo`03001oogoo03Uoo`03
001Fo5Kl011Fo003001Fo5Kl02]Fo003001Fo5Kl00YFo003001Fo5Kl009Fo003001oogoo02]oo`03
001oogoo00]oo`002Goo00<007ooOol0>Goo00<005KlE_`045Kl00<005KlE_`0:eKl00<005KlE_`0
2UKl00<005KlE_`00UKl00<007ooOol0:goo00<007ooOol02goo0009Ool00`00Oomoo`0iOol00`00
E_aFo00AE_`00`00E_aFo00YE_`00`00E_aFo00;E_`00`00E_aFo002E_`00`00Oomoo`0[Ool00`00
Oomoo`0;Ool000Uoo`03001oogoo03Uooe@002eoo`03001oogoo00]oo`002Goo00<007ooOol0>Woo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol04goo0`004goo00<007ooOol037oo00@007oo
Ool002moo`03001oogoo00Yoo`002Goo00<007ooOol0>goo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol03goo0`005Goo00<007ooOol03Goo00<007oo0000<7oo00<007ooOol02Woo0008Ool0
0`00Oomoo`0mOol00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool3000HOol00`00Oomo
o`0=Ool2000aOol00`00Oomoo`0:Ool000Qoo`03001oogoo03eoo`03001oogoo00Qoo`03001oogoo
00Eoo`03001oogoo00Qoo`<001Yoo`03001oogoo00ioo`80035oo`03001oogoo00Yoo`0027oo00<0
07ooOol0?Woo00<007ooOol027oo00<007ooOol017oo00<007ooOol01Goo0`007Goo00<007ooOol0
3Woo00<007ooOol0<7oo00<007ooOol02Woo0008Ool00`00Oomoo`0oOol00`00Oomoo`08Ool00`00
Oomoo`04Ool01000Oomoogoo0`007goo00<007ooOol03Woo0P00<Woo00<007ooOol02Woo0008Ool0
0`00Oomoo`10Ool00`00Oomoo`08Ool00`00Oomoo`03Ool4000ROol00`00Oomoo`0=Ool00`00Ool0
000bOol00`00Oomoo`0:Ool000Qoo`03001oogoo045oo`03001oogoo00Qoo`03001oogoo00@002=o
o`03001oogoo00eoo`04001oogoo000cOol00`00Oomoo`09Ool000Moo`03001oogoo04=oo`03001o
ogoo00Qoo`8000=oo`03001oogoo025oo`03001oogoo00aoo`03001oogoo008003=oo`03001oogoo
00Uoo`001goo00<007ooOol0A7oo00<007ooOol01goo00<007ooOol00goo00<007ooOol07goo00<0
07ooOol03Goo0`000Woo00<007ooOol0<7oo00<007ooOol02Goo0007Ool00`00Oomoo`14Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`0OOol00`00Oomoo`09Ool40006Ool00`00Oomoo`0_
Ool00`00Oomoo`09Ool000Moo`03001oogoo04Eoo`03001oogoo00Ioo`03001oogoo00=oo`03001o
ogoo01moo`03001oogoo00Ioo`<0009oo`03001oogoo00Eoo`03001oogoo02moo`03001oogoo00Uo
o`001goo00<007ooOol0AWoo00<007ooOol01Goo00<007ooOol017oo00<007ooOol07Goo00<007oo
Ool017oo0`0017oo00<007ooOol01goo00<007ooOol0;Woo00<007ooOol02Goo0007Ool00`00Oomo
o`17Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0MOol01000Oomoogoo0`001Woo00<0
07ooOol02Goo00<007ooOol0;Goo00<007ooOol02Goo0006Ool00`00Oomoo`19Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`0KOol00`00Ool000020008Ool00`00Oomoo`0;Ool00`00Oomo
o`0/Ool00`00Oomoo`09Ool000Ioo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo01Uoo`@000]oo`03001oogoo00aoo`03001oogoo02aoo`03001oogoo00Qoo`001Woo00<0
07ooOol0Bgoo00D007ooOomoo`0000Qoo`03001oogoo01Eoo`<00003Ool007oo00]oo`03001oogoo
00eoo`03001oogoo02aoo`03001oogoo00Qoo`001Woo00<007ooOol0Bgoo00D007ooOomoo`0000Qo
o`03001oogoo019oo`<000Aoo`03001oogoo00Uoo`03001oogoo00moo`03001oogoo02]oo`03001o
ogoo00Qoo`001Woo00<007ooOol0C7oo00@007ooOol000Uoo`03001oogoo00ioo`<000Ioo`03001o
ogoo00Uoo`03001oogoo015oo`03001oogoo02Yoo`03001oogoo00Qoo`001Woo00<007ooOol0CGoo
00<007oo00002Goo00<007ooOol02goo0`002Goo00<007ooOol027oo00<007ooOol04goo00<007oo
Ool0:Goo00<007ooOol027oo0006Ool00`00Oomoo`1>Ool20009Ool00`00Oomoo`07Ool4000<Ool0
0`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`0XOol00`00Oomoo`08Ool000Eoo`03001oogoo
051oo`03001oogoo00Qoo`03001oogoo00=oo`<000moo`03001oogoo00Qoo`03001oogoo01Eoo`03
001oogoo02Qoo`03001oogoo00Qoo`001Goo00<007ooOol0Cgoo00<007oo00002Goo00<007ooOol0
0`004Woo00<007ooOol01goo00<007ooOol05goo00<007ooOol0:7oo00<007ooOol01goo0005Ool0
0`00Oomoo`1?Ool01000Oomoo`0027oo0`0057oo00<007ooOol01goo00<007ooOol06Goo00<007oo
Ool09goo00<007ooOol01goo0005Ool00`00Oomoo`1?Ool01000Oomoo`0017oo100000=oo`00Ool0
57oo00<007ooOol01Woo00<007ooOol06goo00<007ooOol09Woo00<007ooOol01goo0005Ool00`00
Oomoo`1?Ool01000Oomoogoo10001Woo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol07Goo
00<007ooOol09Goo00<007ooOol01goo0005Ool00`00Oomoo`1?Ool00`00Ool000030008Ool00`00
Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`0UOol00`00Oomoo`07Ool000Ao
o`03001oogoo04moo`<000Aoo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo00Ioo`03001o
ogoo01moo`03001oogoo02Aoo`03001oogoo00Moo`0017oo00<007ooOol0C7oo0`0000=oo`00Ool0
1Goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol08Goo00<007ooOol0
8goo00<007ooOol01goo0004Ool00`00Oomoo`18Ool40004Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0SOol00`00Oomoo`0ROol00`00Oomoo`07
Ool000Aoo`03001oogoo04Eoo`<000Qoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00eo
o`03001oogoo00Aoo`03001oogoo02Eoo`03001oogoo029oo`03001oogoo00Ioo`0017oo00<007oo
Ool0@Woo0`002goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol03Goo00<007ooOol00goo
00<007ooOol09goo00<007ooOol08Goo00<007ooOol01Woo0004Ool00`00Oomoo`0oOol3000>Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0XOol0
0`00Oomoo`0QOol00`00Oomoo`06Ool000=oo`03001oogoo03aoo`@0015oo`03001oogoo00Qoo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo02Uoo`03001oogoo021oo`03
001oogoo00Ioo`000goo00<007ooOol0>Goo0`005Goo00<007ooOol02Goo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol00goo00<007ooOol0:goo00<007ooOol07goo00<007ooOol01Woo0003
Ool00`00Oomoo`0fOol3000EOol01000Oomoo`0037oo00<007ooOol00Woo00<007ooOol02Goo00<0
07ooOol00Woo00<007ooOol0;Goo00<007ooOol07Woo00<007ooOol01Woo0003Ool00`00Oomoo`0c
Ool3000KOol00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`0_Ool00`00Oomoo`0MOol00`00Oomoo`06Ool000=oo`03001oogoo031oo`<001ioo`03001o
ogoo00aoo`05001oogooOol00009Ool01@00Oomoogoo0000<Woo00<007ooOol07Woo00<007ooOol0
1Goo0003Ool00`00Oomoo`0/Ool4000QOol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool01@00Oomoogoo0000=7oo00<007ooOol07Goo00<007ooOol01Goo0002Ool00`00Oomoo`0ZOol3
000UOol00`00Oomoo`0=Ool01@00Oomoogoo00001goo00D007ooOomoo`0003Eoo`03001oogoo01ao
o`03001oogoo00Eoo`000Woo00<007ooOol09goo0`00:7oo00<007ooOol03Woo00@007ooOol000Mo
o`04001oogoo000gOol00`00Oomoo`0KOol00`00Oomoo`05Ool0009oo`03001oogoo02Aoo`<002]o
o`03001oogoo00moo`04001oogoo0005Ool01000Oomoo`00>Goo00<007ooOol06Woo00<007ooOol0
1Goo0002Ool00`00Oomoo`0QOol3000^Ool00`00Oomoo`0@Ool00`00Ool00005Ool00`00Ool0000j
Ool00`00Oomoo`0JOol00`00Oomoo`05Ool0009oo`03001oogoo01eoo`@0035oo`03001oogoo015o
o`03001oo`0000=oo`03001oo`0003aoo`03001oogoo01Uoo`03001oogoo00Eoo`000Woo00<007oo
Ool06Woo0`00=Goo00<007ooOol04Woo0P000goo0P00?Woo00<007ooOol06Goo00<007ooOol017oo
00000goo001oo`0IOol3000hOol00`00Oomoo`0BOol01`00Ool007oo001oo`0003moo`03001oogoo
01Qoo`03001oogoo00Aoo`0000=oo`00Ool05Woo0`00>goo00<007ooOol04goo0P0000=oo`000000
@Goo00<007ooOol05goo00<007ooOol017oo00000goo001oo`0BOol4000nOol00`00Oomoo`0DOol3
0012Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00003Ool007oo00moo`<0045oo`03001oogoo01Io
o`03001oogoo049oo`03001oogoo01Ioo`03001oogoo00Aoo`0000=oo`00Ool037oo0`00A7oo00<0
07ooOol0G7oo00<007ooOol05Goo00<007ooOol017oo00000goo001oo`09Ool30017Ool00`00Oomo
o`1MOol00`00Oomoo`0DOol00`00Oomoo`04Ool00003001oogoo00Ioo`<004Yoo`03001oogoo05io
o`03001oogoo01=oo`03001oogoo00Aoo`0000<007ooOol00Woo1000CGoo00<007ooOol0GWoo00<0
07ooOol057oo00<007ooOol00goo00000`00Ool00002001AOol00`00Oomoo`1OOol00`00Oomoo`0C
Ool00`00Oomoo`03Ool0008005Aoo`03001oogoo061oo`03001oogoo019oo`03001oogoo00=oo`00
00=oo`000000Dgoo00<007ooOol0HGoo00<007ooOol04Goo00<007ooOol00goo0003Ool00`00Oomo
o`1@Ool00`00Oomoo`1ROol00`00Oomoo`0@Ool00`00Oomoo`03Ool000Aoo`03001oogoo04moo`03
001oogoo069oo`03001oogoo011oo`03001oogoo00=oo`001Goo0P00Cgoo00<007ooOol0Hgoo00<0
07ooOol03goo00<007ooOol00goo0007Ool00`00Oomoo`1<Ool00`00Oomoo`1TOol00`00Oomoo`0?
Ool00`00Oomoo`02Ool000Qoo`8004aoo`03001oogoo06Eoo`03001oogoo00ioo`03001oogoo009o
o`002Woo00<007ooOol0BGoo00<007ooOol0;Goo00<007ooOol0=Woo00<007ooOol03Goo00<007oo
Ool00Woo000;Ool20019Ool00`00Oomoo`1VOol00`00Oomoo`0=Ool00`00Oomoo`02Ool000eoo`03
001oogoo04Ioo`03001oogoo06Moo`03001oogoo00aoo`03001oogoo009oo`003Woo00<007ooOol0
AGoo00<007ooOol0J7oo00<007ooOol02goo00<007ooOol00Woo000?Ool20015Ool00`00Oomoo`1Y
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0015oo`03001oogoo049oo`03001oogoo06Yoo`03001o
ogoo00Uoo`03001oogoo009oo`004Woo0P00@Woo00<007ooOol0Jgoo00<007ooOol02Goo00<007oo
Ool00Goo000DOol00`00Oomoo`0oOol00`00Oomoo`1[Ool00`00Oomoo`09Ool00`00Oomoo`01Ool0
01Eoo`8003moo`03001oogoo06aoo`03001oogoo00Qoo`03001oogoo005oo`005goo00<007ooOol0
?7oo00<007ooOol0KGoo00<007ooOol01goo00<007ooOol00Goo000HOol00`00Oomoo`0kOol00`00
Oomoo`1^Ool00`00Oomoo`06Ool00`00Oomoo`01Ool001Uoo`8003]oo`03001oogoo06moo`03001o
ogoo00Eoo`03001oogoo005oo`006goo00<007ooOol0>7oo00<007ooOol0Kgoo00<007ooOol01Goo
00<007ooOol00Goo000LOol2000gOol00`00Oomoo`1aOol00`00Oomoo`05Ool10001Ool1Ool001io
o`03001oogoo03Aoo`03001oogoo079oo`03001oogoo00Aoo`40005oo`5oo`007goo0P00=7oo00<0
07ooOol0Lgoo00<007ooOol00goo0@000Goo0Goo000QOol00`00Oomoo`0aOol00`00Oomoo`1dOol0
0`00Oomoo`02Ool10001Ool1Ool0029oo`03001oogoo031oo`03001oogoo07Aoo`03001oogoo009o
o`40005oo`5oo`008goo0P00<7oo00<007ooOol0MGoo00D007ooOomoo`00009oo`009Goo00<007oo
Ool0;Goo00<007ooOol0MWoo00@007ooOol0009oo`009Woo0P00;Goo00<007ooOol0Mgoo00<007oo
00000Woo000XOol00`00Oomoo`0ZOol00`00Oomoo`1hOol00`00Ool00001Ool002Uoo`03001oogoo
02Uoo`03001oogoo07Qoo`03001oo`00005oo`00:Woo0P00:Goo00<007ooOol0NGoo0P000Goo000/
Ool00`00Oomoo`0VOol00`00Oomoo`1hOol30001Ool002eoo`8002Ioo`03001oogoo07Aoo`@000Ao
o`00;goo00<007ooOol08goo00<007ooOol0Kgoo1@0027oo000`Ool2000SOol00`00Oomoo`1[Ool4
000=Ool0039oo`03001oogoo021oo`03001oogoo06Ioo`D0015oo`00<goo00<007ooOol07goo00<0
07ooOol0HWoo10005Woo000dOol2000OOol00`00Oomoo`1MOol5000JOol003Ioo`03001oogoo01ao
o`03001oogoo05Uoo`@001moo`00=goo0P0077oo00<007ooOol0E7oo1@008goo000iOol00`00Oomo
o`0IOol00`00Oomoo`1@Ool4000XOol003Yoo`8001Uoo`03001oogoo04]oo`D002aoo`00?7oo00<0
07ooOol05Woo00<007ooOol0Agoo1000<Goo000mOol00`00Oomoo`0EOol00`00Oomoo`12Ool5000e
Ool003ioo`8001Eoo`03001oogoo03ioo`@003Yoo`00@7oo00<007ooOol04Woo00<007ooOol0>Goo
1@00?Woo0011Ool2000AOol00`00Oomoo`0fOol40013Ool004=oo`03001oogoo00ioo`03001oogoo
035oo`D004Moo`00A7oo0P003Woo00<007ooOol0;Goo1000C7oo0016Ool00`00Oomoo`0;Ool00`00
Oomoo`0XOol5001@Ool004Moo`03001oogoo00Yoo`03001oogoo02Aoo`@005Eoo`00B7oo0P002Woo
00<007ooOol07goo1@00FGoo001:Ool00`00Oomoo`07Ool00`00Oomoo`0KOol4001NOol004]oo`80
00Moo`03001oogoo01Ioo`D0069oo`00CGoo00<007ooOol017oo00<007ooOol04Woo1000Igoo001>
Ool20004Ool00`00Oomoo`0=Ool5001[Ool0051oo`05001oogooOol0000;Ool4001`Ool0055oo`04
001oogoo0006Ool5001dOol0059oo`<0009oo`@007Uoo`00E7oo0`00OGoo0000\
\>"],
  ImageRangeCache->{{{0, 211}, {228, 0}} -> {0.0466877, -1.9042*^-16, 
  0.00408288, 0.00408288}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to the built-in ",
  StyleBox["Cuboid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, with the exception that the sides of the ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic are aligned with the local coordinate system on which the graphic \
is located, instead of being aligned with the global coordinate system.\n\n\
The ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function generates a faceted cylinder or cone, with endpoints located at \
the two ends of a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " line object. The ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used with the ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to show only an outline of the bar."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and a ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic spanning from ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the ground."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics3D[{\n\t\t\t
          Box[body2, {{0, 0, 0}, {.5, 1, 1}}, Faces \[Rule] False], \n\t\t\t
          RGBColor[1, 0, 0], \n\t\t\t
          Bar[Line[body2, {.5, 1, 1}, ground, {1, 2, 0}], 0.2, 6, 
            Faces \[Rule] True]}, \n\t\tPlotRange \[Rule] All]; \)\)], "Input",\

  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] .2, Z2 \[Rule] .1, Eo2 \[Rule] 1, 
          Ei2 \[Rule] 0, Ej2 \[Rule] 0, Ek2 \[Rule] 0}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.16534 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0909056 1.25667 0 1.25667 [
[ 0 0 0 0 ]
[ 1 1.16534 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06613 .20337 m
0 .74228 L
s
0 .74228 m
.51247 1.16534 L
s
.51247 1.16534 m
.515 .67758 L
s
.515 .67758 m
.06613 .20337 L
s
.56663 0 m
.95016 .54083 L
s
.95016 .54083 m
1 1.04543 L
s
1 1.04543 m
.57108 .55443 L
s
.57108 .55443 m
.56663 0 L
s
.06613 .20337 m
0 .74228 L
s
0 .74228 m
.57108 .55443 L
s
.57108 .55443 m
.56663 0 L
s
.56663 0 m
.06613 .20337 L
s
.515 .67758 m
.95016 .54083 L
s
.95016 .54083 m
1 1.04543 L
s
1 1.04543 m
.51247 1.16534 L
s
.51247 1.16534 m
.515 .67758 L
s
0 0 m
1 0 L
1 1.16534 L
0 1.16534 L
closepath
clip
newpath
.5 Mabswid
.91609 .58149 m .89112 .64284 L .82148 .6364 L p .552 .533 .787 r
F P
0 g
s
.86914 .51337 m .91609 .58149 L p .82148 .6364 L .552 .533 .787 r
F P
0 g
s
.79863 .50883 m .86914 .51337 L p .82148 .6364 L .552 .533 .787 r
F P
0 g
s
.82148 .6364 m .77592 .57047 L .79863 .50883 L p .552 .533 .787 r
F P
0 g
s
.82148 .6364 m .89112 .64284 L .55965 .93311 L p .528 .14 .249 r
F P
0 g
s
.55965 .93311 m .48527 .92059 L .82148 .6364 L p .528 .14 .249 r
F P
0 g
s
.77592 .57047 m .82148 .6364 L .48527 .92059 L p .843 .602 .575 r
F P
0 g
s
.79863 .50883 m .77592 .57047 L .43246 .84494 L p .921 .965 .784 r
F P
0 g
s
.48527 .92059 m .43246 .84494 L .77592 .57047 L p .843 .602 .575 r
F P
0 g
s
.89112 .64284 m .91609 .58149 L .58216 .8677 L p .914 .979 .764 r
F P
0 g
s
.58216 .8677 m .55965 .93311 L .89112 .64284 L p .914 .979 .764 r
F P
0 g
s
.43246 .84494 m .45218 .77897 L .79863 .50883 L p .921 .965 .784 r
F P
0 g
s
.86914 .51337 m .79863 .50883 L .45218 .77897 L p .501 .093 .198 r
F P
0 g
s
.91609 .58149 m .86914 .51337 L .52746 .78916 L p .85 .602 .564 r
F P
0 g
s
.52746 .78916 m .58216 .8677 L .91609 .58149 L p .85 .602 .564 r
F P
0 g
s
.45218 .77897 m .52746 .78916 L .86914 .51337 L p .501 .093 .198 r
F P
0 g
s
.3241 .55161 m
.50854 .4887 L
s
.3241 .55161 m
.30564 .91413 L
s
.07974 .30146 m
.3241 .55161 L
s
.50854 .4887 m
.27704 .22434 L
s
.5069 .72232 m
.50854 .4887 L
s
.5068 .73637 m
.5069 .72232 L
s
.30564 .91413 m
.42773 .87877 L
s
.30564 .91413 m
.03555 .68183 L
s
.58216 .8677 m .55965 .93311 L .48527 .92059 L p .498 .513 .803 r
F P
0 g
s
.52746 .78916 m .58216 .8677 L p .48527 .92059 L .498 .513 .803 r
F P
0 g
s
.45218 .77897 m .52746 .78916 L p .48527 .92059 L .498 .513 .803 r
F P
0 g
s
.48527 .92059 m .43246 .84494 L .45218 .77897 L p .498 .513 .803 r
F P
0 g
s
.42773 .87877 m
.50597 .85612 L
s
.07974 .30146 m
.03555 .68183 L
s
.27704 .22434 m
.07974 .30146 L
s
.407 .7603 m
.4576 .8093 L
s
.4576 .8093 m
.50597 .85612 L
s
.25109 .60936 m
.407 .7603 L
s
.27704 .22434 m
.25109 .60936 L
s
.03555 .68183 m
.25109 .60936 L
s
.25 Mabswid
.56663 0 m
.95016 .54083 L
s
.95016 .54083 m
1 1.04543 L
s
1 1.04543 m
.57108 .55443 L
s
.57108 .55443 m
.56663 0 L
s
.06613 .20337 m
0 .74228 L
s
0 .74228 m
.57108 .55443 L
s
.57108 .55443 m
.56663 0 L
s
.56663 0 m
.06613 .20337 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{256.813, 299.25},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000400001:a000`40O003h00OSgoo0P00Kgoo002=
Ool200000goo0000001^Ool008Yoo`<000=oo`8006ioo`00R7oo0P001Woo00<007oo0000KGoo0025
Ool30008Ool01000Oomoo`00K7oo0023Ool2000;Ool01@00Oomoogoo0000Jgoo0021Ool2000=Ool0
1@00Oomoogoo0000Jgoo001nOol3000?Ool00`00Oomoo`02Ool00`00Oomoo`1XOol007aoo`80019o
o`03001oogoo00=oo`03001oogoo06Moo`00NGoo0`0057oo00<007ooOol00goo00<007ooOol0Igoo
001gOol2000GOol00`00Oomoo`04Ool00`00Oomoo`1VOol007Aoo`<001Uoo`03001oogoo00Eoo`03
001oogoo06Eoo`00LWoo0P0077oo00<007ooOol01Woo00<007ooOol0I7oo001_Ool3000NOol00`00
Oomoo`06Ool00`00Oomoo`1TOol006eoo`80025oo`03001oogoo00Moo`03001oogoo06=oo`00JWoo
0`008goo00<007ooOol027oo00<007ooOol0HWoo001XOol2000VOol00`00Oomoo`08Ool00`00Oomo
o`1ROol006Eoo`<002Qoo`03001oogoo00Uoo`03001oogoo065oo`00Hgoo0P00:goo00<007ooOol0
2Woo00<007ooOol0H7oo001QOol2000]Ool00`00Oomoo`0;Ool00`00Oomoo`1OOol005ioo`<002mo
o`03001oogoo00]oo`03001oogoo05moo`00G7oo0P00<Woo00<007ooOol037oo00<007ooOol0GWoo
001IOol3000dOol00`00Oomoo`0=Ool00`00Oomoo`1MOol005Moo`8003Moo`03001oogoo00eoo`03
001oogoo05eoo`00E7oo0`00>Goo00<007ooOol03Woo00<007ooOol0G7oo001BOol2000lOol00`00
Oomoo`0?Ool00`00Oomoo`1KOol004moo`<003ioo`03001oogoo011oo`03001oogoo05Yoo`00CGoo
0P00@Goo00<007ooOol047oo00<007ooOol0FWoo001:Ool30013Ool00`00Oomoo`0AOol00`00Oomo
o`1IOol004Qoo`8004Ioo`03001oogoo019oo`03001oogoo05Qoo`00AGoo0`00B7oo00<007ooOol0
4Woo00<007ooOol0F7oo0013Ool2001;Ool00`00Oomoo`0COol00`00Oomoo`1GOol0045oo`8004eo
o`03001oogoo01Aoo`03001oogoo05Ioo`00?Woo0`00Cgoo00<007ooOol05Goo00<007ooOol0EGoo
000lOol2001BOol00`00Oomoo`0EOol00`00Oomoo`1EOol003Uoo`<005Aoo`03001oogoo01Ioo`03
001oogoo05Aoo`00=goo0P00F7oo00<007ooOol05Woo00<007ooOol0Dgoo000dOol3001JOol00`00
Oomoo`0FOol00`00Oomoo`1COol0039oo`8005eoo`03001oogoo01Moo`03001oogoo059oo`00;goo
0`00Ggoo00<007ooOol067oo00<007ooOol0DGoo000]Ool2001ROol00`00Oomoo`0HOol00`00Oomo
o`1AOol002Yoo`<006Aoo`03001oogoo01Uoo`03001oogoo051oo`00:7oo0P00Igoo00<007ooOol0
6Woo00<007ooOol0Cgoo000UOol3001YOol00`00Oomoo`0KOol00`00Oomoo`1>Ool002=oo`8006ao
o`03001oogoo01]oo`03001oogoo04ioo`008Goo0P00KWoo00<007ooOol077oo00<007ooOol0CGoo
000NOol3001`Ool00`00Oomoo`0MOol00`00Oomoo`1<Ool001aoo`8007=oo`03001oogoo01eoo`03
001oogoo04aoo`006Goo0`00MGoo00<007ooOol07Woo00<007ooOol0Bgoo000GOol2001hOol00`00
Oomoo`0OOol00`00Oomoo`1:Ool001Aoo`<007Yoo`03001oogoo021oo`03001oogoo04Uoo`004Woo
0P00OGoo00<007ooOol087oo00<007ooOol0BGoo000@Ool2001oOol00`00Oomoo`0QOol00`00Oomo
o`18Ool0011oo`8007moo`03001oogoo029oo`03001oogoo04Moo`0047oo00<007oo0000OWoo00<0
07ooOol08Woo00<007ooOol0Agoo000@Ool01000Oomoo`00OGoo00<007ooOol08goo00<007ooOol0
AWoo000@Ool01@00Oomoogoo0000O7oo00<007ooOol097oo00<007ooOol0AGoo000?Ool00`00Oomo
o`03Ool00`00Oomoo`1iOol00`00Oomoo`0UOol00`00Oomoo`14Ool000moo`03001oogoo00Aoo`03
001oogoo02aoo`8004Yoo`03001oogoo02Eoo`03001oogoo04Aoo`003goo00<007ooOol01Goo00<0
07ooOol0:Goo0P0000=oo`000000BGoo00<007ooOol09Woo00<007ooOol0@goo000?Ool00`00Oomo
o`06Ool00`00Oomoo`0UOol30003Ool00`00Ool00018Ool00`00Oomoo`0WOol00`00Oomoo`12Ool0
00moo`03001oogoo00Ioo`03001oogoo029oo`<000Ioo`04001oogoo0017Ool00`00Oomoo`0WOol0
0`00Oomoo`12Ool000moo`03001oogoo00Moo`03001oogoo01moo`8000Uoo`05001oogooOol00016
Ool00`00Oomoo`0XOol00`00Oomoo`11Ool000moo`03001oogoo00Qoo`03001oogoo01]oo`<000]o
o`05001oogooOol00016Ool00`00Oomoo`0YOol00`00Oomoo`10Ool000moo`03001oogoo00Uoo`03
001oogoo01Moo`<000ioo`03001oogoo009oo`03001oogoo04=oo`03001oogoo02Yoo`03001oogoo
03moo`003Woo00<007ooOol02goo00<007ooOol057oo0P004Goo00<007ooOol00goo00<007ooOol0
@Woo00<007ooOol0:Woo00<007ooOol0?goo000>Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool3000C
Ool00`00Oomoo`04Ool00`00Oomoo`11Ool00`00Oomoo`0[Ool00`00Oomoo`0nOol000ioo`03001o
ogoo00eoo`03001oogoo00eoo`8001Eoo`03001oogoo00Ioo`03001oogoo041oo`03001oogoo02ao
o`03001oogoo03eoo`003Woo00<007ooOol03Woo00<007ooOol02Goo0`005goo00<007ooOol01goo
00<007ooOol0?goo00<007ooOol0;7oo00<007ooOol0?Goo000>Ool00`00Oomoo`0?Ool00`00Oomo
o`05Ool3000JOol00`00Oomoo`08Ool00`00Oomoo`0nOol00`00Oomoo`0]Ool00`00Oomoo`0lOol0
00ioo`03001oogoo011oo`03001oogoo009oo`8001eoo`03001oogoo00Uoo`03001oogoo03eoo`03
001oogoo02ioo`03001oogoo03]oo`003Woo00<007ooOol04Goo10007goo00<007ooOol02Woo00<0
07ooOol0?7oo00<007ooOol0;goo00<007ooOol0>Woo000>Ool00`00Oomoo`0?Ool4000QOol00`00
Oomoo`0;Ool00`00Oomoo`0kOol00`00Oomoo`0_Ool00`00Oomoo`0jOol000ioo`03001oogoo00eo
o`8000Aoo`03001oogoo01ioo`03001oogoo00]oo`03001oogoo03]oo`03001oogoo031oo`03001o
ogoo03Uoo`003Goo00<007ooOol02goo0`001goo00<007ooOol07Goo00<007ooOol037oo00<007oo
Ool0>Woo00<007ooOol0<Goo00<007ooOol0>7oo000=Ool00`00Oomoo`08Ool3000;Ool00`00Oomo
o`0LOol00`00Oomoo`0=Ool00`00Oomoo`0iOol00`00Oomoo`0aOol00`00Oomoo`0hOol000eoo`03
001oogoo00Ioo`8000moo`03001oogoo01]oo`03001oogoo00ioo`03001oogoo03Qoo`03001oogoo
039oo`03001oogoo03Moo`003Goo00<007ooOol017oo0P004Woo00<007ooOol06Woo00<007ooOol0
3goo00<007ooOol0=goo00<007ooOol0<goo00<007ooOol0=Woo000=Ool00`00Oomoo`04Ool2000C
Ool00`00Oomoo`0IOol00`00Oomoo`0@Ool00`00Oomoo`0fOol00`00Oomoo`0dOol00`00Oomoo`0e
Ool000eoo`03001oogoo00Aoo`03001oo`00019oo`03001oogoo01Uoo`03001oogoo015oo`03001o
ogoo03Eoo`03001oogoo03Aoo`03001oogoo03Eoo`003Goo00<007ooOol017oo00@007ooOol0019o
o`03001oogoo01Qoo`03001oogoo019oo`03001oogoo03Aoo`03001oogoo03Eoo`03001oogoo03Ao
o`003Goo00<007ooOol017oo00D007ooOomoo`00019oo`03001oogoo01Moo`03001oogoo01=oo`03
001oogoo03=oo`03001oogoo03Ioo`03001oogoo03=oo`003Goo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol047oo00<007ooOol05Woo00<007ooOol04goo00<007ooOol0<goo00<007ooOol0
=Woo00<007ooOol0<goo000<Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00
Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0bOol00`00Oomoo`0gOol00`00Oomoo`0bOol000ao
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo01=oo`03001oogoo01Io
o`03001oogoo035oo`03001oogoo03Qoo`03001oogoo035oo`0037oo00<007ooOol017oo00<007oo
Ool01Woo00<007ooOol047oo00<007ooOol04Woo00<007ooOol05goo00<007ooOol0<7oo00<007oo
Ool0>Goo00<007ooOol0<7oo000<Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool0
0`00Oomoo`0AOol00`00Oomoo`0HOol00`00Oomoo`0_Ool00`00Oomoo`0iOol00`00Oomoo`0`Ool0
00aoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo011oo`03001oogoo011oo`03001oogoo
01Uoo`03001oogoo02ioo`03001oogoo03Yoo`03001oogoo02moo`0037oo00<007ooOol017oo00<0
07ooOol02Goo00<007ooOol047oo00<007ooOol03goo00<007ooOol06Woo00<007ooOol0;Goo00<0
07ooOol0>goo00<007ooOol0;Woo000<Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0@
Ool00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`0/Ool00`00Oomoo`0kOol00`00Oomoo`0^
Ool000aoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00eoo`03001o
ogoo01aoo`03001oogoo02]oo`03001oogoo03aoo`03001oogoo02eoo`002goo00<007ooOol017oo
00<007ooOol03Goo00<007ooOol047oo00<007ooOol037oo00<007ooOol07Goo00<007ooOol0:Woo
00<007ooOol0?Goo00<007ooOol0;7oo000;Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomo
o`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0MOol00`00Oomoo`0ZOol00`00Oomoo`0nOol00`00Oomo
o`0[Ool000]oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo00Yoo`03
001oogoo01ioo`03001oogoo02Uoo`03001oogoo03ioo`03001oogoo02]oo`002goo00<007ooOol0
17oo00<007ooOol03goo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol07goo00<007ooOol0
:7oo00<007ooOol0?goo00<007ooOol0:Woo000;Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00
Oomoo`0AOol00`00Oomoo`08Ool00`00Oomoo`0POol00`00Oomoo`0WOol00`00Oomoo`10Ool00`00
Oomoo`0YOol000]oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo011oo`03001oogoo00Qo
o`03001oogoo025oo`03001oogoo02Ioo`03001oogoo041oo`03001oogoo02Uoo`002goo00<007oo
Ool017oo00<007ooOol04Woo00<007ooOol047oo00<007ooOol01goo00<007ooOol08Woo00<007oo
Ool09Goo00<007ooOol0@Goo00<007ooOol0:7oo000;Ool00`00Oomoo`04Ool00`00Oomoo`0COol0
0`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`12Ool0
0`00Oomoo`0WOol000]oo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo011oo`03001oogoo
00Aoo`03001oogoo02Eoo`03001oogoo02=oo`03001oogoo04=oo`03001oogoo02Ioo`002Woo00<0
07ooOol017oo00<007ooOol05Woo00<007ooOol047oo00<007ooOol00goo00<007ooOol09Woo00<0
07ooOol08Woo00<007ooOol0@goo00<007ooOol09Woo000:Ool00`00Oomoo`04Ool00`00Oomoo`0G
Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`0WOol00`00Oomoo`0QOol00`00Oomoo`14
Ool00`00Oomoo`0UOol000Yoo`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo011oo`05001o
ogooOol0000YOol00`00Oomoo`0QOol00`00Oomoo`15Ool00`00Oomoo`0TOol000Yoo`03001oogoo
00Aoo`03001oogoo01Uoo`03001oogoo011oo`04001oogoo000ZOol00`00Oomoo`0POol00`00Oomo
o`15Ool00`00Oomoo`0TOol000Yoo`03001oogoo00Aoo`03001oogoo01Yoo`03001oogoo011oo`03
001oo`0002]oo`03001oogoo01moo`03001oogoo04Ioo`03001oogoo02=oo`002Woo00<007ooOol0
17oo00<007ooOol06goo00<007ooOol047oo0P00;7oo00<007ooOol07Woo00<007ooOol0Agoo00<0
07ooOol08Woo000:Ool00`00Oomoo`04Ool00`00Oomoo`0LOol00`00Oomoo`0@Ool00`00Oomoo`0[
Ool00`00Oomoo`0MOol00`00Oomoo`17Ool00`00Oomoo`0ROol000Yoo`03001oogoo00Aoo`03001o
ogoo01eoo`03001oogoo00moo`8002eoo`03001oogoo01eoo`03001oogoo04Moo`03001oogoo025o
o`002Woo00<007ooOol017oo00<007ooOol07Woo00<007ooOol03Woo00<007oo0000;Goo00<007oo
Ool077oo00<007ooOol0B7oo00<007ooOol087oo0009Ool00`00Oomoo`04Ool00`00Oomoo`0POol0
0`00Oomoo`0=Ool01000Oomoo`00;Goo00<007ooOol06goo00<007ooOol0BGoo00<007ooOol07goo
0009Ool00`00Oomoo`04Ool00`00Oomoo`0QOol00`00Oomoo`0<Ool01@00Oomoogoo0000;Goo00<0
07ooOol06Woo00<007ooOol0BGoo00<007ooOol07goo0009Ool00`00Oomoo`04Ool00`00Oomoo`0R
Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0ZOol00`00Oomoo`0JOol00`00Oomoo`1:
Ool00`00Oomoo`0NOol000Uoo`03001oogoo00Aoo`03001oogoo02=oo`03001oogoo00Yoo`03001o
ogoo00=oo`03001oogoo02Yoo`03001oogoo01Uoo`03001oogoo04]oo`03001oogoo01eoo`002Goo
00<007ooOol017oo00<007ooOol097oo00<007ooOol02Goo00<007ooOol00goo00<007ooOol0:goo
00<007ooOol067oo00<007ooOol0Bgoo00<007ooOol07Goo0009Ool00`00Oomoo`04Ool00`00Oomo
o`0UOol00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool00`00Oomoo`0GOol00`00Oomo
o`1<Ool00`00Oomoo`0LOol000Uoo`03001oogoo00Aoo`03001oogoo02Ioo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo02]oo`03001oogoo01Ioo`03001oogoo04eoo`03001oogoo01]oo`00
2Goo00<007ooOol017oo00<007ooOol09goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
:goo00<007ooOol05Goo00<007ooOol0CWoo00<007ooOol06Woo0008Ool00`00Oomoo`05Ool00`00
Oomoo`0XOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0[Ool00`00Oomoo`0DOol00`00
Oomoo`1>Ool00`00Oomoo`0JOol000Qoo`03001oogoo00Aoo`03001oogoo02Yoo`03001oogoo00=o
o`03001oogoo00Uoo`03001oogoo02]oo`03001oogoo01=oo`03001oogoo04moo`03001oogoo01Uo
o`0027oo00<007ooOol017oo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool0:goo00<007ooOol04Woo00<007ooOol0D7oo00<007ooOol067oo0008Ool00`00Oomoo`04Ool0
0`00Oomoo`0/Ool01@00Oomoogoo00003Goo00<007ooOol0:goo00<007ooOol04Goo00<007ooOol0
D7oo00<007ooOol067oo0008Ool00`00Oomoo`04Ool00`00Oomoo`0]Ool01000Oomoo`003Woo00<0
07ooOol0:Woo00<007ooOol04Goo00<007ooOol0DGoo00<007ooOol05goo0008Ool00`00Oomoo`04
Ool00`00Oomoo`0^Ool00`00Ool0000?Ool00`00Oomoo`0ZOol00`00Oomoo`0@Ool00`00Oomoo`1B
Ool00`00Oomoo`0FOol000Qoo`03001oogoo00Aoo`03001oogoo02moo`80011oo`03001oogoo02Yo
o`03001oogoo00moo`03001oogoo05=oo`03001oogoo01Eoo`0027oo00<007ooOol017oo00<007oo
Ool0<7oo00<007ooOol03goo00<007ooOol0:Woo00<007ooOol03Woo00<007ooOol0Dgoo00<007oo
Ool05Goo0008Ool00`00Oomoo`04Ool00`00Oomoo`0`Ool00`00Oomoo`0@Ool00`00Oomoo`0YOol2
000?Ool00`00Oomoo`1DOol00`00Oomoo`0DOol000Moo`03001oogoo00Aoo`03001oogoo035oo`80
019oo`03001oogoo02Eoo`<00003Ool007oo00ioo`03001oogoo05Eoo`03001oogoo01=oo`001goo
00<007ooOol017oo00<007ooOol0<Goo00<007oo00004Woo00<007ooOol08Goo0`0017oo00<007oo
Ool03Goo00<007ooOol0EGoo00<007ooOol04goo0007Ool00`00Oomoo`04Ool00`00Oomoo`0aOol0
1000Oomoo`004Woo00<007ooOol07Goo0`001goo00<007ooOol03Goo00<007ooOol0EWoo00<007oo
Ool04Woo0007Ool00`00Oomoo`04Ool00`00Oomoo`0aOol01@00Oomoogoo00004Woo00<007ooOol0
6Goo0`002Woo00<007ooOol03Goo00<007ooOol0Egoo00<007ooOol04Goo0007Ool00`00Oomoo`04
Ool00`00Oomoo`0aOol00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0EOol3000=Ool00`00
Oomoo`0=Ool00`00Oomoo`0gOol5000LOol00`00Oomoo`0@Ool000Moo`03001oogoo00Aoo`03001o
ogoo035oo`03001oogoo00=oo`03001oogoo00moo`03001oogoo019oo`<0011oo`03001oogoo00eo
o`03001oogoo03Ioo`030010AT1600=0APT001=oo`03001oogoo011oo`001goo00<007ooOol017oo
00<007ooOol0<7oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol03Woo0`004goo00<007oo
Ool03Goo00<007ooOol0=7oo0P003d161@003goo00<007ooOol03goo0007Ool00`00Oomoo`04Ool0
0`00Oomoo`0`Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0:Ool3000FOol00`00Oomo
o`0=Ool00`00Oomoo`0cOol00`00@4I0AP0B@4H00`00KW80000?Ool00`00Oomoo`0>Ool000Ioo`03
001oogoo00Eoo`03001oogoo031oo`03001oogoo00Moo`03001oogoo00moo`03001oogoo00Ioo`<0
01Uoo`03001oogoo00eoo`03001oogoo039oo`030010AT160150AP80009^LP03001oogoo00eoo`03
001oogoo00ioo`001Woo00<007ooOol017oo00<007ooOol0<Goo00<007ooOol027oo00<007ooOol0
3goo00<007ooOol00Woo0`0077oo00<007ooOol03Goo00<007ooOol0<Goo00<00416@4H04D1600<0
06ibKW800fib00<007ooOol03Goo00<007ooOol03Goo0006Ool00`00Oomoo`04Ool00`00Oomoo`0a
Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool4000OOol00`00Oomoo`0=Ool00`00Oomoo`0_Ool2000C
@4H00`00KW9^LP05KW800`00Oomoo`0=Ool00`00Oomoo`0<Ool000Ioo`03001oogoo00Aoo`03001o
ogoo035oo`03001oogoo00Yoo`03001oogoo00aoo`@0025oo`03001oogoo00eoo`03001oogoo02io
o`030010AT160190AP03001^LVib00M^LP03001oogoo00eoo`03001oogoo00]oo`001Woo00<007oo
Ool017oo00<007ooOol0<Goo00<007ooOol02goo00<007ooOol027oo0`0017oo00<007ooOol07Woo
00<007ooOol03Goo00<007ooOol0;Goo00<00416@4H04D160P002Vib00<007ooOol03Goo00<007oo
Ool02goo0006Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`0<Ool00`00Oomoo`04Ool3
0008Ool00`00Oomoo`0MOol00`00Oomoo`0=Ool00`00Oomoo`0[Ool2000C@4H00`00KW9^LP0;KW80
0`00Oomoo`0<Ool2000<Ool000Ioo`03001oogoo00Aoo`03001oogoo035oo`03001oogoo00eoo`03
001oogoo00<000aoo`03001oogoo01aoo`03001oogoo00eoo`03001oogoo02Yoo`030010AT160190
AP03001^LVib00e^LP03001oogoo00Qoo`<00003Ool007oo00]oo`001Woo00<007ooOol017oo00<0
07ooOol0<Goo00<007ooOol03Woo0P0047oo00<007ooOol06goo00<007ooOol03Goo00<007ooOol0
:Goo00<00416@4H04T1600<006ibKW803Vib00<007ooOol01Goo0`0017oo00<007ooOol02Woo0006
Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`0>Ool00`00Oomoo`0@Ool00`00Oomoo`0J
Ool00`00Oomoo`0<Ool2000ZOol00`00@4I0AP0A@4H2000BKW800`00Oomoo`040007Ool00`00Oomo
o`0:Ool000Eoo`03001oogoo00Eoo`03001oogoo035oo`03001oogoo00ioo`03001oogoo015oo`03
001oogoo01Uoo`03001oogoo00Uoo`<0009oo`03001oogoo02Eoo`8001=0AP03001^LVib01=^LP80
00]oo`03001oogoo00Yoo`001Goo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol03Woo00<0
07ooOol04Woo00<007ooOol067oo00<007ooOol01Woo0`001Woo00<007ooOol08goo00<00416@4H0
4T1600<006ibKW8056ib00<007ooOol02Woo00<007ooOol02Woo0005Ool00`00Oomoo`04Ool00`00
Oomoo`0bOol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`03Ool3000:
Ool00`00Oomoo`0QOol00`00@4I0AP0B@4H00`00KW9^LP0FKW800`00Oomoo`0:Ool00`00Oomoo`09
Ool000Eoo`03001oogoo00Aoo`03001oogoo039oo`03001oogoo00ioo`03001oogoo01Aoo`03001o
ogoo01Ioo`03001oogoo00<000eoo`03001oogoo021oo`030010AT160150AP8001Y^LP03001oogoo
00Uoo`03001oogoo00Uoo`001Goo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol03Woo00<0
07ooOol05Goo00<007ooOol05Goo0`004Goo00<007ooOol07Goo0P004d1600<006ibKW806fib00<0
07ooOol027oo00<007ooOol02Goo0005Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`0?
Ool00`00Oomoo`0EOol00`00Oomoo`0BOol4000DOol00`00Oomoo`0KOol00`00@4I0AP0B@4H00`00
KW9^LP0LKW800`00Oomoo`08Ool00`00Oomoo`09Ool000Eoo`03001oogoo00Aoo`03001oogoo035o
o`03001oogoo00moo`03001oogoo01Ioo`03001oogoo00ioo`<000=oo`03001oogoo01=oo`03001o
ogoo01Uoo`030010AT160190AP03001^LVib01i^LP03001oogoo00Moo`03001oogoo00Uoo`001Goo
00<007ooOol017oo00<007ooOol0<Goo00<007ooOol03goo00<007ooOol05goo00<007ooOol02Woo
0`001Woo00<007ooOol057oo00<007ooOol05Woo0P004d160P0086ib0P002Goo00<007ooOol02Goo
0005Ool00`00Oomoo`04Ool00`00Oomoo`0aOol00`00Oomoo`0?Ool00`00Oomoo`0HOol00`00Oomo
o`06Ool30009Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00@4I0AP0B@4H00`00KW9^LP0OKW82
000:Ool00`00Oomoo`09Ool000Aoo`03001oogoo00Eoo`03001oogoo035oo`03001oogoo00moo`03
001oogoo01Uoo`03001oogoo009oo`<000aoo`03001oogoo01Ioo`03001oogoo019oo`030010AT16
0190AP03001^LVib01i^LP800003MoP007oo00Uoo`03001oogoo00Uoo`0017oo00<007ooOol017oo
00<007ooOol0<Woo00<007ooOol03Woo00<007ooOol06goo10003goo00<007ooOol05goo00<007oo
Ool047oo00<00416@4H04D160P0086ib00@007OhMoP000]oo`03001oogoo00Uoo`0017oo00<007oo
Ool017oo00<007ooOol0<Woo00<007ooOol03Woo00<007ooOol067oo1@004Goo00<007ooOol05goo
00<007ooOol03Woo0P004d1600<006ibKW807fib00D007OhMoQgn00000]oo`03001oogoo00Uoo`00
17oo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol03Woo00<007ooOol05Goo0`001Goo00<0
07ooOol03Goo00<007ooOol06Goo00<007ooOol037oo00<00416@4H04T1600<006ibKW807fib00D0
07OhMoQgn00000aoo`03001oogoo00Uoo`0017oo00<007ooOol017oo00<007ooOol0<Goo0P0047oo
00<007ooOol04Woo0`002Goo00<007ooOol037oo00<007ooOol06Woo00<007ooOol02Woo00<00416
@4H04T1600<006ibKW807fib00<007OhMoP00WOh00<007ooOol02goo00<007ooOol027oo0004Ool0
0`00Oomoo`04Ool00`00Oomoo`0^Ool30002Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool3000=Ool0
0`00Oomoo`0;Ool00`00Oomoo`0KOol00`00Oomoo`08Ool00`00@4I0AP0A@4H2000PKW820004MoP0
0`00Oomoo`0<Ool00`00Oomoo`08Ool000Aoo`03001oogoo00Aoo`03001oogoo02]oo`<000Ioo`03
001oogoo00aoo`03001oogoo00aoo`<0015oo`03001oogoo00Yoo`03001oogoo01aoo`03001oogoo
00Eoo`8001=0AP03001^LVib01m^LP03001gn7Oh00Agn003001oogoo00aoo`03001oogoo00Qoo`00
17oo00<007ooOol017oo00<007ooOol0:7oo0`002Woo00<007ooOol02goo00<007ooOol02Goo0`00
5Goo00<007ooOol02Goo00<007ooOol07Goo00<007ooOol00goo00<00416@4H04T1600<006ibKW80
7fib00<007OhMoP01GOh00<007ooOol037oo00<007ooOol027oo0003Ool00`00Oomoo`05Ool00`00
Oomoo`0UOol3000>Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool3000IOol00`00Oomoo`08Ool00`00
Oomoo`0NOol01@00Oomoogoo0000541600<006ibKW807fib00<007OhMoP01GOh00<007ooOol03Goo
00<007ooOol027oo0003Ool00`00Oomoo`05Ool00`00Oomoo`0SOol2000BOol00`00Oomoo`09Ool0
0`00Oomoo`03Ool3000MOol00`00Oomoo`07Ool00`00Oomoo`0NOol01000Ool000004d160P008Fib
00<007OhMoP01WOh00<007ooOol03Goo00<007ooOol027oo0003Ool00`00Oomoo`04Ool00`00Oomo
o`0QOol3000EOol00`00Oomoo`08Ool00`00Oomoo`03000QOol00`00Oomoo`06Ool00`00Oomoo`0O
Ool00`00@4I0AP0B@4H00`00KW9^LP0PKW800`00MoQgn006MoP00`00Oomoo`0>Ool00`00Oomoo`08
Ool000=oo`03001oogoo00Aoo`03001oogoo01ioo`<001Uoo`03001oogoo00Moo`<002Eoo`03001o
ogoo00Eoo`03001oogoo01ioo`030010AP000190AP03001^LVib01m^LP8000Ugn003001oogoo00io
o`03001oogoo00Qoo`000goo00<007ooOol017oo00<007ooOol06goo0`007Goo00<007ooOol00goo
1000:7oo00<007ooOol017oo00<007ooOol07Goo00D00416@4I0AP000110AP03001^LVib01m^LP03
001gn7Oh00Qgn003001oogoo00moo`03001oogoo00Qoo`000goo00<007ooOol017oo00<007ooOol0
67oo0`008Goo00<007oo00000P000goo00<007ooOol09goo00<007ooOol00goo00<007ooOol06goo
0P001D1600<00416@4H02d160P008Fib00<007OhMoP02GOh00<007ooOol03goo00<007ooOol027oo
0003Ool00`00Oomoo`04Ool00`00Oomoo`0EOol3000SOol30006Ool00`00Oomoo`0WOol00`00Oomo
o`03Ool00`00Oomoo`0HOol30008@4H00`00@4I0AP09@4H00`00KW9^LP0PKW800`00MoQgn009MoP0
0`00Oomoo`0AOol00`00Oomoo`07Ool000=oo`03001oogoo00Aoo`03001oogoo019oo`<002=oo`<0
00=oo`03001oogoo00=oo`03001oogoo02Qoo`03001oogoo009oo`03001oogoo01Aoo`@00003Ool0
041600U0AP030010AT1600M0AP03001^LVib021^LP03001gn7Oh00Ugn003001oogoo019oo`03001o
ogoo00Moo`000goo00<007ooOol017oo00<007ooOol03goo0`008goo0`001goo00<007ooOol00Woo
00<007ooOol0:Goo00D007ooOomoo`0001=oo`<000Aoo`030010AT1600U0AP030010AT1600I0AP03
001^LVib021^LP03001gn7Oh00Ugn003001oogoo01=oo`03001oogoo00Moo`000Woo00<007ooOol0
1Goo00<007ooOol037oo0`008goo0`002goo00D007ooOomoo`0002aoo`04001oogoo000@Ool30005
Ool2000=@4H00`00@4I0AP03@4H2000QKW82000:MoP2000FOol00`00Oomoo`07Ool0009oo`03001o
ogoo00Eoo`03001oogoo00Yoo`8002=oo`<000moo`04001oogoo000]Ool00`00Ool0000=Ool30007
Ool00`00@4I0AP0>@4H01@00@4I0AT1600008Vib00<007OhMoP02GOh00<007ooOol05Woo00<007oo
Ool01goo0002Ool00`00Oomoo`04Ool00`00Oomoo`08Ool3000ROol3000COol00`00Ool0000^Ool2
000:Ool30009Ool00`00@4I0AP0@@4H00`00@4H0000RKW800`00MoQgn009MoP00`00Oomoo`0GOol0
0`00Oomoo`07Ool0009oo`03001oogoo00Aoo`03001oogoo00Eoo`<0029oo`<001Moo`8002moo`03
001oogoo00Aoo`@000Yoo`8001A0AP03001^LVib021^LP03001gn7Oh00Ugn003001oogoo01Qoo`03
001oogoo00Moo`000Woo00<007ooOol017oo00<007ooOol00Woo0`008Woo0`006goo00<007ooOol0
;Goo0P000Woo0`003Goo00<00416@4H04T160P0000=^LP00KW807fib00<007OhMoP02GOh00<007oo
Ool06Goo00<007ooOol01goo0002Ool00`00Oomoo`04Ool00`00Ool00002000ROol3000NOol2000^
Ool01000Ool000003goo00<00416@4H04T1600<006ibKW800Vib00<006ibKW806fib0P002gOh00<0
07ooOol06Woo00<007ooOol01goo0002Ool00`00Oomoo`04Ool2000ROol3000QOol00`00Ool0000]
Ool00`00Ool0000?Ool00`00@4I0AP0B@4H00`00KW9^LP04KW800`00KW9^LP0IKW800`00MoQgn00:
MoP00`00Oomoo`0KOol00`00Oomoo`07Ool0009oo`03001oogoo00Eoo`03001oogoo01eoo`<002=o
o`04001oogooOol2000[Ool00`00Ool0000=Ool2000D@4H00`00KW9^LP05KW800`00KW9^LP0HKW80
0`00MoQgn009MoP2000NOol00`00Oomoo`07Ool0009oo`03001oogoo00Ioo`03001oogoo01Uoo`<0
02Ioo`03001oogoo00=oo`03001oogoo02Qoo`03001oo`0000aoo`030010AT160190AP8000U^LP03
001^LVib01I^LP03001gn7Oh00Ugn003001oogoo01moo`03001oogoo00Ioo`0000=oo`00Ool02Goo
0P005Goo1000:Goo00<007ooOol017oo00<007ooOol09goo00<007oo00002goo00<00416@4H04T16
00<006ibKW802Vib00<006ibKW8056ib00<007OhMoP02GOh00<007ooOol087oo00<007ooOol01Woo
00000goo001oo`0;Ool00`00Oomoo`0?Ool3000]Ool00`00Oomoo`05Ool00`00Oomoo`0VOol00`00
Ool0000:Ool00`00@4I0AP0B@4H00`00KW9^LP0<KW800`00KW9^LP0BKW800`00MoQgn009MoP00`00
Oomoo`0QOol00`00Oomoo`06Ool00003Ool007oo00aoo`03001oogoo00]oo`<0031oo`03001oogoo
00Ioo`03001oogoo02Eoo`03001oo`0000Qoo`8001A0AP03001^LVib00i^LP03001^LVib00m^LP80
00]gn003001oogoo029oo`03001oogoo00Ioo`0000=oo`00Ool03Goo00<007ooOol01goo0`00<goo
00<007ooOol01goo00<007ooOol097oo00<007oo00001goo00<00416@4H04T160P004Vib00<006ib
KW803Fib00<007OhMoP02WOh00<007ooOol08goo00<007ooOol01Woo00000goo001oo`0>Ool00`00
Oomoo`03Ool3000fOol00`00Oomoo`08Ool00`00Oomoo`0SOol00`00Ool00006Ool00`00@4I0AP0B
@4H00`00KW9^LP0CKW800`00KW9^LP0;KW800`00MoQgn00:MoP00`00Oomoo`0TOol00`00Oomoo`06
Ool00003Ool007oo00moo`03001oo`00008003Uoo`03001oogoo00Uoo`03001oogoo029oo`03001o
o`0000Aoo`8001A0AP03001^LVib01A^LP03001^LVib00Y^LP03001gn7Oh00Ygn003001oogoo02Eo
o`03001oogoo00Ioo`0000=oo`00Ool03Woo1000>goo00<007ooOol02Woo00<007ooOol08Goo00<0
07oo00000goo00<00416@4H04d1600<006ibKW805Vib00<006ibKW8026ib00<007OhMoP02GOh0P00
:7oo00<007ooOol01Woo00000goo001oo`0;Ool30004Ool00`00Oomoo`0hOol00`00Oomoo`0;Ool0
0`00Oomoo`0POol00`00Ool00002Ool00`00@4I0AP0B@4H2000JKW800`00KW9^LP06KW800`00MoQg
n009MoP00`00Oomoo`0XOol00`00Oomoo`06Ool00003001oogoo00Qoo`<000Qoo`03001oogoo03Mo
o`03001oogoo00aoo`03001oogoo01moo`05001oo`00Ool0000D@4H00`00KW9^LP0KKW800`00KW9^
LP03KW82000;MoP00`00Oomoo`0YOol00`00Oomoo`06Ool00003001oogoo00Eoo`<000aoo`03001o
ogoo03Ioo`03001oogoo00eoo`03001oogoo01ioo`04001oo`00000D@4H00`00KW9^LP0MKW801@00
KW9^LVib000037Oh00<007ooOol0:Woo00<007ooOol01Woo00000`00Oomoo`02Ool3000@Ool00`00
Oomoo`0eOol00`00Oomoo`0>Ool00`00Oomoo`0MOol2000D@4H2000QKW800`00KW80000<MoP00`00
Oomoo`0/Ool00`00Oomoo`05Ool00003001oo`00008001Aoo`03001oogoo03Aoo`03001oogoo00mo
o`03001oogoo01aoo`030010AT160190AP03001^LVib029^LP03001gn7Oh00Ygn003001oogoo02eo
o`03001oogoo00Eoo`000P0067oo0P00=7oo00<007ooOol047oo00<007ooOol06Woo00<00416@4H0
4T1600<006ibKW808Vib00<007Oh00002WOh00<007ooOol0;Woo00<007ooOol01Goo00000goo001o
o`0IOol00`00Oomoo`0aOol00`00Oomoo`0AOol00`00Oomoo`0GOol2000D@4H00`00KW9^LP0QKW82
0002MoP00`00MoQgn006MoP2000aOol00`00Oomoo`05Ool0009oo`8001Uoo`03001oogoo031oo`03
001oogoo019oo`03001oogoo01Eoo`030010AT160190AP8002=^LP03001gn7Oh00=gn003001gn7Oh
00Agn003001oogoo035oo`03001oogoo00Eoo`0017oo00<007ooOol05goo00<007ooOol0;goo00<0
07ooOol04goo00<007ooOol04goo00<00416@4H04T1600<006ibKW808Vib00<007OhMoP01GOh00<0
07OhMoP00WOh00<007ooOol0<Woo00<007ooOol01Goo0005Ool00`00Oomoo`0GOol00`00Oomoo`0^
Ool00`00Oomoo`0DOol00`00Oomoo`0@Ool2000D@4H00`00KW9^LP0RKW800`00MoQgn007MoP01000
MoQgn000=Goo00<007ooOol01Goo0006Ool00`00Oomoo`0GOol00`00Oomoo`0]Ool00`00Oomoo`0E
Ool00`00Oomoo`0>Ool00`00@4I0AP0C@4H00`00KW9^LP0RKW800`00MoQgn009MoP2000fOol00`00
Oomoo`05Ool000Moo`03001oogoo01Moo`8002eoo`03001oogoo01Ioo`03001oogoo00aoo`030010
AT160190AP8002A^LP03001gn7Oh00Ygn08003Ioo`03001oogoo00Eoo`0027oo0P006Goo00<007oo
Ool0:Woo00<007ooOol05goo00<007ooOol02Woo00<00416@4H04T1600<006ibKW808Vib0P0037Oh
00@007ooOol003Eoo`03001oogoo00Eoo`002Woo00<007ooOol05goo00<007ooOol0:Goo00<007oo
Ool067oo00<007ooOol01goo0P00541600<006ibKW808Vib00<007OhMoP02WOh0P000goo00<007oo
Ool0<goo00<007ooOol01Goo000;Ool00`00Oomoo`0GOol00`00Oomoo`0XOol00`00Oomoo`0IOol0
0`00Oomoo`05Ool00`00@4I0AP0C@4H00`00KW9^LP0RKW800`00MoQgn00:MoP00`00Oomoo`04Ool0
0`00Oomoo`0cOol00`00Oomoo`04Ool000aoo`03001oogoo01Moo`03001oogoo02Ioo`03001oogoo
01]oo`03001oogoo00=oo`D00110AP8002A^LP03001gn7Oh00Ygn003001oogoo00Ioo`03001oogoo
039oo`03001oogoo00Aoo`003Goo00<007ooOol05goo00<007ooOol09Goo00<007ooOol077oo0P00
0goo00<003hI?QT00ShI2P001D1600<006ibKW808fib00<007OhMoP02WOh00<007ooOol027oo00<0
07ooOol0<Goo00<007ooOol017oo000>Ool2000HOol2000UOol00`00Oomoo`0NOol00`00Ool0000?
?QT5000TKW82000<MoP00`00Oomoo`0:Ool00`00Oomoo`0`Ool00`00Oomoo`04Ool0011oo`03001o
ogoo01Moo`03001oogoo029oo`03001oogoo01moo`8001@n6@03001^LVib021^LP03001gn7Oh00]g
n003001oogoo00aoo`03001oogoo02moo`03001oogoo00Aoo`004Goo00<007ooOol05goo00<007oo
Ool08Goo00<007ooOol087oo00<003hI?QT04ShI00<006ibKW807fib00<007OhMoP02gOh00<007oo
Ool03Woo00<007ooOol0;Woo00<007ooOol017oo000BOol00`00Oomoo`0GOol00`00Oomoo`0POol0
0`00Oomoo`0OOol00`00?QT0000D?QT00`00KW9^LP0MKW800`00MoQgn00;MoP00`00Oomoo`0?Ool0
0`00Oomoo`0^Ool00`00Oomoo`04Ool001=oo`8001Qoo`03001oogoo01moo`03001oogoo01moo`04
000n6ChI000D?QT00`00KW9^LP0KKW800`00MoQgn00:MoP2000COol00`00Oomoo`0]Ool00`00Oomo
o`04Ool001Eoo`03001oogoo01Ioo`8001moo`03001oogoo01moo`05000n6ChI?QT0000C?QT00`00
KW9^LP0JKW800`00MoQgn00:MoP00`00Oomoo`0DOol00`00Oomoo`0/Ool00`00Oomoo`04Ool001Io
o`03001oogoo01Moo`03001oogoo01aoo`03001oogoo01ioo`03000n6ChI00<n6@03000n6ChI014n
6@03001^LVib01M^LP8000agn003001oogoo01Ioo`03001oogoo02]oo`03001oogoo00Aoo`005goo
00<007ooOol05goo00<007ooOol06goo00<007ooOol07Woo00<003hI?QT013hI00<003hI?QT04ChI
00<006ibKW805Fib00<007OhMoP02gOh00<007ooOol067oo00<007ooOol0:goo00<007ooOol00goo
000HOol00`00Oomoo`0GOol00`00Oomoo`0JOol00`00Oomoo`0NOol00`00?QTn6@05?QT00`00?QTn
6@0A?QT00`00KW9^LP0CKW800`00MoQgn00;MoP00`00Oomoo`0JOol00`00Oomoo`0ZOol00`00Oomo
o`03Ool001Uoo`8001Qoo`03001oogoo01Uoo`03001oogoo01ioo`03000n6ChI00Hn6@03000n6ChI
010n6@03001^LVib019^LP03001gn7Oh00]gn003001oogoo01aoo`03001oogoo02Uoo`03001oogoo
00=oo`006goo00<007ooOol05Woo00<007ooOol067oo00<007ooOol07Goo00<003hI?QT023hI00<0
03hI?QT043hI00<006ibKW8046ib00<007OhMoP02gOh00<007ooOol07Woo00<007ooOol0:7oo00<0
07ooOol00goo000LOol00`00Oomoo`0FOol2000HOol00`00Oomoo`0MOol00`00?QTn6@09?QT00`00
?QTn6@0@?QT00`00KW9^LP0>KW800`00MoQgn00:MoP2000QOol00`00Oomoo`0XOol00`00Oomoo`03
Ool001eoo`03001oogoo01Moo`03001oogoo01Eoo`03001oogoo01eoo`03000n6ChI00Xn6@03000n
6ChI00ln6@03001^LVib00a^LP8000agn003001oogoo029oo`03001oogoo02Moo`03001oogoo00=o
o`007Woo00<007ooOol05goo00<007ooOol057oo00<007ooOol077oo00<003hI?QT033hI00<003hI
?QT03chI00<006ibKW802Vib00<007OhMoP02gOh00<007ooOol097oo00<007ooOol09Woo00<007oo
Ool00goo000OOol2000HOol00`00Oomoo`0COol00`00Oomoo`0LOol00`00?QTn6@0=?QT00`00?QTn
6@0??QT00`00KW9^LP08KW800`00MoQgn00;MoP00`00Oomoo`0VOol00`00Oomoo`0UOol00`00Oomo
o`03Ool0025oo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo01eoo`03000n6ChI00dn6@03
000n6ChI00hn6@03001^LVib00M^LP03001gn7Oh00]gn003001oogoo02Qoo`03001oogoo02Aoo`03
001oogoo00=oo`008Woo00<007ooOol05Woo00<007ooOol04Goo00<007ooOol07Goo00<003hI?QT0
3ShI00<003hI?QT03ShI00<006ibKW801Fib00<007OhMoP02gOh00<007ooOol0:Woo00<007ooOol0
8goo00<007ooOol00goo000SOol00`00Oomoo`0FOol2000AOol00`00Oomoo`0NOol00`00?QTn6@0=
?QT2000@?QT00`00KW9^LP02KW82000=MoP00`00Oomoo`0/Ool00`00Oomoo`0ROol00`00Oomoo`03
Ool002Aoo`03001oogoo01Moo`03001oogoo00ioo`03001oogoo01moo`03000n6ChI00Tn6@<001<n
6@04001^LVib000>MoP00`00Oomoo`0]Ool00`00Oomoo`0SOol00`00Oomoo`02Ool002Eoo`8001Qo
o`03001oogoo00eoo`03001oogoo01moo`03000n6ChI00Dn6@@001Hn6@03001^LP0000egn080035o
o`03001oogoo029oo`03001oogoo009oo`009goo00<007ooOol05Woo00<007ooOol037oo00<007oo
Ool087oo00@003hI?QTn6@<001/n6@03001gn7Oh00]gn003001oogoo039oo`03001oogoo025oo`03
001oogoo009oo`00:7oo00<007ooOol05Woo00<007ooOol02Woo00<007ooOol08Woo0`007ShI00<0
07OhMoP02WOh00<007ooOol0=7oo00<007ooOol087oo00<007ooOol00Woo000YOol00`00Oomoo`0F
Ool00`00Oomoo`09Ool00`00Oomoo`0NOol400000goo000n6@0M?QT00`00MoQgn00:MoP00`00Oomo
o`0fOol00`00Oomoo`0OOol00`00Oomoo`02Ool002Yoo`8001Moo`8000Uoo`03001oogoo01]oo`<0
00Eoo`03000n6ChI01`n6@03001gn7Oh00Ugn003001oogoo03Qoo`03001oogoo01ioo`03001oogoo
009oo`00;7oo00<007ooOol05Woo00<007ooOol01Woo00<007ooOol05goo10002Goo00<003hI?QT0
6chI00<007OhMoP027Oh00<007ooOol0>Woo00<007ooOol07Goo00<007ooOol00Woo000]Ool00`00
Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0DOol3000>Ool00`00?QTn6@0J?QT00`00MoQgn007
MoP00`00Oomoo`0lOol00`00Oomoo`0LOol00`00Oomoo`02Ool002ioo`03001oogoo01Ioo`03001o
ogoo00Aoo`03001oogoo011oo`@0015oo`03000n6ChI01Tn6@03001gn7Oh00Ign08003moo`03001o
ogoo01aoo`03001oogoo009oo`00;goo00<007ooOol05Woo00<007ooOol00goo00<007ooOol03Goo
0`005Woo00<003hI?QT063hI00<007OhMoP01GOh00<007ooOol0@7oo00<007ooOol06goo00<007oo
Ool00Woo000`Ool2000GOol00`00Oomoo`02Ool00`00Oomoo`0:Ool3000JOol00`00?QTn6@0G?QT0
0`00MoQgn004MoP00`00Oomoo`12Ool00`00Oomoo`0JOol00`00Oomoo`02Ool0039oo`03001oogoo
01Eoo`80009oo`03001oogoo00Ioo`@001eoo`03000n6ChI01Hn6@03001gn7Oh00Agn003001oogoo
04Aoo`03001oogoo01Yoo`03001oogoo005oo`00<goo00<007ooOol05Woo00<007oo00001Goo0`00
8Woo00<003hI?QT05ChI00<007OhMoP00gOh00<007ooOol0AWoo00<007ooOol06Goo00<007ooOol0
0Goo000dOol00`00Oomoo`0FOol200000goo00000002000VOol00`00?QTn6@0D?QT00`00MoQgn002
MoP00`00Oomoo`18Ool00`00Oomoo`0HOol00`00Oomoo`01Ool003Eoo`03001oogoo01Ioo`8002]o
o`03000n6ChI018n6@03001gn7Oh009gn003001oogoo04Yoo`03001oogoo01Moo`03001oogoo005o
o`00=Woo0P00@goo00<003hI?QT04ShI00<007OhMoP00P00CGoo00<007ooOol05goo00<007ooOol0
0Goo000hOol00`00Oomoo`11Ool4000@?QT00`00MoP0001@Ool00`00Oomoo`0FOol00`00Oomoo`01
Ool003Uoo`03001oogoo04Aoo`H000Xn6@80059oo`03001oogoo01Eoo`03001oogoo005oo`00>Woo
00<007ooOol0AWoo00<007ooOol01P000chI0P00E7oo00<007ooOol057oo00<007ooOol00Goo000k
Ool20016Ool00`00Oomoo`06Ool4001FOol00`00Oomoo`0COol00`00Oomoo`01Ool003eoo`03001o
ogoo04=oo`03001oogoo065oo`03001oogoo019oo`03001oogoo005oo`00?Woo00<007ooOol0@Woo
00<007ooOol0HWoo00<007ooOol04Goo00<007ooOol00Goo000oOol00`00Oomoo`11Ool00`00Oomo
o`1SOol00`00Oomoo`0AOol10001Ool1Ool0041oo`03001oogoo041oo`03001oogoo06=oo`03001o
ogoo015oo`40005oo`5oo`00@Goo0P00@7oo00<007ooOol0I7oo00<007ooOol047oo0@000Goo0Goo
0013Ool00`00Oomoo`0mOol00`00Oomoo`1UOol00`00Oomoo`0?Ool10001Ool1Ool004Aoo`03001o
ogoo03aoo`03001oogoo06Ioo`03001oogoo00ioo`40005oo`5oo`00AGoo00<007ooOol0>goo00<0
07ooOol0Igoo00<007ooOol03Goo0@000Goo0Goo0016Ool00`00Oomoo`0jOol00`00Oomoo`1XOol0
0`00Oomoo`0<Ool10001Ool1Ool004Moo`8003Yoo`03001oogoo06Uoo`03001oogoo00]oo`40005o
o`5oo`00BGoo00<007ooOol0=goo00<007ooOol0JGoo00<007ooOol02goo0@000Goo0Goo001:Ool0
0`00Oomoo`0fOol00`00Oomoo`1ZOol00`00Oomoo`0:Ool10001Ool1Ool004]oo`03001oogoo03Eo
o`03001oogoo06]oo`03001oogoo00Yoo`40005oo`00C7oo0P00=Goo00<007ooOol0K7oo00<007oo
Ool02Goo0@000Goo001>Ool00`00Oomoo`0bOol00`00Oomoo`1]Ool00`00Oomoo`08Ool10001Ool0
04moo`03001oogoo035oo`03001oogoo06ioo`03001oogoo00Moo`40005oo`00D7oo00<007ooOol0
<7oo00<007ooOol0Kgoo00<007ooOol01Woo0@000Goo001AOol00`00Oomoo`0_Ool00`00Oomoo`1_
Ool00`00Oomoo`06Ool10001Ool0059oo`8002moo`03001oogoo071oo`03001oogoo00Eoo`40005o
o`00E7oo00<007ooOol0;7oo00<007ooOol0LGoo00<007ooOol017oo0@000Goo001EOol00`00Oomo
o`0[Ool00`00Oomoo`1bOol00`00Oomoo`03Ool10001Ool005Ioo`03001oogoo02Yoo`03001oogoo
07=oo`03001oogoo009oo`40005oo`00Egoo00<007ooOol0:Goo00<007ooOol0M7oo00D007ooOomo
o`00005oo`00F7oo0P00:Goo00<007ooOol0MGoo00@007ooOomoo`400000FWoo00<007ooOol09Woo
00<007ooOol0MWoo00<007ooOol00@00001KOol00`00Oomoo`0UOol00`00Oomoo`1fOol00`00Oomo
o`01000005aoo`03001oogoo02Aoo`03001oogoo07Moo`40005oo`400000GGoo0P0097oo00<007oo
Ool0N7oo0P00001OOol00`00Oomoo`0QOol00`00Oomoo`1gOol30000061oo`03001oogoo021oo`03
001oogoo07=oo`@000=oo`00HGoo00<007ooOol07goo00<007ooOol0Kgoo10001goo001ROol00`00
Oomoo`0NOol00`00Oomoo`1[Ool4000;Ool006=oo`8001ioo`03001oogoo06Moo`@000moo`00IGoo
00<007ooOol06goo00<007ooOol0Hgoo10004goo001VOol00`00Oomoo`0JOol00`00Oomoo`1OOol4
000GOol006Moo`03001oogoo01Uoo`03001oogoo05]oo`@001]oo`00J7oo00<007ooOol067oo00<0
07ooOol0EWoo1@007goo001YOol2000HOol00`00Oomoo`1BOol4000TOol006]oo`03001oogoo01Eo
o`03001oogoo04ioo`@002Qoo`00K7oo00<007ooOol057oo00<007ooOol0BWoo1000;7oo001]Ool0
0`00Oomoo`0COol00`00Oomoo`16Ool4000`Ool006ioo`03001oogoo019oo`03001oogoo049oo`@0
03Aoo`00Kgoo0P004Woo00<007ooOol0?Woo1000>7oo001aOol00`00Oomoo`0?Ool00`00Oomoo`0i
Ool5000lOol0079oo`03001oogoo00ioo`03001oogoo03Eoo`@0045oo`00Lgoo00<007ooOol03Goo
00<007ooOol0<Goo1000AGoo001dOol2000=Ool00`00Oomoo`0]Ool40019Ool007Ioo`03001oogoo
00Yoo`03001oogoo02Uoo`@004eoo`00Mgoo00<007ooOol02Goo00<007ooOol09Goo1000DGoo001h
Ool00`00Oomoo`08Ool00`00Oomoo`0QOol4001EOol007Uoo`03001oogoo00Moo`03001oogoo01eo
o`@005Uoo`00NWoo0P001goo00<007ooOol067oo1@00GGoo001lOol00`00Oomoo`04Ool00`00Oomo
o`0DOol4001ROol007eoo`03001oogoo00=oo`03001oogoo011oo`@006Ioo`00OWoo00<007ooOol0
0Woo00<007ooOol037oo1000JWoo001oOol01@00Oomoogoo00002Woo1000KWoo0020Ool200000goo
001oo`05Ool4001bOol0089oo`80009oo`@007Ioo`00Pgoo0`00NWoo0000\
\>"],
  ImageRangeCache->{{{0, 255.813}, {298.25, 0}} -> {0.0723345, -0.00022466, 
  0.00311072, 0.00311072}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used here to generate a part of an octagon with a hole in it. \
Note that the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-gon returned by ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is placed on the body that is referenced in the ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " argument, and is located with that body as such."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This generates a piece of an octagon on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics3D[{
          Wheel[Line[body2, {0, 0, 0}, {0, 1, \(-1\)}], {.8, .4}, 6, 
            Angle \[Rule] {0, 3\ \[Pi]/2}]}, PlotRange \[Rule] All]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] .2, Z2 \[Rule] .1, Eo2 \[Rule] 1, 
          Ei2 \[Rule] 0, Ej2 \[Rule] 0, Ek2 \[Rule] 0}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .94498 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.01848 -0.00409022 1.01848 [
[ 0 0 0 0 ]
[ 1 .94498 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06022 .2628 m
0 .70799 L
s
0 .70799 m
.31355 .94498 L
s
.31355 .94498 m
.33382 .53057 L
s
.33382 .53057 m
.06022 .2628 L
s
.73399 0 m
.94383 .33204 L
s
.94383 .33204 m
1 .77003 L
s
1 .77003 m
.76837 .4676 L
s
.76837 .4676 m
.73399 0 L
s
.06022 .2628 m
0 .70799 L
s
0 .70799 m
.76837 .4676 L
s
.76837 .4676 m
.73399 0 L
s
.73399 0 m
.06022 .2628 L
s
.33382 .53057 m
.94383 .33204 L
s
.94383 .33204 m
1 .77003 L
s
1 .77003 m
.31355 .94498 L
s
.31355 .94498 m
.33382 .53057 L
s
0 0 m
1 0 L
1 .94498 L
0 .94498 L
closepath
clip
newpath
.5 Mabswid
.35366 .42118 m .35202 .55548 L .20286 .60324 L p .626 .548 .747 r
F P
0 g
s
.20286 .60324 m .2026 .33964 L .35366 .42118 L p .626 .548 .747 r
F P
0 g
s
.44703 .33191 m .35366 .42118 L .2026 .33964 L p .626 .548 .747 r
F P
0 g
s
.2026 .33964 m .38408 .1566 L .44703 .33191 L p .626 .548 .747 r
F P
0 g
s
.83479 .68086 m .63149 .8456 L .57072 .67637 L p .626 .548 .747 r
F P
0 g
s
.57072 .67637 m .66955 .59167 L .83479 .68086 L p .626 .548 .747 r
F P
0 g
s
.58136 .34304 m .44703 .33191 L .38408 .1566 L p .626 .548 .747 r
F P
0 g
s
.38408 .1566 m .65701 .17302 L .58136 .34304 L p .626 .548 .747 r
F P
0 g
s
.66955 .59167 m .6752 .45202 L .85064 .39585 L p .626 .548 .747 r
F P
0 g
s
.85064 .39585 m .83479 .68086 L .66955 .59167 L p .626 .548 .747 r
F P
0 g
s
.6752 .45202 m .58136 .34304 L .65701 .17302 L p .626 .548 .747 r
F P
0 g
s
.65701 .17302 m .85064 .39585 L .6752 .45202 L p .626 .548 .747 r
F P
0 g
s
.25 Mabswid
.73399 0 m
.94383 .33204 L
s
.94383 .33204 m
1 .77003 L
s
1 .77003 m
.76837 .4676 L
s
.76837 .4676 m
.73399 0 L
s
.06022 .2628 m
0 .70799 L
s
0 .70799 m
.76837 .4676 L
s
.76837 .4676 m
.73399 0 L
s
.73399 0 m
.06022 .2628 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{230, 218},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003V0000fQ000`40O003h00OiWoo002WOol2000m
Ool00:Eoo`800003Ool0000003aoo`00XWoo0`000goo0P00?7oo002OOol30006Ool00`00Ool0000k
Ool009eoo`8000Uoo`04001oogoo000jOol009Yoo`<000]oo`04001oogoo000jOol009Qoo`8000io
o`05001oogooOol0000iOol009Eoo`<0011oo`05001oogooOol0000iOol009=oo`8001Aoo`05001o
ogooOol0000hOol0091oo`<001Ioo`03001oogoo009oo`03001oogoo03Eoo`00SGoo0`006Goo00<0
07ooOol00Woo00<007ooOol0=Goo002;Ool2000LOol00`00Oomoo`03Ool00`00Oomoo`0dOol008Qo
o`<001ioo`03001oogoo00Aoo`03001oogoo03=oo`00QWoo0P008Goo00<007ooOol017oo00<007oo
Ool0<goo0023Ool3000SOol00`00Oomoo`05Ool00`00Oomoo`0bOol0081oo`<002Ioo`03001oogoo
00Eoo`03001oogoo039oo`00OWoo0P00:Goo00<007ooOol01Woo00<007ooOol0<Goo001kOol3000[
Ool00`00Oomoo`07Ool00`00Oomoo`0`Ool007Uoo`8002ioo`03001oogoo00Moo`03001oogoo031o
o`00MWoo0`00<7oo00<007ooOol027oo00<007ooOol0;goo001dOol2000cOol00`00Oomoo`09Ool0
0`00Oomoo`0^Ool0075oo`<003Eoo`03001oogoo00Uoo`03001oogoo02ioo`00KWoo0`00>7oo00<0
07ooOol02Woo00<007ooOol0;Goo001/Ool2000lOol00`00Oomoo`0:Ool00`00Oomoo`0/Ool006Uo
o`<003ioo`03001oogoo00Yoo`03001oogoo02aoo`00Igoo0P00@Goo00<007ooOol02goo00<007oo
Ool0:goo001TOol30013Ool00`00Oomoo`0;Ool00`00Oomoo`0[Ool0065oo`<004Ioo`03001oogoo
00aoo`03001oogoo02Yoo`00Ggoo0P00BGoo00<007ooOol03Goo00<007ooOol0:Goo001LOol3001;
Ool00`00Oomoo`0=Ool00`00Oomoo`0YOol005Yoo`8004ioo`03001oogoo00ioo`03001oogoo02Qo
o`00Egoo0`00D7oo00<007ooOol03goo00<007ooOol09goo001EOol2001COol00`00Oomoo`0?Ool0
0`00Oomoo`0WOol0059oo`<005Eoo`03001oogoo011oo`03001oogoo02Ioo`00Cgoo0`00F7oo00<0
07ooOol047oo00<007ooOol09Woo001=Ool2001KOol00`00Oomoo`0AOol00`00Oomoo`0UOol004Yo
o`<000Yoo`/004Qoo`03001oogoo019oo`03001oogoo02Aoo`00B7oo0P0037oo0P002U8g5@00<goo
00<007ooOol04Woo00<007ooOol097oo0015Ool3000=Ool01000DSMB=`007U8g5@007Woo00<007oo
Ool04goo00<007ooOol08goo0012Ool3000?Ool01@00DSMB=e8g0000<e8g2`0057oo00<007ooOol0
4goo00<007ooOol08Woo0010Ool2000AOol00`00DSMB=`02DSL00`00DSMB=`0kDSL2000COol00`00
Oomoo`0COol00`00Oomoo`0ROol003eoo`<0019oo`03001B=e8g00AB=`03001B=e8g03UB=`04001B
=e8g000BOol00`00Oomoo`0DOol00`00Oomoo`0QOol003]oo`8001Aoo`03001B=e8g00EB=`03001B
=e8g03UB=`05001B=e8gDSL0000AOol00`00Oomoo`0EOol00`00Oomoo`0POol003Qoo`<001Eoo`03
001B=e8g00MB=`03001B=e8g03MB=`03001B=e8g009B=`03001oogoo00moo`03001oogoo01Eoo`03
001oogoo021oo`00=Woo0P005goo00<0058gDSL0258g00<0058gDSL0=e8g00<0058gDSL00e8g00<0
07ooOol03Woo00<007ooOol05Woo00<007ooOol07goo000cOol3000HOol00`00DSMB=`09DSL00`00
DSMB=`0fDSL00`00DSMB=`05DSL00`00Oomoo`0=Ool00`00Oomoo`0FOol00`00Oomoo`0OOol0031o
o`<001Yoo`03001B=e8g00]B=`03001B=e8g03EB=`03001B=e8g00IB=`03001oogoo00aoo`03001o
ogoo01Moo`03001oogoo01ioo`00;Woo0P0077oo00<0058gDSL0358g00<0058gDSL0=E8g00<0058g
DSL01e8g00<007ooOol02goo00<007ooOol067oo00<007ooOol07Goo000[Ool3000MOol00`00DSMB
=`0=DSL00`00DSMB=`0dDSL00`00DSMB=`09DSL00`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomo
o`0MOol002Uoo`8001moo`03001B=e8g00mB=`03001B=e8g03=B=`03001B=e8g00YB=`03001oogoo
00Uoo`03001oogoo01Uoo`03001oogoo01aoo`009Woo0`0087oo00<0058gDSL0458g00<0058gDSL0
<U8g00<0058gDSL02e8g00<007ooOol02Goo00<007ooOol06Woo00<007ooOol06goo000SOol3000R
Ool00`00DSMB=`0BDSL00`00DSMB=`0aDSL00`00DSMB=`0<DSL00`00Oomoo`08Ool00`00Oomoo`0J
Ool00`00Oomoo`0KOol0025oo`8002Aoo`03001B=e8g01=B=`03001B=e8g031B=`03001B=e8g00iB
=`03001oogoo00Moo`03001oogoo01]oo`03001oogoo01Yoo`007Woo0`009Goo00<0058gDSL0558g
00<0058gDSL0<58g00<0058gDSL03e8g00<007ooOol01Woo00<007ooOol06goo00<007ooOol06Woo
000LOol2000WOol00`00DSMB=`0FDSL00`00DSMB=`0^DSL00`00DSMB=`0ADSL00`00Oomoo`06Ool0
0`00Oomoo`0KOol00`00Oomoo`0IOol001Uoo`<002Qoo`03001B=e8g01MB=`03001B=e8g02iB=`03
001B=e8g019B=`03001oogoo00Eoo`03001oogoo01aoo`03001oogoo01Qoo`005goo0P00:Woo00<0
058gDSL0658g00<0058gDSL0;U8g00<0058gDSL04e8g00<007ooOol017oo00<007ooOol077oo00<0
07ooOol067oo000DOol3000[Ool00`00DSMB=`0JDSL00`00DSMB=`0/DSL00`00DSMB=`0EDSL00`00
Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`0GOol0015oo`<002ioo`03001B=e8g01YB=`03001B
=e8g02aB=`03001B=e8g01EB=`03001oogoo00=oo`03001oogoo01ioo`03001oogoo01Ioo`003goo
0P00<7oo00<0058gDSL0758g00<0058gDSL0:U8g00<0058gDSL05e8g00<007ooOol00Woo00<007oo
Ool07Woo00<007ooOol05Woo000=Ool2000aOol00`00DSMB=`0MDSL00`00DSMB=`0ZDSL00`00DSMB
=`0HDSL01@00Oomoogoo00008Goo00<007ooOol05Goo000=Ool2000`Ool00`00DSMB=`0NDSL00`00
DSMB=`0YDSL00`00DSMB=`0JDSL01000Oomoo`008Woo00<007ooOol057oo000=Ool00`00Ool0000^
Ool00`00DSMB=`0PDSL00`00DSMB=`0XDSL00`00DSMB=`0KDSL00`00Ool0000ROol00`00Oomoo`0D
Ool000eoo`04001oogoo000/Ool00`00DSMB=`0QDSL00`00DSMB=`0XDSL00`00DSMB=`0LDSL2000S
Ool00`00Oomoo`0COol000aoo`03001oogoo009oo`03001oogoo02Qoo`03001B=e8g029B=`03001B
=e8g02MB=`03001B=e8g01iB=`03001oogoo025oo`03001oogoo01=oo`0037oo00<007ooOol00goo
00<007ooOol09Woo00<0058gDSL0958g00<0058gDSL09U8g00<0058gDSL07U8g00<007ooOol08Woo
00<007ooOol04Woo000<Ool00`00Oomoo`04Ool00`00Oomoo`0TOol00`00DSMB=`0UDSL00`00DSMB
=`0UDSL00`00DSMB=`0ODSL2000TOol00`00Oomoo`0AOol000aoo`03001oogoo00Eoo`03001oogoo
029oo`03001B=e8g02MB=`03001B=e8g02AB=`03001B=e8g01mB=`03001B=`0002=oo`03001oogoo
015oo`0037oo00<007ooOol01Woo00<007ooOol087oo00<0058gDSL0:58g00<0058gDSL08e8g00<0
058gDSL0858g00@0058gDSL002=oo`03001oogoo011oo`0037oo00<007ooOol01goo00<007ooOol0
7Woo00<0058gDSL0:E8g00<0058gDSL08e8g00<0058gDSL08E8g00@0058gDSL002=oo`03001oogoo
00moo`0037oo00<007ooOol027oo00<007ooOol077oo00<0058gDSL0:e8g00<0058gDSL08E8g00<0
058gDSL08U8g00D0058gDSMB=`00029oo`03001oogoo00moo`0037oo00<007ooOol02Goo00<007oo
Ool06Woo00<0058gDSL0;58g00<0058gDSL08E8g00<0058gDSL08U8g00<0058gDSL00U8g00<007oo
Ool087oo00<007ooOol03Woo000;Ool00`00Oomoo`0;Ool00`00Oomoo`0HOol00`00DSMB=`0]DSL0
0`00DSMB=`0QDSL00`00DSMB=`0RDSL00`00DSMB=`02DSL00`00Oomoo`0POol00`00Oomoo`0>Ool0
00]oo`03001oogoo00aoo`03001oogoo01Ioo`03001B=e8g02mB=`03001B=e8g01mB=`03001B=e8g
02=B=`03001B=e8g00=B=`03001oogoo021oo`03001oogoo00eoo`002goo00<007ooOol03Goo00<0
07ooOol057oo00<0058gDSL0<58g00<0058gDSL07e8g00<0058gDSL08e8g00<0058gDSL0158g00<0
07ooOol087oo00<007ooOol037oo000;Ool00`00Oomoo`0>Ool2000COol00`00DSMB=`0bDSL00`00
DSMB=`0MDSL00`00DSMB=`0TDSL00`00DSMB=`05DSL00`00Oomoo`0OOol00`00Oomoo`0<Ool000]o
o`03001oogoo011oo`03001oogoo00moo`03001B=e8g03=B=`P001QB=`03001B=e8g02AB=`03001B
=e8g00IB=`03001oogoo01ioo`8000eoo`002goo00<007ooOol04Goo00<007ooOol03Goo00<0058g
DSL0<e8g00<007ooOol01Woo40001e8g00<0058gDSL09E8g00<0058gDSL01e8g00<007ooOol06Woo
0`0000=oo`00Ool037oo000;Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00DSMB=`0cDSL00`00
Oomoo`0GOol8000WDSL00`00DSMB=`08DSL00`00Oomoo`0FOol30004Ool00`00Oomoo`0;Ool000]o
o`03001oogoo01=oo`03001oogoo00Yoo`<0039B=`03001oogoo021oo`03001B=e8g02AB=`03001B
=e8g00UB=`03001oogoo019oo`<000Moo`03001oogoo00]oo`002Woo00<007ooOol05Goo00<007oo
Ool02Goo00<0058gDSL00P00;e8g00<007ooOol08Woo00<0058gDSL08e8g00<0058gDSL02E8g00<0
07ooOol03goo0`002goo00<007ooOol02Woo000:Ool00`00Oomoo`0FOol00`00Oomoo`08Ool00`00
DSMB=`02DSL2000[DSL2000VOol00`00DSMB=`0RDSL00`00DSMB=`0:DSL00`00Oomoo`0:Ool4000>
Ool00`00Oomoo`0:Ool000Yoo`03001oogoo01Moo`03001oogoo00Moo`03001B=e8g00AB=`8002QB
=`03001oogoo02Ioo`03001B=e8g029B=`03001B=e8g00]B=`03001oogoo00Ioo`<0019oo`03001o
ogoo00Yoo`002Woo00<007ooOol067oo00<007ooOol01Woo00<0058gDSL01U8g0P009E8g00<007oo
Ool0:7oo00<0058gDSL08E8g00<0058gDSL0358g00<007ooOol00Woo0`005Goo00<007ooOol02Woo
000:Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00DSMB=`08DSL2000RDSL00`00Oomoo`0ZOol0
0`00DSMB=`0PDSL00`00DSMB=`0=DSL4000HOol00`00Oomoo`0:Ool000Yoo`03001oogoo01Yoo`03
001oogoo00Aoo`03001B=e8g00YB=`8001mB=`03001oogoo02aoo`03001B=e8g021B=`03001B=e8g
00eB=`03001oogoo01Qoo`03001oogoo00Yoo`002Woo00<007ooOol06goo00<007ooOol00goo00<0
058gDSL0358g0P00758g00<007ooOol0;Woo00<0058gDSL07e8g00<0058gDSL03U8g00<007ooOol0
5goo00<007ooOol02Woo000:Ool00`00Oomoo`0LOol00`00Oomoo`02Ool00`00DSMB=`0>DSL00`00
DSMB=`0HDSL00`00Oomoo`0`Ool00`00DSMB=`0NDSL00`00DSMB=`0>DSL00`00Oomoo`0GOol00`00
Oomoo`0:Ool000Uoo`03001oogoo01ioo`05001oogooOol0000ADSL2000GDSL00`00Oomoo`0aOol0
0`00DSMB=`0NDSL00`00DSMB=`0?DSL00`00Oomoo`0GOol00`00Oomoo`09Ool000Uoo`03001oogoo
01moo`04001oogoo000CDSL2000DDSL00`00Oomoo`0cOol00`00DSMB=`0MDSL00`00DSMB=`0@DSL0
0`00Oomoo`0FOol00`00Oomoo`09Ool000Uoo`03001oogoo021oo`03001oo`0001EB=`80015B=`03
001oogoo03Eoo`03001B=e8g01aB=`03001B=e8g011B=`8001Moo`03001oogoo00Uoo`002Goo00<0
07ooOol08Goo0P005e8g0P003E8g0P00>Goo00<0058gDSL06e8g00<0058gDSL03E8g0`0000=B=`00
Ool05Woo00<007ooOol02Goo0009Ool00`00Oomoo`0ROol00`00DSMB=`0GDSL2000:DSL00`00Oomo
o`0jOol00`00DSMB=`0JDSL00`00DSMB=`0:DSL30004DSL00`00Oomoo`0EOol00`00Oomoo`09Ool0
00Uoo`03001oogoo029oo`03001B=e8g01UB=`8000MB=`03001oogoo03aoo`03001B=e8g01UB=`03
001B=e8g00MB=`<000MB=`03001oogoo01Eoo`03001oogoo00Uoo`002Goo00<007ooOol08Woo00<0
058gDSL06e8g0P00158g00<007ooOol0?Goo00<0058gDSL06E8g00<0058gDSL0158g0`002U8g00<0
07ooOol05Goo00<007ooOol02Goo0009Ool00`00Oomoo`0ROol00`00DSMB=`0MDSL200000e8g001o
o`10Ool00`00DSMB=`0HDSL01000DSMB=e8g0`003E8g00<007ooOol05Goo00<007ooOol02Goo0008
Ool00`00Oomoo`0SOol00`00DSMB=`0ODSL00`00Oomoo`11Ool00`00DSMB=`0GDSL4000@DSL00`00
Oomoo`0FOol00`00Oomoo`08Ool000Qoo`03001oogoo02=oo`03001B=e8g01mB=`03001oogoo049o
o`03001B=e8g01=B=`@001=B=`03001oogoo01Ioo`03001oogoo00Qoo`0027oo00<007ooOol08goo
00<0058gDSL07e8g00<007ooOol0@7oo10004E8g0`000e8g00<0058gDSL04E8g00<007ooOol05Woo
00<007ooOol027oo0008Ool00`00Oomoo`0SOol00`00DSMB=`0ODSL00`00Oomoo`0lOol40004Ool0
0`00DSMB=`0;DSL30006DSL00`00DSMB=`0ADSL00`00Oomoo`0FOol00`00Oomoo`08Ool000Qoo`03
001oogoo02=oo`03001B=e8g01mB=`03001oogoo03Uoo`<000Qoo`03001B=e8g00QB=`<000YB=`03
001B=e8g011B=`03001oogoo01Ioo`03001oogoo00Qoo`0027oo00<007ooOol08goo00<0058gDSL0
7e8g00<007ooOol0=Woo0`0037oo00<0058gDSL0158g0`003E8g00<0058gDSL03e8g00<007ooOol0
5goo00<007ooOol027oo0008Ool00`00Oomoo`0SOol00`00DSMB=`0ODSL00`00Oomoo`0cOol3000@
Ool00`00DSMB=`03000@DSL00`00DSMB=`0?DSL00`00Oomoo`0GOol00`00Oomoo`08Ool000Qoo`03
001oogoo02=oo`03001B=e8g01mB=`03001oogoo031oo`<001Aoo`8001=B=`03001B=e8g00mB=`03
001oogoo01Qoo`03001oogoo00Moo`001goo00<007ooOol097oo00<0058gDSL07e8g00<007ooOol0
;Goo0`005goo00<0058gDSL04U8g00<0058gDSL03e8g00<007ooOol067oo00<007ooOol01goo0007
Ool00`00Oomoo`0TOol00`00DSMB=`0ODSL00`00Oomoo`0ZOol3000JOol00`00DSMB=`0BDSL00`00
DSMB=`0?DSL00`00Oomoo`0HOol00`00Oomoo`07Ool000Moo`03001oogoo02Aoo`03001B=e8g01mB
=`03001oogoo02Moo`<001eoo`03001B=e8g019B=`03001B=e8g00mB=`03001oogoo01Qoo`03001o
ogoo00Moo`001goo00<007ooOol097oo00<0058gDSL07e8g00<007ooOol097oo0`0087oo00<0058g
DSL04E8g0P004E8g00<007ooOol067oo00<007ooOol01goo0007Ool00`00Oomoo`0TOol00`00DSMB
=`0ODSL00`00Oomoo`0POol4000SOol00`00DSMB=`0>DSL30002DSL00`00DSMB=`0>DSL00`00Oomo
o`0HOol00`00Oomoo`07Ool000Moo`03001oogoo02Aoo`03001B=e8g01mB=`03001oogoo01eoo`<0
02Moo`03001B=e8g00]B=`<000IB=`03001B=e8g00eB=`03001oogoo01Qoo`03001oogoo00Moo`00
1goo00<007ooOol097oo00<0058gDSL07e8g00<007ooOol06Woo0`00:Woo00<0058gDSL01e8g1000
2E8g00<0058gDSL03E8g00<007ooOol067oo00<007ooOol01goo0006Ool00`00Oomoo`0UOol00`00
DSMB=`0ODSL00`00Oomoo`0GOol3000]Ool00`00DSMB=`04DSL3000>DSL00`00DSMB=`0<DSL00`00
Oomoo`0IOol00`00Oomoo`06Ool000Ioo`03001oogoo02Eoo`03001B=e8g01mB=`03001oogoo01Ao
o`<0031oo`04001B=e8gDSL3000BDSL00`00DSMB=`0;DSL00`00Oomoo`0IOol00`00Oomoo`06Ool0
00Ioo`03001oogoo02Eoo`03001B=e8g01mB=`03001oogoo015oo`<003=oo`@001IB=`03001B=e8g
00YB=`03001oogoo01Uoo`03001oogoo00Ioo`001Woo00<007ooOol09Goo00<0058gDSL07e8g00<0
07ooOol03Woo0`00=7oo0`006E8g00<0058gDSL02U8g00<007ooOol06Goo00<007ooOol01Woo0006
Ool00`00Oomoo`0UOol00`00DSMB=`0ODSL00`00Oomoo`0;Ool3000cOol40002Ool00`00DSMB=`0H
DSL00`00DSMB=`09DSL00`00Oomoo`0IOol00`00Oomoo`06Ool000Ioo`03001oogoo02Eoo`03001B
=e8g01mB=`03001oogoo00Qoo`<003=oo`<000Ioo`03001B=e8g01UB=`03001B=e8g00QB=`03001o
ogoo01Uoo`03001oogoo00Ioo`001Woo00<007ooOol09Goo00<0058gDSL07e8g00<007ooOol017oo
1000<goo0`002Goo00<0058gDSL06U8g00<0058gDSL01e8g00<007ooOol06Goo00<007ooOol01Woo
0006Ool00`00Oomoo`0UOol00`00DSMB=`0ODSL01000Oomoogoo0`00=7oo0`0037oo00<0058gDSL0
6e8g00<0058gDSL01U8g00<007ooOol06Goo00<007ooOol01Woo0005Ool00`00Oomoo`0VOol00`00
DSMB=`0ODSL4000dOol3000>Ool00`00DSMB=`0LDSL00`00DSMB=`06DSL00`00Oomoo`0JOol00`00
Oomoo`05Ool000Eoo`03001oogoo02Ioo`03001B=e8g01mB=`03001oogoo039oo`<0015oo`03001B
=e8g01eB=`03001B=e8g00EB=`03001oogoo01Yoo`03001oogoo00Eoo`001Goo00<007ooOol09Woo
00<0058gDSL07e8g00<007ooOol0;Woo100057oo00<0058gDSL07U8g00<0058gDSL0158g00<007oo
Ool06Woo00<007ooOol01Goo0005Ool00`00Oomoo`0VOol00`00DSMB=`0ODSL00`00Oomoo`0[Ool3
000HOol00`00DSMB=`0ODSL00`00DSMB=`03DSL00`00Oomoo`0JOol00`00Oomoo`05Ool000Eoo`03
001oogoo02Ioo`03001B=e8g01mB=`03001oogoo02Qoo`<001]oo`03001B=e8g021B=`05001B=e8g
DSL0000MOol00`00Oomoo`05Ool000Eoo`03001oogoo02Ioo`03001B=e8g01mB=`03001oogoo02Eo
o`<001ioo`03001B=e8g021B=`05001B=e8gDSL0000MOol00`00Oomoo`05Ool000Eoo`03001oogoo
02Ioo`03001B=e8g01mB=`03001oogoo029oo`<0025oo`03001B=e8g025B=`04001B=e8g000MOol0
0`00Oomoo`05Ool000Eoo`03001oogoo02Ioo`03001B=e8g01mB=`03001oogoo01ioo`@002Aoo`03
001B=e8g029B=`03001B=`0001eoo`03001oogoo00Eoo`0017oo00<007ooOol09goo00<0058gDSL0
7U8g0P007Goo0`00:7oo00<0058gDSL08e8g0P007Woo00<007ooOol017oo0004Ool00`00Oomoo`0W
Ool00`00DSMB=`0KDSL3000LOol3000[Ool00`00DSMB=`0SDSL2000NOol00`00Oomoo`04Ool000Ao
o`03001oogoo02Moo`03001B=e8g01QB=`@001]oo`<002ioo`03001B=e8g02AB=`03001oogoo01ao
o`03001oogoo00Aoo`0017oo00<007ooOol09goo00<0058gDSL05E8g0`000goo00<007ooOol05Woo
0`00<Goo00<0058gDSL0958g0P007Goo00<007ooOol017oo0004Ool00`00Oomoo`0WOol00`00DSMB
=`0BDSL30005Ool00`00Oomoo`0DOol3000dOol00`00DSMB=`0TDSL00`00Ool0000LOol00`00Oomo
o`04Ool000Aoo`03001oogoo02Moo`03001B=e8g00mB=`<000Qoo`03001oogoo011oo`@003Moo`03
001B=e8g02AB=`04001oogoo000KOol00`00Oomoo`04Ool000Aoo`03001oogoo02Moo`03001B=e8g
00]B=`@000]oo`03001oogoo00eoo`<003]oo`03001B=e8g02AB=`04001oogoo000KOol00`00Oomo
o`04Ool000Aoo`03001oogoo02Moo`03001B=e8g00QB=`<000moo`03001oogoo00Yoo`<003ioo`03
001B=e8g02AB=`05001oogooOol0000KOol00`00Oomoo`03Ool000=oo`03001oogoo02Qoo`03001B
=e8g00EB=`<0019oo`03001oogoo00Moo`<0045oo`03001B=e8g02AB=`03001oogoo009oo`03001o
ogoo01Qoo`03001oogoo00=oo`000goo00<007ooOol0:7oo00<0058gDSL00U8g0`005Goo00<007oo
Ool017oo0`00@goo00@0058g000002AB=`03001oogoo00=oo`03001oogoo01Moo`03001oogoo00=o
o`000goo00<007ooOol0:7oo00<0058g00000P0067oo00<007ooOol01000AGoo00<0058gDSL00U8g
0P008U8g00<007ooOol00goo00<007ooOol05goo00<007ooOol00goo0003Ool00`00Oomoo`0XOol2
000KOol30017Ool20007DSL2000PDSL00`00Oomoo`04Ool00`00Oomoo`0FOol00`00Oomoo`03Ool0
00=oo`03001oogoo049oo`@004Qoo`03001B=e8g00UB=`8001iB=`03001oogoo00Eoo`03001oogoo
01Eoo`03001oogoo00=oo`000goo00<007ooOol0?goo0`000goo00<007ooOol0AGoo00<0058gDSL0
358g00<0058gDSL06e8g00<007ooOol01Woo00<007ooOol057oo00<007ooOol00goo0003Ool00`00
Oomoo`0lOol30006Ool00`00Oomoo`14Ool00`00DSMB=`0>DSL2000KDSL00`00Oomoo`07Ool00`00
Oomoo`0COol00`00Oomoo`03Ool000=oo`03001oogoo03Uoo`<000Uoo`03001oogoo04=oo`03001B
=e8g015B=`8001UB=`03001oogoo00Moo`03001oogoo01Aoo`03001oogoo009oo`000Woo00<007oo
Ool0=Woo100037oo00<007ooOol0@Woo00<0058gDSL0558g0P005e8g00<007ooOol027oo00<007oo
Ool04goo00<007ooOol00Woo0002Ool00`00Oomoo`0cOol3000@Ool00`00Oomoo`11Ool00`00DSMB
=`0GDSL2000EDSL00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`02Ool0009oo`03001oogoo
031oo`<001=oo`03001oogoo03moo`8001aB=`03001B=e8g015B=`03001oogoo00]oo`03001oogoo
015oo`03001oogoo009oo`000Woo00<007ooOol0;Goo0`005Woo00<007ooOol0?Woo00<0058gDSL0
7E8g0P004E8g00<007ooOol037oo00<007ooOol047oo00<007ooOol00Woo0002Ool00`00Oomoo`0Z
Ool3000IOol00`00Oomoo`0mOol00`00DSMB=`0PDSL2000?DSL00`00Oomoo`0<Ool00`00Oomoo`0@
Ool00`00Oomoo`02Ool0009oo`03001oogoo02Ioo`@001aoo`03001oogoo03aoo`03001B=e8g02=B
=`8000eB=`03001oogoo00eoo`03001oogoo00moo`03001oogoo009oo`000Woo00<007ooOol08goo
0`0087oo00<007ooOol0>goo00<0058gDSL09U8g0P002e8g00<007ooOol03Woo00<007ooOol03Woo
00<007ooOol00Woo0002Ool00`00Oomoo`0POol3000ROol00`00Oomoo`0kOol00`00DSMB=`0YDSL2
0009DSL00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`01Ool00003Ool007oo01moo`<002Eo
o`03001oogoo03Yoo`03001B=e8g02aB=`03001B=e8g00IB=`03001oogoo00moo`03001oogoo00io
o`03001oogoo005oo`0000=oo`00Ool077oo0`00:7oo00<007ooOol0>7oo0P00<58g0P001U8g00<0
07ooOol047oo00<007ooOol03Goo00<007ooOol00Goo00000goo001oo`0IOol3000[Ool00`00Oomo
o`0gOol00`00DSMB=`0bDSL20004DSL00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`01Ool0
0003Ool007oo01Eoo`@002ioo`03001oogoo03Ioo`03001B=e8g03EB=`80009B=`03001oogoo019o
o`03001oogoo00]oo`03001oogoo005oo`0000=oo`00Ool04Woo0`00<Woo00<007ooOol0=Goo00<0
058gDSL0>58g0`005Goo00<007ooOol02Woo00<007ooOol00Goo00000goo001oo`0?Ool3000eOol0
0`00Oomoo`0eOol00`00DSMB=`0jDSL00`00Oomoo`0COol00`00Oomoo`0:Ool00`00Oomoo`01Ool0
0003Ool007oo00aoo`<003Qoo`03001oogoo03Ioo`03001B=e8g03QB=`03001oogoo01Eoo`03001o
ogoo00Yoo`40005oo`5oo`0000=oo`00Ool02Goo0`00>goo00<007ooOol0=Woo00<0058gDSL0=U8g
0P006Goo00<007ooOol02Goo0@000Goo0Goo00000`00Oomoo`05Ool4000nOol00`00Oomoo`0fOol0
0`00DSMB=`0eDSL00`00Oomoo`0JOol00`00Oomoo`08Ool10001Ool1Ool00003001oogoo009oo`<0
049oo`03001oogoo03Moo`03001B=e8g03=B=`03001oogoo01]oo`03001oogoo00Qoo`40005oo`5o
o`0000<007oo00000P00AGoo00<007ooOol0=goo00<0058gDSL0<U8g00<007ooOol07Goo00<007oo
Ool01goo0@000Goo0Goo00020018Ool00`00Oomoo`0hOol00`00DSMB=`0_DSL2000QOol00`00Oomo
o`06Ool10001Ool1Ool00003Ool007oo04Moo`03001oogoo03Qoo`03001B=e8g02iB=`03001oogoo
029oo`03001oogoo00Eoo`40005oo`5oo`000Woo0P00AWoo00<007ooOol0>7oo00<0058gDSL0;E8g
00<007ooOol097oo00<007ooOol017oo0@000Goo0Goo0004Ool00`00Oomoo`13Ool00`00Oomoo`0i
Ool00`00DSMB=`0ZDSL2000WOol00`00Oomoo`05Ool10001Ool000Eoo`03001oogoo049oo`03001o
ogoo03Uoo`03001B=e8g02UB=`03001oogoo02Qoo`03001oogoo00Aoo`40005oo`001Woo0P00@Woo
00<007ooOol0>Goo00<0058gDSL0:58g00<007ooOol0:Woo00<007ooOol00goo0@000Goo0008Ool0
0`00Oomoo`0oOol00`00Oomoo`0jOol00`00DSMB=`0VDSL00`00Oomoo`0/Ool00`00Oomoo`02Ool1
0001Ool000Uoo`03001oogoo03eoo`03001oogoo03]oo`03001B=e8g02AB=`80031oo`05001oogoo
Ool00001Ool000Yoo`8003eoo`03001oogoo03aoo`03001B=e8g029B=`03001oogoo031oo`05001o
ogooOol00001Ool000aoo`03001oogoo03Yoo`03001oogoo03aoo`03001B=e8g025B=`03001oogoo
039oo`04001oogoo0001Ool000eoo`03001oogoo03Uoo`03001oogoo03aoo`03001B=e8g021B=`03
001oogoo03Aoo`03001oo`00005oo`003Woo0P00>Goo00<007ooOol0?Goo00<0058gDSL07E8g0P00
>7oo0@000Goo0@00000@Ool00`00Oomoo`0fOol00`00Oomoo`0mOol00`00DSMB=`0LDSL00`00Oomo
o`0hOol10001Ool10000015oo`03001oogoo03Eoo`03001oogoo03eoo`03001B=e8g01]B=`03001o
ogoo03Yoo`8000004Woo0P00=Goo00<007ooOol0?Woo00<0058gDSL0658g0P00?Goo0P00000DOol0
0`00Oomoo`0bOol00`00Oomoo`0nOol00`00DSMB=`0GDSL00`00Oomoo`0iOol40002Ool001Eoo`03
001oogoo035oo`03001oogoo03ioo`03001B=e8g01IB=`03001oogoo03Ioo`@000Ioo`005Woo0P00
<Goo00<007ooOol0?goo00<0058gDSL0558g00<007ooOol0<goo10002Woo000HOol00`00Oomoo`0^
Ool00`00Oomoo`0oOol00`00DSMB=`0BDSL2000bOol4000>Ool001Uoo`03001oogoo02eoo`03001o
ogoo041oo`03001B=e8g011B=`03001oogoo02ioo`@0019oo`006Woo00<007ooOol0;7oo00<007oo
Ool0@7oo00<0058gDSL03e8g00<007ooOol0:goo10005Woo000KOol2000/Ool00`00Oomoo`10Ool0
0`00DSMB=`0>DSL00`00Oomoo`0XOol4000JOol001eoo`03001oogoo02Uoo`03001oogoo045oo`03
001B=e8g00]B=`8002Moo`@001ioo`007Woo00<007ooOol0:7oo00<007ooOol0@Goo00<0058gDSL0
2U8g00<007ooOol08goo10008Woo000OOol2000XOol00`00Oomoo`11Ool00`00DSMB=`09DSL00`00
Oomoo`0POol4000VOol0025oo`03001oogoo02Eoo`03001oogoo049oo`03001B=e8g00IB=`8001mo
o`@002Yoo`008Woo00<007ooOol08goo00<007ooOol0@goo00<0058gDSL01E8g00<007ooOol06goo
1000;Woo000SOol2000SOol00`00Oomoo`14Ool00`00DSMB=`03DSL00`00Oomoo`0HOol4000bOol0
02Eoo`03001oogoo021oo`03001oogoo04Aoo`03001B=e8g009B=`03001oogoo01Eoo`@003Ioo`00
9Woo00<007ooOol07goo00<007ooOol0A7oo00<0058gDSL00P0057oo1000>Woo000WOol2000OOol0
0`00Oomoo`15Ool2000BOol4000nOol002Uoo`03001oogoo01aoo`03001oogoo04Eoo`03001oogoo
00eoo`@0049oo`00:Woo00<007ooOol06goo00<007ooOol0DGoo1000AWoo000[Ool2000KOol00`00
Oomoo`1=Ool4001:Ool002eoo`03001oogoo01Qoo`03001oogoo04Yoo`<004ioo`00;Woo00<007oo
Ool05goo00<007ooOol0AWoo1000DGoo000_Ool00`00Oomoo`0FOol00`00Oomoo`12Ool4001EOol0
031oo`8001Ioo`03001oogoo03ioo`@005Uoo`00<Woo00<007ooOol04goo00<007ooOol0>Woo1000
GGoo000cOol00`00Oomoo`0BOol00`00Oomoo`0fOol4001QOol003Aoo`80019oo`03001oogoo039o
o`@006Eoo`00=Woo00<007ooOol03goo00<007ooOol0;Woo1000JGoo000gOol00`00Oomoo`0>Ool0
0`00Oomoo`0ZOol4001]Ool003Qoo`8000ioo`03001oogoo02Ioo`@0075oo`00>Woo00<007ooOol0
2goo00<007ooOol08Woo1000MGoo000kOol00`00Oomoo`09Ool00`00Oomoo`0OOol4001iOol003ao
o`8000Uoo`03001oogoo01]oo`@007eoo`00?Woo00<007ooOol01Woo00<007ooOol05goo1000PGoo
000oOol00`00Oomoo`05Ool00`00Oomoo`0COol40025Ool0041oo`8000Eoo`03001oogoo00moo`@0
08Uoo`00@Woo00<007ooOol00Woo00<007ooOol02goo1000SGoo0013Ool01@00Oomoogoo00002Goo
1000TGoo0014Ool200000goo001oo`04Ool4002EOol004Ioo`800003Ool00000008009Uoo`00Agoo
0P00WGoo0000\
\>"],
  ImageRangeCache->{{{0, 229}, {217, 0}} -> {-4.90933*^-06, 0.00272598, 
  0.00428762, 0.00428762}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Sphere",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Torus",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions are used here to generate a sphere and a torus."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This generates a piece of a sphere and a torus on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics3D[{\n\t\t\t
          Sphere[Axis[body2, {0, 0, 0}, body2, {0, 0.5, 1}, 
              ground, {1, 0, 0}], 1, 12, Faces \[Rule] True, 
            Angle \[Rule] {0, 3\ \[Pi]/2}], \n\t\t\t
          Torus[Axis[body2, {0, \(-0.5\), \(-1\)}, body2, {0, 0.5, 1}, 
              ground, {1, 0, 0}], 2, 0.5, {12, 12}, Faces \[Rule] False, 
            Angle \[Rule] {0, 3\ \[Pi]/2}]}, \n\t\tPlotRange \[Rule] All, \n
        \t\tBoxed \[Rule] False]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] 0, Z2 \[Rule] 0, Eo2 \[Rule] 1, 
          Ei2 \[Rule] 0, Ej2 \[Rule] 0, Ek2 \[Rule] 0}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93957 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.04161 -0.00712317 1.04161 [
[ 0 0 0 0 ]
[ 1 .93957 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .93957 L
0 .93957 L
closepath
clip
newpath
0 g
.5 Mabswid
.53772 .5452 m
.42501 .56602 L
s
.54371 .57218 m
.53772 .5452 L
s
.53772 .5452 m
.53096 .51531 L
s
.64826 .51564 m
.53772 .5452 L
s
.53096 .51531 m
.42117 .53534 L
s
.53096 .51531 m
.52513 .49002 L
s
.63851 .48626 m
.53096 .51531 L
s
.54371 .57218 m
.43345 .59279 L
s
.65195 .54352 m
.54371 .57218 L
s
.5474 .58936 m
.54371 .57218 L
s
.52513 .49002 m
.42291 .50846 L
s
.52513 .49002 m
.52173 .47588 L
s
.62516 .46276 m
.52513 .49002 L
s
.42501 .56602 m
.3216 .57576 L
s
.43345 .59279 m
.42501 .56602 L
s
.42501 .56602 m
.42117 .53534 L
s
.42117 .53534 m
.32047 .54403 L
s
.42117 .53534 m
.42291 .50846 L
s
.65195 .54352 m
.64826 .51564 L
s
.64826 .51564 m
.63851 .48626 L
s
.74522 .48015 m
.64826 .51564 L
s
.63851 .48626 m
.62516 .46276 L
s
.73258 .45094 m
.63851 .48626 L
s
.43345 .59279 m
.33252 .60301 L
s
.44441 .60875 m
.43345 .59279 L
s
.74688 .50954 m
.65195 .54352 L
s
.64855 .56273 m
.65195 .54352 L
s
.42291 .50846 m
.3294 .51589 L
s
.42291 .50846 m
.42987 .49234 L
s
.62516 .46276 m
.61157 .45127 L
s
.71221 .42938 m
.62516 .46276 L
s
.5474 .58936 m
.44441 .60875 L
s
.64855 .56273 m
.5474 .58936 L
s
.54774 .59192 m
.5474 .58936 L
s
.52173 .47588 m
.42987 .49234 L
s
.52173 .47588 m
.52174 .47696 L
s
.61157 .45127 m
.52173 .47588 L
s
.44441 .60875 m
.35054 .61867 L
s
.45508 .60939 m
.44441 .60875 L
s
.737 .53153 m
.64855 .56273 L
s
.63876 .56799 m
.64855 .56273 L
s
.42987 .49234 m
.34622 .49865 L
s
.42987 .49234 m
.44038 .49155 L
s
.61157 .45127 m
.60131 .45518 L
s
.68926 .4211 m
.61157 .45127 L
s
.54774 .59192 m
.45508 .60939 L
s
.63876 .56799 m
.54774 .59192 L
s
.54454 .57865 m
.54774 .59192 L
s
.52174 .47696 m
.44038 .49155 L
s
.52174 .47696 m
.52528 .49354 L
s
.60131 .45518 m
.52174 .47696 L
s
.32047 .54403 m
.24096 .53954 L
s
.32047 .54403 m
.3294 .51589 L
s
.3216 .57576 m
.32047 .54403 L
s
.3216 .57576 m
.23983 .57247 L
s
.33252 .60301 m
.3216 .57576 L
s
.73258 .45094 m
.71221 .42938 L
s
.80136 .4129 m
.73258 .45094 L
s
.74522 .48015 m
.73258 .45094 L
s
.45508 .60939 m
.37105 .61831 L
s
.46255 .59402 m
.45508 .60939 L
s
.74688 .50954 m
.74522 .48015 L
s
.81653 .44223 m
.74522 .48015 L
s
.71791 .5401 m
.63876 .56799 L
s
.62501 .55739 m
.63876 .56799 L
s
.44038 .49155 m
.36666 .49711 L
s
.44038 .49155 m
.45168 .50683 L
s
.60131 .45518 m
.5973 .47393 L
s
.66974 .4286 m
.60131 .45518 L
s
.3294 .51589 m
.25608 .51067 L
s
.3294 .51589 m
.34622 .49865 L
s
.33252 .60301 m
.25306 .6009 L
s
.35054 .61867 m
.33252 .60301 L
s
.71221 .42938 m
.68926 .4211 L
s
.77513 .39332 m
.71221 .42938 L
s
.54454 .57865 m
.46255 .59402 L
s
.62501 .55739 m
.54454 .57865 L
s
.53856 .55276 m
.54454 .57865 L
s
.81665 .47371 m
.74688 .50954 L
s
.737 .53153 m
.74688 .50954 L
s
.52528 .49354 m
.45168 .50683 L
s
.52528 .49354 m
.53146 .5214 L
s
.5973 .47393 m
.52528 .49354 L
s
.34622 .49865 m
.28132 .49342 L
s
.34622 .49865 m
.36666 .49711 L
s
.46255 .59402 m
.38855 .6016 L
s
.46463 .56646 m
.46255 .59402 L
s
.69457 .53258 m
.62501 .55739 L
s
.61105 .53343 m
.62501 .55739 L
s
.35054 .61867 m
.2773 .61729 L
s
.37105 .61831 m
.35054 .61867 L
s
.53856 .55276 m
.46463 .56646 L
s
.61105 .53343 m
.53856 .55276 L
s
.53146 .5214 m
.53856 .55276 L
s
.45168 .50683 m
.38529 .51212 L
s
.45168 .50683 m
.46063 .53435 L
s
.68926 .4211 m
.66974 .4286 L
s
.74464 .38864 m
.68926 .4211 L
s
.53146 .5214 m
.46063 .53435 L
s
.60084 .5027 m
.53146 .5214 L
s
.5973 .47393 m
.60084 .5027 L
s
.65903 .45026 m
.5973 .47393 L
s
.8015 .49905 m
.737 .53153 L
s
.71791 .5401 m
.737 .53153 L
s
.46463 .56646 m
.39809 .57281 L
s
.46063 .53435 m
.46463 .56646 L
s
.46063 .53435 m
.39689 .53989 L
s
.67337 .51069 m
.61105 .53343 L
s
.60084 .5027 m
.61105 .53343 L
s
.6603 .48041 m
.60084 .5027 L
s
.36666 .49711 m
.31015 .49246 L
s
.36666 .49711 m
.38529 .51212 L
s
.37105 .61831 m
.30626 .61706 L
s
.38855 .6016 m
.37105 .61831 L
s
.66974 .4286 m
.65903 .45026 L
s
.71789 .40026 m
.66974 .4286 L
s
.77491 .51136 m
.71791 .5401 L
s
.69457 .53258 m
.71791 .5401 L
s
.38529 .51212 m
.33488 .50833 L
s
.38529 .51212 m
.39689 .53989 L
s
.38855 .6016 m
.33212 .60001 L
s
.39809 .57281 m
.38855 .6016 L
s
.65903 .45026 m
.6603 .48041 L
s
.7021 .42533 m
.65903 .45026 L
s
.74395 .5071 m
.69457 .53258 L
s
.67337 .51069 m
.69457 .53258 L
s
.39689 .53989 m
.34873 .53696 L
s
.39689 .53989 m
.39809 .57281 L
s
.39809 .57281 m
.34773 .57061 L
s
.6603 .48041 m
.67337 .51069 L
s
.70173 .45722 m
.6603 .48041 L
s
.71707 .48725 m
.67337 .51069 L
s
.24096 .53954 m
.19552 .52085 L
s
.24096 .53954 m
.25608 .51067 L
s
.23983 .57247 m
.24096 .53954 L
s
.23983 .57247 m
.19295 .55492 L
s
.25306 .6009 m
.23983 .57247 L
s
.25608 .51067 m
.21485 .49209 L
s
.25608 .51067 m
.28132 .49342 L
s
.80136 .4129 m
.77513 .39332 L
s
.83274 .37677 m
.80136 .4129 L
s
.81653 .44223 m
.80136 .4129 L
s
.77513 .39332 m
.74464 .38864 L
s
.80286 .35907 m
.77513 .39332 L
s
.81665 .47371 m
.81653 .44223 L
s
.84967 .40653 m
.81653 .44223 L
s
.25306 .6009 m
.20796 .58522 L
s
.2773 .61729 m
.25306 .6009 L
s
.28132 .49342 m
.24574 .4762 L
s
.28132 .49342 m
.31015 .49246 L
s
.74464 .38864 m
.71789 .40026 L
s
.768 .35803 m
.74464 .38864 L
s
.84899 .44047 m
.81665 .47371 L
s
.8015 .49905 m
.81665 .47371 L
s
.2773 .61729 m
.23664 .60353 L
s
.30626 .61706 m
.2773 .61729 L
s
.31015 .49246 m
.28002 .47735 L
s
.31015 .49246 m
.33488 .50833 L
s
.54425 .58131 m .55898 .64643 L .51011 .65586 L p .743 .608 .708 r
F P
0 g
s
.58586 .57033 m .60705 .63403 L .55898 .64643 L p .669 .561 .724 r
F P
0 g
s
.55898 .64643 m .54425 .58131 L .58586 .57033 L p .669 .561 .724 r
F P
0 g
s
.55898 .64643 m .57242 .70703 L .52962 .71549 L p .716 .499 .595 r
F P
0 g
s
.52962 .71549 m .51011 .65586 L .55898 .64643 L p .716 .499 .595 r
F P
0 g
s
.57242 .70703 m .55898 .64643 L .60705 .63403 L p .635 .448 .613 r
F P
0 g
s
.71789 .40026 m
.7021 .42533 L
s
.73736 .37388 m
.71789 .40026 L
s
.83076 .46945 m
.8015 .49905 L
s
.77491 .51136 m
.8015 .49905 L
s
.53161 .52663 m .54425 .58131 L .50185 .58927 L p .753 .712 .813 r
F P
0 g
s
.55594 .52008 m .58586 .57033 L .54425 .58131 L p .688 .671 .828 r
F P
0 g
s
.54425 .58131 m .53161 .52663 L .55594 .52008 L p .688 .671 .828 r
F P
0 g
s
.51011 .65586 m .50185 .58927 L .54425 .58131 L p .743 .608 .708 r
F P
0 g
s
.50185 .58927 m .51011 .65586 L .46683 .66104 L p .819 .661 .687 r
F P
0 g
s
.51011 .65586 m .52962 .71549 L .49191 .72062 L p .793 .54 .555 r
F P
0 g
s
.49191 .72062 m .46683 .66104 L .51011 .65586 L p .793 .54 .555 r
F P
0 g
s
.30626 .61706 m
.2713 .60481 L
s
.33212 .60001 m
.30626 .61706 L
s
.62109 .55775 m .64801 .62025 L .60705 .63403 L p .575 .507 .741 r
F P
0 g
s
.60705 .63403 m .58586 .57033 L .62109 .55775 L p .575 .507 .741 r
F P
0 g
s
.60705 .63403 m .61461 .69638 L .57242 .70703 L p .635 .448 .613 r
F P
0 g
s
.61461 .69638 m .60705 .63403 L .64801 .62025 L p .527 .371 .612 r
F P
0 g
s
.50677 .53118 m .50185 .58927 L .4643 .5931 L p .817 .768 .806 r
F P
0 g
s
.50185 .58927 m .50677 .53118 L .53161 .52663 L p .753 .712 .813 r
F P
0 g
s
.46683 .66104 m .4643 .5931 L .50185 .58927 L p .819 .661 .687 r
F P
0 g
s
.33488 .50833 m
.30865 .49527 L
s
.33488 .50833 m
.34873 .53696 L
s
.5763 .51246 m .62109 .55775 L .58586 .57033 L p .609 .637 .853 r
F P
0 g
s
.58586 .57033 m .55594 .52008 L .5763 .51246 L p .609 .637 .853 r
F P
0 g
s
.7021 .42533 m
.70173 .45722 L
s
.71906 .40248 m
.7021 .42533 L
s
.79982 .48555 m
.77491 .51136 L
s
.74395 .5071 m
.77491 .51136 L
s
.33212 .60001 m
.30249 .58867 L
s
.34773 .57061 m
.33212 .60001 L
s
.34873 .53696 m
.32397 .52532 L
s
.34873 .53696 m
.34773 .57061 L
s
.34773 .57061 m
.32177 .55952 L
s
.70173 .45722 m
.71707 .48725 L
s
.718 .43629 m
.70173 .45722 L
s
.76458 .48438 m
.74395 .5071 L
s
.71707 .48725 m
.74395 .5071 L
s
.73463 .4663 m
.71707 .48725 L
s
.57242 .70703 m .58132 .74852 L .55607 .7536 L p .641 .311 .398 r
F P
0 g
s
.55607 .7536 m .52962 .71549 L .57242 .70703 L p .641 .311 .398 r
F P
0 g
s
.58132 .74852 m .57242 .70703 L .61461 .69638 L p .556 .257 .416 r
F P
0 g
s
.48491 .53309 m .4643 .5931 L .43694 .59217 L p .886 .85 .802 r
F P
0 g
s
.4643 .5931 m .48491 .53309 L .50677 .53118 L p .817 .768 .806 r
F P
0 g
s
.4643 .5931 m .46683 .66104 L .43517 .66115 L p .912 .733 .647 r
F P
0 g
s
.43517 .66115 m .43694 .59217 L .4643 .5931 L p .912 .733 .647 r
F P
0 g
s
.46683 .66104 m .49191 .72062 L .46464 .72162 L p .88 .57 .456 r
F P
0 g
s
.46464 .72162 m .43517 .66115 L .46683 .66104 L p .88 .57 .456 r
F P
0 g
s
.58968 .50483 m .64489 .54528 L .62109 .55775 L p .489 .6 .891 r
F P
0 g
s
.62109 .55775 m .5763 .51246 L .58968 .50483 L p .489 .6 .891 r
F P
0 g
s
.64801 .62025 m .62109 .55775 L .64489 .54528 L p .418 .421 .756 r
F P
0 g
s
.64489 .54528 m .67606 .6069 L .64801 .62025 L p .418 .421 .756 r
F P
0 g
s
.64801 .62025 m .65055 .68495 L .61461 .69638 L p .527 .371 .612 r
F P
0 g
s
.65055 .68495 m .64801 .62025 L .67606 .6069 L p .33 .219 .573 r
F P
0 g
s
.52962 .71549 m .55607 .7536 L .53405 .75684 L p .703 .321 .321 r
F P
0 g
s
.53405 .75684 m .49191 .72062 L .52962 .71549 L p .703 .321 .321 r
F P
0 g
s
.61461 .69638 m .60625 .74232 L .58132 .74852 L p .556 .257 .416 r
F P
0 g
s
.60625 .74232 m .61461 .69638 L .65055 .68495 L p .425 .143 .378 r
F P
0 g
s
.50677 .53118 m .5242 .49598 L .53161 .52663 L closepath p .71 .852 .95 r
F P
0 g
s
.53161 .52663 m .5242 .49598 L .55594 .52008 L closepath p .671 .828 .959 r
F P
0 g
s
.48491 .53309 m .5242 .49598 L .50677 .53118 L closepath p .738 .887 .948 r
F P
0 g
s
.55594 .52008 m .5242 .49598 L .5763 .51246 L closepath p .619 .813 .975 r
F P
0 g
s
.46923 .53202 m .5242 .49598 L .48491 .53309 L closepath p .749 .929 .948 r
F P
0 g
s
.43694 .59217 m .46923 .53202 L .48491 .53309 L p .886 .85 .802 r
F P
0 g
s
.5763 .51246 m .5242 .49598 L .58968 .50483 L closepath p .549 .804 .993 r
F P
0 g
s
.49191 .72062 m .53405 .75684 L .51848 .75774 L p .73 .255 .12 r
F P
0 g
s
.51848 .75774 m .46464 .72162 L .49191 .72062 L p .73 .255 .12 r
F P
0 g
s
.67606 .6069 m .67508 .67429 L .65055 .68495 L p .33 .219 .573 r
F P
0 g
s
.65055 .68495 m .62733 .73588 L .60625 .74232 L p .425 .143 .378 r
F P
0 g
s
.62733 .73588 m .65055 .68495 L .67508 .67429 L p .168 0 .232 r
F P
0 g
s
.46923 .53202 m .43694 .59217 L .42413 .5864 L p .933 .959 .765 r
F P
0 g
s
.43694 .59217 m .43517 .66115 L .42027 .6559 L p 1 .814 .499 r
F P
0 g
s
.42027 .6559 m .42413 .5864 L .43694 .59217 L p 1 .814 .499 r
F P
0 g
s
.59395 .49833 m .65331 .53471 L .64489 .54528 L p .239 .523 .915 r
F P
0 g
s
.64489 .54528 m .58968 .50483 L .59395 .49833 L p .239 .523 .915 r
F P
0 g
s
.67606 .6069 m .64489 .54528 L .65331 .53471 L p .022 .196 .704 r
F P
0 g
s
.43517 .66115 m .46464 .72162 L .4522 .71815 L p .909 .508 .12 r
F P
0 g
s
.4522 .71815 m .42027 .6559 L .43517 .66115 L p .909 .508 .12 r
F P
0 g
s
.46221 .52808 m .5242 .49598 L .46923 .53202 L closepath p .725 .965 .938 r
F P
0 g
s
.42413 .5864 m .46221 .52808 L .46923 .53202 L p .933 .959 .765 r
F P
0 g
s
.58968 .50483 m .5242 .49598 L .59395 .49833 L closepath p .45 .793 .998 r
F P
0 g
s
.24574 .4762 m
.24845 .44813 L
s
.24574 .4762 m
.28002 .47735 L
s
.21485 .49209 m
.24574 .4762 L
s
.65331 .53471 m .6865 .59593 L .67606 .6069 L p .022 .196 .704 r
F P
0 g
s
.67508 .67429 m .67606 .6069 L .6865 .59593 L p 0 0 .341 r
F P
0 g
s
.21485 .49209 m
.21641 .4611 L
s
.19552 .52085 m
.21485 .49209 L
s
.28002 .47735 m
.28368 .45294 L
s
.28002 .47735 m
.30865 .49527 L
s
.768 .35803 m
.73736 .37388 L
s
.7518 .33417 m
.768 .35803 L
s
.80286 .35907 m
.768 .35803 L
s
.19552 .52085 m
.19618 .48867 L
s
.19295 .55492 m
.19552 .52085 L
s
.73736 .37388 m
.71906 .40248 L
s
.72211 .35371 m
.73736 .37388 L
s
.30865 .49527 m
.31288 .47406 L
s
.30865 .49527 m
.32397 .52532 L
s
.58132 .74852 m .55607 .7536 L .58311 .75903 L closepath p .215 0 0 r
F P
0 g
s
.60625 .74232 m .58132 .74852 L .58311 .75903 L closepath p .15 0 0 r
F P
0 g
s
.78623 .33211 m
.80286 .35907 L
s
.83274 .37677 m
.80286 .35907 L
s
.71906 .40248 m
.718 .43629 L
s
.7048 .3854 m
.71906 .40248 L
s
.55607 .7536 m .53405 .75684 L .58311 .75903 L closepath p .203 0 0 r
F P
0 g
s
.62733 .73588 m .60625 .74232 L .58311 .75903 L closepath p .009 0 0 r
F P
0 g
s
.19295 .55492 m
.1935 .52357 L
s
.20796 .58522 m
.19295 .55492 L
s
.81623 .34838 m
.83274 .37677 L
s
.84967 .40653 m
.83274 .37677 L
s
.32397 .52532 m
.32853 .50595 L
s
.32397 .52532 m
.32177 .55952 L
s
.46464 .72162 m .51848 .75774 L .51183 .75612 L p .547 0 0 r
F P
0 g
s
.51183 .75612 m .4522 .71815 L .46464 .72162 L p .547 0 0 r
F P
0 g
s
.718 .43629 m
.73463 .4663 L
s
.7043 .421 m
.718 .43629 L
s
.47794 .514 m .5242 .49598 L .46516 .52176 L closepath p .458 .881 .785 r
F P
0 g
s
.46516 .52176 m .5242 .49598 L .46221 .52808 L closepath p .634 .963 .892 r
F P
0 g
s
.49873 .50599 m .5242 .49598 L .58311 .75903 L p .966 .687 .452 r
F P
0 g
s
.59395 .49833 m .5242 .49598 L .58816 .49399 L closepath p .311 .761 .959 r
F P
0 g
s
.58816 .49399 m .5242 .49598 L .58311 .75903 L p .603 .473 .676 r
F P
0 g
s
.49873 .50599 m .5242 .49598 L .47794 .514 L closepath p 0 0 0 r
F P
0 g
s
.20796 .58522 m
.2093 .55628 L
s
.23664 .60353 m
.20796 .58522 L
s
.6865 .59593 m .68416 .66598 L .67508 .67429 L p 0 0 .341 r
F P
0 g
s
.67508 .67429 m .64145 .73012 L .62733 .73588 L p .168 0 .232 r
F P
0 g
s
.64145 .73012 m .67508 .67429 L .68416 .66598 L p 0 0 0 r
F P
0 g
s
.84899 .44047 m
.84967 .40653 L
s
.83356 .37886 m
.84967 .40653 L
s
.32177 .55952 m
.32647 .54035 L
s
.32177 .55952 m
.30249 .58867 L
s
.46221 .52808 m .42413 .5864 L .42861 .57642 L p .678 .864 .468 r
F P
0 g
s
.42861 .57642 m .46516 .52176 L .46221 .52808 L p .678 .864 .468 r
F P
0 g
s
.65331 .53471 m .59395 .49833 L .58816 .49399 L p 0 .237 .66 r
F P
0 g
s
.23664 .60353 m
.2393 .57772 L
s
.2713 .60481 m
.23664 .60353 L
s
.53405 .75684 m .51848 .75774 L .58311 .75903 L closepath p .1 0 0 r
F P
0 g
s
.73463 .4663 m
.76458 .48438 L
s
.72081 .45128 m
.73463 .4663 L
s
.30249 .58867 m
.30705 .56824 L
s
.30249 .58867 m
.2713 .60481 L
s
.64145 .73012 m .62733 .73588 L .58311 .75903 L closepath p 0 0 0 r
F P
0 g
s
.83325 .41531 m
.84899 .44047 L
s
.83076 .46945 m
.84899 .44047 L
s
.2713 .60481 m
.27516 .58203 L
s
.76458 .48438 m
.79982 .48555 L
s
.7502 .46819 m
.76458 .48438 L
s
.81533 .44765 m
.83076 .46945 L
s
.79982 .48555 m
.83076 .46945 L
s
.42413 .5864 m .42027 .6559 L .42539 .64576 L p 0 0 .143 r
F P
0 g
s
.42539 .64576 m .42861 .57642 L .42413 .5864 L p 0 0 .143 r
F P
0 g
s
.78482 .46698 m
.79982 .48555 L
s
.58816 .49399 m .64426 .52776 L .65331 .53471 L p 0 .237 .66 r
F P
0 g
s
.6865 .59593 m .65331 .53471 L .64426 .52776 L p .808 .389 0 r
F P
0 g
s
.42027 .6559 m .4522 .71815 L .45725 .71052 L p 0 .048 .613 r
F P
0 g
s
.45725 .71052 m .42539 .64576 L .42027 .6559 L p 0 .048 .613 r
F P
0 g
s
.51848 .75774 m .51183 .75612 L .58311 .75903 L closepath p .091 .642 .817 r
F P
0 g
s
.46516 .52176 m .42861 .57642 L .45057 .56358 L p 0 0 .068 r
F P
0 g
s
.45057 .56358 m .47794 .514 L .46516 .52176 L p 0 0 .068 r
F P
0 g
s
.68416 .66598 m .64636 .72589 L .64145 .73012 L p 0 0 0 r
F P
0 g
s
.64636 .72589 m .64145 .73012 L .58311 .75903 L closepath p .455 .874 .746 r
F P
0 g
s
.64426 .52776 m .58816 .49399 L p .58311 .75903 L .603 .473 .676 r
F P
0 g
s
.64426 .52776 m .67667 .58916 L .6865 .59593 L p .808 .389 0 r
F P
0 g
s
.68416 .66598 m .6865 .59593 L .67667 .58916 L p .976 .794 .376 r
F P
0 g
s
.4522 .71815 m .51183 .75612 L .51539 .75213 L p .066 .449 .88 r
F P
0 g
s
.51539 .75213 m .45725 .71052 L .4522 .71815 L p .066 .449 .88 r
F P
0 g
s
.67667 .58916 m .67558 .66141 L .68416 .66598 L p .976 .794 .376 r
F P
0 g
s
.64636 .72589 m .68416 .66598 L .67558 .66141 L p .908 .979 .704 r
F P
0 g
s
.47794 .514 m .45057 .56358 L .48715 .54992 L p .351 .043 .295 r
F P
0 g
s
.48715 .54992 m .49873 .50599 L .47794 .514 L p .351 .043 .295 r
F P
0 g
s
.51183 .75612 m .51539 .75213 L .58311 .75903 L closepath p .3 .754 .956 r
F P
0 g
s
.67558 .66141 m .64101 .72391 L .64636 .72589 L p .908 .979 .704 r
F P
0 g
s
.64101 .72391 m .64636 .72589 L .58311 .75903 L closepath p .631 .962 .887 r
F P
0 g
s
.42861 .57642 m .42539 .64576 L .45099 .63208 L p .241 .137 .53 r
F P
0 g
s
.45099 .63208 m .45057 .56358 L .42861 .57642 L p .241 .137 .53 r
F P
0 g
s
.48715 .54992 m .49873 .50599 L p .58311 .75903 L .966 .687 .452 r
F P
0 g
s
.4938 .61697 m .48715 .54992 L p .58311 .75903 L .966 .687 .452 r
F P
0 g
s
.51732 .68739 m .4938 .61697 L p .58311 .75903 L .966 .687 .452 r
F P
0 g
s
.58311 .75903 m .55047 .73963 L .51732 .68739 L p .966 .687 .452 r
F P
0 g
s
.67667 .58916 m .64426 .52776 L p .58311 .75903 L .603 .473 .676 r
F P
0 g
s
.67558 .66141 m .67667 .58916 L p .58311 .75903 L .603 .473 .676 r
F P
0 g
s
.58311 .75903 m .64101 .72391 L .67558 .66141 L p .603 .473 .676 r
F P
0 g
s
.5289 .74634 m .55047 .73963 L .58311 .75903 L closepath p .565 .834 .996 r
F P
0 g
s
.51539 .75213 m .5289 .74634 L .58311 .75903 L closepath p .46 .807 .998 r
F P
0 g
s
.31288 .47406 m
.34989 .44741 L
s
.31288 .47406 m
.32853 .50595 L
s
.28368 .45294 m
.31288 .47406 L
s
.28368 .45294 m
.32425 .42232 L
s
.24845 .44813 m
.28368 .45294 L
s
.32853 .50595 m
.36441 .48133 L
s
.32853 .50595 m
.32647 .54035 L
s
.7048 .3854 m
.7043 .421 L
s
.72211 .35371 m
.7048 .3854 L
s
.7043 .421 m
.72081 .45128 L
s
.7518 .33417 m
.72211 .35371 L
s
.42539 .64576 m .45725 .71052 L .47995 .69971 L p .357 .385 .753 r
F P
0 g
s
.47995 .69971 m .45099 .63208 L .42539 .64576 L p .357 .385 .753 r
F P
0 g
s
.45725 .71052 m .51539 .75213 L .5289 .74634 L p .432 .592 .909 r
F P
0 g
s
.24845 .44813 m
.2939 .41263 L
s
.21641 .4611 m
.24845 .44813 L
s
.32647 .54035 m
.36412 .51551 L
s
.32647 .54035 m
.30705 .56824 L
s
.72081 .45128 m
.7502 .46819 L
s
.5289 .74634 m .47995 .69971 L .45725 .71052 L p .432 .592 .909 r
F P
0 g
s
.78623 .33211 m
.7518 .33417 L
s
.45057 .56358 m .45099 .63208 L .4938 .61697 L p .498 .338 .595 r
F P
0 g
s
.4938 .61697 m .48715 .54992 L .45057 .56358 L p .498 .338 .595 r
F P
0 g
s
.21641 .4611 m
.26672 .42128 L
s
.19618 .48867 m
.21641 .4611 L
s
.30705 .56824 m
.34885 .54116 L
s
.30705 .56824 m
.27516 .58203 L
s
.47995 .69971 m .5289 .74634 L .55047 .73963 L p .59 .642 .871 r
F P
0 g
s
.7502 .46819 m
.78482 .46698 L
s
.81623 .34838 m
.78623 .33211 L
s
.19618 .48867 m
.25017 .44649 L
s
.1935 .52357 m
.19618 .48867 L
s
.27516 .58203 m
.32224 .55126 L
s
.27516 .58203 m
.2393 .57772 L
s
.55047 .73963 m .51732 .68739 L .47995 .69971 L p .59 .642 .871 r
F P
0 g
s
.78482 .46698 m
.81533 .44765 L
s
.83356 .37886 m
.81623 .34838 L
s
.1935 .52357 m
.24917 .48168 L
s
.2093 .55628 m
.1935 .52357 L
s
.2393 .57772 m
.29118 .54259 L
s
.2393 .57772 m
.2093 .55628 L
s
.45099 .63208 m .47995 .69971 L .51732 .68739 L p .556 .496 .744 r
F P
0 g
s
.51732 .68739 m .4938 .61697 L .45099 .63208 L p .556 .496 .744 r
F P
0 g
s
.2093 .55628 m
.26426 .51706 L
s
.81533 .44765 m
.83325 .41531 L
s
.83325 .41531 m
.83356 .37886 L
s
.34989 .44741 m
.41581 .41966 L
s
.34989 .44741 m
.36441 .48133 L
s
.32425 .42232 m
.34989 .44741 L
s
.36441 .48133 m
.42777 .45544 L
s
.36441 .48133 m
.36412 .51551 L
s
.32425 .42232 m
.39785 .39052 L
s
.2939 .41263 m
.32425 .42232 L
s
.36412 .51551 m
.43075 .48898 L
s
.36412 .51551 m
.34885 .54116 L
s
.2939 .41263 m
.3783 .37556 L
s
.26672 .42128 m
.2939 .41263 L
s
.34885 .54116 m
.42384 .51175 L
s
.34885 .54116 m
.32224 .55126 L
s
.42777 .45544 m
.43075 .48898 L
s
.41581 .41966 m
.42777 .45544 L
s
.39785 .39052 m
.41581 .41966 L
s
.26672 .42128 m
.36226 .37921 L
s
.25017 .44649 m
.26672 .42128 L
s
.43075 .48898 m
.42384 .51175 L
s
.32224 .55126 m
.40851 .51743 L
s
.32224 .55126 m
.29118 .54259 L
s
.3783 .37556 m
.39785 .39052 L
s
.25017 .44649 m
.35426 .40125 L
s
.24917 .48168 m
.25017 .44649 L
s
.29118 .54259 m
.38858 .50375 L
s
.29118 .54259 m
.26426 .51706 L
s
.42384 .51175 m
.40851 .51743 L
s
.36226 .37921 m
.3783 .37556 L
s
.24917 .48168 m
.35687 .43608 L
s
.26426 .51706 m
.24917 .48168 L
s
.26426 .51706 m
.36953 .47388 L
s
.40851 .51743 m
.38858 .50375 L
s
.35426 .40125 m
.36226 .37921 L
s
.38858 .50375 m
.36953 .47388 L
s
.35687 .43608 m
.35426 .40125 L
s
.36953 .47388 m
.35687 .43608 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{404, 380},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006D0001O1000`40O003h00OogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonE
Ool00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00
ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogoo;goo3`00Egoo
003oOol]Ool200000goo001oo`0<Ool2001EOol00?moobaoo`05001oogooOol0000=Ool01000Ool0
0000Dgoo003oOol[Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`02001AOol00?moobUo
o`8000Moo`03001oogoo00]oo`04001oogooOol2001?Ool00?moobQoo`03001oogoo00Moo`03001o
ogoo00]oo`03001oogoo00=oo`8004eoo`00ogoo9goo00<007ooOol02Goo00<007ooOol02goo00<0
07ooOol017oo0P00Bgoo003oOolUOol2000=Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomo
o`18Ool00?moobAoo`03001oogoo00ioo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo04Qo
o`00ogoo8goo00<007oo00003goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol0Agoo003o
OolSOol00`00Ool0000@Ool?0006Ool00`00Oomoo`17Ool00?moob9oo`05001oogooOol0000=Ool2
000=Ool01000Ool000001Goo00<007ooOol0AWoo003oOolROol00`00Oomoo`02Ool00`00Oomoo`08
Ool3000=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`16Ool00?moob5oo`03001oogoo
00Aoo`03001oogoo00Eoo`80009oo`03001oogoo00]oo`03001oogoo00=oo`8000=oo`03001oogoo
04Eoo`00ogoo8Goo00<007ooOol017oo00<007ooOol00goo0P000goo00<007ooOol02goo00<007oo
Ool01Woo00D007ooOomoo`0004Ioo`00ogoo87oo00<007ooOol01Woo00<007ooOol00P0017oo00<0
07ooOol02goo00<007ooOol027oo0P0000=oo`00Ool0AGoo003oOolPOol00`00Oomoo`07Ool20005
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Ool00015Ool009Eoo`@008Eoo`03001oogoo00Mo
o`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00eoo`8004Eoo`00T7oo1`000Woo00<007oo
Ool0PWoo00<007ooOol01goo00<007ooOol017oo00<007ooOol02goo00<007ooOol03goo00<007oo
Ool0@Woo002>Ool200000goo001oo`020005Ool20021Ool00`00Oomoo`07Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Oomoo`0?Ool30013Ool008aoo`80009oo`<000Uoo`03001oogoo07ioo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00moo`04001oo`000013Ool0
08Yoo`80009oo`<000aoo`03001oogoo07aoo`03001oogoo00Ioo`8000Ioo`03001oogoo00Yoo`03
001oogoo00moo`06001oogoo001oo`00@Woo0027Ool30002Ool20002Ool00`00Oomoo`0;Ool2001l
Ool20007Ool00`00Oomoo`03Ool4000;Ool00`00Oomoo`0>Ool01`00Oomoogoo001oo`00049oo`00
QGoo0P000goo0P000goo00<007ooOol03Goo0P00Ngoo0P001Woo00<007ooOol00Woo0`000goo1P00
17oo00<007ooOol03Woo00<007ooOol00Woo00@007ooOol0045oo`00Pgoo0P000goo0P001Goo00<0
07ooOol02goo0P000Woo00<007ooOol0N7oo00<007oo000017oo0P000Woo0`002goo100047oo00<0
07ooOol00goo00@007ooOol0045oo`00PGoo0P000Woo0`001goo00<007ooOol02Goo0P0017oo00<0
07ooOol0N7oo00@007ooOol0009oo`800004Ool00000000>Ool200000goo001oo`0=Ool00`00Oomo
o`04Ool01@00Oomoogoo0000@7oo001oOol20002Ool20009Ool00`00Oomoo`07Ool30007Ool00`00
Oomoo`1gOol01P00Oomoogoo001oo`@000ioo`8000Aoo`8000aoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo03eoo`00O7oo0`000Woo0P002Woo0P001goo0P002Woo00<007ooOol0Mgoo00@0
07ooOomoo`D000ioo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo009o
o`03001oogoo03eoo`00NWoo0P000Woo0`002Woo0P0000=oo`00Ool017oo0P003Goo00<007ooOol0
MGoo00@007ooOomoo`@000ioo`8000Yoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00=o
o`03001oogoo03aoo`00N7oo0P000Woo0P002goo0P000goo00@007ooOomoo`8000moo`03001oogoo
07Eoo`03001oo`0000@000eoo`8000eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo03aoo`00MWoo0P000Woo0P002goo0P001Goo10004Woo00<007ooOol0M7oo1@0000=o
o`00Ool02goo00<007ooOol03Woo0P000goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0
>goo001cOol30002Ool2000;Ool20006Ool2000FOol00`00Oomoo`1aOol400001Goo000007oo0000
2Woo0P004goo00<007oo00002goo00<007ooOol00goo0P00?Goo001aOol20002Ool3000:Ool30006
Ool200000goo001oo`0EOol00`00Oomoo`1`Ool01@00Ool00000Ool00P000Woo00<007ooOol01Woo
0P005Woo00<007ooOol02Woo00<007ooOol00Woo00<007oo0000?Goo001_Ool70002Ool30005Ool2
0006Ool30003Ool00`00Oomoo`0EOol00`00Oomoo`1]Ool4000017oo001oo`000goo00<007ooOol0
1Goo00<007ooOol057oo0P0000=oo`00Ool02Woo00D007ooOomoo`00009oo`03001oogoo03]oo`00
KGoo10000Woo0P001Woo1@001Woo0P001Woo00<007ooOol05Goo00<007ooOol0Jgoo10000goo0P00
17oo00<007ooOol00goo0P005Goo0P000goo00<007ooOol027oo00D007oo001oo`0000=oo`03001o
ogoo03]oo`00Jgoo0P001Goo00<007ooOol01goo1@000goo0P002Goo00<007ooOol057oo0P00JWoo
1@0017oo0P0017oo00@007ooOomoo`8001Eoo`8000Ioo`03001oogoo00Moo`04001oo`000004Ool0
0`00Oomoo`0kOol006Yoo`03001oogoo00Aoo`03001oogoo00Ioo`8000Eoo`<000]oo`03001oogoo
019oo`800003Ool007oo06Moo`@000=oo`80009oo`8000Aoo`04001oogoo000EOol20008Ool00`00
Oomoo`06Ool00`00Oomoo`020004Ool00`00Oomoo`0kOol006Qoo`<000Aoo`8000Ioo`<000Moo`03
001oo`0000]oo`03001oogoo011oo`8000Aoo`03001oogoo06=oo`@000Moo`D000=oo`<001Eoo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oo`00009oo`05001oogooOol0000mOol006Moo`03001o
o`0000Aoo`03001oogoo00Aoo`8000Qoo`8000=oo`03001oogoo00Qoo`03001oogoo00eoo`<000Io
o`03001oogoo065oo`@000Qoo`<00005Ool00000001oo`02000EOol2000<Ool00`00Oomoo`04Ool0
1000Oomoo`000Woo00D007ooOomoo`0003eoo`00IWoo00<007oo000017oo00<007ooOol00goo0P00
2Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol02goo0P002Goo00<007ooOol0Ggoo1000
27oo0P000Woo00<007ooOol00`0000=oo`00Ool04Woo0P003goo00<007ooOol00goo00<007oo0000
17oo00@007ooOol003eoo`00IGoo00@007ooOol000=oo`03001oogoo009oo`8000Yoo`03001oogoo
00Ioo`03001oogoo00Ioo`03001oogoo00Uoo`8000aoo`03001oogoo05]oo`@00003Ool007oo00Mo
o`03001oogoo009oo`D00003Ool00000015oo`80019oo`07001oogooOol007oo00001Woo00<007oo
0000?Goo001SOol20002Ool00`00Oomoo`020002Ool3000:Ool2000:Ool20005Ool20008Ool3000>
Ool00`00Oomoo`1IOol30004Ool00`00Oomoo`04Ool20004Ool20003Ool01000Oomoo`003goo0P00
57oo00@007ooOomoo`8000Qoo`8003eoo`00HWoo00<007ooOol00Woo00<007oo00000Woo0P0037oo
00<007ooOol037oo00<007ooOol00P0000=oo`00Ool01Goo0P004Goo00<007ooOol0EWoo10001Goo
00<007ooOol00goo0P000goo0`0000=oo`00Ool00goo0P0000=oo`00Ool037oo00<007ooOol05Goo
00@007oo000000Uoo`8003eoo`00HGoo00<007ooOol00Woo00@007oo001oo`8000eoo`03001oogoo
00ioo`8000Aoo`03001oogoo00<001Aoo`03001oogoo05=oo`@000Moo`04001oogooOol20002Ool3
0004Ool00`00Oomoo`02Ool00`00Oomoo`02000:Ool2000HOol00`00Ool0000;Ool00`00Oomoo`0k
Ool0061oo`03001oogoo009oo`D000eoo`8000moo`800003Ool007oo00=oo`<001Moo`03001oogoo
055oo`<000Uoo`06001oogooOol007oo0`001goo00<007ooOol00Woo0P000Woo0P001goo0P006goo
00<007ooOol02Goo00<007ooOol0?7oo001NOol20005Ool3000>Ool00`00Oomoo`0<Ool30004Ool0
0`00Oomoo`02000JOol00`00Oomoo`1=Ool4000;Ool00`00Ool00003000:Ool01`00Oomoogoo001o
o`00009oo`03001oo`0000Aoo`8001]oo`<000Yoo`8003ioo`00GGoo00<007ooOol00goo1@003Goo
00<007ooOol02goo0P0027oo0P000Woo00<007ooOol05goo00<007ooOol0Bgoo0`003Goo1@0037oo
00@007ooOol000=oo`07001oogoo001oo`00Ool00P006goo0P0000=oo`0000002Goo0P00?goo001L
Ool00`00Oomoo`02Ool40003Ool70004Ool2000<Ool20008Ool30003Ool00`00Oomoo`0GOol00`00
Oomoo`18Ool4000>Ool3000?Ool00`00Ool00004Ool01@00Oomoo`00Ool00P006goo0P0000Eoo`00
001oo`0000Qoo`80041oo`00Fgoo00<007ooOol01@0000=oo`00Ool02Goo100037oo0P002Goo00D0
07ooOomoo`00009oo`03001oogoo01Qoo`03001oogoo04Eoo`@000eoo`<00003Ool007oo00moo`03
001oo`0000Eoo`06001oo`00001oo`006Goo0P000Woo00D007ooOomoo`0000Moo`03001oo`00041o
o`00FGoo1@000Woo00D007ooOomoo`0000eoo`8000Qoo`<000Yoo`03001oogoo009oo`04001oogoo
000IOol20014Ool40002Ool00`00Oomoo`08Ool40003Ool00`00Oomoo`0>Ool20005Ool50002Ool0
0`00Oomoo`0DOol20002Ool20004Ool20005Ool00`00Ool00011Ool005Qoo`<000Aoo`03001oogoo
009oo`03001oogoo00]oo`04001oo`000004Ool2000;Ool20005Ool01@00Oomoogoo00005Woo0P00
00=oo`00Ool0?goo100000=oo`00Ool017oo0P001Woo0`001Woo00<007ooOol03Woo00<007ooOol0
0Woo0P000goo0`0000=oo`00Ool04goo0P000goo00<007ooOol017oo00<007oo00000goo00<007oo
0000@Woo001GOol20005Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01000Ool0
000037oo00<007ooOol01Woo00@007ooOol001Aoo`8000=oo`03001oogoo03Yoo`@000Aoo`03001o
ogoo00Ioo`03001oogoo00@000Qoo`03001oogoo00aoo`<00004Ool000000006Ool5000AOol20003
Ool20007Ool00`00Ool00003Ool00`00Ool00012Ool005Ioo`8000Aoo`8000Eoo`8000aoo`04001o
ogooOol3000=Ool00`00Oomoo`07Ool01000Oomoo`004Goo0`001Goo00<007ooOol0=Woo1@001goo
00<007ooOol01Woo10002goo00<007ooOol02Woo0P000Woo0P002Woo0P0000=oo`0000003Woo0P00
17oo00<007ooOol01goo00P007ooOol007oo001oo`00@goo001FOol20003Ool00`00Oomoo`05Ool2
000<Ool01000Ool000000goo0P002Goo0P002Woo00D007ooOomoo`0000ioo`8000Qoo`03001oogoo
039oo`D000]oo`03001oogoo009oo`L000aoo`03001oogoo00Qoo`800006Ool00000001oo`002goo
00@007oo001oo`8000Yoo`8000Aoo`8000Yoo`07001oogooOol007oo0000A7oo001EOol00`00Ool0
0002Ool00`00Oomoo`06Ool2000<Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool01000Oomo
o`0037oo0P002Woo00<007ooOol0;Woo1P003Woo1@0000=oo`0000000goo00<007ooOol02goo00<0
07ooOol01Woo00@007oo000000Eoo`03001oogoo00Uoo`03001oo`00009ooa0000aoo`03001oogoo
00800003Ool007oo04=oo`00E7oo00H007ooOol007oo0009Ool2000:Ool30009Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool01000Oomoo`002Goo0`0037oo00<007ooOol0:Woo1P0047oo0`000Woo0`00
1Woo00<007ooOol02Woo00<007ooOol017oo10001goo00<007ooOol027oo00@007oo000000Aoo`04
001oogooOol20008Ool00`00Oomoo`09Ool00`00Ool00002Ool00`00Oomoo`13Ool005Aoo`03001o
ogoo008000Yoo`8000Moo`<00003Ool007oo00Yoo`800003Ool00000011oo`04001oogoo0006Ool2
000?Ool00`00Oomoo`0VOol6000@Ool400000goo001oo`020009Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool3000;Ool00`00Oomoo`06Ool00`00Oomoo`02Ool20003Ool3000;Ool00`00Oomoo`08Ool2
00000goo00000016Ool005=oo`03001oogoo008000]oo`8000Eoo`8000Aoo`03001oogoo00]oo`03
001oogoo011oo`04001oo`000003Ool3000BOol00`00Oomoo`0POol8000@Ool30004Ool3000<Ool0
0`00Oomoo`09Ool00`00Oomoo`02000>Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Ool007oo
0`003Goo00<007ooOol01Woo1@00Agoo001BOol00`00Oomoo`02000;Ool?000=Ool00`00Oomoo`0@
Ool20002Ool3000EOol00`00Oomoo`0KOol9000@Ool40003Ool400000goo001oo`0=Ool00`00Oomo
o`08Ool3000AOol00`00Oomoo`03Ool00`00Oomoo`05Ool400000goo001oo`0<Ool00`00Oomoo`04
Ool400000goo001oo`17Ool0059oo`05001oo`00Ool00009Ool20002Ool40009Ool2000:Ool00`00
Ool0000>Ool300000goo001oo`02000GOol00`00Oomoo`0EOol;0002Ool00`00Oomoo`0;Ool40003
Ool40005Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool3000COol00`00Oomoo`02Ool00`00Oomoo`05
Ool20003Ool3000=Ool01000Oomoogoo1@0000=oo`00Ool0B7oo001AOol00`00Ool00002Ool00`00
Oomoo`05Ool20004Ool4000;Ool20008Ool00`00Ool0000<Ool20004Ool20002Ool00`00Oomoo`0D
Ool00`00Oomoo`0@Ool:0008Ool00`00Oomoo`08Ool30004Ool3000:Ool00`00Oomoo`0<Ool00`00
Oomoo`02Ool400000goo001oo`0COol01000Oomoo`001Goo0`0000=oo`00Ool017oo0P003Goo1@00
00Aoo`00Ool004Yoo`00D7oo0`000goo00<007ooOol00goo0P0017oo0`000goo0P002goo0P001Woo
00@007ooOol000Qoo`<000Aoo`<000Aoo`03001oogoo01=oo`03001oogoo00]oo`X000eoo`8000Eo
o`@000=oo`@000eoo`03001oogoo00aoo`03001oogoo00@000Aoo`03001oogoo015oo`03001oo`00
00Aoo`8000Aoo`03001oogoo00Eooa0000=oo`8004]oo`00D7oo00<007ooOol00goo00@007ooOomo
o`8000Eoo`05001oogooOol00004Ool2000:Ool30004Ool01000Oomoo`001Woo0P001Woo00@007oo
Ool000Aoo`03001oogoo01=oo`03001oogoo00Eoo`X001Aoo`03001oo`0000<000Aoo`<0015oo`03
001oogoo00aoo`@000Moo`03001oogoo019oo`03001oogoo00<000Ioo`03001oogoo00Aoo`03001o
ogoo00Qoo`800003Ool007oo00=oo`03001oo`0004]oo`00Cgoo00<007ooOol017oo00@007oo0000
00Ioo`03001oogoo009oo`03001oogoo00Aoo`8000Yoo`<00003Ool007oo00=oo`03001oogoo00<0
00Moo`05001oogooOol00005Ool00`00Oomoo`0AOol20002Ool:000GOol40004Ool4000DOol00`00
Oomoo`08Ool6000:Ool00`00Oomoo`0?Ool50009Ool00`00Oomoo`03Ool00`00Oomoo`07Ool20002
Ool00`00Oomoo`02Ool00`00Ool0001<Ool004moo`03001oogoo00Aoo`8000Ioo`8000Ioo`03001o
ogoo00Eoo`8000Moo`d000Qoo`8000Aoo`03001oogoo00Aoo`03001oogoo00aoo``001Qoo`D0009o
o`03001oo`0000<001Qoo`03001oogoo00Aoo`L000=oo`03001oogoo00Moo`03001oogoo00eoo`@0
00=oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Ioo`8000=oo`03001oogoo00=oo`80
04eoo`00Cgoo00<007ooOol00goo00<007ooOol00P000goo00<007ooOol01Woo00<007ooOol01goo
200017oo0`0000=oo`000000300017oo00<007ooOol017oo00<007oo00003P000Woo0P0017oo00<0
07ooOol04Woo1@001Goo100037oo3@000goo00<007ooOol0100000Aoo`00000000Ioo`03001oogoo
00Moo`03001oogoo00]oo`<000Moo`03001oogoo00Eoo`05001oogooOol00007Ool20004Ool00`00
Oomoo`03Ool2001>Ool004moo`03001oogoo00=oo`03001oogoo009oo`<000Yoo`03001oogoo00Eo
o`8000Moo`d000Aoo`8000=oo`l000Moo`<000Eoo`03001oogoo00Aoo`03001oogoo00aoo`D000Ao
o`H00003Ool0000000d000e=m@H000=oo`8000Uoo`03001oogoo00Qoo`03001oogoo00Qoo`8000]o
o`8000Eoo`04001oogoo0006Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`1=Ool004ioo`8000Ao
o`03001oogoo00=oo`800003Ool0000000Qoo`03001oogoo00=oo`8000aoo`<00003Ool00000009o
o`03001oo`0000/00004Ool007oo0006Ool00`00Oomoo`03Ool30008Ool00`00Oomoo`04Ool00`00
Oomoo`06Ool60003Ool60004Ool300000gZ^001=m@0KCOD3000017oo0000000037oo00<007ooOol0
1goo00<007ooOol01Goo0`003goo00<007ooOol00Woo00<007oo00001Goo0P001goo00<007ooOol0
0Woo0P00D7oo001>Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`02
Ool00`00Oomoo`09Ool30002Ool01000Oomoogoo0`000goo00@007ooOol000Moo`03001oogoo0080
00Aoo`04001oogooOol2000:Ool00`00Oomoo`06Ool00`00Oomoo`050003Ool60008Ool20004NZh0
0`00COE=m@0LCOD2000?Ool00`00Oomoo`08Ool01000Oomoogoo10004Woo00@007ooOomoo`8000Ao
o`8000Qoo`04001oogooOol3001AOol004ioo`8000=oo`03001oogoo009oo`03001oogoo00Ioo`<0
00Aoo`04001oo`00000:Ool20006Ool01000Oomoogoo1@000Woo00<007ooOol01Woo00<007ooOol0
0Woo00@007ooOomoo`@000aoo`03001oogoo00Aoo`D0009oo`H000]oo`<000Mj[P03001=mDge01a=
m@8000moo`03001oogoo00Moo`H001Eoo`800003Ool007oo009oo`8000Uoo`03001oogoo00<005=o
o`00CWoo00D007ooOomoo`0000=oo`8000aoo`80009oo`8000Uoo`<000Qoo`03001oogoo00=oo`80
009oo`03001oogoo00Moo`03001oogoo00=oo`@00003Ool0000000]oo`800003Ool0000000X000io
o`<000Yj[P03001=mDge01i=m@8000eoo`03001oogoo00Eoo`H001Uoo`D000Yoo`03001oo`000080
05Eoo`00CWoo00@007ooOol000=oo`03001oogoo00ioo`H000Eoo`8000aoo`03001oogoo009oo`03
001oo`0000X00003Ool007oo009oo`D000Aoo`03001oogoo00h000Ioo`03001oogoo00aoo`800003
;2T007Z^00Yj[P03001=mDge021=m@03001oogoo00Yoo`03001oogoo00=oo`80009oo`8001Uoo`D0
0003Ool0000000@000Aoo`@005Moo`00CWoo00@007ooOol0009oo`03001oogoo00moo`04001oogoo
0002Ool:0009Ool01000Oomoogoo0P0000=oo`0000002Goo4`001Goo0P0037oo00<007ooOol027oo
0`000b`Y00<007Z^NZh02GZ^00<004geCOD08Dge0P002goo00<007oo00000P000Woo0P000Woo00<0
07ooOol057oo100000=oo`00Ool01goo1P00FGoo001>Ool01000Ool007oo0P004Woo00H007ooOomo
o`00Ool20008Ool;0002Ool300000goo001oo`02Ool=0003Ool00`00Oomoo`04Ool20002Ool30000
0goo001oo`0;Ool00`00Oomoo`06Ool20005;2T00`00NZij[P0;NZh00`00COE=m@0RCOD20008Ool3
0002Ool30005Ool00`00Oomoo`0AOol30003Ool00`00Oomoo`07Ool4001KOol004eoo`<00003Ool0
07oo019oo`03001oogoo009oo`8001Aoo`/000=oo`@000Yoo`03001oogoo00Aoo`@000=oo`03001o
ogoo00Yoo`03001oogoo00Aoo`8000L/:@03001j[WZ^00]j[P03001=mDge02A=m@80009oo`@00003
Ool007oo008000Uoo`03001oogoo00ioo`<000Eoo`03001oogoo00Eoo`@005eoo`00CGoo100057oo
00<007ooOol00P0000=oo`00Ool057oo00@007oo000000=oo`04001oogooOol2000017oo001oo`00
2Woo00<007ooOol00Woo0`001Woo00<007ooOol02Woo00<007ooOol00Woo0P0000<00P00;2T01R`Y
00<007Z^NZh02gZ^00<004geCOD09Tge0P0017oo0`0037oo00<007ooOol02Woo0`0027oo00<007oo
Ool00goo1000Ggoo001=Ool3000DOol01000Oomoo`0017oo00<007ooOol04Woo100017oo0`0000Eo
o`00001oo`0000]oo`03001oo`0000<000Moo`03001oogoo00aoo`04001oogoo000200800`00;2T/
:@06;2T00`00NZij[P0;NZh00`00COE=m@0WCOD200001Goo000007oo00003Goo00<007ooOol027oo
0`002Goo00<007ooOol00Woo1000HGoo001=Ool2000017oo000000004Goo00<007oo00001Woo00<0
07ooOol04Woo0P000Woo10000Woo00D007ooOomoo`0000]oo`<000Yoo`03001oogoo00aoo`03001o
o`0000<00P03000/:B`Y00D/:@03001j[WZ^00aj[P03001=mDge02U=m@80009oo`03001oogoo00ao
o`03001oogoo00Aoo`@000]oo`03001oogoo00@006=oo`00CGoo0P0017oo0P003Woo0`0027oo00<0
07ooOol04Goo100017oo0P000goo00<007ooOol01goo1@002goo00<007ooOol02goo10000P0200<0
02`Y;2T01R`Y00<007Z^NZh03GZ^00<004geCOD0:Tge00<007oo00003goo00<007ooOol01@003Goo
1@00IGoo001=Ool20006Ool3000;Ool00`00Oomoo`09Ool2000@Ool300000goo00000002Ool20004
Ool00`00Oomoo`05Ool30004Ool00`00Oomoo`08Ool00`00Oomoo`06Ool500000goo000000030080
0`00;2T/:@06;2T00`00NZij[P0=NZh00`00COE=m@0[COD2000?Ool300000goo0000000>Ool4001W
Ool004eoo`<000Qoo`<000Moo`03001oogoo00aoo`03001oogoo00]oo`800003Ool0000000=oo`80
009oo`04001oogoo0005Ool40006Ool00`00Oomoo`08Ool00`00Oomoo`060006Ool01@0000800P02
00002B`Y00<007Z^NZh03GZ^00<004geCOD0:dge0`0037oo0P0000Aoo`00000000ioo`@006Uoo`00
CGoo0`002goo0P000goo0`003goo00<007ooOol01goo0`000goo0P000Woo00<007ooOol00`000Woo
00@007ooOomoo`<000Uoo`03001oogoo00Aoo`L000Moo`H000<00P03000/:B`Y00H/:@03001j[WZ^
00ij[P03001=mDge02a=m@03001UP00000Qoo`H000=oo`<000Uoo`<006aoo`00CGoo0P0000=oo`00
Ool02goo0`0000=oo`00Ool047oo00<007ooOol00goo0`001Woo10001Goo2`001Goo2P0000=oo`00
00002`0017oo00D0000200800P0000T/:@03001j[WZ^00ij[P03001=mDge02a=m@04001UP6F00004
Ool300000goo00000009Ool40002Ool4001^Ool004eoo`04001oogoo000<Ool200000goo00000007
000;Ool00`00Oomoo`020009Ool20008Ool400000goo0000000C0003Ool00`00Oomoo`0:Ool01@00
00800P0200002R`Y00<007Z^NZh03gZ^00<004geCOD0;4ge00<006F000000Woo0P0000Aoo`000000
00ioo`@0075oo`00CGoo00D007ooOomoo`0000Yoo`03001oogoo009oo`03001oogoo00Eooa0000Qo
o`<000=oo`X000ioo`03001oogoo00Moo`03001oogoo00Yoo`0500000P020080000:;2T00`00NZij
[P0?NZh00`00COE=m@0/COD00`00IH1UP005000>Ool4001dOol004eoo`05001oogooOol00009Ool0
0`00Oomoo`03Ool00`00Oomoo`0?Ool20002Ool@00000goo00000003000BOol00`00Oomoo`08Ool0
0`00Oomoo`08Ool01@0000800P0200002R`Y00<007Z^NZh047Z^00<004geCOD0;Dge00@006F00000
00ioo`D007Ioo`00CGoo00<007ooOol00Woo00<007ooOol017oo0P001Woo00<007ooOol03Woo00<0
07ooOol01Goo0`0017oo0P000Woo0`0000Eoo`00Oomoo`00019oo`03001oogoo00Qoo`03001oogoo
00Moo`0300000P0200800P03000/:B`Y00P/:@03001j[WZ^011j[P03001=mDge02e=m@04001UP6F0
000;Ool5001iOol004eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
00aoo`8000]oo`T00003Ool0000000=oo`03001oogoo011oo`03001oogoo00Qoo`03001oogoo00Io
o`0300000P0200800P03000/:B`Y00P/:@8001=j[P03001=mDge02e=m@03001UP00000Qoo`D007ao
o`00CGoo00<007ooOol00goo00D007ooOomoo`0000Uoo`03001oogoo00]oo`03001oogoo00ioo`<0
00=oo`03001oogoo00=oo`03001oogoo011oo`03001oogoo00Qoo`03001oogoo00Ioo`0300000P02
00800P03000/:B`Y00H/:@800003?E<007Z^019j[P03001=mDge02e=m@04001UP6F00004Ool6001n
Ool004eoo`8000Aoo`04001oo`00000:Ool00`00Oomoo`09Ool2000@Ool30002Ool20006Ool00`00
Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`0000800P0200800`00;2T/:@04;2T30003
?E<00`00NZij[P0ANZh00`00COE=m@0^COD01000IH0007oo1P00PGoo001=Ool00`00Ool000020002
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`030008Ool00`00Oomo
o`0@Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`0000800P0300800`00;2T/:@02;2T20006?E<0
0`00NZij[P0ANZh00`00COE=m@0^COD01@00IH1UP000Ool00P00Q7oo001>Ool01000Oomoogoo1@00
2Goo00<007ooOol01goo0P0047oo0`000Woo0P002Goo00<007ooOol04Goo00<007ooOol027oo00<0
07ooOol00goo00<0000200800P0200<002`Y;2T00`0023eC00<007Z^NZh04GZ^00<004geCOD0;dge
00@006F0000008Ioo`00CWoo00<007ooOol00goo100027oo00<007ooOol01Woo00<007ooOol03Woo
0P0000=oo`00Ool00`0000=oo`0000001goo00<007ooOol04Goo00<007ooOol027oo00<007ooOol0
0Woo00<0000200800`020`0033eC00<007Z^NZh04GZ^00<004geCOD0;Tge00@006F0IH0008Ioo`00
Cgoo00<007ooOol00Woo00<007ooOol00`001Woo00<007ooOol017oo0P0047oo00L007ooOol007oo
001oo`020003Ool20005Ool00`00Oomoo`0AOol00`00Oomoo`08Ool00`00Oomoo`0200050082000>
?E<00`00NZij[P0ANZh00`00COE=m@0_COD00`00IH000026Ool004moo`03001oogoo009oo`03001o
ogoo00=oo`8000Aoo`03001oogoo00=oo`03001oogoo00ioo`8000=oo`800004Ool007oo0005Ool2
0003Ool00`00Oomoo`0AOol00`00Oomoo`03Ool800000goo00000P020083000??E<00`00NZij[P0A
NZh00`00COE=m@0_COD01000IH1UP000QGoo001@Ool01@00Oomoogoo00001Woo100000=oo`00Ool0
0Woo0P0047oo00@007ooOomoo`80009oo`04001oogoo0007Ool200000goo001oo`0>Ool:0005Ool0
1000Oomoo`000P020P000Qb@00<003eC?E<03CeC00<007Z^NZh04GZ^00<004geCOD0<4ge00<006F0
0000QGoo001@Ool01000Oomoo`002Goo00<007oo00002@002goo0P000Woo0P0000Eoo`00Oomoo`00
009oo`03001oogoo00Mooa4000Aoo`03001oogoo009oo`T000030080000000@LT003000mDceC00dm
D`03001j[WZ^019j[P03001=mDge02m=m@04001UP6F00024Ool0055oo`03001oo`0000Yoo`D000Io
oa000005Ool007ooOol00003Ool00`00Oomoo`03Ool:0005Ool?0007Ool3000679000`00?E<mD`0=
?E<00`00NZij[P0BNZh00`00COE=m@0`COD00`00IH000024Ool0055oo`03001oo`0000aoo`@000eo
o`@000Aoo`h000Aoo`03001oogoo019oo`03001oogoo00Uoo`03000LT1b@00HLT003000mDceC00dm
D`03001j[WZ^019j[P03001=mDge031=m@04001UP6F00023Ool0059oo`8000aoo`80009oo`L000Ao
o`<000Qoo`03001oo`0000Aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Uoo`8000PL
T003000mDceC00dmD`03001j[WZ^019j[P03001=mDge035=m@03001UP00008=oo`00DWoo0P0037oo
00<007oo000027oo1@002Woo0P001Woo00<007ooOol017oo00<007ooOol04goo00<007ooOol02Goo
0P0021b@00<003eC?E<03CeC00<007Z^NZh04WZ^00<004geCOD0<Dge00@006F0IH00089oo`00Dgoo
00<007ooOol02Woo00<007oo00002goo00<007ooOol027oo0P001goo00<007ooOol017oo00<007oo
Ool04goo00<007ooOol027oo00<00004000021b@00<003eC?E<03SeC00<007Z^NZh04WZ^00<004ge
COD0<Dge00<006F00000PWoo001COol2000;Ool00`00Ool0000;Ool00`00Oomoo`08Ool20008Ool0
0`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`0000@0000879000`00?E<mD`0>?E<0
0`00NZij[P0BNZh00`00COE=m@0aCOD01000IH1UP000PGoo001DOol40008Ool01000Oomoo`002Woo
00<007ooOol027oo0P0027oo00<007ooOol00Woo00<007ooOol04goo00<007ooOol02Goo00<00004
000021b@00<003eC?E<03SeC00<007Z^NZh04WZ^00<004geCOD0<Tge00<006F0IH00PGoo001FOol5
0004Ool01@00Oomoogoo00002Woo00<007ooOol01Woo0P000Woo0`001Woo00@007ooOol001Eoo`03
001oogoo00Yoo`030000100000PLT003000mDceC00hmD`03001j[WZ^019j[P03001=mDge039=m@80
0003IH0007oo07moo`00F7oo00<007ooOol00`0000=oo`00Ool00goo00<007ooOol01Woo00<007oo
Ool01Goo0P001goo0`000goo00<007oo00005Woo00<007ooOol02Woo00<00004000021b@00<003eC
?E<03SeC00<007Z^NZh04WZ^00<004geCOD0<Tge00@007l/0000081oo`00FGoo0P000goo0`000goo
00<007ooOol01Woo00<007ooOol00goo0P0037oo0`0000=oo`0000005Woo00<007ooOol02`0000<0
100079001ab@00<003eC?E<03SeC00<007Z^NZh04gZ^00<004geCOD0<Dge00D007l/Obao;00007mo
o`00Fgoo0P000Woo00<007oo00000P0000=oo`00Ool01Woo00@007ooOomoo`80015oo`d000Eoo`X0
009oo`T0000300@001b@00LLT003000mDceC00hmD`03001j[WZ^01=j[P03001=mDge035=m@05001o
;7l/Ob`0001oOol005eoo`<000Aooa8000eoo`800003Ool007oo00AooaH000Qoo`030000100000PL
T003000mDceC00hmD`03001j[WZ^01=j[P03001=mDge035=m@05001o;7l/Ob`0001oOol005mooa00
00MooaH000moo`03001oogoo00aoo`030000100000PLT003000mDceC00hmD`03001j[WZ^01=j[P03
001=mDge035=m@05001o;7l/Ob`0001oOol0065oo`<000Aoo`8000Eoo`<000moo`03001oogoo00=o
o`03001oogoo011oo`03001oogoo00eoo`030000100000PLT003000mDceC00lmD`03001j[WZ^01=j
[P03001=mDge031=m@05001o;7l/Ob`0001oOol006Aoo`<000=oo`03001oogoo00Eoo`8000]oo`80
00Moo`03001oogoo00ioo`03001oogoo00ioo`030000100000PLT003000mDceC00lmD`03001j[WZ^
01=j[P03001=mDge031=m@05001o;7l/Ob`0001oOol006Moo`H000Moo`<000Moo`03001oogoo00Qo
o`8000eoo`03001oogoo00Yoo`L000TLT003000mDceC00lmD`03001j[WZ^01=j[P03001=mDge031=
m@05001o;7l/Ob`0001oOol006]oo`@000Qoo`<0009oo`8000eoo`03001oogoo00Uoo`03001oogoo
009ooa0000TLT003000mDceC00lmD`03001j[WZ^01=j[P03001=mDge031=m@05001o;7l/Ob`0001o
Ool006iooaX000Aoo`03001oogoo00=ooa0000Qoo`8000TLT003000mDceC00hmD`8001Ej[P03001=
mDge031=m@05001o;7l/Ob`0001oOol007iooa`0011oo`8000TLT003000mDceC00/mD`<00003AOL0
07Z^01Ej[P03001=mDge02m=m@05001o;7l/Ob`0001oOol00:Uoo`030000100000TLT003000mDceC
00PmD`<000E5m`03001j[WZ^01=j[P03001=mDge02m=m@05001o;7l/Ob`0001oOol00:Uoo`030000
100000TLT003000mDceC00DmD`<000Q5m`03001j[WZ^01=j[P03001=mDge02m=m@05001o;7l/Ob`0
001oOol00:Uoo`030000100000TLT003000mDceC008mD`<000]5m`03001j[WZ^01=j[P03001=mDge
02m=m@05001o;7l/Ob`0001oOol00:Uoo`030000100000TLT003000mD`00008000m5m`03001j[WZ^
019j[P03001=mDge02m=m@05001o;7l/Ob`0001oOol00:Uoo`030000100000TLT0800195m`03001j
[WZ^01=j[P03001=mDge02i=m@04001o;7l/0020Ool00:Uoo`030000100000LLT0<001=5m`03001j
[WZ^01=j[P03001=mDge02i=m@04001o;7l/0020Ool00:Uoo`030000100000DLT08000<]V0030015
mdGg0115m`03001j[WZ^01=j[P03001=mDge02i=m@04001o;7l/0020Ool00:Uoo`030000100000@L
T003000]V2fH00<]V0030015mdGg0155m`03001j[WZ^019j[P03001=mDge02i=m@04001o;7l/0020
Ool00:Uoo`0300001000008LT08000L]V0030015mdGg0115m`03001j[WZ^01=j[P03001=mDge02e=
m@04001o;7l/0020Ool00:Uoo`0300001000008000T]V0030015mdGg0115m`03001j[WZ^01=j[P03
001=mDge02e=m@04001o;7l/0020Ool00:Uoo`030000100000`]V0030015mdGg0115m`03001j[WZ^
019j[P03001=mDge02e=m@04001o;7l/0020Ool00:Uoo`<000`]V0030015mdGg0115m`03001j[WZ^
019j[P03001=mDge02e=m@04001o;7l/0020Ool00:Uoo`80000303<002fH00X]V0030015mdGg0115
m`03001j[WZ^019j[P03001=mDge02e=m@04001o;7l/0020Ool00:Uoo`040000<`0c000<;IP00`00
AOM5m`0@AOL00`00NZij[P0BNZh00`00COE=m@0/COD01000Obao;000P7oo002YOol01@0003<0<`0c
00002bfH00<004GgAOL044Gg00<007Z^NZh04WZ^00<004geCOD0;4ge00@007l/Ob`0081oo`00ZWoo
0`0c00<002fH;IP02RfH00<004GgAOL03dGg00<007Z^NZh04WZ^00<004geCOD0;4ge00@007l/Ob`0
081oo`00ZWoo00D0000c03<0<`0000/]V0030015mdGg0115m`03001j[WZ^015j[P03001=mDge02a=
m@04001o;7l/0020Ool00:]oo`040000<`0c000<;IP00`00AOM5m`0?AOL00`00NZij[P0BNZh00`00
COE=m@0ZCOD00`00MoH000020020Ool00:]oo`050000<`0c03<0000;;IP00`00AOM5m`0?AOL00`00
NZij[P0BNZh00`00COE=m@0ZCOD01@00MoIgmWOf0000P7oo002/Ool0100003<0<`002bfH00<004Gg
AOL044Gg00<007Z^NZh04GZ^00<004geCOD0:Dge00D007OfMoIgmP00085oo`00[7oo00D0000c03<0
<`0000/]V0030015mdGg00m5m`03001j[WZ^015j[P03001=mDge02U=m@05001gmWOfMoH00021Ool0
0:eoo`040000<`0c000;;IP00`00AOM5m`0?AOL00`00NZij[P0ANZh00`00COE=m@0XCOD01@00MoIg
mWOf0000PWoo002]Ool01@0003<0<`0c00002bfH00<004GgAOL03TGg00<007Z^NZh04WZ^00<004ge
COD09dge00@007OfMoH008=oo`00[Woo00@0000c03<000/]V0030015mdGg00m5m`03001j[WZ^015j
[P03001=mDge02I=m@05001gmWOfMoH00023Ool00:ioo`050000<`0c03<0000;;IP00`00AOM5m`0>
AOL00`00NZij[P0ANZh00`00COE=m@0VCOD01000MoIgmP00Q7oo002_Ool0100003<0<`002bfH00<0
04GgAOL03TGg00<007Z^NZh04GZ^00<004geCOD09Dge00D007OfMoIgmP0008Aoo`00[goo00D0000c
03<0<`0000X]V0030015mdGg00m5m`03001j[WZ^011j[P03001=mDge02A=m@05001gmWOfMoH00025
Ool00;1oo`040000<`0c000;;IP00`00AOM5m`0=AOL2000CNZh00`00COE=m@0SCOD01000MoIgmP00
QWoo002`Ool01@0003<0<`0c00002RfH00<004GgAOL02TGg0`000TZK00<007Z^NZh047Z^00<004ge
COD08Tge00D007OfMoIgmP0008Ioo`00/Goo00@0000c03<000/]V0030015mdGg00I5m`<000E:V`03
001j[WZ^011j[P03001=mDge029=m@04001gmWOf0027Ool00;5oo`050000<`0c03<0000:;IP00`00
AOM5m`03AOL30009BY/00`00NZij[P0?NZh00`00COE=m@0QCOD01000MoIgmP00R7oo002bOol01000
03<0<`002bfH00<004Gg00000P0034ZK00<007Z^NZh047Z^00<004geCOD084ge00@007OfMoH008Qo
o`00/Woo00D0000c03<0<`0000T]V0<0011:V`03001j[WZ^00mj[P03001=mDge01m=m@04001gmWOf
0029Ool00;=oo`040000<`0c0007;IP20002=Ud00`00BY]:V`0?BY/00`00NZij[P0>NZh00`00COE=
m@0NCOD01@00MoIgmWOf0000RGoo002cOol01@0003<0<`0c000012fH0P001CIM00<004ZKBY/03TZK
00<007Z^NZh03WZ^00<004geCOD07Tge00@007OfMoH008Yoo`00]7oo00@0000c03<0008]V08000Pf
G@03001:VdZK00i:V`03001j[WZ^00ej[P03001=mDge01e=m@04001gmWOf002;Ool00;Aoo`040000
<`0c03<2000;=Ud00`00BY]:V`0>BY/00`00NZij[P0=NZh00`00COE=m@0LCOD01000MoIgmP00Rgoo
002eOol0100003<000WL0P002cIM0P003TZK00<007Z^NZh03GZ^00<004geCOD06dge00@007OfMoH0
08aoo`00]Goo00<0000c00000`WL00<003IM=Ud02SIM00<004ZKBY/034ZK00<007Z^NZh037Z^00<0
04geCOD06dge00<007Of0000SGoo002fOol00`002M`9g0032M`00`00=UdfG@0:=Ud00`00BY]:V`0;
BY/00`00NZij[P0<NZh00`00COE=m@0JCOD01000MoIgmP00SGoo002gOol00`002M`9g0032M`2000;
=Ud00`00BY]:V`0;BY/00`00NZij[P0<NZh00`00COE=m@0ICOD00`00MoH0002>Ool00;Uoo`030009
g0WL00<9g003000fGCIM00TfG@03001:VdZK00]:V`03001j[WZ^00]j[P03001=mDge01Q=m@04001g
mWOf002>Ool00;Yoo`8000@9g003000fGCIM00TfG@03001:VdZK00Y:V`03001j[WZ^00]j[P03001=
mDge01I=m@800003Dm`0000008moo`00_7oo0P000`WL0P002SIM00<004ZKBY/02TZK00<007Z^NZh0
2WZ^00<004geCOD05Dge00<005?LDm`00P00T7oo002nOol00`002M`9g0022M`00`00=UdfG@08=Ud0
0`00BY]:V`0:BY/00`00NZij[P09NZh00`00COE=m@0CCOD2000015?L00000000TGoo002oOol20003
2M`00`00=UdfG@08=Ud00`00BY]:V`09BY/00`00NZij[P0:NZh00`00COE=m@0@COD200000e?L0000
0002002BOol00<5oo`040009g0WL2M`20009=Ud2000:BY/00`00NZij[P09NZh00`00COE=m@0?COD0
0`00Dm`00003002DOol00<9oo`8000<9g003000fGCIM00PfG@03001:VdZK00M:V`03001j[WZ^00Uj
[P03001=mDge00e=m@H009Ioo`00a7oo0P000PWL00<003IM=Ud023IM00<004ZKBY/01TZK0P002WZ^
00<004geCOD034ge1@00V7oo0036Ool00`002M`9g0020009=Ud01000BY]:VdZK10000T]O0P0027Z^
00<004geCOD02Tge1@00VWoo0037Ool200022M`00`00=UdfG@07=Ud30008Bel20007NZh00`00COE=
m@07COD5002LOol00<Uoo`040009g0WL0006=Ud20002>cl40007Bel00`00NZij[P04NZh00`00COE=
m@06COD4002NOol00<Yoo`8000032M`00000008fG@8000Pk?`<000E;G`8000Aj[P03001=mDge00A=
m@@00:1oo`00c7oo0P0000<9g00000000`002S/o10000d]O00D007Z^NZij[P0000E=m@<00:9oo`00
cWoo3`001C/o0`0000=;G`0000000WZ^00<004geCOD00`00Y7oo003?OolO002VOol00=eoo`l00:Qo
o`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003o
OonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEo
o`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003o
OonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEo
o`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003o
OonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEo
o`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003o
OonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEo
o`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00ogooUGoo003o
OonEOol00?mooiEoo`00ogooUGoo003oOonEOol00?mooiEoo`00\
\>"],
  ImageRangeCache->{{{0, 403}, {379, 0}} -> {-4.80031*^-06, 0.00641329, 
  0.00238229, 0.00238229}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Extrude[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " extrudes the sequence of ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1 lines between the ",
  StyleBox["pnti dist",
    FontSlant->"Italic"],
  " units in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Extrude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.\n\n",
  StyleBox["Revolve[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis, segs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox["revo",
    FontFamily->"Times"],
  "lves the sequence of ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1 lines between the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " about the specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The surface of revolution is broken into ",
  StyleBox["segs",
    FontSlant->"Italic"],
  " segments. ",
  StyleBox["Revolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Functions to generate pseudo-solid objects."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Extrude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to generate a sequence of faces that are defined by sweeping a \
sequence of connected lines through 3D space. The following example takes six \
points on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that define an hourglass form and extrudes them at an oblique angle into \
a set of six facets forming a canted hourglass."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the points for an hourglass graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(pntlist
       = {\n\t\tPoint[body2, {0, 0, 0}], Point[body2, {3, 0, 0}], \n\t\t
        Point[body2, {2, 2, 0}], Point[body2, {3, 4, 0}], \n\t\t
        Point[body2, {0, 4, 0}], Point[body2, {1, 2, 0}], \n\t\t
        Point[body2, {0, 0, 0}]}; \n
    \(bdgraph = 
      Graphics3D[{Extrude[pntlist, Line[body2, 0, {0, 0.5, 0.7}], 2.0]}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The graphic is shown shifted 2 units in the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " direction off of the global origin."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] 2, Z2 \[Rule] 0, Eo2 \[Rule] 1, 
          Ei2 \[Rule] 0, Ej2 \[Rule] 0, Ek2 \[Rule] 0}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92981 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-017 1.07385 -0.0207565 1.07385 [
[ 0 0 0 0 ]
[ 1 .92981 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03094 .20332 m
0 .46079 L
s
0 .46079 m
.52162 .92981 L
s
.52162 .92981 m
.52234 .69649 L
s
.52234 .69649 m
.03094 .20332 L
s
.55602 0 m
.9768 .56154 L
s
.9768 .56154 m
1 .80248 L
s
1 .80248 m
.55728 .26441 L
s
.55728 .26441 m
.55602 0 L
s
.03094 .20332 m
0 .46079 L
s
0 .46079 m
.55728 .26441 L
s
.55728 .26441 m
.55602 0 L
s
.55602 0 m
.03094 .20332 L
s
.52234 .69649 m
.9768 .56154 L
s
.9768 .56154 m
1 .80248 L
s
1 .80248 m
.52162 .92981 L
s
.52162 .92981 m
.52234 .69649 L
s
0 0 m
1 0 L
1 .92981 L
0 .92981 L
closepath
clip
newpath
.5 Mabswid
.88036 .4574 m .43243 .59792 L .52228 .91199 L p .623 .516 .712 r
F P
0 g
s
.5077 .7135 m .52228 .91199 L .43243 .59792 L p 0 0 .463 r
F P
0 g
s
.43243 .59792 m .40925 .37046 L .5077 .7135 L p 0 0 .463 r
F P
0 g
s
.52228 .91199 m .97884 .7894 L .88036 .4574 L p .623 .516 .712 r
F P
0 g
s
.56655 .31616 m .88036 .4574 L .97884 .7894 L p .832 .634 .634 r
F P
0 g
s
.97884 .7894 m .66828 .66608 L .56655 .31616 L p .832 .634 .634 r
F P
0 g
s
.15759 .58107 m .5077 .7135 L .40925 .37046 L p .826 .631 .639 r
F P
0 g
s
.40925 .37046 m .05609 .21887 L .15759 .58107 L p .826 .631 .639 r
F P
0 g
s
.555 .02746 m .56655 .31616 L .66828 .66608 L p 0 0 .529 r
F P
0 g
s
.66828 .66608 m .6679 .41369 L .555 .02746 L p 0 0 .529 r
F P
0 g
s
.6679 .41369 m .15759 .58107 L .05609 .21887 L p .604 .502 .712 r
F P
0 g
s
.05609 .21887 m .555 .02746 L .6679 .41369 L p .604 .502 .712 r
F P
0 g
s
.25 Mabswid
.55602 0 m
.9768 .56154 L
s
.9768 .56154 m
1 .80248 L
s
1 .80248 m
.55728 .26441 L
s
.55728 .26441 m
.55602 0 L
s
.03094 .20332 m
0 .46079 L
s
0 .46079 m
.55728 .26441 L
s
.55728 .26441 m
.55602 0 L
s
.55602 0 m
.03094 .20332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{276, 258},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004D00010Q000`40O003h00Oogoo5Goo002GOol2
001kOol009Eoo`800003Ool0000007Yoo`00TWoo0`000goo0P00NWoo002@Ool20006Ool00`00Ool0
001iOol008eoo`<000Qoo`04001oogoo001hOol008Yoo`<000]oo`05001oogooOol0001gOol008Qo
o`8000ioo`05001oogooOol0001gOol008Eoo`<0011oo`03001oogoo009oo`03001oogoo07Aoo`00
Pgoo0P004Woo0P001Goo00<007ooOol0Lgoo0020Ool3000BOol200000dhF001oo`05Ool00`00Oomo
o`1bOol007ioo`80019oo`<000=>5P8000Eoo`03001oogoo079oo`00Ngoo0`004Goo0`001ThF0P00
1Woo00<007ooOol0LGoo001hOol3000BOol20009CQH20007Ool00`00Oomoo`1`Ool007Ioo`80019o
o`<000]>5P8000Qoo`03001oogoo06moo`00Lgoo0`004Goo0`003ThF00<004hF00001goo00<007oo
Ool0Kgoo001aOol2000BOol2000ACQH00`00CQH00008Ool00`00Oomoo`1^Ool006ioo`<0015oo`<0
01=>5P03001>5P0000Uoo`03001oogoo06eoo`00K7oo0P004Goo0`005ThF00@004hFCQH000Uoo`03
001oogoo06aoo`00JGoo0`004Goo0P006DhF00@004hFCQH000Uoo`03001oogoo06aoo`00IWoo0`00
4Goo0`006dhF00@004hFCQH000Yoo`03001oogoo06]oo`00I7oo0P004Woo0P007ThF00D004hFCQI>
5P0000Yoo`03001oogoo06Yoo`00HGoo0`004Goo0`0084hF00D004hFCQI>5P0000]oo`03001oogoo
06Uoo`00Ggoo0P004Goo0`008dhF00D004hFCQI>5P0000]oo`03001oogoo06Uoo`00G7oo0`004Goo
0P009ThF00D004hFCQI>5P0000aoo`03001oogoo06Qoo`00FWoo0P004Goo0`00:4hF00<004hFCQH0
0ThF00<007ooOol02Woo00<007ooOol0Igoo001GOol3000@Ool3000[CQH00`00CQI>5P02CQH00`00
Oomoo`0;Ool00`00Oomoo`1VOol005Aoo`<0015oo`8002i>5P03001>5ThF009>5P03001oogoo00]o
o`03001oogoo06Ioo`00DWoo0P004Goo0`00<4hF00<004hFCQH00dhF00<007ooOol02goo00<007oo
Ool0IGoo001?Ool3000@Ool3000cCQH00`00CQI>5P03CQH00`00Oomoo`0<Ool00`00Oomoo`1TOol0
04eoo`80015oo`8003I>5P03001>5ThF00=>5P03001oogoo00eoo`03001oogoo06=oo`00BWoo0`00
47oo0`00>4hF00<004hFCQH00dhF00<007ooOol03Goo00<007ooOol0Hgoo0018Ool2000AOol2000k
CQH00`00CQI>5P04CQH00`00Oomoo`0=Ool00`00Oomoo`1ROol004Eoo`<0011oo`<003e>5P03001>
5ThF00A>5P03001oogoo00ioo`03001oogoo065oo`00@Woo0`0047oo0`00@4hF00<004hFCQH014hF
00<007ooOol03goo00<007ooOol0H7oo0010Ool2000AOol20013CQH00`00CQI>5P05CQH00`00Oomo
o`0>Ool00`00Oomoo`1POol003eoo`<0011oo`<004E>5P03001>5ThF00E>5P03001oogoo00moo`03
001oogoo05moo`00>goo0P0047oo0`00B4hF00<004hFCQH01DhF00<007ooOol047oo00<007ooOol0
GWoo000hOol3000@Ool2001<CQH00`00CQI>5P04CQH00`00Oomoo`0AOol00`00Oomoo`1MOol003Io
o`80011oo`<004i>5P03001>5ThF00E>5P03001oogoo011oo`03001oogoo05eoo`00<goo0`0047oo
0P00DDhF00<004hFCQH01DhF00<007ooOol04Goo00<007ooOol0G7oo000`Ool3000@Ool3001CCQH0
0`00CQI>5P05CQH00`00Oomoo`0BOol00`00Oomoo`1KOol002ioo`80011oo`<005I>5P03001>5ThF
00I>5P03001oogoo019oo`03001oogoo05Yoo`00:goo0`0047oo0P00FDhF00<004hFCQH01ThF00<0
07ooOol04Woo00<007ooOol0FWoo000YOol2000@Ool3001KCQH00`00CQI>5P06CQH00`00Oomoo`0C
Ool00`00Oomoo`1IOol002Ioo`<000moo`<005i>5P03001>5ThF00M>5P03001oogoo01=oo`03001o
ogoo05Qoo`0097oo0P0047oo0P00HDhF00<004hFCQH01dhF00<007ooOol057oo00<007ooOol0Egoo
000QOol3000?Ool3001SCQH00`00CQI>5P07CQH00`00Oomoo`0DOol00`00Oomoo`1GOol001ioo`<0
00moo`<006I>5P03001>5ThF00M>5P03001oogoo01Eoo`03001oogoo05Ioo`0077oo0P0047oo0P00
JDhF00<004hFCQH024hF00<007ooOol05Goo00<007ooOol0EGoo000IOol3000?Ool3001[CQH00`00
CQI>5P08CQH00`00Oomoo`0FOol00`00Oomoo`1DOol001Moo`80011oo`8006i>5P03001>5ThF00Q>
5P03001oogoo01Ioo`03001oogoo05Aoo`0057oo0`003goo0`00L4hF00<004hFCQH02DhF00<007oo
Ool05Woo00<007ooOol0Dgoo000BOol2000?Ool3001cCQH00`00CQI>5P09CQH00`00Oomoo`0GOol0
0`00Oomoo`1BOol000moo`<000moo`8007I>5P03001>5ThF00U>5P03001oogoo01Qoo`03001oogoo
055oo`0037oo0`003goo0`00N4hF00<004hFCQH02DhF00<007ooOol067oo00<007ooOol0DGoo000:
Ool2000?Ool3001kCQH00`00CQI>5P0:CQH00`00Oomoo`0HOol00`00Oomoo`1@Ool000Qoo`8000mo
o`8007i>5P03001>5ThF00Y>5P03001oogoo01Uoo`03001oogoo04moo`0027oo0P0037oo0`00P4hF
00<004hFCQH02ThF00<007ooOol06Woo00<007ooOol0CWoo0008Ool00`00Ool00008Ool30023CQH0
0`00CQI>5P0;CQH00`00Oomoo`0IOol00`00Oomoo`1>Ool000Qoo`04001oogoo0005Ool20026CQH0
0`00CQI>5P0;CQH00`00Oomoo`0JOol00`00Oomoo`1=Ool000Qoo`05001oogooOol00002Ool20028
CQH00`00CQI>5P0;CQH00`00Oomoo`0KOol00`00Oomoo`1<Ool000Moo`03001oogoo00=oo`03001o
o`0008U>5P03001>5ThF00]>5P03001oogoo01aoo`03001oogoo04]oo`001goo00<007ooOol017oo
00<007oo0000R4hF00<004hFCQH034hF00<007ooOol06goo00<007ooOol0Bgoo0007Ool00`00Oomo
o`05Ool20028CQH00`00CQI>5P0<CQH00`00Oomoo`0LOol00`00Oomoo`1:Ool000Moo`03001oogoo
00Ioo`03001>5ThF08I>5P03001>5ThF00a>5P03001oogoo01eoo`03001oogoo04Uoo`001goo00<0
07ooOol01Woo00<004hFCQH0QThF00<004hFCQH03DhF00<007ooOol07Goo00<007ooOol0B7oo0007
Ool00`00Oomoo`07Ool00`00CQI>5P25CQH00`00CQI>5P0=CQH00`00Oomoo`0MOol00`00Oomoo`18
Ool000Moo`03001oogoo00Moo`03001>5ThF08E>5P03001>5ThF00e>5P03001oogoo01ioo`03001o
ogoo04Moo`001goo00<007ooOol01goo00<004hFCQH0QDhF00<004hFCQH03ThF00<007ooOol07Woo
00<007ooOol0AWoo0007Ool00`00Oomoo`08Ool00`00CQI>5P24CQH00`00CQI>5P0>CQH00`00Oomo
o`0OOol00`00Oomoo`15Ool000Ioo`03001oogoo00Uoo`03001>5ThF08A>5P03001>5ThF00i>5P03
001oogoo01moo`03001oogoo04Eoo`001Woo00<007ooOol02Goo00<004hFCQH0Q4hF00<004hFCQH0
3ThF00<007ooOol087oo00<007ooOol0A7oo0006Ool00`00Oomoo`09Ool00`00CQI>5P24CQH00`00
CQI>5P0?CQH00`00Oomoo`0POol00`00Oomoo`13Ool000Ioo`03001oogoo00Yoo`03001>5ThF089>
5P80015>5P03001oogoo025oo`03001oogoo049oo`001Woo00<007ooOol02Woo00<004hFCQH0OdhF
0`000ThF00<004hFCQH03ThF00<007ooOol08Goo00<007ooOol0@Woo0006Ool00`00Oomoo`0:Ool0
0`00CQI>5P1lCQH30006CQH00`00CQI>5P0>CQH00`00Oomoo`0QOol00`00Oomoo`11Ool000Ioo`03
001oogoo00Yoo`03001>5ThF07Y>5P8000U>5P03001>5ThF00i>5P03001oogoo029oo`03001oogoo
041oo`001Woo00<007ooOol02goo00<004hFCQH0MThF0`0034hF00<004hFCQH03DhF00<007ooOol0
8goo00<007ooOol0?goo0006Ool00`00Oomoo`0;Ool00`00CQI>5P1cCQH3000@CQH00`00CQI>5P0<
CQH00`00Oomoo`0SOol00`00Oomoo`0oOol000Eoo`03001oogoo00aoo`03001>5ThF071>5P<001A>
5P03001>5ThF00a>5P03001oogoo02=oo`03001oogoo03ioo`001Goo00<007ooOol03Goo00<004hF
CQH0K4hF0`0064hF00<004hFCQH02dhF00<007ooOol097oo00<007ooOol0?Goo0005Ool00`00Oomo
o`0=Ool00`00CQI>5P1YCQH3000LCQH00`00CQI>5P0:CQH00`00Oomoo`0UOol00`00Oomoo`0lOol0
00Eoo`03001oogoo00eoo`03001>5ThF06M>5P8001m>5P03001>5ThF00]>5P03001oogoo02Aoo`03
001oogoo03aoo`001Goo00<007ooOol03Goo00<004hFCQH0I4hF0`008ThF00<004hFCQH02ThF00<0
07ooOol09Goo00<007ooOol0>goo0005Ool00`00Oomoo`0>Ool00`00CQI>5P1PCQH3000VCQH00`00
CQI>5P09CQH00`00Oomoo`0VOol00`00Oomoo`0jOol000Eoo`03001oogoo00ioo`03001>5ThF05e>
5P<002Y>5P03001>5ThF00U>5P03001oogoo02Ioo`03001oogoo03Uoo`001Goo00<007ooOol03Woo
00<004hFCQH0FThF0`00;ThF00<004hFCQH024hF00<007ooOol09Woo00<007ooOol0>Goo0005Ool0
0`00Oomoo`0?Ool00`00CQI>5P1FCQH3000bCQH00`00CQI>5P07CQH00`00Oomoo`0WOol00`00Oomo
o`0hOol000Aoo`03001oogoo011oo`03001>5ThF05A>5P8003E>5P03001>5ThF00M>5P03001oogoo
02Qoo`03001oogoo03Moo`0017oo00<007ooOol047oo00<004hFCQH0DDhF0`00>4hF00<004hFCQH0
1dhF00<007ooOol0:7oo00<007ooOol0=Woo0004Ool00`00Oomoo`0@Ool00`00CQI>5P1>CQH3000l
CQH00`00CQI>5P06CQH00`00Oomoo`0XOol00`00Oomoo`0fOol000Aoo`03001oogoo015oo`03001>
5ThF04Y>5P<0041>5P03001>5ThF00E>5P03001oogoo02Uoo`03001oogoo03Eoo`0017oo00<007oo
Ool04Goo00<004hFCQH0AdhF0`00A4hF00<004hFCQH01DhF00<007ooOol0:Goo00<007ooOol0=7oo
0004Ool00`00Oomoo`0AOol00`00CQI>5P14CQH30017CQH00`00CQI>5P05CQH00`00Oomoo`0ZOol0
0`00Oomoo`0cOol000Aoo`03001oogoo019oo`03001>5ThF045>5P8004]>5P03001>5ThF00A>5P03
001oogoo02Yoo`03001oogoo03=oo`0017oo00<007ooOol04Woo00<004hFCQH0?ThF0`00CThF00<0
04hFCQH00dhF00<007ooOol0:goo00<007ooOol0<Woo0003Ool00`00Oomoo`0COol00`00CQI>5P0k
CQH3001BCQH00`00CQI>5P03CQH00`00Oomoo`0[Ool00`00Oomoo`0aOol000=oo`03001oogoo01=o
o`03001>5ThF03Q>5P<005I>5P03001>5ThF009>5P03001oogoo02aoo`03001oogoo031oo`000goo
00<007ooOol057oo00<004hFCQH0=4hF0`00FThF00@004hFCQI>5P<002aoo`03001oogoo031oo`00
0goo00<007ooOol057oo00<004hFCQH0<DhF0`00GDhF00<004hFCQH00ThF00@006ZD000002]oo`03
001oogoo02moo`000goo00<007ooOol057oo00<004hFCQH0;dhF0P00HDhF00D004hFCQI>5P0000=Z
U0<002Uoo`03001oogoo02ioo`000goo00<007ooOol057oo00<004hFCQH0;4hF0`00I4hF00@004hF
CQH000IZU08002Qoo`03001oogoo02eoo`000goo00<007ooOol05Goo00<004hFCQH0:4hF0`00J4hF
00<004hF000026ZD0P009Woo00<007ooOol0;Goo0003Ool00`00Oomoo`0EOol00`00CQI>5P0UCQH3
001/CQH00`00CQH00009JY@2000UOol00`00Oomoo`0/Ool000=oo`03001oogoo01Eoo`03001>5ThF
029>5P<0071>5P8000]ZU0<002=oo`03001oogoo02]oo`000Woo00<007ooOol05goo00<004hFCQH0
7ThF0`00LdhF0P003VZD0P008Woo00<007ooOol0:Woo0002Ool00`00Oomoo`0GOol00`00CQI>5P0L
CQH2001gCQH2000?JY@2000POol00`00Oomoo`0ZOol0009oo`03001oogoo01Moo`03001>5ThF01U>
5P<007Y>5P03001ZU6ZD00mZU08001moo`03001oogoo02Uoo`000Woo00<007ooOol05goo00<004hF
CQH05ThF0`00ODhF0P004VZD0P007Woo00<007ooOol0:7oo0002Ool00`00Oomoo`0HOol00`00CQI>
5P0BCQH30021CQH2000CJY@3000LOol00`00Oomoo`0WOol0009oo`03001oogoo01Qoo`03001>5ThF
00m>5P<008A>5P8001IZU08001Yoo`03001oogoo02Moo`000Woo00<007ooOol067oo00<004hFCQH0
34hF0`00QdhF00<006ZD00005fZD0P006Goo00<007ooOol09Woo0002Ool00`00Oomoo`0IOol00`00
CQI>5P09CQH2002:CQH01000JYAZU00066ZD0P0067oo00<007ooOol09Goo0002Ool00`00Oomoo`0I
Ool00`00CQI>5P06CQH3002=CQH01000JYAZU0006FZD0`005Woo00<007ooOol097oo00000goo001o
o`0KOol00`00CQI>5P03CQH3002?CQH20003JY@00`00JYAZU00IJY@2000DOol00`00Oomoo`0TOol0
0003Ool007oo01]oo`03001>5ThF00<008m>5P<00003010006ZD00=ZU003001ZU6ZD01YZU08001=o
o`03001oogoo02=oo`0000=oo`00Ool06goo0`00SdhF0`00100@00<006ZDJY@00VZD00<006ZDJY@0
76ZD0P004Woo00<007ooOol08Woo00000goo001oo`0HOol300000goo001>5P2<CQH3000701000`00
JYAZU003JY@00`00JYAZU00MJY@3000@Ool00`00Oomoo`0QOol00003Ool007oo01Ioo`8000Aoo`03
001>5ThF08Q>5P<000X04003001ZU6ZD00AZU003001ZU6ZD01mZU08000ioo`03001oogoo025oo`00
00=oo`00Ool04goo0`001goo00<004hFCQH0Q4hF0`003@0@00<006ZDJY@01FZD00<006ZDJY@086ZD
0P003Goo00<007ooOol087oo00000goo001oo`0@Ool3000:Ool00`00CQI>5P21CQH3000@01000`00
JYAZU006JY@00`00JYAZU00QJY@2000<Ool00`00Oomoo`0OOol00003Ool007oo00eoo`<000eoo`03
001>5ThF07i>5P<00003Ool0000@01004003001ZU6ZD00MZU003001ZU6ZD029ZU08000]oo`03001o
ogoo01ioo`0000=oo`00Ool02Woo0`0047oo00<004hFCQH0NdhF0`0017oo00<0000@01003`0@00<0
06ZDJY@01fZD00<006ZDJY@096ZD0`0027oo00<007ooOol07Woo00000`00Oomoo`07Ool3000DOol0
0`00CQI>5P1gCQH30007Ool00`000100400?01000`00JYAZU008JY@00`00JYAZU00VJY@20007Ool0
0`00Oomoo`0MOol00003001oogoo00Eoo`8001Moo`03001>5ThF07A>5P<000]oo`030000400@00h0
4003001ZU6ZD00UZU003001ZU6ZD02MZU08000Ioo`03001oogoo01aoo`0000<007ooOol00Woo0`00
6Goo00<004hFCQH0LDhF0`003Woo00<0000@01003P0@00<006ZDJY@02VZD00<006ZDJY@0:6ZD0P00
1Goo00<007ooOol06goo00000`00Ool00002000LOol00`00CQI>5P1]CQH4000AOol00`000100400>
01000`00JYAZU00;JY@00`00JYAZU00YJY@20003Ool00`00Oomoo`0KOol00080021oo`03001>5ThF
06U>5P<001Ioo`030000400@00d04003001ZU6ZD00aZU003001ZU6ZD02UZU003001oogoo009oo`03
001oogoo01Yoo`0000=oo`00Ool07goo00<004hFCQH0IThF0`006Goo00<0000@01003@0@00<006ZD
JY@036ZD00<006ZDJY@0:VZD00<007ooOol00Woo00<007ooOol06Goo0002Ool00`00Oomoo`0MOol0
0`00CQI>5P1SCQH3000LOol00`000100400=01000`00JYAZU00=JY@00`00JYAZU00YJY@00`00Oomo
o`03Ool00`00Oomoo`0HOol000=oo`03001oogoo01eoo`03001>5ThF05m>5P<0021oo`030000400@
00`04003001ZU6ZD00iZU003001ZU6ZD02QZU003001oogoo00=oo`03001oogoo01Qoo`0017oo00<0
07ooOol077oo00<004hFCQH0G4hF0`008goo00<0000@0100300@00<006ZDJY@03fZD00<006ZDJY@0
9fZD00<007ooOol017oo00<007ooOol05goo0005Ool2000LOol00`00CQI>5P1ICQH3000VOol00`00
0100400<01000`00JYAZU00@JY@00`00JYAZU00WJY@00`00Oomoo`04Ool00`00Oomoo`0FOol000Mo
o`03001oogoo01Uoo`03001>5ThF05I>5P<002Uoo`030000400@00`04003001ZU6ZD011ZU003001Z
U6ZD02MZU003001oogoo00Eoo`03001oogoo01Eoo`0027oo00<007ooOol06Goo00<004hFCQH0DThF
0`00;Goo00<0000@01002`0@00<006ZDJY@04FZD00<006ZDJY@09VZD00<007ooOol01Goo00<007oo
Ool05Goo0009Ool00`00Oomoo`0HOol00`00CQI>5P1?CQH4000_Ool00`000100400;01000`00JYAZ
U00BJY@00`00JYAZU00VJY@00`00Oomoo`05Ool00`00Oomoo`0DOol000Yoo`03001oogoo01Moo`03
001>5ThF04a>5P<000AZU003001oogoo02aoo`030000400@00/04003001ZU6ZD01=ZU003001ZU6ZD
02EZU003001oogoo00Ioo`03001oogoo01=oo`002goo00<007ooOol05goo00<004hFCQH0B4hF0`00
1fZD00<007ooOol0;Goo00<0000@01002P0@00<006ZDJY@056ZD00<006ZDJY@096ZD00<007ooOol0
1goo00<007ooOol04Woo000<Ool00`00Oomoo`0FOol00`00CQI>5P15CQH3000:JY@00`00Oomoo`0]
Ool00`000100400:01000`00JYAZU00EJY@00`00JYAZU00TJY@00`00Oomoo`06Ool00`00Oomoo`0B
Ool000eoo`03001oogoo01Eoo`03001>5ThF049>5P<000iZU003001oogoo02aoo`030000400@00X0
4003001ZU6ZD01EZU003001ZU6ZD02AZU003001oogoo00Moo`03001oogoo015oo`003Woo00<007oo
Ool057oo00<004hFCQH0?dhF0`004FZD00<007ooOol0;7oo00<0000@01002P0@00<006ZDJY@05VZD
00<006ZDJY@08fZD00<007ooOol027oo00<007ooOol047oo000?Ool2000EOol00`00CQI>5P0kCQH3
000DJY@00`00Oomoo`0]Ool00`000100400901000`00JYAZU00GJY@00`00JYAZU00RJY@00`00Oomo
o`09Ool00`00Oomoo`0?Ool0015oo`03001oogoo019oo`03001>5ThF03Q>5P<001MZU003001oogoo
02eoo`030000400@00T04003001ZU6ZD01QZU003001ZU6ZD029ZU003001oogoo00Qoo`03001oogoo
00moo`004Woo00<007ooOol04Goo00<004hFCQH0=DhF0`006fZD00<007ooOol0;7oo00<0000@0100
2@0@00<006ZDJY@06FZD00<006ZDJY@08FZD00<007ooOol02Goo00<007ooOol03Woo000COol00`00
Oomoo`0AOol00`00CQI>5P0aCQH3000NJY@00`00Oomoo`0]Ool00`000100400801000`00JYAZU00J
JY@00`00JYAZU00PJY@00`00Oomoo`0:Ool00`00Oomoo`0=Ool001Aoo`03001oogoo011oo`03001>
5ThF02i>5P<0025ZU003001oogoo02eoo`030000400@00P04003001ZU6ZD01YZU003001ZU6ZD025Z
U003001oogoo00Yoo`03001oogoo00aoo`005Goo00<007ooOol03goo00<004hFCQH0:dhF0`009FZD
00<007ooOol0;7oo00<0000@0100200@00<006ZDJY@06fZD00<006ZDJY@086ZD00<007ooOol02Woo
00<007ooOol037oo000FOol00`00Oomoo`0>Ool00`00CQI>5P0XCQH3000XJY@00`00Oomoo`0/Ool0
0`000100400801000`00JYAZU00LJY@00`00JYAZU00OJY@00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
01Moo`03001oogoo00ioo`03001>5ThF02A>5P<002]ZU003001oogoo02]oo`<000T04003001ZU6ZD
01eZU003001ZU6ZD01mZU003001oogoo00]oo`03001oogoo00Yoo`0067oo00<007ooOol03Goo00<0
04hFCQH084hF1000;VZD00<007ooOol0:7oo0`000ThF00<0000@01001`0@00<006ZDJY@07VZD00<0
06ZDJY@07VZD00<007ooOol037oo00<007ooOol02Goo000IOol2000=Ool00`00CQI>5P0MCQH3000c
JY@00`00Oomoo`0TOol30005CQH00`000100400701000`00JYAZU00NJY@00`00JYAZU00NJY@00`00
Oomoo`0<Ool00`00Oomoo`09Ool001]oo`03001oogoo00Yoo`03001>5ThF01Y>5P<003IZU003001o
ogoo021oo`@000U>5P030000400@00H04003001ZU6ZD01mZU003001ZU6ZD01eZU003001oogoo00eo
o`03001oogoo00Qoo`0077oo00<007ooOol02Woo00<004hFCQH05ThF0`00>FZD00<007ooOol07Goo
0`003DhF00<0000@01001P0@00<006ZDJY@086ZD00<006ZDJY@07FZD00<007ooOol03Goo00<007oo
Ool01goo000MOol00`00Oomoo`09Ool00`00CQI>5P0CCQH3000mJY@00`00Oomoo`0IOol3000@CQH0
0`000100400601000`00JYAZU00QJY@00`00JYAZU00LJY@00`00Oomoo`0>Ool00`00Oomoo`06Ool0
01ioo`03001oogoo00Qoo`03001>5ThF011>5P<0041ZU003001oogoo01Ioo`<001A>5P030000400@
00D04003001ZU6ZD029ZU003001ZU6ZD01]ZU003001oogoo00ioo`03001oogoo00Ioo`007goo00<0
07ooOol027oo00<004hFCQH034hF0`00@fZD00<007ooOol04goo0`005dhF00<0000@01001@0@00<0
06ZDJY@08fZD00<006ZDJY@06fZD00<007ooOol03Goo0P001goo000POol00`00Oomoo`07Ool00`00
CQI>5P09CQH30017JY@00`00Oomoo`0?Ool3000JCQH00`000100400501000`00JYAZU00SJY@00`00
JYAZU00KJY@00`00Oomoo`09Ool400000goo001oo`06Ool0025oo`03001oogoo00Ioo`03001>5ThF
00I>5P<004YZU003001oogoo00]oo`@001e>5P030000400@00D04003001ZU6ZD02AZU003001ZU6ZD
01YZU003001oogoo00Ioo`<000Eoo`03001oogoo00Eoo`008Woo00<007ooOol01Goo00<004hFCQH0
0dhF0`00CFZD00<007ooOol027oo0`008ThF00<0000@0100100@00<006ZDJY@09FZD00<006ZDJY@0
6FZD00<007ooOol00goo0`0027oo00<007ooOol01Goo000SOol20006Ool00`00CQH00002001@JY@0
0`00Oomoo`05Ool3000UCQH00`000100400401000`00JYAZU00VJY@00`00JYAZU00IJY@5000;Ool0
0`00Oomoo`05Ool002Eoo`03001oogoo00=oo`8005AZU004001oogooOol3000XCQH00`0001004004
01000`00JYAZU00WJY@00`00JYAZU00HJY@00`00Oomoo`0>Ool00`00Oomoo`04Ool002Ioo`03001o
ogoo00Aoo`80059ZU0@002a>5P030000400@00<04003001ZU6ZD02QZU003001ZU6ZD01MZU003001o
ogoo00ioo`03001oogoo00Aoo`009goo00<007ooOol01Goo0`00CfZD00<004hFCQH0;DhF00<0000@
01000`0@00<006ZDJY@0:6ZD00<006ZDJY@066ZD00<007ooOol03Goo00<007ooOol017oo000XOol0
0`00Oomoo`07Ool3001=JY@00`00CQI>5P0/CQH00`000100400301000`00JYAZU00YJY@00`00JYAZ
U00GJY@00`00Oomoo`0=Ool00`00Oomoo`04Ool002Uoo`03001oogoo00Uoo`8004]ZU003001>5ThF
02a>5P030000400@00<04003001ZU6ZD02YZU003001ZU6ZD01IZU003001oogoo00eoo`03001oogoo
00Aoo`00:Woo00<007ooOol02Woo0`00B6ZD00<004hFCQH0;DhF00<0000@01000P0@00<006ZDJY@0
:fZD00<006ZDJY@05VZD00<007ooOol037oo00<007ooOol017oo000[Ool00`00Oomoo`0<Ool30015
JY@00`00CQI>5P0]CQH00`000100400201000`00JYAZU00/JY@00`00JYAZU00EJY@00`00Oomoo`0<
Ool00`00Oomoo`04Ool002aoo`03001oogoo00ioo`8004AZU003001>5ThF02a>5P030000400@0080
4003001ZU6ZD02aZU003001ZU6ZD01EZU003001oogoo00aoo`03001oogoo00Aoo`00;Goo0P0047oo
0`00@FZD00<004hFCQH0;DhF00D0000@0100400002mZU003001ZU6ZD01AZU003001oogoo00aoo`03
001oogoo00Aoo`00;goo00<007ooOol047oo0`00?VZD00<004hFCQH0;DhF00D0000@01004000031Z
U003001ZU6ZD01AZU003001oogoo00]oo`03001oogoo00Aoo`00<7oo00<007ooOol04Woo0P00?FZD
00<004hFCQH0;4hF00D0000@01004000035ZU003001ZU6ZD01=ZU003001oogoo00aoo`03001oogoo
00=oo`00<Goo00<007ooOol04goo0`00>VZD00<004hFCQH0;4hF00D0000@01004000039ZU003001Z
U6ZD019ZU003001oogoo00aoo`03001oogoo00=oo`00<Woo00<007ooOol05Goo0`00=fZD00<004hF
CQH0;DhF00@0000@010003=ZU003001ZU6ZD019ZU003001oogoo00]oo`03001oogoo00=oo`00<goo
00<007ooOol05goo0P00=FZD00<004hFCQH0;DhF00@0000@010003=ZU003001ZU6ZD019ZU003001o
ogoo00]oo`03001oogoo00=oo`00=7oo00<007ooOol067oo0`00<fZD00<004hFCQH0;4hF00@0000@
010003AZU003001ZU6ZD015ZU003001oogoo00]oo`03001oogoo00=oo`00=Goo00<007ooOol06Woo
0`00<6ZD00<004hFCQH0;DhF00<0000@0000=FZD00<006ZDJY@04FZD00<007ooOol02Woo00<007oo
Ool00goo000fOol00`00Oomoo`0LOol2000^JY@00`00CQI>5P0]CQH00`000100000fJY@00`00JYAZ
U00@JY@00`00Oomoo`0:Ool00`00Oomoo`03Ool003Moo`03001oogoo01eoo`<002aZU003001>5ThF
02a>5P030000400003MZU003001ZU6ZD00mZU003001oogoo00Yoo`03001oogoo00=oo`00>7oo0P00
87oo0`00:FZD00<004hFCQH0;DhF0P00>6ZD00<006ZDJY@03VZD00<007ooOol02Woo00<007ooOol0
0goo000jOol00`00Oomoo`0POol2000WJY@00`00CQI>5P0]CQH2000hJY@00`00JYAZU00?JY@00`00
Oomoo`0:Ool00`00Oomoo`02Ool003]oo`03001oogoo025oo`<002AZU003001>5ThF02e>5P8003UZ
U003001ZU6ZD00iZU003001oogoo00Yoo`03001oogoo009oo`00?7oo00<007ooOol08goo0`008VZD
00<004hFCQH0;4hF0P00>VZD00<006ZDJY@03FZD00<007ooOol02Woo00<007ooOol00Woo000mOol0
0`00Oomoo`0UOol2000PJY@00`00CQI>5P0]CQH00`00JYAZU00iJY@00`00JYAZU00=JY@00`00Oomo
o`09Ool00`00Oomoo`02Ool003ioo`03001oogoo02Ioo`<001eZU003001>5ThF02e>5P8003]ZU003
001ZU6ZD00aZU003001oogoo00Uoo`03001oogoo009oo`00?goo00<007ooOol0:7oo0`006fZD00<0
04hFCQH0;ThF0P00>FZD00<006ZDJY@036ZD00<007ooOol02Goo00<007ooOol00Woo0010Ool00`00
Oomoo`0ZOol2000IJY@00`00CQI>5P0`CQH3000gJY@00`00JYAZU00<JY@00`00Oomoo`08Ool00`00
Oomoo`02Ool0045oo`03001oogoo02]oo`<001IZU003001>5ThF03=>5P8003IZU003001ZU6ZD00]Z
U003001oogoo00Qoo`03001oogoo009oo`00@Woo0P00;Woo0`004fZD00<004hFCQH0=DhF0`00=6ZD
00<006ZDJY@02VZD00<007ooOol027oo00<007ooOol00Woo0014Ool00`00Oomoo`0^Ool2000BJY@0
0`00CQI>5P0gCQH2000cJY@00`00JYAZU009JY@00`00Oomoo`08Ool00`00Oomoo`02Ool004Eoo`03
001oogoo02moo`<000mZU003001>5ThF03U>5P<0035ZU003001ZU6ZD00UZU003001oogoo00Qoo`03
001oogoo005oo`00AWoo00<007ooOol0<Goo0`0036ZD00<004hFCQH0?4hF0P00;fZD00<006ZDJY@0
2FZD00<007ooOol027oo00<007ooOol00Goo0017Ool00`00Oomoo`0cOol2000;JY@00`00CQI>5P0m
CQH3000]JY@00`00JYAZU008JY@00`00Oomoo`08Ool00`00Oomoo`01Ool004Qoo`03001oogoo03=o
o`@000QZU003001>5ThF041>5P<002]ZU003001ZU6ZD00QZU003001oogoo00Moo`03001oogoo005o
o`00BGoo00<007ooOol0<Woo00@0000>00h03P<000EZU003001>5ThF04=>5P8002YZU003001ZU6ZD
00MZU003001oogoo00Moo`03001oogoo005oo`00BWoo00<007ooOol0<Goo00<0000>00h0100>0P00
0fZD00<004hFCQH0ADhF0`00:6ZD00<006ZDJY@01VZD00<007ooOol01goo00<007ooOol00Goo001;
Ool00`00Oomoo`0aOol00`0000h03P0500h300000fZD001>5P18CQH2000WJY@00`00JYAZU005JY@0
0`00Oomoo`07Ool00`00Oomoo`01Ool004aoo`80035oo`0300003P0>00P03P8004]>5P<002AZU003
001ZU6ZD00IZU003001oogoo00Ioo`03001oogoo005oo`00CWoo00<007ooOol0;Woo00<0000>00h0
2@0>00<004hFCQH0C4hF0P008fZD00<006ZDJY@01FZD00<007ooOol01Woo00<007ooOol00Goo001?
Ool00`00Oomoo`0^Ool00`0000h03P0800h00`00CQI>5P1>CQH3000QJY@00`00JYAZU004JY@00`00
Oomoo`07Ool10001Ool1Ool0051oo`03001oogoo02eoo`0300003P0>00P03P03001>5ThF055>5P80
021ZU003001ZU6ZD00AZU003001oogoo00Ioo`40005oo`5oo`00DGoo00<007ooOol0;7oo00<0000>
00h0200>00<004hFCQH0DdhF0`007VZD00<006ZDJY@00fZD00<007ooOol01Woo0@000Goo0Goo001B
Ool00`00Oomoo`0[Ool00`0000h03P0800h00`00CQI>5P1FCQH2000MJY@00`00JYAZU002JY@00`00
Oomoo`06Ool10001Ool1Ool005=oo`03001oogoo02]oo`0300003P0>00L03P03001>5ThF05Q>5P<0
01YZU003001ZU6ZD00=ZU003001oogoo00Eoo`40005oo`5oo`00E7oo00<007ooOol0:Woo00<0000>
00h0200>00<004hFCQH0FThF0P006FZD00<006ZDJY@00VZD00<007ooOol01Goo0@000Goo0Goo001E
Ool00`00Oomoo`0YOol00`0000h03P0800h00`00CQI>5P1LCQH3000GJY@01@00JYAZU6ZD00001goo
0@000Goo0Goo001FOol2000ZOol00`0000h03P0700h00`00CQI>5P1OCQH2000FJY@01000JYAZU000
1goo0@000Goo0Goo001HOol00`00Oomoo`0WOol00`0000h03P0700h00`00CQI>5P1QCQH3000DJY@0
1000JYAZU0001Woo0@000Goo0Goo001IOol00`00Oomoo`0VOol00`0000h03P0700h00`00CQI>5P1T
CQH2000BJY@01000JYAZU0001goo0@000Goo001JOol00`00Oomoo`0UOol00`0000h03P0700h00`00
CQI>5P1VCQH3000@JY@00`00JY@00007Ool10001Ool005]oo`03001oogoo02Eoo`0300003P0>00H0
3P03001>5ThF06U>5P<000iZU003001ZU00000Ioo`40005oo`00G7oo00<007ooOol097oo00<0000>
00h01P0>00<004hFCQH0K4hF0P003FZD0P001Woo0@000Goo001MOol00`00Oomoo`0SOol00`0000h0
3P0600h00`00CQI>5P1^CQH3000;JY@00`00Oomoo`04Ool10001Ool005ioo`03001oogoo02=oo`03
00003P0>00D03P03001>5ThF075>5P8000YZU003001oogoo00=oo`40005oo`00Ggoo00<007ooOol0
8Woo00<0000>00h01@0>00<004hFCQH0LdhF0`001fZD00<007ooOol00goo0@000Goo001POol00`00
Oomoo`0QOol00`0000h03P0500h00`00CQI>5P1fCQH20005JY@20004Ool10001Ool0065oo`80029o
o`0300003P0>00@03P03001>5ThF07Q>5P<0009ZU003001oo`0000=oo`40005oo`00Hgoo00<007oo
Ool07goo00<0000>00h0100>00<004hFCQH0NdhF0P0000AZU000Ool0009oo`40005oo`00I7oo00<0
07ooOol07Woo00<0000>00h01@0>00<004hFCQH0O4hF0P000Woo00<007ooOol00@00001UOol00`00
Oomoo`0MOol00`0000h03P0500h00`00CQI>5P1hCQH40005Ool10001Ool1000006Ioo`03001oogoo
01eoo`0300003P0>00@03P03001>5ThF07A>5P@000Uoo`40005oo`400000Igoo00<007ooOol077oo
00<0000>00h0100>00<004hFCQH0LDhF0`003Woo0P00001XOol00`00Oomoo`0KOol00`0000h03P04
00h00`00CQI>5P1]CQH4000AOol2000006Uoo`03001oogoo01]oo`0300003P0>00<03P03001>5ThF
06U>5P@0015oo`@0009oo`00JWoo00<007ooOol06Woo00<0000>00h00`0>00<004hFCQH0IDhF1000
4Goo10001Woo001[Ool2000JOol00`0000h03P0300h00`00CQI>5P1RCQH3000AOol4000:Ool006eo
o`03001oogoo01Moo`0300003P0>00<03P03001>5ThF05i>5P@0015oo`<000ioo`00KWoo00<007oo
Ool05goo00<0000>00h00P0>00<004hFCQH0FThF10004Goo10004Goo001_Ool00`00Oomoo`0FOol0
0`0000h03P0200h00`00CQI>5P1GCQH3000AOol4000EOol0071oo`03001oogoo01Eoo`0300003P0>
00803P03001>5ThF05=>5P@0011oo`@001Uoo`00LGoo00<007ooOol05Goo00D0000>00h03P00055>
5P@0011oo`@001eoo`00LWoo00<007ooOol057oo00D0000>00h03P0004e>5P@0015oo`<0025oo`00
Lgoo00<007ooOol04goo00<0000>00h00P0>00<004hFCQH0AdhF0`004Goo100097oo001dOol00`00
Oomoo`0BOol00`0000h03P0200h00`00CQI>5P13CQH4000@Ool4000XOol007Eoo`8001=oo`050000
3P0>00h00011CQH4000@Ool4000/Ool007Moo`03001oogoo011oo`0500003P0>00h0000nCQH3000A
Ool3000`Ool007Qoo`03001oogoo00moo`0500003P0>00h0000jCQH4000@Ool4000cOol007Uoo`03
001oogoo00moo`0400003P0>000fCQH4000@Ool4000gOol007Yoo`03001oogoo00ioo`0400003P0>
000cCQH3000@Ool4000kOol007]oo`03001oogoo00eoo`0400003P0>000_CQH4000@Ool3000oOol0
07aoo`03001oogoo00eoo`0300003P0002]>5P@0011oo`@0049oo`00OGoo00<007ooOol037oo00<0
000>00009dhF100047oo1000AWoo001nOol00`00Oomoo`0;Ool00`0000h0000TCQH3000@Ool4001:
Ool007moo`8000]oo`0300003P00021>5P@000moo`@004ioo`00PGoo00<007ooOol02Goo0P0074hF
100047oo0`00DWoo0022Ool00`00Oomoo`08Ool2000ICQH3000@Ool4001EOol008=oo`03001oogoo
00Moo`0300003P0001A>5P@000moo`@005Uoo`00Q7oo00<007ooOol01goo0P0044hF10003goo1000
GGoo0025Ool00`00Oomoo`06Ool2000<CQH4000@Ool3001QOol008Ioo`03001oogoo00Eoo`8000U>
5P<0011oo`@006Aoo`00Qgoo00<007ooOol017oo0P001DhF10003goo1000J7oo0028Ool00`00Oomo
o`04Ool00`00CQH00003000?Ool4001/Ool008Uoo`8000Aoo`8000moo`@0071oo`00Rgoo00D007oo
Oomoo`0000eoo`<007Aoo`00S7oo00@007ooOol000Uoo`@007Moo`00SGoo00<007oo00001Goo1000
Ngoo002>Ool200000goo00000002001oOol008moo`8008=oo`00\
\>"],
  ImageRangeCache->{{{0, 275}, {257, 0}} -> {-4.65619*^-06, 0.0171198, 
  0.00338632, 0.00338632}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The same list of points can be revolved about an axis specified on ",
  StyleBox["body2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a revolution of the hourglass graphic. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(bdgraph = 
      Graphics3D[{
          Revolve[pntlist, Line[body2, 0, {0, 1, 0}], 8, 
            Angle \[Rule] \[Pi]]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] 0, Z2 \[Rule] 0, Eo2 \[Rule] 1, 
          Ei2 \[Rule] 0, Ej2 \[Rule] 0, Ek2 \[Rule] 0}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .82963 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-016 1.0137 -0.0576173 1.0137 [
[ 0 0 0 0 ]
[ 1 .82963 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.04295 .26772 m
0 .59252 L
s
0 .59252 m
.29964 .82963 L
s
.29964 .82963 m
.3151 .52592 L
s
.3151 .52592 m
.04295 .26772 L
s
.75156 0 m
.95924 .32134 L
s
.95924 .32134 m
1 .64219 L
s
1 .64219 m
.77731 .34107 L
s
.77731 .34107 m
.75156 0 L
s
.04295 .26772 m
0 .59252 L
s
0 .59252 m
.77731 .34107 L
s
.77731 .34107 m
.75156 0 L
s
.75156 0 m
.04295 .26772 L
s
.3151 .52592 m
.95924 .32134 L
s
.95924 .32134 m
1 .64219 L
s
1 .64219 m
.29964 .82963 L
s
.29964 .82963 m
.3151 .52592 L
s
0 0 m
1 0 L
1 .82963 L
0 .82963 L
closepath
clip
newpath
.5 Mabswid
.62471 .72753 m .40369 .57756 L .50042 .48729 L closepath p .564 .354 .554 r
F P
0 g
s
.35272 .50715 m .42346 .44117 L .50042 .48729 L p .855 .96 .874 r
F P
0 g
s
.50042 .48729 m .40369 .57756 L .35272 .50715 L p .855 .96 .874 r
F P
0 g
s
.62471 .72753 m .50042 .48729 L .61586 .42972 L closepath p .564 .354 .554 r
F P
0 g
s
.61586 .42972 m .50042 .48729 L .42346 .44117 L p .695 .938 .963 r
F P
0 g
s
.62471 .72753 m .33675 .69026 L .40369 .57756 L closepath p .564 .354 .554 r
F P
0 g
s
.30345 .58854 m .35272 .50715 L .40369 .57756 L p .951 .945 .733 r
F P
0 g
s
.40369 .57756 m .33675 .69026 L .30345 .58854 L p .951 .945 .733 r
F P
0 g
s
.42346 .44117 m .50685 .39879 L .61586 .42972 L p .695 .938 .963 r
F P
0 g
s
.62471 .72753 m .61586 .42972 L .73699 .41293 L closepath p .564 .354 .554 r
F P
0 g
s
.73699 .41293 m .61586 .42972 L .50685 .39879 L p .377 .812 .96 r
F P
0 g
s
.62471 .72753 m .30878 .81284 L .33675 .69026 L closepath p .564 .354 .554 r
F P
0 g
s
.2826 .67532 m .30345 .58854 L .33675 .69026 L p .978 .857 .47 r
F P
0 g
s
.33675 .69026 m .30878 .81284 L .2826 .67532 L p .978 .857 .47 r
F P
0 g
s
.59255 .38607 m .51446 .12976 L p .64908 .37057 L .442 .498 .821 r
F P
0 g
s
.59255 .38607 m .73699 .41293 L p .53899 .40076 L .377 .812 .96 r
F P
0 g
s
.62471 .72753 m .73699 .41293 L .84862 .44208 L closepath p .564 .354 .554 r
F P
0 g
s
.84862 .44208 m .73699 .41293 L .59255 .38607 L p .239 0 0 r
F P
0 g
s
.66906 .40633 m .84862 .44208 L p .62784 .39379 L .239 0 0 r
F P
0 g
s
.59255 .38607 m .66906 .40633 L p .62784 .39379 L .239 0 0 r
F P
0 g
s
.62471 .72753 m .84862 .44208 L .93378 .51763 L closepath p .564 .354 .554 r
F P
0 g
s
.93378 .51763 m .84862 .44208 L .66906 .40633 L p .721 .212 .015 r
F P
0 g
s
.66906 .40633 m .63369 .15213 L p .71294 .41966 L .171 .281 .736 r
F P
0 g
s
.72457 .45894 m .93378 .51763 L p .70512 .42149 L .721 .212 .015 r
F P
0 g
s
.66906 .40633 m .72457 .45894 L p .70512 .42149 L .721 .212 .015 r
F P
0 g
s
.62471 .72753 m .93378 .51763 L .97581 .63272 L closepath p .564 .354 .554 r
F P
0 g
s
.97581 .63272 m .93378 .51763 L .72457 .45894 L p .847 .496 .387 r
F P
0 g
s
.72457 .45894 m .74863 .53818 L .97581 .63272 L p .847 .496 .387 r
F P
0 g
s
.72457 .45894 m .7223 .22634 L p .74531 .49887 L 0 0 .419 r
F P
0 g
s
.74863 .53818 m .72457 .45894 L p .74531 .49887 L 0 0 .419 r
F P
0 g
s
.72457 .45894 m .66906 .40633 L p .71294 .41966 L .171 .281 .736 r
F P
0 g
s
.66906 .40633 m .59255 .38607 L p .64908 .37057 L .442 .498 .821 r
F P
0 g
s
.50685 .39879 m .59255 .38607 L p .53899 .40076 L .377 .812 .96 r
F P
0 g
s
.40233 .59865 m .39265 .64293 L .62471 .72753 L closepath p .833 .609 .599 r
F P
0 g
s
.42727 .55657 m .40233 .59865 L .62471 .72753 L closepath p .802 .648 .691 r
F P
0 g
s
.46379 .52249 m .42727 .55657 L .62471 .72753 L closepath p .754 .658 .755 r
F P
0 g
s
.50685 .5011 m .46379 .52249 L .62471 .72753 L closepath p .687 .644 .801 r
F P
0 g
s
.55052 .49556 m .50685 .5011 L .62471 .72753 L closepath p .586 .596 .829 r
F P
0 g
s
.58853 .5071 m .55052 .49556 L .62471 .72753 L closepath p .421 .49 .824 r
F P
0 g
s
.61502 .53461 m .58853 .5071 L .62471 .72753 L closepath p .116 .247 .723 r
F P
0 g
s
.62542 .57443 m .61502 .53461 L .62471 .72753 L closepath p 0 0 .347 r
F P
0 g
s
.14551 .32825 m .25538 .22596 L .42346 .44117 L p .752 .655 .753 r
F P
0 g
s
.42346 .44117 m .35272 .50715 L .14551 .32825 L p .752 .655 .753 r
F P
0 g
s
.50685 .39879 m .42346 .44117 L .25538 .22596 L p .688 .641 .797 r
F P
0 g
s
.06537 .45245 m .14551 .32825 L .35272 .50715 L p .798 .645 .692 r
F P
0 g
s
.35272 .50715 m .30345 .58854 L .06537 .45245 L p .798 .645 .692 r
F P
0 g
s
.25538 .22596 m .38296 .15669 L .50685 .39879 L p .688 .641 .797 r
F P
0 g
s
.59255 .38607 m .50685 .39879 L .38296 .15669 L p .593 .596 .824 r
F P
0 g
s
.02552 .58531 m .06537 .45245 L .30345 .58854 L p .828 .608 .606 r
F P
0 g
s
.30345 .58854 m .2826 .67532 L .02552 .58531 L p .828 .608 .606 r
F P
0 g
s
.38296 .15669 m .51446 .12976 L .59255 .38607 L p .593 .596 .824 r
F P
0 g
s
.37141 .47348 m .42727 .55657 L .46379 .52249 L closepath p .849 .976 .87 r
F P
0 g
s
.37141 .47348 m .46379 .52249 L .50685 .5011 L closepath p .671 .946 .959 r
F P
0 g
s
.37141 .47348 m .40233 .59865 L .42727 .55657 L closepath p .949 .956 .714 r
F P
0 g
s
.25538 .22596 m .14551 .32825 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.38296 .15669 m .25538 .22596 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.14551 .32825 m .06537 .45245 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.37141 .47348 m .50685 .5011 L .55052 .49556 L closepath p .306 .783 .922 r
F P
0 g
s
.37141 .47348 m .39265 .64293 L .40233 .59865 L closepath p .954 .841 .413 r
F P
0 g
s
.37141 .47348 m .55052 .49556 L .58853 .5071 L closepath p .329 0 0 r
F P
0 g
s
.51446 .12976 m .38296 .15669 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.06537 .45245 m .02552 .58531 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.51446 .12976 m .63369 .15213 L .66906 .40633 L p .442 .498 .821 r
F P
0 g
s
.37141 .47348 m .58853 .5071 L .61502 .53461 L closepath p .742 .255 .085 r
F P
0 g
s
.37141 .47348 m .61502 .53461 L .62542 .57443 L closepath p .844 .505 .413 r
F P
0 g
s
.63369 .15213 m .51446 .12976 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.63369 .15213 m .7223 .22634 L .72457 .45894 L p .171 .281 .736 r
F P
0 g
s
.7223 .22634 m .76194 .34721 L .74863 .53818 L p 0 0 .419 r
F P
0 g
s
.7223 .22634 m .63369 .15213 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.76194 .34721 m .7223 .22634 L .37141 .47348 L closepath p .517 .285 .503 r
F P
0 g
s
.25 Mabswid
.75156 0 m
.95924 .32134 L
s
.95924 .32134 m
1 .64219 L
s
1 .64219 m
.77731 .34107 L
s
.77731 .34107 m
.75156 0 L
s
.04295 .26772 m
0 .59252 L
s
0 .59252 m
.77731 .34107 L
s
.77731 .34107 m
.75156 0 L
s
.75156 0 m
.04295 .26772 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{297.375, 246.688},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004Y0000mQ000`40O003h00OgGoo0P00BWoo003K
Ool200000goo00000019Ool00=Qoo`<000=oo`8004Uoo`00eGoo0`001Woo00<007oo0000B7oo003C
Ool20009Ool01000Oomoo`00Agoo003@Ool3000;Ool01000Oomoo`00Agoo003=Ool3000>Ool01@00
Oomoogoo0000AWoo003;Ool2000BOol01@00Oomoogoo0000AGoo0038Ool3000DOol01@00Oomoogoo
0000AGoo0035Ool3000GOol00`00Oomoo`02Ool00`00Oomoo`12Ool00<=oo`8001Yoo`03001oogoo
00=oo`03001oogoo045oo`00`7oo0`0077oo00<007ooOol00goo00<007ooOol0@Goo002mOol3000O
Ool00`00Oomoo`04Ool00`00Oomoo`10Ool00;]oo`80029oo`03001oogoo00Aoo`03001oogoo041o
o`00^7oo0`0097oo00<007ooOol01Goo00<007ooOol0?goo002eOol3000WOol00`00Oomoo`06Ool0
0`00Oomoo`0nOol00;=oo`8002Yoo`03001oogoo00Ioo`03001oogoo03ioo`00/7oo0`00;7oo00<0
07ooOol01goo00<007ooOol0?Goo002]Ool3000_Ool00`00Oomoo`08Ool00`00Oomoo`0lOol00:]o
o`8003=oo`03001oogoo00Moo`03001oogoo03aoo`00Z7oo0`00=Goo00<007ooOol027oo00<007oo
Ool0>goo002UOol3000hOol00`00Oomoo`09Ool00`00Oomoo`0jOol00:=oo`8003]oo`03001oogoo
00Uoo`03001oogoo03Yoo`00X7oo0`00?Goo00<007ooOol02Woo00<007ooOol0>Goo002MOol30010
Ool00`00Oomoo`0;Ool00`00Oomoo`0hOol009]oo`8004=oo`03001oogoo00]oo`03001oogoo03Qo
o`00V7oo0`00AGoo00<007ooOol037oo00<007ooOol0=goo002EOol30018Ool00`00Oomoo`0=Ool0
0`00Oomoo`0fOol009=oo`8004]oo`03001oogoo00eoo`03001oogoo03Ioo`00T7oo0`00CGoo00<0
07ooOol03Woo00<007ooOol0=Goo002=Ool3001@Ool00`00Oomoo`0?Ool00`00Oomoo`0dOol008]o
o`8005=oo`03001oogoo00moo`03001oogoo03Aoo`00R7oo0`00EWoo00<007ooOol03goo00<007oo
Ool0<goo0025Ool3001IOol00`00Oomoo`0@Ool00`00Oomoo`0bOol008=oo`8005aoo`03001oogoo
011oo`03001oogoo039oo`00P7oo0`00GWoo00<007ooOol04Goo00<007ooOol0<Goo001mOol3001Q
Ool00`00Oomoo`0AOol00`00Oomoo`0aOol007]oo`8006Aoo`03001oogoo019oo`03001oogoo031o
o`00N7oo0`006goo1@00AWoo00<007ooOol04goo00<007ooOol0;goo001fOol2000IOol50002@C00
0`00@C11<0050011Ool00`00Oomoo`0COol00`00Oomoo`0_Ool007=oo`<001Ioo`D000I1<0030011
<44`00I1<0D003aoo`03001oogoo01Aoo`03001oogoo02ioo`00L7oo0`0057oo1@002d4`00<0044`
@C002d4`1@00=goo00<007ooOol05Goo00<007ooOol0;Goo001^Ool2000COol4000?@C000`00@C11
<00A@C05000bOol00`00Oomoo`0EOol00`00Oomoo`0]Ool006]oo`<0011oo`D001=1<0030011<44`
01I1<0D002eoo`03001oogoo01Ioo`03001oogoo02aoo`00J7oo0`003Woo1@00644`00<0044`@C00
6d4`1@00:7oo00<007ooOol05goo00<007ooOol0:goo001VOol2000<Ool5000L@C000`00@C11<00Q
@C03000VOol00`00Oomoo`0FOol00`00Oomoo`0[Ool006=oo`<000]oo`<00251<0030011<44`0291
<0030011<00002Eoo`03001oogoo01Moo`03001oogoo02Yoo`00H7oo0`0037oo0`008T4`00<0044`
@C008T4`00@0044`@C11<08002=oo`03001oogoo01Qoo`03001oogoo02Uoo`00GWoo0P003Goo0P00
0T4`00<0044`@C00844`00<0044`@C008T4`00<0044`@C000d4`00<007ooOol087oo00<007ooOol0
67oo00<007ooOol0:Goo001KOol3000=Ool20004@C000`00@C11<00O@C000`00@C11<00R@C000`00
@C11<005@C000`00Oomoo`0OOol00`00Oomoo`0IOol00`00Oomoo`0XOol005Qoo`<000ioo`8000I1
<0030011<44`01m1<0030011<44`0251<0030011<44`00M1<003001oogoo01ioo`03001oogoo01Yo
o`03001oogoo02Moo`00EWoo0P0047oo00<0044`@C001T4`00<0044`@C007d4`00<0044`@C00844`
00<0044`@C002D4`00<007ooOol07Goo00<007ooOol06Woo00<007ooOol09goo001COol3000@Ool2
0009@C000`00@C11<00N@C000`00@C11<00P@C000`00@C11<00;@C02000MOol00`00Oomoo`0KOol0
0`00Oomoo`0VOol0051oo`<0015oo`8000]1<0030011<44`01i1<0030011<44`0211<0030011<44`
00e1<003001oogoo01Yoo`03001oogoo01aoo`03001oogoo02Eoo`00CWoo0P004Woo0P003D4`00<0
044`@C007D4`00<0044`@C00844`00<0044`@C003d4`00<007ooOol06Goo00<007ooOol077oo00<0
07ooOol09Goo001;Ool3000BOol2000?@C000`00@C11<00M@C000`00@C11<00O@C000`00@C11<00A
@C000`00Oomoo`0HOol00`00Oomoo`0MOol00`00Oomoo`0TOol004Qoo`<001Aoo`030011<44`00m1
<0030011<44`01e1<0030011<44`01i1<0030011<44`01=1<08001Qoo`03001oogoo01ioo`03001o
ogoo02=oo`00AWoo0P005Goo0P004T4`00<0044`@C00744`00<0044`@C007T4`00<0044`@C005T4`
00<007ooOol05Woo00<007ooOol07Goo00<007ooOol08goo0013Ool3000EOol2000D@C000`00@C11
<00L@C000`00@C11<00M@C000`00@C11<00H@C000`00Oomoo`0EOol00`00Oomoo`0NOol00`00Oomo
o`0ROol0041oo`<001Ioo`8001I1<0030011<44`01]1<0030011<44`01i1<0030011<44`01U1<003
001oogoo01Aoo`03001oogoo01moo`03001oogoo025oo`00?Woo0P005goo0P00644`00<0044`@C00
6d4`00<0044`@C007D4`00<0044`@C006d4`0P0057oo00<007ooOol07goo00<007ooOol08Goo000k
Ool3000GOol2000J@C000`00@C11<00K@C000`00@C11<00L@C000`00@C11<00N@C000`00Oomoo`0A
Ool00`00Oomoo`0POol00`00Oomoo`0POol003Qoo`<001Uoo`030011<44`01U1<0030011<44`01]1
<0030011<44`01a1<0030011<44`0211<003001oogoo011oo`03001oogoo021oo`03001oogoo021o
o`00=Woo0P006Woo0P00744`00<0044`@C006d4`00<0044`@C006d4`00<0044`@C008T4`00<007oo
Ool03goo00<007ooOol08Goo00<007ooOol07goo000cOol3000JOol2000N@C000`00@C11<00J@C00
0`00@C11<00L@C000`00@C11<00S@C000`00Oomoo`0>Ool00`00Oomoo`0ROol00`00Oomoo`0NOol0
031oo`<001]oo`800211<0030011<44`01Y1<0030011<44`01]1<0030011<44`02E1<08000ioo`03
001oogoo029oo`03001oogoo01ioo`00;Woo0P0077oo0P008T4`00<0044`@C006D4`00<0044`@C00
6d4`00<0044`@C00:44`00<007ooOol02goo00<007ooOol08goo00<007ooOol07Goo000[Ool3000M
Ool00`00@C11<00R@C000`00@C11<00I@C000`00@C11<00J@C000`00@C11<00Z@C000`00Oomoo`0:
Ool00`00Oomoo`0TOol00`00Oomoo`0LOol002Qoo`<001moo`8002A1<0030011<44`01U1<0030011
<44`01U1<0030011<44`02U1<0<000aoo`03001oogoo02Aoo`03001oogoo01aoo`009Woo0P008Goo
00@0044`@C0002=1<0030011<44`01Q1<0030011<44`01Y1<0030011<44`02Q1<0050011<44`@C00
000;Ool00`00Oomoo`0UOol00`00Oomoo`0KOol002=oo`<0029oo`050011<44`@C00000S@C000`00
@C11<00H@C000`00@C11<00I@C000`00@C11<00X@C000`00@C11<002@C000`00Oomoo`0:Ool00`00
Oomoo`0UOol00`00Oomoo`0JOol0021oo`<002Aoo`030011<44`00=1<0030011<44`0211<0030011
<44`01M1<0030011<44`01U1<0030011<44`02M1<08000E1<003001oogoo00Yoo`03001oogoo02Eo
o`03001oogoo01Yoo`007Woo0P009Woo00<0044`@C00144`00<0044`@C00844`00<0044`@C005d4`
00<0044`@C00644`00<0044`@C009d4`00<0044`@C001T4`00<007ooOol02Goo00<007ooOol09Woo
00<007ooOol06Goo000KOol3000WOol00`00@C11<006@C000`00@C11<00O@C000`00@C11<00G@C00
0`00@C11<00G@C000`00@C11<00V@C020009@C000`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomo
o`0HOol001Qoo`<002Uoo`030011<44`00M1<0030011<44`01m1<0030011<44`01I1<0030011<44`
01M1<0030011<44`02I1<0030011<44`00U1<003001oogoo00Uoo`03001oogoo02Moo`03001oogoo
01Qoo`005Woo0P00:Woo0P002d4`00<0044`@C007T4`00<0044`@C005T4`00<0044`@C005d4`00<0
044`@C00944`0P00344`00<007ooOol02Goo00<007ooOol0:7oo00<007ooOol05goo000COol3000[
Ool00`00@C11<00;@C000`00@C11<00N@C000`00@C11<00E@C000`00@C11<00G@C000`00@C11<00T
@C000`00@C11<00=@C000`00Oomoo`08Ool00`00Oomoo`0YOol00`00Oomoo`0FOol0011oo`<002eo
o`030011<44`00e1<0030011<44`01e1<0030011<44`01E1<0030011<44`01I1<0030011<44`02A1
<0030011<44`00i1<003001oogoo00Qoo`03001oogoo02Uoo`03001oogoo01Ioo`003Woo0P00;goo
00<0044`@C003T4`00<0044`@C007D4`00<0044`@C005D4`00<0044`@C005D4`00<0044`@C008d4`
0P004D4`00<007ooOol027oo00<007ooOol0:Woo00<007ooOol05Goo000<Ool2000`Ool00`00@C11
<00@@C000`00@C11<00L@C000`00@C11<00D@C000`00@C11<00E@C000`00@C11<00S@C000`00@C11
<00B@C000`00Oomoo`07Ool00`00Oomoo`0[Ool00`00Oomoo`0DOol000aoo`8002moo`030011<44`
0151<0030011<44`01a1<0030011<44`01A1<0030011<44`01E1<0030011<44`0251<08001E1<003
001oogoo00Moo`03001oogoo02]oo`03001oogoo01Aoo`0037oo00<007oo0000;Goo00<0044`@C00
4d4`00<0044`@C006d4`00<0044`@C004d4`00<0044`@C005D4`00<0044`@C008D4`00<0044`@C00
5D4`00<007ooOol01goo00<007ooOol0;7oo00<007ooOol04goo000<Ool01000Oomoo`00:goo00<0
044`@C00544`00<0044`@C006d4`00<0044`@C004d4`00<0044`@C00544`00<0044`@C00844`0P00
6D4`00<007ooOol01Woo00<007ooOol0;Goo00<007ooOol04Woo000;Ool00`00Oomoo`02Ool00`00
Oomoo`0WOol00`00@C11<00F@C000`00@C11<00J@C000`00@C11<00B@C000`00@C11<00D@C000`00
@C11<00P@C000`00@C11<00I@C000`00Oomoo`07Ool00`00Oomoo`0/Ool00`00Oomoo`0BOol000]o
o`03001oogoo00=oo`03001oogoo02Eoo`030011<44`01M1<0030011<44`01Y1<0030011<44`0191
<0030011<44`01=1<0030011<44`0211<0030011<44`01Y1<003001oogoo00Moo`03001oogoo02eo
o`03001oogoo015oo`002goo00<007ooOol017oo00<007ooOol08goo00<0044`@C006D4`00<0044`
@C006D4`00<0044`@C004T4`00<0044`@C004d4`00<0044`@C007T4`0P007D4`00<007ooOol01goo
00<007ooOol0;Goo00<007ooOol04Goo000;Ool00`00Oomoo`05Ool00`00Oomoo`0QOol00`00@C11
<00J@C000`00@C11<00I@C000`00@C11<00A@C000`00@C11<00C@C000`00@C11<00N@C000`00@C11
<00N@C000`00Oomoo`06Ool00`00Oomoo`0^Ool00`00Oomoo`0@Ool000]oo`03001oogoo00Ioo`03
001oogoo01moo`030011<44`01a1<0030011<44`01Q1<0030011<44`0151<0030011<44`0191<003
0011<44`01e1<0800251<003001oogoo00Ioo`03001oogoo02moo`03001oogoo00moo`002goo00<0
07ooOol01goo00<007ooOol07Goo00<0044`@C007D4`00<0044`@C00644`00<0044`@C00444`00<0
044`@C004T4`00<0044`@C007D4`00<0044`@C008D4`00<007ooOol01Woo00<007ooOol0;goo00<0
07ooOol03goo000;Ool00`00Oomoo`08Ool2000LOol00`00@C11<00O@C000`00@C11<00G@C000`00
@C11<00@@C000`00@C11<00A@C000`00@C11<00L@C02000U@C000`00Oomoo`05Ool00`00Oomoo`0`
Ool00`00Oomoo`0>Ool000]oo`03001oogoo00Yoo`03001oogoo01Moo`800291<0030011<44`01M1
<0030011<44`0111<0030011<44`0151<0030011<44`01]1<0030011<44`02E1<003001oogoo00Eo
o`03001oogoo035oo`03001oogoo00eoo`002Woo00<007ooOol037oo00<007ooOol05Goo00<0044`
@C008d4`00<0044`@C005T4`00<0044`@C003d4`00<0044`@C004D4`00<0044`@C006d4`00<0044`
@C009T4`00<007ooOol01Goo00<007ooOol0<Goo00<007ooOol03Goo000:Ool00`00Oomoo`0=Ool0
0`00Oomoo`0COol00`00@C11<00T@C000`00@C11<00F@C000`00@C11<00?@C000`00@C11<00@@C00
0`00@C11<00J@C02000Z@C000`00Oomoo`04Ool00`00Oomoo`0bOol00`00Oomoo`0<Ool000Yoo`03
001oogoo00ioo`03001oogoo015oo`030011<44`02E1<0030011<44`01E1<0030011<44`00m1<003
0011<44`0111<0030011<44`01Y1<0030011<44`02Y1<003001oogoo00Aoo`03001oogoo03=oo`03
001oogoo00]oo`002Woo00<007ooOol03goo00<007ooOol03goo00<0044`@C009d4`00<0044`@C00
544`00<0044`@C003d4`00<0044`@C003d4`00<0044`@C006D4`0P00;D4`00<007ooOol017oo00<0
07ooOol0<goo00<007ooOol02goo000:Ool00`00Oomoo`0@Ool00`00Oomoo`0=Ool00`00@C11<00X
@C000`00@C11<00D@C000`00@C11<00?@C000`00@C11<00>@C000`00@C11<00I@C000`00@C11<00^
@C000`00Oomoo`04Ool00`00Oomoo`0bOol2000<Ool000Yoo`03001oogoo015oo`03001oogoo00]o
o`030011<44`02Y1<0030011<44`01=1<0030011<44`00i1<0030011<44`00m1<0030011<44`01M1
<0800351<003001oogoo00Aoo`03001oogoo02moo`<00003Ool007oo00]oo`002Woo00<007ooOol0
4Woo00<007ooOol02Goo00<0044`@C00:d4`00<0044`@C004d4`00<0044`@C003T4`00<0044`@C00
3T4`00<0044`@C005d4`00<0044`@C00<D4`00<007ooOol017oo00<007ooOol0;7oo0`0017oo00<0
07ooOol02Woo000:Ool00`00Oomoo`0COol00`00Oomoo`07Ool01000@C000000;44`00<0044`@C00
4T4`00<0044`@C003D4`00<0044`@C003T4`00<0044`@C005d4`00<0044`@C00<T4`00<007ooOol0
17oo00<007ooOol0:Goo0`001goo00<007ooOol02Woo0009Ool00`00Oomoo`0EOol00`00Oomoo`06
Ool01@00@C11<44`0000:d4`00<0044`@C004T4`00<0044`@C003D4`00<0044`@C003D4`00<0044`
@C005T4`0P00=T4`00<007ooOol00goo00<007ooOol09Goo10002goo00<007ooOol02Goo0009Ool0
0`00Oomoo`0FOol00`00Oomoo`04Ool00`00@C11<003@C02000Z@C000`00@C11<00A@C000`00@C11
<00<@C000`00@C11<00=@C000`00@C11<00F@C000`00@C11<00f@C000`00Oomoo`03Ool00`00Oomo
o`0ROol3000?Ool00`00Oomoo`09Ool000Uoo`03001oogoo01Moo`03001oogoo009oo`030011<44`
00I1<08002Q1<0030011<44`0151<0030011<44`00a1<0030011<44`00e1<0030011<44`01A1<080
03U1<003001oogoo009oo`80025oo`<0019oo`03001oogoo00Uoo`002Goo00<007ooOol067oo00D0
07ooOomoo`0000Y1<0030011<44`02I1<0030011<44`0111<0030011<44`00a1<0030011<44`00a1
<0030011<44`01A1<0030011<44`03Y1<0@0009oo`03001oogoo01]oo`<001Eoo`03001oogoo00Uo
o`002Goo00<007ooOol06Goo00<007oo0000344`0P009T4`00<0044`@C00444`00<0044`@C002d4`
00<0044`@C00344`00<0044`@C00544`00<0044`@C00>D4`0`001Goo00<007ooOol067oo0`0067oo
00<007ooOol02Goo0009Ool00`00Oomoo`0JOol00`00@C11<00=@C000`00@C11<00T@C000`00@C11
<00?@C000`00@C11<00;@C000`00@C11<00;@C000`00@C11<00C@C02000i@C0400000`0=001oo`05
Ool00`00Oomoo`0DOol3000KOol00`00Oomoo`09Ool000Uoo`03001oogoo01Yoo`030011<44`00i1
<08002A1<0030011<44`00m1<0030011<44`00Y1<0030011<44`00]1<0030011<44`01=1<0030011
<44`03I1<0@000@03@03001oogoo00Eoo`03001oogoo011oo`<001ioo`03001oogoo00Uoo`002Goo
00<007ooOol06Goo00<0044`@C004D4`00<0044`@C008T4`00<0044`@C003T4`00<0044`@C002T4`
00<0044`@C002d4`00<0044`@C004D4`0P00=D4`1@001`0=00<007ooOol01Woo00<007ooOol02goo
10008Goo00<007ooOol02Goo0008Ool00`00Oomoo`0JOol00`00@C11<00B@C02000R@C000`00@C11
<00>@C000`00@C11<00:@C000`00@C11<00:@C000`00@C11<00A@C000`00@C11<00b@C05000200d0
0goo00d03@0500d00`00Oomoo`06Ool00`00Oomoo`08Ool3000VOol00`00Oomoo`08Ool000Qoo`03
001oogoo01Uoo`030011<44`01E1<0030011<44`0211<0030011<44`00e1<0030011<44`00U1<003
0011<44`00Y1<0030011<44`0111<0800391<0D0008E5`0300003@0=00P03@03001oogoo00Moo`03
001oogoo00Aoo`<002Uoo`03001oogoo00Qoo`0027oo00<007ooOol067oo00<0044`@C005d4`0P00
844`00<0044`@C003D4`00<0044`@C002D4`00<0044`@C002D4`00<0044`@C00444`00<0044`@C00
;d4`10001QDG00<0000=00d0200=00<007ooOol027oo00<007ooOol00`00;7oo00<007ooOol027oo
0008Ool00`00Oomoo`0HOol00`00@C11<00I@C02000O@C000`00@C11<00<@C000`00@C11<008@C00
0`00@C11<009@C000`00@C11<00@@C000`00@C11<00]@C0400095AL00`0000d03@0700d00`00Oomo
o`09Ool3000_Ool00`00Oomoo`08Ool000Qoo`03001oogoo01Moo`030011<44`01a1<0030011<44`
01a1<0030011<44`00a1<0030011<44`00Q1<0030011<44`00U1<0030011<44`00i1<08002e1<0@0
00`E5`0300003@0=00L03@03001oogoo00Ioo`<00003Ool007oo02moo`03001oogoo00Qoo`0027oo
00<007ooOol05Woo00<0044`@C007T4`0P007D4`00<0044`@C002d4`00<0044`@C00244`00<0044`
@C00244`00<0044`@C003T4`00<0044`@C00:T4`10003aDG00<0000=00d01`0=00<007ooOol00goo
0`001Goo00<007ooOol0;Goo00<007ooOol027oo0008Ool00`00Oomoo`0FOol00`00@C11<00P@C00
0`00@C11<00J@C000`00@C11<00;@C000`00@C11<007@C000`00@C11<008@C000`00@C11<00=@C02
000Z@C0400000cWj000E5`0?5AL00`0000d03@0700d00`00Oomoo`030009Ool00`00Oomoo`0/Ool0
0`00Oomoo`08Ool000Qoo`03001oogoo01Eoo`030011<44`0291<08001]1<0030011<44`00Y1<003
0011<44`00M1<0030011<44`00M1<0030011<44`00e1<0030011<44`02M1<0@000@inP03000E5aDG
00hE5`0300003@0=00L03@<000eoo`03001oogoo02]oo`03001oogoo00Qoo`001goo00<007ooOol0
5Goo00<0044`@C009D4`00<0044`@C00644`00<0044`@C002T4`00<0044`@C001T4`00<0044`@C00
1d4`00<0044`@C00344`0P009T4`1@001CWj00=oocWj000041DG00<0000=00d01`0=00<007ooOol0
3Goo00<007ooOol0;7oo00<007ooOol01goo0007Ool00`00Oomoo`0EOol00`00@C11<00V@C02000H
@C000`00@C11<00:@C000`00@C11<006@C000`00@C11<006@C000`00@C11<00<@C000`00@C11<00S
@C05000:>OX00`005ALE5`0>5AL00`0000d03@0700d00`00Oomoo`0>Ool00`00Oomoo`0[Ool00`00
Oomoo`07Ool000Moo`03001oogoo01Aoo`030011<44`02U1<0030011<44`01I1<0030011<44`00U1
<0030011<44`00E1<0030011<44`00M1<0030011<44`00]1<0030011<44`0251<0D00003<ch00000
008000TinP03000E5aDG00dE5`0300003@0=00L03@03001oogoo00moo`03001oogoo02Yoo`03001o
ogoo00Moo`001goo00<007ooOol04goo00<0044`@C00:d4`0P005T4`00<0044`@C002D4`00<0044`
@C001D4`00<0044`@C001T4`00<0044`@C002T4`0P008D4`10002C<n10001CWj00<001DG5AL03ADG
00<0000=00d01`0=00<007ooOol047oo00<007ooOol0:Goo00<007ooOol01goo0007Ool00`00Oomo
o`0COol00`00@C11<00]@C02000E@C000`00@C11<008@C000`00@C11<005@C000`00@C11<005@C00
0`00@C11<00:@C000`00@C11<00N@C04000@<ch400000cWj000E5`0>5AL00`0000d03@0700d00`00
Oomoo`0@Ool00`00Oomoo`0YOol00`00Oomoo`07Ool000Moo`03001oogoo019oo`030011<44`0311
<0030011<44`0191<0030011<44`00Q1<0030011<44`00A1<0030011<44`00E1<0030011<44`00U1
<08001i1<0@000Xc?PEoo`Pc?P8000lE5`0500003@0=00eoo`0500d00`00Oomoo`0AOol00`00Oomo
o`0XOol00`00Oomoo`07Ool000Moo`03001oogoo015oo`030011<44`0391<08001=1<0030011<44`
00M1<0030011<44`00A1<0030011<44`00A1<0030011<44`00U1<0030011<44`01]1<0@001`c?P03
000E5aDG00`E5`0500003@0=00eoo`0500d00`00Oomoo`0BOol00`00Oomoo`0WOol00`00Oomoo`07
Ool000Moo`03001oogoo015oo`030011<44`03A1<0030011<44`0111<0030011<44`00M1<0030011
<44`00=1<0030011<44`00E1<0030011<44`00M1<08001]1<0@0020c?P03000E5aDG00/E5`030000
3@0=00L03@03001oogoo01=oo`03001oogoo02Ioo`03001oogoo00Moo`001Woo00<007ooOol04Goo
00<0044`@C00=T4`0P004D4`00<0044`@C001T4`00<0044`@C000d4`00<0044`@C00144`00<0044`
@C001d4`00<0044`@C00644`100000=KgP0000000P007c<n00<001DG5AL02QDG00<0000=00d01`0=
00<007ooOol04goo00<007ooOol09goo00<007ooOol01Woo0006Ool00`00Oomoo`0@Ool00`00@C11
<00i@C000`00@C11<00>@C000`00@C11<006@C000`00@C11<003@C000`00@C11<003@C000`00@C11
<007@C000`00@C11<00E@C050008Fmh4000K<ch2000;5AL00`0000d03@0600d5000COol00`00Oomo
o`0VOol00`00Oomoo`06Ool000Ioo`03001oogoo011oo`030011<44`03Y1<08000m1<0030011<44`
00A1<0030011<44`00=1<0030011<44`00=1<0030011<44`00I1<08001E1<0D000mKgP<0010c?PP0
0099L@03000E5aDG00PE5`0300003@0=00H03@8000<L00<0015oo`03001oogoo02Eoo`03001oogoo
00Ioo`001Woo00<007ooOol03goo00<0044`@C00?D4`00<0044`@C00344`00<0044`@C00144`00<0
044`@C000d4`00<0044`@C000T4`00<0044`@C001T4`00<0044`@C004T4`1@005E_N10001C<n1`00
2dUa00<001DG5AL01aDG00<0000=00d01P0=00<005c00000100000<L000000000P003Woo00<007oo
Ool097oo00<007ooOol01Woo0006Ool00`00Oomoo`0?Ool00`00@C11<00n@C02000=@C000`00@C11
<003@C000`00@C11<002@C000`00@C11<003@C000`00@C11<004@C02000B@C04000MFmh5000CBG40
0`005ALE5`065AL00`0000d03@0600d00`00G<1L`004G<09000:Ool00`00Oomoo`0TOol00`00Oomo
o`06Ool000Ioo`03001oogoo00ioo`030011<44`0451<08000]1<0030011<44`00=1<0030011<44`
0091<0030011<44`0091<0030011<44`00A1<0030011<44`00m1<0@001mKgP<001M9L@03000E5aDG
00DE5`0300003@0=00H03@03001L`5c000UL`0L000Qoo`03001oogoo02=oo`03001oogoo00Ioo`00
1Woo00<007ooOol03Goo00<0044`@C00A44`00<0044`@C002D4`00<0044`@C000T4`00<0044`@C00
0T4`00D0044`@C11<00000E1<08000m1<0@0021KgP800099L@030019LDUa01I9L@03000E5aDG00@E
5`0300003@0=00H03@03001L`5c000eL`0L000Eoo`03001oogoo029oo`03001oogoo00Ioo`001Woo
00<007ooOol03Goo00<0044`@C00AD4`0P002D4`00<0044`@C000T4`00D0044`@C11<00000=1<003
0011<44`00=1<0030011<44`00a1<0@0025KgP8000A9L@030019LDUa01M9L@03000E5aDG00<E5`03
00003@0=00H03@03001L`5c0019L`0H0009oo`03001oogoo025oo`03001oogoo00Ioo`001Goo00<0
07ooOol03Goo00<0044`@C00B44`00<0044`@C001d4`00D0044`@C11<00000=1<0040011<44`0005
@C000`00@C11<00:@C04000RFmh20006BG400`00BG59L@0HBG400`005ALE5`025AL00`0000d03@06
00d00`00G<1L`00GG<04000TOol00`00Oomoo`05Ool000Eoo`03001oogoo00aoo`030011<44`04Y1
<08000M1<0050011<44`@C000002@C001000@C11<000144`0P002T4`10008e_N0P0024Ua00<004Ua
BG406DUa00D001DG5ALE5`0000P03@04001L`4UaBG4IG<02000SOol00`00Oomoo`05Ool000Eoo`03
001oogoo00aoo`030011<44`04a1<0030011<44`00E1<0040011<44`0002@C001000@C11<0000d4`
00<0044`@C001T4`1@0095_N0P002TUa00<004UaBG406TUa00@001DG5AL000@03@05G<003@0=00d0
0004G<000dUaG<1L`00FG<02000ROol00`00Oomoo`05Ool000Eoo`03001oogoo00]oo`P004U1<080
00E1<0060011<44`0011<0000T4`00<0044`@C000P001T4`1`008e_N0P0034Ua00<004UaBG406dUa
00<001DG0000100=00EL`00=00d03@0000IL`099LAIL`003001oogoo021oo`03001oogoo00Eoo`00
1Goo00<007ooOol02goo00<0044`@C001D4`3`00?44`00<0044`@C000d4`00L0044`0011<000@C00
0002@C000`00@C11<003@C050005Km/2000OFmh2000>BG400`00BG59L@0LBG42000800d00`00G<1L
`007G<000dUaG<1L`00CG<02000POol00`00Oomoo`05Ool000Eoo`03001oogoo00Yoo`030011<44`
01E1<0l002i1<08000=1<0040011<000@C0200000d4`00000003@C04000;Km/00`00FmiKgP0JFmh2
000@BG400`00BG59L@0LBG42000800d00`00G<1L`009G<000dUaG<1L`00BG<02000OOol00`00Oomo
o`05Ool000Eoo`03001oogoo00Yoo`030011<44`02A1<1000211<0800091<0@00004@C00044`@C04
000?Km/2000HFmh2000BBG400`00BG59L@0LBG42000800d00`00G<1L`00<G<000dUaG<1L`00@G<02
000NOol00`00Oomoo`05Ool000Eoo`03001oogoo00Yoo`030011<44`03A1<0l001=1<0030011<000
00P001A_f`03001KgU_N01=KgP8001A9L@030019LDUa01]9L@040019LDUa000600d2000@G<000dUa
G<1L`00>G<000`00G<00000MOol00`00Oomoo`05Ool000Aoo`03001oogoo00Yoo`030011<44`04A1
<0l000E1<0L00003HYP006oK01E_f`80015KgP8001I9L@030019LDUa01]9L@040019LDUa000600d0
0`00KN`00002000?G<000dUaG<1L`00=G<000`00G<00000MOol00`00Oomoo`04Ool000Aoo`03001o
ogoo00Yoo`030011<44`05=1<0d001U_f`8000eKgP8001Q9L@030019LDUa01]9L@040019LDUa0006
00d00`00KNa]k002KN`4000>G<000dUaG<1L`00;G<000`00G<00000LOol00`00Oomoo`04Ool000Ao
o`03001oogoo00Yoo`030011<44`05E1<0@00003HYP0000000X001E_f`03001KgU_N00QKgP8001Y9
L@030019LDUa01Y9L@030019LDUa0099L@0300003@0=00<03@03001]k6g/00I]k0@000aL`003BG5L
`5c000YL`003001L`00001]oo`03001oogoo00Aoo`0017oo00<007ooOol02Woo00<0044`@C00DT4`
100016:H0P0000=_n`0000003P003foK0P001U_N0P007DUa00<004UaBG406DUa00<004UaBG400TUa
00<0000=00d00`0=00<006g/KN`02Vg/0`005Uc000<005c0G<000P006Goo00<007ooOol017oo0004
Ool00`00Oomoo`09Ool00`00@C11<01?@C050007HYP30002Ko/400000fh=000000020002G@8;0009
Km/20002Fmh2000OBG400`00BG59L@0IBG400`00BG59L@02BG400`0000d03@0300d00`00KNa]k00=
KN`4000:G<000dUaG<1L`006G<001@00G<1L`5c0000067oo00<007ooOol017oo0004Ool00`00Oomo
o`09Ool00`00@C11<01<@C05000:HYP200000g_F001_n`02Ko/50002KPd40005G@8<0003Km/2000Q
BG400`00BG59L@0HBG400`00BG59L@03BG400`0000d03@0300d00`00KNa]k00AKN`3000AG<001@00
G<1L`5c000005goo00<007ooOol017oo0004Ool00`00Oomoo`09Ool00`00@C11<019@C040002IYH0
0`00HYQRV008HYP01@00Km/007_F00001Fok00<005ONEmh00P0016h=10001ed23@007dUa00<004Ua
BG4064Ua00<004UaBG4014Ua00<0000=00d00P0=00<006g/KN`056g/100025c000=9LEc0G<000ec0
00D005c0G<1L`00001Ioo`03001oogoo00Aoo`0017oo00<007ooOol027oo00<0044`@C00Ad4`1000
1VJF00<006:HHYP01V:H00@006oKKm/0009keP03001_nfok00=_n`80009GgP<000E^3@@000YM0Ph0
01M9L@030019LDUa01M9L@030019LDUa00E9L@0600003@0=KN`03@006Vg/10001Uc000E9LEc0G<1L
`00000AL`003001oogoo01=oo`03001oogoo00Aoo`000goo00<007ooOol02Goo00<0044`@C00A44`
10002VJF0P001F:H00@006oKKm]_f`800003NmH006ok00I_n`8000=GgP8000M^3@@000aM0PH0008X
00D00199L@030019LDUa01M9L@030019LDUa00E9L@0600003@0=KN`03@007Vg/0`0025c000<005c0
G<000Uc000<007ooOol04goo00<007ooOol00goo0003Ool00`00Oomoo`09Ool00`00@C11<011@C04
000?IYH01@00HYQRV6:H000016oK0P000W_F00<006okKo/01Vok0P000eON0`0026h=10003Ud22`00
3TUa00<004UaBG405dUa00<004UaBG401TUa00D0000=KN`03@00025]k0@000AL`003BG4005c000=L
`003001oogoo019oo`03001oogoo00=oo`000goo00<007ooOol027oo00<0044`@C00?d4`10004fJF
00<006:H00001FoK0P000g_F00<006okKo/01fok0P0015ON0P002Vh=10004Ed220002TUa00<004Ua
BG405TUa00<004UaBG401dUa00D0000=00d03@0002E]k0@0009L`003001L`5c0009L`080019oo`03
001oogoo00=oo`000goo00<007ooOol027oo00<0044`@C00?44`10005fJF00<006oKKm/016oK0P00
0g_F00<006okKo/02Fok00<005ONEmh00eON0`002fh=10004ed2100024Ua00<004UaBG405TUa00<0
04UaBG401dUa00D0000=00d03@0002U]k0<000IL`003001oogoo00moo`03001oogoo00=oo`000goo
00<007ooOol027oo00<0044`@C00>D4`10006FJF00<007_G00001FoK00<007]=00000g_F00<006ok
Ko/02Fok0P001UON0P003Fh=10004ed200<004UaBG401DUa00<004UaBG405TUa00<004UaBG4024Ua
00@0000=00d002a]k0@000=L`003001oogoo00ioo`03001oogoo00=oo`000goo00<007ooOol01goo
00<0044`@C00=T4`1@0076JF00<007_G00001FoK00<007]=000017_F00<006okKo/02Vok0P001UON
0`003Vh=100045d200<004UaBG4014Ua00<004UaBG405DUa00<004UaBG402DUa00<0000=0000;Vg/
00<006g/KN`01@003goo00<007ooOol00goo0003Ool00`00Oomoo`07Ool00`00@C11<00c@C04000O
IYH01@00NmMkeg_G00001FoK0P0017_F00<006okKo/036ok0P001EON100046h=10003Ed200<004Ua
BG400dUa00<004UaBG405DUa00<004UaBG402DUa00<0000=0000;fg/00<006g/KN`00fg/0P003Woo
00<007ooOol00goo0003Ool00`00Oomoo`07Ool00`00@C11<00`@C04000QIYH00`00NmMke`03NmL0
0`00Km]_f`02Km/20005NmH00`00Ko]_n`0=Ko/200000eON00000004EYT3000AKPd4000:G@800`00
BG59L@02BG400`00BG59L@0EBG400`00BG59L@09BG400`0000d0000_KN`00`00KNa]k004KN`00`00
Oomoo`0<Ool00`00Oomoo`03Ool0009oo`03001oogoo00Qoo`030011<44`02e1<0@002AVUP03001k
eg_G00Ake`07001_ffoKKm/007]=00001G_F00<006okKo/03Vok00<005JIEYT01eJI0P004fh=1000
1ed200D004UaBG59L@0001I9L@030019LDUa00]9L@80031]k003001]k6g/00A]k003001oogoo00ao
o`03001oogoo009oo`000Woo00<007ooOol01goo00<0044`@C00:d4`10009VJF00<007_GNmL01G_G
00L006oKKm]_f`00Ndd00005NmH00`00Ko]_n`0=Ko/00`00H[P0000:EYT3000DKPd40004G@801000
BG59L@005TUa00<004UaBG402dUa0P00<Fg/00<006g/KN`00fg/00<007ooOol037oo00<007ooOol0
0Woo0002Ool00`00Oomoo`07Ool00`00@C11<00X@C06000WIYH00`00NmMke`06NmL01P00Km]_f`00
Ndd000IkeP03001_nfok00]_n`05001R^6:hH[P0000<EYT2000FKPd4000015d20019L@005TUa00<0
04UaBG402dUa0P00<Vg/00<006g/KN`00fg/00<007ooOol02goo00<007ooOol00Woo0002Ool00`00
Oomoo`07Ool00`00@C11<00U@C040005JW<00`00IYIVUP0SIYH00`00NmMke`08NmL01@00Km/007]=
00001g_F00<006okKo/02Fok00<006:hH[P00V:h00<005JIEYT035JI0`005fh=10005DUa00<004Ua
BG403DUa00<006g/KN`0<6g/00<006g/KN`00fg/00<007ooOol02goo00<007ooOol00Woo0002Ool0
0`00Oomoo`06Ool00`00@C11<00S@C040009JW<2000RIYH00`00NmMke`09NmL00`00Km/00002Ndd0
0`00NmIkeP04NmH00`00Ko]_n`08Ko/00`00H[QR^004H[P00`00EYUFV@0=EYT3000GKPd2000EBG40
0`00BG59L@0=BG42000bKN`00`00KNa]k002KN`00`00Oomoo`0;Ool00`00Oomoo`02Ool0009oo`03
001oogoo00Ioo`030011<44`0211<0@000iZL`80021VUP03001keg_G00Yke`80009kC@03001keW_F
00EkeP03001_nfok00E_n`8000QR^003001FVEJI00aFV@03001:NTYj00<001A^3@8001E9L@030019
LDUa00m9L@80035]k003001]k6g/009]k003001oogoo00Yoo`03001oogoo009oo`000Woo00<007oo
Ool01Woo00<0044`@C00744`1@004fYc0P007FJF00<007_GNmL037_G0P0000=kC@00NmH01W_F00<0
06okKo/016ok00<006:hH[P02F:h00<005JIEYT035JI00<004YjBWX00TYj0P004fh=00<004UaBG40
4TUa00<004UaBG404TUa0`00;Vg/00<006g/KN`00Vg/00<007ooOol02Woo00<007ooOol00Woo0002
Ool00`00Oomoo`05Ool00`00@C11<00J@C04000IJW<00`00IYIVUP0IIYH00`00NmMke`0>NmL00`00
Ndd00008NmH00`00Ko]_n`02Ko/00`00H[QR^00;H[P00`00EYUFV@0;EYT00`00BWY:NP04BWX3000@
KPd00`00BG59L@0BBG400`00BG59L@0DBG43000]KN`01@00KNa]k6g/000037oo00<007ooOol00Woo
00000goo001oo`07Ool00`00@C11<00G@C04000MJW<2000IIYH00`00NmMke`0>NmL01000NdekC@00
27_F00@006okKo/000iR^003001FVEJI00aFV@03001:NTYj00I:NP8000i^3@030019LDUa0159L@03
0019LDUa01A9L@040019LDUaBG42000/KN`01@00KNa]k6g/000037oo00<007ooOol00Goo00000goo
001oo`07Ool00`00@C11<00D@C04000RJW<2000FIYH00`00NmMke`0?NmL01000NdekC@0027_F00<0
06ok000046:h00<005JIEYT02eJI00<004YjBWX01dYj10002fh=00<004UaBG404DUa00<004UaBG40
4dUa00<004UaBG4014Ua0`00:Vg/00@006g/KN`000aoo`03001oogoo005oo`0000=oo`00Ool01Woo
00<0044`@C004T4`10009fYc0P0056JF00<007_GNmL03g_G00@007]=Ndd000UkeP03001R^6:h011R
^003001FVEJI00]FV@03001:NTYj00M:NP03000enSGj008000Y^3@030019LDUa0119L@030019LDUa
0199L@030019LDUa00Q9L@8002Q]k005001]k6g/KN`0000;Ool00`00Oomoo`01Ool00003Ool007oo
00Ioo`030011<44`00m1<0@002aZL`03001VUVJF011VUP03001keg_G011ke`04001kCG]=0008NmH0
0`00IYH0000BH[P00`00EYUFV@0:EYT00`00BWY:NP07BWX00`00=OXenP02=OX30007KPd00`00BG59
L@0?BG400`00BG59L@0BBG400`00BG59L@0;BG43000VKN`01000KNa]k0002goo00<007ooOol00Goo
00000goo001oo`06Ool00`00@C11<00<@C04000`JW<2000?IYH00`00NmMke`0ANmL01@00NdekCG]=
00001g_F00@006JFIYH0019R^003001FVEJI00YFV@03001:NTYj00I:NP03000enSGj00DenP8000E^
3@030019LDUa00m9L@030019LDUa0199L@030019LDUa00i9L@8002E]k003001]k00000]oo`03001o
ogoo005oo`0000=oo`00Ool01Woo00<0044`@C002D4`1000=FYc0P003FJF00<007_GNmL04G_G00D0
07]=NdekC@0000IkeP03001VUVJF009VUP80011R^003001FVEJI00YFV@03001:NTYj00M:NP03000e
nSGj00@enP03000<m`000080009^3@030019LDUa00m9L@030019LDUa0159L@030019LDUa0159L@<0
02=]k003001]k00000Yoo`03001oogoo005oo`0000=oo`00Ool01Goo00<0044`@C001d4`1000>VYc
0P002VJF00<007_GNmL04W_G00D007]=NdekC@0000IkeP03001VUVJF00AVUP03001R^6:h00iR^003
001FVEJI00YFV@03001:NTYj00I:NP03000enSGj00@enP03000<m`cg008<m`800003KPd004Ua00i9
L@030019LDUa0159L@030019LDUa01E9L@80025]k003001]k00000Yoo`03001oogoo005oo`0000=o
o`00Ool01Goo00<0044`@C000d4`1000@6Yc00<006JFIYH01VJF00<007_GNmL057_G00@007]=Ndd0
00EkeP03001VUVJF00IVUP03001R^6:h00iR^003001FVEJI00UFV@03001:NTYj00I:NP03000enSGj
00@enP03000<m`cg00<<m`<000m9L@030019LDUa0119L@030019LDUa01Q9L@80021]k08000Yoo`03
001oogoo005oo`0000<007ooOol01Goo00<0044`@C001000A6Yc0P001VJF00<007_GNmL057_G00D0
07]=NdekC@0000=keP03001VUVJF00QVUP03001R^6:h00iR^003001FVEJI00UFV@03001:NTYj00I:
NP03000enSGj00@enP03000<m`cg008<m`0300002`0000m9L@030019LDUa0119L@030019LDUa01Y9
L@<001i]k08000Yoo`40005oo`5oo`0000<007ooOol017oo1@00BFYc0P000fJF00<007_GNmL05G_G
00D007]=NdekC@0000=keP03001VUVJF00UVUP03001R^6:h00iR^003001FVEJI00UFV@03001:NTYj
00E:NP03000enSGj00@enP03000<m`cg008<m`0300002`0000i9L@030019LDUa0119L@030019LDUa
01Y9L@040019LDUaBG42000MKN`00`00Oomoo`08Ool10001Ool1Ool00003001oogoo009oo`@004iZ
L`800003IYH007_G01Ike`05001kCG]=Ndd00002NmH00`00IYIVUP0;IYH2000>H[P00`00EYUFV@09
EYT00`00BWY:NP05BWX00`00=OXenP04=OX00`003?L<m`023?L00`0000/0000>BG400`00BG59L@0?
BG400`00BG59L@0IBG420006BG43000JKN`20009Ool10001Ool1Ool00003001oo`00008000Aoo`<0
04eZL`03001keg_G01Ike`05001kCG]=Ndd00002NmH00`00IYIVUP0=IYH00`00H[QR^00<H[P00`00
EYUFV@09EYT00`00BWY:NP05BWX00`00=OXenP03=OX00`003?L<m`023?L00`0000/0000>BG400`00
BG59L@0>BG400`00BG59L@0IBG400`00BG59L@09BG42000IKN`00`00Oomoo`07Ool10001Ool1Ool0
008000Yoo`<004YZL`03001keg_G01Ike`03001kCG]=009kC@80015VUP03001R^6:h00aR^003001F
VEJI00QFV@03001:NTYj00E:NP03000enSGj00<enP03000<m`cg008<m`0300002`0000e9L@030019
LDUa00i9L@030019LDUa01Q9L@8000i9L@<001I]k08000Qoo`40005oo`5oo`0000=oo`00Ool037oo
0P00B6Yc0P005g_G00<007]=Ndd00W]=0P004VJF00<006:hH[P036:h00<005JIEYT025JI00<004Yj
BWX014Yj00<003Gj=OX00cGj00<000cg3?L00Pcg00<0000;00003DUa00<004UaBG403TUa00<004Ua
BG405dUa00<004UaBG404DUa0P005Fg/0P001goo0@000Goo0Goo0002Ool2000=Ool30014JW<00`00
Ofl0000GNmL00`00NdekC@02Ndd00`00IYIVUP0BIYH00`00H[QR^00<H[P00`00EYUFV@07EYT00`00
BWY:NP05BWX00`00=OXenP03=OX01`003?L<m`cg00002`0000a9L@030019LDUa00i9L@030019LDUa
01M9L@030019LDUa01A9L@8001=]k08000Moo`40005oo`5oo`0017oo00<007ooOol03Goo0`00@FYc
00<007m_000067_G00@007]=NdekC@<001=VUP03001R^6:h00]R^003001FVEJI00QFV@03001:NTYj
00A:NP03000enSGj00<enP07000<m`cg3?L0000;000034Ua00<004UaBG403DUa00<004UaBG405TUa
0P006DUa0`004Fg/0P001Woo0@000Goo0Goo0005Ool00`00Oomoo`0?Ool3000nJW<01000OfmoK`00
5W_G0P000g]=00<006YcJW<00P004VJF0P0036:h00<005JIEYT01eJI00<004YjBWX014Yj00<003Gj
=OX00cGj00L000cg3?L<m`0000/0000<BG400`00BG59L@0<BG400`00BG59L@0FBG400`00BG59L@0L
BG42000?KN`00`00Ool00006Ool10001Ool000Ioo`03001oogoo015oo`<003]ZL`04001oKgm_000F
NmL20002Ndd00`00JW=ZL`03JW<2000BIYH00`00H[QR^00:H[P00`00EYUFV@07EYT00`00BWY:NP04
BWX00`00=OXenP02=OX01`003?L<m`cg00002`0000]9L@030019LDUa00a9L@030019LDUa01E9L@80
0259L@<000a]k004001oogoo0005Ool10001Ool000Moo`8001Aoo`8003QZL`05001oKgm_Ofl0000E
NmL00`00BG400002Ndd00`00JW=ZL`05JW<00`00IYIVUP0@IYH00`00H[QR^00:H[P00`00EYUFV@06
EYT00`00BWY:NP04BWX00`00=OXenP02=OX01`003?L<m`cg00002`0000]9L@030019LDUa00a9L@03
0019LDUa01A9L@030019LDUa02A9L@8000]]k003001oo`0000Eoo`40005oo`002Goo00<007ooOol0
4goo0`00=FYc00<007m_Ofl00Wm_00<007_GNmL04G_G00@004UaBG40009kC@03001ZLfYc00IZL`80
015VUP03001R^6:h00YR^003001FVEJI00IFV@03001:NTYj00=:NP03000enSGj008enP07000<m`cg
3?L0000;00002dUa00<004UaBG402dUa00<004UaBG404dUa0P00:DUa0`0026g/00@007ooOol000Ao
o`40005oo`002Woo00<007ooOol05Goo0`00<VYc00<007m_Ofl00Wm_00<007_GNmL04G_G00@004Ua
BG40009kC@03001ZLfYc00QZL`80011VUP03001R^6:h00UR^003001FVEJI00IFV@03001:NTYj00A:
NP03000enSGj008enP06000<m`cg00002`002TUa00<004UaBG402dUa00<004UaBG404dUa00<004Ua
BG40;4Ua0P001Vg/00D007ooOomoo`0000=oo`40005oo`002goo00<007ooOol05goo0`00;fYc00<0
07m_Ofl00Wm_00<007_GNmL047_G00L004UaBG59L@00Ndd0000=JW<2000?IYH2000:H[P00`00EYUF
V@06EYT00`00BWY:NP03BWX00`00=OXenP02=OX01P003?L<m`0000/000Y9L@030019LDUa00Y9L@03
0019LDUa0199L@800359L@8000E]k005001oogooOol00002Ool10001Ool000aoo`8001Yoo`<002]Z
L`03001oKgm_00AoK`03001keg_G00mke`070019LDUaBG4007]=00003fYc00<006JFIYH03VJF00<0
06:hH[P026:h00<005JIEYT01EJI00<004YjBWX00dYj00<003Gj=OX00SGj00H000cg3?L0000;000:
BG400`00BG59L@0:BG400`00BG59L@0ABG400`00BG59L@0cBG430002KN`01@00Oomoogoo00000Woo
0@000Goo000>Ool00`00Oomoo`0JOol2000YJW<00`00OfmoK`04Ofl00`00NmMke`0>NmL00`00BG59
L@03BG42000@JW<2000?IYH00`00H[QR^008H[P00`00EYUFV@05EYT00`00BWY:NP03BWX01@00=OXe
nSGj00000Pcg00<0000;00002DUa00<004UaBG402TUa00<004UaBG4044Ua0P00>DUa0P0000=]k000
Ool00Woo00<007oo00000Goo000?Ool00`00Oomoo`0KOol3000VJW<00`00OfmoK`04Ofl00`00NmMk
e`0=NmL00`00BG59L@04BG42000BJW<2000>IYH00`00H[QR^008H[P00`00EYUFV@04EYT00`00BWY:
NP03BWX01@00=OXenSGj00000`cg0P002DUa00<004UaBG402DUa00<004UaBG4044Ua00<004UaBG40
>dUa0P0017oo0@000Goo0@00000@Ool00`00Oomoo`0MOol3000SJW<00`00OfmoK`05Ofl00`00NmMk
e`0<NmL00`00BG59L@04BG400`00JW=ZL`0CJW<00`00IYIVUP0<IYH00`00H[QR^007H[P00`00EYUF
V@05EYT00`00BWY:NP02BWX01@00=OXenSGj00000`cg0P002DUa00<004UaBG4024Ua00<004UaBG40
3dUa0P00>TUa10001goo0P00000AOol2000POol3000PJW<00`00OfmoK`05Ofl00`00NmMke`0;NmL0
0`00BG59L@05BG400`00JW=ZL`0DJW<2000=IYH00`00H[QR^007H[P00`00EYUFV@04EYT00`00BWY:
NP03BWX01@00=OXenSGj00000Pcg0P0024Ua00<004UaBG4024Ua00<004UaBG403dUa00<004UaBG40
=TUa10002goo0P00000COol00`00Oomoo`0POol3000LJW<00`00OfmoK`06Ofl00`00NmMke`0:NmL0
0`00BG59L@06BG42000GJW<2000<IYH20008H[P00`00EYUFV@04EYT00`00BWY:NP02BWX01@00=OXe
nSGj00000Pcg0P0024Ua00<004UaBG4024Ua00<004UaBG403DUa0P00=TUa0`003goo0P00000DOol0
0`00Oomoo`0ROol3000IJW<00`00OfmoK`07Ofl00`00NmMke`09NmL00`00BG59L@08BG43000FJW<2
000<IYH00`00H[QR^006H[P00`00EYUFV@03EYT00`00BWY:NP02BWX01@00=OXenSGj00000Pcg0P00
24Ua00<004UaBG401dUa00<004UaBG403DUa00<004UaBG40<TUa10003Woo10000Woo000EOol00`00
Oomoo`0TOol2000GJW<00`00OfmoK`07Ofl00`00NmMke`08NmL00`00BG59L@0<BG42000FJW<00`00
IYIVUP0:IYH00`00H[QR^006H[P00`00EYUFV@03EYT00`00BWY:NP02BWX01000=OXenP000Pcg0P00
1dUa00<004UaBG401dUa00<004UaBG403DUa00<004UaBG40;dUa10003Woo10001Woo000FOol2000V
Ool3000DJW<00`00OfmoK`07Ofl00`00NmMke`08NmL00`00BG59L@0>BG43000DJW<2000;IYH00`00
H[QR^005H[P00`00EYUFV@04EYT01@00BWY:NTYj00000SGj00<000cg3?L00P001dUa00<004UaBG40
1TUa00<004UaBG4034Ua0P00;TUa10003Woo10002Woo000HOol00`00Oomoo`0VOol3000@JW<00`00
OfmoK`09Ofl00`00NmMke`06NmL00`00BG59L@0BBG43000CJW<2000:IYH00`00H[QR^005H[P00`00
EYUFV@03EYT01@00BWY:NTYj00000SGj00<000cg3?L00P001TUa00<004UaBG401TUa00<004UaBG40
34Ua00<004UaBG40:dUa0`003Woo10003Woo000IOol00`00Oomoo`0XOol3000=JW<00`00OfmoK`09
Ofl00`00NmMke`05NmL00`00BG59L@0FBG43000BJW<20009IYH00`00H[QR^005H[P00`00EYUFV@03
EYT01@00BWY:NTYj00000SGj00@000cg000000I9L@030019LDUa00I9L@030019LDUa00Y9L@8002Y9
L@@000ioo`<0019oo`006Woo0P00:goo0`002VYc00<007m_Ofl02Gm_00<007_GNmL01G_G00<004Ua
BG406DUa0P004VYc00<006JFIYH01fJF0P001V:h00<005JIEYT00UJI00D004YjBWY:NP00008enP04
000<m`000006BG400`00BG59L@05BG400`00BG59L@0:BG400`00BG59L@0VBG44000>Ool4000EOol0
01aoo`03001oogoo02]oo`8000QZL`03001oKgm_00YoK`03001keg_G00=ke`030019LDUa01a9L@<0
011ZL`8000UVUP03001R^6:h00AR^003001FVEJI009FV@04001:NTYj0002=OX010003?L000001DUa
00<004UaBG401DUa00<004UaBG402DUa0P009TUa0`003Woo10006Goo000MOol00`00Oomoo`0/Ool3
0004JW<00`00OfmoK`0;Ofl00`00NmMke`03NmL00`00BG59L@0OBG43000?JW<20008IYH00`00H[QR
^003H[P00`00EYUFV@02EYT01000BWY:NP000SGj00@000cg000000E9L@030019LDUa00A9L@030019
LDUa00U9L@030019LDUa0299L@@000eoo`@001eoo`007Woo00<007ooOol0;Woo0`0000=ZL`00Ofl0
37m_00<007_GNmL00W_G00<004UaBG408dUa0`003VYc0P001fJF00<006:hH[P00f:h00<005JIEYT0
0UJI00L004YjBWX003Gj000<m`020005BG400`00BG59L@04BG400`00BG59L@07BG42000QBG44000>
Ool3000QOol001moo`80035oo`8000ioK`04001keg_G000YBG42000>JW<00`00IYIVUP05IYH00`00
H[QR^003H[P01@00EYUFVEJI00000TYj00@003Gj000<m`8000A9L@030019LDUa00A9L@030019LDUa
00M9L@030019LDUa01e9L@@000ioo`@002Aoo`008Goo00<007ooOol0;goo00<007m_Ofl037m_00@0
07_GNmL002]9L@<000aZL`8000IVUP8000AR^007001FVEJIEYT004Yj00000SGj0`0014Ua00<004Ua
BG400dUa00<004UaBG401TUa0P007DUa0`003Woo1000:7oo000ROol00`00Oomoo`0^Ool00`00Ofmo
K`0<Ofl00`00NmL0000_BG43000;JW<20006IYH00`00H[QR^002H[P01000EYUFV@000TYj00<003Gj
00000P0014Ua00<004UaBG400TUa00<004UaBG401TUa00<004UaBG406DUa10003Goo1000;7oo000S
Ool00`00Oomoo`0^Ool00`00OfmoK`0<Ofl2000bBG43000:JW<20005IYH01@00H[QR^6:h00000eJI
00@004Yj000enP<000=9L@030019LDUa0099L@030019LDUa00E9L@8001Q9L@@000eoo`@0031oo`00
97oo0P00;Woo00<007m_Ofl037m_1000<dUa0`002FYc00<006JFIYH00fJF00D006:hH[QR^000009F
V@04001:NP00=OX30003BG400`00BG59L@02BG400`00BG59L@04BG400`00BG59L@0EBG43000>Ool3
000dOol002Ioo`03001oogoo02]oo`03001oKgm_00aoK`040019LDUaBG48000^BG420008JW<20004
IYH01@00H[QR^6:h00000UJI00<004Yj00000`000dUa00D004UaBG59L@0000E9L@8001A9L@@000eo
o`@003Moo`009goo00<007ooOol0:Woo00<007m_Ofl037m_00<004UaBG402DUa2000:4Ua0`001fYc
0P000fJF00P006:hH[QR^000EYT004Yj0P0000D<m`00BG59L@0000=9L@030019LDUa00=9L@030019
LDUa0119L@@000eoo`@003]oo`00:7oo00<007ooOol0:Goo00<007m_Ofl02gm_00<004UaBG404TUa
20008dUa0`001VYc00@006JFIYIVUP80009R^005001FV@00000enP020002BG401000BG59L@001DUa
00<004UaBG403DUa10003Goo1000?goo000YOol2000ZOol00`00OfmoK`0:Ofl00`00BG59L@0JBG48
000NBG430004JW<20003IYH01P00H[P005JI001:NP<00005BG4004UaBG400004BG42000=BG43000>
Ool30013Ool002]oo`03001oogoo02Moo`03001oKgm_00YoK`030019LDUa0299L@L001Y9L@8000AZ
L`80009VUP04001R^000EYT400001DUa0019LDUa00000dUa00<004UaBG402DUa10003Goo1000AWoo
000/Ool00`00Oomoo`0VOol00`00OfmoK`0:Ofl00`00BG59L@0YBG48000DBG430003JW<200000fJF
001R^005000014Ua0019L@000TUa0P0024Ua10003Goo1000BWoo000]Ool00`00Oomoo`0UOol00`00
OfmoK`09Ofl00`00BG59L@0bBG48000?BG430002JW<01000IYH006:h1@0000E9L@00BG59L@0000M9
L@<000eoo`@004ioo`00;Woo0P009Goo00<007m_Ofl02Gm_00<004UaBG40>TUa20002TUa300000=9
L@00000014Ua100037oo1000DWoo000`Ool00`00Oomoo`0SOol00`00OfmoK`08Ofl00`00BG59L@12
BG480005BG4:0002BG44000=Ool3001FOol0035oo`03001oogoo029oo`03001oKgm_00QoK`030019
LDUa04Y9LA4000eoo`@005Uoo`00<Woo00<007ooOol08Goo00<007m_Ofl027m_00<004UaBG40DTUa
1@003Goo1000GGoo000cOol2000QOol00`00OfmoK`07Ofl00`00BG59L@1ABG44000<Ool4001QOol0
03Eoo`03001oogoo01ioo`03001oKgm_00MoK`030019LDUa04e9L@@000eoo`<006Eoo`00=Woo00<0
07ooOol07Woo00<007m_Ofl01Wm_00<004UaBG40BTUa0`003Goo1000J7oo000gOol00`00Oomoo`0M
Ool00`00OfmoK`06Ofl00`00BG59L@16BG44000<Ool4001/Ool003Qoo`8001eoo`03001oKgm_00Io
K`030019LDUa04=9L@<000aoo`@0071oo`00>Woo00<007ooOol06Woo00<007m_Ofl01Gm_00<004Ua
BG40@4Ua10002goo1000M7oo000kOol00`00Oomoo`0IOol00`00OfmoK`05Ofl00`00BG59L@0lBG44
000<Ool3001hOol003aoo`03001oogoo01Qoo`03001oKgm_00EoK`030019LDUa03U9L@<000aoo`@0
07]oo`00?Goo0P006Goo00<007m_Ofl017m_00<004UaBG40=DUa10002goo1000Ogoo000oOol00`00
Oomoo`0FOol00`00OfmoK`03Ofl00`00BG59L@0cBG43000;Ool40023Ool0041oo`03001oogoo01Eo
o`03001oKgm_00=oK`030019LDUa02m9L@@000Yoo`@008Moo`00@Goo00<007ooOol057oo00<007m_
Ofl00gm_00<004UaBG40:dUa10002goo0`00Rgoo0012Ool2000DOol00`00OfmoK`03Ofl00`00BG59
L@0XBG43000;Ool4002>Ool004Aoo`03001oogoo019oo`03001oKgm_009oK`030019LDUa02A9L@@0
00Yoo`@0099oo`00AGoo00<007ooOol04Goo00D007m_OfmoK`0002=9L@@000Yoo`@009Ioo`00AWoo
0P004Goo00D007m_OfmoK`000219L@<000]oo`<009Yoo`00B7oo00<007ooOol03Woo00D007m_Ofmo
K`0001a9L@@000Yoo`@009eoo`00BGoo00<007ooOol03Goo00D007m_OfmoK`0001U9L@<000Yoo`@0
0:5oo`00BWoo00<007ooOol037oo0P000Wm_00<004UaBG404dUa10002Goo1000YGoo001;Ool2000<
Ool200000gm_0019L@0ABG440009Ool4002YOol004eoo`03001oogoo00Uoo`800003Ofl004Ua00i9
L@<000Yoo`<00:eoo`00CWoo00<007ooOol01goo00D007oo001oK`0000]9L@@000Uoo`@00;1oo`00
Cgoo00<007ooOol01Woo00D007oo001oK`0000Q9L@<000Uoo`@00;Aoo`00D7oo0P001Woo00@007oo
Ool000E9L@@000Qoo`@00;Qoo`00DWoo00<007ooOol00goo00D007ooOol004Ua00@000Uoo`<00;ao
o`00Dgoo00<007ooOol00Woo00<007ooOol00P002Goo1000_goo001DOol01@00Oomoogoo00002Goo
1000`goo001EOol200000goo001oo`04Ool40037Ool005Moo`800003Ool0000000800<]oo`00F7oo
0P00cgoo0000\
\>"],
  ImageRangeCache->{{{0, 296.375}, {245.688, 0}} -> {-0.000389658, 0.0568386, 
  0.00333113, 0.00333113}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Annotation Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three graphics functions are provided by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifically for annotation. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Arrow[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, length",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates an arrow of specified ",
  StyleBox["length",
    FontSlant->"Italic"],
  " that emanates from the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and points in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["PointLabel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a label specifying the local coordinates of ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["LocalAxes[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, size",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a local coordinate axes on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", labeled with the body number and the ",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["z",
    FontSlant->"Italic"],
  " direction vectors. The length of each arm of the axes is specified by ",
  StyleBox["size",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Graphics functions for annotation."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["PointLabel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["LocalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to conveniently label points and bodies. The following input \
generates a triangle placed on body 2, with two of the points labeled with \
their body numbers and local coordinates. If ",
  StyleBox["PointLabel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is given a local point number as an argument instead of a coordinate \
pair, then it labels the point with its body number and its point number."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This generates the triangle graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(body2 = 2; \)\), 
    \(\(bdgraph = 
      Graphics3D[{\n\t\t\t
          Edge[body2, {{0, 0, 0}, {1, 0, 0}, {1, 1, 0}, {0, 0, 0}}], \n\t\t\t
          Arrow[Line[body2, {0.5, 0.5, 0}, {0, 1, 0}], 0.5], \n\t\t\t
          PointLabel[body2, {1, 1, 0}], \n\t\t\tPointLabel[body2, {1, 0, 0}], 
          \n\t\t\tLocalAxes[body2, .3]}, \n\t\tPlotRange \[Rule] All]; \)\)}],
   "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      bdgraph /. {X2 \[Rule] 0, Y2 \[Rule] 0, Z2 \[Rule] 0, Eo2 \[Rule] 0, 
          Ei2 \[Rule] 0, Ej2 \[Rule] 1, Ek2 \[Rule] 0}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79139 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
2.22045e-016 1.04959 -0.0776046 1.04959 [
[ 0 0 0 0 ]
[ 1 .79139 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03355 .25566 m
0 .46737 L
s
0 .46737 m
.39771 .79139 L
s
.39771 .79139 m
.40441 .59981 L
s
.40441 .59981 m
.03355 .25566 L
s
.68991 0 m
.97232 .42999 L
s
.97232 .42999 m
1 .63247 L
s
1 .63247 m
.70277 .22158 L
s
.70277 .22158 m
.68991 0 L
s
.03355 .25566 m
0 .46737 L
s
0 .46737 m
.70277 .22158 L
s
.70277 .22158 m
.68991 0 L
s
.68991 0 m
.03355 .25566 L
s
.40441 .59981 m
.97232 .42999 L
s
.97232 .42999 m
1 .63247 L
s
1 .63247 m
.39771 .79139 L
s
.39771 .79139 m
.40441 .59981 L
s
0 0 m
1 0 L
1 .79139 L
0 .79139 L
closepath
clip
newpath
.5 Mabswid
.40432 .74039 m
.67878 .21392 L
s
.04615 .43697 m
.40432 .74039 L
s
.83134 .56944 m
.77183 .58624 L
s
.78565 .52424 m
.83134 .56944 L
s
.83134 .56944 m
.80584 .53749 L
s
.7916 .60107 m
.83134 .56944 L
s
.52076 .51704 m
.83134 .56944 L
s
.67878 .21392 m
.04615 .43697 L
s
.77402 .34392 m
.75725 .33674 L
s
.77656 .31251 m
.77402 .34392 L
s
.77402 .34392 m
.75471 .30203 L
s
.73554 .32602 m
.77402 .34392 L
s
.67878 .21392 m
.77402 .34392 L
s
.67035 .04649 m
.69242 .07078 L
s
.66211 .06421 m
.67035 .04649 L
s
.67035 .04649 m
.65164 .08615 L
s
.68167 .09259 m
.67035 .04649 L
s
.67878 .21392 m
.67035 .04649 L
s
.47292 .2865 m
.51282 .29003 L
s
.50181 .25921 m
.47292 .2865 L
s
.47292 .2865 m
.51296 .25498 L
s
.52382 .28542 m
.47292 .2865 L
s
.47292 .2865 m
.67878 .21392 L
s
gsave
.40432 .74039 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(<) show
67.812500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
72.375000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
76.937500 14.437500 moveto
(8) show
81.750000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
86.312500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
95.437500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
100.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
109.125000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
113.687500 14.437500 moveto
(<) show
118.500000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.04615 .43697 -61 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(<) show
67.812500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
72.375000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
76.937500 14.437500 moveto
(8) show
81.750000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
86.312500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
95.437500 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
100.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
109.125000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
113.687500 14.437500 moveto
(<) show
118.500000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 8.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%DocumentNeededResources: + font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math1Mono
%%DocumentNeededFont: + Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math1Mono
%%DocumentFonts: + font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.47292 .2865 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.77402 .34392 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67035 .04649 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.67878 .21392 -72.5 -21.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.68991 0 m
.97232 .42999 L
s
.97232 .42999 m
1 .63247 L
s
1 .63247 m
.70277 .22158 L
s
.70277 .22158 m
.68991 0 L
s
.03355 .25566 m
0 .46737 L
s
0 .46737 m
.70277 .22158 L
s
.70277 .22158 m
.68991 0 L
s
.68991 0 m
.03355 .25566 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{279.875, 221.438},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004G0000gA000`40O003h00O_goo0P00EWoo002m
Ool200000goo0000001EOol00;Yoo`<000=oo`8005Eoo`00]goo0`001Woo00<007oo0000E7oo002e
Ool20009Ool01000Oomoo`00Dgoo002bOol3000;Ool01000Oomoo`00Dgoo002`Ool2000>Ool01@00
Oomoogoo0000DWoo002]Ool3000@Ool00`00Oomoo`02Ool00`00Oomoo`1?Ool00:]oo`8001=oo`03
001oogoo009oo`03001oogoo04moo`00Z7oo0`005Goo00<007ooOol00goo00<007ooOol0CWoo002U
Ool3000HOol00`00Oomoo`04Ool00`00Oomoo`1=Ool00:=oo`8001aoo`03001oogoo00=oo`03001o
ogoo04eoo`00X7oo0`007Woo00<007ooOol017oo00<007ooOol0C7oo002NOol2000JOol00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`1;Ool009]oo`<001aoo`8000Eoo`03001oogoo00Eoo`03
001oogoo04]oo`00VGoo0P007Woo100017oo00<007ooOol01Woo00<007ooOol0BWoo002FOol3000P
Ool300000goo001oo`02Ool00`00Oomoo`07Ool00`00Oomoo`19Ool009=oo`<0029oo`04001oo`00
0002Ool01000Oomoo`002Goo00<007ooOol0BGoo002AOol2000UOol01@00Ool007oo00000Woo00<0
07oo00002Woo00<007ooOol0B7oo002>Ool3000VOol01P00Oomoo`00Ool000=oo`8000]oo`03001o
ogoo04Moo`00S7oo0P00:Goo00H007ooOol007oo0004Ool00`00Oomoo`09Ool00`00Oomoo`17Ool0
08Uoo`<002Yoo`03001oogoo009oo`80009oo`@000]oo`03001oogoo04Ioo`00Qgoo0P00;Goo00<0
07ooOol00Woo00<007oo00000Woo0`002goo00<007ooOol0AWoo0024Ool3000^Ool00`00Oomoo`03
Ool01`00Ool007oo001oo`0000eoo`03001oogoo04Eoo`00PGoo0`00<Goo00<007ooOol00goo00@0
07oo001oo`@000eoo`03001oogoo04Aoo`00Ogoo0P00>Woo00@007ooOol0009oo`03001oogoo00ao
o`03001oogoo04Aoo`00O7oo0`00?7oo00@007ooOol0009oo`03001oogoo00eoo`03001oogoo04=o
o`00NWoo0P00?goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0@Woo001gOol30011Ool0
0`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`12Ool007Aoo`<004Aoo`03001oogoo00=oo`03
001oogoo00moo`03001oogoo045oo`00LWoo0P00Agoo00<007ooOol00goo00<007ooOol047oo00<0
07ooOol0@7oo001_Ool30019Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`10Ool006eo
o`8004aoo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo03moo`00JWoo0`00CWoo00<007oo
Ool017oo00<007ooOol04Goo00<007ooOol0?Woo001XOol2001AOol00`00Oomoo`04Ool00`00Oomo
o`0AOol00`00Oomoo`0nOol006Eoo`<005=oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo
03eoo`00HWoo0`00EWoo00<007ooOol017oo00<007ooOol04goo00<007ooOol0?7oo001POol2001J
Ool00`00Oomoo`03Ool00`00Oomoo`0COol00`00Oomoo`0lOol005eoo`<005aoo`03001oogoo00=o
o`03001oogoo01Aoo`03001oogoo03]oo`00Fgoo0P00Ggoo00<007ooOol00goo00<007ooOol05Goo
00<007ooOol0>Woo001HOol3001QOol00`00Oomoo`03Ool00`00Oomoo`0EOol00`00Oomoo`0jOol0
05Ioo`8006Aoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo03Uoo`00Dgoo0`00IWoo00<0
07ooOol00goo00<007ooOol05goo00<007ooOol0>7oo001@Ool3001YOol00`00Oomoo`03Ool00`00
Oomoo`0GOol00`00Oomoo`0hOol004ioo`8006aoo`03001oogoo00=oo`03001oogoo01Qoo`03001o
ogoo03Moo`00Bgoo0`00KWoo00<007ooOol00goo00<007ooOol06Goo00<007ooOol0=Woo0019Ool2
001aOol00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`0fOol004Ioo`<007=oo`03001oogoo
00=oo`03001oogoo01Yoo`03001oogoo03Eoo`00@goo0`00KWoo0`001Goo00<007ooOol00goo00<0
07ooOol06goo00<007ooOol0=7oo0011Ool2001aOol00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`0KOol00`00Oomoo`0dOol003ioo`<007Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo01aoo`03001oogoo03=oo`00?7oo0P00Mgoo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool07Goo00<007ooOol0<Woo000iOol3001hOol00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomo
o`0LOol00`00Oomoo`0bOol003Moo`8007aoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo
01eoo`03001oogoo035oo`00=7oo0`00QWoo00<007ooOol00goo00<007ooOol07Woo00<007ooOol0
<7oo000aOol30029Ool00`00Oomoo`03Ool00`00Oomoo`0NOol00`00Oomoo`0`Ool002moo`8008ao
o`03001oogoo00=oo`03001oogoo01moo`03001oogoo02moo`00;7oo0`00SWoo00<007ooOol00goo
00<007ooOol087oo00<007ooOol0;Woo000ZOol2002AOol00`00Oomoo`03Ool00`00Oomoo`0POol0
0`00Oomoo`0^Ool002Moo`<009=oo`03001oogoo00=oo`03001oogoo025oo`03001oogoo02eoo`00
9Goo0P00UGoo0P001Goo00<007ooOol08Goo00<007ooOol0;Goo000ROol3002DOol400000goo001o
o`03Ool00`00Oomoo`0ROol00`00Oomoo`0/Ool001moo`<009Aoo`<000=oo`03001oo`0000=oo`80
02Eoo`03001oogoo02]oo`007Goo0P00U7oo0`001Goo00@007ooOomoo`<0009oo`03001oogoo029o
o`03001oogoo02]oo`006Woo0`00Tgoo10001goo100000=oo`00Ool00Woo00<007ooOol08goo00<0
07ooOol0:Woo000HOol2002DOol30008Ool30005Ool01@00Oomoogoo00009Goo00<007ooOol0:Goo
000EOol3002COol30009Ool200000goo001oo`05Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00
Oomoo`0YOol001=oo`8009=oo`<000Uoo`<0009oo`03001oogoo00Ioo`03001oogoo009oo`03001o
ogoo029oo`03001oogoo02Qoo`0047oo0`00TWoo0`002Goo0`001Goo00<007ooOol01goo00D007oo
Oomoo`0002Eoo`03001oogoo02Moo`003Goo0`00TWoo0`002Goo0`001goo00<007ooOol027oo00<0
07ooOol00Woo00<007ooOol08Woo00<007ooOol09goo000;Ool2002BOol40008Ool3000:Ool00`00
Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`0VOol000Uoo`8008Aoo`03001o
ogoo00Yoo`@000Qoo`<000aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo029oo`03001o
ogoo02Eoo`002Goo0P00P7oo00@007ooOol000Yoo`@000Qoo`<000moo`03001oogoo00aoo`05001o
ogooOol0000TOol00`00Oomoo`0UOol000Uoo`03001oo`0007ioo`04001oo`000008Ool40009Ool2
000AOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0ROol00`00Oomoo`0TOol000Uoo`04
001oogoo001lOol00`00Ool00007Ool40009Ool3000COol00`00Oomoo`0>Ool00`00Oomoo`02Ool0
0`00Oomoo`0ROol00`00Oomoo`0SOol000Qoo`03001oogoo009oo`03001oogoo07Qoo`03001oo`00
00Ioo`<000Uoo`<001Eoo`03001oogoo011oo`05001oogooOol0000TOol00`00Oomoo`0SOol000Qo
o`03001oogoo00=oo`03001oogoo07Ioo`<000Aoo`@000Qoo`<001Qoo`03001oogoo015oo`05001o
ogooOol0000TOol00`00Oomoo`0ROol000Qoo`03001oogoo00Aoo`03001oogoo07Aoo`8000=oo`@0
00Qoo`<001Yoo`03001oogoo019oo`03001oogoo009oo`03001oogoo029oo`03001oogoo025oo`00
27oo00<007ooOol01Goo0P00Lgoo0P0000=oo`0000000P0027oo0`007Goo00<007ooOol04goo00<0
07ooOol00Woo00<007ooOol08Goo00<007ooOol08Goo0008Ool00`00Oomoo`07Ool00`00Oomoo`1_
Ool50008Ool3000OOol00`00Oomoo`0EOol01@00Oomoogoo000097oo00<007ooOol087oo0008Ool0
0`00Oomoo`08Ool00`00Oomoo`1]Ool@000OOol00`00Oomoo`0FOol00`00Oomoo`02Ool00`00Oomo
o`0ROol00`00Oomoo`0OOol000Moo`03001oogoo00Yoo`03001oogoo06Uoo`<000Ioo`L0029oo`03
001oogoo01Moo`03001oogoo009oo`03001oogoo025oo`03001oogoo01moo`001goo00<007ooOol0
2goo00<007ooOol0IWoo0P002Goo0`009Goo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol0
8Goo00<007ooOol07Woo0007Ool00`00Oomoo`0<Ool00`00Oomoo`1ROol30008Ool3000XOol00`00
Oomoo`0JOol01@00Oomoogoo000097oo00<007ooOol07Goo0007Ool00`00Oomoo`0=Ool00`00Oomo
o`1NOol30008Ool3000ZOol00`00Oomoo`0KOol01000Oomoogoo0P008goo00<007ooOol07Goo0007
Ool00`00Oomoo`0>Ool00`00Oomoo`1JOol30008Ool3000]Ool00`00Oomoo`0LOol01P00Oomoo`00
Ool002=oo`03001oogoo01aoo`001goo00<007ooOol03goo00<007ooOol0EWoo0`0027oo0`00;goo
00<007ooOol07Woo00<007ooOol00P0097oo00<007ooOol06goo0007Ool00`00Oomoo`0@Ool00`00
Oomoo`1BOol30008Ool3000bOol00`00Oomoo`0NOol01P00Oomoo`00Ool0009oo`03001oogoo01io
o`03001oogoo01]oo`001Woo00<007ooOol04Woo00<007ooOol0Cgoo0P002Goo0P003Woo00@007oo
Ool0029oo`03001oogoo021oo`08001oogoo001oo`00Ool0025oo`03001oogoo01Yoo`001Woo00<0
07ooOol04goo00<007ooOol0Bgoo0`0027oo0`004Goo0P008goo00<007ooOol08Goo00<007oo0000
0Woo0P008Woo00<007ooOol06Goo0006Ool00`00Oomoo`0DOol00`00Oomoo`17Ool30008Ool3000D
Ool2000ROol00`00Oomoo`0SOol20002Ool2000ROol00`00Oomoo`0IOol000Ioo`03001oogoo01Eo
o`03001oogoo04=oo`<000Qoo`<001Ioo`04001oogoo000QOol00`00Oomoo`0MOol00`00Oomoo`03
Ool00`00Ool00002Ool00`00Oomoo`0QOol00`00Oomoo`0HOol000Ioo`03001oogoo01Ioo`80041o
o`<000Qoo`<003eoo`03001oogoo01moo`8000Aoo`800004Ool007oo000SOol00`00Oomoo`0GOol0
00Ioo`03001oogoo01Qoo`03001oogoo03Yoo`<000Qoo`<0041oo`03001oogoo025oo`8000=oo`<0
009oo`03001oogoo021oo`03001oogoo01Moo`001Goo00<007ooOol06Woo00<007ooOol0=goo0P00
27oo0`00@Woo00<007ooOol097oo0P000Woo0P000Woo00<007ooOol08Goo00<007ooOol05Woo0005
Ool00`00Oomoo`0KOol00`00Oomoo`0cOol30007Ool30015Ool00`00Oomoo`0VOol40003Ool00`00
Oomoo`0QOol00`00Oomoo`0EOol000Eoo`03001oogoo01aoo`03001oogoo02moo`<000Qoo`8004Mo
o`03001oogoo02Uoo`8000Aoo`03001oogoo021oo`03001oogoo01Eoo`001Goo00<007ooOol07Goo
00<007ooOol0:goo0`0027oo0`00B7oo00<007ooOol0<7oo00<007ooOol08Goo00<007ooOol057oo
0005Ool00`00Oomoo`0NOol00`00Oomoo`0WOol30008Ool3001;Ool00`00Oomoo`0aOol00`00Oomo
o`0QOol00`00Oomoo`0COol000Eoo`03001oogoo01moo`03001oogoo02=oo`<000Qoo`<004eoo`03
001oogoo03=oo`03001oogoo021oo`03001oogoo01=oo`001Goo00<007ooOol087oo00<007ooOol0
87oo0P0027oo0`00D7oo00<007ooOol0=7oo00<007ooOol087oo00<007ooOol04Woo0004Ool00`00
Oomoo`0ROol00`00Oomoo`0LOol30007Ool3001BOol00`00Oomoo`0eOol00`00Oomoo`0POol00`00
Oomoo`0BOol000Aoo`03001oogoo02=oo`03001oogoo01Qoo`<000Moo`<005Eoo`03001oogoo039o
o`80009oo`03001oogoo021oo`03001oogoo015oo`0017oo00<007ooOol097oo00<007ooOol057oo
0`001goo0`00Egoo00<007ooOol0=7oo00D007ooOomoo`00029oo`03001oogoo011oo`0017oo00<0
07ooOol09Goo00<007ooOol047oo0`0027oo0P00FWoo00<007ooOol0=7oo00<007ooOol00Woo00<0
07ooOol07goo00<007ooOol047oo0004Ool00`00Oomoo`0VOol2000=Ool30008Ool3001KOol00`00
Oomoo`0dOol00`00Ool00003Ool00`00Oomoo`0POol00`00Oomoo`0?Ool000Aoo`03001oogoo02Qo
o`03001oogoo00Qoo`8000Qoo`<005ioo`03001oogoo03Aoo`03001oo`0000Aoo`03001oogoo021o
o`03001oogoo00ioo`0017oo00<007ooOol0:Goo00<007ooOol017oo0`001goo0`00H7oo00<007oo
Ool0=7oo0P0000=oo`00000017oo00<007ooOol07goo00<007ooOol03Woo0003Ool00`00Oomoo`0[
Ool00`00Oomoo`030007Ool3001SOol00`00Oomoo`0mOol00`00Oomoo`0POol00`00Oomoo`0=Ool0
00=oo`03001oogoo02]oo`<000Moo`<006Eoo`03001oogoo03moo`03001oogoo021oo`03001oogoo
00aoo`000goo00<007ooOol0:7oo0`000Woo00<007ooOol00Woo0`00J7oo00<007ooOol0@7oo00<0
07ooOol07goo00<007ooOol037oo0003Ool00`00Oomoo`0UOol30006Ool01000Ool00000JWoo00<0
07ooOol0@Woo00<007ooOol07goo00<007ooOol02goo0003Ool00`00Oomoo`0ROol30008Ool3001/
Ool00`00Oomoo`12Ool00`00Oomoo`0POol00`00Oomoo`0:Ool000=oo`03001oogoo021oo`8000Qo
o`<000=oo`03001oogoo06Qoo`03001oogoo04Aoo`03001oogoo01moo`03001oogoo00Yoo`000Woo
00<007ooOol07Woo0`001goo0`001goo00<007ooOol0Igoo00<007ooOol0AGoo00<007ooOol07goo
00<007ooOol02Goo0002Ool00`00Oomoo`0KOol30007Ool3000;Ool00`00Oomoo`1UOol00`00Oomo
o`17Ool00`00Oomoo`0OOol00`00Oomoo`08Ool0009oo`03001oogoo01Qoo`<000Moo`<000moo`03
001oogoo06=oo`03001oogoo04Qoo`03001oogoo01moo`03001oogoo00Qoo`000Woo00<007ooOol0
5Goo0`001goo0`004goo00<007ooOol0HWoo00<007ooOol0BGoo00<007ooOol07goo00<007ooOol0
1goo0002Ool00`00Oomoo`0BOol30005Ool5000GOol00`00Oomoo`04Ool2001JOol00`00Oomoo`1;
Ool00`00Oomoo`0OOol00`00Oomoo`06Ool0009oo`03001oogoo011oo`80009oo`03001oogoo00=o
o`8000Ioo`03001oogoo00]oo`03001oogoo00Aoo`8000Eoo`03001oogoo05Qoo`03001oogoo04]o
o`03001oogoo01moo`03001oogoo00Ioo`000Woo00<007ooOol03Goo1@000Woo0P0000=oo`000000
0P000Woo0`000Woo0P001goo0`000Woo0P001goo0`000Woo00<007ooOol0Egoo00<007ooOol0CGoo
00<007ooOol07Woo0P001goo00000goo001oo`0<Ool30002Ool20003Ool30002Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Ool0000;Ool30003Ool00`00Oomoo`1FOol00`00Oomoo`1>Ool00`00
Oomoo`0IOol400000goo001oo`06Ool00003Ool007oo00Yoo`8000=oo`04001oogooOol30006Ool0
1@00Oomoogoo000037oo00<007oo00002goo00<007oo00000Woo00<007ooOol0EWoo00<007ooOol0
D7oo00<007ooOol05Goo0`001Goo00<007ooOol01Goo00000goo001oo`0;Ool00`00Oomoo`02Ool4
0008Ool01@00Oomoogoo000037oo00<007oo00002goo00H007oo000007oo001HOol00`00Oomoo`1@
Ool00`00Oomoo`0BOol30008Ool00`00Oomoo`05Ool00003Ool007oo00aoo`@00004Ool000000008
Ool200000goo0000000<Ool3000;Ool300000goo0000001GOol00`00Oomoo`1BOol00`00Oomoo`0=
Ool4000;Ool00`00Oomoo`05Ool00003Ool007oo00Yoo`D0035oo`03001oogoo05Eoo`03001oogoo
05=oo`03001oogoo00Uoo`<0011oo`03001oogoo00Aoo`0000=oo`00Ool027oo0P001Goo00<007oo
Ool0;goo00<007ooOol0Dgoo00<007ooOol0EGoo00<007ooOol01Goo0`004goo00<007ooOol017oo
00000`00Oomoo`05Ool30008Ool00`00Oomoo`0_Ool00`00Oomoo`1BOol00`00Oomoo`1EOol01000
Oomoogoo10005Woo00<007ooOol017oo00000`00Oomoo`02Ool3000<Ool00`00Oomoo`0_Ool00`00
Oomoo`1@Ool00`00Oomoo`1GOol3000JOol00`00Oomoo`04Ool00003001oo`000080011oo`03001o
ogoo02moo`03001oogoo04moo`03001oogoo05=oo`@00003Ool007oo01Yoo`03001oogoo00Aoo`00
0P0057oo0P00<7oo00<007ooOol0CGoo00<007ooOol0DGoo0`001Woo00<007ooOol067oo00<007oo
Ool017oo00000goo001oo`0EOol00`00Oomoo`0^Ool00`00Oomoo`1<Ool00`00Oomoo`1>Ool30009
Ool00`00Oomoo`0HOol00`00Oomoo`04Ool0009oo`8001Eoo`03001oogoo02ioo`03001oogoo04Yo
o`03001oogoo04]oo`@000eoo`03001oogoo01Moo`03001oogoo00Aoo`0017oo00<007ooOol04goo
00<007ooOol0;Woo0P00BGoo00<007ooOol0BGoo0`004Woo00<007ooOol05goo00<007ooOol00goo
0005Ool00`00Oomoo`0COol00`00Oomoo`0_Ool00`00Oomoo`16Ool00`00Oomoo`15Ool4000EOol0
0`00Oomoo`0GOol00`00Oomoo`03Ool000Ioo`03001oogoo01=oo`03001oogoo02moo`03001oogoo
04Aoo`03001oogoo04=oo`<001Yoo`03001oogoo01Ioo`03001oogoo00=oo`001goo00<007ooOol0
4goo0P00<7oo00<007ooOol0@goo00<007ooOol0@7oo0`007Woo00<007ooOol05Goo00<007ooOol0
0goo0008Ool2000EOol00`00Oomoo`0^Ool00`00Oomoo`11Ool00`00Oomoo`0mOol4000ROol00`00
Oomoo`0DOol00`00Oomoo`03Ool000Yoo`03001oogoo01=oo`03001oogoo02ioo`03001oogoo041o
o`03001oogoo03Yoo`<002Ioo`03001oogoo01Aoo`03001oogoo00=oo`002goo00<007ooOol04goo
00<007ooOol0;Woo00<007ooOol0?Woo00<007ooOol0>7oo0`00:Woo00<007ooOol04goo00<007oo
Ool00goo000<Ool00`00Oomoo`0COol00`00Oomoo`0^Ool00`00Oomoo`0mOol00`00Oomoo`0dOol4
000^Ool00`00Oomoo`0BOol00`00Oomoo`03Ool000eoo`8001Aoo`03001oogoo02ioo`03001oogoo
03]oo`03001oogoo039oo`<003=oo`03001oogoo019oo`03001oogoo009oo`003goo00<007ooOol0
4Woo0P00;goo00<007ooOol0>Woo00<007ooOol0;Woo1000=Woo00<007ooOol04Woo00<007ooOol0
0Woo000@Ool00`00Oomoo`0COol00`00Oomoo`0]Ool00`00Oomoo`0hOol00`00Oomoo`0/Ool3000k
Ool00`00Oomoo`0AOol00`00Oomoo`02Ool0015oo`03001oogoo01=oo`03001oogoo02eoo`03001o
ogoo03Moo`<002Uoo`<003moo`03001oogoo011oo`03001oogoo009oo`004Woo00<007ooOol04goo
00<007ooOol0;Goo00<007ooOol0=Goo00@007ooOomoo`H001moo`@0049oo`03001oogoo011oo`03
001oogoo009oo`004goo0P0057oo00<007ooOol0;Goo0P00=Goo00<007ooOol01goo1P005Woo0`00
8Woo00<007ooOol08Woo00<007ooOol03goo00<007ooOol00Woo000EOol00`00Oomoo`0BOol2000_
Ool00`00Oomoo`0aOol00`00Oomoo`0>Ool6000<Ool4000VOol00`00Oomoo`0ROol00`00Oomoo`0>
Ool00`00Oomoo`02Ool001Ioo`03001oogoo01=oo`03001oogoo02eoo`03001oogoo031oo`03001o
ogoo01Aoo`D000Aoo`<002]oo`03001oogoo029oo`03001oogoo00eoo`03001oogoo009oo`005goo
00<007ooOol04goo00<007ooOol0;Goo00<007ooOol0;Woo00<007ooOol06Woo1P00;Goo00<007oo
Ool08Goo00<007ooOol03Woo00<007ooOol00Goo000HOol2000DOol00`00Oomoo`0]Ool00`00Oomo
o`0]Ool00`00Oomoo`0GOol40005Ool6000XOol2000ROol00`00Oomoo`0=Ool00`00Oomoo`01Ool0
01Yoo`03001oogoo019oo`03001oogoo02eoo`03001oogoo02]oo`03001oogoo01Eoo`<000moo`D0
02Aoo`80029oo`03001oogoo00aoo`03001oogoo005oo`006goo00<007ooOol04Woo00<007ooOol0
;Goo00<007ooOol0:Goo00<007ooOol04goo0`005goo1P007goo0P008Woo00<007ooOol02goo00<0
07ooOol00Goo000LOol00`00Oomoo`0BOol2000^Ool00`00Oomoo`0XOol00`00Oomoo`0?Ool4000P
Ool6000IOol2000ROol00`00Oomoo`0;Ool00`00Oomoo`01Ool001eoo`03001oogoo01=oo`03001o
ogoo02aoo`03001oogoo02Ioo`03001oogoo00eoo`<002Yoo`H001Aoo`80029oo`03001oogoo00Yo
o`03001oogoo005oo`007Woo0P0057oo00<007ooOol0;7oo00<007ooOol09Goo00<007ooOol02Goo
1000<goo1@0047oo0P008Woo00<007ooOol02Goo00<007ooOol00Goo000POol00`00Oomoo`0BOol0
0`00Oomoo`0/Ool00`00Oomoo`0SOol00`00Oomoo`07Ool3000lOol6000;Ool2000QOol00`00Oomo
o`09Ool00`00Oomoo`01Ool0025oo`03001oogoo019oo`03001oogoo02aoo`03001oogoo029oo`03
001oogoo00Aoo`<004Eoo`H000Ioo`03001oogoo021oo`03001oogoo00Uoo`40005oo`5oo`008Woo
00<007ooOol04Woo0P00;Goo00<007ooOol087oo00@007ooOomoo`@004ioo`H00003Ool007oo025o
o`03001oogoo00Qoo`40005oo`5oo`008goo0P0057oo00<007ooOol0:goo00<007ooOol07goo1000
F7oo0`008Woo00<007ooOol01goo0@000Goo0Goo000UOol00`00Oomoo`0BOol00`00Oomoo`0[Ool2
000LOol4001HOol5000SOol00`00Oomoo`07Ool10001Ool1Ool002Ioo`03001oogoo019oo`03001o
ogoo02aoo`03001oogoo01Ioo`<0009oo`03001oogoo05=oo`@0009oo`03001oogoo02Aoo`03001o
ogoo00Ioo`40005oo`5oo`009goo00<007ooOol04Woo00<007ooOol0;7oo00<007ooOol04Woo0`00
17oo00<007ooOol0D7oo10001Goo00<007ooOol09Woo00<007ooOol01Goo0@000Goo0Goo000XOol0
0`00Oomoo`0BOol00`00Oomoo`0/Ool00`00Oomoo`0=Ool40007Ool00`00Oomoo`1=Ool30007Ool2
000ZOol00`00Oomoo`04Ool10001Ool1Ool002Uoo`8001=oo`8002eoo`03001oogoo00Uoo`<000Yo
o`03001oogoo05Moo`03001oogoo02Yoo`03001oogoo00Aoo`40005oo`5oo`00:goo00<007ooOol0
4Woo00<007ooOol0:goo00<007ooOol01Goo0`003Goo00<007ooOol0EWoo00<007ooOol0;7oo00<0
07ooOol017oo0@000Goo000/Ool00`00Oomoo`0BOol00`00Oomoo`0[Ool00`00Oomoo`04000?Ool0
0`00Oomoo`1EOol2000`Ool00`00Oomoo`03Ool10001Ool002eoo`03001oogoo019oo`03001oogoo
02]oo`8001=oo`03001oogoo05Aoo`03001oogoo031oo`03001oogoo00=oo`40005oo`00;Woo0P00
4goo00<007ooOol0:Woo00<007ooOol04Goo00<007ooOol0RGoo00<007ooOol00Woo0@000Goo000`
Ool00`00Oomoo`0AOol00`00Oomoo`0YOol00`00Oomoo`0AOol00`00Oomoo`2:Ool01@00Oomoogoo
00000Goo000aOol00`00Oomoo`0AOol2000YOol00`00Oomoo`0@Ool00`00Oomoo`2<Ool01000Oomo
o`000Goo000bOol00`00Oomoo`0BOol00`00Oomoo`0VOol00`00Oomoo`0?Ool00`00Oomoo`2=Ool0
1000Oomoo`000Goo000cOol00`00Oomoo`0BOol00`00Oomoo`0UOol00`00Oomoo`0?Ool00`00Oomo
o`2>Ool00`00Ool00001Ool003Aoo`8001=oo`03001oogoo02Aoo`03001oogoo00ioo`03001oogoo
091oo`40005oo`400000=Woo00<007ooOol04Goo00<007ooOol08goo00<007ooOol03Woo00<007oo
Ool0TGoo0P00000gOol00`00Oomoo`0AOol2000SOol00`00Oomoo`0=Ool00`00Oomoo`2BOol20000
03Qoo`03001oogoo019oo`03001oogoo021oo`03001oogoo00eoo`03001oogoo099oo`800000>Goo
0P004goo00<007ooOol07goo00<007ooOol037oo00<007ooOol0Sgoo10000Woo000kOol00`00Oomo
o`0AOol00`00Oomoo`0NOol00`00Oomoo`0<Ool00`00Oomoo`2;Ool40006Ool003aoo`03001oogoo
015oo`03001oogoo01eoo`03001oogoo00]oo`03001oogoo08Qoo`@000Yoo`00?Goo00<007ooOol0
4Goo00<007ooOol077oo00<007ooOol02goo00<007ooOol0Q7oo10003Woo000nOol00`00Oomoo`0A
Ool2000KOol00`00Oomoo`0;Ool00`00Oomoo`22Ool3000BOol003moo`8001=oo`03001oogoo01Qo
o`03001oogoo00]oo`03001oogoo07ioo`@001Eoo`00@Goo00<007ooOol04Goo00<007ooOol05goo
00<007ooOol02Woo00<007ooOol0Ngoo10006Goo0012Ool00`00Oomoo`0AOol00`00Oomoo`0FOol0
0`00Oomoo`0:Ool00`00Oomoo`1gOol4000MOol004=oo`03001oogoo015oo`03001oogoo01Eoo`03
001oogoo00Uoo`03001oogoo07Aoo`@0025oo`00A7oo0P004Woo0P005Goo00<007ooOol02Goo00<0
07ooOol0L7oo10009Goo0016Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`08Ool00`00
Oomoo`1^Ool3000YOol004Moo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Moo`03001o
ogoo06]oo`@002aoo`00B7oo00<007ooOol04Goo00<007ooOol047oo00<007ooOol01goo00<007oo
Ool0Igoo1000<7oo0019Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`06Ool00`00Oomo
o`1TOol4000dOol004Yoo`80019oo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo061oo`@0
03Qoo`00C7oo00<007ooOol047oo0P003Woo00<007ooOol01Goo00<007ooOol0GWoo0`00?7oo001=
Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`1JOol4000oOol004io
o`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo05Moo`@004=oo`00Cgoo
0P004Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol0Dgoo1000Agoo001AOol00`00Oomo
o`0@Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1@Ool4001;Ool0059oo`03001oogoo
011oo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo04aoo`@004moo`00Dgoo00<007ooOol0
47oo0P001goo00<007ooOol00Woo00<007ooOol0BWoo0`00Dgoo001DOol00`00Oomoo`0AOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`16Ool4001FOol005Eoo`80019oo`03001oogoo00=o
o`05001oogooOol00015Ool4001JOol005Moo`03001oogoo011oo`03001oogoo009oo`05001oogoo
Ool00011Ool4001NOol005Qoo`03001oogoo011oo`05001oogooOol00002Ool00`00Oomoo`0=Ool2
000ROol20009Ool4001ROol005Uoo`03001oogoo011oo`800005Ool007ooOol0000:Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool3001VOol0
05Yoo`80019oo`800003Ool007oo009oo`03001oogoo00<0009oo`8000=oo`04001oogooOol30002
Ool20007Ool300000goo00000007Ool30003Ool00`00Oomoo`04001YOol005aoo`03001oogoo011o
o`04001oo`00Ool20003Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool0
0`00Ool00002Ool4001]Ool005eoo`03001oogoo00moo`8000Aoo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Uoo`D00003Ool007oo06ioo`00GWoo
00<007ooOol03Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol02goo
00<007ooOol01Woo100000=oo`00Ool00Woo00<007ooOol0KGoo001OOol00`00Oomoo`0<Ool00`00
Oomoo`07Ool30007Ool20002Ool2000<Ool20004Ool40003Ool30002Ool2001_Ool0061oo`8000ao
o`03001oogoo02Ioo`<007eoo`00HWoo00<007ooOol02Goo00<007ooOol08Woo1000P7oo001SOol0
0`00Oomoo`08Ool00`00Oomoo`0NOol40024Ool006Aoo`03001oogoo00Moo`03001oogoo01Yoo`@0
08Qoo`00IGoo0P001goo00<007ooOol05Woo1000S7oo001WOol00`00Oomoo`04Ool00`00Oomoo`0C
Ool3002@Ool006Qoo`03001oogoo00=oo`03001oogoo00moo`@009=oo`00JGoo00<007ooOol00Woo
00<007ooOol02goo1000Ugoo001ZOol01@00Oomoogoo00002Goo1000Vgoo001[Ool200000goo001o
o`04Ool4002OOol006eoo`800003Ool0000000800:=oo`00KWoo0P00Ygoo0000\
\>"],
  ImageRangeCache->{{{0, 278.875}, {220.438, 0}} -> {-0.000569638, 0.0739342, 
  0.0034205, 0.0034205}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LocusPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules1, rules2, ..., rulesn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives representing a series of line segments connecting the \
location of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", when subject to ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A function for plotting the locus of a moving point."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The nested list of rules required by ",
  StyleBox["LocusPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is of the form returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism Graphics"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The spatial slider-crank mechanism model that was developed in Section 3.2 \
is used to demonstrate the use of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions to create an image of a mechanism model. Creating a \
complex mechanism image often requires more lines of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code than were used in the kinematic model of the mechanism. This is \
because of the terse nature of the data required to kinematically describe a \
mechanism. A kinematic model uses only a small number of points in space to \
define rotational and translational axes that tie the bodies together, while \
the mechanism image requires much more information about the shape of the \
bodies in the model.\n\nThe spatial slider-crank model is redefined as \
follows in abbreviated form. See Section 3.2 for a full description of this \
mechanism model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here is the complete definition of the slider-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(slider = 3; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      Body[ground, 
        PointList \[Rule] {{0, 10, 12}, {10, 10, 12}, {1, 0, 0}, {0, 1, 0}}], 
      \n\tBody[crank, PointList \[Rule] {{8, 0, 0}, {0, 8, 0}}, 
        InitialGuess \[Rule] {{0, 10, 12}, {1, 0, 0, 0}}], \n\t
      Body[slider, PointList \[Rule] {{1, 0, 0}, {0, 1, 0}}, 
        InitialGuess \[Rule] {{20, 0, 0}, {1, 0, 0, 0}}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRevolute5[1, Line[ground, 1, 2], Line[crank, 0, 1]], 
      \n\tProjectedAngle1[2, Line[crank, 0, 2], Line[ground, 0, 4], 
        Line[ground, 0, 3], 2\ \[Pi]\ T], \n\t
      RelativeDistance1[3, \n\t\tPoint[crank, 2], Point[slider, 0], 30.0], \n
      \tTranslate5[4, \n\t\tAxis[ground, 0, 3, 4], Axis[slider, 0, 1, 2]]]\)],
   "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of the graphics functions the image of the \
slider-crank mechanism that is displayed in the preceding sections is built. \
These images are generated with a mix of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions and built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Ground"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ground body of the slider-crank mechanism was generated using mostly \
built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives. The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function was used to generate a line on the crank axis referencing local \
points by their point numbers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the ground body graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(groundgraphic = 
      Graphics3D[{\n\t\t\tThickness[.008], \n\t\t\t
          Line[{{\(-1\), \(-5\), 0}, {\(-1\), 18, 0}, {35, 18, 0}, {35, 
                \(-5\), 0}, {\(-1\), \(-5\), 0}, {\(-1\), \(-5\), 22}, {
                \(-1\), 18, 22}, {\(-1\), 18, 0}}], \n\t\t\t
          Line[{{\(-1\), 1.8, 0}, {35, 1.8, 0}}], \n\t\t\t
          Line[{{\(-1\), \(-1.8\), 0}, {35, \(-1.8\), 0}}], \n\t\t\t
          Edge[ground, {1, 2}]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The text that was displayed with the ground body was generated entirely \
with the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Text",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, except for the axes at the global coordinate origin, generated \
with the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["LocalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, and the use of the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to reference the global coordinates of local point numbers on \
the ground body."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the ground body annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(groundtext = 
      Graphics3D[{\n\t\t\t
          Text["\<{0,10,12}\>", \n\t\t\t\t
            Location[ground, 1], {0.5, \(-1.6\)}], \n\t\t\t
          Text["\<P1\>", Location[ground, 1], {1.3, 0.9}], \n\t\t\t
          Text["\<{10,10,12}\>", \n\t\t\t\t
            Location[ground, 2], {\(-0.5\), 1.6}], \n\t\t\t
          Text["\<P2\>", Location[ground, 2], {\(-1.3\), \(-0.9\)}], \n\t\t\t
          Text[FontForm["\<Ground\>", \n\t\t\t\t\t{"\<Times-Bold\>", 12}], {
              24, 7, 23}], \n\t\t\tLocalAxes[ground, 8]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot1 = 
      Show[{groundgraphic, groundtext}, 
        PlotRange \[Rule] {{\(-2\), 37}, {\(-10\), 20}, {\(-4\), 24}}]; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95309 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.02544 -0.000586442 1.02544 [
[ 0 0 0 0 ]
[ 1 .95309 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
.35203 .54414 m
.06189 .25974 L
s
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
.35203 .54414 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
0 0 m
1 0 L
1 .95309 L
0 .95309 L
closepath
clip
newpath
.008 w
.33117 .90216 m
.34648 .57645 L
s
.34648 .57645 m
.90387 .39909 L
s
.12467 .36349 m
.34648 .57645 L
s
.5 Mabswid
.27066 .48472 m
.25629 .45887 L
s
.24373 .47399 m
.27066 .48472 L
s
.27066 .48472 m
.25462 .48115 L
s
.26723 .46594 m
.27066 .48472 L
s
.19219 .40862 m
.27066 .48472 L
s
.008 w
.19553 .43152 m
.78642 .2228 L
s
.08427 .70957 m
.33117 .90216 L
s
.5 Mabswid
.19219 .40862 m
.18107 .52547 L
s
.31477 .36479 m
.19219 .40862 L
s
.008 w
.27811 .67698 m
.43459 .62939 L
s
.90387 .39909 m
.73063 .13907 L
s
.15862 .39609 m
.75742 .17927 L
s
.5 Mabswid
.29769 .38187 m
.31477 .36479 L
s
.31477 .36479 m
.29057 .36237 L
s
.31477 .36479 m
.28905 .38512 L
s
.28188 .36547 m
.31477 .36479 L
s
.008 w
.12467 .36349 m
.08427 .70957 L
s
.73063 .13907 m
.12467 .36349 L
s
.5 Mabswid
.19175 .50918 m
.18107 .52547 L
s
.18107 .52547 m
.17108 .50565 L
s
.18107 .52547 m
.19569 .49725 L
s
.1749 .49368 m
.18107 .52547 L
s
gsave
.27811 .67698 -104.5 .5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
111.000000 14.437500 moveto
(<) show
117.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.27811 .67698 -79.4 -18.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P1) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.43459 .62939 -77 -23.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
87.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
105.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(12) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
117.000000 14.437500 moveto
(<) show
123.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.43459 .62939 -58.6 -4.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P2) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.65043 .71238 -84 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Ground) show
104.250000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
gsave
.31477 .36479 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.27066 .48472 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.18107 .52547 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.19219 .40862 -72.5 -21.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
.25 Mabswid
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{276, 263},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004D00011a000`40O003h00OaGoo0P00CGoo0033
Ool200000goo0000001<Ool00<1oo`<000=oo`8004aoo`00_Woo0P001Woo00<007oo0000Bgoo002k
Ool30008Ool01000Oomoo`00BWoo002iOol2000;Ool01000Oomoo`00BWoo002fOol3000=Ool01@00
Oomoogoo0000BGoo002dOol2000@Ool01@00Oomoogoo0000BGoo002aOol3000COol01@00Oomoogoo
0000B7oo002_Ool2000FOol00`00Oomoo`02Ool00`00Oomoo`15Ool00:aoo`<001Qoo`03001oogoo
009oo`03001oogoo04Eoo`00ZWoo0P006goo00<007ooOol00goo00<007ooOol0A7oo002WOol3000M
Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00:Eoo`80021oo`03001oogoo00Aoo`03001oogoo04=o
o`00XWoo0`008Woo00<007ooOol01Goo00<007ooOol0@Woo002POol2000UOol00`00Oomoo`05Ool0
0`00Oomoo`12Ool009eoo`<002Moo`03001oogoo00Ioo`03001oogoo045oo`00Vgoo0P00:Woo00<0
07ooOol01goo00<007ooOol0@7oo002HOol3000/Ool00`00Oomoo`07Ool00`00Oomoo`10Ool009Eo
o`<002moo`03001oogoo00Qoo`03001oogoo03moo`00Tgoo0P00<Woo00<007ooOol02Goo00<007oo
Ool0?Woo002@Ool3000dOol00`00Oomoo`09Ool00`00Oomoo`0nOol008ioo`8003Qoo`03001oogoo
00Uoo`03001oogoo03eoo`00Rgoo0`00>Woo00<007ooOol02Goo00<007ooOol0?Goo0029Ool2000m
Ool00`00Oomoo`0:Ool00`00Oomoo`0lOol008Ioo`<003moo`03001oogoo00]oo`03001oogoo03]o
o`00Q7oo0P00@Woo00<007ooOol02goo00<007ooOol0>goo0021Ool30014Ool00`00Oomoo`0<Ool0
0`00Oomoo`0jOol007moo`8004Moo`03001oogoo00eoo`03001oogoo03Uoo`00O7oo0`00BGoo00<0
07ooOol03Goo00<007ooOol0>Goo001jOol2001<Ool00`00Oomoo`0>Ool00`00Oomoo`0hOol007Mo
o`<004ioo`03001oogoo00ioo`03001oogoo03Qoo`00MGoo0P00DGoo00<007ooOol03goo00<007oo
Ool0=goo001bOol3001COol00`00Oomoo`0@Ool00`00Oomoo`0fOol0071oo`8005Ioo`03001oogoo
011oo`03001oogoo03Ioo`00KGoo0`00F7oo00<007ooOol04Goo00<007ooOol0=Goo001[Ool2001L
Ool00`00Oomoo`0AOol00`00Oomoo`0dOol006Qoo`<005ioo`03001oogoo015oo`03001oogoo03Ao
o`00IWoo0P00H7oo0P0057oo00<007ooOol0<goo001SOol3001OOol5000EOol00`00Oomoo`0bOol0
065oo`8005moo`P001Eoo`03001oogoo039oo`00GWoo0`00Ggoo1P000goo0P005Goo00<007ooOol0
<Goo001LOol2001OOol60006Ool2000EOol00`00Oomoo`0aOol005Uoo`<005ioo`L000Qoo`<001Eo
o`03001oogoo031oo`00Egoo0P00Ggoo1P002goo00@007oo000001Eoo`03001oogoo02moo`00E7oo
0`00GWoo1P003Woo00@007ooOol001Eoo`03001oogoo02moo`00DWoo0P00GWoo1`0047oo00<007oo
Ool00P005Goo00<007ooOol0;Woo001?Ool3001MOol7000COol01000Oomoogoo0P005Goo00<007oo
Ool0;Goo001=Ool2001NOol6000FOol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`0]Ool0
04Yoo`<005eoo`H001Uoo`03001oogoo009oo`<001Aoo`03001oogoo02aoo`00B7oo0P00GGoo1`00
77oo00<007ooOol01@004goo00<007ooOol0;7oo0015Ool3001MOol6000OOol7000EOol00`00Oomo
o`0[Ool004=oo`8005eoo`H0021oo`H0009oo`8001Eoo`03001oogoo02Yoo`00@7oo0`00G7oo1`00
7goo1P001Woo0P0057oo00<007ooOol0:Woo000mOol3001LOol7000OOol700000goo001oo`06Ool0
0`00Oomoo`0COol00`00Oomoo`0YOol003]oo`8005eoo`H001moo`L000Aoo`03001oogoo00Eoo`80
01Eoo`03001oogoo02Qoo`00>7oo0`00G7oo1P007goo1`001goo00<007ooOol01Woo0P0057oo00<0
07ooOol0:7oo000fOol2001LOol7000OOol6000:Ool00`00Oomoo`07Ool2000DOol00`00Oomoo`0W
Ool003=oo`<005aoo`H001moo`H000eoo`03001oogoo00Qoo`03001oogoo019oo`03001oogoo02Mo
o`00<Goo0P00G7oo1P007goo1`003goo00<007ooOol027oo0P0057oo00<007ooOol09Woo000^Ool3
001KOol7000NOol7000BOol00`00Oomoo`09Ool2000DOol00`00Oomoo`0UOol002aoo`8005]oo`L0
01ioo`L001Eoo`03001oogoo00Yoo`8001=oo`03001oogoo02Eoo`00:Goo0`00Fgoo1P007goo1P00
67oo00<007ooOol027oo1@004goo00<007ooOol097oo000WOol2001KOol6000OOol6000KOol00`00
Oomoo`05Ool8000DOol00`00Oomoo`0SOol002Aoo`<005Yoo`L001ioo`L001eoo`03001oogoo009o
o`L000=oo`03001oogoo019oo`03001oogoo02=oo`008Woo0P00Fgoo1P007Woo1`008Goo00<007oo
00001@001Woo0P0057oo00<007ooOol08Woo000OOol3001JOol6000NOol7000SOol6000:Ool2000D
Ool00`00Oomoo`0QOol001eoo`8005Yoo`L001ioo`H002=oo`L000eoo`03001oogoo019oo`03001o
ogoo025oo`006Woo0`00FGoo1`007Woo1P008goo20003goo0P0057oo00<007ooOol087oo000HOol2
001JOol6000NOol7000ROol70003Ool00`00Oomoo`0>Ool2000COol00`00Oomoo`0POol001Eoo`<0
05Uoo`H001ioo`L0029oo`L000Ioo`03001oogoo00moo`03001oogoo019oo`03001oogoo01moo`00
4goo0P00FGoo1`007Goo1`008Woo1`002Goo00<007ooOol03goo0P0057oo00<007ooOol07Woo000A
Ool2001HOol7000NOol6000SOol6000<Ool00`00Oomoo`0@Ool2000COol00`00Oomoo`0NOol0015o
o`8005Ioo`H001ioo`H002=oo`H000moo`03001oogoo015oo`03001oogoo019oo`03001oogoo01eo
o`004Goo00<007oo0000DWoo1P007Woo1`008Woo1`004Goo00<007ooOol04Goo0P0057oo00<007oo
Ool077oo000AOol01000Oomoo`00CWoo1`007Goo1`008Woo1`0057oo00<007ooOol04Woo0P004goo
00<007ooOol077oo000@Ool00`00Oomoo`02Ool00`00Oomoo`19Ool6000MOol7000ROol7000GOol0
0`00Oomoo`0COol00`00Oomoo`0BOol00`00Oomoo`0KOol0011oo`03001oogoo00=oo`03001oogoo
04Eoo`H001ioo`H0029oo`L001Yoo`03001oogoo01=oo`8001=oo`03001oogoo01]oo`0047oo00<0
07ooOol017oo00<007ooOol0@Goo1`007Goo1P008Woo1`007Goo00<007ooOol057oo0P004goo00<0
07ooOol06Woo000@Ool00`00Oomoo`05Ool00`00Oomoo`0mOol7000MOol7000ROol6000QOol00`00
Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`0IOol0011oo`03001oogoo00Ioo`03001oogoo03Yo
o`H001eoo`L0029oo`H002Aoo`03001oogoo01Aoo`8001=oo`03001oogoo01Uoo`0047oo00<007oo
Ool01goo00<007ooOol0=Woo1P007Woo1P008Woo1`009Woo00<007ooOol05Goo0P004goo00<007oo
Ool067oo000@Ool00`00Oomoo`08Ool00`00Oomoo`0bOol7000MOol6000ROol7000YOol00`00Oomo
o`0FOol00`00Oomoo`0BOol00`00Oomoo`0GOol000moo`03001oogoo00Yoo`03001oogoo02moo`H0
01eoo`L0025oo`L002aoo`03001oogoo01Ioo`8001=oo`03001oogoo01Moo`003goo00<007ooOol0
2goo00<007ooOol0:goo1P007Goo1`008Goo1`00;goo00<007ooOol05goo0P004goo00<007ooOol0
5Woo000?Ool00`00Oomoo`0<Ool00`00Oomoo`0WOol7000LOol7000QOol7000bOol00`00Oomoo`0H
Ool00`00Oomoo`0AOol00`00Oomoo`0FOol000moo`03001oogoo00eoo`03001oogoo02=oo`L001eo
o`H0029oo`H003Eoo`03001oogoo01Qoo`8001=oo`03001oogoo01Eoo`003goo00<007ooOol03Woo
00<007ooOol087oo1P007Goo1P008Woo1P00>7oo00<007ooOol06Goo0P004goo00<007ooOol057oo
000?Ool00`00Oomoo`0?Ool00`00Oomoo`0LOol6000MOol7000QOol7000jOol00`00Oomoo`0JOol0
0`00Oomoo`0AOol00`00Oomoo`0DOol000moo`03001oogoo011oo`03001oogoo01Qoo`L001aoo`L0
025oo`L003eoo`03001oogoo01Yoo`8001=oo`03001oogoo01=oo`003Woo00<007ooOol04Woo00<0
07ooOol05Goo1P0077oo1`008Goo1`00@7oo00<007ooOol06goo0P004goo00<007ooOol04Woo000>
Ool00`00Oomoo`0COol00`00Oomoo`0AOol6000MOol6000QOol70013Ool00`00Oomoo`0LOol00`00
Oomoo`0AOol00`00Oomoo`0BOol000ioo`03001oogoo01Aoo`03001oogoo00eoo`L001aoo`H0025o
o`L004Ioo`03001oogoo01aoo`8001=oo`03001oogoo015oo`003Woo00<007ooOol05Goo00<007oo
Ool02Goo1`0077oo1`0087oo1`00BWoo00<007ooOol077oo0P004Woo00<007ooOol04Goo000>Ool0
0`00Oomoo`0FOol00`00Oomoo`06Ool6000LOol7000QOol6001=Ool00`00Oomoo`0MOol2000BOol0
0`00Oomoo`0@Ool000ioo`03001oogoo01Moo`03001oogoo009oo`H001aoo`L0025oo`H0051oo`03
001oogoo01ioo`03001oogoo015oo`03001oogoo00moo`003Woo00<007ooOol067oo200077oo1P00
8Goo1`00DWoo00<007ooOol07Woo0P004Woo00<007ooOol03goo000=Ool00`00Oomoo`0HOol6000L
Ool6000QOol7001EOol00`00Oomoo`0OOol2000AOol2000@Ool000eoo`03001oogoo01Eoo`L001]o
o`L0021oo`L005Qoo`03001oogoo021oo`03001oogoo00aoo`<00003Ool007oo00moo`003Goo00<0
07ooOol04Woo1`000goo00<007ooOol05Goo1`0087oo1`00Fgoo00<007ooOol087oo0P002Woo0`00
17oo00<007ooOol03Woo000=Ool00`00Oomoo`0AOol50007Ool00`00Oomoo`0AOol70007Ool4000E
Ool7001NOol00`00Oomoo`0QOol20006Ool30007Ool00`00Oomoo`0>Ool000eoo`03001oogoo015o
o`@000Ioo`D000moo`H000Qoo`X000moo`H0065oo`03001oogoo029oo`04001oogooOol3000;Ool0
0`00Oomoo`0=Ool000eoo`03001oogoo015oo`D000Moo`03001oo`0000aoo`H0011oo`@000eoo`H0
06Aoo`03001oogoo029oo`@000ioo`03001oogoo00eoo`003Goo00<007ooOol04Goo0P0000Aoo`00
000000Ioo`04001oogoo0008Ool7000?Ool300000goo0000000;Ool7001VOol00`00Oomoo`0POol5
000?Ool00`00Oomoo`0=Ool000eoo`03001oogoo015oo`80009oo`<000Eoo`05001oogooOol00004
Ool7000@Ool20003Ool00`00Oomoo`08Ool7001YOol00`00Oomoo`0LOol40004Ool00`00Oomoo`0=
Ool00`00Oomoo`0=Ool000aoo`03001oogoo019oo`8000=oo`<000Aoo`03001oogoo009oo`P0011o
o`<000=oo`8000Qoo`L006aoo`03001oogoo01Uoo`<000Qoo`8000ioo`03001oogoo00eoo`0037oo
00<007ooOol04Woo0P0017oo0`000Woo0P000goo1P0047oo0`001Goo00<007ooOol01Goo1`00Kgoo
00<007ooOol05Woo0`0037oo0P003Goo00<007ooOol03Goo000<Ool00`00Oomoo`0BOol20005Ool3
0003Ool7000?Ool3000=Ool7001cOol00`00Oomoo`0BOol3000@Ool00`00Oomoo`0;Ool00`00Oomo
o`0=Ool000aoo`03001oogoo019oo`8000Ioo`T000=oo`03001oogoo00Uoo`<000ioo`H007Ioo`03
001oogoo00moo`<001=oo`8000aoo`03001oogoo00eoo`0037oo00<007ooOol04Goo0P0027oo1@00
1goo00<007ooOol01Goo0`003Woo1P001Woo00@007ooOol006moo`03001oogoo00aoo`<001Moo`80
00aoo`03001oogoo00aoo`0037oo00<007ooOol04Goo0P002Goo0`002Goo00<007ooOol00Woo0P00
3Woo1`002Goo0P00L7oo00<007ooOol02Goo0`0067oo100037oo00<007ooOol037oo000<Ool00`00
Oomoo`0AOol2000:Ool30009Ool4000=Ool7000<Ool2001`Ool00`00Oomoo`06Ool3000HOol7000<
Ool00`00Oomoo`0<Ool000]oo`03001oogoo019oo`8000]oo`<000Ioo`<00003Ool007oo00Yoo`L0
00ioo`04001oogoo001_Ool00`00Oomoo`03Ool3000HOol6000@Ool00`00Oomoo`0<Ool000]oo`03
001oogoo019oo`8000aoo`<000=oo`8000Eoo`03001oogoo00Eoo`L008Aoo`03001oogoo00<001Qo
o`H001=oo`03001oogoo00aoo`002goo00<007ooOol04Woo0P003Goo0`000Woo0P001Woo00@007oo
Oomoo`L008Moo`<001Qoo`H001Ioo`03001oogoo00aoo`002goo00<007ooOol04Woo0P003Woo1@00
00=oo`00Ool01Goo1`00Qgoo10005goo1P006Goo00<007ooOol037oo000;Ool00`00Oomoo`0BOol2
000?Ool40002Ool01000Oomoogoo1P00Qgoo0`000goo00<007ooOol04Woo1P0077oo00<007ooOol0
37oo000;Ool00`00Oomoo`0BOol2000AOol30002Ool80024Ool40006Ool00`00Oomoo`0>Ool7000P
Ool00`00Oomoo`0;Ool000]oo`03001oogoo015oo`8001=oo`P000Aoo`03001oogoo07ioo`<000Yo
o`03001oogoo00]oo`L002=oo`03001oogoo00]oo`002Woo00<007ooOol04Woo0P004Woo1P0000=o
o`00Ool01Goo00<007ooOol0NWoo0`003Goo00<007ooOol027oo1P009goo00<007ooOol02goo000:
Ool00`00Oomoo`0BOol2000BOol00`00Ool000030002Ool00`00Oomoo`04Ool00`00Oomoo`1fOol3
000@Ool00`00Oomoo`05Ool6000ZOol00`00Oomoo`0;Ool000Yoo`03001oogoo019oo`80019oo`04
001oogooOol30002Ool00`00Oomoo`04Ool00`00Oomoo`1bOol3000DOol01000Oomoogoo1P00;Goo
00<007ooOol02goo000:Ool00`00Oomoo`0BOol2000BOol00`00Oomoo`02Ool30002Ool00`00Oomo
o`04Ool00`00Oomoo`1^Ool3000GOol7000`Ool00`00Oomoo`0;Ool000Yoo`03001oogoo019oo`80
019oo`03001oogoo00=oo`<0009oo`03001oogoo00Aoo`03001oogoo06Yoo`<001Qoo`H003=oo`03
001oogoo00]oo`002Woo00<007ooOol04Woo0P004Woo00<007ooOol017oo0`000Woo0P001Goo00<0
07ooOol0IWoo0`0067oo1P00=Woo00<007ooOol02goo000:Ool00`00Oomoo`0BOol2000BOol00`00
Oomoo`05Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`1ROol3000HOol60002Ool00`00Oomoo`0e
Ool00`00Oomoo`0:Ool000Uoo`03001oogoo01=oo`80019oo`03001oogoo00Ioo`<000=oo`03001o
ogoo00=oo`03001oogoo05ioo`<001Moo`L000Eoo`03001oogoo03Eoo`03001oogoo00Yoo`002Goo
00<007ooOol04Woo0P004goo00<007ooOol01goo0`000goo00@007ooOol0009oo`03001oogoo05Yo
o`<001Moo`L000Qoo`03001oogoo03Eoo`03001oogoo00Yoo`002Goo00<007ooOol04Woo0P004goo
00<007ooOol027oo0`000goo00@007ooOol0009oo`03001oogoo05Ioo`<001Moo`H000]oo`8003Mo
o`03001oogoo00Yoo`002Goo00<007ooOol04Woo0P004Woo00<007ooOol02Woo0`000goo00L007oo
001oo`00Ool0001DOol3000GOol6000;Ool30002Ool00`00Oomoo`0dOol00`00Oomoo`0:Ool000Uo
o`03001oogoo019oo`80019oo`03001oogoo00]oo`<000=oo`04001oo`000002Ool00`00Oomoo`1=
Ool4000GOol6000;Ool30006Ool00`00Oomoo`0cOol00`00Oomoo`0:Ool000Uoo`03001oogoo019o
o`80019oo`03001oogoo00aoo`@0009oo`<000=oo`03001oogoo04Uoo`<001Qoo`H000Yoo`@000Uo
o`03001oogoo03=oo`03001oogoo00Yoo`002Goo00<007ooOol04Woo0P004Woo00<007ooOol03Goo
1@0000Aoo`00000000=oo`03001oogoo04Eoo`<001Qoo`H000Yoo`<000ioo`03001oogoo039oo`03
001oogoo00Yoo`0027oo00<007ooOol04goo0P004Woo00<007ooOol03Woo200017oo00<007ooOol0
@Goo0`0067oo1P002Woo0`004Woo00<007ooOol0<Woo00<007ooOol02Goo0008Ool00`00Oomoo`0C
Ool2000BOol00`00Oomoo`0?Ool3000017oo000000001Goo00<007ooOol0?Goo0`005goo1`002Woo
0`005Woo00<007ooOol0<Goo00<007ooOol02Goo0008Ool00`00Oomoo`0BOol2000COol00`00Oomo
o`0@Ool30009Ool00`00Oomoo`0iOol3000GOol7000:Ool3000IOol00`00Oomoo`0aOol00`00Oomo
o`09Ool000Qoo`03001oogoo019oo`80015oo`03001oo`0001=oo`<000Uoo`03001oogoo03Eoo`<0
01Moo`H000Yoo`@001eoo`03001oogoo031oo`03001oogoo00Uoo`0027oo00<007ooOol04Woo0P00
4Goo00<007oo00000Woo00<007ooOol03goo0`002Goo00<007ooOol0<Goo0`005goo1P002Woo0`00
8Woo00<007ooOol0;goo00<007ooOol02Goo0008Ool00`00Oomoo`0BOol2000AOol01@00Ool007oo
00004goo0`002Goo00<007ooOol0;Goo0`005goo1P002Woo0`009Woo00<007ooOol0;Woo00<007oo
Ool02Goo0008Ool00`00Oomoo`0BOol2000@Ool2000017oo001oo`0057oo0`002Goo00<007ooOol0
:Goo0`005goo1P002Woo0`00:Goo00<007ooOol0;Woo00<007ooOol02Goo0007Ool00`00Oomoo`0C
Ool2000@Ool300000goo0000000EOol300000goo00000006Ool00`00Oomoo`0UOol3000GOol6000:
Ool3000]Ool00`00Oomoo`0]Ool00`00Oomoo`09Ool000Moo`03001oogoo01=oo`80015oo`800003
Ool007oo01Ioo`<00003Ool007oo00Ioo`03001oogoo025oo`<001Moo`H000Yoo`<0035oo`03001o
ogoo02eoo`03001oogoo00Qoo`001goo00<007ooOol04goo0P004Goo100067oo100027oo00<007oo
Ool07Goo0`005Woo1`002Goo1000=Goo00<007ooOol0;7oo00<007ooOol027oo0007Ool00`00Oomo
o`0COol2000AOol3000JOol40008Ool00`00Oomoo`0HOol4000FOol70009Ool3000iOol00`00Oomo
o`0/Ool00`00Oomoo`08Ool000Moo`03001oogoo019oo`8001=oo`8001]oo`@000Qoo`03001oogoo
01Aoo`<001Moo`H000Yoo`<003eoo`03001oogoo02]oo`03001oogoo00Qoo`001goo00<007ooOol0
4Woo0P004goo00<007ooOol06Goo0P0000Aoo`00000000Qoo`03001oogoo011oo`<001Moo`H000Yo
o`<0045oo`03001oogoo02Yoo`03001oogoo00Qoo`001goo00<007ooOol04Woo0P00<goo0`0027oo
00<007ooOol037oo0`005goo1P002Woo0`00AGoo00<007ooOol0:Goo00<007ooOol027oo0006Ool0
0`00Oomoo`0COol2000dOol30008Ool00`00Oomoo`08Ool3000GOol60009Ool40018Ool00`00Oomo
o`0YOol00`00Oomoo`08Ool000Ioo`03001oogoo01=oo`8003Eoo`<000Qoo`03001oogoo00Aoo`<0
01Moo`H000Uoo`<004eoo`03001oogoo02Qoo`03001oogoo00Qoo`001Woo00<007ooOol04goo0P00
=Woo0`0027oo00<007ooOol00`005goo1P002Goo0`00DGoo00<007ooOol0:7oo00<007ooOol01goo
0006Ool00`00Oomoo`0COol2000gOol30008Ool2000GOol60009Ool3001EOol00`00Oomoo`0WOol0
0`00Oomoo`07Ool000Ioo`03001oogoo01=oo`8003Qoo`<000Moo`03001oogoo019oo`L000Uoo`<0
05Uoo`03001oogoo02Ioo`03001oogoo00Moo`001Woo00<007ooOol04goo0P00>Goo0`001Woo00<0
07ooOol03goo1`0027oo1000G7oo00<007ooOol09Woo00<007ooOol01goo0006Ool00`00Oomoo`0B
Ool2000IOol4000NOol30005Ool00`00Oomoo`0<Ool60009Ool3001QOol00`00Oomoo`0UOol00`00
Oomoo`07Ool000Eoo`03001oogoo01=oo`8001Yoo`03001oo`0001moo`<000Aoo`03001oogoo00Uo
o`H000Uoo`<006Eoo`03001oogoo02Aoo`03001oogoo00Moo`001Goo00<007ooOol04goo0P006Goo
00<007oo00008Goo0`000goo00<007ooOol01Woo1P002Goo0`00JGoo00<007ooOol08goo00<007oo
Ool01goo0005Ool00`00Oomoo`0COol2000IOol4000QOol30002Ool00`00Oomoo`03Ool60009Ool3
001/Ool00`00Oomoo`0SOol00`00Oomoo`07Ool000Eoo`03001oogoo01=oo`8003moo`<00004Ool0
07ooOol60009Ool3001`Ool00`00Oomoo`0SOol00`00Oomoo`06Ool000Eoo`03001oogoo01=oo`80
041oo`T000Moo`D002ioo`03001oogoo04=oo`03001oogoo029oo`03001oogoo00Ioo`001Goo00<0
07ooOol04goo0P00@Goo1@0027oo0`003goo00<007ooOol03goo00<007ooOol03goo00<007ooOol0
@goo00<007ooOol08Goo00<007ooOol01Woo0005Ool00`00Oomoo`0COol20011Ool30007Ool30000
17oo001oogoo1@000Woo00<007ooOol017oo00@007ooOomoo`D0009oo`03001oogoo00Aoo`04001o
ogooOol5000017oo000000001Goo00<007ooOol0@goo00<007ooOol08Goo00<007ooOol01Woo0004
Ool00`00Oomoo`0DOol20011Ool30004Ool30004Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`00
00Ioo`03001oogoo009oo`07001oogooOol007oo00001Woo00<007ooOol00Woo00D007ooOomoo`00
00Moo`03001oogoo04Aoo`03001oogoo021oo`03001oogoo00Ioo`0017oo00<007ooOol04goo0P00
@Woo0P000Woo0`001Woo00<007ooOol00goo00L007ooOomoo`00Ool0000;Ool01`00Oomoogoo001o
o`0000]oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo04Aoo`03001oogoo01moo`03001o
ogoo00Ioo`0017oo00<007ooOol04goo0P00@Woo10002Woo00<007ooOol00Woo00L007ooOomoo`00
Ool0000;Ool01`00Oomoogoo001oo`0000]oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
04Ioo`03001oogoo01ioo`03001oogoo00Ioo`0017oo00<007ooOol04goo0P00?goo1@0037oo00<0
07ooOol00Woo00L007ooOomoo`00Ool0000;Ool01`00Oomoogoo001oo`0000]oo`07001oogooOol0
07oo00001Goo00<007ooOol0AWoo00<007ooOol07Woo00<007ooOol01Woo0004Ool00`00Oomoo`0C
Ool2000lOol30003Ool2000=Ool00`00Oomoo`020004Ool00`00Oomoo`09Ool20004Ool00`00Oomo
o`09Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`18Ool00`00Oomoo`0NOol00`00Oomoo`05Ool0
00Aoo`03001oogoo01=oo`8003Uoo`<000Ioo`8008aoo`03001oogoo01eoo`03001oogoo00Eoo`00
17oo00<007ooOol04goo0P00=Woo0`002Goo0P00SGoo00<007ooOol077oo00<007ooOol01Goo0004
Ool00`00Oomoo`0COol2000cOol3000<Ool2002=Ool00`00Oomoo`0LOol00`00Oomoo`05Ool000=o
o`03001oogoo01Aoo`8002moo`@000moo`8008ioo`03001oogoo01]oo`03001oogoo00Eoo`000goo
00<007ooOol04goo0P00;Goo0`004goo0P00Sgoo00<007ooOol06Woo00<007ooOol01Goo0003Ool0
0`00Oomoo`0COol2000ZOol3000FOol2002@Ool00`00Oomoo`0IOol00`00Oomoo`05Ool000=oo`03
001oogoo01=oo`8002Moo`<001Uoo`80091oo`03001oogoo01Uoo`03001oogoo00Eoo`000goo00<0
07ooOol04goo0P0097oo0`0077oo0P005goo00<007ooOol0Mgoo00<007ooOol06Goo00<007ooOol0
17oo0003Ool00`00Oomoo`0COol2000POol4000OOol2000DOol4001jOol00`00Oomoo`0HOol00`00
Oomoo`04Ool000=oo`03001oogoo01=oo`8001eoo`<002=oo`80015oo`H007aoo`03001oogoo01Mo
o`03001oogoo00Aoo`000Woo00<007ooOol057oo0P006Woo0`009Woo0P003Woo1P00P7oo00<007oo
Ool05Woo00<007ooOol017oo0002Ool00`00Oomoo`0DOol2000GOol3000YOol2000:Ool70023Ool0
0`00Oomoo`0FOol00`00Oomoo`04Ool0009oo`03001oogoo01Aoo`8001Aoo`<000Yoo`<0009oo`D0
01Qoo`8000Moo`L000eoo`<000=oo`<0075oo`03001oogoo01Eoo`03001oogoo00Aoo`000Woo00<0
07ooOol04goo0P004Goo10003Woo00<007ooOol00goo00<007ooOol067oo0P0017oo1P004Woo00<0
07ooOol00Woo00<007ooOol0LWoo00<007ooOol057oo00<007ooOol017oo0002Ool00`00Oomoo`0C
Ool2000>Ool3000BOol30003Ool00`00Oomoo`0HOol9000EOol30003Ool00`00Oomoo`1bOol00`00
Oomoo`0COol00`00Oomoo`04Ool0009oo`03001oogoo01=oo`8000]oo`<001Eoo`04001oogoo0002
Ool00`00Oomoo`0GOol7000HOol01000Oomoo`000Woo00<007ooOol0LWoo00<007ooOol057oo00<0
07ooOol00goo0002Ool00`00Oomoo`0COol20008Ool3000HOol01000Oomoo`000Woo00<007ooOol0
57oo1P0077oo00P007ooOol007oo001oo`00M7oo00<007ooOol04goo00<007ooOol00goo00000goo
001oo`0EOol20005Ool3000JOol40002Ool2000BOol:000KOol40003Ool00`00Oomoo`1dOol00`00
Oomoo`0BOol00`00Oomoo`03Ool00003Ool007oo01Eoo`80009oo`<003Aoo`L000=oo`8009]oo`03
001oogoo015oo`03001oogoo00=oo`0000=oo`00Ool05Goo1000=7oo1P001goo0P00Vgoo00<007oo
Ool04Goo00<007ooOol00goo00000goo001oo`0BOol5000cOol6000:Ool2002LOol00`00Oomoo`0@
Ool00`00Oomoo`03Ool00003Ool007oo00moo`<000=oo`80039oo`@000eoo`8009eoo`03001oogoo
00moo`03001oogoo00=oo`0000=oo`00Ool037oo0`001Goo0P00<goo00<007ooOol03Woo0P00WWoo
00<007ooOol03Woo00<007ooOol00goo00000goo001oo`09Ool30008Ool20014Ool2002NOol00`00
Oomoo`0?Ool00`00Oomoo`02Ool00003001oogoo00Eoo`@000]oo`8004Aoo`8009moo`03001oogoo
00ioo`03001oogoo009oo`0000<007ooOol00Woo0`003goo0P00A7oo0P00X7oo00<007ooOol03Goo
00<007ooOol00Woo00000`00Ool00002000BOol20014Ool2002QOol00`00Oomoo`0<Ool00`00Oomo
o`02Ool0008001Eoo`8004Aoo`800:5oo`03001oogoo00aoo`03001oogoo009oo`0000=oo`00Ool0
57oo0P00A7oo0P00@Goo10000Woo10000Woo0`0017oo200000Eoo`00000007oo00D003aoo`03001o
ogoo00]oo`03001oogoo009oo`000Woo0P004goo0P003Woo00<007ooOol0:Woo00<007ooOol01Woo
0P00@7oo0P000Woo0P000Woo0P000Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000Ao
o`00001oo`800003Ool0000003ioo`03001oogoo00Yoo`03001oogoo009oo`0017oo00<007ooOol0
3goo0`003Goo00<007ooOol027oo00<007ooOol03goo00<007ooOol03goo00<007ooOol01Goo0P00
?goo0P000goo0P000Woo0P000Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000Aoo`00
001oo`800003Ool0000003moo`03001oogoo00Uoo`03001oogoo009oo`001Goo00<007ooOol03Woo
1@002goo00<007ooOol00Woo00<007ooOol00goo00@007ooOomoo`D0009oo`03001oogoo00Aoo`04
001oogooOol5000017oo000000001Goo00<007ooOol01Goo0P00?goo0P000Woo100000=oo`000000
0Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000Aoo`00001oo`800003Ool00000041o
o`03001oogoo00Uoo`03001oogoo005oo`001Woo0P0047oo10002Woo00L007ooOomoo`00Ool00005
Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`03001oogoo009oo`05001oogooOol00007
Ool00`00Oomoo`05Ool2000oOol20007Ool200001Goo00000000Ool00P000Woo0P0000=oo`000000
0Woo0P0000Aoo`00001oo`800003Ool00000041oo`03001oogoo00Uoo`03001oogoo005oo`0027oo
00<007ooOol03goo0`0027oo00<007ooOol00Woo00<007oo00002Woo00L007ooOomoo`00Ool0000;
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool2000oOol20006Ool5000017oo0000
00000Woo0`0000Aoo`00001oo`D000=oo`@0045oo`03001oogoo00Qoo`03001oogoo005oo`002Goo
00<007ooOol03goo10001goo00L007ooOomoo`00Ool0000:Ool01`00Oomoogoo001oo`0000]oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`8003moo`8000Aoo`03001oogoo01]oo`80
049oo`03001oogoo00Moo`03001oogoo005oo`002Woo0P0047oo10001Woo00L007ooOomoo`00Ool0
000:Ool01`00Oomoogoo001oo`0000]oo`07001oogooOol007oo00001Goo00<007ooOol01Goo0P00
@7oo0P000Woo0P007Goo0P00@goo00<007ooOol01Woo00<007ooOol00Goo000<Ool00`00Oomoo`0?
Ool30006Ool01@00Oomoogoo00002Woo0P0017oo00<007ooOol02Goo0P0017oo00<007ooOol00goo
00<007ooOol01Woo0P00@Goo0`0000=oo`00Ool06goo0`00@goo00<007ooOol01Woo00<007ooOol0
0Goo000=Ool00`00Oomoo`0?Ool3000kOol2002YOol00`00Oomoo`05Ool00`00Oomoo`01Ool000io
o`80011oo`@003Qoo`<00:Yoo`03001oogoo00Aoo`03001oogoo005oo`0047oo00<007ooOol03Woo
1000=goo0`00Zgoo00<007ooOol017oo0@000Goo0Goo000AOol00`00Oomoo`0?Ool3000fOol2002/
Ool00`00Oomoo`04Ool10001Ool1Ool0019oo`80011oo`@003Aoo`800:eoo`03001oogoo00=oo`40
005oo`5oo`0057oo00<007ooOol03Woo1000<goo0P00[Woo00<007ooOol00Woo0@000Goo0Goo000E
Ool00`00Oomoo`0?Ool3000bOol2002_Ool01@00Oomoogoo00000Woo000FOol2000@Ool4000`Ool2
002_Ool01@00Oomoogoo00000Woo000HOol00`00Oomoo`0>Ool4000_Ool2002`Ool01000Oomoo`00
0Woo000IOol00`00Oomoo`0?Ool3000^Ool2002aOol00`00Ool00002Ool001Yoo`80011oo`@002ao
o`800;9oo`03001oo`00005oo`0077oo00<007ooOol03Woo1000:goo0P00/Woo00<007oo00000Goo
000MOol00`00Oomoo`0?Ool3000ZOol2002cOol20001Ool001ioo`03001oogoo00moo`<002Uoo`80
0;=oo`80005oo`007goo0P0047oo10009goo0P00[goo10000goo000QOol00`00Oomoo`0>Ool4000V
Ool2002[Ool40007Ool0029oo`03001oogoo00moo`<002Eoo`800:Moo`@000]oo`008goo0P0047oo
10008goo0P00Xgoo10003goo000UOol00`00Oomoo`0>Ool4000ROol2002OOol4000COol002Ioo`03
001oogoo00moo`<0025oo`8009]oo`@001Moo`009goo0P0047oo10007goo0P00Ugoo10006goo000Y
Ool00`00Oomoo`0>Ool4000NOol2002COol4000OOol002Yoo`03001oogoo00moo`<001eoo`8008mo
o`@002=oo`00:goo0P0047oo10006Woo0`00Rgoo10009goo000]Ool00`00Oomoo`0>Ool4000IOol3
0027Ool4000[Ool002ioo`03001oogoo00moo`<001Qoo`<008=oo`@002moo`00;goo0P0047oo0`00
5goo0P00P7oo1000<goo000aOol00`00Oomoo`0>Ool4000EOol2001lOol4000gOol0039oo`03001o
ogoo00ioo`@001Aoo`8007Qoo`@003]oo`00<goo0P0047oo0`004goo0P00M7oo1000?goo000eOol0
0`00Oomoo`0>Ool4000AOol2001`Ool40013Ool003Ioo`03001oogoo00ioo`@0011oo`8006aoo`@0
04Moo`00=goo0P0047oo0`003goo0P00J7oo1000Bgoo000iOol00`00Oomoo`0>Ool4000=Ool2001T
Ool4001?Ool003Yoo`03001oogoo00ioo`@000aoo`80061oo`@005=oo`00>goo0P0047oo0`002goo
0P00G7oo1000Egoo000mOol00`00Oomoo`0>Ool40009Ool2001HOol4001KOol003ioo`03001oogoo
00ioo`@000Qoo`8005Aoo`@005moo`00?goo00<007ooOol03goo0`001goo0P00D7oo1000Hgoo0010
Ool2000@Ool30006Ool2001<Ool4001WOol0049oo`03001oogoo00ioo`@000Aoo`8004Qoo`@006]o
o`00@goo00<007ooOol03Woo10000goo0P00A7oo1000Kgoo0014Ool2000@Ool30002Ool20010Ool4
001cOol004Ioo`03001oogoo00ioo`H003aoo`@007Moo`00Agoo00<007ooOol03Woo1@00>7oo1000
Ngoo0018Ool2000@Ool3000dOol4001oOol004Yoo`03001oogoo00eoo`<0031oo`@008=oo`00Bgoo
00<007ooOol03Woo00<007ooOol0:Woo1000Qgoo001<Ool2000=Ool00`00Oomoo`0WOol4002;Ool0
04ioo`03001oogoo00Yoo`03001oogoo02=oo`@008moo`00Cgoo00<007ooOol02Goo00<007ooOol0
7goo1000Tgoo001@Ool20009Ool00`00Oomoo`0KOol4002GOol0059oo`03001oogoo00Ioo`03001o
ogoo01Moo`@009]oo`00Dgoo00<007ooOol01Goo00<007ooOol04goo1000Wgoo001DOol20005Ool0
0`00Oomoo`0?Ool4002SOol005Ioo`03001oogoo009oo`03001oogoo00]oo`@00:Moo`00Egoo00D0
07ooOomoo`0000Uoo`@00:]oo`00F7oo0P0000=oo`00Ool017oo1000[goo001JOol200000goo0000
0002002cOol005]oo`800;Moo`00\
\>"],
  ImageRangeCache->{{{0, 275}, {262, 0}} -> {-0.000190518, 0.000567246, 
  0.00354754, 0.00354754}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Crank"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The crank graphic uses the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to generate a very short cylinder. The cylinder is only one unit \
long because the line that defines its axis is one unit long, while the \
radius of the cylinder is ten units as specified."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the crank body graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(crankgraphic = 
      Graphics3D[{Bar[Line[crank, 0, {\(-1\), 0, 0}], 10.0, 12]}]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The text that was displayed with the crank graphic also used the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to specify the global coordinates of the text so that the text \
moves with the crank."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the crank annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cranktext = 
      Graphics3D[{\n\t\t\t
          Text["\<{8,0,0}\>", Location[crank, 1], {\(-0.4\), 1.6}], \n\t\t\t
          Text["\<P1\>", Location[crank, 1], {\(-1.9\), \(-0.9\)}], \n\t\t\t
          Text["\<{0,8,0}\>", Location[crank, 2], {\(-1.3\), 0.9}], \n\t\t\t
          Text["\<P2\>", Location[crank, 2], {\(-2.6\), \(-1.6\)}], \n\t\t\t
          LocalAxes[crank, 7], \n\t\t\t
          Text[FontForm["\<Crank\>", {"\<Times-Bold\>", 12}], {15, 0, 0}]}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Because the coordinates of some of the elements in ",
  StyleBox["crankgraphic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["cranktext",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are now functions of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " dependent variables, ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on, a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule must be applied before they can be displayed. Note the use \
of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the following input. The rules that are returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " determine where the crank is located in 3D space."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot2 = 
      Show[{crankgraphic, cranktext} /. SolveMech[0], 
        PlotRange \[Rule] {{\(-2\), 37}, {\(-10\), 20}, {\(-4\), 24}}]; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95309 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.02544 -0.000586442 1.02544 [
[ 0 0 0 0 ]
[ 1 .95309 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
.35203 .54414 m
.06189 .25974 L
s
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
.35203 .54414 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
0 0 m
1 0 L
1 .95309 L
0 .95309 L
closepath
clip
newpath
.5 Mabswid
.34774 .67926 m .35644 .76253 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.31771 .59745 m .34774 .67926 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.35644 .76253 m .34774 .67926 L .36222 .67492 L p .597 .435 .633 r
F P
0 g
s
.34774 .67926 m .31771 .59745 L .33216 .59288 L p .633 .551 .744 r
F P
0 g
s
.33216 .59288 m .36222 .67492 L .34774 .67926 L p .633 .551 .744 r
F P
0 g
s
.36222 .67492 m .37114 .75835 L .35644 .76253 L p .597 .435 .633 r
F P
0 g
s
.36222 .67492 m .37114 .75835 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.33216 .59288 m .36222 .67492 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.27294 .53551 m .31771 .59745 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.31771 .59745 m .27294 .53551 L .28754 .53069 L p .658 .667 .848 r
F P
0 g
s
.28754 .53069 m .33216 .59288 L .31771 .59745 L p .658 .667 .848 r
F P
0 g
s
.28754 .53069 m .33216 .59288 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.35644 .76253 m .341 .828 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.341 .828 m .35644 .76253 L .37114 .75835 L p .521 .25 .445 r
F P
0 g
s
.37114 .75835 m .35605 .82388 L .341 .828 L p .521 .25 .445 r
F P
0 g
s
.37114 .75835 m .35605 .82388 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.2233 .50921 m .27294 .53551 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.27294 .53551 m .2233 .50921 L .23821 .50418 L p .65 .834 .971 r
F P
0 g
s
.23821 .50418 m .28754 .53069 L .27294 .53551 L p .65 .834 .971 r
F P
0 g
s
.23821 .50418 m .28754 .53069 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.33184 .71305 m
.34418 .73477 L
s
.34181 .72046 m
.34418 .73477 L
s
.341 .828 m .30344 .85786 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.33081 .73407 m
.34418 .73477 L
s
.30344 .85786 m .341 .828 L .35605 .82388 L p .19 0 0 r
F P
0 g
s
.35605 .82388 m .3189 .85367 L .30344 .85786 L p .19 0 0 r
F P
0 g
s
.35605 .82388 m .3189 .85367 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.27811 .67698 m
.34418 .73477 L
s
.18125 .52844 m .2233 .50921 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.2233 .50921 m .18125 .52844 L .19656 .52329 L p 0 0 0 r
F P
0 g
s
.19656 .52329 m .23821 .50418 L .2233 .50921 L p 0 0 0 r
F P
0 g
s
.19656 .52329 m .23821 .50418 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.27811 .67698 m
.38673 .64395 L
s
.30344 .85786 m .25203 .84043 L p .16645 .68425 L .938 .685 .528 r
F P
0 g
s
.25203 .84043 m .30344 .85786 L .3189 .85367 L p .58 .865 .995 r
F P
0 g
s
.3189 .85367 m .26784 .83606 L .25203 .84043 L p .58 .865 .995 r
F P
0 g
s
.3189 .85367 m .26784 .83606 L p .18239 .67933 L .94 .685 .525 r
F P
0 g
s
.27102 .78689 m
.27811 .67698 L
s
.37128 .6568 m
.38673 .64395 L
s
.38673 .64395 m
.36511 .63993 L
s
.38673 .64395 m
.36423 .66144 L
s
.35801 .64446 m
.38673 .64395 L
s
.16645 .68425 m .15953 .59211 L .18125 .52844 L p .938 .685 .528 r
F P
0 g
s
.18125 .52844 m .15953 .59211 L .17522 .58699 L p .46 .159 .366 r
F P
0 g
s
.17522 .58699 m .19656 .52329 L .18125 .52844 L p .46 .159 .366 r
F P
0 g
s
.27102 .78689 m
.27947 .77017 L
s
.18239 .67933 m .17522 .58699 L .19656 .52329 L p .94 .685 .525 r
F P
0 g
s
.27102 .78689 m
.28339 .76123 L
s
.26542 .75855 m
.27102 .78689 L
s
.25203 .84043 m .20099 .77673 L .16645 .68425 L p .938 .685 .528 r
F P
0 g
s
.20099 .77673 m .25203 .84043 L .26784 .83606 L p .643 .681 .871 r
F P
0 g
s
.26784 .83606 m .21698 .77209 L .20099 .77673 L p .643 .681 .871 r
F P
0 g
s
.26784 .83606 m .21698 .77209 L .18239 .67933 L p .94 .685 .525 r
F P
0 g
s
.15953 .59211 m .16645 .68425 L .18239 .67933 L p .575 .408 .618 r
F P
0 g
s
.18239 .67933 m .17522 .58699 L .15953 .59211 L p .575 .408 .618 r
F P
0 g
s
.16645 .68425 m .20099 .77673 L .21698 .77209 L p .62 .546 .749 r
F P
0 g
s
.21698 .77209 m .18239 .67933 L .16645 .68425 L p .62 .546 .749 r
F P
0 g
s
gsave
.4026 .63912 -74.8 -23.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
87.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 14.437500 moveto
(<) show
105.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.4026 .63912 -53.8 -4.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P1) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.35325 .7427 -54.1 -18.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(8) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(8) show
87.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(,) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 14.437500 moveto
(<) show
105.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%DocumentNeededResources: + font Courier
%%DocumentNeededFonts: Math2Mono
%%DocumentNeededFont: + Courier
%%DocumentFonts: font Math2Mono
%%DocumentFonts: + font Courier
grestore
gsave
.35325 .7427 -48.2 .5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(P2) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.38673 .64395 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.34418 .73477 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.27102 .78689 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.27811 .67698 -72.5 -21.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.42659 .3248 -79.5 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Crank) show
95.750000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
.25 Mabswid
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{276, 263},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004D00011a000`40O003h00OaGoo0P00CGoo0033
Ool200000goo0000001<Ool00<1oo`<000=oo`8004aoo`00_Woo0P001Woo00<007oo0000Bgoo002k
Ool30008Ool01000Oomoo`00BWoo002iOol2000;Ool01000Oomoo`00BWoo002fOol3000=Ool01@00
Oomoogoo0000BGoo002dOol2000@Ool01@00Oomoogoo0000BGoo002aOol3000COol01@00Oomoogoo
0000B7oo002_Ool2000FOol00`00Oomoo`02Ool00`00Oomoo`15Ool00:aoo`<001Qoo`03001oogoo
009oo`03001oogoo04Eoo`00ZWoo0P006goo00<007ooOol00goo00<007ooOol0A7oo002WOol3000M
Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00:Eoo`80021oo`03001oogoo00Aoo`03001oogoo04=o
o`00XWoo0`008Woo00<007ooOol01Goo00<007ooOol0@Woo002POol2000UOol00`00Oomoo`05Ool0
0`00Oomoo`12Ool009eoo`<002Moo`03001oogoo00Ioo`03001oogoo045oo`00Vgoo0P00:Woo00<0
07ooOol01goo00<007ooOol0@7oo002HOol3000/Ool00`00Oomoo`07Ool00`00Oomoo`10Ool009Eo
o`<002moo`03001oogoo00Qoo`03001oogoo03moo`00Tgoo0P00<Woo00<007ooOol02Goo00<007oo
Ool0?Woo002@Ool3000dOol00`00Oomoo`09Ool00`00Oomoo`0nOol008ioo`8003Qoo`03001oogoo
00Uoo`03001oogoo03eoo`00Rgoo0`00>Woo00<007ooOol02Goo00<007ooOol0?Goo0029Ool2000m
Ool00`00Oomoo`0:Ool00`00Oomoo`0lOol008Ioo`<003moo`03001oogoo00]oo`03001oogoo03]o
o`00Q7oo0P00@Woo00<007ooOol02goo00<007ooOol0>goo0021Ool30014Ool00`00Oomoo`0<Ool0
0`00Oomoo`0jOol007moo`8004Moo`03001oogoo00eoo`03001oogoo03Uoo`00O7oo0`00BGoo00<0
07ooOol03Goo00<007ooOol0>Goo001jOol2001<Ool00`00Oomoo`0>Ool00`00Oomoo`0hOol007Mo
o`<004ioo`03001oogoo00ioo`03001oogoo03Qoo`00MGoo0P00DGoo00<007ooOol03goo00<007oo
Ool0=goo001bOol3001COol00`00Oomoo`0@Ool00`00Oomoo`0fOol0071oo`8005Ioo`03001oogoo
011oo`03001oogoo03Ioo`00KGoo0`00F7oo00<007ooOol04Goo00<007ooOol0=Goo001[Ool2001L
Ool00`00Oomoo`0AOol00`00Oomoo`0dOol006Qoo`<005ioo`03001oogoo015oo`03001oogoo03Ao
o`00IWoo0P00HGoo00<007ooOol04Woo00<007ooOol0<goo001SOol3001SOol00`00Oomoo`0COol0
0`00Oomoo`0bOol0065oo`8006Ioo`03001oogoo01=oo`03001oogoo039oo`00GWoo0`00J7oo00<0
07ooOol057oo00<007ooOol0<Goo001LOol2001[Ool00`00Oomoo`0DOol00`00Oomoo`0aOol005Uo
o`<006eoo`03001oogoo01Eoo`03001oogoo031oo`00Egoo0P00L7oo00<007ooOol05Woo00<007oo
Ool0;goo001DOol3001bOol00`00Oomoo`0FOol00`00Oomoo`0_Ool0059oo`8007Eoo`03001oogoo
01Moo`03001oogoo02ioo`00Cgoo0`00Mgoo00<007ooOol067oo00<007ooOol0;Goo001=Ool2001j
Ool00`00Oomoo`0HOol00`00Oomoo`0]Ool004Yoo`<007aoo`03001oogoo01Uoo`03001oogoo02ao
o`00B7oo0P00P7oo00<007ooOol067oo00<007ooOol0;7oo0015Ool30022Ool00`00Oomoo`0IOol0
0`00Oomoo`0[Ool004=oo`8008Eoo`03001oogoo01Yoo`03001oogoo02Yoo`00@7oo0`00Qgoo00<0
07ooOol06Woo00<007ooOol0:Woo000mOol3002:Ool00`00Oomoo`0KOol00`00Oomoo`0YOol003]o
o`8008eoo`03001oogoo01aoo`03001oogoo02Qoo`00>7oo0`00Sgoo00<007ooOol077oo00<007oo
Ool0:7oo000fOol2002BOol00`00Oomoo`0MOol00`00Oomoo`0WOol003=oo`<009Aoo`03001oogoo
01eoo`03001oogoo02Moo`00<Goo0P00Ugoo00<007ooOol07Woo00<007ooOol09Woo000^Ool3002I
Ool00`00Oomoo`0OOol00`00Oomoo`0UOol002aoo`8009aoo`03001oogoo01moo`03001oogoo02Eo
o`00:Goo0`00WWoo00<007ooOol087oo00<007ooOol097oo000WOol2002QOol00`00Oomoo`0QOol0
0`00Oomoo`0SOol002Aoo`<00:=oo`03001oogoo025oo`03001oogoo02=oo`008Woo0P00Ygoo00<0
07ooOol08Goo00<007ooOol08Woo000OOol3002YOol00`00Oomoo`0ROol00`00Oomoo`0QOol001eo
o`800:aoo`03001oogoo029oo`03001oogoo025oo`006Woo0`00[Woo00<007ooOol08goo00<007oo
Ool087oo000HOol2002aOol00`00Oomoo`0SOol00`00Oomoo`0POol001Eoo`<00;=oo`03001oogoo
02Aoo`03001oogoo01moo`004goo0P00]Woo00<007ooOol09Goo00<007ooOol07Woo000AOol2002h
Ool00`00Oomoo`0UOol00`00Oomoo`0NOol0015oo`800;Qoo`03001oogoo02Ioo`03001oogoo01eo
o`004Goo00<007oo0000]goo00<007ooOol09goo00<007ooOol077oo000AOol01000Oomoo`00]Woo
00<007ooOol09goo00<007ooOol077oo000@Ool00`00Oomoo`02Ool00`00Oomoo`2cOol00`00Oomo
o`0XOol00`00Oomoo`0KOol0011oo`03001oogoo00=oo`03001oogoo0;9oo`03001oogoo02Qoo`03
001oogoo01]oo`0047oo00<007ooOol017oo00<007ooOol0/Goo00<007ooOol0:Goo00<007ooOol0
6Woo000@Ool00`00Oomoo`05Ool00`00Oomoo`2aOol00`00Oomoo`0YOol00`00Oomoo`0IOol0011o
o`03001oogoo00Ioo`03001oogoo0;1oo`03001oogoo02Uoo`03001oogoo01Uoo`0047oo00<007oo
Ool01goo00<007ooOol0[goo00<007ooOol0:Woo00<007ooOol067oo000@Ool00`00Oomoo`08Ool0
0`00Oomoo`2^Ool00`00Oomoo`0[Ool00`00Oomoo`0GOol000moo`03001oogoo00Yoo`03001oogoo
0:eoo`03001oogoo02]oo`03001oogoo01Moo`003goo00<007ooOol02goo00<007ooOol0[7oo00<0
07ooOol0;7oo00<007ooOol05Woo000?Ool00`00Oomoo`0<Ool00`00Oomoo`2[Ool00`00Oomoo`0/
Ool00`00Oomoo`0FOol000moo`03001oogoo00eoo`03001oogoo0:Yoo`03001oogoo02eoo`03001o
ogoo01Eoo`003goo00<007ooOol03Woo00<007ooOol0ZGoo00<007ooOol0;Woo00<007ooOol057oo
000?Ool00`00Oomoo`0?Ool00`00Oomoo`13Ool40002Ool40002Ool800000goo00000004000017oo
00000000AWoo00<007ooOol0;Woo00<007ooOol057oo000?Ool00`00Oomoo`0@Ool00`00Oomoo`11
Ool20003Ool00`00Oomoo`020002Ool200000goo00000002Ool200000goo00000002Ool200000goo
00000017Ool00`00Oomoo`0_Ool00`00Oomoo`0COol000ioo`03001oogoo019oo`03001oogoo03mo
o`8000Moo`8000=oo`04001oo`000002Ool200000goo00000002Ool200000goo00000017Ool00`00
Oomoo`0`Ool00`00Oomoo`0BOol000ioo`03001oogoo01=oo`03001oogoo03ioo`8000Moo`8000Ao
o`<0009oo`800003Ool00000009oo`@004Qoo`03001oogoo031oo`03001oogoo019oo`003Woo00<0
07ooOol057oo00<007ooOol0?Goo0P001goo0P0000Eoo`00000007oo0080009oo`800003Ool00000
009oo`800003Ool007oo04Moo`03001oogoo035oo`03001oogoo015oo`003Woo00<007ooOol05Goo
00<007ooOol0?7oo0P001Woo1@0000Aoo`000000009oo`D000=oo`800004Ool000000017Ool00`00
Oomoo`0`Ool00`00Oomoo`0AOol000ioo`03001oogoo01Ioo`03001oogoo03]oo`8000Aoo`03001o
ogoo019oo`8004]oo`03001oogoo035oo`03001oogoo011oo`003Woo00<007ooOol05goo00<007oo
Ool0>goo0P000Woo0P0057oo0P00Bgoo00<007ooOol0<Woo00<007ooOol03goo000>Ool00`00Oomo
o`0HOol00`00Oomoo`0kOol300000goo001oo`0BOol3001;Ool00`00Oomoo`0bOol00`00Oomoo`0?
Ool000eoo`03001oogoo01Yoo`03001oogoo0:1oo`03001oogoo039oo`80011oo`003Goo00<007oo
Ool06goo00<007ooOol0Wgoo00<007ooOol0;goo0`0000=oo`00Ool03goo000=Ool00`00Oomoo`0L
Ool00`00Oomoo`2NOol00`00Oomoo`0/Ool30004Ool00`00Oomoo`0>Ool000eoo`03001oogoo01eo
o`03001oogoo09eoo`03001oogoo02Uoo`<000Moo`03001oogoo00ioo`003Goo00<007ooOol07Woo
00<007ooOol0W7oo00<007ooOol09Woo0`002goo00<007ooOol03Goo000=Ool00`00Oomoo`0OOol0
0`00Oomoo`2KOol00`00Oomoo`0SOol3000>Ool00`00Oomoo`0=Ool000eoo`03001oogoo021oo`03
001oogoo09Yoo`03001oogoo021oo`<0015oo`03001oogoo00eoo`003Goo00<007ooOol08Goo00<0
07ooOol0VGoo00<007ooOol077oo100057oo00<007ooOol03Goo000<Ool00`00Oomoo`0SOol00`00
Oomoo`2HOol00`00Oomoo`0IOol3000HOol00`00Oomoo`0=Ool000aoo`03001oogoo02Aoo`03001o
ogoo09Moo`03001oogoo01Ioo`<001]oo`03001oogoo00eoo`0037oo00<007ooOol09Goo00<007oo
Ool0Ugoo00<007ooOol04Woo0`007Woo00<007ooOol03Goo000<Ool00`00Oomoo`0VOol00`00Oomo
o`2FOol00`00Oomoo`0?Ool3000QOol00`00Oomoo`0=Ool000aoo`03001oogoo02Moo`03001oogoo
09Eoo`03001oogoo00aoo`<002Eoo`03001oogoo00aoo`0037oo00<007ooOol0:7oo00<007ooOol0
U7oo00<007ooOol02Goo0`00:7oo00<007ooOol037oo000<Ool00`00Oomoo`0YOol2002DOol00`00
Oomoo`06Ool3000[Ool00`00Oomoo`0<Ool000]oo`03001oogoo02aoo`03001oogoo095oo`03001o
ogoo00=oo`<002ioo`03001oogoo00aoo`002goo00<007ooOol0;Goo00<007ooOol0T7oo00<007oo
Ool00`00<Goo00<007ooOol037oo000;Ool00`00Oomoo`0^Ool00`00Oomoo`2?Ool3000dOol00`00
Oomoo`0<Ool000]oo`03001oogoo02moo`03001oogoo08]oo`@003Ioo`03001oogoo00aoo`002goo
00<007ooOol0<7oo00<007ooOol0Qgoo0`000goo00<007ooOol0=7oo00<007ooOol037oo000;Ool0
0`00Oomoo`0aOol00`00Oomoo`22Ool40006Ool00`00Oomoo`0eOol00`00Oomoo`0;Ool000]oo`03
001oogoo039oo`03001oogoo07ioo`<000Yoo`03001oogoo03Eoo`03001oogoo00]oo`002Woo00<0
07ooOol0=7oo00<007ooOol0NWoo0`003Goo00<007ooOol0=Goo00<007ooOol02goo000:Ool00`00
Oomoo`0eOol00`00Oomoo`1fOol3000@Ool00`00Oomoo`0eOol00`00Oomoo`0;Ool000Yoo`03001o
ogoo03Ioo`03001oogoo079oo`<001Aoo`03001oogoo03Aoo`03001oogoo00]oo`002Woo00<007oo
Ool0=goo00<007ooOol0KWoo0`005goo00<007ooOol0=7oo00<007ooOol02goo000:Ool00`00Oomo
o`0hOol00`00Oomoo`1ZOol3000JOol00`00Oomoo`0dOol00`00Oomoo`0;Ool000Yoo`03001oogoo
03Uoo`03001oogoo06Ioo`<001eoo`03001oogoo03Aoo`03001oogoo00]oo`002Woo00<007ooOol0
>Woo00<007ooOol0HWoo0`0087oo00<007ooOol0=Goo00<007ooOol02Woo0009Ool00`00Oomoo`0l
Ool00`00Oomoo`1NOol3000SOol00`00Oomoo`0eOol00`00Oomoo`0:Ool000Uoo`03001oogoo03eo
o`03001oogoo05Yoo`<002Ioo`03001oogoo03Eoo`03001oogoo00Yoo`002Goo00<007ooOol0?Woo
00<007ooOol0EWoo0`00:7oo0P00=goo00<007ooOol02Woo0009Ool00`00Oomoo`0oOol00`00Oomo
o`1BOol3000XOol30002Ool00`00Oomoo`0dOol00`00Oomoo`0:Ool000Uoo`03001oogoo041oo`03
001oogoo04eoo`@002Qoo`<000Ioo`03001oogoo03=oo`03001oogoo00Yoo`002Goo00<007ooOol0
@Goo00<007ooOol0BGoo0`00:7oo10002Goo00<007ooOol0<goo00<007ooOol02Woo0009Ool00`00
Oomoo`12Ool00`00Oomoo`15Ool3000XOol3000>Ool00`00Oomoo`0bOol00`00Oomoo`0:Ool000Qo
o`03001oogoo04Aoo`03001oogoo045oo`<002Qoo`<0019oo`03001oogoo039oo`03001oogoo00Uo
o`0027oo00<007ooOol0AGoo00<007ooOol0?Goo0`00:7oo0`005Woo00<007ooOol0<Goo00<007oo
Ool02Goo0008Ool00`00Oomoo`16Ool00`00Oomoo`0iOol3000XOol3000IOol00`00Oomoo`0aOol0
0`00Oomoo`09Ool000Qoo`03001oogoo04Moo`03001oogoo03Eoo`<002Moo`@001eoo`03001oogoo
031oo`03001oogoo00Uoo`0027oo00<007ooOol0B7oo00<007ooOol0<Goo0`009goo0`008Woo00<0
07ooOol0;goo00<007ooOol02Goo0008Ool00`00Oomoo`19Ool00`00Oomoo`0]Ool3000WOol3000V
Ool00`00Oomoo`0^Ool00`00Oomoo`09Ool000Qoo`03001oogoo03Eoo`8001=oo`03001oogoo02Uo
o`<002Moo`<002Uoo`03001oogoo02ioo`03001oogoo00Uoo`001goo00<007ooOol0<goo0`000WZ`
0P004Woo00<007ooOol09Goo0`009goo0`00;Goo00<007ooOol0;Goo00<007ooOol02Goo0007Ool0
0`00Oomoo`0aOol30006N[02000AOol00`00Oomoo`0QOol3000WOol3000aOol00`00Oomoo`0]Ool0
0`00Oomoo`08Ool000Moo`03001oogoo02moo`<000Yj/080011oo`03001oogoo01eoo`<002Ioo`@0
03Eoo`03001oogoo02aoo`03001oogoo00Qoo`001goo00<007ooOol0;Goo0`003WZ`0P003goo00<0
07ooOol067oo10009Woo0`00>Goo00<007ooOol0;7oo00<007ooOol027oo0007Ool00`00Oomoo`0[
Ool3000BN[02000>Ool00`00Oomoo`0DOol3000WOol3000mOol00`00Oomoo`0[Ool00`00Oomoo`08
Ool000Moo`03001oogoo02Uoo`800003>:/007Z`01Aj/08000eoo`03001oogoo011oo`<002Moo`<0
045oo`03001oogoo02Yoo`03001oogoo00Qoo`001goo00<007ooOol09goo0P000SR[00<007Z`N[00
5WZ`0P0037oo00<007ooOol037oo0`009goo0`00AGoo00<007ooOol0:Goo00<007ooOol027oo0006
Ool00`00Oomoo`0XOol4>:/00`00N[1j/00HN[000`00Oomoo`0:Ool00`00Oomoo`08Ool3000VOol4
0018Ool00`00Oomoo`0YOol00`00Oomoo`08Ool000Ioo`03001oogoo02Moo`03000hZcR[008hZ`03
001j/7Z`01Qj/003001oogoo00]oo`03001oogoo00Aoo`<002Ioo`<004eoo`03001oogoo02Qoo`03
001oogoo00Qoo`001Woo00<007ooOol09goo00D003R[>:/hZ`0001aj/003001oogoo00]oo`03001o
ogoo00<002Ioo`<0055oo`03001oogoo02Qoo`03001oogoo00Moo`001Woo00<007ooOol09goo00D0
03R[>:/hZ`0001ej/003001oogoo00]oo`8002Ioo`<005Eoo`03001oogoo02Moo`03001oogoo00Mo
o`001Woo00<007ooOol09Woo00<003R[>:/00SR[00<007Z`N[0077Z`00<007ooOol02Woo00<007oo
Ool08Woo0`00FGoo00<007ooOol09Woo00<007ooOol01goo0006Ool00`00Oomoo`0VOol01@00>:/h
ZcR[00007gZ`00<007ooOol02Woo00<007ooOol07Woo1000G7oo00<007ooOol09Woo00<007ooOol0
1goo0006Ool00`00Oomoo`0VOol01@00>:/hZcR[000087Z`00<007ooOol02Goo00<007ooOol06goo
0`00HGoo00<007ooOol09Goo00<007ooOol01goo0005Ool00`00Oomoo`0VOol00`00>:/hZ`02>:/0
0`00N[1j/00ON[000`00Oomoo`08Ool00`00Oomoo`0HOol3001UOol00`00Oomoo`0TOol00`00Oomo
o`07Ool000Eoo`03001oogoo02Ioo`05000hZcR[>:/0000RN[000`00Oomoo`08Ool00`00Oomoo`0E
Ool3001YOol00`00Oomoo`0SOol00`00Oomoo`07Ool000Eoo`03001oogoo02Eoo`03000hZcR[008h
Z`03001j/7Z`025j/003001oogoo00Moo`03001oogoo019oo`<006aoo`03001oogoo02=oo`03001o
ogoo00Moo`001Goo00<007ooOol09Goo00<003R[>:/00SR[00<007Z`N[008WZ`00<007ooOol01Woo
00<007ooOol03goo0`00L7oo00<007ooOol08goo00<007ooOol01Woo0005Ool00`00Oomoo`0UOol0
1@00>:/hZcR[00009GZ`00<007ooOol01Woo00<007ooOol02goo1000M7oo00<007ooOol08Woo00<0
07ooOol01Woo0005Ool00`00Oomoo`0TOol00`00>:/hZ`02>:/00`00N[1j/00TN[000`00Oomoo`05
Ool00`00Oomoo`08Ool3001iOol00`00Oomoo`0QOol00`00Oomoo`06Ool000Eoo`03001oogoo02Ao
o`03000hZcR[008hZ`03001j/7Z`02Ej/003001oogoo00Aoo`03001oogoo00=oo`03001oo`000080
01aoo`03001oogoo05eoo`03001oogoo025oo`03001oogoo00Ioo`0017oo00<007ooOol09Goo00D0
03R[>:/hZ`0002Uj/003001oogoo00=oo`03001oogoo009oo`<000Qoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo05eoo`03001oogoo021oo`03001oogoo00Ioo`0017oo00<007ooOol097oo
00<003R[>:/00`00:GZ`00<007ooOol00Woo00<007ooOol0100017oo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol0GWoo00<007oo
Ool07goo00<007ooOol01Woo0004Ool00`00Oomoo`0TOol30002BK<00`00N[1j/00XN[000`00Oomo
o`040003Ool01`00Oomoogoo001oo`0000Eoo`07001oogooOol007oo00001Goo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`1OOol00`00Oomoo`0NOol00`00Oomoo`06Ool000Aoo`03001oogoo02Ao
o`030019/dVc0099/`03001j/7Z`02Mj/0@00003Ool007oo00=oo`03001oogoo009oo`03001oo`00
00Uoo`03001oo`0000Uoo`03001oo`0000Eoo`03001oogoo05ioo`03001oogoo01ioo`03001oogoo
00Ioo`0017oo00<007ooOol097oo00<004VcBK<00TVc00<007Z`N[009GZ`0`0000Ej/000Oomoo`00
00Eoo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0000Uoo`03001oo`0000Aoo`03001oogoo
061oo`03001oogoo01ioo`03001oogoo00Eoo`0017oo00<007ooOol097oo00<004VcBK<00TVc00<0
07Z`N[008WZ`0`0017Z`00@007ooOol000Eoo`07001oogooOol007oo00002Goo00<007oo00002Goo
00<007oo000017oo00<007ooOol0HGoo00<007ooOol07Goo00<007ooOol01Goo0004Ool00`00Oomo
o`0TOol00`00BK=9/`02BK<00`00N[1j/00ON[030007N[001000Oomoo`001Woo00D007ooOomoo`00
00]oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo06=oo`03001oogoo01aoo`03001oogoo
00Eoo`0017oo00<007ooOol097oo00<004VcBK<00TVc00<007Z`N[0077Z`0`002gZ`00<007oo0000
SGoo00<007ooOol077oo00<007ooOol01Goo0003Ool00`00Oomoo`0UOol00`00BK=9/`03BK<00`00
N[1j/00GN[04000>N[000`00Ool0002>Ool00`00Oomoo`0KOol00`00Oomoo`05Ool000=oo`03001o
ogoo02Ioo`030019/dVc0099/`03001j/7Z`01Aj/0<0019j/003001oo`0008moo`03001oogoo01Yo
o`03001oogoo00Eoo`000goo00<007ooOol09Woo00<004VcBK<00TVc00<007Z`N[004GZ`0`005WZ`
0P00T7oo00<007ooOol06Goo00<007ooOol01Goo0003Ool00`00Oomoo`0VOol00`00BK=9/`02BK<0
0`00N[1j/00>N[03000IN[02002@Ool00`00Oomoo`0IOol00`00Oomoo`05Ool000=oo`03001oogoo
02Ioo`030019/dVc0099/`03001j/7Z`00]j/0<001aj/080095oo`03001oogoo01Uoo`03001oogoo
00Aoo`000goo00<007ooOol09Woo00<004VcBK<00TVc00<007Z`N[001gZ`100087Z`00<007ooOol0
T7oo00<007ooOol067oo00<007ooOol017oo0003Ool00`00Oomoo`0VOol00`00BK=9/`02BK<00`00
N[1j/004N[030009N[03000HN[000`00Oomoo`2AOol00`00Oomoo`0GOol00`00Oomoo`04Ool0009o
o`03001oogoo02Moo`030019/dVc0099/`04001j/7Z`N[03000<N[000`00N[1j/00IN[001000Oomo
ogoo0P00SWoo00<007ooOol05Woo00<007ooOol017oo0002Ool00`00Oomoo`0WOol00`00BK=9/`02
BK<4000@N[000`00N[1j/00HN[000`00Oomoo`03Ool3002;Ool00`00Oomoo`0FOol00`00Oomoo`04
Ool0009oo`03001oogoo02Moo`030019/dVc00<001=j/003001j/7Z`01Qj/003001oo`0000P008Yo
o`03001oogoo01Eoo`03001oogoo00Aoo`000Woo00<007ooOol09Woo10000TVc00<007Z`N[0047Z`
00<007Z`00006WZ`00<007ooOol00Woo1000S7oo00<007ooOol057oo00<007ooOol017oo0002Ool0
0`00Oomoo`0SOol300000goo0019/`03BK<00`00N[1j/00AN[000`00N[1j/00IN[0500000goo0000
002>Ool00`00Oomoo`0COol00`00Oomoo`04Ool0009oo`03001oogoo021oo`<000Aoo`030019/dVc
00=9/`03001j/7Z`02Yj/0<000=oo`80011oo`<0009oo`D007Ioo`03001oogoo01Aoo`03001oogoo
00=oo`000Woo00<007ooOol07Goo0`001goo00<004VcBK<00dVc00<007Z`N[009gZ`0`000gZ`00<0
07oo00004goo00<007ooOol00goo00<007ooOol0Mgoo00<007ooOol04goo00<007ooOol00goo0000
0goo001oo`0LOol3000;Ool00`00BK=9/`02BK<00`00N[1j/00SN[040006N[000`00Oomoo`0COol3
0003Ool00`00Oomoo`1hOol00`00Oomoo`0BOol00`00Oomoo`03Ool00003Ool007oo01Uoo`<000io
o`030019/dVc0099/`03001j/7Z`021j/0<000Yj/003001oogoo01=oo`04001oogoo0002Ool00`00
Oomoo`1iOol00`00Oomoo`0AOol00`00Oomoo`03Ool00003Ool007oo01Eoo`@0015oo`030019/dVc
0099/`03001j/7Z`01ej/0<000ij/003001oogoo00Qoo`04001oogoo0006Ool01000Oomoo`000Woo
00<007ooOol0NGoo00<007ooOol04Goo00<007ooOol00goo00000goo001oo`0BOol3000EOol00`00
BK=9/`02BK<00`00N[1j/00IN[04000AN[000`00Oomoo`09Ool20006Ool40002Ool2001lOol00`00
Oomoo`0@Ool00`00Oomoo`03Ool00003Ool007oo00moo`<001Qoo`040019/dVcBK<2000IN[02000E
N[000`00Oomoo`09Ool2002;Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00003Ool007oo00aoo`<0
01]oo`060019/`00001>=`006GZ`0P005GZ`00<007ooOol027oo00@007ooOol008]oo`03001oogoo
00ioo`03001oogoo00=oo`0000=oo`00Ool02Goo0`007Woo0P0014hg00<007Z`N[005WZ`00<007Z`
000057Z`00<007ooOol0Ugoo00<007ooOol03goo00<007ooOol00Woo00000`00Oomoo`05Ool4000Q
Ool00`00CSM>=`03CSL00`00N[1j/00FN[000`00N[1j/002000CN[000`00Oomoo`2GOol00`00Oomo
o`0>Ool00`00Oomoo`02Ool00003001oogoo009oo`<002Ioo`03001>=dhg009>=`03001j/7Z`01Ij
/003001j/7Z`009j/003001j/7Z`011j/003001oogoo09Qoo`03001oogoo00eoo`03001oogoo009o
o`0000<007oo00000P00:Goo00<004hgCSL00dhg00<007Z`N[005GZ`00<007Z`N[000gZ`00<007Z`
N[003gZ`00<007ooOol0VGoo00<007ooOol037oo00<007ooOol00Woo0002000]Ool00`00CSM>=`02
CSL00`00N[1j/00EN[000`00N[1j/004N[000`00N[1j/00>N[000`00Oomoo`2IOol00`00Oomoo`0<
Ool00`00Oomoo`02Ool00003Ool007oo02aoo`03001>=dhg009>=`03001j/7Z`01Ej/003001j/7Z`
00Ej/003001j/7Z`00ej/003001oogoo00Moo`03001oogoo01ioo`03001oogoo06moo`03001oogoo
00]oo`03001oogoo009oo`000Woo0P00:goo00<004hgCSL00dhg00<007Z`N[004gZ`00<007Z`N[00
1gZ`0P003GZ`00<007ooOol01Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol0Kgoo00<007ooOol02Woo00<007ooOol00Woo0004Ool00`00Oomoo`0YOol00`00CSM>=`02
CSL00`00N[1j/00CN[000`00N[1j/009N[000`00N[1j/00:N[000`00Oomoo`06Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`1`Ool00`00Oomoo`09Ool00`00Oomoo`02Ool000Eoo`03001oogoo02Qoo`03001>
=dhg009>=`03001j/7Z`01=j/003001j/7Z`00Yj/004001j/7Z`0008N[000`00Oomoo`06Ool01`00
Oomoogoo001oo`0000Eoo`07001oogooOol007oo00001Goo00L007ooOomoo`00Ool00004Ool00`00
Oomoo`1aOol00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`8002Uoo`03001>=dhg009>=`03001j
/7Z`019j/003001j/7Z`00]j/004001j/7Z`0008N[000`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Ool00009Ool00`00Ool00009Ool00`00Ool00005Ool00`00Oomoo`1`Ool00`00Oomoo`09Ool00`00
Oomoo`01Ool000Qoo`03001oogoo02Ioo`03001>=dhg009>=`03001j/7Z`019j/003001j/7Z`00aj
/005001j/000N[000006N[000`00Oomoo`05Ool01`00Oomoogoo001oo`0000Yoo`03001oogoo00Qo
o`03001oo`0000Aoo`03001oogoo079oo`03001oogoo00Qoo`03001oogoo005oo`002Goo00<007oo
Ool09Goo00<004hgCSL00Thg00<007Z`N[004WZ`00<007Z`N[003GZ`10001WZ`00<007ooOol01Goo
00L007ooOomoo`00Ool00009Ool00`00Ool00009Ool00`00Ool00004Ool00`00Oomoo`1cOol00`00
Oomoo`07Ool00`00Oomoo`01Ool000Yoo`8002Ioo`03001>=dhg009>=`03001j/7Z`015j/003001j
/7Z`00mj/08000Ij/003001oogoo00Ioo`05001oogooOol0000;Ool00`00Oomoo`09Ool00`00Oomo
o`02Ool00`00Oomoo`1eOol00`00Oomoo`06Ool00`00Oomoo`01Ool000aoo`03001oogoo02=oo`03
001>=dhg009>=`03001j/7Z`015j/003001j/7Z`00aj/0D000Ij/003001oogoo09moo`03001oogoo
00Ioo`03001oogoo005oo`003Goo00<007ooOol08goo00<004hgCSL00Thg00<007Z`N[0047Z`00<0
07Z`N[005gZ`00<007ooOol0X7oo00<007ooOol01Goo00<007ooOol00Goo000>Ool2000SOol00`00
CSM>=`02CSL00`00N[1j/00@N[000`00N[1j/00GN[000`00Oomoo`2QOol00`00Oomoo`04Ool00`00
Oomoo`01Ool0011oo`03001oogoo021oo`03001>=dhg009>=`03001j/7Z`011j/003001j/7Z`01Mj
/003001oogoo0:9oo`03001oogoo00Aoo`40005oo`5oo`004Goo00<007ooOol087oo00<004hgCSL0
0Thg00<007Z`N[003gZ`00<007Z`N[0067Z`00<007ooOol0XGoo00<007ooOol017oo0@000Goo0Goo
000BOol2000POol00`00CSM>=`02CSL00`00N[1j/00?N[000`00N[1j/00HN[000`00Oomoo`2ROol0
0`00Oomoo`03Ool10001Ool1Ool001Aoo`03001oogoo01ioo`05001>=dhgCSL0000AN[000`00N[1j
/00EN[0200000gZ`001oo`2TOol00`00Oomoo`02Ool10001Ool1Ool001Eoo`03001oogoo01eoo`03
001>=dhg009>=`03001j/7Z`00aj/003001j/00001Qj/003001j/0000:Ioo`05001oogooOol00002
Ool001Ioo`8001eoo`03001>=dhg009>=`03001j/7Z`00aj/080009j/003001j/7Z`01Aj/003001j
/0000:Ioo`05001oogooOol00002Ool001Qoo`03001oogoo01]oo`05001>=dhgCSL0000>N[020002
N[000`00N[1j/00CN[000`00N[00002XOol01000Oomoo`000Woo000IOol00`00Oomoo`0JOol00`00
CSM>=`02CSL00`00N[1j/00;N[0200000gZ`001j/00EN[000`00N[00002YOol00`00Ool00002Ool0
01Yoo`8001]oo`03001>=dhg008000ej/0800003N[0007Z`01Aj/0800003N[0000000:Uoo`03001o
o`00005oo`0077oo00<007ooOol067oo0`000U:k00<007Z`N[002gZ`0P006GZ`00<007ooOol0Z7oo
00<007oo00000Goo000MOol00`00Oomoo`0HOol00`00D[]B^`02D[/00`00N[1j/00:N[02000HN[00
0`00Oomoo`08Ool30003Ool3002IOol20001Ool001ioo`03001oogoo01Qoo`05001B^e:kD[/0000<
N[000`00N[1j/00GN[000`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`2IOol20001Ool001mo
o`8001Qoo`03001B^e:k009B^`03001j/7Z`00Uj/003001j/7Z`01Mj/003001oogoo00Uoo`<000=o
o`03001oogoo09Aoo`@000=oo`008Goo00<007ooOol05Woo00<005:kD[/00U:k00<007Z`N[008GZ`
00<007ooOol02Woo00@007ooOol0009oo`03001oogoo091oo`@000Moo`008Woo00<007ooOol05Woo
00<005:kD[/00U:k00<007Z`N[0087Z`00<007ooOol02Woo00P007ooOol007oo001oo`00SGoo1000
2goo000SOol2000GOol00`00D[]B^`02D[/00`00N[1j/00ON[000`00Oomoo`09Ool40003Ool00`00
Oomoo`28Ool4000?Ool002Eoo`03001oogoo01Aoo`03001B^e:k00=B^`03001j/7Z`01ij/003001o
ogoo09Moo`@001=oo`009Woo00<007ooOol057oo00<005:kD[/00U:k00<007Z`N[007GZ`00<007oo
Ool0U7oo10005goo000WOol2000EOol00`00D[]B^`02D[/00`00N[1j/00LN[000`00Oomoo`2@Ool4
000KOol002Uoo`03001oogoo01=oo`03001B^e:k009B^`03001j/7Z`01]j/003001oogoo08aoo`@0
01moo`00:Woo00<007ooOol04goo00<005:kD[/00U:k00<007Z`N[001gZ`10003gZ`00<007ooOol0
R7oo10008goo000[Ool2000COol00`00D[]B^`03D[/00`00N[1j/007N[000`00N[00000>N[000`00
Oomoo`25Ool4000WOol002eoo`03001oogoo015oo`03001B^e:k00=B^`03001j/7Z`00Ej/003001j
/00000mj/003001oogoo085oo`@002]oo`00;Woo00<007ooOol04Goo00<005:kD[/00U:k00<007Z`
N[001GZ`10003GZ`00<007ooOol0OWoo1000;goo000_Ool2000BOol00`00D[]B^`02D[/00`00N[1j
/00CN[02001mOol4000cOol0035oo`03001oogoo00moo`03001B^e:k00=B^`80019j/003001oogoo
07Uoo`@003Moo`00<Woo00<007ooOol03goo00<005:kD[/00P000T]o0`003WZ`00<007ooOol0MWoo
1000>goo000cOol2000@Ool20007Bgl2000;N[02001dOol4000oOol003Eoo`03001oogoo00moo`@0
00E;O`<000Ij/0800003Ool007oo06moo`@004=oo`00=Woo00<007ooOol04Woo0`001D]o0`000WZ`
00D007ooOomoo`0006aoo`@004Moo`00=goo0P005Goo100014]o0P0017oo00<007ooOol0IWoo1000
Bgoo000iOol00`00Oomoo`0FOol40006Ool00`00Oomoo`1ROol4001?Ool003Yoo`03001oogoo01mo
o`03001oogoo05ioo`@005=oo`00>goo0P007goo00<007ooOol0FWoo1000Egoo000mOol00`00Oomo
o`0LOol00`00Oomoo`1FOol4001KOol003ioo`03001oogoo01]oo`03001oogoo059oo`@005moo`00
?goo00<007ooOol06Woo00<007ooOol0CWoo1000Hgoo0010Ool2000JOol00`00Oomoo`1:Ool4001W
Ool0049oo`03001oogoo01Moo`03001oogoo04Ioo`@006]oo`00@goo00<007ooOol05Woo00<007oo
Ool0@Woo1000Kgoo0014Ool2000FOol00`00Oomoo`0nOol4001cOol004Ioo`03001oogoo01=oo`03
001oogoo03Yoo`@007Moo`00Agoo00<007ooOol04Woo00<007ooOol0=Woo1000Ngoo0018Ool2000B
Ool00`00Oomoo`0bOol4001oOol004Yoo`03001oogoo00moo`03001oogoo02ioo`@008=oo`00Bgoo
00<007ooOol03Woo00<007ooOol0:Woo1000Qgoo001<Ool2000=Ool00`00Oomoo`0WOol4002;Ool0
04ioo`03001oogoo00Yoo`03001oogoo02=oo`@008moo`00Cgoo00<007ooOol02Goo00<007ooOol0
7goo1000Tgoo001@Ool20009Ool00`00Oomoo`0KOol4002GOol0059oo`03001oogoo00Ioo`03001o
ogoo01Moo`@009]oo`00Dgoo00<007ooOol01Goo00<007ooOol04goo1000Wgoo001DOol20005Ool0
0`00Oomoo`0?Ool4002SOol005Ioo`03001oogoo009oo`03001oogoo00]oo`@00:Moo`00Egoo00D0
07ooOomoo`0000Uoo`@00:]oo`00F7oo0P0000=oo`00Ool017oo1000[goo001JOol200000goo0000
0002002cOol005]oo`800;Moo`00\
\>"],
  ImageRangeCache->{{{0, 275}, {262, 0}} -> {-0.000190518, 0.000567246, 
  0.00354754, 0.00354754}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Slider"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The slider graphic uses the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to generate the rectangular box form of the slider."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the slider graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(slidergraphic = 
      Graphics3D[{Box[slider, {{\(-4\), \(-1.5\), \(-2\)}, {4, 1.5, 2}}]}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the slider annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(slidertext = 
      Graphics3D[{LocalAxes[slider, 8], 
          Text[FontForm["\<Slider\>", {"\<Times-Bold\>", 12}], {24, 4, 
              23}]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Like the crank graphic, the coordinates in the slider graphic are \
functions of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " dependent variables. Thus, a solution rule must be applied to display the \
graphic."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Show it."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot3 = 
      Show[{slidergraphic, slidertext} /. SolveMech[0], 
        PlotRange \[Rule] {{\(-2\), 37}, {\(-10\), 20}, {\(-4\), 24}}]; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95309 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.02544 -0.000586442 1.02544 [
[ 0 0 0 0 ]
[ 1 .95309 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
.35203 .54414 m
.06189 .25974 L
s
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
.35203 .54414 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
0 0 m
1 0 L
1 .95309 L
0 .95309 L
closepath
clip
newpath
.5 Mabswid
.59189 .37584 m
.57823 .34797 L
s
.56533 .36384 m
.59189 .37584 L
s
.59189 .37584 m
.57868 .37079 L
s
.59164 .35483 m
.59189 .37584 L
s
.44237 .26933 m .47003 .30209 L .60284 .25443 L p .668 .736 .901 r
F P
0 g
s
.60447 .31227 m .46928 .35944 L .47003 .30209 L p .537 .314 .524 r
F P
0 g
s
.55436 .32975 m
.59189 .37584 L
s
.47003 .30209 m .60284 .25443 L .60447 .31227 L p .537 .314 .524 r
F P
0 g
s
.44237 .26933 m .47003 .30209 L .46928 .35944 L p .966 .687 .456 r
F P
0 g
s
.60284 .25443 m .57669 .22013 L .44237 .26933 L p .668 .736 .901 r
F P
0 g
s
.46928 .35944 m .44112 .32702 L .44237 .26933 L p .966 .687 .456 r
F P
0 g
s
.57669 .22013 m .44237 .26933 L .44112 .32702 L p .531 .305 .517 r
F P
0 g
s
.52241 .29053 m
.53589 .30707 L
s
.44112 .32702 m .46928 .35944 L .60447 .31227 L p .664 .741 .907 r
F P
0 g
s
.57786 .27829 m .60447 .31227 L .60284 .25443 L p .974 .683 .407 r
F P
0 g
s
.60284 .25443 m .57669 .22013 L .57786 .27829 L p .974 .683 .407 r
F P
0 g
s
.59056 .26616 m
.66033 .24121 L
s
.60447 .31227 m .57786 .27829 L .44112 .32702 L p .664 .741 .907 r
F P
0 g
s
.52241 .29053 m
.52243 .29804 L
s
.44112 .32702 m .57786 .27829 L .57669 .22013 L p .531 .305 .517 r
F P
0 g
s
.5225 .31967 m
.52277 .4103 L
s
.6391 .26045 m
.66033 .24121 L
s
.66033 .24121 m
.63179 .23967 L
s
.66033 .24121 m
.63266 .26293 L
s
.62529 .24199 m
.66033 .24121 L
s
.53012 .39435 m
.52277 .4103 L
s
.52277 .4103 m
.50886 .39037 L
s
.52277 .4103 m
.5366 .3809 L
s
.51521 .37687 m
.52277 .4103 L
s
gsave
.66033 .24121 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(x) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.59189 .37584 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(y) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.52277 .4103 -59.5 -1.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(z) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.52241 .29053 -72.5 -21.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
69.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier
%%DocumentNeededFonts: Courier
%%DocumentFonts: font Courier
grestore
gsave
.62282 .68313 -79 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Slider) show
94.312500 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
.25 Mabswid
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{276, 263},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004D00011a000`40O003h00OaGoo0P00CGoo0033
Ool200000goo0000001<Ool00<1oo`<000=oo`8004aoo`00_Woo0P001Woo00<007oo0000Bgoo002k
Ool30008Ool01000Oomoo`00BWoo002iOol2000;Ool01000Oomoo`00BWoo002fOol3000=Ool01@00
Oomoogoo0000BGoo002dOol2000@Ool01@00Oomoogoo0000BGoo002aOol3000COol01@00Oomoogoo
0000B7oo002_Ool2000FOol00`00Oomoo`02Ool00`00Oomoo`15Ool00:aoo`<001Qoo`03001oogoo
009oo`03001oogoo04Eoo`00ZWoo0P006goo00<007ooOol00goo00<007ooOol0A7oo002WOol3000M
Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00:Eoo`80021oo`03001oogoo00Aoo`03001oogoo04=o
o`00XWoo0`008Woo00<007ooOol01Goo00<007ooOol0@Woo002POol2000UOol00`00Oomoo`05Ool0
0`00Oomoo`12Ool009eoo`<002Moo`03001oogoo00Ioo`03001oogoo045oo`00Vgoo0P00:Woo00<0
07ooOol01goo00<007ooOol0@7oo002HOol3000/Ool00`00Oomoo`07Ool00`00Oomoo`10Ool009Eo
o`<002moo`03001oogoo00Qoo`03001oogoo03moo`00Tgoo0P00<Woo00<007ooOol02Goo00<007oo
Ool0?Woo002@Ool3000dOol00`00Oomoo`09Ool00`00Oomoo`0nOol008ioo`8003Qoo`03001oogoo
00Uoo`03001oogoo03eoo`00Rgoo0`00>Woo00<007ooOol02Goo00<007ooOol0?Goo0029Ool2000m
Ool00`00Oomoo`0:Ool00`00Oomoo`0lOol008Ioo`<003moo`03001oogoo00]oo`03001oogoo03]o
o`00Q7oo0P00@Woo00<007ooOol02goo00<007ooOol0>goo0021Ool30014Ool00`00Oomoo`0<Ool0
0`00Oomoo`0jOol007moo`8004Moo`03001oogoo00eoo`03001oogoo03Uoo`00O7oo0`00BGoo00<0
07ooOol03Goo00<007ooOol0>Goo001jOol2001<Ool00`00Oomoo`0>Ool00`00Oomoo`0hOol007Mo
o`<004ioo`03001oogoo00ioo`03001oogoo03Qoo`00MGoo0P00DGoo00<007ooOol03goo00<007oo
Ool0=goo001bOol3001COol00`00Oomoo`0@Ool00`00Oomoo`0fOol0071oo`8005Ioo`03001oogoo
011oo`03001oogoo03Ioo`00KGoo0`00F7oo00<007ooOol04Goo00<007ooOol0=Goo001[Ool2001L
Ool00`00Oomoo`0AOol00`00Oomoo`0dOol006Qoo`<005ioo`03001oogoo015oo`03001oogoo03Ao
o`00IWoo0P00HGoo00<007ooOol04Woo00<007ooOol0<goo001SOol3001SOol00`00Oomoo`0COol0
0`00Oomoo`0bOol0065oo`8006Ioo`03001oogoo01=oo`03001oogoo039oo`00GWoo0`00J7oo00<0
07ooOol057oo00<007ooOol0<Goo001LOol2001[Ool00`00Oomoo`0DOol00`00Oomoo`0aOol005Uo
o`<006eoo`03001oogoo01Eoo`03001oogoo031oo`00Egoo0P00L7oo00<007ooOol05Woo00<007oo
Ool0;goo001DOol3001bOol00`00Oomoo`0FOol00`00Oomoo`0_Ool0059oo`8007Eoo`03001oogoo
01Moo`03001oogoo02ioo`00Cgoo0`00Mgoo00<007ooOol067oo00<007ooOol0;Goo001=Ool2001j
Ool00`00Oomoo`0HOol00`00Oomoo`0]Ool004Yoo`<007aoo`03001oogoo01Uoo`03001oogoo02ao
o`00B7oo0P00P7oo00<007ooOol067oo00<007ooOol0;7oo0015Ool30022Ool00`00Oomoo`0IOol0
0`00Oomoo`0[Ool004=oo`8008Eoo`03001oogoo01Yoo`03001oogoo02Yoo`00@7oo0`00Qgoo00<0
07ooOol06Woo00<007ooOol0:Woo000mOol3002:Ool00`00Oomoo`0KOol00`00Oomoo`0YOol003]o
o`8008eoo`03001oogoo01aoo`03001oogoo02Qoo`00>7oo0`00Sgoo00<007ooOol077oo00<007oo
Ool0:7oo000fOol2002BOol00`00Oomoo`0MOol00`00Oomoo`0WOol003=oo`<009Aoo`03001oogoo
01eoo`03001oogoo02Moo`00<Goo0P00Ugoo00<007ooOol07Woo00<007ooOol09Woo000^Ool3002I
Ool00`00Oomoo`0OOol00`00Oomoo`0UOol002aoo`8006moo`8002]oo`03001oogoo01moo`03001o
ogoo02Eoo`00:Goo0`00Kgoo0P0000=1<0000000:Woo00<007ooOol087oo00<007ooOol097oo000W
Ool2001_Ool30003@C000`00OZd0000YOol00`00Oomoo`0QOol00`00Oomoo`0SOol002Aoo`<006io
o`<000I1<003001n[@0002Uoo`03001oogoo025oo`03001oogoo02=oo`008Woo0P00Kgoo0P002D4`
00@007j]OZd002Uoo`03001oogoo025oo`03001oogoo029oo`007goo0`00KWoo0`002d4`00D007j]
OZen[@0000Yoo`@001Yoo`03001oogoo029oo`03001oogoo025oo`007Goo0P00KWoo0`003T4`00<0
07j]OZd00Wj]00<007ooOol01Goo2`005Goo00<007ooOol08Woo00<007ooOol08Goo000JOol3001^
Ool2000A@C000`00OZen[@02OZd00`00Oomoo`0;Ool4000FOol00`00Oomoo`0SOol00`00Oomoo`0P
Ool001Qoo`8006eoo`@001=1<003001n[Gj]00=n[@03001oogoo00Qoo`800003Ool0000001Moo`03
001oogoo02=oo`03001oogoo021oo`005Goo0`00KGoo0`0000=1<000@C004d4`00<007j]OZd017j]
00<007ooOol017oo0`000Woo0P0067oo00<007ooOol097oo00<007ooOol07goo000COol2001^Ool2
0003@C000`00@C11<00C@C000`00OZen[@04OZd01000Oomoogoo0`0017oo00<007ooOol067oo00<0
07ooOol09Goo00<007ooOol07Woo000AOol2001]Ool30006@C000`00@C11<00B@C000`00OZen[@04
OZd01000Ool000001Goo0P006goo00<007ooOol09Goo00<007ooOol07Woo000AOol2001ZOol30007
@C000`00@C00000D@C000`00OZen[@03OZd30006Ool00`00Oomoo`0KOol00`00Oomoo`0VOol00`00
Oomoo`0MOol0015oo`03001oo`0006Moo`8000]1<0030011<44`01=1<004001n[Gj]OZd200000gj]
001oo`0TOol00`00Oomoo`0WOol00`00Oomoo`0LOol0015oo`04001oogoo001TOol2000S@C000`00
OZen[@04OZd00`00Oomoo`0BOol01000Oomoo`003Goo00<007ooOol09goo00<007ooOol077oo000@
Ool00`00Oomoo`02Ool00`00Oomoo`1QOol00`00@C11<00R@C000`00OZen[@04OZd00`00Oomoo`0C
Ool2000>Ool00`00Oomoo`0XOol00`00Oomoo`0KOol0011oo`03001oogoo00=oo`03001oogoo061o
o`030011<44`0251<08000In[@03001oogoo01=oo`8000ioo`03001oogoo02Qoo`03001oogoo01]o
o`0047oo00<007ooOol017oo00<007ooOol0Ggoo00<0044`@C007T4`0`000UKm00<007j]OZd00gj]
00<007ooOol04Woo00@007ooOol000eoo`03001oogoo02Uoo`03001oogoo01Yoo`0047oo00<007oo
Ool01Goo00<007ooOol0GWoo00<0044`@C006d4`0`001UKm00<007j]OZd00gj]00<007ooOol08goo
00<007ooOol0:Goo00<007ooOol06Goo000@Ool00`00Oomoo`06Ool00`00Oomoo`1MOol00`00@C11
<00I@C02000:E_d00`00OZen[@02OZd00`00Oomoo`0SOol00`00Oomoo`0YOol00`00Oomoo`0IOol0
011oo`03001oogoo00Moo`03001oogoo05aoo`030011<44`01I1<0<000eFo@05001n[Gj]OZd0000U
Ool00`00Oomoo`0ZOol00`00Oomoo`0HOol0011oo`03001oogoo00Qoo`03001oogoo05]oo`030011
<44`01=1<0<0011Fo@05001n[Gj]OZd0000UOol00`00Oomoo`0[Ool00`00Oomoo`0GOol000moo`03
001oogoo00Yoo`03001oogoo05Yoo`030011<44`0111<0<001AFo@04001n[Gj]000UOol00`00Oomo
o`0[Ool00`00Oomoo`0GOol000moo`03001oogoo00]oo`03001oogoo05Uoo`030011<44`00e1<0<0
01QFo@03001n[@0002Eoo`03001oogoo02aoo`03001oogoo01Ioo`003goo00<007ooOol037oo00<0
07ooOol0F7oo00<0044`@C002T4`0`0075Km0P009Goo00<007ooOol0;7oo00<007ooOol05Woo000?
Ool00`00Oomoo`0=Ool00`00Oomoo`1GOol00`00@C11<007@C03000PE_d00`00Oomoo`0SOol00`00
Oomoo`0]Ool00`00Oomoo`0EOol000moo`03001oogoo00ioo`03001oogoo05Ioo`030011<44`00E1
<08001mFo@<002Moo`03001oogoo02ioo`03001oogoo01Aoo`003goo00<007ooOol03goo00<007oo
Ool0EGoo00<0044`@C000T4`0`003UKm00<005KmE_d03EKm0`00:Woo00<007ooOol0;Woo00<007oo
Ool057oo000?Ool00`00Oomoo`0@Ool00`00Oomoo`1DOol00`00@C000002000AE_d00`00E_eFo@0;
E_d2000]Ool00`00Oomoo`0_Ool00`00Oomoo`0COol000ioo`03001oogoo019oo`03001oogoo05=o
o`8001AFo@03001FoEKm00QFo@<002moo`03001oogoo031oo`03001oogoo019oo`003Woo00<007oo
Ool04goo00<007ooOol0Dgoo00<005KmE_d04UKm00<005KmE_d01EKm0`00<Woo00<007ooOol0<7oo
00<007ooOol04Woo000>Ool00`00Oomoo`0DOol00`00Oomoo`1COol00`00E_eFo@0AE_d00`00E_eF
o@02E_d30002Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol00`00Oomoo`0AOol000ioo`03001oogoo
01Eoo`03001oogoo05=oo`03001FoEKm011Fo@03001Fo@00008000Ioo`03001oogoo031oo`03001o
ogoo031oo`03001oogoo015oo`003Woo00<007ooOol05Woo00<007ooOol0Dgoo00<005KmE_d03UKm
0`002Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol047oo000>Ool00`00Oomoo`0GOol0
0`00Oomoo`1BOol00`00E_eFo@0;E_d300000goo001oo`0:Ool00`00Oomoo`0_Ool00`00Oomoo`0b
Ool00`00Oomoo`0?Ool000ioo`03001oogoo01Qoo`03001oogoo059oo`03001FoEKm00QFo@8000Ao
o`03001oogoo00Yoo`04001oogoo000]Ool00`00Oomoo`0bOol00`00Oomoo`0?Ool000eoo`03001o
ogoo01Yoo`03001oogoo059oo`03001FoEKm00AFo@<000Ioo`03001oogoo00]oo`03001oo`0002eo
o`03001oogoo039oo`80011oo`003Goo00<007ooOol06goo00<007ooOol0DWoo00<005KmE_d00`00
2Goo00<007ooOol02goo00H007ooOol007oo000ZOol00`00Oomoo`0_Ool300000goo001oo`0?Ool0
00eoo`03001oogoo01aoo`03001oogoo059oo`8000aoo`03001oogoo00aoo`05001oo`00Ool0000Z
Ool00`00Oomoo`0/Ool30004Ool00`00Oomoo`0>Ool000eoo`03001oogoo01eoo`03001oogoo05mo
o`03001oogoo00eoo`800003Ool007oo02Uoo`03001oogoo02Uoo`<000Moo`03001oogoo00ioo`00
3Goo00<007ooOol07Woo00<007ooOol0GWoo00<007ooOol02Goo0P000goo0`00:Woo00<007ooOol0
9Woo0`002goo00<007ooOol03Goo000=Ool00`00Oomoo`0OOol00`00Oomoo`1MOol00`00Oomoo`0;
Ool6000ZOol00`00Oomoo`0SOol3000>Ool00`00Oomoo`0=Ool000eoo`03001oogoo021oo`03001o
ogoo05aoo`03001oogoo00eoo`@002Yoo`03001oogoo021oo`<0015oo`03001oogoo00eoo`003Goo
00<007ooOol08Goo00<007ooOol0FGoo00<007oo00004Goo0P00:Woo00<007ooOol077oo100057oo
00<007ooOol03Goo000<Ool00`00Oomoo`0SOol00`00Oomoo`1HOol00`00Ool00003Ool00`00Oomo
o`0gOol00`00Oomoo`0IOol3000HOol00`00Oomoo`0=Ool000aoo`03001oogoo02Aoo`03001oogoo
05Moo`03001oo`00009oo`03001oogoo03Qoo`03001oogoo01Ioo`<001]oo`03001oogoo00eoo`00
37oo00<007ooOol09Goo00<007ooOol0Egoo0P000Woo00<007ooOol0>Goo00<007ooOol04Woo0`00
7Woo00<007ooOol03Goo000<Ool00`00Oomoo`0VOol00`00Oomoo`1COol00`00Oomoo`0200000goo
001oo`0kOol00`00Oomoo`0?Ool3000QOol00`00Oomoo`0=Ool000aoo`03001oogoo02Moo`03001o
ogoo05=oo`06001oo`00001oo`00?7oo00<007ooOol037oo0`009Goo00<007ooOol037oo000<Ool0
0`00Oomoo`0XOol00`00Oomoo`1COol4000FOol2000UOol00`00Oomoo`09Ool3000XOol00`00Oomo
o`0<Ool000aoo`03001oogoo02Uoo`8005=oo`04001oo`00000GOol00`00Oomoo`0SOol00`00Oomo
o`06Ool3000[Ool00`00Oomoo`0<Ool000]oo`03001oogoo02aoo`03001oogoo055oo`8001Qoo`03
001oogoo02=oo`03001oogoo00=oo`<002ioo`03001oogoo00aoo`002goo00<007ooOol0;Goo00<0
07ooOol0DGoo00<007ooOol05Goo00<007oo000097oo00<007ooOol00`00<Goo00<007ooOol037oo
000;Ool00`00Oomoo`0^Ool00`00Oomoo`1XOol00`00Ool0000TOol3000dOol00`00Oomoo`0<Ool0
00]oo`03001oogoo02moo`03001oogoo06Ioo`800003Ool00000021oo`@003Ioo`03001oogoo00ao
o`002goo00<007ooOol0<7oo00<007ooOol0Qgoo0`000goo00<007ooOol0=7oo00<007ooOol037oo
000;Ool00`00Oomoo`0aOol00`00Oomoo`22Ool40006Ool00`00Oomoo`0eOol00`00Oomoo`0;Ool0
00]oo`03001oogoo039oo`03001oogoo07ioo`<000Yoo`03001oogoo03Eoo`03001oogoo00]oo`00
2Woo00<007ooOol0=7oo00<007ooOol0NWoo0`003Goo00<007ooOol0=Goo00<007ooOol02goo000:
Ool00`00Oomoo`0eOol00`00Oomoo`1fOol3000@Ool00`00Oomoo`0eOol00`00Oomoo`0;Ool000Yo
o`03001oogoo03Ioo`03001oogoo04ioo`@0021oo`<001Aoo`03001oogoo03Aoo`03001oogoo00]o
o`002Woo00<007ooOol0=goo00<007ooOol0CWoo00<007oo00007Goo0`005goo00<007ooOol0=7oo
00<007ooOol02goo000:Ool00`00Oomoo`0hOol00`00Oomoo`1<Ool00`00Ool0000KOol3000JOol0
0`00Oomoo`0dOol00`00Oomoo`0;Ool000Yoo`03001oogoo03Uoo`03001oogoo04]oo`@001Moo`<0
01eoo`03001oogoo03Aoo`03001oogoo00]oo`002Woo00<007ooOol0>Woo00<007ooOol0HWoo0`00
87oo00<007ooOol0=Goo00<007ooOol02Woo0009Ool00`00Oomoo`0lOol00`00Oomoo`1NOol3000S
Ool00`00Oomoo`0eOol00`00Oomoo`0:Ool000Uoo`03001oogoo03eoo`03001oogoo05Yoo`<002Io
o`03001oogoo03Eoo`03001oogoo00Yoo`002Goo00<007ooOol0?Woo00<007ooOol0EWoo0`00:7oo
0P00=goo00<007ooOol02Woo0009Ool00`00Oomoo`0oOol00`00Oomoo`1BOol3000XOol30002Ool0
0`00Oomoo`0dOol00`00Oomoo`0:Ool000Uoo`03001oogoo041oo`03001oogoo04eoo`@002Qoo`<0
00Ioo`03001oogoo03=oo`03001oogoo00Yoo`002Goo00<007ooOol0@Goo00<007ooOol0BGoo0`00
:7oo10002Goo00<007ooOol0<goo00<007ooOol02Woo0009Ool00`00Oomoo`12Ool00`00Oomoo`15
Ool3000XOol3000>Ool00`00Oomoo`0bOol00`00Oomoo`0:Ool000Qoo`03001oogoo04Aoo`03001o
ogoo045oo`<002Qoo`<0019oo`03001oogoo039oo`03001oogoo00Uoo`0027oo00<007ooOol0AGoo
00<007ooOol0?Goo0`00:7oo0`005Woo00<007ooOol0<Goo00<007ooOol02Goo0008Ool00`00Oomo
o`16Ool00`00Oomoo`0iOol3000XOol3000IOol00`00Oomoo`0aOol00`00Oomoo`09Ool000Qoo`03
001oogoo04Moo`03001oogoo03Eoo`<002Moo`@001eoo`03001oogoo031oo`03001oogoo00Uoo`00
27oo00<007ooOol0B7oo00<007ooOol0<Goo0`009goo0`008Woo00<007ooOol0;goo00<007ooOol0
2Goo0008Ool00`00Oomoo`19Ool00`00Oomoo`0]Ool3000WOol3000VOol00`00Oomoo`0^Ool00`00
Oomoo`09Ool000Qoo`03001oogoo04Yoo`03001oogoo02Uoo`<002Moo`<002Uoo`03001oogoo02io
o`03001oogoo00Uoo`001goo00<007ooOol0C7oo00<007ooOol09Goo0`009goo0`00;Goo00<007oo
Ool0;Goo00<007ooOol02Goo0007Ool00`00Oomoo`1=Ool00`00Oomoo`0QOol3000WOol3000aOol0
0`00Oomoo`0]Ool00`00Oomoo`08Ool000Moo`03001oogoo04ioo`03001oogoo01eoo`<002Ioo`@0
03Eoo`03001oogoo02aoo`03001oogoo00Qoo`001goo00<007ooOol0Cgoo00<007ooOol067oo1000
9Woo0`00>Goo00<007ooOol0;7oo00<007ooOol027oo0007Ool00`00Oomoo`1@Ool00`00Oomoo`0D
Ool3000WOol3000mOol00`00Oomoo`0[Ool00`00Oomoo`08Ool000Moo`03001oogoo055oo`03001o
ogoo011oo`<002Moo`<0045oo`03001oogoo02Yoo`03001oogoo00Qoo`001goo00<007ooOol0DWoo
00<007ooOol037oo0`009goo0`00AGoo00<007ooOol0:Goo00<007ooOol027oo0006Ool00`00Oomo
o`1DOol00`00Oomoo`08Ool3000VOol40018Ool00`00Oomoo`0YOol00`00Oomoo`08Ool000Ioo`03
001oogoo05Eoo`03001oogoo00Aoo`<002Ioo`<004eoo`03001oogoo02Qoo`03001oogoo00Qoo`00
1Woo00<007ooOol0EWoo00<007ooOol00`009Woo0`00DGoo00<007ooOol0:7oo00<007ooOol01goo
0006Ool00`00Oomoo`1GOol2000VOol3001EOol00`00Oomoo`0WOol00`00Oomoo`07Ool000Ioo`03
001oogoo05Moo`03001oogoo029oo`<005Uoo`03001oogoo02Ioo`03001oogoo00Moo`001Woo00<0
07ooOol0Egoo00<007ooOol07Woo1000G7oo00<007ooOol09Woo00<007ooOol01goo0006Ool00`00
Oomoo`1GOol00`00Oomoo`0KOol3001QOol00`00Oomoo`0UOol00`00Oomoo`07Ool000Eoo`03001o
ogoo05Qoo`03001oogoo01Qoo`<006Eoo`03001oogoo02Aoo`03001oogoo00Moo`001Goo00<007oo
Ool0F7oo00<007ooOol05Goo0`00JGoo00<007ooOol08goo00<007ooOol01goo0005Ool00`00Oomo
o`1HOol00`00Oomoo`0BOol3001/Ool00`00Oomoo`0SOol00`00Oomoo`07Ool000Eoo`03001oogoo
05Qoo`03001oogoo00moo`<0071oo`03001oogoo02=oo`03001oogoo00Ioo`001Goo00<007ooOol0
F7oo00<007ooOol02goo1000M7oo00<007ooOol08Woo00<007ooOol01Woo0005Ool00`00Oomoo`1H
Ool00`00Oomoo`08Ool3001iOol00`00Oomoo`0QOol00`00Oomoo`06Ool000Eoo`03001oogoo05Qo
o`03001oogoo00Eoo`<007aoo`03001oogoo025oo`03001oogoo00Ioo`0017oo00<007ooOol0FGoo
00<007ooOol00Woo0`00P7oo00<007ooOol087oo00<007ooOol01Woo0004Ool00`00Oomoo`1HOol0
0`00Oomoo`030024Ool00`00Oomoo`0OOol00`00Oomoo`06Ool000Aoo`03001oogoo05Moo`@008Qo
o`03001oogoo01ioo`03001oogoo00Ioo`0017oo00<007ooOol0E7oo0`0000=oo`00Ool0RGoo00<0
07ooOol07Woo00<007ooOol01Woo0004Ool00`00Oomoo`1AOol30004Ool00`00Oomoo`29Ool00`00
Oomoo`0NOol00`00Oomoo`05Ool000Aoo`03001oogoo04ioo`<000Moo`03001oogoo08Yoo`03001o
ogoo01eoo`03001oogoo00Eoo`0017oo00<007ooOol0Bgoo0`002Woo00<007ooOol0Rgoo00<007oo
Ool077oo00<007ooOol01Goo0004Ool00`00Oomoo`18Ool3000=Ool00`00Oomoo`2;Ool00`00Oomo
o`0LOol00`00Oomoo`05Ool000=oo`03001oogoo04Eoo`@0011oo`03001oogoo08aoo`03001oogoo
01]oo`03001oogoo00Eoo`000goo00<007ooOol0@Woo0`0057oo00<007ooOol0SGoo00<007ooOol0
6Woo00<007ooOol01Goo0003Ool00`00Oomoo`0oOol3000GOol00`00Oomoo`2>Ool00`00Oomoo`0I
Ool00`00Oomoo`05Ool000=oo`03001oogoo03aoo`<001Yoo`03001oogoo08ioo`03001oogoo01Uo
o`03001oogoo00Eoo`000goo00<007ooOol0>Goo0`007Goo00<007ooOol0Sgoo00<007ooOol06Goo
00<007ooOol017oo0003Ool00`00Oomoo`0eOol4000POol00`00Oomoo`2@Ool00`00Oomoo`0HOol0
0`00Oomoo`04Ool000=oo`03001oogoo039oo`<002Aoo`03001oogoo095oo`03001oogoo01Moo`03
001oogoo00Aoo`000Woo00<007ooOol0<7oo0`009goo00<007ooOol0TWoo00<007ooOol05Woo00<0
07ooOol017oo0002Ool00`00Oomoo`0]Ool3000ZOol00`00Oomoo`2BOol00`00Oomoo`0FOol00`00
Oomoo`04Ool0009oo`03001oogoo02Yoo`<002eoo`03001oogoo09=oo`03001oogoo01Eoo`03001o
ogoo00Aoo`000Woo00<007ooOol09Woo1000<7oo00<007ooOol0U7oo00<007ooOol057oo00<007oo
Ool017oo0002Ool00`00Oomoo`0SOol3000dOol00`00Oomoo`2EOol00`00Oomoo`0COol00`00Oomo
o`04Ool0009oo`03001oogoo021oo`<003Moo`03001oogoo09Eoo`03001oogoo01Aoo`03001oogoo
00=oo`000Woo00<007ooOol07Goo0`00>Woo00<007ooOol0UWoo00<007ooOol04goo00<007ooOol0
0goo00000goo001oo`0LOol3000mOol00`00Oomoo`2GOol00`00Oomoo`0BOol00`00Oomoo`03Ool0
0003Ool007oo01Uoo`<003moo`03001oogoo09Uoo`03001oogoo015oo`03001oogoo00=oo`0000=o
o`00Ool05Goo1000@Woo00<007ooOol0VGoo00<007ooOol04Goo00<007ooOol00goo00000goo001o
o`0BOol30016Ool00`00Oomoo`0kOol00`00Ool000020002Ool800000goo00000003000017oo0000
00000Woo1000@7oo00<007ooOol047oo00<007ooOol00goo00000goo001oo`0?Ool30019Ool00`00
Oomoo`0kOol20002Ool20002Ool20002Ool2000017oo000007oo0P0000=oo`0000000Woo00<007oo
Ool00P00@Woo00<007ooOol03goo00<007ooOol00goo00000goo001oo`0<Ool3001<Ool00`00Oomo
o`0kOol01000Oomoogoo0P000Woo0P000Woo0P0000Aoo`00001oo`800003Ool0000000Eoo`8004=o
o`03001oogoo00ioo`03001oogoo00=oo`0000=oo`00Ool02Goo0`00Cgoo00<007ooOol0?Woo0`00
0Woo0P000Woo0P0000Aoo`00001oo`800003Ool0000000<0009oo`8004=oo`03001oogoo00moo`03
001oogoo009oo`0000<007ooOol01Goo1000DWoo00<007ooOol0?7oo10000goo0P000Woo0P0000Ao
o`00001oo`800004Ool00000Ool20002Ool200000goo001oo`11Ool00`00Oomoo`0>Ool00`00Oomo
o`02Ool00003001oogoo009oo`<005Ioo`03001oogoo03]oo`<000Eoo`800004Ool000000002Ool4
0002Ool30002Ool50013Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00003001oo`00008005Uoo`03
001oogoo03]oo`8000=oo`03001oogoo008000Qoo`80051oo`03001oogoo00aoo`03001oogoo009o
o`000P00G7oo00<007ooOol0>goo0P000Woo0P000Woo0P000Woo0P0017oo0P00D7oo00<007ooOol0
37oo00<007ooOol00Woo00000goo001oo`1KOol00`00Oomoo`0lOol300000goo001oo`030002Ool2
0003Ool3001AOol00`00Oomoo`0;Ool00`00Oomoo`02Ool0009oo`8005Yoo`03001oogoo0:5oo`03
001oogoo00Yoo`03001oogoo009oo`0017oo00<007ooOol0Egoo00<007ooOol0XWoo00<007ooOol0
2Goo00<007ooOol00Woo0005Ool00`00Oomoo`1FOol00`00Oomoo`2SOol00`00Oomoo`09Ool00`00
Oomoo`01Ool000Ioo`8005Ioo`03001oogoo0:=oo`03001oogoo00Uoo`03001oogoo005oo`0027oo
00<007ooOol0Dgoo00<007ooOol0Y7oo00<007ooOol027oo00<007ooOol00Goo0009Ool00`00Oomo
o`1BOol00`00Oomoo`2UOol00`00Oomoo`07Ool00`00Oomoo`01Ool000Yoo`80059oo`03001oogoo
0:Ioo`03001oogoo00Ioo`03001oogoo005oo`0037oo00<007ooOol0Cgoo00<007ooOol0YWoo00<0
07ooOol01Woo00<007ooOol00Goo000=Ool00`00Oomoo`1>Ool00`00Oomoo`2WOol00`00Oomoo`05
Ool00`00Oomoo`01Ool000ioo`8004ioo`03001oogoo0:Qoo`03001oogoo00Aoo`03001oogoo005o
o`0047oo00<007ooOol0Bgoo00<007ooOol0ZGoo00<007ooOol017oo0@000Goo0Goo000AOol00`00
Oomoo`19Ool00`00Oomoo`2ZOol00`00Oomoo`04Ool10001Ool1Ool0019oo`8004Uoo`03001oogoo
0:]oo`03001oogoo00=oo`40005oo`5oo`0057oo00<007ooOol0AWoo00<007ooOol0[7oo00<007oo
Ool00Woo0@000Goo0Goo000EOol00`00Oomoo`15Ool00`00Oomoo`2]Ool01@00Oomoogoo00000Woo
000FOol20015Ool00`00Oomoo`2]Ool01@00Oomoogoo00000Woo000HOol00`00Oomoo`12Ool00`00
Oomoo`2^Ool01000Oomoo`000Woo000IOol00`00Oomoo`11Ool00`00Oomoo`2_Ool00`00Ool00002
Ool001Yoo`80045oo`03001oogoo0;1oo`03001oo`00005oo`0077oo00<007ooOol0?Woo00<007oo
Ool0/7oo00<007oo00000Goo000MOol00`00Oomoo`0mOol00`00Oomoo`2aOol20001Ool001ioo`03
001oogoo03aoo`03001oogoo0;5oo`80005oo`007goo0P00?7oo00<007ooOol0[Goo10000goo000Q
Ool00`00Oomoo`0iOol00`00Oomoo`2YOol40007Ool0029oo`03001oogoo03Qoo`03001oogoo0:Eo
o`@000]oo`008goo0P00>7oo00<007ooOol0XGoo10003goo000UOol00`00Oomoo`0eOol00`00Oomo
o`2MOol4000COol002Ioo`03001oogoo03Aoo`03001oogoo09Uoo`@001Moo`009goo0P00=7oo00<0
07ooOol0UGoo10006goo000YOol00`00Oomoo`0aOol00`00Oomoo`2AOol4000OOol002Yoo`03001o
ogoo031oo`03001oogoo08eoo`@002=oo`00:goo0P00<7oo00<007ooOol0RGoo10009goo000]Ool0
0`00Oomoo`0]Ool00`00Oomoo`25Ool4000[Ool002ioo`03001oogoo02aoo`03001oogoo085oo`@0
02moo`00;goo0P00:goo00<007ooOol0OWoo1000<goo000aOol00`00Oomoo`0XOol00`00Oomoo`1j
Ool4000gOol0039oo`03001oogoo02Moo`03001oogoo07Ioo`@003]oo`00<goo0P009goo00<007oo
Ool0LWoo1000?goo000eOol00`00Oomoo`0TOol00`00Oomoo`1^Ool40013Ool003Ioo`03001oogoo
02=oo`03001oogoo06Yoo`@004Moo`00=goo0P008goo00<007ooOol0IWoo1000Bgoo000iOol00`00
Oomoo`0POol00`00Oomoo`1ROol4001?Ool003Yoo`03001oogoo01moo`03001oogoo05ioo`@005=o
o`00>goo0P007goo00<007ooOol0FWoo1000Egoo000mOol00`00Oomoo`0LOol00`00Oomoo`1FOol4
001KOol003ioo`03001oogoo01]oo`03001oogoo059oo`@005moo`00?goo00<007ooOol06Woo00<0
07ooOol0CWoo1000Hgoo0010Ool2000JOol00`00Oomoo`1:Ool4001WOol0049oo`03001oogoo01Mo
o`03001oogoo04Ioo`@006]oo`00@goo00<007ooOol05Woo00<007ooOol0@Woo1000Kgoo0014Ool2
000FOol00`00Oomoo`0nOol4001cOol004Ioo`03001oogoo01=oo`03001oogoo03Yoo`@007Moo`00
Agoo00<007ooOol04Woo00<007ooOol0=Woo1000Ngoo0018Ool2000BOol00`00Oomoo`0bOol4001o
Ool004Yoo`03001oogoo00moo`03001oogoo02ioo`@008=oo`00Bgoo00<007ooOol03Woo00<007oo
Ool0:Woo1000Qgoo001<Ool2000=Ool00`00Oomoo`0WOol4002;Ool004ioo`03001oogoo00Yoo`03
001oogoo02=oo`@008moo`00Cgoo00<007ooOol02Goo00<007ooOol07goo1000Tgoo001@Ool20009
Ool00`00Oomoo`0KOol4002GOol0059oo`03001oogoo00Ioo`03001oogoo01Moo`@009]oo`00Dgoo
00<007ooOol01Goo00<007ooOol04goo1000Wgoo001DOol20005Ool00`00Oomoo`0?Ool4002SOol0
05Ioo`03001oogoo009oo`03001oogoo00]oo`@00:Moo`00Egoo00D007ooOomoo`0000Uoo`@00:]o
o`00F7oo0P0000=oo`00Ool017oo1000[goo001JOol200000goo00000002002cOol005]oo`800;Mo
o`00\
\>"],
  ImageRangeCache->{{{0, 275}, {262, 0}} -> {-0.000190518, 0.000567246, 
  0.00354754, 0.00354754}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Connecting Rod"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The connecting rod graphic uses the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function again to generate a long, thin cylinder spanning from the crank \
to the slider."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the connecting rod graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(conrodgraphic = Graphics3D[{Bar[Line[crank, 2, slider, 0], 1.0, 8]}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the connecting rod annotation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(conrodtext = 
      Graphics3D[{
          Text[FontForm["\<Connecting Rod\>", {"\<Times-Bold\>", 12}], {25, 
              4, 23}]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot4 = 
      Show[{conrodgraphic, conrodtext} /. SolveMech[0], 
        PlotRange \[Rule] {{\(-2\), 37}, {\(-10\), 20}, {\(-4\), 24}}]; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95309 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.02544 -0.000586442 1.02544 [
[ 0 0 0 0 ]
[ 1 .95309 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
.35203 .54414 m
.06189 .25974 L
s
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
.35203 .54414 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
0 0 m
1 0 L
1 .95309 L
0 .95309 L
closepath
clip
newpath
.5 Mabswid
.50787 .28139 m .51967 .28208 L .35173 .73245 L p .811 .787 .83 r
F P
0 g
s
.35173 .73245 m .34051 .7332 L .50787 .28139 L p .811 .787 .83 r
F P
0 g
s
.36381 .73768 m .35173 .73245 L .51967 .28208 L p .65 .602 .788 r
F P
0 g
s
.35173 .73245 m .34051 .7332 L p .36606 .75226 L .751 .401 .39 r
F P
0 g
s
.36381 .73768 m .35173 .73245 L p .36606 .75226 L .751 .401 .39 r
F P
0 g
s
.51967 .28208 m .53303 .28769 L .36381 .73768 L p .65 .602 .788 r
F P
0 g
s
.36976 .74587 m .36381 .73768 L .53303 .28769 L p .395 .324 .659 r
F P
0 g
s
.36606 .75226 m .36976 .74587 L .36381 .73768 L p .751 .401 .39 r
F P
0 g
s
.5045 .28606 m .50787 .28139 L .34051 .7332 L p .841 .901 .486 r
F P
0 g
s
.34051 .7332 m .33669 .73953 L .5045 .28606 L p .841 .901 .486 r
F P
0 g
s
.34051 .7332 m .33669 .73953 L p .36606 .75226 L .751 .401 .39 r
F P
0 g
s
.53303 .28769 m .54024 .29498 L .36976 .74587 L p .395 .324 .659 r
F P
0 g
s
.36606 .75226 m .36976 .74587 L .54024 .29498 L p .82 .887 .46 r
F P
0 g
s
.51166 .2934 m .5045 .28606 L .33669 .73953 L p .388 .318 .657 r
F P
0 g
s
.33669 .73953 m .34259 .74778 L p .36606 .75226 L .751 .401 .39 r
F P
0 g
s
.33669 .73953 m .34259 .74778 L .51166 .2934 L p .388 .318 .657 r
F P
0 g
s
.34259 .74778 m .35479 .75307 L .36606 .75226 L p .751 .401 .39 r
F P
0 g
s
.35479 .75307 m .36606 .75226 L .53704 .29972 L p .812 .791 .832 r
F P
0 g
s
.54024 .29498 m .53704 .29972 L .36606 .75226 L p .82 .887 .46 r
F P
0 g
s
.52519 .29908 m .51166 .2934 L .34259 .74778 L p .649 .602 .789 r
F P
0 g
s
.34259 .74778 m .35479 .75307 L .52519 .29908 L p .649 .602 .789 r
F P
0 g
s
.53704 .29972 m .52519 .29908 L .35479 .75307 L p .812 .791 .832 r
F P
0 g
s
.51967 .28208 m .50787 .28139 L p .53704 .29972 L .729 .292 .212 r
F P
0 g
s
.53303 .28769 m .51967 .28208 L p .53704 .29972 L .729 .292 .212 r
F P
0 g
s
.53704 .29972 m .54024 .29498 L .53303 .28769 L p .729 .292 .212 r
F P
0 g
s
.50787 .28139 m .5045 .28606 L p .53704 .29972 L .729 .292 .212 r
F P
0 g
s
.5045 .28606 m .51166 .2934 L p .53704 .29972 L .729 .292 .212 r
F P
0 g
s
.51166 .2934 m .52519 .29908 L .53704 .29972 L p .729 .292 .212 r
F P
0 g
s
gsave
.64171 .67774 -108 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Connecting) show
130.687500 14.437500 moveto
(Rod) show
152.437500 14.437500 moveto
%%IncludeResource: font Times-Bold
%%IncludeFont: Times-Bold
/Times-Bold findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Times-Bold
%%DocumentNeededFonts: Times-Bold
%%DocumentFonts: font Times-Bold
grestore
.25 Mabswid
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{276, 263},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004D00011a000`40O003h00OaGoo0P00CGoo0033
Ool200000goo0000001<Ool00<1oo`<000=oo`8004aoo`00_Woo0P001Woo00<007oo0000Bgoo002k
Ool30008Ool01000Oomoo`00BWoo002iOol2000;Ool01000Oomoo`00BWoo002fOol3000=Ool01@00
Oomoogoo0000BGoo002dOol2000@Ool01@00Oomoogoo0000BGoo002aOol3000COol01@00Oomoogoo
0000B7oo002_Ool2000FOol00`00Oomoo`02Ool00`00Oomoo`15Ool00:aoo`<001Qoo`03001oogoo
009oo`03001oogoo04Eoo`00ZWoo0P006goo00<007ooOol00goo00<007ooOol0A7oo002WOol3000M
Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00:Eoo`80021oo`03001oogoo00Aoo`03001oogoo04=o
o`00XWoo0`008Woo00<007ooOol01Goo00<007ooOol0@Woo002POol2000UOol00`00Oomoo`05Ool0
0`00Oomoo`12Ool009eoo`<002Moo`03001oogoo00Ioo`03001oogoo045oo`00Vgoo0P00:Woo00<0
07ooOol01goo00<007ooOol0@7oo002HOol3000/Ool00`00Oomoo`07Ool00`00Oomoo`10Ool009Eo
o`<002moo`03001oogoo00Qoo`03001oogoo03moo`00Tgoo0P00<Woo00<007ooOol02Goo00<007oo
Ool0?Woo002@Ool3000dOol00`00Oomoo`09Ool00`00Oomoo`0nOol008ioo`8003Qoo`03001oogoo
00Uoo`03001oogoo03eoo`00Rgoo0`00>Woo00<007ooOol02Goo00<007ooOol0?Goo0029Ool2000m
Ool00`00Oomoo`0:Ool00`00Oomoo`0lOol008Ioo`<003moo`03001oogoo00]oo`03001oogoo03]o
o`00Q7oo0P00@Woo00<007ooOol02goo00<007ooOol0>goo0021Ool30014Ool00`00Oomoo`0<Ool0
0`00Oomoo`0jOol007moo`8004Moo`03001oogoo00eoo`03001oogoo03Uoo`00O7oo0`00BGoo00<0
07ooOol03Goo00<007ooOol0>Goo001jOol2001<Ool00`00Oomoo`0>Ool00`00Oomoo`0hOol007Mo
o`<004ioo`03001oogoo00ioo`03001oogoo03Qoo`00MGoo0P00DGoo00<007ooOol03goo00<007oo
Ool0=goo001bOol3001COol00`00Oomoo`0@Ool00`00Oomoo`0fOol0071oo`8005Ioo`03001oogoo
011oo`03001oogoo03Ioo`00KGoo0`00F7oo00<007ooOol04Goo00<007ooOol0=Goo001[Ool2001L
Ool00`00Oomoo`0AOol00`00Oomoo`0dOol006Qoo`<005ioo`03001oogoo015oo`03001oogoo03Ao
o`00IWoo0P00HGoo00<007ooOol04Woo00<007ooOol0<goo001SOol3001SOol00`00Oomoo`0COol0
0`00Oomoo`0bOol0065oo`8006Ioo`03001oogoo01=oo`03001oogoo039oo`00GWoo0`00J7oo00<0
07ooOol057oo00<007ooOol0<Goo001LOol2001[Ool00`00Oomoo`0DOol00`00Oomoo`0aOol005Uo
o`<006eoo`03001oogoo01Eoo`03001oogoo031oo`00Egoo0P00L7oo00<007ooOol05Woo00<007oo
Ool0;goo001DOol3001bOol00`00Oomoo`0FOol00`00Oomoo`0_Ool0059oo`8007Eoo`03001oogoo
01Moo`03001oogoo02ioo`00Cgoo0`00Mgoo00<007ooOol067oo00<007ooOol0;Goo001=Ool2001j
Ool00`00Oomoo`0HOol00`00Oomoo`0]Ool004Yoo`<007aoo`03001oogoo01Uoo`03001oogoo02ao
o`00B7oo0P00P7oo00<007ooOol067oo00<007ooOol0;7oo0015Ool30022Ool00`00Oomoo`0IOol0
0`00Oomoo`0[Ool004=oo`8008Eoo`03001oogoo01Yoo`03001oogoo02Yoo`00@7oo0`00Qgoo00<0
07ooOol06Woo00<007ooOol0:Woo000mOol3002:Ool00`00Oomoo`0KOol00`00Oomoo`0YOol003]o
o`8008eoo`03001oogoo01aoo`03001oogoo02Qoo`00>7oo0`00Sgoo00<007ooOol077oo00<007oo
Ool0:7oo000fOol2002BOol00`00Oomoo`0MOol00`00Oomoo`0WOol003=oo`<009Aoo`03001oogoo
01eoo`03001oogoo02Moo`00<Goo0P00Ugoo00<007ooOol07Woo00<007ooOol09Woo000^Ool3002I
Ool00`00Oomoo`0OOol00`00Oomoo`0UOol002aoo`8009aoo`03001oogoo01moo`03001oogoo02Eo
o`00:Goo0`00WWoo00<007ooOol087oo00<007ooOol097oo000WOol2002QOol00`00Oomoo`0QOol0
0`00Oomoo`0SOol002Aoo`<00:=oo`03001oogoo025oo`03001oogoo02=oo`008Woo0P00Ygoo00<0
07ooOol08Goo00<007ooOol08Woo000OOol3002YOol00`00Oomoo`0ROol00`00Oomoo`0QOol001eo
o`800:aoo`03001oogoo029oo`03001oogoo025oo`006Woo0`00[Woo00<007ooOol08goo00<007oo
Ool087oo000HOol2002aOol00`00Oomoo`0SOol00`00Oomoo`0POol001Eoo`<00;=oo`03001oogoo
02Aoo`03001oogoo01moo`004goo0P00]Woo00<007ooOol09Goo00<007ooOol07Woo000AOol2002h
Ool00`00Oomoo`0UOol00`00Oomoo`0NOol0015oo`800;Qoo`03001oogoo02Ioo`03001oogoo01eo
o`004Goo00<007oo0000]goo00<007ooOol09goo00<007ooOol077oo000AOol01000Oomoo`00]Woo
00<007ooOol09goo00<007ooOol077oo000@Ool00`00Oomoo`02Ool00`00Oomoo`2cOol00`00Oomo
o`0XOol00`00Oomoo`0KOol0011oo`03001oogoo00=oo`03001oogoo0;9oo`03001oogoo02Qoo`03
001oogoo01]oo`0047oo00<007ooOol017oo00<007ooOol0LGoo1000?7oo00<007ooOol0:Goo00<0
07ooOol06Woo000@Ool00`00Oomoo`05Ool00`00Oomoo`1_Ool00`00GBIM9P02GBH2000kOol00`00
Oomoo`0YOol00`00Oomoo`0IOol0011oo`03001oogoo00Ioo`03001oogoo06ioo`8000EM9P8003Uo
o`03001oogoo02Uoo`03001oogoo01Uoo`0047oo00<007ooOol01goo00<007ooOol0K7oo00@0035E
<ED000IM9P03001oogoo03Ioo`03001oogoo02Yoo`03001oogoo01Qoo`0047oo00<007ooOol027oo
00<007ooOol0Jgoo00<0035E<ED00`001EdV00<007ooOol0=Goo00<007ooOol0:goo00<007ooOol0
5goo000?Ool00`00Oomoo`0:Ool00`00Oomoo`1ZOol00`00<ED00003DWT6000gOol00`00Oomoo`0[
Ool00`00Oomoo`0GOol000moo`03001oogoo00]oo`03001oogoo06Qoo`04000aEC5E0004DWT01000
IcYW>P00>7oo00<007ooOol0;7oo00<007ooOol05Woo000?Ool00`00Oomoo`0<Ool00`00Oomoo`1W
Ool01000<EDaE@000e9i00D006LjIcYW>P0003Qoo`03001oogoo02aoo`03001oogoo01Ioo`003goo
00<007ooOol03Goo00<007ooOol0IGoo00@0035E<ED000ABN@04001W>VLj000iOol00`00Oomoo`0]
Ool00`00Oomoo`0EOol000moo`03001oogoo00ioo`03001oogoo06Aoo`04000aEC5E0003DWT01@00
IcYW>VLjJhh0>Goo00<007ooOol0;Woo00<007ooOol057oo000?Ool00`00Oomoo`0?Ool00`00Oomo
o`1SOol00`00<ED00004DWT00`00IcYW>P02000iOol00`00Oomoo`0^Ool00`00Oomoo`0DOol000mo
o`03001oogoo011oo`03001oogoo065oo`04000aEC5E0004DWT01000IcYW>P00>Woo00<007ooOol0
;goo00<007ooOol04goo000>Ool00`00Oomoo`0BOol00`00Oomoo`1POol01000<EDaE@000e9i00D0
06LjIcYW>P0003Yoo`03001oogoo031oo`03001oogoo019oo`003Woo00<007ooOol04goo00<007oo
Ool0Ggoo00<0035E0000159i00<006LjIcX00P00>Woo00<007ooOol0<7oo00<007ooOol04Woo000>
Ool00`00Oomoo`0DOol00`00Oomoo`1MOol01000<EDaE@00159i00@006LjIcX003]oo`03001oogoo
035oo`03001oogoo015oo`003Woo00<007ooOol05Goo00<007ooOol0G7oo00@0035E<ED000=BN@03
001W>VLj008003aoo`03001oogoo031oo`03001oogoo015oo`003Woo00<007ooOol05Woo00<007oo
Ool0FWoo00@0035E<ED000ABN@04001W>VLj000mOol00`00Oomoo`0aOol00`00Oomoo`0@Ool000io
o`03001oogoo01Moo`03001oogoo05Uoo`04000aEC5E0003DWT01@00IcYW>VLjJhh0?Goo00<007oo
Ool0<Woo00<007ooOol03goo000>Ool00`00Oomoo`0HOol00`00Oomoo`1HOol00`00<ED00004DWT0
0`00IcYW>P02000mOol00`00Oomoo`0bOol00`00Oomoo`0?Ool000eoo`03001oogoo01Yoo`03001o
ogoo05Ioo`04000aEC5E0004DWT01000IcYW>P00?Woo00<007ooOol0<Woo0P0047oo000=Ool00`00
Oomoo`0KOol00`00Oomoo`1EOol01000<EDaE@000e9i00<006LjIcX00P00?Woo00<007ooOol0;goo
0`0000=oo`00Ool03goo000=Ool00`00Oomoo`0LOol00`00Oomoo`1DOol00`00<ED00004DWT00`00
IcYW>P02000nOol00`00Oomoo`0/Ool30004Ool00`00Oomoo`0>Ool000eoo`03001oogoo01eoo`03
001oogoo059oo`04000aEC5E0004DWT01000IcYW>P00?goo00<007ooOol0:Goo0`001goo00<007oo
Ool03Woo000=Ool00`00Oomoo`0NOol00`00Oomoo`1AOol01000<EDaE@000e9i00<006LjIcX00P00
?goo00<007ooOol09Woo0`002goo00<007ooOol03Goo000=Ool00`00Oomoo`0OOol00`00Oomoo`1@
Ool00`00<ED00004DWT01000IcYW>P00@7oo00<007ooOol08goo0`003Woo00<007ooOol03Goo000=
Ool00`00Oomoo`0POol00`00Oomoo`1>Ool01000<EDaE@000e9i00<006LjIcX00P00@7oo00<007oo
Ool087oo0`004Goo00<007ooOol03Goo000=Ool00`00Oomoo`0QOol00`00Oomoo`1=Ool01000<EDa
E@000e9i00<006LjIcX00P00@7oo00<007ooOol077oo100057oo00<007ooOol03Goo000<Ool00`00
Oomoo`0SOol00`00Oomoo`1;Ool01000<EDaE@00159i00@006LjIcX0045oo`03001oogoo01Uoo`<0
01Qoo`03001oogoo00eoo`0037oo00<007ooOol097oo00<007ooOol0BWoo00@0035E<ED000=BN@03
001W>VLj0080045oo`03001oogoo01Ioo`<001]oo`03001oogoo00eoo`0037oo00<007ooOol09Goo
00<007ooOol0BGoo00<0035E0000159i00<006LjIcX00P00@Woo00<007ooOol04Woo0`007Woo00<0
07ooOol03Goo000<Ool00`00Oomoo`0VOol00`00Oomoo`17Ool01000<EDaE@00159i00@006LjIcX0
04=oo`03001oogoo00moo`<0025oo`03001oogoo00eoo`0037oo00<007ooOol09goo00<007ooOol0
AWoo00@0035E<ED000=BN@03001W>VLj008004=oo`03001oogoo00aoo`<002Eoo`03001oogoo00ao
o`0037oo00<007ooOol0:7oo00<007ooOol0AGoo00<0035E0000159i00@006LjIcX004Aoo`03001o
ogoo00Uoo`<002Qoo`03001oogoo00aoo`0037oo00<007ooOol0:Goo0P00A7oo00@0035E<ED000=B
N@03001W>VLj008004Aoo`03001oogoo00Ioo`<002]oo`03001oogoo00aoo`002goo00<007ooOol0
;7oo00<007ooOol0@Goo00@0035E<ED000=BN@03001W>VLj008004Aoo`03001oogoo00=oo`<002io
o`03001oogoo00aoo`002goo00<007ooOol0;Goo00<007ooOol0?goo00@0035E<ED000ABN@04001W
>VLj0015Ool00`00Oomoo`03000aOol00`00Oomoo`0<Ool000]oo`03001oogoo02ioo`03001oogoo
03ioo`04000aEC5E0003DWT00`00IcYW>P020015Ool3000dOol00`00Oomoo`0<Ool000]oo`03001o
ogoo02moo`03001oogoo03eoo`03000aE@0000ABN@04001W>VLj0013Ool4000fOol00`00Oomoo`0<
Ool000]oo`03001oogoo031oo`03001oogoo03]oo`04000aEC5E0004DWT01000IcX00000@7oo0`00
0goo00<007ooOol0=7oo00<007ooOol037oo000;Ool00`00Oomoo`0aOol00`00Oomoo`0jOol01000
<EDaE@000e9i00<006LjIcX00P00?7oo10001Woo00<007ooOol0=Goo00<007ooOol02goo000;Ool0
0`00Oomoo`0bOol00`00Oomoo`0iOol00`00<ED00004DWT01000IcYW>P00>Woo0`002Woo00<007oo
Ool0=Goo00<007ooOol02goo000:Ool00`00Oomoo`0dOol00`00Oomoo`0gOol01000<EDaE@000e9i
00<006LjIcX00P00=goo0`003Goo00<007ooOol0=Goo00<007ooOol02goo000:Ool00`00Oomoo`0e
Ool00`00Oomoo`0fOol01000<EDaE@000e9i00<006LjIcX00P00=7oo0`0047oo00<007ooOol0=Goo
00<007ooOol02goo000:Ool00`00Oomoo`0fOol00`00Oomoo`0eOol00`00<ED00004DWT01000IcYW
>P00<Woo0`0057oo00<007ooOol0=7oo00<007ooOol02goo000:Ool00`00Oomoo`0gOol00`00Oomo
o`0cOol01000<EDaE@000e9i00<006LjIcX00P00;goo0`005goo00<007ooOol0=7oo00<007ooOol0
2goo000:Ool00`00Oomoo`0hOol00`00Oomoo`0bOol01000<EDaE@000e9i00@006LjIcX002eoo`<0
01Yoo`03001oogoo03Aoo`03001oogoo00]oo`002Woo00<007ooOol0>Goo00<007ooOol0<7oo00@0
035E<ED000ABN@04001W>P00000ZOol3000MOol00`00Oomoo`0dOol00`00Oomoo`0;Ool000Yoo`03
001oogoo03Yoo`03001oogoo02moo`04000aEC5E0003DWT00`00IcYW>P02000WOol3000POol00`00
Oomoo`0eOol00`00Oomoo`0:Ool000Uoo`03001oogoo03aoo`03001oogoo02ioo`03000aE@0000AB
N@04001W>VLj000UOol3000SOol00`00Oomoo`0eOol00`00Oomoo`0:Ool000Uoo`03001oogoo03eo
o`03001oogoo02aoo`04000aEC5E0003DWT00`00IcYW>P02000ROol3000VOol00`00Oomoo`0eOol0
0`00Oomoo`0:Ool000Uoo`03001oogoo03ioo`03001oogoo02]oo`04000aEC5E0003DWT00`00IcYW
>P02000OOol3000XOol2000gOol00`00Oomoo`0:Ool000Uoo`03001oogoo03moo`03001oogoo02Yo
o`03000aE@0000ABN@04001W>VLj000MOol3000XOol30002Ool00`00Oomoo`0dOol00`00Oomoo`0:
Ool000Uoo`03001oogoo041oo`03001oogoo02Qoo`04000aEC5E0003DWT00`00IcYW>P02000IOol4
000XOol30006Ool00`00Oomoo`0cOol00`00Oomoo`0:Ool000Uoo`03001oogoo045oo`03001oogoo
02Moo`04000aEC5E0003DWT01000IcYW>P005goo0`00:7oo10002Goo00<007ooOol0<goo00<007oo
Ool02Woo0009Ool00`00Oomoo`12Ool00`00Oomoo`0UOol01000<EDaE@00159i00@006Lj000001Ao
o`<002Qoo`<000ioo`03001oogoo039oo`03001oogoo00Yoo`0027oo00<007ooOol0A7oo00<007oo
Ool097oo00@0035E<ED000=BN@03001W>VLj0080015oo`<002Qoo`<0019oo`03001oogoo039oo`03
001oogoo00Uoo`0027oo00<007ooOol0AGoo00<007ooOol08goo00<0035E0000159i00@006LjIcX0
00moo`<002Qoo`<001Ioo`03001oogoo035oo`03001oogoo00Uoo`0027oo00<007ooOol0AWoo00<0
07ooOol08Goo00@0035E<ED000=BN@03001W>VLj008000aoo`<002Qoo`<001Uoo`03001oogoo035o
o`03001oogoo00Uoo`0027oo00<007ooOol0Agoo00<007ooOol087oo00@0035E<ED000=BN@03001W
>VLj008000Uoo`<002Moo`@001eoo`03001oogoo031oo`03001oogoo00Uoo`0027oo00<007ooOol0
B7oo00<007ooOol07goo00<0035E0000159i00@006LjIcX000Moo`<002Moo`<0029oo`03001oogoo
02moo`03001oogoo00Uoo`0027oo00<007ooOol0BGoo00<007ooOol07Goo00@0035E<ED000=BN@03
001W>VLj008000Aoo`<002Moo`<002Ioo`03001oogoo02ioo`03001oogoo00Uoo`0027oo00<007oo
Ool0BWoo00<007ooOol077oo00@0035E<ED000=BN@04001W>VLj0002Ool3000WOol3000YOol00`00
Oomoo`0^Ool00`00Oomoo`09Ool000Moo`03001oogoo04aoo`03001oogoo01]oo`03000aE@0000AB
N@03001W>P0000<002Moo`<002eoo`03001oogoo02eoo`03001oogoo00Uoo`001goo00<007ooOol0
CGoo00<007ooOol06Goo00@0035E<ED000=BN@03001W>VLj008002Ioo`<0035oo`03001oogoo02eo
o`03001oogoo00Qoo`001goo00<007ooOol0CWoo00<007ooOol067oo00@0035E<ED000=BN@04001W
>VLj000SOol4000eOol00`00Oomoo`0/Ool00`00Oomoo`08Ool000Moo`03001oogoo04moo`03001o
ogoo01Ioo`04000aEC5E0003DWT00`00IcYW>P02000POol3000iOol00`00Oomoo`0/Ool00`00Oomo
o`08Ool000Moo`03001oogoo051oo`03001oogoo01Aoo`80008aE@05001BNE9iDWT00002IcX00`00
Oomoo`0LOol3000mOol00`00Oomoo`0[Ool00`00Oomoo`08Ool000Moo`03001oogoo055oo`03001o
ogoo011oo`<00004Ool0035E0004DWT01000IcX000006goo0`00@Goo00<007ooOol0:Woo00<007oo
Ool027oo0007Ool00`00Oomoo`1BOol00`00Oomoo`0<Ool30003Ool01000<EDaE@000e9i00<006Lj
IcX00P0067oo0`00AGoo00<007ooOol0:Goo00<007ooOol027oo0006Ool00`00Oomoo`1DOol00`00
Oomoo`08Ool30006Ool01000<EDaE@000e9i00@006LjIcX001Eoo`@004Qoo`03001oogoo02Uoo`03
001oogoo00Qoo`001Woo00<007ooOol0EGoo00<007ooOol017oo0`002Goo00<0035E0000159i00@0
06Lj0000019oo`<004eoo`03001oogoo02Qoo`03001oogoo00Qoo`001Woo00<007ooOol0EWoo00<0
07ooOol00`002goo00@0035E<ED000=BN@03001W>VLj008000moo`<0055oo`03001oogoo02Qoo`03
001oogoo00Moo`001Woo00<007ooOol0Egoo0P003Woo00@0035E<ED000=BN@04001W>VLj000=Ool3
001EOol00`00Oomoo`0WOol00`00Oomoo`07Ool000Ioo`03001oogoo05Moo`03001oogoo00eoo`03
000aE@0000=BN@03001W>VLj008000Yoo`<005Uoo`03001oogoo02Ioo`03001oogoo00Moo`001Woo
00<007ooOol0Egoo00<007ooOol037oo00@0035E<ED000=BN@04001W>VLj0007Ool4001LOol00`00
Oomoo`0VOol00`00Oomoo`07Ool000Ioo`03001oogoo05Moo`03001oogoo00aoo`04000aEC5E0003
DWT01000IcX0000017oo0`00HGoo00<007ooOol09Goo00<007ooOol01goo0005Ool00`00Oomoo`1H
Ool00`00Oomoo`0;Ool01000<EDaE@000e9i00<006LjIcX00P0000Aoo`00000006Eoo`03001oogoo
02Aoo`03001oogoo00Moo`001Goo00<007ooOol0F7oo00<007ooOol02goo00@0035E<ED000=BN@03
001W>VLj00<006Uoo`03001oogoo02=oo`03001oogoo00Moo`001Goo00<007ooOol0F7oo00<007oo
Ool02goo00<0035E0000159i1000Jgoo00<007ooOol08goo00<007ooOol01goo0005Ool00`00Oomo
o`1HOol00`00Oomoo`0:Ool01@00<EDaE@00DWT00`000VLj0P00K7oo00<007ooOol08goo00<007oo
Ool01Woo0005Ool00`00Oomoo`1HOol00`00Oomoo`0:Ool50002DWT01000IcYW>P00KWoo00<007oo
Ool08Woo00<007ooOol01Woo0005Ool00`00Oomoo`1HOol00`00Oomoo`08Ool300000c5E001BN@02
DWT00`00IcYW>P02001_Ool00`00Oomoo`0QOol00`00Oomoo`06Ool000Eoo`03001oogoo05Qoo`03
001oogoo00Eoo`<00005Ool0035E<ED00003DWT01000IcYW>P00L7oo00<007ooOol08Goo00<007oo
Ool01Woo0004Ool00`00Oomoo`1IOol00`00Oomoo`02Ool30004Ool01000<EDaE@000e9i00@006Lj
0000075oo`03001oogoo021oo`03001oogoo00Ioo`0017oo00<007ooOol0F7oo00<007ooOol00`00
1Woo00@0035E<ED000=BN@03001W>VLj0080079oo`03001oogoo01moo`03001oogoo00Ioo`0017oo
00<007ooOol0Egoo10002Goo00@0035E<ED000=BN@04001W>VLj001dOol00`00Oomoo`0NOol00`00
Oomoo`06Ool000Aoo`03001oogoo05Aoo`<00003Ool007oo00Yoo`03000aE@0000ABN@04001W>P00
001dOol00`00Oomoo`0NOol00`00Oomoo`06Ool000Aoo`03001oogoo055oo`<000Aoo`03001oogoo
00Qoo`04000aEC5E0003DWT00`00IcYW>P02001eOol00`00Oomoo`0NOol00`00Oomoo`05Ool000Ao
o`03001oogoo04ioo`<000Moo`03001oogoo00Qoo`04000aEC5E0003DWT01000IcYW>P00Mgoo00<0
07ooOol07Goo00<007ooOol01Goo0004Ool00`00Oomoo`1;Ool3000:Ool00`00Oomoo`08Ool00`00
<ED00003DWT00`00IcYW>P02001hOol00`00Oomoo`0LOol00`00Oomoo`05Ool000Aoo`03001oogoo
04Qoo`<000eoo`03001oogoo00Moo`04000aEC5E0003DWT01000IcYW>P00NGoo00<007ooOol077oo
00<007ooOol01Goo0003Ool00`00Oomoo`15Ool4000@Ool00`00Oomoo`07Ool01000<EDaE@000e9i
00@006Lj000007Yoo`03001oogoo01]oo`03001oogoo00Eoo`000goo00<007ooOol0@Woo0`0057oo
00<007ooOol01goo00<0035E00000e9i00<006LjIcX00P00Ngoo00<007ooOol06Woo00<007ooOol0
1Goo0003Ool00`00Oomoo`0oOol3000GOol00`00Oomoo`06Ool01000<EDaE@000e9i00@006LjIcX0
07eoo`03001oogoo01Uoo`03001oogoo00Eoo`000goo00<007ooOol0?7oo0`006Woo00<007ooOol0
1Woo00@0035E<ED000=BN@04001W>P00001mOol00`00Oomoo`0IOol00`00Oomoo`05Ool000=oo`03
001oogoo03Uoo`<001eoo`03001oogoo00Eoo`04000aEC5E0003DWT00`00IcYW>P02001nOol00`00
Oomoo`0IOol00`00Oomoo`04Ool000=oo`03001oogoo03Eoo`@0021oo`03001oogoo00Eoo`04000a
EC5E0003DWT01000IcYW>P00P7oo00<007ooOol067oo00<007ooOol017oo0003Ool00`00Oomoo`0b
Ool3000TOol00`00Oomoo`05Ool00`00<ED00003DWT00`00IcYW>P020021Ool00`00Oomoo`0GOol0
0`00Oomoo`04Ool0009oo`03001oogoo031oo`<002Moo`03001oogoo00Aoo`04000aEC5E0003DWT0
1000IcYW>P00Pgoo00<007ooOol05Woo00<007ooOol017oo0002Ool00`00Oomoo`0]Ool3000ZOol0
0`00Oomoo`04Ool01000<EDaE@000e9i00@006Lj000008=oo`03001oogoo01Ioo`03001oogoo00Ao
o`000Woo00<007ooOol0:Woo0`00;Goo00<007ooOol017oo00<0035E00000e9i00<006LjIcX00P00
Q7oo00<007ooOol05Goo00<007ooOol017oo0002Ool00`00Oomoo`0VOol4000`Ool00`00Oomoo`03
Ool01000<EDaE@000e9i00@006LjIcX008Ioo`03001oogoo01Aoo`03001oogoo00Aoo`000Woo00<0
07ooOol08goo0`00=7oo00<007ooOol00goo00@0035E<ED000=BN@04001W>P000027Ool00`00Oomo
o`0COol00`00Oomoo`04Ool0009oo`03001oogoo021oo`<003Moo`03001oogoo009oo`04000aEC5E
0003DWT01000IcYW>P00R7oo00<007ooOol057oo00<007ooOol00goo0002Ool00`00Oomoo`0MOol3
000jOol00`00Oomoo`02Ool01000<EDaE@000e9i00@006Lj000004aoo`@003Uoo`03001oogoo01=o
o`03001oogoo00=oo`0000=oo`00Ool077oo0`00?Goo00<007ooOol00Woo00<0035E00000e9i00<0
06LjIcX00P00Bgoo00<007ooOol00Woo00<007ooOol0=goo00<007ooOol04Woo00<007ooOol00goo
00000goo001oo`0IOol3000oOol00`00Oomoo`02Ool01000<EDaE@000e9i00@006LjIcX004aoo`H0
03Yoo`03001oogoo015oo`03001oogoo00=oo`0000=oo`00Ool05Goo1000@Woo00<007ooOol00Woo
00@0035E<ED000=BN@04001W>P00000HOol40003Ool30002Ool300000goo0000000400001Goo0000
0000Ool00`000goo0P000goo2P0000=oo`0000001P0027oo100000Eoo`00000007oo00<000=oo`D0
01moo`03001oogoo015oo`03001oogoo00=oo`0000=oo`00Ool04Woo0`00AWoo00<007ooOol00Woo
00<0035E00000e9i00<006LjIcX00P005goo0P000goo00D007oo000007oo0080009oo`800003Ool0
0000009oo`800004Ool00000Ool20002Ool01P00Ool00000Ool0009oo`80009oo`80009oo`800005
Ool00000Ool0000=Ool20002Ool2000017oo000007oo0P0000Aoo`00001oo`80025oo`03001oogoo
011oo`03001oogoo00=oo`0000=oo`00Ool03goo0`00BGoo00D007ooOomoo`00008aE@05001BNE9i
DWT00002IcX00`00Oomoo`0EOol20006Ool200000goo00000002Ool200000goo00000002Ool20000
17oo000007oo0P0017oo0P0017oo0P000Woo0P000Woo0P0000=oo`0000000Woo0`002Woo0P0000=o
o`0000000Woo0P0000Aoo`00001oo`800003Ool00000029oo`03001oogoo00moo`03001oogoo00=o
o`0000=oo`00Ool037oo0`00C7oo00D007ooOomoo`00008aE@06001BNE9iDWT006Lj0P005goo0P00
1Woo0P0000=oo`0000000Woo0P0000=oo`0000000Woo0P0000Aoo`00001oo`D00003Ool0000000Ao
o`80009oo`80009oo`800004Ool00000Ool200000goo00000009Ool200000goo00000002Ool20000
17oo000007oo0P0000=oo`0000008goo00<007ooOol03Woo00<007ooOol00goo00000goo001oo`09
Ool3001?Ool01000Oomoogoo0S5E00D0059iDWUBN@00009W>P03001oogoo01Ioo`8000Ioo`800003
Ool00000009oo`800003Ool00000009oo`800004Ool00000Ool2000017oo000007oo0P0000Aoo`00
Oomoo`80009oo`80009oo`800004Ool00000Ool200000goo00000009Ool40003Ool2000017oo0000
07oo0P0000=oo`0000008goo00<007ooOol03goo00<007ooOol00Woo00000`00Oomoo`05Ool4001B
Ool01000Oomoo`000S5E00H0059iDWUBN@00IcX2000HOol20007Ool30002Ool50002Ool50003Ool3
0003Ool300000goo0000000500000goo000000030003Ool50008Ool20002Ool20002Ool30003Ool4
000TOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00003001oogoo009oo`<005Ioo`04001oogoo0002
<ED01000DWUBN@000VLj0P0067oo0P0017oo00<007ooOol087oo00<007ooOol067oo0P000Woo0P00
2Woo0P009Goo00<007ooOol03Goo00<007ooOol00Woo00000`00Ool00002001IOol00`00Ool00002
<ED01@00DWUBNE9i00000VLj00<007ooOol067oo0P000Woo0P008Woo00<007ooOol00P005Woo0P00
0Woo0P002Woo0P009Woo00<007ooOol037oo00<007ooOol00Woo0002001LOol00`00Ool00002<ED0
1P00DWUBNE9i001W>P8001]oo`<00003Ool007oo02Aoo`8001Eoo`H000Yoo`<002Ioo`03001oogoo
00aoo`03001oogoo009oo`0000=oo`00Ool0Fgoo00D007oo<EDaE@0000=BN@03001W>VLj008009Io
o`03001oogoo00]oo`03001oogoo009oo`000Woo0P00FWoo0P000S5E00D0059iDWUBN@00009W>P03
001oogoo09Ioo`03001oogoo00Yoo`03001oogoo009oo`0017oo00<007ooOol0Egoo0P000S5E00H0
059iDWUBN@00IcX2002IOol00`00Oomoo`09Ool00`00Oomoo`02Ool000Eoo`03001oogoo05Ioo`04
000aEC5E0003DWT01000IcYW>P00Vgoo00<007ooOol02Goo00<007ooOol00Goo0006Ool2001FOol0
1000<EDaE@000e9i00@006Lj000009]oo`03001oogoo00Uoo`03001oogoo005oo`0027oo00<007oo
Ool0Dgoo0c5E0e9i00<006LjIcX00P00W7oo00<007ooOol027oo00<007ooOol00Goo0009Ool00`00
Oomoo`1AOol01000<EDaE@000e9i00@006LjIcX009ioo`03001oogoo00Moo`03001oogoo005oo`00
2Woo0P00DGoo00@0035E<ED000=BN@04001W>P00002OOol00`00Oomoo`06Ool00`00Oomoo`01Ool0
00aoo`03001oogoo04ioo`8aE@05001BNE9iDWT00002IcX2002OOol00`00Oomoo`06Ool00`00Oomo
o`01Ool000eoo`03001oogoo04aoo`04000aEC5E0003DWT01000IcYW>P00XGoo00<007ooOol01Goo
00<007ooOol00Goo000>Ool2001<Ool00`00<EDaE@04DWT01000IcX00000XWoo00<007ooOol017oo
00<007ooOol00Goo000@Ool00`00Oomoo`1:Ool20003DWT01000IcYW>P00Y7oo00<007ooOol017oo
0@000Goo0Goo000AOol00`00Oomoo`19Ool20003DWT01000IcX00000Y7oo00<007ooOol017oo0@00
0Goo0Goo000BOol20019Ool00`00Ool0000200000fLj0000002VOol00`00Oomoo`03Ool10001Ool1
Ool001Aoo`03001oogoo04Ioo`04001oogooOol2002YOol00`00Oomoo`02Ool10001Ool1Ool001Eo
o`03001oogoo04Eoo`03001oogoo0:eoo`05001oogooOol00002Ool001Ioo`8004Eoo`03001oogoo
0:eoo`05001oogooOol00002Ool001Qoo`03001oogoo049oo`03001oogoo0:ioo`04001oogoo0002
Ool001Uoo`03001oogoo045oo`03001oogoo0:moo`03001oo`00009oo`006Woo0P00@Goo00<007oo
Ool0/7oo00<007oo00000Goo000LOol00`00Oomoo`0nOol00`00Oomoo`2`Ool00`00Ool00001Ool0
01eoo`03001oogoo03eoo`03001oogoo0;5oo`80005oo`007Woo00<007ooOol0?7oo00<007ooOol0
/Goo0P000Goo000OOol2000lOol00`00Oomoo`2]Ool40003Ool0025oo`03001oogoo03Uoo`03001o
ogoo0:Uoo`@000Moo`008Woo00<007ooOol0>7oo00<007ooOol0YGoo10002goo000SOol2000hOol0
0`00Oomoo`2QOol4000?Ool002Eoo`03001oogoo03Eoo`03001oogoo09eoo`@001=oo`009Woo00<0
07ooOol0=7oo00<007ooOol0VGoo10005goo000WOol2000dOol00`00Oomoo`2EOol4000KOol002Uo
o`03001oogoo035oo`03001oogoo095oo`@001moo`00:Woo00<007ooOol0<7oo00<007ooOol0SGoo
10008goo000[Ool2000`Ool00`00Oomoo`29Ool4000WOol002eoo`03001oogoo02eoo`03001oogoo
08Eoo`@002]oo`00;Woo00<007ooOol0;7oo00<007ooOol0PGoo1000;goo000_Ool2000[Ool00`00
Oomoo`1nOol4000cOol0035oo`03001oogoo02Qoo`03001oogoo07Yoo`@003Moo`00<Woo00<007oo
Ool09goo00<007ooOol0MWoo1000>goo000cOol2000WOol00`00Oomoo`1bOol4000oOol003Eoo`03
001oogoo02Aoo`03001oogoo06ioo`@004=oo`00=Woo00<007ooOol08goo00<007ooOol0JWoo1000
Agoo000gOol2000SOol00`00Oomoo`1VOol4001;Ool003Uoo`03001oogoo021oo`03001oogoo069o
o`@004moo`00>Woo00<007ooOol07goo00<007ooOol0GWoo1000Dgoo000kOol2000OOol00`00Oomo
o`1JOol4001GOol003eoo`03001oogoo01aoo`03001oogoo05Ioo`@005]oo`00?Woo00<007ooOol0
6goo00<007ooOol0DWoo1000Ggoo000oOol00`00Oomoo`0JOol00`00Oomoo`1>Ool4001SOol0041o
o`8001Yoo`03001oogoo04Yoo`@006Moo`00@Woo00<007ooOol05goo00<007ooOol0AWoo1000Jgoo
0013Ool00`00Oomoo`0FOol00`00Oomoo`12Ool4001_Ool004Aoo`8001Ioo`03001oogoo03ioo`@0
07=oo`00AWoo00<007ooOol04goo00<007ooOol0>Woo1000Mgoo0017Ool00`00Oomoo`0BOol00`00
Oomoo`0fOol4001kOol004Qoo`80019oo`03001oogoo039oo`@007moo`00BWoo00<007ooOol03goo
00<007ooOol0;Woo1000Pgoo001;Ool00`00Oomoo`0>Ool00`00Oomoo`0ZOol40027Ool004aoo`80
00eoo`03001oogoo02Moo`@008]oo`00CWoo00<007ooOol02Woo00<007ooOol08goo1000Sgoo001?
Ool00`00Oomoo`09Ool00`00Oomoo`0OOol4002COol0051oo`8000Uoo`03001oogoo01]oo`@009Mo
o`00DWoo00<007ooOol01Woo00<007ooOol05goo1000Vgoo001COol00`00Oomoo`05Ool00`00Oomo
o`0COol4002OOol005Aoo`8000Eoo`03001oogoo00moo`@00:=oo`00EWoo00<007ooOol00Woo00<0
07ooOol02goo1000Ygoo001GOol01@00Oomoogoo00002Goo1000Zgoo001HOol200000goo001oo`04
Ool4002_Ool005Yoo`800003Ool0000000800;=oo`00Fgoo0P00]goo0000\
\>"],
  ImageRangeCache->{{{0, 275}, {262, 0}} -> {-0.000190518, 0.000567246, 
  0.00354754, 0.00354754}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To show the complete quick-return mechanism, all of the graphics objects \
are put together and displayed subject to a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the complete slider-crank mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{groundgraphic, crankgraphic, slidergraphic, conrodgraphic} /. 
        SolveMech[.10], 
      PlotRange \[Rule] {{\(-2\), 37}, {\(-10\), 20}, {\(-4\), 24}}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95309 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1.02544 -0.000586442 1.02544 [
[ 0 0 0 0 ]
[ 1 .95309 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
.35203 .54414 m
.06189 .25974 L
s
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
.35203 .54414 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.33328 .95309 L
s
.33328 .95309 m
.35203 .54414 L
s
0 0 m
1 0 L
1 .95309 L
0 .95309 L
closepath
clip
newpath
.5 Mabswid
.32516 .61278 m .35134 .69641 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.28265 .54549 m .32516 .61278 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.35134 .69641 m .32516 .61278 L .33959 .60827 L p .627 .529 .724 r
F P
0 g
s
.008 w
.34358 .63817 m
.34648 .57645 L
s
.5 Mabswid
.32516 .61278 m .28265 .54549 L .2972 .54073 L p .654 .642 .826 r
F P
0 g
s
.008 w
.12467 .36349 m
.23397 .46843 L
s
.5 Mabswid
.2972 .54073 m .33959 .60827 L .32516 .61278 L p .654 .642 .826 r
F P
0 g
s
.35134 .69641 m .3553 .77766 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.3553 .77766 m .35134 .69641 L .36584 .69211 L p .586 .407 .605 r
F P
0 g
s
.33959 .60827 m .36584 .69211 L .35134 .69641 L p .627 .529 .724 r
F P
0 g
s
.23305 .51102 m .28265 .54549 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.36584 .69211 m .37006 .7735 L .3553 .77766 L p .586 .407 .605 r
F P
0 g
s
.36584 .69211 m .36663 .70732 L p .30581 .66359 L .94 .685 .525 r
F P
0 g
s
.30413 .65253 m .36584 .69211 L .30581 .66359 L .94 .685 .525 r
F
.31348 .71411 m .36663 .70732 L .34438 .74654 L F
.17736 .57123 m .30581 .66359 L .31348 .71411 L F
.30581 .66359 m .36663 .70732 L .31348 .71411 L F
.3553 .77766 m .33509 .83732 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.33509 .83732 m .3553 .77766 L .37006 .7735 L p .491 .189 .381 r
F P
0 g
s
.32234 .79435 m .31889 .79928 L p .33319 .80444 L .714 .294 .249 r
F P
0 g
s
.37006 .7735 m .35022 .8332 L .33509 .83732 L p .491 .189 .381 r
F P
0 g
s
.36857 .77799 m .35022 .8332 L p .33189 .80541 L .94 .685 .525 r
F P
0 g
s
.34971 .8104 m .33598 .80235 L .33319 .80444 L .714 .294 .249 r
F
.33598 .80235 m .32234 .79435 L .33319 .80444 L F
.32234 .79435 m .31889 .79928 L .32389 .78266 L p .904 .91 .509 r
F P
0 g
s
.27201 .67358 m .34438 .74654 L .34252 .74982 L .94 .685 .525 r
F
.17736 .57123 m .26969 .66815 L .27201 .67358 L F
.26969 .66815 m .34438 .74654 L .27201 .67358 L F
.37006 .7735 m .36857 .77799 L p .34252 .74982 L F P
0 g
s
.34438 .74654 m .37006 .7735 L .34252 .74982 L .94 .685 .525 r
F
.32234 .79435 m .32389 .78266 L .32792 .77555 L .904 .91 .509 r
F
.32809 .77525 m .32234 .79435 L p .32792 .77555 L F P
0 g
s
.29297 .72261 m .36857 .77799 L .34737 .79384 L .94 .685 .525 r
F
.27201 .67358 m .36857 .77799 L .29297 .72261 L F
.3337 .79412 m .32234 .79435 L .32809 .77525 L p .823 .758 .791 r
F P
0 g
s
.3337 .79412 m .32809 .77525 L .33666 .78351 L .823 .758 .791 r
F
.3337 .79412 m .32234 .79435 L p .33598 .80235 L .714 .294 .249 r
F P
0 g
s
.34971 .8104 m .33933 .79984 L .33598 .80235 L .714 .294 .249 r
F
.33933 .79984 m .3337 .79412 L .33598 .80235 L F
.33509 .83732 m .29388 .85835 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.29388 .85835 m .33509 .83732 L .35022 .8332 L p .017 0 0 r
F P
0 g
s
.35022 .8332 m .30943 .85414 L .29388 .85835 L p .017 0 0 r
F P
0 g
s
.35022 .8332 m .30943 .85414 L p .29838 .83046 L .94 .685 .525 r
F P
0 g
s
.31889 .79928 m .32678 .80173 L .32399 .78332 L .399 .312 .641 r
F
.33189 .80541 m .35022 .8332 L .29838 .83046 L .94 .685 .525 r
F
.31889 .79928 m .32548 .80606 L p .34971 .8104 L .714 .294 .249 r
F P
0 g
s
.32548 .80606 m .33829 .81069 L .34971 .8104 L p .714 .294 .249 r
F P
0 g
s
.32548 .80606 m .32921 .80741 L p .32686 .80191 L .665 .588 .758 r
F P
0 g
s
.32678 .80173 m .32548 .80606 L p .32686 .80191 L .665 .588 .758 r
F P
0 g
s
.31889 .79928 m .32548 .80606 L .32678 .80173 L p .399 .312 .641 r
F P
0 g
s
.32389 .78266 m .31889 .79928 L p .32399 .78332 L .399 .312 .641 r
F P
0 g
s
.17736 .57123 m .33189 .80541 L .29838 .83046 L .94 .685 .525 r
F
.34267 .79735 m .3337 .79412 L .33686 .7837 L p .666 .588 .758 r
F P
0 g
s
.34636 .79868 m .3337 .79412 L p .34971 .8104 L .714 .294 .249 r
F P
0 g
s
.32598 .79647 m .34737 .79384 L .33189 .80541 L .94 .685 .525 r
F
.2838 .73254 m .32185 .76923 L .32598 .79647 L F
.17736 .57123 m .34737 .79384 L .2838 .73254 L F
.36663 .70732 m .37006 .7735 L p .34438 .74654 L F P
0 g
s
.33959 .60827 m .36584 .69211 L p .27227 .6321 L .94 .685 .525 r
F P
0 g
s
.40838 .28178 m .4364 .31416 L .56766 .26706 L p .668 .736 .901 r
F P
0 g
s
.4364 .31416 m .47033 .31688 L .44003 .36372 L .537 .314 .524 r
F
.47033 .31688 m .4876 .31827 L .47132 .33473 L F
.46067 .3401 m .47132 .33473 L .4568 .34941 L F
.47033 .31688 m .47132 .33473 L .46067 .3401 L F
.47309 .33384 m .3337 .79412 L p .4572 .35089 L .823 .758 .791 r
F P
0 g
s
.32185 .76923 m .34737 .79384 L .32598 .79647 L .94 .685 .525 r
F
.34636 .79868 m .34267 .79735 L p .47393 .33341 L .666 .588 .758 r
F P
0 g
s
.34636 .79868 m .47393 .33341 L .47427 .33324 L .666 .588 .758 r
F
.47033 .31688 m .4568 .34941 L .43507 .37138 L .537 .314 .524 r
F
.43957 .36981 m .43507 .37138 L p .44139 .36499 L F P
0 g
s
.4568 .34941 m .44281 .36633 L .44139 .36499 L .537 .314 .524 r
F
.45537 .35286 m .44281 .36633 L .4568 .34941 L F
.43507 .37138 m .43535 .35934 L p .44003 .36372 L F P
0 g
s
.40838 .28178 m .4364 .31416 L .43507 .37138 L p .963 .688 .466 r
F P
0 g
s
.43507 .37138 m .40653 .33934 L .40838 .28178 L p .963 .688 .466 r
F P
0 g
s
.40653 .33934 m .43507 .37138 L .43957 .36981 L p .664 .741 .907 r
F P
0 g
s
.4479 .37764 m .45537 .35286 L p .44841 .37811 L .823 .758 .791 r
F P
0 g
s
.4729 .38342 m .49072 .32495 L p .47438 .38196 L .406 .318 .644 r
F P
0 g
s
.35301 .80541 m .49072 .32495 L .49103 .32523 L .406 .318 .644 r
F
.44281 .36633 m .43957 .36981 L .44139 .36499 L .537 .314 .524 r
F
.33666 .78351 m .45537 .35286 L .4572 .35089 L .823 .758 .791 r
F
.45537 .35286 m .32809 .77525 L p .44886 .3685 L .904 .91 .509 r
F P
0 g
s
.33686 .7837 m .47309 .33384 L p .34267 .79735 L .666 .588 .758 r
F P
0 g
s
.34267 .79735 m .47309 .33384 L .47393 .33341 L .666 .588 .758 r
F
.47309 .33384 m .44455 .36796 L .44281 .36633 L .537 .314 .524 r
F
.4876 .31827 m .4749 .33293 L .47309 .33384 L F
.49072 .32495 m .34636 .79868 L p .47427 .33324 L .666 .588 .758 r
F P
0 g
s
.4749 .33293 m .44455 .36796 L .47309 .33384 L .537 .314 .524 r
F
.4876 .31827 m .50173 .3194 L .49072 .32495 L F
.48569 .32047 m .49072 .32495 L .4749 .33293 L F
.4876 .31827 m .49072 .32495 L .48569 .32047 L F
.498 .33142 m .35301 .80541 L p .49103 .32523 L .406 .318 .644 r
F P
0 g
s
.4749 .33293 m .49834 .33058 L .44455 .36796 L .537 .314 .524 r
F
.35301 .80541 m .34636 .79868 L .4729 .38342 L p .406 .318 .644 r
F P
0 g
s
.35301 .80541 m .4729 .38342 L .47438 .38196 L .406 .318 .644 r
F
.34971 .8104 m .35301 .80541 L .34636 .79868 L p .714 .294 .249 r
F P
0 g
s
.34971 .8104 m .35301 .80541 L .48606 .37045 L p .889 .901 .487 r
F P
0 g
s
.48606 .37045 m .498 .33142 L p .48628 .36928 L .889 .901 .487 r
F P
0 g
s
.34971 .8104 m .48606 .37045 L .48628 .36928 L .889 .901 .487 r
F
.49834 .33058 m .49055 .3496 L .44455 .36796 L .537 .314 .524 r
F
.48818 .3541 m .49055 .3496 L .48917 .35109 L .824 .76 .792 r
F
.33829 .81069 m .48885 .35476 L .48818 .3541 L F
.48885 .35476 m .49055 .3496 L .48818 .3541 L F
.49055 .3496 m .48883 .35146 L .44455 .36796 L .537 .314 .524 r
F
.33829 .81069 m .34971 .8104 L .49055 .3496 L p .824 .76 .792 r
F P
0 g
s
.34971 .8104 m .498 .33142 L .49765 .33227 L .889 .901 .487 r
F
.49055 .3496 m .34971 .8104 L p .49765 .33227 L F P
0 g
s
.54276 .3338 m .4894 .35242 L p .56191 .32423 L .537 .314 .524 r
F P
0 g
s
.48723 .35318 m .43957 .36981 L p .48883 .35146 L .537 .314 .524 r
F P
0 g
s
.4498 .36624 m .48723 .35318 L p .47098 .3475 L .664 .741 .907 r
F P
0 g
s
.47033 .31688 m .4768 .31258 L .48277 .31788 L .537 .314 .524 r
F
.47761 .29937 m .51907 .28449 L p .47033 .31688 L F P
0 g
s
.4876 .31827 m .45537 .35286 L .4568 .34941 L .537 .314 .524 r
F
.4768 .31258 m .51907 .28449 L .48277 .31788 L F
.4364 .31416 m .47761 .29937 L p .47033 .31688 L F P
0 g
s
.47246 .29614 m .48406 .2976 L .47309 .33384 L p .823 .758 .791 r
F P
0 g
s
.4572 .35089 m .47246 .29614 L .47309 .33384 L .823 .758 .791 r
F
.46248 .35007 m .47726 .30381 L .46243 .35012 L .399 .312 .641 r
F
.45016 .36409 m .46959 .29869 L .45015 .36417 L .904 .91 .509 r
F
.45837 .3429 m .47246 .29614 L p .45934 .3432 L .823 .758 .791 r
F P
0 g
s
.4572 .35089 m .45837 .3429 L .45934 .3432 L .823 .758 .791 r
F
.45537 .35286 m .45837 .3429 L p .4572 .35089 L F P
0 g
s
.46959 .29869 m .47246 .29614 L .45537 .35286 L p .904 .91 .509 r
F P
0 g
s
.44281 .36633 m .44455 .36796 L .43957 .36981 L .537 .314 .524 r
F
.4498 .36624 m .46959 .29869 L .45537 .35286 L .904 .91 .509 r
F
.45015 .36417 m .46959 .29869 L .4498 .36624 L F
.44464 .36804 m .4498 .36624 L p .44773 .36493 L .664 .741 .907 r
F P
0 g
s
.43535 .35934 m .4364 .31416 L p .44003 .36372 L .537 .314 .524 r
F P
0 g
s
.4071 .33929 m .4498 .36624 L .45392 .34154 L .664 .741 .907 r
F
.44782 .37102 m .46959 .29869 L p .44882 .3686 L .904 .91 .509 r
F P
0 g
s
.47726 .30381 m .46959 .29869 L .45048 .36215 L p .399 .312 .641 r
F P
0 g
s
.44886 .3685 m .45015 .36417 L .4498 .36624 L .904 .91 .509 r
F
.46422 .34879 m .4498 .36624 L .47098 .3475 L .664 .741 .907 r
F
.45048 .36215 m .4498 .36624 L .46422 .34879 L F
.48277 .31788 m .51907 .28449 L .4876 .31827 L .537 .314 .524 r
F
.56766 .26706 m .56857 .3209 L p .4876 .31827 L F P
0 g
s
.56857 .3209 m .56864 .32477 L p .56191 .32423 L .537 .314 .524 r
F P
0 g
s
.4876 .31827 m .56857 .3209 L .56191 .32423 L .537 .314 .524 r
F
.32809 .77525 m .4479 .37764 L p .33666 .78351 L .823 .758 .791 r
F P
0 g
s
.33666 .78351 m .4479 .37764 L .44841 .37811 L .823 .758 .791 r
F
.32686 .80191 m .4706 .36986 L .32678 .80173 L .665 .588 .758 r
F
.51907 .28449 m .56766 .26706 L p .4876 .31827 L .537 .314 .524 r
F P
0 g
s
.48406 .2976 m .49765 .30221 L .49072 .32495 L p .666 .588 .758 r
F P
0 g
s
.48853 .31597 m .49102 .30848 L .48853 .31596 L .665 .588 .758 r
F
.47245 .34722 m .48723 .35318 L .48508 .35109 L .664 .741 .907 r
F
.47098 .3475 m .46581 .34569 L .46364 .3489 L .665 .588 .758 r
F
.47851 .34606 m .46581 .34569 L .47098 .3475 L F
.47427 .33324 m .48406 .2976 L .49072 .32495 L .666 .588 .758 r
F
.50173 .3194 m .56191 .32423 L .4749 .33293 L .537 .314 .524 r
F
.47427 .33324 m .47393 .33341 L .48406 .2976 L .666 .588 .758 r
F
.47851 .34606 m .49102 .30848 L .46581 .34569 L .665 .588 .758 r
F
.47309 .33384 m .48406 .2976 L p .47393 .33341 L .666 .588 .758 r
F P
0 g
s
.49102 .30848 m .47726 .30381 L .46364 .3489 L p .665 .588 .758 r
F P
0 g
s
.45266 .35996 m .47726 .30381 L .45048 .36215 L .399 .312 .641 r
F
.45048 .36215 m .46422 .34879 L .46364 .3489 L .664 .741 .907 r
F
.45494 .37769 m .46364 .3489 L p .45395 .37676 L .399 .312 .641 r
F P
0 g
s
.46364 .3489 m .47726 .30381 L p .46248 .35007 L .399 .312 .641 r
F P
0 g
s
.45395 .37676 m .46364 .3489 L .46248 .35007 L .399 .312 .641 r
F
.46697 .34554 m .47098 .3475 L .47245 .34722 L .664 .741 .907 r
F
.32792 .77555 m .44882 .3686 L .32809 .77525 L .904 .91 .509 r
F
.44882 .3686 m .44886 .3685 L .32809 .77525 L F
.32792 .77555 m .44782 .37102 L .44882 .3686 L F
.45391 .37673 m .46243 .35012 L .44782 .37102 L .399 .312 .641 r
F
.46243 .35012 m .47726 .30381 L .45266 .35996 L F
.46243 .35012 m .45266 .35996 L .44782 .37102 L F
.48853 .31597 m .48853 .31596 L .47851 .34606 L .665 .588 .758 r
F
.48853 .31597 m .47851 .34606 L .47851 .34606 L F
.49765 .30221 m .50538 .30731 L .498 .33142 L p .406 .318 .644 r
F P
0 g
s
.49103 .32523 m .49765 .30221 L .498 .33142 L .406 .318 .644 r
F
.48282 .34891 m .50268 .30992 L .47966 .34584 L .824 .76 .792 r
F
.48818 .3541 m .48917 .35109 L .48723 .35318 L F
.47763 .34623 m .48294 .34903 L .47966 .34584 L .664 .741 .907 r
F
.48917 .35109 m .50268 .30992 L .48282 .34891 L .824 .76 .792 r
F
.48917 .35109 m .48282 .34891 L .48723 .35318 L F
.4894 .35242 m .48723 .35318 L p .48997 .35103 L .537 .314 .524 r
F P
0 g
s
.48997 .35103 m .48723 .35318 L .48883 .35146 L .537 .314 .524 r
F
.46697 .34554 m .4894 .35242 L .47018 .34232 L .664 .741 .907 r
F
.47098 .3475 m .48723 .35318 L .47245 .34722 L F
.48723 .35318 m .48282 .34891 L .47267 .36883 L .824 .76 .792 r
F
.47852 .34606 m .48853 .31597 L .47851 .34606 L .665 .588 .758 r
F
.47966 .34584 m .49102 .30848 L p .47852 .34606 L F P
0 g
s
.47018 .34232 m .47763 .34623 L .47962 .3458 L .664 .741 .907 r
F
.49072 .32495 m .49765 .30221 L p .49103 .32523 L .406 .318 .644 r
F P
0 g
s
.50268 .30992 m .49102 .30848 L .47966 .34584 L p .824 .76 .792 r
F P
0 g
s
.47632 .34261 m .47962 .3458 L .49109 .34332 L .664 .741 .907 r
F
.47018 .34232 m .47962 .3458 L .47632 .34261 L F
.49055 .3496 m .48997 .35103 L .48883 .35146 L .537 .314 .524 r
F
.49055 .3496 m .50268 .30992 L p .48917 .35109 L .824 .76 .792 r
F P
0 g
s
.47966 .34584 m .4894 .35242 L .49102 .34368 L .664 .741 .907 r
F
.48294 .34903 m .4894 .35242 L .47966 .34584 L F
.47267 .36883 m .33829 .81069 L p .48818 .3541 L .824 .76 .792 r
F P
0 g
s
.48818 .3541 m .48723 .35318 L .47267 .36883 L .824 .76 .792 r
F
.4706 .36986 m .47852 .34606 L .47058 .36987 L .665 .588 .758 r
F
.47852 .34606 m .47851 .34606 L .47058 .36987 L F
.47763 .34623 m .49102 .34368 L .49109 .34332 L .664 .741 .907 r
F
.45392 .34154 m .46697 .34554 L .47018 .34232 L F
.45392 .34154 m .46656 .34595 L .46697 .34554 L F
.46656 .34595 m .47098 .3475 L .46697 .34554 L F
.47851 .34606 m .47851 .34606 L .47058 .36987 L .665 .588 .758 r
F
.4706 .36986 m .47058 .36987 L .32678 .80173 L F
.46364 .3489 m .46422 .34879 L .46656 .34595 L .664 .741 .907 r
F
.46364 .3489 m .32678 .80173 L p .47851 .34606 L .665 .588 .758 r
F P
0 g
s
.44882 .3686 m .45016 .36409 L .44886 .3685 L .904 .91 .509 r
F
.45016 .36409 m .45015 .36417 L .44886 .3685 L F
.45048 .36215 m .44782 .37102 L p .45266 .35996 L .399 .312 .641 r
F P
0 g
s
.43957 .36981 m .44464 .36804 L p .4071 .33929 L .664 .741 .907 r
F P
0 g
s
.4071 .33929 m .44464 .36804 L .44773 .36493 L .664 .741 .907 r
F
.47267 .36883 m .47966 .34584 L p .4706 .36986 L .665 .588 .758 r
F P
0 g
s
.4706 .36986 m .47966 .34584 L .47852 .34606 L .665 .588 .758 r
F
.46656 .34595 m .46422 .34879 L .47098 .3475 L .664 .741 .907 r
F
.47966 .34584 m .47267 .36883 L p .48282 .34891 L .824 .76 .792 r
F P
0 g
s
.56191 .32423 m .4894 .35242 L .48997 .35103 L .537 .314 .524 r
F
.50538 .30731 m .50268 .30992 L .49055 .3496 L p .889 .901 .487 r
F P
0 g
s
.49765 .33227 m .50538 .30731 L .49055 .3496 L .889 .901 .487 r
F
.45395 .37676 m .46248 .35007 L .45391 .37673 L .399 .312 .641 r
F
.46248 .35007 m .46243 .35012 L .45391 .37673 L F
.45392 .34154 m .45048 .36215 L .46656 .34595 L .664 .741 .907 r
F
.48723 .35318 m .4894 .35242 L p .48508 .35109 L F P
0 g
s
.49834 .33058 m .56191 .32423 L .48997 .35103 L .537 .314 .524 r
F
.4894 .35242 m .51254 .34435 L p .49109 .34332 L .664 .741 .907 r
F P
0 g
s
.498 .33142 m .50538 .30731 L p .49765 .33227 L .889 .901 .487 r
F P
0 g
s
.32389 .78266 m .44782 .37102 L p .32792 .77555 L .904 .91 .509 r
F P
0 g
s
.32399 .78332 m .45395 .37676 L .32389 .78266 L .399 .312 .641 r
F
.45395 .37676 m .45391 .37673 L .32389 .78266 L F
.56864 .32477 m .54276 .3338 L p .56191 .32423 L .537 .314 .524 r
F P
0 g
s
.51254 .34435 m .56864 .32477 L p .52876 .32835 L .664 .741 .907 r
F P
0 g
s
.4071 .33929 m .51254 .34435 L .52876 .32835 L .664 .741 .907 r
F
.40653 .33934 m .43957 .36981 L .4071 .33929 L F
.32678 .80173 m .45494 .37769 L p .32399 .78332 L .399 .312 .641 r
F P
0 g
s
.32399 .78332 m .45494 .37769 L .45395 .37676 L .399 .312 .641 r
F
.33829 .81069 m .47267 .36883 L p .32686 .80191 L .665 .588 .758 r
F P
0 g
s
.32686 .80191 m .47267 .36883 L .4706 .36986 L .665 .588 .758 r
F
.44782 .37102 m .32389 .78266 L p .45391 .37673 L .399 .312 .641 r
F P
0 g
s
.32921 .80741 m .33829 .81069 L p .32686 .80191 L .665 .588 .758 r
F P
0 g
s
.17736 .57123 m .27201 .67358 L .29297 .72261 L .94 .685 .525 r
F
.17736 .57123 m .30413 .65253 L .30581 .66359 L F
.17736 .57123 m .25377 .58867 L .27227 .6321 L F
.25377 .58867 m .33959 .60827 L .27227 .6321 L F
0 g
.008 w
.33117 .90216 m
.33402 .84151 L
s
.36061 .57196 m
.39015 .56255 L
s
.63913 .48333 m
.90387 .39909 L
s
.46144 .53987 m
.63913 .48333 L
s
.4313 .54946 m
.46144 .53987 L
s
.34648 .57645 m
.36061 .57196 L
s
.5 Mabswid
.28265 .54549 m .23305 .51102 L .24788 .50603 L p .66 .795 .947 r
F P
0 g
s
.24788 .50603 m .2972 .54073 L .28265 .54549 L p .66 .795 .947 r
F P
0 g
s
.2972 .54073 m .33959 .60827 L p .17736 .57123 L .94 .685 .525 r
F P
0 g
s
.008 w
.29103 .52321 m
.34648 .57645 L
s
.5 Mabswid
.24788 .50603 m .2972 .54073 L p .17736 .57123 L .94 .685 .525 r
F P
0 g
s
.008 w
.23397 .46843 m
.29103 .52321 L
s
.5 Mabswid
.16174 .57637 m .18841 .5208 L .23305 .51102 L p .938 .685 .528 r
F P
0 g
s
.23305 .51102 m .18841 .5208 L .20364 .51566 L p .328 .811 .784 r
F P
0 g
s
.20364 .51566 m .24788 .50603 L .23305 .51102 L p .328 .811 .784 r
F P
0 g
s
.17736 .57123 m .20364 .51566 L .24788 .50603 L p .94 .685 .525 r
F P
0 g
s
.008 w
.19553 .43152 m
.41631 .35354 L
s
.41631 .35354 m
.41849 .35277 L
s
.28247 .86417 m
.33117 .90216 L
s
.39909 .64019 m
.43459 .62939 L
s
.37977 .64606 m
.38057 .64582 L
s
.38057 .64582 m
.39909 .64019 L
s
.36124 .6517 m
.37977 .64606 L
s
.33449 .65983 m
.36124 .6517 L
s
.33284 .66034 m
.33449 .65983 L
s
.27811 .67698 m
.33284 .66034 L
s
.90387 .39909 m
.73063 .13907 L
s
.22339 .37264 m
.40458 .30703 L
s
.15862 .39609 m
.22339 .37264 L
s
.5 Mabswid
.18841 .5208 m .16174 .57637 L .17736 .57123 L p .41 .067 .271 r
F P
0 g
s
.17736 .57123 m .20364 .51566 L .18841 .5208 L p .41 .067 .271 r
F P
0 g
s
.29388 .85835 m .24126 .83107 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.24126 .83107 m .29388 .85835 L .30943 .85414 L p .617 .829 .982 r
F P
0 g
s
.30943 .85414 m .25713 .82665 L .24126 .83107 L p .617 .829 .982 r
F P
0 g
s
.30943 .85414 m .25713 .82665 L p .17736 .57123 L .94 .685 .525 r
F P
0 g
s
.008 w
.12467 .36349 m
.08427 .70957 L
s
.17161 .34611 m
.37331 .27141 L
s
.12467 .36349 m
.17161 .34611 L
s
.5 Mabswid
.56766 .26706 m .54109 .23317 L .40838 .28178 L p .668 .736 .901 r
F P
0 g
s
.54109 .23317 m .40838 .28178 L .40653 .33934 L p .531 .305 .517 r
F P
0 g
s
.008 w
.40458 .30703 m
.44423 .29267 L
s
.5 Mabswid
.19228 .75971 m .16266 .66479 L .16174 .57637 L p .938 .685 .528 r
F P
0 g
s
.24126 .83107 m .19228 .75971 L p .16174 .57637 L .938 .685 .528 r
F P
0 g
s
.16174 .57637 m .16266 .66479 L .17857 .65982 L p .561 .373 .584 r
F P
0 g
s
.17857 .65982 m .17736 .57123 L .16174 .57637 L p .561 .373 .584 r
F P
0 g
s
.19228 .75971 m .24126 .83107 L .25713 .82665 L p .64 .651 .845 r
F P
0 g
s
.008 w
.23759 .82916 m
.24268 .83314 L
s
.24268 .83314 m
.28247 .86417 L
s
.5 Mabswid
.48406 .2976 m .47246 .29614 L p .50268 .30992 L .613 .074 0 r
F P
0 g
s
.49765 .30221 m .48406 .2976 L p .50268 .30992 L .613 .074 0 r
F P
0 g
s
.50268 .30992 m .50538 .30731 L .49765 .30221 L p .613 .074 0 r
F P
0 g
s
.20829 .755 m .17857 .65982 L .17736 .57123 L p .94 .685 .525 r
F P
0 g
s
.25713 .82665 m .20829 .755 L p .17736 .57123 L .94 .685 .525 r
F P
0 g
s
.54161 .29121 m .56864 .32477 L .56766 .26706 L p .972 .685 .421 r
F P
0 g
s
.008 w
.57078 .29897 m
.78642 .2228 L
s
.56822 .29988 m
.57078 .29897 L
s
.5 Mabswid
.56766 .26706 m .54109 .23317 L .54161 .29121 L p .972 .685 .421 r
F P
0 g
s
.008 w
.50896 .22117 m
.73063 .13907 L
s
.5 Mabswid
.25713 .82665 m .20829 .755 L .19228 .75971 L p .64 .651 .845 r
F P
0 g
s
.47246 .29614 m .46959 .29869 L p .50268 .30992 L .613 .074 0 r
F P
0 g
s
.46959 .29869 m .47726 .30381 L p .50268 .30992 L .613 .074 0 r
F P
0 g
s
.47726 .30381 m .49102 .30848 L .50268 .30992 L p .613 .074 0 r
F P
0 g
s
.56864 .32477 m .54161 .29121 L .40653 .33934 L p .664 .741 .907 r
F P
0 g
s
.40653 .33934 m .54161 .29121 L .54109 .23317 L p .531 .305 .517 r
F P
0 g
s
.008 w
.44423 .29267 m
.53862 .25849 L
s
.40899 .25819 m
.50896 .22117 L
s
.53862 .25849 m
.75742 .17927 L
s
.37331 .27141 m
.40899 .25819 L
s
.5 Mabswid
.16266 .66479 m .19228 .75971 L .20829 .755 L p .613 .521 .726 r
F P
0 g
s
.008 w
.20636 .8048 m
.23759 .82916 L
s
.5 Mabswid
.20829 .755 m .17857 .65982 L .16266 .66479 L p .613 .521 .726 r
F P
0 g
s
.008 w
.08427 .70957 m
.20636 .8048 L
s
.25 Mabswid
.72114 0 m
.94376 .35267 L
s
.94376 .35267 m
1 .78494 L
s
1 .78494 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.06189 .25974 m
0 .70183 L
s
0 .70183 m
.75381 .46412 L
s
.75381 .46412 m
.72114 0 L
s
.72114 0 m
.06189 .25974 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{276, 263},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004D00011a000`40O003h00OaGoo0P00CGoo0033
Ool200000goo0000001<Ool00<1oo`<000=oo`8004aoo`00_Woo0P001Woo00<007oo0000Bgoo002k
Ool30008Ool01000Oomoo`00BWoo002iOol2000;Ool01000Oomoo`00BWoo002fOol3000=Ool01@00
Oomoogoo0000BGoo002dOol2000@Ool01@00Oomoogoo0000BGoo002aOol3000COol01@00Oomoogoo
0000B7oo002_Ool2000FOol00`00Oomoo`02Ool00`00Oomoo`15Ool00:aoo`<001Qoo`03001oogoo
009oo`03001oogoo04Eoo`00ZWoo0P006goo00<007ooOol00goo00<007ooOol0A7oo002WOol3000M
Ool00`00Oomoo`04Ool00`00Oomoo`13Ool00:Eoo`80021oo`03001oogoo00Aoo`03001oogoo04=o
o`00XWoo0`008Woo00<007ooOol01Goo00<007ooOol0@Woo002POol2000UOol00`00Oomoo`05Ool0
0`00Oomoo`12Ool009eoo`<002Moo`03001oogoo00Ioo`03001oogoo045oo`00Vgoo0P00:Woo00<0
07ooOol01goo00<007ooOol0@7oo002HOol3000/Ool00`00Oomoo`07Ool00`00Oomoo`10Ool009Eo
o`<002moo`03001oogoo00Qoo`03001oogoo03moo`00Tgoo0P00<Woo00<007ooOol02Goo00<007oo
Ool0?Woo002@Ool3000dOol00`00Oomoo`09Ool00`00Oomoo`0nOol008ioo`8003Qoo`03001oogoo
00Uoo`03001oogoo03eoo`00Rgoo0`00>Woo00<007ooOol02Goo00<007ooOol0?Goo0029Ool2000m
Ool00`00Oomoo`0:Ool00`00Oomoo`0lOol008Ioo`<003moo`03001oogoo00]oo`03001oogoo03]o
o`00Q7oo0P00@Woo00<007ooOol02goo00<007ooOol0>goo0021Ool30014Ool00`00Oomoo`0<Ool0
0`00Oomoo`0jOol007moo`8004Moo`03001oogoo00eoo`03001oogoo03Uoo`00O7oo0`00BGoo00<0
07ooOol03Goo00<007ooOol0>Goo001jOol2001<Ool00`00Oomoo`0>Ool00`00Oomoo`0hOol007Mo
o`<004ioo`03001oogoo00ioo`03001oogoo03Qoo`00MGoo0P00DGoo00<007ooOol03goo00<007oo
Ool0=goo001bOol3001COol00`00Oomoo`0@Ool00`00Oomoo`0fOol0071oo`8005Ioo`03001oogoo
011oo`03001oogoo03Ioo`00KGoo0`00F7oo00<007ooOol04Goo00<007ooOol0=Goo001[Ool2001L
Ool00`00Oomoo`0AOol00`00Oomoo`0dOol006Qoo`<005ioo`03001oogoo015oo`03001oogoo03Ao
o`00IWoo0P00H7oo0P0057oo00<007ooOol0<goo001SOol3001OOol5000EOol00`00Oomoo`0bOol0
065oo`80061oo`L001Eoo`03001oogoo039oo`00GWoo0`00Ggoo1P000goo0P005Goo00<007ooOol0
<Goo001LOol2001OOol70005Ool2000EOol00`00Oomoo`0aOol005Uoo`<005ioo`L000Qoo`<001Eo
o`03001oogoo031oo`00Egoo0P00GWoo1`002goo00@007oo000001Eoo`03001oogoo02moo`00E7oo
0`00GWoo1P003Woo00@007ooOol001Eoo`03001oogoo02moo`00DWoo0P00GWoo1P004Goo00<007oo
Ool00P005Goo00<007ooOol0;Woo001?Ool3001MOol7000COol01000Oomoogoo0P005Goo00<007oo
Ool0;Goo001=Ool2001MOol7000FOol00`00Oomoo`02Ool00`00Oomoo`0COol00`00Oomoo`0]Ool0
04Yoo`<005aoo`L001Uoo`03001oogoo009oo`<001Aoo`03001oogoo02aoo`00B7oo0P00GGoo1P00
7Goo00<007ooOol01@004goo00<007ooOol0;7oo0015Ool3001LOol6000POol7000EOol00`00Oomo
o`0[Ool004=oo`8005aoo`L0021oo`H0009oo`8001Eoo`03001oogoo02Yoo`00@7oo0`00Fgoo1`00
87oo1P001Woo0P0057oo00<007ooOol0:Woo000mOol3001LOol6000POol700000goo001oo`06Ool0
0`00Oomoo`0COol00`00Oomoo`0YOol003]oo`8005aoo`H0025oo`H000Aoo`03001oogoo00Eoo`80
01Eoo`03001oogoo02Qoo`00>7oo0`00Fgoo1`0087oo1P001goo00<007ooOol01Woo0P0057oo00<0
07ooOol0:7oo000fOol2001KOol7000POol70009Ool00`00Oomoo`07Ool2000DOol00`00Oomoo`0W
Ool003=oo`<005Yoo`L0021oo`L000aoo`03001oogoo00Qoo`03001oogoo019oo`03001oogoo02Mo
o`00<Goo0P00Fgoo1P008Goo1P003goo00<007ooOol027oo0P0057oo00<007ooOol09Woo000^Ool3
001JOol6000QOol6000BOol00`00Oomoo`09Ool2000DOol00`00Oomoo`0UOol002aoo`8005Yoo`L0
021oo`L001Aoo`03001oogoo00Yoo`8001=oo`03001oogoo02Eoo`00:Goo0`00FWoo1P008Goo1P00
5goo00<007ooOol027oo1@004goo00<007ooOol097oo000WOol2001JOol6000QOol6000JOol00`00
Oomoo`05Ool8000DOol00`00Oomoo`0SOol002Aoo`<005Uoo`L0021oo`L001aoo`03001oogoo009o
o`L000=oo`03001oogoo019oo`03001oogoo02=oo`008Woo0P00FGoo1`003goo0P003goo1`0087oo
00<007oo00001@001Woo0P0057oo00<007ooOol08Woo000OOol3001IOol6000?Ool300000d4`0000
000<Ool6000ROol6000:Ool2000DOol00`00Oomoo`0QOol001eoo`8005Uoo`H0011oo`8000A1<003
001n[@0000Qoo`H0029oo`L000eoo`03001oogoo019oo`03001oogoo025oo`006Woo0`00F7oo1`00
3goo0`001T4`00@007j]OZd000Aoo`L0025oo`P000moo`8001Aoo`03001oogoo021oo`0067oo0P00
FGoo1P003goo0`002D4`00H007j]OZen[@00Ool6000QOol70003Ool00`00Oomoo`0>Ool2000COol0
0`00Oomoo`0POol001Eoo`<005Qoo`H000moo`<000a1<003001n[Gj]00H0025oo`L000Ioo`03001o
ogoo00moo`03001oogoo019oo`03001oogoo01moo`004goo0P00F7oo1`003goo0P003d4`1`0087oo
1`002Goo00<007ooOol03goo0P0057oo00<007ooOol07Woo000AOol2001HOol6000?Ool3000>@C07
0002OZd00`00Oomoo`0LOol6000<Ool00`00Oomoo`0@Ool2000COol00`00Oomoo`0NOol0015oo`80
05Eoo`H000moo`<000i1<0L000In[@03001oogoo01Qoo`H000moo`03001oogoo015oo`03001oogoo
019oo`03001oogoo01eoo`004Goo00<007oo0000DWoo1P003Woo0`003T4`1`000T4`00<007j]OZd0
1Gj]00<007ooOol057oo1`004Goo00<007ooOol04Goo0P0057oo00<007ooOol077oo000AOol01000
Oomoo`00CWoo1P003Woo0`003T4`1`001D4`00<007j]OZd01Gj]00<007ooOol04Goo1`0057oo00<0
07ooOol04Woo0P004goo00<007ooOol077oo000@Ool00`00Oomoo`02Ool00`00Oomoo`19Ool6000>
Ool2000?@C060008@C000`00OZen[@05OZd00`00Oomoo`0>Ool7000GOol00`00Oomoo`0COol00`00
Oomoo`0BOol00`00Oomoo`0KOol0011oo`03001oogoo00=oo`03001oogoo04Eoo`H000ioo`<000i1
<0H000]1<003001n[Gj]00En[@03001oogoo00]oo`L001Yoo`03001oogoo01=oo`8001=oo`03001o
ogoo01]oo`0047oo00<007ooOol017oo00<007ooOol0@Goo1`003Woo0P003T4`1`003D4`00<007j]
OZd01Gj]00<007ooOol027oo1`007Goo00<007ooOol057oo0P004goo00<007ooOol06Woo000@Ool0
0`00Oomoo`05Ool00`00Oomoo`0nOol6000AOol00`00@C11<00:@C07000@@C000`00OZen[@05OZd0
0`00Oomoo`06Ool6000QOol00`00Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`0IOol0011oo`03
001oogoo00Ioo`03001oogoo03Yoo`H001Aoo`030011<44`00M1<0L001=1<003001n[Gj]00En[@03
001oogoo00=oo`H002Aoo`03001oogoo01Aoo`8001=oo`03001oogoo01Uoo`0047oo00<007ooOol0
1goo00<007ooOol0=goo1P005Woo00<0044`@C00144`1`005D4`0P001gj]00<007ooOol01`009Woo
00<007ooOol05Goo0P004goo00<007ooOol067oo000@Ool00`00Oomoo`08Ool00`00Oomoo`0cOol6
000IOol01000@C11<44`1`005D4`0`000UKm00<007j]OZd017j]1`00:Goo00<007ooOol05Woo00<0
07ooOol04Woo00<007ooOol05goo000?Ool00`00Oomoo`0:Ool00`00Oomoo`0_Ool7000KOol00`00
@C000005000E@C030006E_d00`00OZen[@02OZd5000/Ool00`00Oomoo`0FOol2000COol00`00Oomo
o`0GOol000moo`03001oogoo00]oo`03001oogoo02aoo`H001eoo`H001I1<08000YFo@03001n[Gj]
009n[@03001oogoo02eoo`03001oogoo01Moo`8001=oo`03001oogoo01Ioo`003goo00<007ooOol0
37oo00<007ooOol0:7oo1P007Goo1`005D4`0`003EKm00D007j]OZen[@0002moo`03001oogoo01Qo
o`03001oogoo015oo`03001oogoo01Ioo`003goo00<007ooOol03Goo00<007ooOol09Goo1P0077oo
1`005D4`0`0045Km00D007j]OZen[@0002moo`03001oogoo01Qoo`8001=oo`03001oogoo01Eoo`00
3goo00<007ooOol03Woo00<007ooOol08Goo1P007Goo1P000Woo00<0044`@C00444`0`0055Km00@0
07j]OZd002moo`03001oogoo01Uoo`8001=oo`03001oogoo01Aoo`003goo00<007ooOol03goo00<0
07ooOol07Goo1`0077oo1P001Goo00<0044`@C003D4`0`0065Km00<007j]0000;goo00<007ooOol0
6Woo00<007ooOol04Goo00<007ooOol057oo000?Ool00`00Oomoo`0@Ool00`00Oomoo`0JOol6000L
Ool70007Ool00`00@C11<00:@C03000LE_d2000_Ool00`00Oomoo`0JOol2000COol00`00Oomoo`0C
Ool000ioo`03001oogoo019oo`03001oogoo01Ioo`H001aoo`L000Yoo`030011<44`00M1<0<0021F
o@03001oogoo02eoo`03001oogoo01]oo`8001=oo`03001oogoo019oo`003Woo00<007ooOol04goo
00<007ooOol04goo1P0077oo1P003Goo00<0044`@C001D4`0P007eKm0`00<Goo00<007ooOol077oo
00<007ooOol04Goo00<007ooOol04Woo000>Ool00`00Oomoo`0DOol00`00Oomoo`0?Ool6000LOol6
000@Ool00`00@C11<002@C03000NE_d3000dOol00`00Oomoo`0LOol2000COol00`00Oomoo`0AOol0
00ioo`03001oogoo01Eoo`03001oogoo00]oo`L001]oo`L0019oo`030011<000008001eFo@@003Qo
o`03001oogoo01aoo`80019oo`03001oogoo015oo`003Woo00<007ooOol05Woo00<007ooOol027oo
1P006goo1`005Goo0P007EKm0`00?7oo00<007ooOol07Goo0P004Woo00<007ooOol047oo000>Ool0
0`00Oomoo`0GOol00`00Oomoo`04Ool6000KOol7000IOol00`00E_eFo@0>E_d2EUP01000JaU[6F/I
14E@0`00?goo00<007ooOol07Woo00<007ooOol04Goo00<007ooOol03goo000>Ool00`00Oomoo`0H
Ool00`00Oomoo`07000KOol6000MOol00`00E_d0000>E_d01UIH001FoEKm001Fo@<0049oo`03001o
ogoo01ioo`80019oo`03001oogoo00moo`003Goo00<007ooOol06Goo1`006goo1P008Goo0`002UKm
00D005IHEUQFF000009[6@8004Eoo`03001oogoo01moo`80015oo`80011oo`003Goo00<007ooOol0
5Woo1P0077oo1`0087oo1@002UKm00D005IHEUQFF000009[6@8004Ioo`03001oogoo021oo`03001o
ogoo00aoo`<00003Ool007oo00moo`003Goo00<007ooOol04Woo1`000goo00<007ooOol05Woo1`00
87oo20001eKm00@005Km<C@000=FF005001[6F/IJaT00016Ool00`00Oomoo`0POol2000:Ool30004
Ool00`00Oomoo`0>Ool000eoo`03001oogoo015oo`D000Moo`03001oogoo01=oo`H0021oo`L000Ao
o`03001FoEKm00AFo@04000a=34d0003EUP01@00JaU[6F/I0000AWoo00<007ooOol08Goo0P001Woo
0`001goo00<007ooOol03Woo000=Ool00`00Oomoo`0AOol40009Ool00`00Oomoo`0?Ool6000POol7
0008Ool00`00E_eFo@03E_d00`00<C@00003EUP00`00JaU[6@02JaU7Ool00`00Oomoo`0ROol01000
Oomoogoo0`002goo00<007ooOol03Goo000=Ool00`00Oomoo`0AOol50009Ool00`00Oomoo`0;Ool7
000OOol7000<Ool00`00E_d0000300000c4d001FF002EUP01@00JaU[6F/I0000Agoo00<007ooOol0
8Woo10003Woo00<007ooOol03Goo000=Ool00`00Oomoo`0AOol2000017oo000000002Goo00<007oo
Ool01goo1`0087oo1P0047oo00L007ooOomoo`00<C@00003EUP01@00JaU[6F/I0000Agoo00<007oo
Ool087oo1@003goo00<007ooOol03Goo000=Ool00`00Oomoo`0AOol20002Ool30009Ool00`00Oomo
o`03Ool7000POol6000FOol01000<C@a=0000UIH00<006/IJaT00V/IB7oo00<007ooOol077oo1000
17oo00<007ooOol03Goo00<007ooOol03Goo000<Ool00`00Oomoo`0BOol20003Ool30009Ool00`00
Ool00006000POol7000HOol01000<C@a=0000UIH00D006/IJaU[6@0004Qoo`03001oogoo01Uoo`<0
00Qoo`8000ioo`03001oogoo00eoo`0037oo00<007ooOol04Woo0P0017oo0`001goo1`0087oo1`00
6goo00<0034d<C@00eIH00D006/IJaU[6@0004Qoo`03001oogoo01Ioo`<000aoo`8000eoo`03001o
ogoo00eoo`0037oo00<007ooOol04Woo0P001Goo0`000goo1`0087oo1`007Woo00<0034d<C@00eIH
00@006/IJaU[6DYoo`03001oogoo019oo`<0011oo`03001oogoo00]oo`03001oogoo00eoo`0037oo
00<007ooOol04Woo0P001Woo2@000goo00<007ooOol06Woo1`0087oo00@0034d<C@0009FF005001[
6F/IJaT0001:Ool00`00Oomoo`0?Ool3000COol2000<Ool00`00Oomoo`0=Ool000aoo`03001oogoo
015oo`8000Qoo`D000Moo`03001oogoo01Ioo`L002=oo`03000a=34d00=FF005001[6F/IJaT0001:
Ool00`00Oomoo`0<Ool3000GOol2000<Ool00`00Oomoo`0<Ool000aoo`03001oogoo015oo`8000Uo
o`<000Uoo`03001oogoo019oo`L002Ioo`03000a=34d00=FF005001[6F/IJaT0001:Ool00`00Oomo
o`09Ool3000HOol4000<Ool00`00Oomoo`0<Ool000aoo`03001oogoo015oo`8000Yoo`<000Uoo`80
00moo`L002Qoo`04000a=34d0002EUP01@00JaU[6F/I0000Bgoo00<007ooOol01Woo0`0067oo1`00
37oo00<007ooOol037oo000;Ool00`00Oomoo`0BOol2000;Ool3000:Ool00`00Oomoo`09Ool7000[
Ool01000<C@a=0000UIH00D006/IJaU[6@0004]oo`03001oogoo00=oo`<001Qoo`H0011oo`03001o
ogoo00aoo`002goo00<007ooOol04Woo0P0037oo0`002Woo00<007ooOol01Woo1P00;Woo00<0034d
<C@00eIH00D006/IJaU[6@0004]oo`03001oogoo00<001Qoo`H001=oo`03001oogoo00aoo`002goo
00<007ooOol04Woo0P003Goo10002Goo00<007ooOol00Woo1P00<7oo00@0034d<C@0009FF005001[
6F/IJaT0001<Ool3000HOol6000FOol00`00Oomoo`0<Ool000]oo`03001oogoo019oo`8000ioo`@0
00Uoo`P0039oo`04000a=34d0002EUP01@00JaU[6F/I0000BGoo10005Woo1`006Goo00<007ooOol0
37oo000;Ool00`00Oomoo`0BOol2000@Ool30006Ool7000eOol00`00<C@a=003EUP01@00JaU[6F/I
0000AWoo0`000goo00<007ooOol04Goo1`0077oo00<007ooOol037oo000;Ool00`00Oomoo`0BOol2
000AOol30002Ool8000gOol00`00<C@00003EUP01000JaU[6@00@goo10001Woo00<007ooOol03Woo
1P008Goo00<007ooOol02goo000;Ool00`00Oomoo`0AOol2000COol80004Ool00`00Oomoo`0cOol0
1000<C@a=0000UIH00D006/IJaU[6@00041oo`<000Yoo`03001oogoo00]oo`H002Aoo`03001oogoo
00]oo`002Woo00<007ooOol04Woo0P004goo1@0027oo00<007ooOol0<Woo00<0034d<C@00eIH00D0
06/IJaU[6@0003eoo`<000eoo`03001oogoo00Qoo`H002Moo`03001oogoo00]oo`002Woo00<007oo
Ool04Woo0P0057oo10002Goo00<007ooOol0<Goo00<0034d00000eIH00<006/IJaT00P00>Woo0`00
47oo00<007ooOol01Goo1P00:Woo00<007ooOol02goo000:Ool00`00Oomoo`0BOol2000FOol30009
Ool00`00Oomoo`0_Ool01000<C@a=0000UIH00D006/IJaU[6@0003Qoo`<001Aoo`03001oogoo00L0
02eoo`03001oogoo00]oo`002Woo00<007ooOol04Woo0P005goo0`002Goo00<007ooOol0;Woo00<0
034d<C@00eIH00D006/IJaU[6@0003Eoo`<001Moo`L0031oo`03001oogoo00]oo`002Woo00<007oo
Ool04Woo0P0067oo0`002Goo00<007ooOol0;Goo00<0034d00000eIH00<006/IJaT00P00<Woo0`00
5goo1P00=7oo00<007ooOol02goo000:Ool00`00Oomoo`0BOol2000IOol30009Ool00`00Oomoo`0[
Ool01000<C@a=0000UIH00D006/IJaU[6@00031oo`<001Moo`L003Ioo`03001oogoo00]oo`002Woo
00<007ooOol04Woo0P006Woo0`002Goo00<007ooOol0:Woo00@0034d<C@0009FF005001[6F/IJaT0
000]Ool3000GOol60003Ool00`00Oomoo`0eOol00`00Oomoo`0:Ool000Uoo`03001oogoo01=oo`80
01]oo`<000Uoo`03001oogoo02Uoo`03000a=00000=FF003001[6F/I008002Yoo`<001Moo`H000Io
o`03001oogoo03Eoo`03001oogoo00Yoo`002Goo00<007ooOol04Woo0P007Goo0`002Goo00<007oo
Ool0:7oo00<0034d00000eIH00@006/IJaT002Qoo`<001Ioo`L000Uoo`03001oogoo03Eoo`03001o
ogoo00Yoo`002Goo00<007ooOol04Woo0P007Woo0`002Goo00<007ooOol09Woo00@0034d<C@0009F
F005001[6F/IJaT0000UOol3000FOol7000;Ool2000gOol00`00Oomoo`0:Ool000Uoo`03001oogoo
019oo`8001moo`<000Uoo`03001oogoo02Eoo`03000a=00000=FF003001[6F/I0080029oo`<001Io
o`H000aoo`<0009oo`03001oogoo03Aoo`03001oogoo00Yoo`002Goo00<007ooOol04Woo0P0087oo
0`002Goo00<007ooOol097oo00<0034d00000eIH00<006/IJaT00P007Woo10005Woo1P0037oo0`00
1Woo00<007ooOol0<goo00<007ooOol02Woo0009Ool00`00Oomoo`0BOol2000QOol30009Ool00`00
Oomoo`0ROol01000<C@a=0000UIH00D006/IJaU[6@0001aoo`<001Moo`H000]oo`@000Uoo`03001o
ogoo03=oo`03001oogoo00Yoo`002Goo00<007ooOol04Woo0P008Woo0`002Goo00<007ooOol08Goo
00<0034d00000eIH00<006/IJaT00P006Goo0`005Woo1`002goo0`003Woo00<007ooOol0<Woo00<0
07ooOol02Woo0008Ool00`00Oomoo`0COol2000SOol30009Ool00`00Oomoo`0POol00`00<C@00003
EUP00`00JaU[6@02000FOol3000FOol7000;Ool3000BOol00`00Oomoo`0bOol00`00Oomoo`09Ool0
00Qoo`03001oogoo01=oo`8002Aoo`<000Uoo`03001oogoo01ioo`04000a=34d0002EUP01@00JaU[
6F/I000057oo0`005Woo1`002goo0`005Woo00<007ooOol0<Goo00<007ooOol02Goo0008Ool00`00
Oomoo`0BOol2000VOol30009Ool00`00Oomoo`0MOol00`00<C@a=003EUP01@00JaU[6F/I00004Goo
0`005Woo1P0037oo0`006Goo00<007ooOol0<Goo00<007ooOol02Goo0008Ool00`00Oomoo`0BOol2
000WOol40008Ool00`00Oomoo`0LOol00`00<C@00003EUP00`00JaU[6@02000>Ool3000FOol6000;
Ool4000MOol00`00Oomoo`0`Ool00`00Oomoo`09Ool000Qoo`03001oogoo019oo`8002Qoo`@000Qo
o`03001oogoo01]oo`03000a=00000=FF004001[6F/I000<Ool3000FOol6000;Ool3000ROol00`00
Oomoo`0_Ool00`00Oomoo`09Ool000Qoo`03001oogoo019oo`8002Yoo`<000Qoo`03001oogoo01Uo
o`04000a=34d0002EUP01@00JaU[6F/I00002Goo0`005Woo1P002goo0`009Woo00<007ooOol0;Woo
00<007ooOol02Goo0008Ool00`00Oomoo`0BOol2000[Ool30008Ool00`00Oomoo`0HOol00`00<C@0
0003EUP00`00JaU[6@020006Ool3000FOol6000;Ool3000YOol00`00Oomoo`0^Ool00`00Oomoo`09
Ool000Moo`03001oogoo01=oo`8002=oo`<000Ioo`<000Qoo`03001oogoo01Moo`03000a=00000=F
F003001[6F/I008000=oo`<001Ioo`H000]oo`<002eoo`03001oogoo02eoo`03001oogoo00Uoo`00
1goo00<007ooOol04goo0P007Goo1P000gZ`0P001Goo0`0027oo00<007ooOol05Goo00@0034d<C@0
009FF006001[6F/IJaT007oo0`005Woo1P002goo0`00<Goo00<007ooOol0;Goo00<007ooOol027oo
0007Ool00`00Oomoo`0COol2000HOol5000;N[000`00Oomoo`03Ool30008Ool00`00Oomoo`0DOol0
0`00<C@00003EUP00`00JaU[6@03000FOol6000:Ool4000eOol00`00Oomoo`0/Ool00`00Oomoo`08
Ool000Moo`03001oogoo01=oo`8001Ioo`<0011j/08000Aoo`<000Qoo`03001oogoo01=oo`03000a
=00000=FF003001[6F/I008001Aoo`H000Yoo`<003Uoo`03001oogoo02aoo`03001oogoo00Qoo`00
1goo00<007ooOol04Woo0P005Goo0P000SA800<007Z`N[0047Z`00<007ooOol00Woo0`0027oo00<0
07ooOol04Goo00@0034d<C@000=FF004001[6F/I000BOol6000:Ool3000mOol00`00Oomoo`0[Ool0
0`00Oomoo`08Ool000Moo`03001oogoo019oo`8001Eoo`<dB003001j/7Z`019j/003001oogoo009o
o`<000Qoo`03001oogoo011oo`03000a=00000=FF005001[6F/IJaT0000?Ool6000:Ool30011Ool0
0`00Oomoo`0ZOol00`00Oomoo`08Ool000Moo`03001oogoo019oo`8001Aoo`05000dB3A8=4P0000E
N[020003Ool30008Ool00`00Oomoo`0<Ool400000c4d001FF002EUP00`00JaU[6@02000<Ool6000:
Ool30015Ool00`00Oomoo`0YOol00`00Oomoo`08Ool000Ioo`03001oogoo01=oo`8001Aoo`04000d
B3A8000HN[001000Oomoogoo0`0027oo00<007ooOol027oo0`000goo00<0034d00000eIH00@006/I
JaT000Yoo`H000Uoo`@004Qoo`03001oogoo02Uoo`03001oogoo00Qoo`001Woo00<007ooOol04goo
0P004goo00D003A8=4PdB00001Uj/080009oo`<000Qoo`03001oogoo00Aoo`<000Eoo`03000a=000
00=FF005001[6F/IJaT00006Ool70009Ool3001=Ool00`00Oomoo`0XOol00`00Oomoo`08Ool000Io
o`03001oogoo01=oo`8001=oo`04000dB3A8000LN[000`00Oomoo`030008Ool00`00Oomoo`030008
Ool00`00<C@00003EUP00`00JaU[6@020003Ool70009Ool3001AOol00`00Oomoo`0XOol00`00Oomo
o`07Ool000Ioo`03001oogoo01=oo`80019oo`05000dB3A8=4P0000MN[000`00Oomoo`030008Ool2
000;Ool00`00<C@00003EUP00`00JaU[6@0200000goo000000040009Ool3001EOol00`00Oomoo`0W
Ool00`00Oomoo`07Ool000Ioo`03001oogoo01=oo`80019oo`04000dB3A8000NN[001000Oomoogoo
0`001goo00<007ooOol02Goo00@0034d<C@0009FF004001[6F/IJaT60009Ool3001IOol00`00Oomo
o`0VOol00`00Oomoo`07Ool000Ioo`03001oogoo01=oo`80015oo`05000dB3A8=4P0000ON[001000
Oomoogoo0`001Woo00<007ooOol02Goo00<0034d00000eIH00<006/IJaT01@001goo1000G7oo00<0
07ooOol09Woo00<007ooOol01goo0006Ool00`00Oomoo`0BOol2000BOol01000=4PdB0008GZ`00@0
07ooOomoo`<000Eoo`03001oogoo00Uoo`03000a=00000=FF003001[6F/I008000Moo`<0065oo`03
001oogoo02Eoo`03001oogoo00Moo`001Goo00<007ooOol04goo0P004Goo00D003A8=4PdB000025j
/003001oogoo009oo`<000Aoo`03001oogoo00Qoo`04000a=34d0003EUP01000JaU[6@001Goo0`00
IGoo00<007ooOol097oo00<007ooOol01goo0005Ool00`00Oomoo`0COol2000AOol01000=4PdB000
8gZ`00<007ooOol00Woo0`000goo00<007ooOol01Goo1P000eIH00D006/IJaU[6@00009oo`<006Uo
o`03001oogoo02=oo`03001oogoo00Moo`001Goo00<007ooOol04goo0P0047oo00D003A8=4PdB000
02=j/003001oogoo00=oo`<0009oo`03001oogoo00=oo`H00003<C@005IH009FF003001[6F/I00@0
06aoo`03001oogoo02=oo`03001oogoo00Moo`001Goo00<007ooOol04goo0P0047oo00@003A8=4P0
02Ej/003001oogoo00=oo`<00004Ool007ooOol60002Ool00`00<C@00003EUP4001`Ool00`00Oomo
o`0SOol00`00Oomoo`06Ool000Eoo`03001oogoo01=oo`8000moo`03000dB3A8008002Ij/003001o
ogoo00=oo`X000=oo`04000a=000EUP40002JaT00`00Oomoo`1_Ool00`00Oomoo`0ROol00`00Oomo
o`06Ool000Eoo`03001oogoo01=oo`8000moo`<00003AG8007Z`02Ej/003001oogoo00Aoo`H000Io
o`@0009FF003001[6F/I0080079oo`03001oogoo025oo`03001oogoo00Ioo`001Goo00<007ooOol0
4goo0P003goo00D004EbAG95LP0002Mj/003001oogoo00=oo`<000Moo`<00003<C@005IH009FF003
001[6F/I0080079oo`03001oogoo025oo`03001oogoo00Ioo`0017oo00<007ooOol057oo0P003goo
00D004EbAG95LP0002Qj/003001oogoo009oo`<000Aoo`<00004Ool0034d0003EUP01@00JaU[6F/I
0000M7oo00<007ooOol087oo00<007ooOol01Woo0004Ool00`00Oomoo`0COol2000@Ool01@00AG95
LTEb0000:7Z`00<007ooOol00Woo0P000Woo0`0017oo00<0034d00000eIH00<006/IJaT00P00MGoo
00<007ooOol07goo00<007ooOol01Woo0004Ool00`00Oomoo`0COol2000@Ool01@00AG95LTEb0000
:GZ`00@007ooOomoo`@000Moo`03000a=00000=FF003001[6F/I008007Ioo`03001oogoo01ioo`03
001oogoo00Ioo`0017oo00<007ooOol04goo0P0047oo00D004EbAG95LP0002Uj/0H000Uoo`03000a
=00000=FF004001[6F/I001gOol00`00Oomoo`0NOol00`00Oomoo`06Ool000Aoo`03001oogoo01=o
o`80011oo`050015LTEbAG80000WN[040002Ool20008Ool00`00<C@00003EUP00`00JaU[6@02001h
Ool00`00Oomoo`0NOol00`00Oomoo`05Ool000Aoo`03001oogoo01=oo`80011oo`050015LTEbAG80
000TN[030004N[001000Ool0000027oo00<0034d00000eIH00<006/IJaT00P00NGoo00<007ooOol0
7Goo00<007ooOol01Goo0004Ool00`00Oomoo`0COol2000@Ool01@00AG95LTEb00008GZ`0`001gZ`
00@007oo000000Qoo`03000a=00000=FF004001[6F/I001kOol00`00Oomoo`0LOol00`00Oomoo`05
Ool000Aoo`03001oogoo01=oo`80011oo`050015LTEbAG80000NN[03000;N[030007Ool00`00<C@0
0003EUP01@00JaU[6F/I0000Ngoo00<007ooOol077oo00<007ooOol01Goo0003Ool00`00Oomoo`0D
Ool2000@Ool01@00AG95LTEb00006WZ`10003WZ`0`001goo00<0034d00000eIH00<006/IJaT00P00
O7oo00<007ooOol06goo00<007ooOol01Goo0003Ool00`00Oomoo`0COol2000AOol01@00AG95LTEb
00005gZ`0`004gZ`0P001goo00<0034d00000eIH00<006/IJaT00P00OGoo00<007ooOol06Woo00<0
07ooOol01Goo0003Ool00`00Oomoo`0COol2000AOol00`00AG95LP02AG800`00N[1j/00AN[03000F
N[020006Ool00`00<C@00003EUP01@00JaU[6F/I0000Ogoo00<007ooOol06Goo00<007ooOol01Goo
0003Ool00`00Oomoo`0COol2000AOol00`00AG95LP02AG800`00N[1j/00>N[03000IN[020006Ool0
0`00<C@00003EUP00`00JaU[6@02001oOol00`00Oomoo`0IOol00`00Oomoo`05Ool000=oo`03001o
ogoo01=oo`80015oo`030015LTEb0095LP03001j/7Z`00]j/0<001ej/003001oogoo00Aoo`03000a
=00000=FF003001[6F/I0080081oo`03001oogoo01Uoo`03001oogoo00Aoo`000goo00<007ooOol0
4goo0P004Goo00<004EbAG800TEb00<007Z`N[001gZ`100087Z`00<007ooOol017oo0P0015IH00@0
06/IJaT0009oo`H007Yoo`03001oogoo01Qoo`03001oogoo00Aoo`000goo00<007ooOol04goo0P00
4Goo00<004EbAG800TEb00<007Z`N[0017Z`0`0097Z`00<007ooOol00goo00<0034d00000eIH00<0
06/I00002P00Ngoo00<007ooOol05goo00<007ooOol017oo0002Ool00`00Oomoo`0DOol2000AOol0
0`00AG95LP02AG801000N[1j/7Z`0`009gZ`00<007ooOol00goo00<0034d00000UIH2000PWoo00<0
07ooOol05Woo00<007ooOol017oo0002Ool00`00Oomoo`0DOol2000AOol00`00AG95LP02AG84000[
N[000`00Oomoo`02Ool00`00<C@000070025Ool00`00Oomoo`0FOol00`00Oomoo`04Ool0009oo`03
001oogoo01Aoo`80015oo`030015LTEb00<002ij/004001oogooOol70003JaT00`00Oomoo`24Ool0
0`00Oomoo`0EOol00`00Oomoo`04Ool0009oo`03001oogoo01=oo`80015oo`@00095LP03001j/7Z`
02aj/003001oogoo00H00004EUP006/IJaT20027Ool00`00Oomoo`0DOol00`00Oomoo`04Ool0009o
o`03001oogoo01=oo`8000ioo`<00003Ool004Eb00=5LP03001j/7Z`02aj/0L000=FF003001[6F/I
008008Qoo`03001oogoo01=oo`03001oogoo00Aoo`000Woo00<007ooOol04goo0P002goo0`0017oo
00<004EbAG800TEb00<007Z`N[009gZ`2@0000<a=000EUP00UIH00D006/IJaU[6@0008Uoo`03001o
ogoo01Aoo`03001oogoo00=oo`000Woo00<007ooOol04goo0P0027oo0`001goo00<004EbAG800`00
9WZ`200000Ij/000Ool0034d0003EUP00`00JaU[6@02002:Ool00`00Oomoo`0COol00`00Oomoo`03
Ool00003Ool007oo01Eoo`8000Eoo`<000Yoo`<0009>5`03001j/7Z`025j/0P000Ej/0800003<C@0
05IH009FF003001[6F/I008008]oo`03001oogoo019oo`03001oogoo00=oo`0000=oo`00Ool05Goo
0P000Woo0`003Goo00<004hGCQL00dhG00<007Z`N[007GZ`1`002GZ`0`0015IH00@006/IJaT008eo
o`03001oogoo015oo`03001oogoo00=oo`0000=oo`00Ool05Goo10004Goo00<004hGCQL00ThG00<0
07Z`N[006WZ`1`0037Z`00<0034d00000eIH00<006/IJaT00P00SGoo00<007ooOol04Goo00<007oo
Ool00goo00000goo001oo`0BOol5000COol00`00CQM>5`02CQL00`00N[1j/00GN[07000?N[000`00
<C@00003EUP00`00JaU[6@02002>Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00003Ool007oo00mo
o`<000=oo`8001=oo`03001>5dhG00=>5`03001j/7Z`01Ej/0D0019j/08000AFF004001[6F/I002@
Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00003Ool007oo00aoo`<000Eoo`8001Eoo`03001>5dhG
009>5`03001j/7Z`01Ij/003001j/7Z`019j/003000a=00000=FF005001[6F/IJaT0002AOol00`00
Oomoo`0>Ool00`00Oomoo`03Ool00003Ool007oo00Uoo`<000Qoo`8001Eoo`03001>5dhG009>5`03
001j/7Z`02]j/003000a=00000=FF003001[6F/I0080095oo`03001oogoo00moo`03001oogoo009o
o`0000<007ooOol01Goo10002goo0P005Goo00<004hGCQL00ThG00<007Z`N[00:gZ`00<0034d0000
0eIH00<006/IJaT00P00TWoo00<007ooOol03Woo00<007ooOol00Woo00000`00Oomoo`02Ool3000?
Ool2000EOol00`00CQM>5`03CQL00`00N[1j/00YN[000`00<C@00004EUP01000JaU[6@00U7oo00<0
07ooOol03Goo00<007ooOol00Woo00000`00Ool00002000BOol2000FOol00`00CQM>5`02CQL00`00
N[1j/00YN[000`00<C@00003EUP00`00JaU[6@02002EOol00`00Oomoo`0<Ool00`00Oomoo`02Ool0
008001Eoo`8001Ioo`03001>5dhG009>5`03001j/7Z`02Uj/003000a=00000=FF003001[6F/I0080
09Eoo`03001oogoo00aoo`03001oogoo009oo`0000=oo`00Ool057oo0P005Woo00<004hGCQL00dhG
00<007Z`N[00:7Z`0P0015IH00@006/IJaT009Moo`03001oogoo00]oo`03001oogoo009oo`000Woo
0P004goo0P005goo00<004hGCQL00ThG00<007Z`N[009gZ`00<0034d00000eIH00<006/IJaT00P00
V7oo00<007ooOol02Woo00<007ooOol00Woo0004Ool00`00Oomoo`0?Ool3000GOol00`00CQM>5`02
CQL00`00N[1j/00WN[000`00<C@00003EUP00`00JaU[6@02002IOol00`00Oomoo`09Ool00`00Oomo
o`02Ool000Eoo`03001oogoo00ioo`D001Eoo`03001>5dhG00=>5`03001j/7Z`02Ij/08000AFF004
001[6F/I002KOol00`00Oomoo`09Ool00`00Oomoo`01Ool000Ioo`80011oo`@001Eoo`03001>5dhG
009>5`03001j/7Z`02Ej/003000a=00000=FF005001[6F/IJaT0002KOol00`00Oomoo`09Ool00`00
Oomoo`01Ool000Qoo`03001oogoo00moo`<001Aoo`03001>5dhG009>5`03001j/7Z`02Ej/003000a
=00000=FF003001[6F/I008009aoo`03001oogoo00Qoo`03001oogoo005oo`002Goo00<007ooOol0
3goo0`004goo00<004hGCQL00dhG00<007Z`N[0097Z`0P0015IH00<006/IJaT00P00WGoo00<007oo
Ool01goo00<007ooOol00Goo000:Ool2000@Ool4000BOol00`00CQM>5`02CQL00`00N[1j/00SN[00
0`00<C@00004EUP01000JaU[6@00Wgoo00<007ooOol01Woo00<007ooOol00Goo000<Ool00`00Oomo
o`0>Ool4000AOol00`00CQM>5`02CQL00`00N[1j/00SN[000`00<C@00003EUP00`00JaU[6@02002O
Ool00`00Oomoo`06Ool00`00Oomoo`01Ool000eoo`03001oogoo00moo`<0011oo`03001>5dhG009>
5`03001j/7Z`02=j/003000a=00000=FF003001[6F/I00800:1oo`03001oogoo00Eoo`03001oogoo
005oo`003Woo0P0047oo0`003goo00<004hGCQL00dhG00<007Z`N[008WZ`0P0015IH00@006/IJaT0
0:9oo`03001oogoo00Aoo`03001oogoo005oo`0047oo00<007ooOol03Woo10003Woo00<004hGCQL0
0ThG00<007Z`N[008GZ`00<0034d00000eIH00<006/IJaT00P00Xgoo00<007ooOol017oo0@000Goo
0Goo000AOol00`00Oomoo`0>Ool4000=Ool00`00CQM>5`02CQL00`00N[1j/00QN[000`00<C@00003
EUP00`00JaU[6@02002SOol00`00Oomoo`04Ool10001Ool1Ool0019oo`80011oo`<000aoo`03001>
5dhG00=>5`03001j/7Z`021j/08000AFF004001[6F/I002UOol00`00Oomoo`03Ool10001Ool1Ool0
01Aoo`03001oogoo00ioo`<000aoo`03001>5dhG00<0025j/003000a=00000=FF005001[6F/IJaT0
002VOol00`00Oomoo`02Ool10001Ool1Ool001Eoo`03001oogoo00ioo`@000Yoo`<000=BV`03001j
/7Z`01ij/003000a=00000=FF003001[6F/I00800:Moo`05001oogooOol00002Ool001Ioo`8000mo
o`@000Yoo`EBV`03001j/7Z`01ij/08000AFF003001[6F/I00800:Moo`05001oogooOol00002Ool0
01Qoo`03001oogoo00ioo`<000Uoo`03001BVe:K00=BV`03001j/7Z`01aj/003000a=00000AFF003
001[6F/I00800:Qoo`04001oogoo0002Ool001Uoo`03001oogoo00ioo`@000Qoo`03001BVe:K00=B
V`03001j/7Z`01]j/003000a=00000=FF003001[6F/I00<00:Uoo`03001oo`00009oo`006Woo0P00
3goo100027oo00<005:KDY/00U:K00<007Z`N[006gZ`0P0015IH00<006/IJaT00`00ZWoo00<007oo
00000Goo000LOol00`00Oomoo`0>Ool30007Ool00`00DY]BV`03DY/00`00N[1j/00JN[020004EUP0
1P00JaU[6@00N[000:Yoo`03001oo`00005oo`007Goo00<007ooOol03Woo0`001goo00<005:KDY/0
0e:K00<007Z`N[0067Z`00<0034d00000eIH00<006/IJaT00P0000=j/000Ool0ZWoo0P000Goo000N
Ool00`00Oomoo`0>Ool40006Ool00`00DY]BV`02DY/00`00N[1j/00HN[000`00<CAFF003EUP00`00
JaU[6@03002/Ool20001Ool001moo`8000moo`@000Ioo`03001BVe:K009BV`03001j/7Z`01Mj/003
<C@005IH00=FF006001[6F/I001j/000Z7oo10000goo000QOol00`00Oomoo`0>Ool30005Ool00`00
DY]BV`02DY/00`00N[1j/00GN[000c4d001FF002EUP01`00JaU[6F/I001j/0000:Aoo`@000Moo`00
8Woo00<007ooOol03Woo0`001Goo00<005:KDY/00U:K00<007Z`N[005WZ`00<a=5IHEUP00UIH00<0
06/IJaT00`00XGoo10002goo000SOol2000?Ool40004Ool00`00DY]BV`02DY/00`00N[1j/00EN[00
0`00EUQFF002EUP00`00JaU[6@03002MOol4000?Ool002Eoo`03001oogoo00eoo`@000=oo`03001B
Ve:K009BV`03001j/7Z`01Ej/0EFF006001[6F/I001j/000VGoo10004goo000VOol00`00Oomoo`0>
Ool40002Ool00`00DY]BV`02DY/00`00N[1j/00EN[02000015IH001[6F/I0`00UWoo10005goo000W
Ool2000?Ool40002Ool00`00DY]BV`02DY/00`00N[1j/00EN[0600000gZ`001oo`2AOol4000KOol0
02Uoo`03001oogoo00ioo`<00003Ool005:K00=BV`03001j/7Z`01aj/003001oogoo08aoo`@001mo
o`00:Woo00<007ooOol03Woo1@0015:K00<007Z`N[006gZ`00<007ooOol0R7oo10008goo000[Ool2
000?Ool50004DY/00`00N[1j/00IN[000`00Oomoo`25Ool4000WOol002eoo`03001oogoo00ioo`@0
00=BV`03001j/7Z`01Uj/003001oogoo085oo`@002]oo`00;Woo00<007ooOol03Woo10000U:K0`00
6GZ`00<007ooOol0OGoo1000;goo000_Ool2000@Ool40003Cel2000FN[000`00Oomoo`1jOol4000c
Ool0035oo`03001oogoo00eoo`@000E?G`8001=j/08007Qoo`@003Moo`00<Woo00<007ooOol03Goo
1@001DmO0P003gZ`0P00MWoo1000>goo000cOol2000>Ool60005Cel2000:N[03001dOol4000oOol0
03Eoo`03001oogoo00eoo`<00003Ool0000000E?G`8000Mj/0@0071oo`@004=oo`00=Woo00<007oo
Ool03Goo100000=oo`0000001DmO0P000gZ`0P0000Aoo`00000006aoo`@004Moo`00=goo0P003Woo
10000Woo0P0014mO10000goo0`00J7oo1000Bgoo000iOol00`00Oomoo`0=Ool40002Ool40007Ool3
001TOol4001?Ool003Yoo`03001oogoo00eoo`@000aoo`<0061oo`@005=oo`00>goo0P003goo0`00
2goo0`00G7oo1000Egoo000mOol00`00Oomoo`0=Ool40009Ool3001HOol4001KOol003ioo`03001o
ogoo00eoo`@000Qoo`<005Aoo`@005moo`00?goo00<007ooOol03Woo10001Woo0`00D7oo1000Hgoo
0010Ool2000?Ool40005Ool3001<Ool4001WOol0049oo`03001oogoo00ioo`<000Aoo`<004Qoo`@0
06]oo`00@goo00<007ooOol03Woo10000Woo0`00A7oo1000Kgoo0014Ool2000?Ool4000017oo0000
0000@7oo1000Lgoo0016Ool00`00Oomoo`0>Ool6000lOol4001gOol004Moo`03001oogoo00ioo`D0
03Qoo`@007]oo`00B7oo0P0047oo0`00=7oo1000Ogoo001:Ool00`00Oomoo`0=Ool3000`Ool40023
Ool004]oo`03001oogoo00ioo`03001oogoo02Yoo`@008Moo`00C7oo0P003Goo00<007ooOol09goo
1000Rgoo001>Ool00`00Oomoo`0:Ool00`00Oomoo`0SOol4002?Ool004moo`03001oogoo00Uoo`03
001oogoo01moo`@009=oo`00D7oo0P002Goo00<007ooOol06goo1000Ugoo001BOol00`00Oomoo`06
Ool00`00Oomoo`0GOol4002KOol005=oo`03001oogoo00Eoo`03001oogoo01=oo`@009moo`00E7oo
0P001Goo00<007ooOol03goo1000Xgoo001FOol00`00Oomoo`02Ool00`00Oomoo`0;Ool4002WOol0
05Moo`05001oogooOol00009Ool4002[Ool005Qoo`800003Ool007oo00Aoo`@00:moo`00FWoo0P00
00=oo`0000000P00/goo001KOol2002gOol00001\
\>"],
  ImageRangeCache->{{{0, 275}, {262, 0}} -> {-0.000190518, 0.000567246, 
  0.00354754, 0.00354754}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.25, shown from a different perspective."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{groundgraphic, crankgraphic, slidergraphic, conrodgraphic} /. 
        SolveMech[.25], 
      PlotRange \[Rule] {{\(-2\), 37}, {\(-10\), 20}, {\(-4\), 24}}, 
      ViewPoint \[Rule] {1.273, 2.942, 1.083}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .82636 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0447593 1.04476 -0.0594246 1.04476 [
[ 0 0 0 0 ]
[ 1 .82636 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.68066 .35448 m
.69297 .82636 L
s
.69297 .82636 m
1 .71121 L
s
1 .71121 m
.96419 .15308 L
s
.96419 .15308 m
.68066 .35448 L
s
.03011 .25029 m
.20328 0 L
s
.20328 0 m
.18032 .62178 L
s
.18032 .62178 m
0 .76713 L
s
0 .76713 m
.03011 .25029 L
s
.68066 .35448 m
.69297 .82636 L
s
.69297 .82636 m
0 .76713 L
s
0 .76713 m
.03011 .25029 L
s
.03011 .25029 m
.68066 .35448 L
s
.96419 .15308 m
.20328 0 L
s
.20328 0 m
.18032 .62178 L
s
.18032 .62178 m
1 .71121 L
s
1 .71121 m
.96419 .15308 L
s
0 0 m
1 0 L
1 .82636 L
0 .82636 L
closepath
clip
newpath
.008 w
.70763 .38895 m
.71889 .77193 L
s
.5 Mabswid
.75796 .56981 m .76702 .47385 L .79863 .38812 L p .297 .205 .579 r
F P
0 g
s
.79863 .38812 m .76702 .47385 L .75063 .4715 L p .761 .71 .804 r
F P
0 g
s
.76702 .47385 m .75796 .56981 L .74149 .56771 L p .785 .634 .694 r
F P
0 g
s
.74149 .56771 m .75063 .4715 L .76702 .47385 L p .785 .634 .694 r
F P
0 g
s
.75063 .4715 m .78209 .38551 L .79863 .38812 L p .761 .71 .804 r
F P
0 g
s
.74149 .56771 m .75063 .4715 L .78209 .38551 L p .291 .2 .577 r
F P
0 g
s
.77364 .65474 m .75796 .56981 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.75796 .56981 m .77364 .65474 L .7569 .65283 L p .785 .531 .553 r
F P
0 g
s
.7569 .65283 m .74149 .56771 L .75796 .56981 L p .785 .531 .553 r
F P
0 g
s
.7569 .65283 m .74149 .56771 L p .78209 .38551 L .291 .2 .577 r
F P
0 g
s
.33381 .24463 m .31365 .26563 L .455 .28891 L p .584 .802 .982 r
F P
0 g
s
.455 .28891 m .47737 .26879 L .33381 .24463 L p .584 .802 .982 r
F P
0 g
s
.31365 .26563 m .455 .28891 L .45479 .35913 L p .788 .589 .632 r
F P
0 g
s
.008 w
.45482 .34968 m
.70763 .38895 L
s
.455 .28891 m .47426 .33305 L .4649 .34559 L .173 .096 .522 r
F
.5 Mabswid
.45479 .35913 m .45484 .3425 L p .4649 .34559 L F P
0 g
s
.45484 .3425 m .455 .28891 L p .4649 .34559 L .173 .096 .522 r
F P
0 g
s
.47736 .34016 m .47401 .34298 L p .47426 .33305 L .173 .096 .522 r
F P
0 g
s
.47401 .34298 m .46929 .34695 L p .47426 .33305 L .173 .096 .522 r
F P
0 g
s
.46929 .34695 m .45479 .35913 L p .4649 .34559 L .173 .096 .522 r
F P
0 g
s
.47426 .33305 m .46929 .34695 L .4649 .34559 L .173 .096 .522 r
F
.81176 .70799 m .77364 .65474 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.86447 .71287 m .81176 .70799 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.91818 .66302 m .86447 .71287 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.77364 .65474 m .81176 .70799 L .79458 .70616 L p .716 .298 .252 r
F P
0 g
s
.79458 .70616 m .7569 .65283 L .77364 .65474 L p .716 .298 .252 r
F P
0 g
s
.79458 .70616 m .7569 .65283 L p .76092 .61018 L .291 .2 .577 r
F P
0 g
s
.77483 .46251 m .79136 .62357 L .76092 .61018 L .291 .2 .577 r
F
.7862 .49095 m .79136 .62357 L .77483 .46251 L F
.78209 .38551 m .83308 .64192 L .79136 .62357 L F
.83369 .65615 m .84942 .66902 L p .8337 .65679 L .683 .512 .648 r
F P
0 g
s
.83308 .64192 m .83533 .65326 L .79136 .62357 L .291 .2 .577 r
F
.8568 .65866 m .84942 .66902 L .83369 .65615 L p .556 .521 .772 r
F P
0 g
s
.8568 .65866 m .83369 .65615 L .83982 .64538 L .556 .521 .772 r
F
.82922 .66399 m .83393 .67658 L .82344 .67414 L .291 .2 .577 r
F
.84942 .66902 m .83949 .68062 L .83393 .67605 L p .683 .512 .648 r
F P
0 g
s
.84942 .66902 m .83393 .67605 L .8337 .65679 L .683 .512 .648 r
F
.83393 .67605 m .83949 .68062 L p .834 .67625 L .784 .448 .419 r
F P
0 g
s
.85733 .65558 m .8568 .65866 L .84005 .64499 L p 0 .336 .815 r
F P
0 g
s
.40244 .30318 m .40799 .29222 L .46585 .33947 L p .556 .521 .772 r
F P
0 g
s
.47736 .34016 m .46823 .33872 L p .46663 .34115 L .57 .807 .989 r
F P
0 g
s
.39272 .31388 m .40244 .30318 L .45207 .3438 L p .683 .512 .648 r
F P
0 g
s
.45479 .35913 m .46929 .34695 L p .46758 .34322 L .57 .807 .989 r
F P
0 g
s
.45479 .35913 m .46758 .34322 L .46521 .34331 L .57 .807 .989 r
F
.44414 .3441 m .39272 .31388 L .45207 .3438 L .683 .512 .648 r
F
.46585 .33947 m .40799 .29222 L p .46552 .33875 L 0 .336 .815 r
F P
0 g
s
.4537 .34329 m .40244 .30318 L .46585 .33947 L .556 .521 .772 r
F
.45479 .35913 m .31213 .33717 L .31365 .26563 L p .788 .589 .632 r
F P
0 g
s
.43017 .34462 m .39272 .31388 L p .43216 .34454 L .683 .512 .648 r
F P
0 g
s
.38443 .31814 m .39272 .31388 L .43017 .34462 L p .784 .448 .419 r
F P
0 g
s
.41406 .34522 m .41468 .34515 L .39191 .33766 L .57 .807 .989 r
F
.41468 .34515 m .42576 .34382 L .41279 .34146 L F
.41468 .34515 m .41279 .34146 L .39191 .33766 L F
.41399 .34168 m .38443 .31814 L .43017 .34462 L .784 .448 .419 r
F
.43011 .3507 m .44239 .34684 L .41406 .34522 L .57 .807 .989 r
F
.44239 .34684 m .43017 .34462 L .41406 .34522 L F
.45479 .35913 m .46521 .34331 L .43011 .3507 L F
.46521 .34331 m .45725 .34361 L .43011 .3507 L F
.46663 .34115 m .46585 .33947 L .43011 .3507 L F
.44239 .34684 m .45207 .3438 L .43017 .34462 L F
.43216 .34454 m .39272 .31388 L .44414 .3441 L .683 .512 .648 r
F
.40244 .30318 m .39272 .31388 L p .40611 .28736 L .89 .969 .83 r
F P
0 g
s
.39272 .31388 m .38443 .31814 L p .40611 .28736 L .89 .969 .83 r
F P
0 g
s
.38443 .31814 m .38242 .31341 L p .40611 .28736 L .89 .969 .83 r
F P
0 g
s
.38242 .31341 m .38796 .30237 L p .40611 .28736 L .89 .969 .83 r
F P
0 g
s
.38796 .30237 m .38242 .31341 L .41006 .33612 L p .553 .52 .773 r
F P
0 g
s
.37609 .34702 m .45479 .35913 L p .39838 .33987 L .57 .807 .989 r
F P
0 g
s
.82135 .64382 m .82344 .67414 L .79136 .62357 L .291 .2 .577 r
F
.83533 .65326 m .82922 .66399 L .82135 .64382 L F
.82922 .66399 m .82344 .67414 L .82135 .64382 L F
.43017 .34462 m .42576 .34382 L .41406 .34522 L .57 .807 .989 r
F
.83393 .67658 m .8365 .68345 L .83406 .68697 L .291 .2 .577 r
F
.83393 .67658 m .8341 .69095 L .82344 .67414 L F
.84604 .7071 m .84681 .71099 L .8365 .68345 L F
.8367 .68316 m .8365 .68345 L .82922 .66399 L F
.84604 .7071 m .8365 .68345 L .8367 .68316 L F
.83949 .68062 m .8367 .68316 L p .83401 .67626 L .784 .448 .419 r
F P
0 g
s
.8367 .68316 m .83274 .68678 L p .83401 .67626 L .784 .448 .419 r
F P
0 g
s
.79136 .62357 m .8341 .69095 L .79458 .70616 L .291 .2 .577 r
F
.79136 .62357 m .79458 .70616 L .76092 .61018 L F
.83949 .68062 m .41279 .34146 L .41398 .34167 L .784 .448 .419 r
F
.46521 .34331 m .46663 .34115 L .45725 .34361 L .57 .807 .989 r
F
.46663 .34115 m .46823 .33872 L .46585 .33947 L F
.46521 .34331 m .46758 .34322 L .46663 .34115 L F
.46929 .34695 m .47736 .34016 L p .46663 .34115 L F P
0 g
s
.78209 .38551 m .87044 .59165 L .84005 .64499 L .291 .2 .577 r
F
.83308 .64192 m .84005 .64499 L .83533 .65326 L F
.78209 .38551 m .84005 .64499 L .83308 .64192 L F
.84938 .64909 m .85733 .65558 L p .84922 .64902 L 0 .336 .815 r
F P
0 g
s
.84005 .64499 m .8568 .65866 L p .83982 .64538 L .556 .521 .772 r
F P
0 g
s
.83949 .68062 m .8367 .68316 L p .85733 .65558 L .748 .959 .661 r
F P
0 g
s
.85733 .65558 m .84005 .64499 L .84919 .64901 L 0 .336 .815 r
F
.87044 .59165 m .88183 .61822 L .83533 .65326 L .291 .2 .577 r
F
.85733 .65558 m .84501 .67121 L .84959 .66462 L .748 .959 .661 r
F
.85733 .65558 m .8367 .68316 L .84501 .67121 L F
.85733 .65558 m .84919 .64901 L .84922 .64902 L 0 .336 .815 r
F
.85339 .65914 m .85733 .65558 L .84938 .64909 L p .785 .445 .412 r
F P
0 g
s
.84942 .66902 m .83949 .68062 L p .85733 .65558 L .748 .959 .661 r
F P
0 g
s
.85733 .65558 m .8568 .65866 L .84942 .66902 L p .748 .959 .661 r
F P
0 g
s
.83533 .65326 m .8558 .65568 L .84026 .67804 L .291 .2 .577 r
F
.84054 .67343 m .8506 .66168 L .85339 .65914 L p .748 .959 .661 r
F P
0 g
s
.85339 .65914 m .85733 .65558 L p .85175 .66151 L .748 .959 .661 r
F P
0 g
s
.85175 .66151 m .84054 .67343 L .85339 .65914 L .748 .959 .661 r
F
.90014 .66093 m .84681 .71099 L p .84026 .67804 L .291 .2 .577 r
F P
0 g
s
.83533 .65326 m .84026 .67804 L .82922 .66399 L .291 .2 .577 r
F
.84026 .67804 m .84604 .7071 L .8367 .68316 L F
.84026 .67804 m .8367 .68316 L .82922 .66399 L F
.83313 .68385 m .84054 .67343 L p .85175 .66151 L .748 .959 .661 r
F P
0 g
s
.85733 .65558 m .84959 .66462 L .85175 .66151 L .748 .959 .661 r
F
.84959 .66462 m .83313 .68385 L .85175 .66151 L F
.8558 .65568 m .90014 .66093 L .84026 .67804 L .291 .2 .577 r
F
.88183 .61822 m .90014 .66093 L .8558 .65568 L F
.88183 .61822 m .8558 .65568 L .83533 .65326 L F
.4851 .35182 m .84938 .64909 L p .47959 .35012 L 0 .336 .815 r
F P
0 g
s
.84922 .64902 m .47959 .35012 L .84938 .64909 L 0 .336 .815 r
F
.46585 .33947 m .84005 .64499 L p .4537 .34329 L .556 .521 .772 r
F P
0 g
s
.83982 .64538 m .4537 .34329 L .84005 .64499 L .556 .521 .772 r
F
.83274 .68678 m .83313 .68385 L p .84959 .66462 L .748 .959 .661 r
F P
0 g
s
.84501 .67121 m .83274 .68678 L .84959 .66462 L .748 .959 .661 r
F
.83274 .68678 m .41279 .34146 L p .83401 .67626 L .784 .448 .419 r
F P
0 g
s
.83369 .65615 m .45207 .3438 L p .83982 .64538 L .556 .521 .772 r
F P
0 g
s
.45207 .3438 m .40244 .30318 L p .4537 .34329 L .556 .521 .772 r
F P
0 g
s
.83982 .64538 m .45207 .3438 L .4537 .34329 L .556 .521 .772 r
F
.46585 .33947 m .46823 .33872 L .46565 .33903 L .57 .807 .989 r
F
.46552 .33875 m .40799 .29222 L .45397 .32776 L 0 .336 .815 r
F
.4653 .33826 m .47736 .34016 L p .44986 .31867 L .789 .589 .63 r
F P
0 g
s
.41344 .29021 m .44181 .3165 L .44986 .31867 L .789 .589 .63 r
F
.44181 .3165 m .4653 .33826 L .44986 .31867 L F
.4653 .33826 m .45397 .32776 L .46406 .33556 L 0 .336 .815 r
F
.40799 .29222 m .40611 .28736 L .44181 .3165 L p F P
0 g
s
.44181 .3165 m .4634 .33411 L p .44941 .32354 L 0 .336 .815 r
F P
0 g
s
.44941 .32354 m .40799 .29222 L .44181 .3165 L 0 .336 .815 r
F
.44019 .31606 m .44085 .31624 L .40611 .28736 L .785 .445 .412 r
F
.46552 .33875 m .45397 .32776 L .4653 .33826 L 0 .336 .815 r
F
.42264 .33208 m .38796 .30237 L .41006 .33612 L .553 .52 .773 r
F
.41279 .34146 m .38443 .31814 L p .41398 .34167 L .784 .448 .419 r
F P
0 g
s
.46406 .33556 m .40799 .29222 L .4634 .33411 L 0 .336 .815 r
F
.41398 .34167 m .38443 .31814 L .41399 .34168 L .784 .448 .419 r
F
.38242 .31341 m .38443 .31814 L .41279 .34146 L p 0 .319 .803 r
F P
0 g
s
.41024 .33647 m .38242 .31341 L .41279 .34146 L 0 .319 .803 r
F
.834 .67625 m .41398 .34167 L .83393 .67605 L .784 .448 .419 r
F
.41398 .34167 m .41399 .34168 L .83393 .67605 L F
.43017 .34462 m .83393 .67605 L p .41399 .34168 L F P
0 g
s
.83274 .68678 m .83313 .68385 L .44685 .36636 L p 0 .319 .803 r
F P
0 g
s
.42576 .34382 m .46823 .33872 L .41098 .33792 L .57 .807 .989 r
F
.41279 .34146 m .41098 .33792 L .39191 .33766 L F
.42576 .34382 m .41098 .33792 L .41279 .34146 L F
.41006 .33612 m .38242 .31341 L p .41024 .33647 L 0 .319 .803 r
F P
0 g
s
.46823 .33872 m .42377 .33172 L p .40471 .33784 L .57 .807 .989 r
F P
0 g
s
.45207 .3438 m .46585 .33947 L .42576 .34382 L .57 .807 .989 r
F
.46585 .33947 m .46565 .33903 L .42576 .34382 L F
.45207 .3438 m .42576 .34382 L .43017 .34462 L F
.47315 .37642 m .43216 .34454 L .47353 .36137 L .683 .512 .648 r
F
.43216 .34454 m .44414 .3441 L .47353 .36137 L F
.83393 .67605 m .43017 .34462 L p .8337 .65679 L F P
0 g
s
.8337 .65679 m .43017 .34462 L .43216 .34454 L .683 .512 .648 r
F
.47353 .36137 m .83369 .65615 L p .47315 .37642 L F P
0 g
s
.8337 .65679 m .47315 .37642 L .83369 .65615 L .683 .512 .648 r
F
.83313 .68385 m .84054 .67343 L .42377 .33172 L p .553 .52 .773 r
F P
0 g
s
.42377 .33172 m .38796 .30237 L p .42264 .33208 L .553 .52 .773 r
F P
0 g
s
.83313 .68385 m .42377 .33172 L .42264 .33208 L .553 .52 .773 r
F
.39191 .33766 m .40471 .33784 L .42377 .33172 L .57 .807 .989 r
F
.42377 .33172 m .33245 .31735 L p .37944 .3334 L F P
0 g
s
.39191 .33766 m .42377 .33172 L .37944 .3334 L .57 .807 .989 r
F
.40611 .28736 m .40799 .29222 L .40244 .30318 L p .89 .969 .83 r
F P
0 g
s
.38796 .30237 m .39781 .29154 L .40611 .28736 L p .89 .969 .83 r
F P
0 g
s
.39781 .29154 m .38796 .30237 L .42377 .33172 L p .683 .511 .647 r
F P
0 g
s
.44181 .3165 m .42228 .31665 L .4653 .33826 L .789 .589 .63 r
F
.42184 .31227 m .39781 .29154 L .42377 .33172 L .683 .511 .647 r
F
.42228 .31665 m .3933 .31688 L .42318 .32575 L .789 .589 .63 r
F
.42228 .31665 m .42318 .32575 L .4653 .33826 L F
.40641 .32899 m .42377 .33172 L p .3933 .31688 L F P
0 g
s
.42377 .33172 m .4653 .33826 L p .42318 .32575 L .789 .589 .63 r
F P
0 g
s
.3933 .31688 m .42377 .33172 L .42318 .32575 L .789 .589 .63 r
F
.42173 .31109 m .39781 .29154 L p .42184 .31227 L .683 .511 .647 r
F P
0 g
s
.38259 .30055 m .33245 .31735 L .44181 .3165 L .789 .589 .63 r
F
.84054 .67343 m .8506 .66168 L .42173 .31109 L p .683 .511 .647 r
F P
0 g
s
.84054 .67343 m .42173 .31109 L .42184 .31227 L .683 .511 .647 r
F
.44353 .33098 m .42184 .31227 L .42377 .33172 L F
.45207 .3438 m .47353 .36137 L p .44414 .3441 L .683 .512 .648 r
F P
0 g
s
.42377 .33172 m .84054 .67343 L p .44353 .33098 L .683 .511 .647 r
F P
0 g
s
.44685 .36636 m .41006 .33612 L p .45176 .3709 L 0 .319 .803 r
F P
0 g
s
.45176 .3709 m .41006 .33612 L .41024 .33647 L 0 .319 .803 r
F
.83274 .68678 m .44685 .36636 L .45176 .3709 L F
.33245 .31735 m .40641 .32899 L p .3933 .31688 L .789 .589 .63 r
F P
0 g
s
.44181 .3165 m .40611 .28736 L p .44085 .31624 L .785 .445 .412 r
F P
0 g
s
.47959 .35012 m .46552 .33875 L .4851 .35182 L 0 .336 .815 r
F
.46552 .33875 m .46406 .33556 L .4851 .35182 L F
.47849 .34978 m .46585 .33947 L p .47959 .35012 L F P
0 g
s
.47959 .35012 m .46585 .33947 L .46552 .33875 L 0 .336 .815 r
F
.84922 .64902 m .47849 .34978 L .47959 .35012 L F
.84919 .64901 m .47849 .34978 L .84922 .64902 L F
.53575 .39654 m .47849 .34978 L p .52053 .38372 L F P
0 g
s
.84919 .64901 m .53575 .39654 L .52053 .38372 L 0 .336 .815 r
F
.84005 .64499 m .53575 .39654 L p .84919 .64901 L F P
0 g
s
.40611 .28736 m .39781 .29154 L .8506 .66168 L p .785 .445 .412 r
F P
0 g
s
.41344 .29021 m .38259 .30055 L .44181 .3165 L .789 .589 .63 r
F
.4634 .33411 m .4851 .35182 L p .46406 .33556 L 0 .336 .815 r
F P
0 g
s
.84938 .64909 m .44181 .3165 L p .85339 .65914 L .785 .445 .412 r
F P
0 g
s
.85339 .65914 m .44181 .3165 L .44085 .31624 L .785 .445 .412 r
F
.33381 .24463 m .33301 .2872 L p .41344 .29021 L .789 .589 .63 r
F P
0 g
s
.33301 .2872 m .33245 .31735 L p .38259 .30055 L .789 .589 .63 r
F P
0 g
s
.41344 .29021 m .33301 .2872 L .38259 .30055 L .789 .589 .63 r
F
.47737 .26879 m .371 .25089 L p .41344 .29021 L F P
0 g
s
.371 .25089 m .33381 .24463 L p .41344 .29021 L .789 .589 .63 r
F P
0 g
s
.8506 .66168 m .85339 .65914 L p .44085 .31624 L .785 .445 .412 r
F P
0 g
s
.8506 .66168 m .44085 .31624 L .44019 .31606 L .785 .445 .412 r
F
.455 .28891 m .47737 .26879 L .47736 .34016 L p .173 .096 .522 r
F P
0 g
s
.47736 .34016 m .47737 .26879 L p .41344 .29021 L .789 .589 .63 r
F P
0 g
s
.41006 .33612 m .83313 .68385 L p .42264 .33208 L .553 .52 .773 r
F P
0 g
s
.31213 .33717 m .37609 .34702 L p .39191 .33766 L .57 .807 .989 r
F P
0 g
s
.39838 .33987 m .39191 .33766 L .37609 .34702 L .57 .807 .989 r
F
.33245 .31735 m .32425 .32535 L p .39191 .33766 L F P
0 g
s
.32425 .32535 m .31213 .33717 L p .39191 .33766 L .57 .807 .989 r
F P
0 g
s
.41279 .34146 m .83274 .68678 L p .41024 .33647 L 0 .319 .803 r
F P
0 g
s
.8367 .68316 m .83274 .68678 L p .84501 .67121 L .748 .959 .661 r
F P
0 g
s
.83406 .68697 m .84681 .71099 L .8341 .69095 L .291 .2 .577 r
F
.8365 .68345 m .84681 .71099 L .83406 .68697 L F
.84681 .71099 m .83432 .70984 L p .8341 .69095 L F P
0 g
s
.83432 .70984 m .79458 .70616 L p .8341 .69095 L .291 .2 .577 r
F P
0 g
s
.78209 .38551 m .7862 .49095 L .77483 .46251 L .291 .2 .577 r
F
0 g
.008 w
.59171 .34788 m
.73484 .37063 L
s
.47736 .3297 m
.59171 .34788 L
s
.39193 .28799 m
.41701 .29209 L
s
.41701 .29209 m
.43195 .29453 L
s
.43195 .29453 m
.44621 .29685 L
s
.44621 .29685 m
.47966 .30232 L
s
.47966 .30232 m
.49907 .30548 L
s
.49907 .30548 m
.76671 .34917 L
s
.73023 .37374 m
.74872 .36129 L
s
.70763 .38895 m
.73023 .37374 L
s
.82633 .72834 m
.85787 .71555 L
s
.71889 .77193 m
.82633 .72834 L
s
.5 Mabswid
.95634 .56917 m .91818 .66302 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.96601 .45955 m .95634 .56917 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.94437 .36913 m .96601 .45955 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.89973 .32401 m .94437 .36913 L p .79863 .38812 L .297 .205 .579 r
F P
0 g
s
.79863 .38812 m .84641 .33273 L .89973 .32401 L p .297 .205 .579 r
F P
0 g
s
.84641 .33273 m .79863 .38812 L .78209 .38551 L p .684 .784 .926 r
F P
0 g
s
.78209 .38551 m .82953 .32989 L .84641 .33273 L p .684 .784 .926 r
F P
0 g
s
.93812 .56676 m .90014 .66093 L p .78209 .38551 L .291 .2 .577 r
F P
0 g
s
.94788 .45682 m .93812 .56676 L p .78209 .38551 L .291 .2 .577 r
F P
0 g
s
.92657 .3662 m .94788 .45682 L p .78209 .38551 L .291 .2 .577 r
F P
0 g
s
.89973 .32401 m .84641 .33273 L .82953 .32989 L p .26 .723 .95 r
F P
0 g
s
.82953 .32989 m .88239 .32105 L .89973 .32401 L p .26 .723 .95 r
F P
0 g
s
.88239 .32105 m .92657 .3662 L p .78209 .38551 L .291 .2 .577 r
F P
0 g
s
.78209 .38551 m .82953 .32989 L .88239 .32105 L p .291 .2 .577 r
F P
0 g
s
.008 w
.74872 .36129 m
.82827 .30773 L
s
.85187 .29183 m
.92898 .23991 L
s
.82827 .30773 m
.85187 .29183 L
s
.5 Mabswid
.33381 .24463 m .31365 .26563 L .31213 .33717 L p .092 .025 .48 r
F P
0 g
s
.008 w
.1056 .2706 m
.31091 .30324 L
s
.31091 .30324 m
.31285 .30354 L
s
.08845 .29276 m
.29023 .32411 L
s
.29023 .32411 m
.31233 .32754 L
s
.3352 .27873 m
.39193 .28799 L
s
.5 Mabswid
.31213 .33717 m .33245 .31735 L .33381 .24463 L p .092 .025 .48 r
F P
0 g
s
.008 w
.12576 .24454 m
.3352 .27873 L
s
.22979 .1101 m
.08845 .29276 L
s
.5 Mabswid
.81176 .70799 m .86447 .71287 L .84681 .71099 L p 0 .527 .718 r
F P
0 g
s
.84681 .71099 m .79458 .70616 L .81176 .70799 L p 0 .527 .718 r
F P
0 g
s
.008 w
.65984 .4913 m
.67953 .49401 L
s
.67953 .49401 m
.70892 .49807 L
s
.70892 .49807 m
.75345 .50421 L
s
.75345 .50421 m
.78986 .50924 L
s
.78986 .50924 m
.83797 .51588 L
s
.5 Mabswid
.94437 .36913 m .89973 .32401 L .88239 .32105 L p .668 .175 .07 r
F P
0 g
s
.88239 .32105 m .92657 .3662 L .94437 .36913 L p .668 .175 .07 r
F P
0 g
s
.008 w
.92898 .23991 m
.9361 .36077 L
s
.92898 .23991 m
.22979 .1101 L
s
.5 Mabswid
.86447 .71287 m .91818 .66302 L .90014 .66093 L p .656 .821 .962 r
F P
0 g
s
.90014 .66093 m .84681 .71099 L .86447 .71287 L p .656 .821 .962 r
F P
0 g
s
.008 w
.85787 .71555 m
.86447 .71287 L
s
.86447 .71287 m
.95466 .67628 L
s
.5 Mabswid
.96601 .45955 m .94437 .36913 L .92657 .3662 L p .796 .517 .515 r
F P
0 g
s
.008 w
.93801 .39327 m
.9397 .42205 L
s
.5 Mabswid
.92657 .3662 m .94788 .45682 L .96601 .45955 L p .796 .517 .515 r
F P
0 g
s
.91818 .66302 m .95634 .56917 L .93812 .56676 L p .769 .734 .82 r
F P
0 g
s
.008 w
.94937 .58632 m
.95466 .67628 L
s
.94419 .49834 m
.9483 .5681 L
s
.5 Mabswid
.93812 .56676 m .90014 .66093 L .91818 .66302 L p .769 .734 .82 r
F P
0 g
s
.95634 .56917 m .96601 .45955 L .94788 .45682 L p .798 .644 .69 r
F P
0 g
s
.94788 .45682 m .93812 .56676 L .95634 .56917 L p .798 .644 .69 r
F P
0 g
s
.25 Mabswid
.03011 .25029 m
.20328 0 L
s
.20328 0 m
.18032 .62178 L
s
.18032 .62178 m
0 .76713 L
s
0 .76713 m
.03011 .25029 L
s
.96419 .15308 m
.20328 0 L
s
.20328 0 m
.18032 .62178 L
s
.18032 .62178 m
1 .71121 L
s
1 .71121 m
.96419 .15308 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280.438, 231.688},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000ia000`40O003h00O>7oo0`00gGoo000g
Ool20002Ool5003HOol003Moo`8000Moo`D00==oo`00=Woo00<007oo000037oo1@00cWoo000eOol0
1000Oomoo`004Goo1@00bGoo000eOol01000Oomoo`005Woo1@00a7oo000dOol01@00Oomoogoo0000
6goo1@00_goo000cOol00`00Oomoo`02Ool00`00Oomoo`0NOol5002jOol003=oo`03001oogoo009o
o`03001oogoo02=oo`D00;Eoo`00<Woo00<007ooOol00goo00<007ooOol0:7oo1@00/7oo000aOol0
0`00Oomoo`04Ool00`00Oomoo`0]Ool5002[Ool0031oo`03001oogoo00Eoo`03001oogoo039oo`@0
0:Moo`00<7oo00<007ooOol01Goo00<007ooOol0=Woo1@00XWoo000_Ool00`00Oomoo`06Ool00`00
Oomoo`0kOol5002MOol002ioo`03001oogoo00Moo`03001oogoo041oo`D009Qoo`00;Woo00<007oo
Ool01Woo00<007ooOol0AWoo1@00Tgoo000]Ool00`00Oomoo`07Ool00`00Oomoo`1;Ool5002>Ool0
02aoo`03001oogoo00Qoo`03001oogoo051oo`D008Uoo`00;7oo00<007ooOol027oo00<007ooOol0
EGoo1@00Q7oo000[Ool00`00Oomoo`09Ool00`00Oomoo`1JOol5001oOol002Yoo`03001oogoo00Yo
o`03001oogoo05moo`D007Yoo`00:Woo00<007ooOol02Woo00<007ooOol0I7oo1@00MGoo000YOol0
0`00Oomoo`0;Ool00`00Oomoo`1YOol5001`Ool002Qoo`03001oogoo00aoo`03001oogoo06ioo`D0
06]oo`00:7oo00<007ooOol037oo00<007ooOol0Lgoo1@00IWoo000WOol00`00Oomoo`0=Ool00`00
Oomoo`1hOol5001QOol002Ioo`03001oogoo00ioo`03001oogoo07eoo`D005aoo`009Goo00<007oo
Ool03goo00<007ooOol0PWoo1@00Egoo000UOol00`00Oomoo`0?Ool00`00Oomoo`27Ool5001BOol0
02Aoo`03001oogoo011oo`03001oogoo08aoo`D004eoo`008goo00<007ooOol04Goo00<007ooOol0
1Goo0P00RWoo1@00B7oo000SOol00`00Oomoo`0AOol00`00Oomoo`05Ool7002:Ool50013Ool0029o
o`03001oogoo019oo`03001oogoo00Aoo`d008Yoo`@003moo`008Goo00<007ooOol04goo00<007oo
Ool017oo0P001Woo2`00R7oo1@00>Woo000QOol00`00Oomoo`0COol00`00Oomoo`03Ool2000<Ool;
0028Ool5000eOol0021oo`03001oogoo01Aoo`03001oogoo009oo`<0019oo`/008Moo`D0031oo`00
7goo00<007ooOol05Goo00@007ooOomoo`<001Qoo`/008Moo`D002]oo`007goo00<007ooOol05Goo
00@007ooOomoo`8001moo`X008Moo`D002Ioo`007Woo00<007ooOol05Woo00<007ooOol00P009Goo
2`00QWoo1@008Goo000MOol00`00Oomoo`0GOol00`00Ool00002000ZOol;0026Ool5000LOol001eo
o`03001oogoo01Moo`@0035oo`/008Eoo`D001Moo`0077oo00<007ooOol067oo0`00=goo2`00QGoo
1@004Woo000KOol00`00Oomoo`0IOol2000nOol;0024Ool5000=Ool001]oo`03001oogoo01Qoo`80
04Aoo`/008Aoo`<000Yoo`006Woo00<007ooOol067oo0`00BWoo2P00Ogoo0`002Woo000IOol00`00
Oomoo`0HOol3001@Ool;001hOol01000Oomoo`002Woo000HOol00`00Oomoo`0HOol4001EOol;001b
Ool01@00Oomoogoo00002Woo000HOol00`00Oomoo`0HOol200000goo001oo`1JOol;001ZOol20004
Ool00`00Oomoo`08Ool001Moo`03001oogoo01Qoo`80009oo`03001oogoo05ioo`/006Aoo`03001o
ogoo00Aoo`03001oogoo00Qoo`005Woo00<007ooOol067oo0`000Woo00<007ooOol0I7oo2P00GGoo
0P001goo00<007ooOol027oo000FOol00`00Oomoo`0GOol30003Ool00`00Oomoo`1YOol;001FOol0
0`00Oomoo`07Ool00`00Oomoo`08Ool001Eoo`03001oogoo01Qoo`8000Aoo`03001oogoo06ioo`/0
051oo`03001oogoo00Uoo`03001oogoo00Moo`0057oo00<007ooOol067oo0P001Goo00<007ooOol0
M7oo2`00B7oo0P0037oo00<007ooOol01goo000DOol00`00Oomoo`0GOol30005Ool00`00Oomoo`1i
Ool;0012Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool001=oo`03001oogoo01Moo`<000Ioo`03001o
ogoo07moo`X003]oo`8000moo`03001oogoo00Moo`004Woo00<007ooOol05goo0`001goo00<007oo
Ool0Q7oo2`00=7oo00<007ooOol03goo00<007ooOol01goo000BOol00`00Oomoo`0GOol20008Ool0
0`00Oomoo`29Ool;000]Ool2000BOol00`00Oomoo`07Ool0015oo`03001oogoo01Moo`8000Uoo`03
001oogoo08moo`/002Ioo`03001oogoo019oo`03001oogoo00Moo`0047oo00<007ooOol05goo0`00
2Goo00<007ooOol0U7oo2`0087oo00<007ooOol04goo00<007ooOol01goo000@Ool00`00Oomoo`0F
Ool3000:Ool00`00Oomoo`2JOol;000HOol2000FOol00`00Oomoo`07Ool000moo`03001oogoo01Io
o`<000]oo`03001oogoo09moo`/0019oo`03001oogoo01Ioo`03001oogoo00Moo`003Woo00<007oo
Ool05goo0P0037oo00<007ooOol0YGoo2P002goo0P006Goo00<007ooOol01goo000=Ool00`00Oomo
o`0GOol2000=Ool00`00Oomoo`2ZOol;0004Ool00`00Oomoo`0IOol00`00Oomoo`07Ool000eoo`03
001oogoo01Ioo`<000eoo`03001oogoo0:moo`/001]oo`03001oogoo00Moo`0037oo00<007ooOol0
5Woo0`003Woo00<007ooOol0]Goo2`005Goo00<007ooOol01goo000;Ool00`00Oomoo`0GOol2000?
Ool00`00Oomoo`2eOol00`00Oomoo`02Ool;000@Ool00`00Oomoo`07Ool000]oo`03001oogoo01Io
o`80011oo`03001oogoo0;=oo`8000]oo`/000Yoo`03001oogoo00Moo`002Woo00<007ooOol05Goo
100047oo00<007ooOol0/Woo00<007ooOol047oo1`002Woo00<007ooOol01Woo0009Ool00`00Oomo
o`0FOol7000=Ool00`00Oomoo`0TOol3002:Ool00`00Oomoo`0COol5000:Ool00`00Oomoo`06Ool0
00Uoo`03001oogoo01Eoo`h000Moo`03001oogoo02=oo`80009VE0H0089oo`8001Aoo`@00003Ool0
000000Yoo`03001oogoo00Ioo`0027oo10005Goo0P001Woo300000=oo`00Ool08goo00<000P?0000
1fID1`00Ngoo00<007ooOol04goo10000Woo0P002Woo00<007ooOol01Woo0008Ool01000Oomoogoo
1P003Woo0P003Goo30007goo00@000P?20l000aVE0L007Aoo`8001Aoo`@000Aoo`8000Yoo`03001o
ogoo00Ioo`0027oo00<007ooOol01goo1P001goo0`004goo2`006Goo00D000P?20l83`00019VE0L0
06eoo`03001oogoo01=oo`@000Eoo`8000Yoo`03001oogoo00Ioo`0027oo00<007ooOol03Goo2@00
57oo00<007ooOol00goo2`004Woo00<000P?20l00PP?00<006IDIU@05VID1`00IGoo0P0057oo1000
1goo0P002Woo00<007ooOol01Woo0008Ool00`00Oomoo`0AOol9000@Ool00`00Oomoo`08Ool<000;
Ool00`0020l83`0320l00`00IUAVE00LIU@7001NOol00`00Oomoo`0BOol50008Ool2000:Ool00`00
Oomoo`06Ool000Qoo`03001oogoo015oo`P00003Ool0000000@000Yoo`03001oogoo00ioo``000Eo
o`0300083`P?00<83`03001VE6ID029VE0@005Yoo`03001oogoo019oo`@000Yoo`8000Yoo`03001o
ogoo00Ioo`0027oo00<007ooOol04Goo3P0000=oo`000000100017oo00<007ooOol057oo30001@P?
00<006IDIU@09FID00<007ooOol0EWoo0P004goo100037oo0P002Woo00<007ooOol01Woo0008Ool0
0`00Oomoo`0@Ool30006Ool<00000goo00000005000JOol<000WIU@00`00Oomoo`1EOol00`00Oomo
o`0BOol4000=Ool2000:Ool00`00Oomoo`06Ool000Qoo`03001oogoo00moo`<000eoo`d00003Ool0
000000@001Uoo`h0021VE003001oogoo05=oo`8001=oo`@000moo`8000Yoo`03001oogoo00Ioo`00
1goo00<007ooOol047oo0P0057oo3@0000=oo`00000010004goo00<000P?20l00PP?4@0066ID00<0
07ooOol0DWoo00<007ooOol04Woo100047oo0P002Woo00<007ooOol01Woo0007Ool00`00Oomoo`0?
Ool2000JOol00`00Ool0000B000=Ool00`0020l83`0220l20007IU@@000@IU@00`00Oomoo`1AOol0
0`00Oomoo`0AOol4000BOol2000:Ool00`00Oomoo`06Ool000Moo`03001oogoo00eoo`@001Yoo`03
001oogoo00Eooa@000Ioo`0300083`P?00883`8000mVE0/000eVE003001oogoo04moo`8001=oo`@0
01=oo`8000Yoo`03001oogoo00Ioo`001goo00<007ooOol03Goo2@005Goo00<007ooOol037oo3000
00=oo`0000001@0010P?0P005VID2@0026ID00<007ooOol0CWoo00<007ooOol04Woo0`005Goo0P00
2goo00<007ooOol01Goo0007Ool00`00Oomoo`0>Ool?000>Ool00`00Oomoo`0BOol>000420l2000J
IU@>001>Ool2000COol4000FOol2000;Ool00`00Oomoo`05Ool000Moo`03001oogoo01Ioo`h000Mo
o`03001oogoo01Qoo`P000@83`03001VE6ID01eVE10004Moo`03001oogoo019oo`@001Moo`8000]o
o`03001oogoo00Eoo`001goo00<007ooOol07Goo3`0087oo0`000`P?00<006IDIU@09VID3@00@7oo
00<007ooOol04Woo0`006Woo0P002Woo00<007ooOol01Goo0007Ool00`00Oomoo`0TOol>000KOol0
0`0020l83`0220l00`00IUAVE00JIU@00`00IUAVE009IU@00`00Oomoo`04Ool<000hOol2000DOol3
000KOol2000:Ool00`00Oomoo`05Ool000Moo`03001oogoo02]oo`h001Aoo`0300083`P?00883`03
001VE6ID01IVE08000=VE003001VE6ID00QVE003001oogoo00Yoo``0035oo`03001oogoo019oo`@0
01aoo`8000Yoo`03001oogoo00Eoo`001goo00<007ooOol0:goo00<007ooOol017oo3P003Goo00<0
00P?20l00PP?0`005fID00=F500000000VG=00<006IDIU@01fID00<007ooOol047oo3@00:7oo0P00
57oo10007Goo0P002Woo00<007ooOol01Goo0007Ool00`00Oomoo`0[Ool00`00Oomoo`0;Ool?0005
Ool01@0020l83`P?00000d/o1@004VID0UHD0P000VG=00<006IDIU@01VID00<007ooOol05Woo3@00
8Goo00<007ooOol04Woo10003goo1@002goo0P002Woo00<007ooOol01Goo0007Ool00`00Oomoo`0[
Ool00`00Oomoo`0BOol>000220l20008Bcl6000<IU@3EQ@20002ILd20006IU@4000LOol<000IOol2
000DOol4000;Ool500039=800`00E:8000020008Ool2000:Ool00`00Oomoo`05Ool000Moo`03001o
ogoo02]oo`03001oogoo01Yoo`H0000320l0000000m;?`D000MVE0AF5080009Uc@03IU@006ID00=V
E08000=oo`H001aoo``0019oo`03001oogoo019oo`@000Qoo`D000TTdP05001DXUBRE:800007Ool2
000:Ool00`00Oomoo`05Ool000Moo`03001oogoo02]oo`03001oogoo01moo`0300083`0001E;?`P0
00AF508000=Uc@04000DL6IDIU@80003Ool7000KOol<000;Ool00`00Oomoo`0BOol40006Ool3000?
9=801@00E:9DXUBR00001Woo0P002Woo00<007ooOol01Goo0007Ool00`00Oomoo`0[Ool00`00Oomo
o`0OOol2000MBcl00dHH001F5004EQ@20002ILd01000IUAVE6ID3@0017oo1P006goo3@000Woo0P00
4goo10001goo00<002CB9=804BCB00D005BRE:9DXP0000Eoo`8000Yoo`03001oogoo00Eoo`001goo
00<007ooOol0:goo00<007ooOol07goo00<004/oBcl064/o00<004HHAQP00dHH0P0015HD0P000VG=
0P0000=VE000Ool01Goo3@000goo1P006goo3@0047oo10001goo00<002CB9=804bCB00D005BRE:9D
XP0000Aoo`8000Yoo`03001oogoo00Eoo`001goo00<007ooOol0:goo00<007ooOol08Woo1P003d/o
00EVE4/oBcm;?`0000I66003001F55HD009F5080009Uc@<000aoo`d000=oo`L001Yoo`d000Qoo`@0
00Qoo`03000TdRCB01DTdP05001DXUBRE:800003Ool2000:Ool00`00Oomoo`05Ool000Moo`03001o
ogoo02]oo`03001oogoo02Qoo`H000i;?`8000E66003001F55HD009F5080009Uc@8001=oo`d000=o
o`H001=oo`03001oogoo00Eoo``00003Ool00000008000Uoo`03000TdRCB01DTdP03001DXUBR009D
XP03001oogoo008000Yoo`03001oogoo00Eoo`001Woo00<007ooOol0;7oo00<007ooOol0;Woo1`00
24/o0P001DHH00<005HDEQ@00UHD0P000fG=00<007ooOol05Woo3@000goo1P0037oo00<007ooOol0
37oo2@002Woo00<002CB9=805bCB00D005BRE:9DXP00009oo`8000Yoo`03001oogoo00Eoo`001Woo
00<007ooOol0;7oo00<007ooOol0=Goo1`000d/o00<004HHAQP00dHH00<005HDEQ@00UHD0`000VG=
1@006Goo3P000Woo1P0017oo0P004goo10002Woo00<002CB9=806BCB00H005BRE:9DXP00Ool2000;
Ool00`00Oomoo`04Ool000Ioo`03001oogoo02aoo`03001oogoo03aoo`D000E6608000AF508000=U
c@T001Yoo`d0009oo`@001=oo`@000]oo`03000TdRCB01/TdP04001DXUBRE:83000;Ool00`00Oomo
o`04Ool000Ioo`03001oogoo02aoo`03001oogoo045oo`03001664HH00A66003001F55HD009F5080
009Uc@800003Ool0000000/001Yoo`d0015oo`@000]oo`03000TdRCB01dTdP04001DXUBRE:82000;
Ool00`00Oomoo`04Ool000Ioo`03001oogoo02]oo`03001oogoo04=oo`8000E66003001F55HD009F
5080009Uc@8000Ioo`d001Yoo`h000Qoo`@000aoo`03000TdRCB01lTdP04001DXUBRE:82000:Ool0
0`00Oomoo`04Ool000Ioo`03001oogoo02]oo`03001oogoo04Aoo`8000E66003001F55HD009F50<0
0003ILd0000000aoo`d001Qoo`03001oo`00014000aoo`03000TdRCB024TdPD000Yoo`03001oogoo
00Aoo`001Woo00<007ooOol0:goo00<007ooOol0AWoo00<004HHAQP00dHH00<005HDEQ@00UHD0`00
0VG=00<007ooOol03goo3@004Woo00<007ooOol01Woo2@003Goo00<002CB9=808RCB00<006H@IQ00
0`002Goo00<007ooOol017oo0006Ool00`00Oomoo`0[Ool00`00Oomoo`17Ool00`00AQQ66003AQP2
0004EQ@20003ILd00`00Oomoo`0DOol<000<Ool00`00Oomoo`08Ool5000?Ool00`009=8TdP0R9=80
0`00IQ1V4002IQ000`00Oomoo`07Ool00`00Oomoo`04Ool000Ioo`03001oogoo02]oo`03001oogoo
04Qoo`03001664HH00A66003001F55HD009F508000=Uc@03001oogoo01Uoo`d000Eoo`03001oogoo
00Moo`@0011oo`03000TdRCB02@TdP05001V46H@IQ000009Ool00`00Oomoo`04Ool000Ioo`03001o
ogoo02]oo`03001oogoo04Uoo`8000E66003001F55HD009F5080009Uc@030EX007oo01moo`d000Qo
o`<0015oo`03000TdRCB02DTdP03001V46H@009V4003001oogoo00Ioo`03001oogoo00Aoo`001Woo
00<007ooOol0:goo00<007ooOol0BWoo0P001DHH00<005HDEQ@00UHD0`0000=Uc@0000009Woo4000
4Goo00<002CB9=809RCB00<006H@IQ000VH@00<007ooOol01Woo00<007ooOol017oo0006Ool00`00
Oomoo`0[Ool00`00Oomoo`1<Ool00`00AQQ66003AQP00`00EQAF5003EQ@20002ILd2000YOol:000B
OolY9=800`00IQ1V4002IQ000`00Oomoo`06Ool00`00Oomoo`04Ool000Ioo`03001oogoo02]oo`03
001oogoo04eoo`03001664HH00=6608000AF508000=Uc@03001oogoo02Ioo`03001oogoo00Aoo`80
019oo`03000TdRCB02PTdP05001V46H@IQ000008Ool00`00Oomoo`04Ool000Ioo`03001oogoo02]o
o`03001oogoo04ioo`8000E66003001F55HD009F508000=Uc@03001oogoo02Eoo`03001oogoo00Ao
o`80019oo`03000TdRCB02PTdP03001V46H@009V4003001oogoo00Eoo`03001oogoo00Aoo`001Woo
00<007ooOol0:goo00<007ooOol0Cgoo0P001DHH00<005HDEQ@00UHD0P000VG=0P009Woo00<007oo
Ool017oo0P004Goo00<002CB9=80:BCB00<006H@00000VH@00<007ooOol01Goo00<007ooOol017oo
0006Ool00`00Oomoo`0[Ool00`00Oomoo`1@Ool20005AQP00`00EQAF5002EQ@3000016G=0EX00000
97oo00<007ooOol017oo0P004Goo00<002CB9=80:BCB00<006H@IQ000VH@00<007ooOol01Goo00<0
07ooOol017oo0006Ool00`00Oomoo`0[Ool00`00Oomoo`1BOol00`00AQQ66003AQP00`00EQAF5003
EQ@2000016G=001Uc@008goo00<007ooOol017oo0P004Goo00<002CB9=80:RCB00D006H@IQ1V4000
00Qoo`03001oogoo00=oo`001Woo00<007ooOol0:goo00<007ooOol0Dgoo00<004HHAQP00dHH0P00
15HD0P000fG=00<007ooOol087oo00<007ooOol017oo0P0047oo00<002CB9=80:bCB00<006H@IQ00
0VH@00<007ooOol01Goo00<007ooOol00goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`1DOol20005
AQP00`00EQAF5002EQ@20003ILd00`00Oomoo`0OOol00`00Oomoo`04Ool2000@Ool00`009=8TdP0[
9=800`00IQ1V4002IQ000`00Oomoo`05Ool00`00Oomoo`03Ool000Eoo`03001oogoo02aoo`03001o
ogoo05Eoo`8000E66003001F55HD009F50<0009Uc@03001oogoo01ioo`03001oogoo00Aoo`80011o
o`03000TdRCB02/TdP03001V46H@009V4003001oogoo00Eoo`03001oogoo00=oo`001Goo00<007oo
Ool0;7oo00<007ooOol0EWoo0P001DHH00<005HDEQ@00eHD0P0000AUc@00000001ioo`03001oogoo
00Aoo`8000moo`03000TdRCB02`TdP8000=V4003001oogoo00Eoo`03001oogoo00=oo`001Goo00<0
07ooOol0;7oo00<007ooOol0F7oo00<004HHAQP00dHH0P0015HD0P0000AUc@00ILd001eoo`03001o
ogoo00Aoo`8000moo`03000TdRCB02`TdP8000AV4003001oogoo00Aoo`03001oogoo00=oo`001Goo
00<007ooOol0;7oo00<007ooOol0FGoo0P001DHH00<005HDEQ@00UHD0P000fG=00<007ooOol06Woo
00<007ooOol017oo0P003Woo00<002CB9=80;RCB00<006H@IQ000VH@00<007ooOol017oo00<007oo
Ool00goo0005Ool00`00Oomoo`0/Ool00`00Oomoo`1JOol20005AQP00`00EQAF5002EQ@20003ILd0
0`00Oomoo`0IOol00`00Oomoo`04Ool2000>Ool00`009=8TdP0^9=800`00IQ1V4002IQ000`00Oomo
o`04Ool00`00Oomoo`03Ool000Eoo`03001oogoo02aoo`03001oogoo05]oo`8000E66003001F55HD
00=F5080009Uc@8001Yoo`03001oogoo00=oo`8000ioo`03000TdRCB02lTdP05001V46H@IQ000006
Ool00`00Oomoo`03Ool000Eoo`03001oogoo02aoo`03001oogoo05aoo`8000E66003001F55HD00=F
508000=Uc@03001oogoo01Moo`03001oogoo00=oo`8000eoo`03000TdRCB030TdP03001V46H@009V
4003001oogoo00=oo`03001oogoo00=oo`001Goo00<007ooOol0;7oo00<007ooOol0GWoo00<004HH
AQP00dHH0P0015HD0P0000AUc@00ILd001Qoo`03001oogoo00=oo`8000eoo`03000TdRCB030TdP03
001V46H@009V4003001oogoo00=oo`03001oogoo00=oo`001Goo00<007ooOol0;7oo00<007ooOol0
Ggoo0P001DHH00<005HDEQ@00UHD0P0000AUc@00ILd001Moo`03001oogoo00=oo`8000eoo`03000T
dRCB030TdP03001V46H@009V4003001oogoo00=oo`03001oogoo00=oo`001Goo00<007ooOol0;7oo
00<007ooOol0H7oo0P001DHH00<005HDEQ@00UHD0P000fG=00<007ooOol057oo00<007ooOol00goo
0P0037oo00<002CB9=80<RCB00D006H@IQ1V400000Eoo`03001oogoo00=oo`001Goo00<007ooOol0
;7oo00<007ooOol0HGoo0P001DHH00<005HDEQ@00eHD0P000VG=0P0057oo00<007ooOol00goo0P00
37oo00<002CB9=80<RCB00<006H@IQ000VH@00<007ooOol00Woo00<007ooOol00goo0005Ool00`00
Oomoo`0/Ool00`00Oomoo`1ROol20005AQP00`00EQAF5003EQ@20003ILd00`00Oomoo`0AOol00`00
Oomoo`03Ool2000;Ool00`009=8TdP0c9=830002IQ000`00Oomoo`02Ool00`00Oomoo`03Ool000Eo
o`03001oogoo02aoo`03001oogoo06Aoo`03001664HH00=6608000AF50800004ILd006G=000BOol0
0`00Oomoo`03Ool2000;Ool00`009=8TdP0c9=800`00IYIVUP030004Ool00`00Oomoo`03Ool000Eo
o`03001oogoo02aoo`03001oogoo06Eoo`8000E66003001F55HD009F50800004ILd006G=000AOol0
0`00Oomoo`03Ool2000;Ool00`009=8TdP0c9=800`00IYIVUP02IYH00`00Oomoo`03Ool00`00Oomo
o`02Ool000Eoo`03001oogoo02]oo`03001oogoo06Moo`8000E66003001F55HD00=F5004001UcFG=
ILd2000?Ool00`00Oomoo`03Ool2000:Ool00`009=8TdP0d9=800`00IYIVUP02IYH00`00Oomoo`03
Ool00`00Oomoo`02Ool000Eoo`03001oogoo02]oo`03001oogoo06Qoo`8000E66003001F55HD00=F
508000=Uc@03001oogoo00aoo`03001oogoo00=oo`8000Yoo`03000TdRCB03@TdP03001VUVJF009V
UP03001oogoo00=oo`03001oogoo009oo`001Goo00<007ooOol0:goo00<007ooOol0JWoo00<004HH
AQP00dHH00<005HDEQ@00eHD0P000fG=00<007ooOol02goo00<007ooOol00goo0P002Woo00<002CB
9=80=2CB00<006JFIYH00VJF00<007ooOol00goo00<007ooOol00Woo0004Ool00`00Oomoo`0/Ool0
0`00Oomoo`1[Ool20004AQP20004EQ@20003ILd00`00Oomoo`0:Ool00`00Oomoo`03Ool2000:Ool0
0`009=8TdP0d9=800`00IYIVUP02IYH00`00Oomoo`03Ool00`00Oomoo`02Ool000Aoo`03001oogoo
02aoo`03001oogoo06aoo`8000E66003001F55HD009F50800004ILd006G=000;Ool00`00Oomoo`03
Ool2000:Ool00`009=8TdP0d9=800`00IYIVUP02IYH00`00Oomoo`03Ool00`00Oomoo`02Ool000Ao
o`03001oogoo02aoo`03001oogoo06eoo`8000E66003001F55HD00=F50<00003ILd0000000Uoo`03
001oogoo00=oo`8000Yoo`03000TdRCB03<TdP03001VUVJF00=VUP03001oogoo00=oo`03001oogoo
009oo`0017oo00<007ooOol0;7oo00<007ooOol0KWoo0P001DHH00<005HDEQ@00eHD0P000fG=0P00
1goo00<007ooOol00goo0P002Woo00<002CB9=80<bCB00<006JFIYH00VJF00<007ooOol017oo00<0
07ooOol00Woo0004Ool00`00Oomoo`0/Ool00`00Oomoo`1`Ool00`00AQQ66003AQP00`00EQAF5003
EQ@20003ILd700000goo001oo`04Ool2000:Ool00`009=8TdP0c9=800`00IYIVUP02IYH00`00Oomo
o`04Ool00`00Oomoo`02Ool000Aoo`03001oogoo02aoo`03001oogoo075oo`8000A6608000AF5080
00=Uc@l000Uoo`03000TdRCB03@TdP03001VUVJF009VUP03001oogoo00Aoo`03001oogoo009oo`00
17oo00<007ooOol0;7oo00<007ooOol0LWoo0P001DHH00<005HDEQ@00eHD00@006G=ILeUc@8000=o
o`h000Aoo`03000TdRCB03<TdP8000AVUP03001oogoo00Aoo`03001oogoo009oo`0017oo00<007oo
Ool0;7oo00<007ooOol0Lgoo0P001DHH00<005HDEQ@00eHD0P0000A666G=ILd000=oo`03001oogoo
00=oo`h003@TdP03001VUVJF009VUP03001oogoo00Aoo`03001oogoo009oo`0017oo00<007ooOol0
;7oo00<007ooOol0M7oo0P001DHH00<005HDEQ@00eHD0P000fG=00@007ooOol000Eoo`8000Eooa00
02/TdP03001VUVJF009VUP03001oogoo00Aoo`03001oogoo009oo`0017oo00<007ooOol0;7oo00<0
07ooOol0MWoo00<004HHAQP00dHH0P0015HD0P000fG=00<007oo00001Goo0P002Goo00<002CB0000
400092CB00<006JFIYH00VJF00<007ooOol017oo00<007ooOol00Woo0004Ool00`00Oomoo`0/Ool0
0`00Oomoo`1gOol20005AQP00`00EQAF5002EQ@20003ILd20005Ool20009Ool00`009=8TdP099=8?
000L9=800`00IYIVUP02IYH00`00Oomoo`04Ool00`00Oomoo`02Ool000Aoo`03001oogoo02aoo`03
001oogoo07Qoo`8000E66003001F55HD00=F5003001UcFG=009Uc@03001oogoo00=oo`8000Qoo`03
000TdRCB010TdPP001`TdP03001VUVJF009VUP03001oogoo00Eoo`03001oogoo005oo`0017oo00<0
07ooOol0;7oo00<007ooOol0NGoo0P001DHH00<005HDEQ@00eHD0P000fG=00<007ooOol00Woo0P00
27oo00<002CB9=80=2CB00<006JFIYH00VJF00<007ooOol01Goo00<007ooOol00Goo0004Ool00`00
Oomoo`0/Ool00`00Oomoo`1jOol20005AQP00`00EQAF5003EQ@2000014HHILeUc@000goo0P0027oo
00<002CB9=80=2CB00<006JFIYH00VJF00<007ooOol01Goo00<007ooOol00Goo0004Ool00`00Oomo
o`0/Ool00`00Oomoo`1lOol20004AQP20004EQ@20003ILd00`00Oomoo`020008Ool00`009=8TdP0d
9=800`00IYIVUP02IYH00`00Oomoo`05Ool00`00Oomoo`01Ool000Aoo`03001oogoo02aoo`03001o
ogoo07eoo`8000E66003001F55HD00=F5004001UcFG=ILd40008Ool00`009=8TdP0d9=800`00IYIV
UP02IYH00`00Oomoo`05Ool00`00Oomoo`01Ool000Aoo`03001oogoo02aoo`03001oogoo07ioo`80
00E66003001F55HD00=F5003001UcFG=009Uc@8000Qoo`03000TdRCB03@TdP03001VUVJF009VUP03
001oogoo00Eoo`03001oogoo005oo`0017oo00<007ooOol0;7oo00<007ooOol0Ogoo0P001DHH00<0
05HDEQ@00eHD0P000fG=00<007ooOol01Woo00<002CB9=80=2CB00<006JFIYH00VJF00<007ooOol0
1Goo00<007ooOol00Goo0003Ool00`00Oomoo`0]Ool00`00Oomoo`20Ool20005AQP00`00EQAF5003
EQ@2000014HHILeUc@001goo00<002CB9=80<bCB00<006JFIYH00fJF00<007ooOol01Goo00<007oo
Ool00Goo0003Ool00`00Oomoo`0]Ool00`00Oomoo`22Ool20004AQP20004EQ@20003ILd20004Ool0
0`009=8TdP0d9=800`00IYIVUP02IYH00`00Oomoo`06Ool00`00Oomoo`01Ool000=oo`03001oogoo
02eoo`03001oogoo08=oo`8000E66003001F55HD00=F5003001UcFG=009Uc@05001oogooOol0000f
9=800`00IYIVUP02IYH00`00Oomoo`06Ool00`00Oomoo`01Ool000=oo`03001oogoo02eoo`03001o
ogoo08Aoo`8000E66003001F55HD00=F508000=Uc@04001oogoo000f9=800`00IYIVUP02IYH00`00
Oomoo`06Ool00`00Oomoo`01Ool000=oo`03001oogoo02eoo`03001oogoo08Eoo`8000E66003001F
55HD00=F508000=Uc@03001oo`0003HTdP03001VUVJF009VUP03001oogoo00Ioo`03001oogoo005o
o`000goo00<007ooOol0;Goo00<007ooOol0QWoo0`0014HH00<005HDEQ@00eHD0P000fG=0P00=RCB
00<006JFIYH00VJF00<007ooOol01Woo00<007ooOol00Goo0003Ool00`00Oomoo`0]Ool00`00Oomo
o`28Ool20004AQP20005EQ@01000AQQUcFG=0P00=BCB00<006JFIYH00VJF00<007ooOol01Woo00<0
07ooOol00Goo0003Ool00`00Oomoo`0]Ool00`00Oomoo`29Ool20005AQP00`00EQAF5003EQ@00`00
ILeUc@02ILd00`009=8TdP0b9=830002IYH00`00Oomoo`06Ool00`00Oomoo`01Ool000=oo`03001o
ogoo02aoo`03001oogoo08Yoo`<000E66003001F55HD00=F508000=Uc@03000TdRCB034TdP03001R
nP0000<000Qoo`03001oogoo005oo`000goo00<007ooOol0;7oo00<007ooOol0RWoo00@007oo0000
00E66003001F55HD00=F508000=Uc@03000TdRCB02lTdP03001RnV;j00=RnP03001oogoo00Moo`40
005oo`5oo`000goo00<007ooOol0;7oo00<007ooOol0RWoo00@007ooOomoo`8000A66003001F55HD
00=F508000=Uc@8002lTdP03001RnV;j009RnP03001oogoo00Qoo`40005oo`5oo`000goo00<007oo
Ool0;7oo00<007ooOol0RWoo00<007ooOol00Woo0P0014HH0P001EHD00<006G=ILd00VG=00<002CB
9=80:bCB00<006;jH_X00f;j00<007ooOol027oo0@000Goo0Goo0003Ool00`00Oomoo`0/Ool00`00
Oomoo`2:Ool00`00Oomoo`03Ool20005AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0Z
9=801000H_YRnV;j0P002goo0@000Goo0Goo0003Ool00`00Oomoo`0/Ool00`00Oomoo`2:Ool00`00
Oomoo`04Ool20005AQP00`00EQAF5003EQ@20003ILd00`009=8TdP0X9=800`00H_YRnP03H_X2000:
Ool10001Ool1Ool000=oo`03001oogoo02aoo`03001oogoo08]oo`03001oogoo00=oo`<000E66003
001F55HD00=F508000=Uc@03000TdRCB02LTdP03001RnV;j009RnP<000Yoo`40005oo`5oo`000goo
00<007ooOol0;7oo00<007ooOol0Rgoo00<007ooOol00goo0P0000=oo`00000014HH0P001EHD00@0
06G=ILeUc@8002LTdP03001RnV;j009RnP<000Yoo`40005oo`5oo`000goo00<007ooOol0;7oo00<0
07ooOol0Rgoo00<007ooOol00goo0P000Woo0P001DHH00<005HDEQ@00eHD00<006G=ILd00VG=00<0
02CB9=808bCB00<006;jH_X00f;j0`002Woo0@000Goo0Goo0003Ool00`00Oomoo`0/Ool00`00Oomo
o`2;Ool00`00Oomoo`03Ool20003Ool20005AQP00`00EQAF5003EQ@20003ILd00`009=8TdP0R9=80
0`00H_YRnP02H_X01000Ool000002Woo0@000Goo0Goo0002Ool00`00Oomoo`0]Ool00`00Oomoo`2;
Ool00`00Oomoo`03Ool20004Ool20005AQP00`00EQAF5003EQ@20003ILd00`009=8TdP0P9=800`00
H_YRnP03H_X01000Ool000002Woo0@000Goo0Goo0002Ool00`00Oomoo`0]Ool00`00Oomoo`2;Ool0
0`00Oomoo`03Ool20005Ool30004AQP00`00EQAF5004EQ@01000ILeUcFG=0P0082CB00<006;jH_X0
0V;j00<007ooOol00P002Woo0@000Goo0Goo0002Ool00`00Oomoo`0]Ool00`00Oomoo`2;Ool00`00
Oomoo`03Ool20007Ool20004AQP20005EQ@00`00ILeUc@02ILd00`009=8TdP0L9=800`00H_YRnP03
H_X00`00Oomoo`02000:Ool10001Ool1Ool0009oo`03001oogoo02eoo`03001oogoo08]oo`03001o
ogoo00=oo`8000Qoo`8000E66003001F55HD00=F5003001UcFG=009Uc@03000TdRCB01/TdP03001R
nV;j009RnP04001oogooOol2000:Ool10001Ool1Ool0009oo`03001oogoo02eoo`D008Uoo`03001o
ogoo00=oo`8000Uoo`8000E66003001F55HD00=F5003001UcFG=009Uc@03000TdRCB01XTdP03001R
nV;j009RnP04001oogooOol2000:Ool10001Ool1Ool0009oo`03001oogoo02aoo`03001oogoo00=o
o`T0081oo`03001oogoo00=oo`8000Yoo`8000E66003001F55HD00=F508000=Uc@8001TTdP03001R
nV;j00=RnP04001oogooOol2000:Ool10001Ool1Ool0009oo`03001oogoo02Yoo`8000moo`T007Mo
o`03001oogoo00=oo`8000Yoo`@000A66003001F55HD00AF5003001UcFG=009Uc@03000TdRCB01HT
dP03001RnV;j009RnP03001oogoo009oo`8000]oo`40005oo`000Woo00<007ooOol0:Goo00<007oo
Ool067oo2P00KGoo00<007ooOol00goo0P002Woo00<002CB9=800P0014HH0P001EHD00<006G=ILd0
0VG=00<002CB9=8052CB00<006;jH_X00f;j00<007ooOol00Woo0P002goo0@000Goo0002Ool00`00
Oomoo`0XOol00`00Oomoo`0SOol9001TOol00`00Oomoo`03Ool2000:Ool010009=8TdRCB0P001DHH
00<005HDEQ@00eHD00<006G=ILd00VG=00<002CB9=804bCB00<006;jH_X00V;j00<007ooOol00goo
0P002goo0@000Goo0002Ool00`00Oomoo`0WOol00`00Oomoo`0]Ool9001KOol00`00Oomoo`03Ool2
000:Ool00`009=8TdP029=820005AQP00`00EQAF5003EQ@00`00ILeUc@02ILd00`009=8TdP0B9=80
0`00H_YRnP02H_X00`00Oomoo`03Ool2000;Ool10001Ool0009oo`03001oogoo02Ioo`03001oogoo
03Moo`T0059oo`03001oogoo00=oo`8000Yoo`03000TdRCB00<TdP<000A66003001F55HD00AF50AU
c@80014TdP03001RnV;j00=RnP03001oogoo00=oo`8000]oo`40005oo`000Woo00<007ooOol097oo
0P00@goo2@00BGoo00<007ooOol017oo0P002Woo00<002CB9=800bCB0`0014HH00<005HDEQ@015HD
00<006G=ILd00VG=00<002CB9=803RCB00<006;jH_X00V;j00<007ooOol017oo0P002goo0@000Goo
0002Ool00`00Oomoo`0SOol00`00Oomoo`1<Ool90010Ool00`00Oomoo`04Ool2000:Ool00`009=8T
dP059=820004AQP20005EQ@00`00ILeUc@02ILd00`009=8TdP0<9=800`00H_YRnP03H_X00`00Oomo
o`04Ool2000;Ool10001Ool0009oo`03001oogoo029oo`03001oogoo05Ioo`X003Ioo`03001oogoo
00Aoo`8000Yoo`03000TdRCB00HTdP8000E66003001F55HD00=F5003001UcFG=009Uc@hTdP03001R
nV;j009RnP03001oogoo00Eoo`8000]oo`40005oo`000Woo00<007ooOol08Goo00<007ooOol0HGoo
2@00;Goo00<007ooOol017oo0P002goo00<002CB9=801RCB0P001DHH00<005HDEQ@00eHD00@006G=
ILeUc@dTdP03001RnV;j00=RnP03001oogoo00Eoo`8000]oo`40005oo`000Woo00<007ooOol07goo
0P00KGoo2@0097oo00<007ooOol017oo0P002goo00<002CB9=801bCB0`0014HH00<005HDEQ@015HD
0VG=00<002CB9=802RCB0`000f;j27oo0P002goo0@000Goo0002Ool00`00Oomoo`0NOol00`00Oomo
o`1fOol9000KOol00`00Oomoo`04Ool2000<Ool00`009=8TdP079=830004AQP00`00EQAF5004EQ@0
0`009=8TdP0:9=801000DeiCGU=N0`0027oo0P002goo0@000Goo0002Ool00`00Oomoo`0MOol00`00
Oomoo`20Ool9000BOol00`00Oomoo`04Ool2000=Ool00`009=8TdP089=820004AQP20003EQ@00`00
9=8TdP0:9=800`00DeiCGP03Deh00`00Oomoo`07Ool2000;Ool10001Ool00003Ool007oo01ioo`03
001oogoo08Yoo`T000Uoo`03001oogoo00Aoo`8000eoo`03000TdRCB00TTdP8000E66003001F5000
00`TdP03001CGU=N00=CGP03001oogoo00Qoo`8000]oo`40005oo`0000=oo`00Ool07Goo00<007oo
Ool0U7oo2P001Woo0P003Woo00<002CB9=802BCB0P001DHH00<005oE9=802RCB00<005=NDeh00e=N
00<007ooOol02Goo0P002goo0@000Goo00000goo001oo`0KOol2002POol:000>Ool00`009=8TdP09
9=830002AQP00`00GmDTdP0:9=800`00DeiCGP03Deh00`00Oomoo`08Ool5000:Ool10001Ool00003
Ool007oo01Yoo`03001oogoo0:1oo`03001oogoo00Aoo`800003Ool0000000L000Eoo`03000TdRCB
00XTdP<00003AQP002CB00XTdP03001CGU=N00=CGP03001oogoo00Moo`L000Yoo`40005oo`0000=o
o`00Ool06Goo00<007ooOol0XGoo00<007ooOol017oo0P002Woo2@002bCB0`002BCB0P001E=N00<0
07ooOol01Goo1P003goo0@0000000goo001oo`0HOol00`00Oomoo`2ROol00`00Oomoo`04Ool2000A
Ool00`009=800008000=9=800`00DeiCGP03Deh20006Ool6000AOol100000003Ool007oo01Moo`03
001oogoo0:=oo`03001oogoo00Aoo`80015oo`03000TdRCB00PTdPT000<TdP03001CGU=N00=CGP03
001oogoo00=oo`H001Aoo`40000000=oo`00Ool05Goo0P00YWoo00<007ooOol017oo0P004Woo00<0
02CB9=8042CB2@0017oo1P005Woo0@0000000goo001oo`0DOol00`00Oomoo`2VOol00`00Oomoo`04
Ool2000COol00`009=8TdP0@9=800`00DeiCGP03Deh00`00Ool00009000FOol100000003Ool007oo
01=oo`03001oogoo0:Moo`03001oogoo00Aoo`8001=oo`03000TdRCB00lTdP03001CGU=N00=CGP03
001oo`0000D000Eoo`T000eoo`40000000=oo`00Ool04Woo00<007ooOol0Z7oo00<007ooOol017oo
0P0057oo2@001bCB00<005=NDeh00e=N1P004Goo2@0017oo0@0000000goo001oo`0@Ool2002[Ool0
0`00Oomoo`04Ool2000JOol<0002Deh6000LOol500000003Ool007oo00moo`03001oogoo0:]oo`03
001oogoo00Aoo`8002Eoo`H001moo`<0009oo`0000=oo`00Ool03Woo00<007ooOol0[7oo00<007oo
Ool017oo0P008goo1P007goo0P001Goo00000goo001oo`0=Ool00`00Oomoo`2]Ool00`00Oomoo`04
Ool2000POol7000NOol30007Ool00003Ool007oo00aoo`03001oogoo0:ioo`03001oogoo00Aoo`80
01eoo`L001ioo`<000Yoo`0000=oo`00Ool02Woo0P00/Goo00<007ooOol017oo0P006Woo1`007goo
0P003Goo00000goo001oo`09Ool00`00Oomoo`2aOol00`00Oomoo`04Ool2000HOol6000OOol3000?
Ool00003001oogoo00Qoo`03001oogoo0;9oo`03001oogoo00Aoo`8001Eoo`H001moo`<0019oo`00
00<007ooOol01goo00<007ooOol0/goo00<007ooOol017oo0P004goo1P007goo0P005Goo00000`00
Oomoo`05Ool2002fOol00`00Oomoo`04Ool2000@Ool6000OOol3000GOol00003001oogoo00Aoo`03
001oogoo0;Ioo`03001oogoo00Aoo`8000ioo`H001ioo`<001Yoo`0000<007ooOol00goo00<007oo
Ool0^7oo00<007ooOol00goo0P002goo1P007goo0P007Goo00000`00Oomoo`02Ool00`00Oomoo`2i
Ool00`00Oomoo`03Ool20009Ool6000NOol3000OOol00005001oogooOol0002lOol00`00Oomoo`03
Ool20006Ool6000NOol3000ROol00004001oo`00002mOol00`00Oomoo`03Ool20004Ool6000NOol2
000UOol000800;moo`03001oogoo00=oo`800003Ool0000000@001ioo`<002Moo`001`00^Woo00<0
07ooOol00goo1`007Goo0`00:Woo0007Ool<002^Ool00`00Oomoo`03Ool4000MOol3000]Ool001=o
o``00:9oo`03001oogoo00=oo`8001eoo`80031oo`007goo3000UWoo00<007ooOol07goo0`00<Woo
000[Ool<002:Ool00`00Oomoo`0LOol3000eOol003Moo``007ioo`03001oogoo01Yoo`8003Qoo`00
@goo3000LWoo00<007ooOol05goo0`00>Woo001?Ool<001VOol00`00Oomoo`0DOol3000mOol005]o
o``005Yoo`03001oogoo019oo`80041oo`00Igoo3000CWoo00<007ooOol03goo0`00@Woo001cOol<
0012Ool00`00Oomoo`0<Ool30015Ool007moo``003Ioo`03001oogoo00Yoo`8004Qoo`00Rgoo3000
:Woo00<007ooOol01goo0`00BWoo002GOol<000NOol00`00Oomoo`04Ool3001=Ool00:=oo``0019o
o`03001oogoo009oo`80051oo`00[goo30001Woo00<007oo00000P00DWoo002kOol8001EOol00001
\
\>"],
  ImageRangeCache->{{{0, 279.438}, {230.688, 0}} -> {0.0423677, 0.0568787, 
  0.00342869, 0.00342869}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This was used to generate the array of four graphics objects seen in Section \
3.2."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Show[
      GraphicsArray[{{plot1, plot2}, {plot3, plot4}}, 
        GraphicsSpacing \[Rule] 0], Frame \[Rule] True]; \)\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{480, 684},
WindowMargins->{{250, Automatic}, {Automatic, 15}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 85, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1841, 57, 78, 2, 47, "Subsection"],
Cell[1922, 61, 982, 25, 166, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2941, 91, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[3069, 96, 1345, 39, 189, "Text"],

Cell[CellGroupData[{
Cell[4439, 139, 98, 2, 47, "Subsection"],
Cell[4540, 143, 977, 18, 243, "Text"],
Cell[5520, 163, 189, 8, 24, "SmallText"],
Cell[5712, 173, 84, 2, 25, "Input"],
Cell[5799, 177, 126, 2, 24, "SmallText"],
Cell[5928, 181, 10441, 225, 197, 1468, 109, "GraphicsData", 
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[16394, 410, 89, 2, 43, "Subsubsection"],
Cell[16486, 414, 144, 4, 33, "Text"],
Cell[16633, 420, 301, 6, 76, "Special1"],
Cell[16937, 428, 252, 5, 59, "Special1"],
Cell[17192, 435, 313, 6, 59, "Special1"],
Cell[17508, 443, 236, 5, 42, "Special1"],
Cell[17747, 450, 125, 2, 24, "SmallText"],
Cell[17875, 454, 26031, 589, 293, 4161, 313, "GraphicsData", 
"PostScript", "Graphics"],
Cell[43909, 1045, 147, 4, 24, "SmallText"],
Cell[44059, 1051, 159, 5, 85, "Input"],
Cell[44221, 1058, 118, 2, 24, "SmallText"],
Cell[44342, 1062, 562, 13, 185, "Input"],
Cell[44907, 1077, 143, 4, 24, "SmallText"],
Cell[45053, 1083, 82, 2, 25, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45172, 1090, 94, 2, 29, "Subsubsection"],
Cell[45269, 1094, 170, 4, 52, "Text"],
Cell[45442, 1100, 437, 15, 60, "Special1"],
Cell[45882, 1117, 285, 9, 43, "Special1"],
Cell[46170, 1128, 326, 10, 43, "Special1"],
Cell[46499, 1140, 282, 9, 43, "Special1"],
Cell[46784, 1151, 287, 9, 43, "Special1"],
Cell[47074, 1162, 289, 9, 43, "Special1"],

Cell[CellGroupData[{
Cell[47388, 1175, 133, 3, 24, "SmallText"],
Cell[47524, 1180, 516, 9, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48077, 1194, 138, 3, 24, "SmallText"],
Cell[48218, 1199, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[48354, 1207, 91, 2, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[48470, 1213, 189, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[48684, 1225, 82, 2, 25, "Input"],
Cell[48769, 1229, 523, 11, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[49341, 1246, 205, 8, 24, "SmallText"],
Cell[49549, 1256, 9856, 222, 179, 1523, 114, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[59466, 1485, 96, 2, 31, "Subsection"],
Cell[59565, 1489, 831, 17, 187, "Text"],

Cell[CellGroupData[{
Cell[60421, 1510, 5223, 221, 305, "Special3"],
Cell[65647, 1733, 120, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[65804, 1741, 2457, 99, 239, "Special3"],
Cell[68264, 1842, 133, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[68412, 1848, 375, 15, 53, "Text"],

Cell[CellGroupData[{
Cell[68812, 1867, 140, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[68977, 1874, 87, 2, 25, "Input"],
Cell[69067, 1878, 70, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[69186, 1885, 299, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[69510, 1900, 80, 2, 25, "Input"],
Cell[69593, 1904, 70, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[69712, 1911, 215, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[69952, 1923, 109, 3, 45, "Input"],
Cell[70064, 1928, 83, 1, 29, "Output"],
Cell[70150, 1931, 83, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[70260, 1936, 305, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[70590, 1949, 158, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[70773, 1957, 102, 2, 25, "Input"],
Cell[70878, 1961, 122, 2, 34, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[71049, 1969, 99, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[71173, 1975, 109, 3, 45, "Input"],
Cell[71285, 1980, 54, 1, 29, "Output"],
Cell[71342, 1983, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[71445, 1990, 160, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[71630, 1998, 101, 2, 25, "Input"],
Cell[71734, 2002, 35, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[71796, 2007, 268, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[72089, 2016, 171, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[72285, 2024, 117, 2, 45, "Input"],
Cell[72405, 2028, 116, 3, 42, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[72570, 2037, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[72701, 2043, 110, 3, 45, "Input"],
Cell[72814, 2048, 55, 1, 29, "Output"],
Cell[72872, 2051, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[72957, 2056, 216, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[73198, 2064, 152, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[73375, 2072, 94, 2, 25, "Input"],
Cell[73472, 2076, 99, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[73620, 2084, 118, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[73763, 2090, 89, 2, 39, "Input"],
Cell[73855, 2094, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[73936, 2099, 235, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[74196, 2111, 110, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[74331, 2117, 77, 2, 25, "Input"],
Cell[74411, 2121, 37, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[74497, 2128, 182, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[74704, 2136, 155, 3, 65, "Input"],
Cell[74862, 2141, 61, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[74950, 2146, 285, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[75260, 2159, 140, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[75425, 2166, 141, 3, 65, "Input"],
Cell[75569, 2171, 83, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[75713, 2179, 104, 2, 31, "Subsection"],
Cell[75820, 2183, 959, 22, 208, "Text"],

Cell[CellGroupData[{
Cell[76804, 2209, 3473, 143, 288, "Special3"],
Cell[80280, 2354, 128, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[80423, 2360, 602, 22, 73, "Text"],

Cell[CellGroupData[{
Cell[81050, 2386, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[81206, 2393, 98, 2, 25, "Input"],
Cell[81307, 2397, 90, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81446, 2404, 107, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[81578, 2410, 78, 2, 25, "Input"],
Cell[81659, 2414, 78, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[81764, 2419, 388, 13, 54, "Text"],

Cell[CellGroupData[{
Cell[82177, 2436, 246, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[82448, 2448, 113, 2, 25, "Input"],
Cell[82564, 2452, 37, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[82650, 2459, 193, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[82868, 2470, 77, 2, 25, "Input"],
Cell[82948, 2474, 36, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[83033, 2481, 198, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[83256, 2492, 71, 2, 25, "Input"],
Cell[83330, 2496, 52, 1, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[83431, 2503, 137, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[83593, 2510, 102, 2, 25, "Input"],
Cell[83698, 2514, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[83816, 2521, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[83947, 2527, 77, 2, 25, "Input"],
Cell[84027, 2531, 53, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[84129, 2538, 175, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[84329, 2546, 81, 2, 25, "Input"],
Cell[84413, 2550, 83, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[84523, 2555, 297, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[84845, 2564, 170, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[85040, 2572, 110, 2, 25, "Input"],
Cell[85153, 2576, 101, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[85303, 2584, 232, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[85560, 2596, 83, 2, 25, "Input"],
Cell[85646, 2600, 101, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[85796, 2608, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[85927, 2614, 75, 2, 25, "Input"],
Cell[86005, 2618, 62, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[86116, 2625, 237, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[86378, 2637, 97, 2, 25, "Input"],
Cell[86478, 2641, 44, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[86549, 2646, 249, 9, 54, "Text"],

Cell[CellGroupData[{
Cell[86823, 2659, 590, 20, 86, "Special3"],
Cell[87416, 2681, 122, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[87553, 2687, 105, 2, 43, "Subsubsection"],
Cell[87661, 2691, 510, 19, 73, "Text"],

Cell[CellGroupData[{
Cell[88196, 2714, 1128, 47, 101, "Special3"],
Cell[89327, 2763, 126, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[89490, 2771, 146, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[89661, 2779, 83, 2, 35, "Input"],
Cell[89747, 2783, 45, 1, 32, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[89841, 2790, 91, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[89957, 2796, 71, 2, 25, "Input"],
Cell[90031, 2800, 47, 1, 40, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[90127, 2807, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[90279, 2813, 104, 2, 25, "Input"],
Cell[90386, 2817, 78, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[90513, 2824, 190, 8, 24, "SmallText"],
Cell[90706, 2834, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[90836, 2843, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[90964, 2848, 1427, 44, 189, "Text"],

Cell[CellGroupData[{
Cell[92416, 2896, 98, 2, 47, "Subsection"],
Cell[92517, 2900, 762, 15, 186, "Text"],

Cell[CellGroupData[{
Cell[93304, 2919, 189, 8, 24, "SmallText"],
Cell[93496, 2929, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93617, 2936, 136, 3, 24, "SmallText"],
Cell[93756, 2941, 52056, 2090, 243, 26235, 1766, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145849, 5036, 89, 2, 43, "Subsubsection"],
Cell[145941, 5040, 259, 5, 71, "Text"],
Cell[146203, 5047, 478, 8, 93, "Special1"],
Cell[146684, 5057, 333, 6, 76, "Special1"],
Cell[147020, 5065, 393, 7, 93, "Special1"],

Cell[CellGroupData[{
Cell[147438, 5076, 130, 3, 24, "SmallText"],
Cell[147571, 5081, 89687, 2385, 468, 16458, 1474, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[237295, 7471, 137, 3, 24, "SmallText"],
Cell[237435, 7476, 130, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[237602, 7485, 115, 2, 24, "SmallText"],
Cell[237720, 7489, 491, 11, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[238248, 7505, 143, 4, 24, "SmallText"],
Cell[238394, 7511, 82, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[238525, 7519, 94, 2, 29, "Subsubsection"],
Cell[238622, 7523, 137, 3, 33, "Text"],
Cell[238762, 7528, 343, 10, 60, "Special1"],
Cell[239108, 7540, 336, 10, 60, "Special1"],
Cell[239447, 7552, 282, 9, 43, "Special1"],
Cell[239732, 7563, 698, 21, 78, "Special1"],

Cell[CellGroupData[{
Cell[240455, 7588, 132, 3, 24, "SmallText"],
Cell[240590, 7593, 438, 9, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[241065, 7607, 137, 3, 24, "SmallText"],
Cell[241205, 7612, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[241341, 7620, 91, 2, 29, "Subsubsection"],
Cell[241435, 7624, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[241648, 7636, 82, 2, 25, "Input"],
Cell[241733, 7640, 675, 13, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242445, 7658, 201, 8, 24, "SmallText"],
Cell[242649, 7668, 50480, 2129, 281, 22581, 1779, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[293190, 9804, 96, 2, 31, "Subsection"],
Cell[293289, 9808, 910, 21, 188, "Text"],

Cell[CellGroupData[{
Cell[294224, 9833, 6637, 281, 363, "Special3"],
Cell[300864, 10116, 120, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[301021, 10124, 4673, 192, 347, "Special3"],
Cell[305697, 10318, 125, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[305837, 10324, 302, 11, 53, "Text"],

Cell[CellGroupData[{
Cell[306164, 10339, 173, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[306362, 10347, 84, 2, 25, "Input"],
Cell[306449, 10351, 168, 3, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[306666, 10360, 298, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[306989, 10375, 77, 2, 25, "Input"],
Cell[307069, 10379, 168, 3, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[307286, 10388, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[307417, 10394, 126, 3, 45, "Input"],
Cell[307546, 10399, 65, 1, 29, "Output"],
Cell[307614, 10402, 81, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[307722, 10407, 306, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[308053, 10420, 169, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[308247, 10428, 102, 2, 25, "Input"],
Cell[308352, 10432, 258, 5, 95, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[308659, 10443, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[308790, 10449, 109, 3, 45, "Input"],
Cell[308902, 10454, 54, 1, 29, "Output"],
Cell[308959, 10457, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[309062, 10464, 159, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[309246, 10472, 101, 2, 25, "Input"],
Cell[309350, 10476, 35, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[309412, 10481, 236, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[309673, 10490, 176, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[309874, 10498, 147, 3, 65, "Input"],
Cell[310024, 10503, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[310127, 10510, 148, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[310300, 10518, 141, 3, 65, "Input"],
Cell[310444, 10523, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[310548, 10530, 122, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[310695, 10536, 68, 2, 39, "Input"],
Cell[310766, 10540, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[310847, 10545, 310, 9, 54, "Text"],

Cell[CellGroupData[{
Cell[311182, 10558, 197, 4, 40, "SmallText"],

Cell[CellGroupData[{
Cell[311404, 10566, 137, 3, 45, "Input"],
Cell[311544, 10571, 127, 2, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[311720, 10579, 197, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[311942, 10591, 78, 2, 25, "Input"],
Cell[312023, 10595, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[312126, 10602, 260, 9, 24, "SmallText"],

Cell[CellGroupData[{
Cell[312411, 10615, 74, 2, 37, "Input"],
Cell[312488, 10619, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[312592, 10626, 183, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[312800, 10634, 161, 3, 65, "Input"],
Cell[312964, 10639, 81, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[313072, 10644, 441, 11, 91, "Text"],

Cell[CellGroupData[{
Cell[313538, 10659, 135, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[313698, 10666, 74, 2, 25, "Input"],
Cell[313775, 10670, 130, 2, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[313954, 10678, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[314085, 10684, 78, 2, 25, "Input"],
Cell[314166, 10688, 73, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[314300, 10696, 104, 2, 31, "Subsection"],
Cell[314407, 10700, 934, 22, 188, "Text"],

Cell[CellGroupData[{
Cell[315366, 10726, 4448, 186, 334, "Special3"],
Cell[319817, 10914, 128, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[319960, 10920, 328, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[320313, 10936, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[320469, 10943, 95, 2, 25, "Input"],
Cell[320567, 10947, 198, 3, 92, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[320814, 10956, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[320945, 10962, 77, 2, 25, "Input"],
Cell[321025, 10966, 117, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[321169, 10972, 395, 13, 54, "Text"],

Cell[CellGroupData[{
Cell[321589, 10989, 246, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[321860, 11001, 110, 2, 25, "Input"],
Cell[321973, 11005, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[322076, 11012, 121, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[322222, 11018, 86, 2, 25, "Input"],
Cell[322311, 11022, 39, 1, 30, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[322399, 11029, 199, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[322623, 11040, 79, 2, 25, "Input"],
Cell[322705, 11044, 73, 1, 53, "Output"]
}, Open  ]]
}, Open  ]],
Cell[322805, 11049, 220, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[323050, 11061, 329, 13, 25, "SmallText"],

Cell[CellGroupData[{
Cell[323404, 11078, 102, 2, 25, "Input"],
Cell[323509, 11082, 280, 4, 105, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[323838, 11092, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[323969, 11098, 77, 2, 25, "Input"],
Cell[324049, 11102, 112, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[324210, 11110, 137, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[324372, 11117, 97, 2, 25, "Input"],
Cell[324472, 11121, 208, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[324729, 11130, 122, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[324876, 11136, 77, 2, 25, "Input"],
Cell[324956, 11140, 82, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[325065, 11145, 297, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[325387, 11154, 170, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[325582, 11162, 138, 3, 65, "Input"],
Cell[325723, 11167, 103, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[325875, 11175, 222, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[326122, 11187, 105, 2, 25, "Input"],
Cell[326230, 11191, 103, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[326382, 11199, 237, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[326644, 11211, 96, 2, 25, "Input"],
Cell[326743, 11215, 88, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[326880, 11222, 335, 12, 56, "Special3"],
Cell[327218, 11236, 122, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[327355, 11242, 105, 2, 43, "Subsubsection"],
Cell[327463, 11246, 357, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[327845, 11262, 3508, 147, 255, "Special3"],
Cell[331356, 11411, 126, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[331519, 11419, 155, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[331699, 11427, 93, 2, 35, "Input"],
Cell[331795, 11431, 48, 1, 32, "Output"]
}, Open  ]]
}, Open  ]],
Cell[331870, 11436, 91, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[331986, 11442, 78, 2, 25, "Input"],
Cell[332067, 11446, 50, 1, 40, "Output"]
}, Open  ]],
Cell[332132, 11450, 126, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[332283, 11456, 110, 2, 25, "Input"],
Cell[332396, 11460, 103, 2, 29, "Output"]
}, Open  ]],
Cell[332514, 11465, 191, 8, 24, "SmallText"],
Cell[332708, 11475, 69, 2, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[332826, 11483, 122, 3, 33, "Section",
  PageBreakAbove->True],
Cell[332951, 11488, 1033, 29, 168, "Text"],

Cell[CellGroupData[{
Cell[334009, 11521, 97, 2, 47, "Subsection"],
Cell[334109, 11525, 492, 11, 129, "Text"],

Cell[CellGroupData[{
Cell[334626, 11540, 117, 2, 24, "SmallText"],
Cell[334746, 11544, 218, 7, 125, "Input"],
Cell[334967, 11553, 490, 10, 185, "Input"],
Cell[335460, 11565, 455, 7, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[335952, 11577, 119, 2, 24, "SmallText"],
Cell[336074, 11581, 10441, 225, 197, 1468, 109, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[346564, 11812, 90, 2, 31, "Subsection"],
Cell[346657, 11816, 351, 9, 72, "Text"],

Cell[CellGroupData[{
Cell[347033, 11829, 117, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[347175, 11835, 134, 3, 45, "Input"],
Cell[347312, 11840, 342, 6, 67, "Output"]
}, Open  ]]
}, Open  ]],
Cell[347681, 11850, 728, 24, 92, "Text"],
Cell[348412, 11876, 125, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[348562, 11882, 127, 3, 25, "Input"],
Cell[348692, 11887, 13829, 357, 181, 3070, 218, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[362536, 12247, 137, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[362698, 12254, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[362854, 12261, 164, 3, 65, "Input"],
Cell[363021, 12266, 18045, 406, 181, 3057, 215, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[381093, 12676, 1356, 43, 173, "Text"],

Cell[CellGroupData[{
Cell[382474, 12723, 121, 2, 24, "SmallText"],
Cell[382598, 12727, 160, 4, 45, "Input"]
}, Open  ]],
Cell[382773, 12734, 230, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[383028, 12746, 225, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[383278, 12758, 261, 6, 85, "Input"],
Cell[383542, 12766, 18167, 444, 181, 3711, 260, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[401770, 13217, 93, 2, 31, "Subsection"],
Cell[401866, 13221, 630, 21, 93, "Text"],

Cell[CellGroupData[{
Cell[402521, 13246, 1194, 47, 86, "Special3"],
Cell[403718, 13295, 177, 7, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[403910, 13305, 416, 13, 73, "Text"],

Cell[CellGroupData[{
Cell[404351, 13322, 114, 2, 24, "SmallText"],
Cell[404468, 13326, 160, 4, 65, "Input"]
}, Open  ]],
Cell[404643, 13333, 205, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[404873, 13345, 129, 3, 45, "Input"],
Cell[405005, 13350, 117, 3, 29, "Output"]
}, Open  ]],
Cell[405137, 13356, 135, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[405297, 13363, 86, 2, 25, "Input"],
Cell[405386, 13367, 20149, 523, 181, 4817, 328, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[425572, 13895, 190, 8, 24, "SmallText"],
Cell[425765, 13905, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[425895, 13914, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[426023, 13919, 1577, 48, 248, "Text"],

Cell[CellGroupData[{
Cell[427625, 13971, 98, 2, 47, "Subsection"],
Cell[427726, 13975, 447, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[428198, 13993, 2819, 119, 163, "Special3"],
Cell[431020, 14114, 185, 8, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[431242, 14127, 5399, 228, 320, "Special3"],
Cell[436644, 14357, 130, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[436811, 14365, 1081, 35, 133, "Special3"],
Cell[437895, 14402, 134, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[438044, 14408, 983, 41, 74, "Text"],

Cell[CellGroupData[{
Cell[439052, 14453, 188, 8, 24, "SmallText"],
Cell[439243, 14463, 139, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[439419, 14472, 133, 3, 24, "SmallText"],
Cell[439555, 14477, 371, 7, 145, "Input"]
}, Open  ]],
Cell[439941, 14487, 905, 36, 74, "Text"],

Cell[CellGroupData[{
Cell[440871, 14527, 214, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[441110, 14539, 129, 3, 25, "Input"],
Cell[441242, 14544, 17393, 682, 188, 5903, 534, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[458684, 15232, 229, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[458938, 15244, 128, 3, 25, "Input"],
Cell[459069, 15249, 17521, 683, 188, 5902, 534, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[476617, 15936, 1339, 41, 190, "Text"],

Cell[CellGroupData[{
Cell[477981, 15981, 571, 24, 40, "SmallText"],
Cell[478555, 16007, 493, 9, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[479085, 16021, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[479208, 16027, 130, 3, 25, "Input"],
Cell[479341, 16032, 18047, 693, 196, 5954, 538, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[497415, 16729, 562, 20, 73, "Text"],

Cell[CellGroupData[{
Cell[498002, 16753, 193, 8, 24, "SmallText"],
Cell[498198, 16763, 302, 6, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[498537, 16774, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[498660, 16780, 137, 3, 25, "Input"],
Cell[498800, 16785, 24194, 790, 196, 6293, 563, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[523055, 17582, 100, 2, 31, "Subsection"],
Cell[523158, 17586, 229, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[523412, 17598, 1668, 66, 162, "Special3"],
Cell[525083, 17666, 137, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[525235, 17672, 670, 18, 111, "Text"],

Cell[CellGroupData[{
Cell[525930, 17694, 202, 8, 24, "SmallText"],
Cell[526135, 17704, 482, 9, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[526654, 17718, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[526777, 17724, 130, 3, 25, "Input"],
Cell[526910, 17729, 31154, 1041, 206, 13112, 812, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[558113, 18776, 754, 29, 70, "Special3"],
Cell[558870, 18807, 156, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[559041, 18814, 365, 12, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[559443, 18831, 106, 2, 31, "Subsection"],
Cell[559552, 18835, 332, 10, 72, "Text"],

Cell[CellGroupData[{
Cell[559909, 18849, 101, 2, 24, "SmallText"],
Cell[560013, 18853, 159, 5, 85, "Input"],
Cell[560175, 18860, 483, 10, 185, "Input"],
Cell[560661, 18872, 455, 7, 165, "Input"]
}, Open  ]],
Cell[561131, 18882, 461, 13, 91, "Text"],
Cell[561595, 18897, 89, 2, 43, "Subsubsection"],
Cell[561687, 18901, 741, 21, 112, "Text"],

Cell[CellGroupData[{
Cell[562453, 18926, 111, 2, 24, "SmallText"],
Cell[562567, 18930, 273, 6, 85, "Input"]
}, Open  ]],
Cell[562855, 18939, 312, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[563192, 18955, 122, 2, 24, "SmallText"],
Cell[563317, 18959, 682, 12, 225, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[564036, 18976, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[564159, 18982, 210, 5, 65, "Input"],
Cell[564372, 18989, 20354, 561, 189, 12640, 460, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[584753, 19554, 88, 2, 43, "Subsubsection"],
Cell[584844, 19558, 701, 21, 112, "Text"],

Cell[CellGroupData[{
Cell[585570, 19583, 110, 2, 24, "SmallText"],
Cell[585683, 19587, 379, 7, 125, "Input"]
}, Open  ]],
Cell[586077, 19597, 321, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[586423, 19610, 116, 2, 24, "SmallText"],
Cell[586542, 19614, 462, 8, 145, "Input"]
}, Open  ]],
Cell[587019, 19625, 927, 37, 94, "Text"],

Cell[CellGroupData[{
Cell[587971, 19666, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[588094, 19672, 224, 5, 65, "Input"],
Cell[588321, 19679, 11735, 330, 182, 7026, 266, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[600083, 20013, 92, 2, 43, "Subsubsection"],
Cell[600178, 20017, 848, 28, 110, "Text"],

Cell[CellGroupData[{
Cell[601051, 20049, 109, 2, 24, "SmallText"],
Cell[601163, 20053, 421, 8, 165, "Input"]
}, Open  ]],
Cell[601599, 20064, 330, 9, 72, "Text"],

Cell[CellGroupData[{
Cell[601954, 20077, 120, 2, 24, "SmallText"],
Cell[602077, 20081, 463, 8, 145, "Input"]
}, Open  ]],
Cell[602555, 20092, 328, 10, 73, "Text"],

Cell[CellGroupData[{
Cell[602908, 20106, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[603031, 20112, 230, 5, 85, "Input"],
Cell[603264, 20119, 12697, 348, 182, 7121, 273, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[615988, 20471, 89, 2, 43, "Subsubsection"],
Cell[616080, 20475, 306, 11, 54, "Text"],

Cell[CellGroupData[{
Cell[616411, 20490, 106, 2, 24, "SmallText"],
Cell[616520, 20494, 243, 6, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[616800, 20505, 109, 2, 24, "SmallText"],
Cell[616912, 20509, 462, 8, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[617411, 20522, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[617534, 20528, 226, 5, 85, "Input"],
Cell[617763, 20535, 11021, 320, 182, 6974, 264, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[628811, 20859, 97, 2, 43, "Subsubsection"],
Cell[628911, 20863, 178, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[629114, 20871, 114, 2, 24, "SmallText"],
Cell[629231, 20875, 211, 5, 85, "Input"]
}, Open  ]],
Cell[629457, 20883, 296, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[629778, 20896, 201, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[630004, 20908, 269, 5, 85, "Input"],
Cell[630276, 20915, 8583, 193, 182, 1403, 98, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[638908, 21114, 192, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[639125, 21126, 269, 5, 85, "Input"],
Cell[639397, 21133, 8508, 192, 182, 1409, 98, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[647954, 21331, 158, 4, 24, "SmallText"],
Cell[648115, 21337, 167, 4, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[648319, 21346, 190, 8, 24, "SmallText"],
Cell[648512, 21356, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[648642, 21365, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[648770, 21370, 1486, 44, 248, "Text"],

Cell[CellGroupData[{
Cell[650281, 21418, 98, 2, 47, "Subsection"],
Cell[650382, 21422, 633, 19, 92, "Text"],

Cell[CellGroupData[{
Cell[651040, 21445, 4743, 199, 318, "Special3"],
Cell[655786, 21646, 131, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[655954, 21654, 4417, 177, 349, "Special3"],
Cell[660374, 21833, 130, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[660541, 21841, 1464, 44, 211, "Special3"],
Cell[662008, 21887, 134, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[662157, 21893, 941, 40, 74, "Text"],

Cell[CellGroupData[{
Cell[663123, 21937, 188, 8, 24, "SmallText"],
Cell[663314, 21947, 139, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[663490, 21956, 117, 2, 24, "SmallText"],
Cell[663610, 21960, 545, 11, 145, "Input"]
}, Open  ]],
Cell[664170, 21974, 1128, 49, 74, "Text"],

Cell[CellGroupData[{
Cell[665323, 22027, 219, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[665567, 22039, 202, 4, 45, "Input"],
Cell[665772, 22045, 21270, 383, 236, 1649, 135, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[687069, 22432, 836, 22, 151, "Text"],
Cell[687908, 22456, 166, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[688099, 22464, 91, 2, 25, "Input"],
Cell[688193, 22468, 83, 1, 29, "Output"]
}, Open  ]],
Cell[688291, 22472, 445, 20, 24, "SmallText"],

Cell[CellGroupData[{
Cell[688761, 22496, 101, 2, 25, "Input"],
Cell[688865, 22500, 138, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[689040, 22507, 259, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[689324, 22522, 147, 4, 25, "Input"],
Cell[689474, 22528, 21200, 382, 237, 1649, 135, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[710701, 22914, 1055, 35, 151, "Text"],

Cell[CellGroupData[{
Cell[711781, 22953, 460, 20, 24, "SmallText"],
Cell[712244, 22975, 349, 8, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[712630, 22988, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[712753, 22994, 204, 4, 45, "Input"],
Cell[712960, 23000, 36190, 649, 308, 3346, 238, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[749177, 23653, 572, 20, 73, "Text"],

Cell[CellGroupData[{
Cell[749774, 23677, 204, 8, 24, "SmallText"],
Cell[749981, 23687, 235, 6, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[750253, 23698, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[750376, 23704, 204, 4, 45, "Input"],
Cell[750583, 23710, 22665, 417, 226, 2192, 158, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[773275, 24131, 304, 12, 34, "Text"],

Cell[CellGroupData[{
Cell[773604, 24147, 215, 8, 24, "SmallText"],
Cell[773822, 24157, 534, 10, 185, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[774393, 24172, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[774516, 24178, 202, 4, 45, "Input"],
Cell[774721, 24184, 50249, 1828, 388, 20583, 1456, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[825019, 26018, 1950, 81, 133, "Special3"],
Cell[826972, 26101, 146, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[827133, 26107, 519, 14, 92, "Text"],

Cell[CellGroupData[{
Cell[827677, 26125, 124, 2, 24, "SmallText"],
Cell[827804, 26129, 405, 9, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[828246, 26143, 213, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[828484, 26154, 202, 4, 45, "Input"],
Cell[828689, 26160, 25522, 452, 266, 2175, 158, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[854238, 26616, 226, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[854489, 26628, 126, 2, 24, "SmallText"],
Cell[854618, 26632, 187, 5, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[854842, 26642, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[854965, 26648, 202, 4, 45, "Input"],
Cell[855170, 26654, 44349, 858, 255, 6933, 390, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[899580, 27519, 100, 2, 31, "Subsection"],
Cell[899683, 27523, 230, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[899938, 27535, 1596, 63, 162, "Special3"],
Cell[901537, 27600, 137, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[901689, 27606, 670, 18, 111, "Text"],

Cell[CellGroupData[{
Cell[902384, 27628, 115, 2, 24, "SmallText"],
Cell[902502, 27632, 430, 9, 185, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[902969, 27646, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[903092, 27652, 202, 4, 45, "Input"],
Cell[903297, 27658, 31461, 756, 230, 11410, 503, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[934807, 28420, 755, 29, 70, "Special3"],
Cell[935565, 28451, 156, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[935736, 28458, 310, 12, 54, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[936083, 28475, 106, 2, 31, "Subsection"],
Cell[936192, 28479, 1006, 20, 224, "Text"],
Cell[937201, 28501, 138, 3, 24, "SmallText"],
Cell[937342, 28506, 130, 4, 65, "Input"],
Cell[937475, 28512, 421, 8, 145, "Input"],
Cell[937899, 28522, 403, 7, 165, "Input"],
Cell[938305, 28531, 459, 13, 91, "Text"],
Cell[938767, 28546, 89, 2, 43, "Subsubsection"],
Cell[938859, 28550, 511, 17, 72, "Text"],

Cell[CellGroupData[{
Cell[939395, 28571, 111, 2, 24, "SmallText"],
Cell[939509, 28575, 501, 9, 165, "Input"]
}, Open  ]],
Cell[940025, 28587, 756, 26, 92, "Text"],

Cell[CellGroupData[{
Cell[940806, 28617, 114, 2, 24, "SmallText"],
Cell[940923, 28621, 593, 11, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[941553, 28637, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[941676, 28643, 188, 5, 45, "Input"],
Cell[941867, 28650, 35706, 850, 271, 12787, 561, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[977600, 29504, 88, 2, 43, "Subsubsection"],
Cell[977691, 29508, 463, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[978179, 29526, 110, 2, 24, "SmallText"],
Cell[978292, 29530, 149, 4, 45, "Input"]
}, Open  ]],
Cell[978456, 29537, 322, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[978803, 29550, 108, 2, 24, "SmallText"],
Cell[978914, 29554, 533, 10, 165, "Input"]
}, Open  ]],
Cell[979462, 29567, 1021, 37, 113, "Text"],

Cell[CellGroupData[{
Cell[980508, 29608, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[980631, 29614, 202, 5, 45, "Input"],
Cell[980836, 29621, 37965, 976, 271, 15613, 694, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1018828, 30601, 89, 2, 43, "Subsubsection"],
Cell[1018920, 30605, 325, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[1019270, 30621, 106, 2, 24, "SmallText"],
Cell[1019379, 30625, 161, 4, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1019577, 30634, 109, 2, 24, "SmallText"],
Cell[1019689, 30638, 212, 5, 65, "Input"]
}, Open  ]],
Cell[1019916, 30646, 325, 10, 53, "Text"],

Cell[CellGroupData[{
Cell[1020266, 30660, 87, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[1020378, 30666, 204, 5, 65, "Input"],
Cell[1020585, 30673, 26531, 609, 271, 7200, 364, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1047143, 31286, 97, 2, 43, "Subsubsection"],
Cell[1047243, 31290, 362, 13, 53, "Text"],

Cell[CellGroupData[{
Cell[1047630, 31307, 114, 2, 24, "SmallText"],
Cell[1047747, 31311, 138, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1047922, 31319, 117, 2, 24, "SmallText"],
Cell[1048042, 31323, 198, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1048277, 31333, 98, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[1048400, 31339, 204, 5, 65, "Input"],
Cell[1048607, 31346, 26358, 532, 271, 4379, 255, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[1074992, 31882, 293, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[1075310, 31895, 214, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[1075549, 31907, 230, 5, 65, "Input"],
Cell[1075782, 31914, 48448, 1353, 271, 21143, 1010, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1124279, 33273, 228, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[1124532, 33285, 275, 5, 85, "Input"],
Cell[1124810, 33292, 45988, 1290, 240, 19441, 956, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1170847, 34588, 163, 4, 24, "SmallText"],
Cell[1171013, 34594, 203, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1171253, 34604, 190, 8, 24, "SmallText"],
Cell[1171446, 34614, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

