(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    471290,      23606]*)
(*NotebookOutlinePosition[    472233,      23638]*)
(*  CellTagsIndexPosition[    472189,      23634]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["4.  Velocity and Acceleration", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Overview"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  "'s velocity and acceleration solution blocks, and issues related to the \
representation of angular orientation and velocity in spatial systems. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " automatically differentiates the kinematic equations with respect to time \
and can solve for the velocity and acceleration of each body in a model \
without any further input from the user. Output functions are provided for \
utilizing the higher-order solution data, and definitions for the derivatives \
of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " dependent variables are automatically made in the ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context so that expressions containing ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " dependent variables can be properly differentiated."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1  Velocity and Acceleration Solutions", "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " calculates all velocities and accelerations with respect to the time \
variable (the symbol ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default). As was shown in Chapter 2, the use of the time variable in a \
model is optional, if the model is to be used to generate a location solution \
only. However, a model must have some explicit functional dependence on the \
time variable in order to have a nontrivial solution to the higher-order \
(velocity and acceleration) equations."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech'",
    FontSlant->"Italic"],
  "s velocity and acceleration solutions, a 2D model is developed that can be \
measured. A 3D model is treated in the same manner as 2D with regard to \
higher-order solutions. The model is be a pull-rod and rocker rear suspension \
linkage for a car, consisting of three moving bodies: the chassis, the \
carrier, and the rocker. A real suspension linkage would have three more \
moving bodies: the upper and lower A-arms, and the pull-rod between the wheel \
carrier and the rocker.\n\nThe input to the model is the chassis moving \
vertically relative to the ground. This model could have been reduced in size \
by making the ground body the chassis, and simply moving the wheel carrier \
relative to the chassis, but the chosen method allows more flexibility and \
makes for better graphics.\n\nThe wheel carrier is attached to the chassis by \
two A-arms. These A-arms are not modeled as independent bodies because their \
function can be represented by a pair of relative distance constraints \
between the chassis and the wheel carrier.\n\nThe rocker pivots about an axis \
on the chassis and is attached to the wheel carrier by the pull-rod, a \
connecting link in tension. This pull-rod is also modeled with a relative \
distance constraint, not a separate body.\n\nThe shock absorber is connected \
between the other end of the rocker and the chassis. The damper is not \
actually part of the kinematic model at all, but the length of the damper as \
a function of wheel motion is a primary point of interest for any suspension \
linkage. Thus, the shock absorber exists only as a pair of mounting points on \
the chassis and the rocker, the separation of which can be measured as the \
car is bounced."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the 2D pull-rod suspension model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
  
  
 
  
  
%%Creator: Mathematica 
  
  
 
  
  
%%AspectRatio: .75862  
  
  
 
  
  
MathPictureStart 
  
  
 
  
  
%% Graphics 
  
  
 
  
  
/Courier findfont 10  scalefont  setfont 
  
  
 
  
  
% Scaling calculations 
  
  
 
  
  
0.0344828 0.0344828 0.0344828 0.0344828 [ 
  
  
 
  
  
[(0)] .03448 0 0 2 Msboxa 
  
  
 
  
  
[(5)] .2069 0 0 2 Msboxa 
  
  
 
  
  
[(10)] .37931 0 0 2 Msboxa 
  
  
 
  
  
[(15)] .55172 0 0 2 Msboxa 
  
  
 
  
  
[(20)] .72414 0 0 2 Msboxa 
  
  
 
  
  
[(25)] .89655 0 0 2 Msboxa 
  
  
 
  
  
[(0)] -0.0125 .03448 1 0 Msboxa 
  
  
 
  
  
[(5)] -0.0125 .2069 1 0 Msboxa 
  
  
 
  
  
[(10)] -0.0125 .37931 1 0 Msboxa 
  
  
 
  
  
[(15)] -0.0125 .55172 1 0 Msboxa 
  
  
 
  
  
[(20)] -0.0125 .72414 1 0 Msboxa 
  
  
 
  
  
[ -0.001 -0.001 0 0 ] 
  
  
 
  
  
[ 1.001 .75962 0 0 ] 
  
  
 
  
  
] MathScale 
  
  
 
  
  
% Start of Graphics 
  
  
 
  
  
1 setlinecap 
  
  
 
  
  
1 setlinejoin 
  
  
 
  
  
newpath 
  
  
 
  
  
[ ] 0 setdash 
  
  
 
  
  
0 g 
  
  
 
  
  
p 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.03448 0 m 
  
  
 
  
  
.03448 .00625 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(0)] .03448 0 0 2 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.2069 0 m 
  
  
 
  
  
.2069 .00625 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(5)] .2069 0 0 2 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.37931 0 m 
  
  
 
  
  
.37931 .00625 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(10)] .37931 0 0 2 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.55172 0 m 
  
  
 
  
  
.55172 .00625 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(15)] .55172 0 0 2 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.72414 0 m 
  
  
 
  
  
.72414 .00625 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(20)] .72414 0 0 2 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.89655 0 m 
  
  
 
  
  
.89655 .00625 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(25)] .89655 0 0 2 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.06897 0 m 
  
  
 
  
  
.06897 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.10345 0 m 
  
  
 
  
  
.10345 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.13793 0 m 
  
  
 
  
  
.13793 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.17241 0 m 
  
  
 
  
  
.17241 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.24138 0 m 
  
  
 
  
  
.24138 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.27586 0 m 
  
  
 
  
  
.27586 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.31034 0 m 
  
  
 
  
  
.31034 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.34483 0 m 
  
  
 
  
  
.34483 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.41379 0 m 
  
  
 
  
  
.41379 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.44828 0 m 
  
  
 
  
  
.44828 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.48276 0 m 
  
  
 
  
  
.48276 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.51724 0 m 
  
  
 
  
  
.51724 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.58621 0 m 
  
  
 
  
  
.58621 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.62069 0 m 
  
  
 
  
  
.62069 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.65517 0 m 
  
  
 
  
  
.65517 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.68966 0 m 
  
  
 
  
  
.68966 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.75862 0 m 
  
  
 
  
  
.75862 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.7931 0 m 
  
  
 
  
  
.7931 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.82759 0 m 
  
  
 
  
  
.82759 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.86207 0 m 
  
  
 
  
  
.86207 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.93103 0 m 
  
  
 
  
  
.93103 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.96552 0 m 
  
  
 
  
  
.96552 .00375 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 0 m 
  
  
 
  
  
1 0 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 .03448 m 
  
  
 
  
  
.00625 .03448 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(0)] -0.0125 .03448 1 0 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 .2069 m 
  
  
 
  
  
.00625 .2069 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(5)] -0.0125 .2069 1 0 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 .37931 m 
  
  
 
  
  
.00625 .37931 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(10)] -0.0125 .37931 1 0 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 .55172 m 
  
  
 
  
  
.00625 .55172 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(15)] -0.0125 .55172 1 0 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 .72414 m 
  
  
 
  
  
.00625 .72414 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
[(20)] -0.0125 .72414 1 0 Mshowa 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .06897 m 
  
  
 
  
  
.00375 .06897 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .10345 m 
  
  
 
  
  
.00375 .10345 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .13793 m 
  
  
 
  
  
.00375 .13793 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .17241 m 
  
  
 
  
  
.00375 .17241 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .24138 m 
  
  
 
  
  
.00375 .24138 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .27586 m 
  
  
 
  
  
.00375 .27586 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .31034 m 
  
  
 
  
  
.00375 .31034 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .34483 m 
  
  
 
  
  
.00375 .34483 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .41379 m 
  
  
 
  
  
.00375 .41379 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .44828 m 
  
  
 
  
  
.00375 .44828 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .48276 m 
  
  
 
  
  
.00375 .48276 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .51724 m 
  
  
 
  
  
.00375 .51724 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .58621 m 
  
  
 
  
  
.00375 .58621 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .62069 m 
  
  
 
  
  
.00375 .62069 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .65517 m 
  
  
 
  
  
.00375 .65517 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
0 .68966 m 
  
  
 
  
  
.00375 .68966 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 0 m 
  
  
 
  
  
0 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.03448 .75237 m 
  
  
 
  
  
.03448 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.2069 .75237 m 
  
  
 
  
  
.2069 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.37931 .75237 m 
  
  
 
  
  
.37931 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.55172 .75237 m 
  
  
 
  
  
.55172 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.72414 .75237 m 
  
  
 
  
  
.72414 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.89655 .75237 m 
  
  
 
  
  
.89655 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.06897 .75487 m 
  
  
 
  
  
.06897 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.10345 .75487 m 
  
  
 
  
  
.10345 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.13793 .75487 m 
  
  
 
  
  
.13793 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.17241 .75487 m 
  
  
 
  
  
.17241 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.24138 .75487 m 
  
  
 
  
  
.24138 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.27586 .75487 m 
  
  
 
  
  
.27586 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.31034 .75487 m 
  
  
 
  
  
.31034 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.34483 .75487 m 
  
  
 
  
  
.34483 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.41379 .75487 m 
  
  
 
  
  
.41379 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.44828 .75487 m 
  
  
 
  
  
.44828 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.48276 .75487 m 
  
  
 
  
  
.48276 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.51724 .75487 m 
  
  
 
  
  
.51724 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.58621 .75487 m 
  
  
 
  
  
.58621 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.62069 .75487 m 
  
  
 
  
  
.62069 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.65517 .75487 m 
  
  
 
  
  
.65517 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.68966 .75487 m 
  
  
 
  
  
.68966 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.75862 .75487 m 
  
  
 
  
  
.75862 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.7931 .75487 m 
  
  
 
  
  
.7931 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.82759 .75487 m 
  
  
 
  
  
.82759 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.86207 .75487 m 
  
  
 
  
  
.86207 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.93103 .75487 m 
  
  
 
  
  
.93103 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.96552 .75487 m 
  
  
 
  
  
.96552 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
0 .75862 m 
  
  
 
  
  
1 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.99375 .03448 m 
  
  
 
  
  
1 .03448 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.99375 .2069 m 
  
  
 
  
  
1 .2069 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.99375 .37931 m 
  
  
 
  
  
1 .37931 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.99375 .55172 m 
  
  
 
  
  
1 .55172 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
.99375 .72414 m 
  
  
 
  
  
1 .72414 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .06897 m 
  
  
 
  
  
1 .06897 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .10345 m 
  
  
 
  
  
1 .10345 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .13793 m 
  
  
 
  
  
1 .13793 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .17241 m 
  
  
 
  
  
1 .17241 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .24138 m 
  
  
 
  
  
1 .24138 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .27586 m 
  
  
 
  
  
1 .27586 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .31034 m 
  
  
 
  
  
1 .31034 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .34483 m 
  
  
 
  
  
1 .34483 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .41379 m 
  
  
 
  
  
1 .41379 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .44828 m 
  
  
 
  
  
1 .44828 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .48276 m 
  
  
 
  
  
1 .48276 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .51724 m 
  
  
 
  
  
1 .51724 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .58621 m 
  
  
 
  
  
1 .58621 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .62069 m 
  
  
 
  
  
1 .62069 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .65517 m 
  
  
 
  
  
1 .65517 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.001 w 
  
  
 
  
  
.99625 .68966 m 
  
  
 
  
  
1 .68966 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.002 w 
  
  
 
  
  
1 0 m 
  
  
 
  
  
1 .75862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
P 
  
  
 
  
  
0 0 m 
  
  
 
  
  
1 0 L 
  
  
 
  
  
1 .75862 L 
  
  
 
  
  
0 .75862 L 
  
  
 
  
  
closepath 
  
  
 
  
  
clip 
  
  
 
  
  
newpath 
  
  
 
  
  
p 
  
  
 
  
  
p 
  
  
 
  
  
.02 w 
  
  
 
  
  
.03448 .03448 m 
  
  
 
  
  
.96552 .03448 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
1 0 0 r 
  
  
 
  
  
p 
  
  
 
  
  
.006 w 
  
  
 
  
  
.03448 .43103 m 
  
  
 
  
  
.31034 .46552 L 
  
  
 
  
  
.2931 .25862 L 
  
  
 
  
  
.03448 .08621 L 
  
  
 
  
  
.03448 .43103 L 
  
  
 
  
  
.2931 .25862 L 
  
  
 
  
  
s 
  
  
 
  
  
.31034 .46552 m 
  
  
 
  
  
.24138 .22845 L 
  
  
 
  
  
.2931 .25862 L 
  
  
 
  
  
s 
  
  
 
  
  
.31034 .46552 m 
  
  
 
  
  
.36207 .53448 L 
  
  
 
  
  
.2931 .25862 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
0 0 1 r 
  
  
 
  
  
p 
  
  
 
  
  
.7953 .22308 m 
  
  
 
  
  
.75358 .53254 L 
  
  
 
  
  
.81925 .37885 L 
  
  
 
  
  
F 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.03 w 
  
  
 
  
  
.83477 .37922 m 
  
  
 
  
  
.81925 .37885 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
p 
  
  
 
  
  
.01 w 
  
  
 
  
  
.40092 .27916 Mdot 
  
  
 
  
  
.33142 .20475 Mdot 
  
  
 
  
  
.24138 .22845 Mdot 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.01 w 
  
  
 
  
  
.7953 .22308 Mdot 
  
  
 
  
  
.75358 .53254 Mdot 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.01 w 
  
  
 
  
  
.36207 .53448 Mdot 
  
  
 
  
  
P 
  
  
 
  
  
0 .8 .2 r 
  
  
 
  
  
p 
  
  
 
  
  
.24138 .22845 m 
  
  
 
  
  
.40092 .27916 L 
  
  
 
  
  
.33142 .20475 L 
  
  
 
  
  
F 
  
  
 
  
  
P 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.6 0 1 r 
  
  
 
  
  
.37706 .27553 m 
  
  
 
  
  
.42479 .28279 L 
  
  
 
  
  
.38593 .53811 L 
  
  
 
  
  
.33821 .53085 L 
  
  
 
  
  
F 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.007 w 
  
  
 
  
  
.75358 .53254 m 
  
  
 
  
  
.33142 .20475 L 
  
  
 
  
  
s 
  
  
 
  
  
.2931 .25862 m 
  
  
 
  
  
.7953 .22308 L 
  
  
 
  
  
s 
  
  
 
  
  
.31034 .46552 m 
  
  
 
  
  
.75358 .53254 L 
  
  
 
  
  
s 
  
  
 
  
  
P 
  
  
 
  
  
p 
  
  
 
  
  
.3 .3 .2 r 
  
  
 
  
  
.84281 .03448 m 
  
  
 
  
  
.98071 .0377 L 
  
  
 
  
  
.96462 .72717 L 
  
  
 
  
  
.82672 .72395 L 
  
  
 
  
  
F 
  
  
 
  
  
P 
  
  
 
  
  
P 
  
  
 
  
  
% End of Graphics 
  
  
 
  
  
MathPictureEnd 
  
  
 
  
  
 
  
  
 
  
 
  
  
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{300, 228},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000i1000`40O003h00Oogoo;Goo003oOol]
Ool00?moobeoo`00ogoo;Goo000KOol00`00Oomoo`0/Ool00`00Oomoo`0XOol50002Ool00`00Oomo
o`0VOol50002Ool00`00Oomoo`0VOol30003Ool00`00Oomoo`0WOol30003Ool00`00Oomoo`0NOol0
01Yoo`03001oo`0002aoo`03001oo`0002]oo`07001oogooOol007oo0000:Goo00L007ooOomoo`00
Ool0000WOol00`00Oomoo`02Ool00`00Ool0000XOol00`00Oomoo`02Ool00`00Ool0000OOol001Yo
o`03001oo`0002ioo`03001oogoo02Uoo`07001oogooOol007oo0000:Goo00<007ooOol00goo00<0
07ooOol09Woo00L007ooOomoo`00Ool0000YOol00`00Oomoo`03Ool00`00Oomoo`0MOol001Yoo`03
001oo`0002aoo`8002aoo`07001oogooOol007oo0000:Goo00@007ooOomoo`8002Uoo`07001oogoo
Ool007oo0000:Goo00@007ooOomoo`80021oo`006Woo00<007oo0000;7oo00<007ooOol0:goo00L0
07ooOomoo`00Ool0000YOol01@00Oomoogoo0000:Goo00<007oo00000Woo00<007oo0000:7oo00<0
07oo00000Woo00<007ooOol07goo000KOol00`00Oomoo`0[Ool3000ZOol20004Ool00`00Oomoo`0W
Ool20003Ool3000XOol00`00Oomoo`02Ool00`00Oomoo`0XOol01000Oomoogoo0`007goo003oOol]
Ool00?moobeoo`00ogoo;Goo003oOol]Ool00?moobeoo`00ogoo;Goo003oOol]Ool00?moobeoo`00
4Wooo`005@001Woo000BOol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Aoo`004Woo00<007ooOol0ogoo4Goo00<007ooOol017oo000BOol0
0`00Oomoo`3oOolAOol00`00Oomoo`04Ool0019oo`03001oogoo0?mooa5oo`03001oogoo00Aoo`00
4Woo00<007ooOol0ogoo4Goo00<007ooOol017oo000BOol00`00Oomoo`3oOolAOol00`00Oomoo`04
Ool000aoo`03001oogoo00=oo`03001oogoo00Eoool000H000Ioo`03001oogoo00Aoo`002goo00<0
07oo000017oo00<007ooOol01Gooo`001P001Woo00<007ooOol017oo000;Ool00`00Ool00004Ool3
0005Oooo00060004Ool30006Ool000]oo`03001oo`0000Aoo`03001oogoo00Eoon0002HU9PEoo`03
001oogoo00Aoo`002goo00<007oo000017oo00<007ooOol01Gooh0009RDV1Goo00<007ooOol017oo
000<Ool00`00Oomoo`03Ool00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo
0>EoobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol0iGoo9RDV1Goo00<007ooOol017oo000B
Ool00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo0>EoobHU9PEoo`03001o
ogoo00Aoo`004Woo00<007ooOol0iGoo9RDV1Goo00<007ooOol017oo000BOol2003VOolV9BH4Ool2
0006Ool0019oo`03001oogoo0>EoobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol0iGoo9RDV
1Goo00<007ooOol017oo000BOol00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001o
ogoo0>EoobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0fgoo9RDV1Goo
00<007ooOol017oo000BOol00`00Oomoo`07Ool3O03KOolV9BH5Ool00`00Oomoo`04Ool0019oo`03
001oogoo00Moo`04O01oogooO03JOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`04
O01oogooOol2O03HOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo00=o
o`03O01oogoo0=EoobHU9PEoo`03001oogoo00Aoo`004Woo0P0027oo00=l07ooOol017oo0W`0eGoo
9RDV17oo0P001Woo000BOol00`00Oomoo`07Ool00g`0Oomoo`06Ool00g`0Oomoo`3BOolV9BH5Ool0
0`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo00Moo`9l0=9oobHU9PEoo`03001oogoo
00Aoo`004Woo00<007ooOol01goo00=l07ooOol02Goo00=l07ooOol0cgoo9RDV1Goo00<007ooOol0
17oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0:Ool2O03?OolV9BH5Ool00`00Oomoo`04Ool0019o
o`03001oogoo00Moo`03O01oogoo00aoo`03O01oogoo0<aoobHU9PEoo`03001oogoo00Aoo`004Woo
00<007ooOol01goo00=l07ooOol03Goo0W`0c7oo9RDV1Goo00<007ooOol017oo000BOol00`00Oomo
o`07Ool00g`0Oomoo`0?Ool00g`0Oomoo`39OolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo
00Moo`03O01oogoo011oo`03O01oogoo0<QoobHU9PEoo`03001oogoo00Aoo`004Woo0P0027oo00=l
07ooOol04Goo0W`0b7oo9RDV17oo0P001Woo000BOol00`00Oomoo`07Ool00g`0Oomoo`0COol00g`0
Oomoo`35OolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo01Aoo`9l0<Eo
obHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol05Woo00=l07ooOol0`Woo
9RDV1Goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0GOol2O032OolV9BH5Ool0
0`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo01Uoo`03O01oogoo0;moobHU9PEoo`03
001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol06Woo0W`0_goo9RDV1Goo00<007ooOol0
17oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0LOol00g`0Oomoo`2lOolV9BH5Ool00`00Oomoo`04
Ool0019oo`03001oogoo00Moo`03O01oogoo01eoo`9l0;aoobHU9PEoo`03001oogoo00Aoo`004Woo
00<007ooOol01goo00=l07ooOol07goo00=l07ooOol0^Goo9RDV1Goo00<007ooOol017oo000BOol2
0008Ool00g`0Oomoo`0POol2O02hOolW9BH4Ool20006Ool0019oo`03001oogoo00Moo`03O01oogoo
029oo`03O01oogoo0;EoobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0
8goo0W`0]Goo9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0UOol00g`0
Oomoo`2bOolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo02Ioo`9l0;9o
obHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0:7oo00=l07ooOol0[goo
9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0YOol2O02_OolV9BH6Ool0
0`00Oomoo`04Ool000aoo`03001oogoo00=oo`03001oogoo00Moo`03O01oogoo02]oo`03O01oogoo
0:aoobHU9PIoo`03001oogoo00Aoo`002goo00<007oo000017oo00<007ooOol01goo00=l07ooOol0
;7oo0W`0[7oo9RDV1Woo00<007ooOol017oo000=Ool00`00Oomoo`02Ool30007Ool00g`0Oomoo`0^
Ool00g`0Oomoo`0MOol00`00Oomoo`29OolV9BH4Ool30006Ool000]oo`8000Eoo`03001oogoo00Mo
o`03O01oogoo02moo`9l01Uoo`D39P03001oogoo08QoobHU9PIoo`03001oogoo00Aoo`002goo00<0
07ooOol017oo00<007ooOol01goo00=l07ooOol0<Goo00=l07ooOol04Woo2P<V0P00R7oo9RDV1Woo
00<007ooOol017oo000;Ool30004Ool00`00Oomoo`07Ool00g`0Oomoo`0bOol00g`0Oomoo`0=Ool?
0bH00goo001oo`26OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03=o
o`9l00Uooa@39P03Ool007oo08EoobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l
07ooOol0=Goo00=l07ooOol00Woo6@<V00=oo`000000LWoo1`002goo9RDV1Woo00<007ooOol017oo
000BOol00`00Oomoo`07Ool00g`0Oomoo`0eOolO0bH2Ool00`00Oomoo`1QOol>0005Ool00`0001mo
o`0:OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03Eoo`04001l07`0
O00L0bH2Ool00`00Oomoo`1BOol>000DOol00`0OOomoo`09OolV9BH6Ool00`00Oomoo`04Ool0019o
o`03001oogoo00Moo`03O01oogoo03Ioo`03O01oog`0009l0003Ool39P<V01P39P9oo`03001oogoo
04=oo`h0029oo`0301moogoo00UoobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l
07ooOol0=Woo00Al07ooOomoo`9l00=ooaP39P9oo`8003Eoo`h0031oo`0301moogoo00UoobHU9PIo
o`03001oogoo00Aoo`004Woo0P0027oo00=l07ooOol0=Woo00=l07ooOol00Woo0g`017oo5P<V0goo
00<007ooOol09Goo3@00?Woo00<07gooOol02Goo9RDV1Goo0P001Woo000BOol00`00Oomoo`07Ool0
0g`0Oomoo`0fOol00g`0Oomoo`04Ool2O006OolD0bH3Ool00`00Oomoo`0FOol>001;Ool00`0OOomo
o`09OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03Moo`03O01oogoo
00Eoo`9l00Mooa839P=oo`8000Qoo`h005Uoo`0301moogoo00UoobHU9PIoo`03001oogoo00Aoo`00
4Woo00<007ooOol01goo00=l07ooOol0=goo00=l07ooOol01Woo0W`02Goo3P<V3P00IWoo0`0O2Woo
9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0gOol00g`0Oomoo`08Ool2
O007Ool>00030bH4Ool00`00Oomoo`1ZOol301l:OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001o
ogoo00Moo`03O01oogoo03Qoo`03O01oogoo00Uoo`L000Moo`/39PAoo`03001oogoo06Uoo`<07`Yo
obHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0>7oo00=l07ooOol01goo
0g`047oo2@<V17oo0P00JGoo0`0O2Woo9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool0
0g`0Oomoo`0hOol00g`0Oomoo`06Ool017`0Oomoog`04goo1`<V1Goo00<007ooOol0IWoo0`0O2Woo
9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0hOol00g`0Oomoo`04Ool2
O003Ool2O00EOol50bH5Ool00`00Oomoo`1UOol301l:OolV9BH6Ool00`00Oomoo`04Ool0019oo`80
00Qoo`03O01oogoo03Uoo`03O01oogoo009oo`03O01oogoo00=oo`9l01Qoo`<39PEoo`8006Eoo`<0
7`YoobHU9PEoo`8000Ioo`004Woo00<007ooOol01goo00=l07ooOol0>Goo00=l07ooOol00W`01Woo
0W`05Goo1d`O1Woo00<007ooOol0HGoo1@0O2Goo9RDV1Woo00<007ooOol017oo000BOol00`00Oomo
o`07Ool00g`0Oomoo`0iOol00g`0Ooml0008Ool2O00EOol=C1l00goo001oo`1QOol501l9OolV9BH6
Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03Uoo`9l00Uoo`03O01oog`001Ao
o`e<7`9oo`03001oogoo05moo`D07`UoobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo
00=l07ooOol0>7oo00=l07ooO0002Woo0W`057oo3D`O0goo0P00Ggoo1@0O2Goo9RDV1Woo00<007oo
Ool017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0fOol2O002Ool00g`0Oomoo`08Ool2O00DOol=
C1l5Ool00`00Oomoo`1LOol501l9OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03
O01oogoo03Eoo`03O01oogoo009oo`03O01oogoo00Qoo`9l01Aoo`e<7`Ioo`03001oogoo05]oo`D0
7`UoobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0<goo0W`01Woo00=l
07ooOol01goo00=l07ooO0004Woo3T`O1goo0P00Fgoo1@0O2Goo9RDV1Woo00<007ooOol017oo000B
Ool00`00Oomoo`07Ool00g`0Oomoo`0bOol00g`0Oomoo`06Ool00g`0Oomoo`07Ool00g`0Ooml000B
Ool>C1l9Ool00`00Oomoo`1GOol701l8OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Mo
o`03O01oogoo031oo`9l00Uoo`03O01oogoo00Moo`03O01oog`0019oo`e<7`]oo`03001oogoo05Io
o`L07`QoobHU9PIoo`03001oogoo00Aoo`004Woo0P0027oo00=l07ooOol0;goo00=l07ooOol02Woo
00=l07ooOol01Woo00=l07ooO0004Woo3D`O37oo0P00EWoo1`0O1goo9bDV1Goo0P001Woo000BOol0
0`00Oomoo`07Ool00g`0Oomoo`0]Ool2O00=Ool00g`0Oomoo`06Ool017`0Oomoog`04Goo3D`O3Woo
00<007ooOol0Dgoo1`0O1goo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomo
o`0/Ool00g`0Oomoo`0=Ool00g`0Oomoo`06Ool017`0Oomoog`04Goo3D`O3goo00<007ooOol0DWoo
1`0O1goo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0ZOol2O00@Ool0
0g`0Oomoo`06Ool017`0Oomoog`047oo3T`O47oo00<007ooOol0DGoo1`0O1goo9RDV1goo00<007oo
Ool017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0YOol00g`0Oomoo`0AOol00g`0Oomoo`05Ool0
17`0Oomoog`047oo3T`O4Goo0P00DGoo1`0O1goo9RDV1goo00<007ooOol017oo000BOol00`00Oomo
o`07Ool00g`0Oomoo`0WOol2O00DOol00g`0Oomoo`05Ool01G`0OomoogooO0003goo3D`O57oo00<0
07ooOol0CGoo2@0O1Woo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0V
Ool00g`0Oomoo`0DOol00g`0Oomoo`05Ool01G`0OomoogooO0003goo3D`O5Goo00<007ooOol0C7oo
2@0O1Woo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0TOol2O00HOol0
0g`0Oomoo`04Ool01G`0OomoogooO0003goo3D`O5Woo0P00C7oo2@0O1Woo9RDV1goo00<007ooOol0
17oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0SOol00g`0Oomoo`0HOol00g`0Oomoo`05Ool017`0
Oomoog`03goo3D`O67oo00<007ooOol0BGoo2@0O1Woo9RDV1goo00<007ooOol017oo000BOol20008
Ool00g`0Oomoo`0QOol2O00KOol00g`0Oomoo`05Ool01G`0OomoogooO0003Woo3D`O6Goo00<007oo
Ool0B7oo2@0O1Woo9RDV1Woo0P001Woo000BOol00`00Oomoo`07Ool00g`0Oomoo`0OOol2O00MOol0
0g`0Oomoo`05Ool01G`0OomoogooO0003Goo3T`O6Woo00<007ooOol0Agoo2@0O1Woo9RDV1goo00<0
07ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0NOol00g`0Oomoo`0NOol00g`0Oomoo`04
Ool01G`0OomoogooO0003Goo3T`O6goo0P00Agoo2@0O1Woo9RDV1goo00<007ooOol017oo000BOol0
0`00Oomoo`07Ool00g`0Oomoo`0LOol2O00QOol00g`0Oomoo`04Ool01G`0OomoogooO0003Goo3D`O
7Woo00<007ooOol0@goo2`0O1Goo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0
Oomoo`0KOol00g`0Oomoo`0QOol00g`0Oomoo`04Ool00g`0Oomoo`02Ool00g`0Oomoo`0:Ool=C1lO
Ool00`00Oomoo`12Ool;01l5OolV9BH7Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01o
ogoo01Uoo`9l02Eoo`03O01oogoo00=oo`03O01oogoo009oo`03O01oogoo00Yoo`e<7b1oo`80049o
o`/07`EoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol067oo00=l07oo
Ool09Goo00=l07ooOol00goo00=l07ooOol00Woo00=l07ooOol02Woo3D`O8Woo00<007ooOol0?goo
2`0O1Goo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0FOol2O00XOol0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`09Ool>C1lSOol00`00Oomoo`0nOol@01lV9BH7
Ool00`00Oomoo`04Ool000Eoo`D0009oo`03001oogoo00=oo`03001oogoo00Moo`03O01oogoo01Eo
o`03O01oogoo02Uoo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Qoo`i<7bAoo`03001o
ogoo03eooa007bHU9PMoo`03001oogoo00Aoo`001goo00L007ooOomoo`00Ool00004Ool00`00Oomo
o`07Ool00g`0Oomoo`0COol2O00/Ool00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`08Ool=
C1lVOol2000mOol@01lV9BH7Ool00`00Oomoo`04Ool000Moo`07001oogooOol007oo000017oo0`00
1goo00=l07ooOol04Woo00=l07ooOol0;7oo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol0
27oo3D`O:7oo00<007ooOol0>Goo4@0O9RDV1Goo0`001Woo0007Ool01`00Oomoogoo001oo`0000Ao
o`03001oogoo00Moo`03O01oogoo011oo`9l02moo`03O01oogoo009oo`03O01oogoo00=oo`03O01o
ogoo00Qoo`e<7bUoo`03001oogoo03Qooa407bHU9PMoo`03001oogoo00Aoo`001goo00L007ooOomo
o`00Ool00004Ool00`00Oomoo`07Ool00g`0Oomoo`0?Ool00g`0Oomoo`0`Ool01G`0OomoogooO000
1Woo00=l07ooOol01goo3D`O:Woo0P00>7oo4@0O9RDV1goo00<007ooOol017oo0006Ool20004Ool0
0`00Oomoo`03Ool00`00Oomoo`07Ool00g`0Oomoo`0=Ool2O00cOol00g`0Oomoo`02Ool00g`0Oomo
o`03Ool00g`0Oomoo`07Ool=C1l/Ool00`00Oomoo`0eOolA01lV9BH7Ool00`00Oomoo`04Ool0019o
o`03001oogoo00Moo`03O01oogoo00aoo`03O01oogoo03=oo`03O01oogoo009oo`03O01oogoo00=o
o`03O01oogoo00Ioo`i<7beoo`03001oogoo03Aooa407bHU9PMoo`03001oogoo00Aoo`004Woo00<0
07ooOol01goo00=l07ooOol02Woo0W`0=goo00El07ooOomoog`000Eoo`03O01oogoo00Ioo`i<7bio
o`03001oogoo03=oo`X07`MoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07oo
Ool02Goo00=l07ooOol0=goo00El07ooOomoog`000Ioo`03O01oogoo00Eoo`e<7c1oo`8003=oo`X0
7`MoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol01goo0W`0>Woo00El
07ooOomoog`000Ioo`03O01oogoo00Eoo`e<7c9oo`03001oogoo02moo`X07`QoobHU9PMoo`03001o
ogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol01Woo00=l07ooOol0>Woo00El07ooOomoog`0
00Ioo`03O01oogoo00Eoo`e<7c=oo`03001oogoo02ioo`X07`QoobHU9PMoo`03001oogoo00Aoo`00
4Woo0P0027oo00=l07ooOol017oo0W`0?Woo00Al07ooOoml00Ioo`03O01oogoo00Eoo`e<7cAoo`80
02ioo`X07`QoobHU9PIoo`8000Ioo`004Woo00<007ooOol01goo00=l07ooOol00goo00=l07ooOol0
?Woo00Al07ooOoml00Moo`03O01oogoo00=oo`i<7cIoo`03001oogoo02]oo`T07`UoobHU9PMoo`03
001oogoo00Aoo`004Woo00<007ooOol01goo00Al07ooOomoo`9l045oo`04O01oogooO007Ool00g`0
Oomoo`03Ool>C1lgOol00`00Oomoo`0ZOol901l9OolV9BH7Ool00`00Oomoo`04Ool0019oo`03001o
ogoo00Moo`04O01oogooO014Ool00g`0Ooml0007Ool00g`0Oomoo`03Ool=C1liOol00`00Oomoo`0Y
Ool801l:OolV9BH7Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`=l04Eoo`03O01oog`000Mo
o`03O01oogoo00=oo`e<7cYoo`8002Uoo`P07`YoobHU9PMoo`03001oogoo00Aoo`004Woo00<007oo
Ool01goo17`0A7oo00=l07ooO00027oo00=l07ooOol00Woo3D`O?7oo00<007ooOol09Goo200O2goo
9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`0;Ool8O00lOol00g`0Ooml0008Ool00g`0Oomo
o`02Ool=C1lmOol00`00Oomoo`0TOol801l;OolV9BH7Ool00`00Oomoo`04Ool0019oo`03001oogoo
01=oo`Ml03Ioo`9l00Qoo`03O01oogoo009oo`e<7cioo`8002Aoo`P07`]oobHU9PMoo`03001oogoo
00Aoo`004Woo00<007ooOol06Woo27`0;Woo00=l07ooO0001goo00Al07ooOomoo`i<7d1oo`03001o
ogoo025oo`L07`aoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol08Woo1g`09goo00=l07oo
O00027oo00=l07ooOol03T`O@Goo00<007ooOol087oo1`0O37oo9RDV1goo00<007ooOol017oo000B
Ool2000ZOol8O00POol2O008Ool00g`0Oomoo`0=C1m3Ool00`00Oomoo`0OOol601l<OolW9BH6Ool2
0006Ool0019oo`03001oogoo035oo`Ml01Uoo`9l00Qoo`03O01oogoo00e<7dAoo`8001moo`H07`ao
obHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0>7oo27`04Goo0W`027oo00=l07ooOol03D`O
AWoo00<007ooOol06goo1P0O3Goo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`10Ool7O00:
Ool2O009Ool00g`0Oom<7`0<C1m7Ool00`00Oomoo`0JOol601l=OolV9BH8Ool00`00Oomoo`04Ool0
019oo`03001oogoo04Moo`Ql00=oo`03O01oogoo00Moo`03O01<7d`O00a<7dQoo`8001Yoo`H07`eo
obHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0Cgoo0g`010001Woo00=l04`OC1l034`OBWoo
00<007ooOol05goo1@0O3Woo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`1COol00g`0Oomo
o`07000=C1m<Ool00`00Oomoo`0FOol501l>OolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo
05Aoo`03O01oogoo00Ioo`H000M<7deoo`8001Ioo`@07`moobHU9PQoo`03001oogoo00Aoo`004Woo
00<007ooOol0E7oo00=l07ooOol01Woo1T`O1`00Cgoo00<007ooOol04goo100O3goo9RDV27oo00<0
07ooOol017oo000BOol2001FOol00g`0Oomoo`05Ool=C1l70019Ool00`00Oomoo`0AOol401l@OolV
9BH7Ool20006Ool0019oo`03001oogoo05Ioo`03O01oogoo00Aoo`e<7`Moo`L004=oo`03001oogoo
011oo`@07a1oobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0Egoo00=l07ooOol00Woo3T`O
3Woo1`00?Goo0P0047oo100O47oo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`1HOol017`0
Oomoogoo3T`O5Goo1P00>Goo00<007ooOol03Goo0`0O4Goo9RDV27oo00<007ooOol017oo000BOol0
0`00Oomoo`1HOol017`0Oomoogoo3D`O77oo1`00<goo00<007ooOol037oo0`0O4Goo9RDV27oo00<0
07ooOol017oo000BOol00`00Oomoo`1IOol00g`0Oomoo`0=C1lSOol7000]Ool2000<Ool201lBOolV
9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo05Yoo`03O01ood`O00a<7bYoo`L002Qoo`03001o
ogoo00Uoo`807a9oobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0Fgoo00=l04`OC1l02d`O
<Goo1P008goo00<007ooOol01goo0P0O4goo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`1K
Ool>C1lgOol7000MOol00`00Oomoo`06Ool201lCOolV9BH8Ool00`00Oomoo`04Ool0019oo`03001o
ogoo05]oo`i<7cioo`L001Moo`8000Ioo`807a=oobHU9PQoo`03001oogoo00Aoo`004Woo0P00G7oo
3D`OAWoo1`004Woo00<007ooOol00goo00<07gooOol04Woo9RDV1goo0P001Woo000BOol00`00Oomo
o`1KOol=C1m=Ool7000<Ool00`00Oomoo`02Ool00`0OOomoo`0BOolV9BH8Ool00`00Oomoo`04Ool0
019oo`03001oogoo05]oo`e<7eAoo`H000Moo`8001MoobHU9PQoo`03001oogoo00Aoo`004Woo00<0
07ooOol0Fgoo3D`OFWoo1`000Woo00<007ooOol057oo9RDV27oo00<007ooOol017oo000BOol00`00
Oomoo`1JOol>C1mQOol4000EOolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo061oo`03001<
7d`O00E<7f=oo`03001oogoo01AoobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0hWoo9RDV
27oo00<007ooOol017oo0005Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`3ROolV9BH8Ool00`00
Oomoo`04Ool000Moo`07001oogooOol007oo000017oo00<007ooOol0hWoo9RDV27oo00<007ooOol0
17oo0007Ool00`00Oomoo`03Ool00`00Oomoo`02Ool3003ROolV9BH6Ool30006Ool000Moo`04001o
ogooOol20005Ool00`00Oomoo`3ROolV9BH8Ool00`00Oomoo`04Ool000Moo`05001oogooOol00006
Ool00`00Oomoo`3ROolV9BH8Ool00`00Oomoo`04Ool000Ioo`8000=oo`<000Aoo`03001oogoo0>9o
obHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0hWoo9RDV27oo00<007ooOol017oo000BOol0
0`00Oomoo`3ROolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo0>9oobHU9PQoo`03001oogoo
00Aoo`004Woo00<007ooOol0hWoo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`3ROolV9BH8
Ool00`00Oomoo`04Ool0019oo`03001oogoo0>9oobHU9PQoo`03001oogoo00Aoo`004Woo0P00hWoo
9bDV1goo0P001Woo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo
0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000B
Ool00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001o
ogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV
9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo0P00
hWoo9RDV27oo0P001Woo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001o
ogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo
000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03
001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3Q
OolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo
00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol2003ROolV9BH8Ool20006Ool0019oo`03
001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol0
17oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUo
o`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomo
o`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`00
4Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol2003ROolV9BH8Ool20006Ool0019o
o`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007oo
Ool017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU
9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00
Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Ao
o`001Woo0`000goo00<007ooOol00goo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo0006Ool0
0`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool000Moo`07
001oogooOol007oo000017oo0`00h7oo9bDV1goo0`001Woo0007Ool01`00Oomoogoo001oo`0000Ao
o`03001oogoo0?mooa5oo`03001oogoo00Aoo`001Woo00<007oo00000Woo00<007oo000017oo00<0
07ooOol0ogoo4Goo00<007ooOol017oo0007Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`3oOolAOol00`00Oomoo`04Ool0019oo`03001oogoo0?mooa5oo`03001oogoo00Aoo`004Woo00<0
07ooOol0ogoo4Goo00<007ooOol017oo000BOol00`00Oomoo`3oOolAOol00`00Oomoo`04Ool0019o
o`03001oogoo0?mooa5oo`03001oogoo00Aoo`004Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<0
07ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo00<007ooOol017oo000BOooo000E0006Ool00001\
\>"],
  ImageRangeCache->{{{0, 299}, {227, 0}} -> {-2.95149, -2.89736, 0.105403, 
  0.105403}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four body objects are defined for the pull-rod suspension model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground body (body 1) requires two point definitions. \nP1 is the origin \
of the ground body.\nP2 is a point directly above the origin that defines a \
vertical translation line upon which the chassis slides."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The chassis (body 2) requires six local point definitions.\nP1 is the local \
origin, which is a point at the bottom of the chassis.\nP2 is a second point \
that, with P1, defines the vertical translation line of the chassis.\nP3 is \
the pivot point of the lower A-arm.\nP4 is the pivot point of the upper \
A-arm.\nP5 is the pivot point of the rocker.\nP6 is the upper mounting point \
of the shock absorber."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The wheel carrier (body 3) requires three local point definitions.\nP1 is \
the local origin, which is the attachment point of the lower A-arm.\nP2 is \
the attachment point of the upper A-arm and the pull-rod.\nP3 is the bottom \
of the tire where the tire contacts the road."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The rocker arm (body 4) requires three local point definitions.\nP1 is the \
local origin, which is the rotational axis of the rocker.\nP2 is the lower \
attachment point of the shock absorber.\nP3 is the attachment point of the \
connecting rod."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are each of the bodies in the pull-rod model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .76667 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.018254 0.47619 [
[ -0.001 -0.001 0 0 ]
[ 1.001 .76767 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 .76667 L
s
P
P
p
p
.002 w
0 .76667 m
1 .76667 L
s
P
p
.002 w
1 0 m
1 .76667 L
s
P
P
p
P
0 0 m
1 0 L
1 .76667 L
0 .76667 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.018254 0.477324 0.365949 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.0333333 0.0666667 0.0333333 [
[ 0 0 0 0 ]
[ 1 .76667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .76667 L
0 .76667 L
closepath
clip
newpath
p
p
p
0 0 1 r
p
.80212 .24898 m
.7618 .54812 L
.82528 .39956 L
F
P
P
p
.03 w
.84028 .39991 m
.82528 .39956 L
s
P
p
.3 .3 .2 r
.84805 .06667 m
.98135 .06978 L
.9658 .73626 L
.8325 .73315 L
F
P
p
.01 w
.80212 .24898 Mdot
.7618 .54812 Mdot
P
P
p
[(P1)] .80212 .24898 1 1.6 Mshowa
[(P2)] .7618 .54812 1 -1.6 Mshowa
[(P3)] .84805 .06667 0 1.6 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.018254 0.97619 0.365949 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.0333333 0.0666667 0.0333333 [
[ 0 0 0 0 ]
[ 1 .76667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .76667 L
0 .76667 L
closepath
clip
newpath
p
p
p
.01 w
.41745 .31294 Mdot
.34844 .23814 Mdot
.26667 .25417 Mdot
P
0 .8 .2 r
p
.26667 .25417 m
.41745 .31294 L
.34844 .23814 L
F
P
P
p
[(P1)] .26667 .25417 1.6 0 Mshowa
[(P2)] .41745 .31294 -1.6 0 Mshowa
[(P3)] .34844 .23814 0 1.6 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.400718 0.477324 0.748413 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.0333333 0.0666667 0.0333333 [
[ 0 0 0 0 ]
[ 1 .76667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .76667 L
0 .76667 L
closepath
clip
newpath
p
p
p
1 0 0 r
p
.006 w
.06667 .48333 m
.33333 .48333 L
.31667 .28333 L
.06667 .15 L
.06667 .48333 L
.26667 .25417 L
s
.33333 .48333 m
.26667 .25417 L
s
.33333 .48333 m
.38333 .55 L
.31667 .28333 L
s
P
P
p
.01 w
.31667 .28333 Mdot
.33333 .48333 Mdot
.38333 .55 Mdot
P
P
p
[(P1)] .06667 .15 1.5 0 Mshowa
[(P2)] .06667 .48333 1.5 0 Mshowa
[(P3)] .31667 .28333 -1.5 1.2 Mshowa
[(P4)] .33333 .48333 1.5 -1.8 Mshowa
[(P5)] .26667 .25417 -1.5 1.2 Mshowa
[(P6)] .38333 .55 0 -1.6 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.400718 0.97619 0.748413 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.0333333 0.0666667 0.0333333 [
[ 0 0 0 0 ]
[ 1 .76667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .76667 L
0 .76667 L
closepath
clip
newpath
p
p
p
.02 w
.06667 .06667 m
.96667 .06667 L
s
P
p
.6 0 1 r
.39435 .30961 m
.44054 .31626 L
.40643 .55332 L
.36024 .54668 L
F
P
p
.007 w
.7618 .54812 m
.34844 .23814 L
s
.31667 .28333 m
.80212 .24898 L
s
.33333 .48333 m
.7618 .54812 L
s
P
P
p
[(Shock)] .38333 .55 0 -1.8 Mshowa
[(Upper A-arm)] .7618 .54812 0 -1.5 Mshowa
[(Lower A-arm)] .80212 .24898 0 1.5 Mshowa
[(Pull-Rod)] .7618 .54812 .4 9.2 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{480, 367},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007P0001Ka000`40O003h00OogoohGoo00000goo
0000003o003L0002Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@00
0Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`00
00=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo
0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol1
0001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo
00000goo001oo`2kOol30003Ool2003oOolHOol10001Ool1Ool00003Ool007oo0;aoo`03001oogoo
00Aoo`03001oogoo0?mooaEoo`40005oo`5oo`0000=oo`00Ool0_7oo0`000goo00<007ooOol0ogoo
5Woo0@000Goo0Goo00000goo001oo`2lOol01000Oomoo`000goo00<007ooOol0ogoo5Goo0@000Goo
0Goo00000goo001oo`2lOol02000Oomoo`00Ool007oo003oOolGOol10001Ool1Ool00003Ool007oo
0;]oo`@000=oo`03001oogoo0?mooaIoo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo
00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00
Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]o
o`40005oo`5oo`0000=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo00000goo001oo`30OolM9BKmOol1
0001Ool1Ool00003Ool007oo0<1ooadU9_eoo`40005oo`5oo`0000=oo`00Ool0`7oo7BDVoGoo0@00
0Goo0Goo00000goo001oo`30OolM9BKmOol10001Ool1Ool00003Ool007oo0<1ooadU9_eoo`40005o
o`5oo`0000=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo00000goo001oo`30OolM9BKmOol10001Ool1
Ool00003Ool007oo0<1ooadU9_eoo`40005oo`5oo`0000=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo
00000goo001oo`30OolM9BKmOol10001Ool1Ool00003Ool007oo0<1ooadU9_eoo`40005oo`5oo`00
00=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo00000goo001oo`30OolM9BKmOol10001Ool1Ool00003
Ool007oo0<1ooadU9_eoo`40005oo`5oo`0000=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo00000goo
001oo`30OolM9BKmOol10001Ool1Ool00003Ool007oo0<1ooadU9_eoo`40005oo`5oo`0000=oo`00
Ool0`7oo7BDVoGoo0@000Goo0Goo00000goo001oo`30OolM9BKmOol10001Ool1Ool00003Ool007oo
0<1ooadU9_eoo`40005oo`5oo`0000=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo00000goo001oo`30
OolM9BKmOol10001Ool1Ool00003Ool007oo0<1ooadU9_eoo`40005oo`5oo`0000=oo`00Ool0`7oo
7BDVoGoo0@000Goo0Goo00000goo001oo`30OolM9BIPOol30003Ool2002EOol10001Ool1Ool00003
Ool007oo0<1ooadU9V5oo`03001oogoo00Aoo`03001oogoo099oo`40005oo`5oo`0000=oo`00Ool0
[7oo0`000Woo1@002Woo7BDVHGoo0`000goo00<007ooOol0Tgoo0@000Goo0Goo00000goo001oo`2]
Ool00`00Oomoo`03Ool00`00Oomoo`0:OolM9BIQOol01000Oomoo`000goo00<007ooOol0TWoo0@00
0Goo0Goo00000goo001oo`2]Ool30003Ool00`00Oomoo`0:OolM9BIQOol02000Oomoo`00Ool007oo
002DOol10001Ool1Ool00003Ool007oo0:eoo`04001oogoo0002Ool00`00Oomoo`0:OolM9BIPOol4
0003Ool00`00Oomoo`2COol10001Ool1Ool00003Ool007oo0:eoo`04001oogoo0002Ool00`00Oomo
o`0:OolM9BKmOol10001Ool1Ool00003Ool007oo0:aoo`@0009oo`8000aooadU9_eoo`40005oo`5o
o`0000=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo00000goo001oo`30OolM9BKmOol10001Ool1Ool0
0003Ool007oo0<1ooadU9_eoo`40005oo`5oo`0000=oo`00Ool0`7oo7BDVoGoo0@000Goo0Goo0000
0goo001oo`30OolM9BIQOol50bJGOol10001Ool1Ool00003Ool007oo0<1ooadU9TIoo`<0009oo`D0
00aoo`/39YIoo`40005oo`5oo`0000=oo`00Ool0]Woo00<007ooOol01goo7BDVAgoo00<007ooOol0
0goo00<007ooOol027oo40<VUGoo0@000Goo0Goo00000goo001oo`2fOol00`0OOomoo`07OolM9BI7
Ool30003Ool00`00Oomoo`03OolF0bJDOol10001Ool1Ool00003Ool007oo0;Ioo`0301moogoo00Mo
oadU9TMoo`04001oogoo0002Ool00`00Oomoo`06OolD0bJCOol10001Ool1Ool00003Ool007oo0;Io
o`0301moogoo00MooadU9TMoo`04001oogoo0002Ool00`00Oomoo`09OolB0bJBOol10001Ool1Ool0
0003Ool007oo0;Ioo`0301moogoo00MooadU9TIoo`@0009oo`8000iooa039Y5oo`40005oo`5oo`00
00=oo`00Ool0]Woo00<07gooOol01goo7BDVGWoo3`<VT7oo0@000Goo0Goo00000goo001oo`2fOol2
01l8OolM9BIQOol=0bJ?Ool10001Ool1Ool00003Ool007oo0;Ioo`807`QooadU9VAoo`/39Xioo`40
005oo`5oo`0000=oo`00Ool0]Goo0`0O1goo7RDVIgoo2@<VSGoo0@000Goo0Goo00000goo001oo`2e
Ool301l7OolM9BIZOol80bJ<Ool10001Ool1Ool00003Ool007oo0;Eoo`<07`MooadU9Veoo`H39X]o
o`40005oo`5oo`0000=oo`00Ool0]Goo0`0O1goo7BDVL7oo10<V17oo0`000goo0`00OGoo0@000Goo
0Goo00000goo001oo`2eOol301l7OolM9BIcOol20bH4Ool00`00Oomoo`02Ool00`00Oomoo`1mOol1
0001Ool1Ool00003Ool007oo0;Eoo`@07`IooadU9WUoo`<000=oo`03001oogoo07aoo`40005oo`5o
o`0000=oo`00Ool0]Goo100O1Woo7BDVM7oo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo
07aoo`40005oo`5oo`0000=oo`00Ool0]Goo100O1Woo7BDVNGoo00P007ooOol007oo001oo`00OGoo
0@000Goo0Goo00000goo001oo`2dOol501l6OolM9BIhOol40003Ool00`00Oomoo`1lOol10001Ool1
Ool00003Ool007oo0;Aoo`D07`IooadU9_ioo`40005oo`5oo`0000=oo`00Ool0]7oo1@0O1Woo7BDV
oWoo0@000Goo0Goo00000goo001oo`2dOol601l5OolM9BKnOol10001Ool1Ool00003Ool007oo0;Ao
o`H07`EooadU9_ioo`40005oo`5oo`0000=oo`00Ool0]7oo1P0O1Goo7BDVoWoo0@000Goo0Goo0000
0goo001oo`2dOol601l5OolM9BKnOol10001Ool1Ool00003Ool007oo0;Aoo`H07`EooadU9_ioo`40
005oo`5oo`0000=oo`00Ool0/goo1`0O1Goo7BDVoWoo0@000Goo0Goo00000goo001oo`2cOol701l5
OolM9BKnOol10001Ool1Ool00003Ool007oo0;=oo`P07`AooadU9_ioo`40005oo`5oo`0000=oo`00
Ool0/goo200O17oo7BDVoWoo0@000Goo0Goo00000goo001oo`2cOol801l4OolM9BKnOol10001Ool1
Ool00003Ool007oo0;=oo`P07`AooadU9_ioo`40005oo`5oo`0000=oo`00Ool0/goo1@0O1`007BDV
oWoo0@000Goo0Goo00000goo001oo`2cOol501l7000M9BKnOol10001Ool1Ool00003Ool007oo0;9o
o`H07`L001dU9_ioo`40005oo`5oo`0000=oo`00Ool0/Woo1P0O1`007BDVoWoo0@000Goo0Goo0000
0goo001oo`2bOol601l7000M9BKnOol10001Ool1Ool00003Ool007oo0;9oo`H07`L001dU9_ioo`40
005oo`5oo`0000=oo`00Ool0/Woo200O1Goo7BDVoWoo0@000Goo0Goo00000goo001oo`2bOol701l6
OolM9BKnOol10001Ool1Ool00003Ool007oo0;9oo`L07`IooadU9_ioo`40005oo`5oo`0000=oo`00
Ool0/Woo1`0O1Woo7BDVoWoo0@000Goo0Goo00000goo001oo`2aOol701l7OolM9BKnOol10001Ool1
Ool00003Ool007oo0;5oo`L07`MooadU9_ioo`40005oo`5oo`0000=oo`00Ool0/Goo1P0O27oo7BDV
oWoo0@000Goo0Goo00000goo001oo`2aOol601l8OolM9BKnOol10001Ool1Ool00003Ool007oo0;5o
o`H07`QooadU9_ioo`40005oo`5oo`0000=oo`00Ool0/Goo1@0O2Goo7BDVoWoo0@000Goo0Goo0000
0goo001oo`2aOol501l9OolM9BKnOol10001Ool1Ool00003Ool007oo0;5oo`@07`YooadU9_ioo`40
005oo`5oo`0000=oo`00Ool0/7oo1@0O2Woo7BDVoWoo0@000Goo0Goo00000goo001oo`2`Ool501l:
OolM9BKnOol10001Ool1Ool00003Ool007oo0;1oo`@07`]ooadU9_ioo`40005oo`5oo`0000=oo`00
Ool0/7oo100O2goo7BDVoWoo0@000Goo0Goo00000goo001oo`2`Ool301l<OolM9BKnOol10001Ool1
Ool00003Ool007oo0;1oo`<07`aooadU9_ioo`40005oo`5oo`0000=oo`00Ool0/7oo0`0O37oo7BDV
oWoo0@000Goo0Goo00000goo001oo`2`Ool201l=OolM9BKnOol10001Ool1Ool00003Ool007oo0:mo
o`<07`aooahU9_ioo`40005oo`5oo`0000=oo`00Ool0[goo0P0O3Goo7BDVogoo0@000Goo0Goo0000
0goo001oo`2_Ool201l=OolM9BKoOol10001Ool1Ool00003Ool007oo0:moo`807`eooadU9_moo`40
005oo`5oo`0000=oo`00Ool0[goo00<07gooOol037oo7BDVogoo0@000Goo0Goo00000goo001oo`2_
Ool00`0OOomoo`0<OolM9BKoOol10001Ool1Ool00003Ool007oo0;iooadU9_moo`40005oo`5oo`00
00=oo`00Ool0_Woo7BDVogoo0@000Goo0Goo00000goo001oo`2nOolM9BKoOol10001Ool1Ool00003
Ool007oo0:eoo`03001oogoo00iooadU9_moo`40005oo`5oo`0000=oo`00Ool0_Woo7BDVogoo0@00
0Goo0Goo00000goo001oo`2nOolM9BKoOol10001Ool1Ool00003Ool007oo0;iooadU9_moo`40005o
o`5oo`0000=oo`00Ool0_Woo7BDVogoo0@000Goo0Goo00000goo001oo`2nOolM9BKoOol10001Ool1
Ool00003Ool007oo0;iooadU9_moo`40005oo`5oo`0000=oo`00Ool0Y7oo0`000goo0`004Goo7BDV
ogoo0@000Goo0Goo00000goo001oo`2UOol00`00Oomoo`02Ool00`00Oomoo`0AOolM9BKoOol10001
Ool1Ool00003Ool007oo0:Eoo`<000=oo`03001oogoo011ooadU9_moo`40005oo`5oo`0000=oo`00
Ool0YGoo00@007ooOol0009oo`03001oogoo011ooadU9_moo`40005oo`5oo`0000=oo`00Ool0YGoo
00P007ooOol007oo001oo`004Goo7BDVogoo0@000Goo0Goo00000goo001oo`2TOol40003Ool00`00
Oomoo`0@OolM9BKoOol10001Ool1Ool00003Ool007oo0;iooadU9_moo`40005oo`5oo`0000=oo`00
Ool0_Woo7BDVogoo0@000Goo0Goo00000goo001oo`2nOolM9BKoOol10001Ool1Ool00003Ool007oo
0;iooadU9_moo`40005oo`5oo`0000=oo`00Ool0_Woo7BDVogoo0@000Goo0Goo00000goo001oo`2n
OolM9BKoOol10001Ool1Ool00003Ool007oo0;iooadU9_moo`40005oo`5oo`0000=oo`00Ool0_Woo
7BDVogoo0@000Goo0Goo00000goo001oo`2nOolM9BKoOol10001Ool1Ool00003Ool007oo0;iooadU
9_moo`40005oo`5oo`0000=oo`00Ool0_Woo7BDVogoo0@000Goo0Goo00000goo001oo`2nOolM9BKo
Ool10001Ool1Ool00003Ool007oo0;iooadU9_moo`40005oo`5oo`0000=oo`00Ool0_Woo7BDVogoo
0@000Goo0Goo00000goo001oo`2nOolM9BKoOol10001Ool1Ool00003Ool007oo0;iooadU9_moo`40
005oo`5oo`0000=oo`00Ool0_Woo7BDVogoo0@000Goo0Goo00000goo001oo`2nOolM9BKoOol10001
Ool1Ool00003Ool007oo0;iooadU9_moo`40005oo`5oo`0000=oo`00Ool0_Woo7BDVogoo0@000Goo
0Goo00000goo001oo`2nOolM9BKoOol10001Ool1Ool00003Ool007oo0;iooadU9_moo`40005oo`5o
o`0000=oo`00Ool0_Woo7BDVogoo0@000Goo0Goo00000goo001oo`2nOolM9BKoOol10001Ool1Ool0
0003Ool007oo0;iooadU9_moo`40005oo`5oo`0000=oo`00Ool0_Woo7BDVogoo0@000Goo0Goo0000
0goo001oo`2mOolN9BKoOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00
Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]o
o`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1
Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo
001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoo
fgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005o
o`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003
Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3o
OooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@00
0Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`00
00=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo
0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol1
0001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo
00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00
Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]o
o`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1
Ool00003Ool007oo0?moo`AoolH0015oo`40005oo`5oo`0000=oo`00Ool0ogoo17ooaP004Goo0@00
0Goo0Goo00000goo001oo`3oOol4Ooo6000AOol10001Ool1Ool00003Ool007oo0?moo`AoolH0015o
o`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1
Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo
001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoo
fgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005o
o`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003
Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`0;
Ool30002Ool5003oOoo6Ool10001Ool1Ool00003Ool007oo00aoo`03001oogoo00=oo`03001oogoo
0?moolIoo`40005oo`5oo`0000=oo`00Ool037oo0`000goo00<007ooOol00goo00=l07ooOol0ogoo
`7oo0@000Goo0Goo00000goo001oo`0<Ool01000Oomoo`000Woo00<007ooOol00goo0g`0ogoo`7oo
0@000Goo0Goo00000goo001oo`0<Ool01000Oomoo`000Woo00<007ooOol00goo00=l07ooOol00W`0
ogoo_Woo0@000Goo0Goo00000goo001oo`0;Ool40002Ool20005Ool00g`0Oomoo`02Ool2O03oOonl
Ool10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo00Aoo`9l0?mookYoo`40005oo`5oo`0000=o
o`00Ool067oo00=l07ooOol01Woo0W`0ogoo^7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomo
o`08Ool2O03oOonfOol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo00Yoo`03O01oogoo0?mo
ok=oo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol02goo0W`0ogoo/goo0@000Goo0Goo0000
0goo001oo`0HOol00g`0Oomoo`0=Ool2O03oOonaOol10001Ool1Ool00003Ool007oo01Qoo`03O01o
ogoo00moo`9l0?moojmoo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol04Goo0W`0ogooFgoo
1@000Woo0P000Woo00<007oo00000goo0P000Woo0`001Woo0P0000=oo`0000001Woo100000Yoo`00
000007oo001oo`00Ool001]oo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol04goo0W`0ogoo
FWoo00H007ooOol007oo0002Ool200001Woo001oo`00Ool000Eoo`03001oogoo00Eoo`05001oogoo
Ool00006Ool30003Ool02000Oomoo`00Ool007oo000KOol10001Ool1Ool00003Ool007oo01Qoo`03
O01oogoo01Eoo`9l0?mooeQoo`03001oogoo009oo`03001oogoo00800005Ool007oo001oo`030003
Ool00`00Oomoo`06Ool30002Ool30004Ool01@00Oomoogoo00000Woo00D007oo001oo`0001]oo`40
005oo`5oo`0000=oo`00Ool067oo00=l07ooOol05goo00=l07ooOol047oo0`0017oo00<007ooOol0
ogoo>goo00<007ooOol00goo0P0000Aoo`00001oo`800004Ool000000002Ool40006Ool00`00Ool0
0008Ool20002Ool600000goo001oo`0KOol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo01Qo
o`9l015oo`03001oogoo009oo`03001oo`000?moocaoo`03001oogoo01aoo`03001oogoo02moo`40
005oo`5oo`0000=oo`00Ool067oo00=l07ooOol06Woo0W`03goo0`0017oo00<007ooOol0ogoo>Goo
0`0077oo0P00<Goo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0LOol2O00=Ool01@00Oomo
o`00Ool00P00ogooSWoo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0NOol2O00;Ool01P00
Oomoo`00Ool00?moohmoo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol087oo0W`027oo1000
0Woo0`00m7oo00<007ooOol0UGoo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0ROol2O00A
Ool30003Ool2003[Ool00`00Oomoo`2DOol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo02Ao
o`9l011oo`03001oogoo00Aoo`03001oogoo0>Uoo`8009Aoo`40005oo`5oo`0000=oo`00Ool067oo
00=l07ooOol09Woo00=l07ooOol03Goo0`000goo00<007ooOol0k7oo00<007ooOol0E7oo2000=Goo
0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0WOol2O00=Ool01000Oomoo`000goo00<007oo
Ool0k7oo00<007ooOol0A7oo3`00?Goo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0WOol4
O00;Ool02000Oomoo`00Ool007oo003_Ool2000eOol?001<Ool10001Ool1Ool00003Ool007oo01Qo
o`03O01oogoo02Ioo`05O01oogooO01oo`02O008Ool40003Ool00`00Oomoo`3`Ool00`00Oomoo`0S
Ool?001KOol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo02Eoo`05O01oogooOoml0003Ool2
O03oOol2Ool00`00Oomoo`0COol?001ZOol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo02Ao
o`03O01oogoo009oo`03O01oogoo00=oo`9l0?moo`5oo`8000Aoo`l007Uoo`40005oo`5oo`0000=o
o`00Ool067oo00=l07ooOol097oo00=l07ooOol00Woo00=l07ooOol01Goo0W`0mGoo3`00R7oo0@00
0Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0SOol00g`0Oomoo`04Ool00g`0Oomoo`06Ool00g`0
Oomoo`3ZOol8000<Ool00`00Oomoo`0]Ool30004Ool3000017oo000000000Woo0`001Woo0`0000Ao
o`00Oomoo`8000=oo`<003=oo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol08Woo00=l07oo
Ool01Goo00=l07ooOol01Goo00<007`0Ool0ogoo0Goo0P00;Woo00<007ooOol00Woo00@007ooOol0
009oo`03001oogoo009oo`03001oogoo00Ioo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol0<Goo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0QOol00g`0Oomoo`06Ool00g`0
Oomoo`06Ool00g`0Oomoo`3oOol2Ool00`00Oomoo`0[Ool30002Ool01000Oomoo`000Woo00<007oo
Ool00Woo00@007ooOomoo`<0009oo`<0009oo`06001oogoo001oo`000Woo00<007ooOol0<Goo0@00
0Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0POol00g`0Oomoo`08Ool00g`0Oomoo`05Ool2O03o
Ool4Ool00`00Oomoo`0ZOol00`00Oomoo`0300000goo00000002Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool01000Oomoo`000Woo0P000goo0`00<goo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomo
o`0OOol00g`0Oomoo`09Ool00g`0Oomoo`05Ool2O03oOol5Ool2000ZOol01000Oomoo`001goo00<0
07ooOol00Woo00<007ooOol01Woo00@007ooOol000Uoo`03001oogoo035oo`40005oo`5oo`0000=o
o`00Ool067oo00=l07ooOol07Woo00=l07ooOol02Woo00=l07ooOol01Goo0W`0ogoo1goo00<007oo
Ool09Woo10001goo0P000goo0P001goo10002Goo0P00<goo0@000Goo0Goo00000goo001oo`0HOol0
0g`0Oomoo`0MOol00g`0Oomoo`0;Ool00g`0Oomoo`05Ool2O03oOol8Ool00`00Oomoo`20Ool10001
Ool1Ool00003Ool007oo01Qoo`03O01oogoo01eoo`03O01oogoo00aoo`03O01oogoo00Aoo`03O01o
og`00?]oo`Y<7`9oo`80081oo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol077oo00=l07oo
Ool03Goo00=l07ooOol01Goo0W`0ngoo2T`O17oo00<007ooOol0OGoo0@000Goo0Goo00000goo001o
o`0HOol00g`0Oomoo`0KOol00g`0Oomoo`0>Ool00g`0Oomoo`05Ool2O03kOol:C1l5Ool00`00Oomo
o`1lOol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo01Yoo`03O01oogoo011oo`03O01oogoo
00Aoo`9l0?]oo`Y<7`Ioo`8007aoo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol06Goo00=l
07ooOol04Goo00=l07ooOol017oo00=l07ooO000nWoo2T`O27oo00<007ooOol0NGoo0@000Goo0Goo
00000goo001oo`0HOol00g`0Oomoo`0HOol00g`0Oomoo`0BOol00g`0Oomoo`04Ool00g`0Ooml003j
Ool:C1l9Ool00`00Oomoo`1hOol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo01Moo`03O01o
ogoo01=oo`03O01oogoo00Aoo`03O01oog`00?Yoo`Y<7`Yoo`8007Qoo`40005oo`5oo`0000=oo`00
Ool067oo00=l07ooOol05Woo00=l07ooOol05Goo00=l07ooOol00goo00=l07ooO000nGoo2d`O37oo
00<007ooOol0MGoo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0FOol00g`0Oomoo`0EOol0
0g`0Oomoo`03Ool017`0Oomoog`0n7oo2T`O3Woo00<007ooOol0M7oo0@000Goo0Goo00000goo001o
o`0HOol00g`0Oomoo`0EOol00g`0Oomoo`0FOol00g`0Oomoo`03Ool017`0Oomoog`0n7oo2T`O3goo
0P00M7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0DOol00g`0Oomoo`0HOol00g`0Oomo
o`02Ool017`0Oomoog`0n7oo2T`O4Goo00<007ooOol0LGoo0@000Goo0Goo00000goo001oo`0HOol0
0g`0Oomoo`0COol00g`0Oomoo`0IOol00g`0Oomoo`02Ool017`0Oomoog`0n7oo2T`O4Woo00<007oo
Ool0L7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0BOol00g`0Oomoo`0JOol00g`0Oomo
o`02Ool01G`0OomoogooO000mgoo2T`O4goo0P00L7oo0@000Goo0Goo00000goo001oo`0HOol00g`0
Oomoo`0AOol00g`0Oomoo`0KOol00g`0Oomoo`02Ool01G`0OomoogooO000mgoo2T`O5Goo00<007oo
Ool0KGoo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0@Ool00g`0Oomoo`0MOol01G`0Oomo
ogooO0000goo00=l07ooOol0m7oo2d`O5Woo00<007ooOol0K7oo0@000Goo0Goo00000goo001oo`0H
Ool00g`0Oomoo`0?Ool00g`0Oomoo`0NOol00g`0Oomoo`02Ool017`0Oomoog`0mWoo2T`O67oo0P00
K7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0?Ool00g`0Oomoo`0NOol00g`0Oomoo`02
Ool01G`0OomoogooO000mGoo2T`O6Woo00<007ooOol0JGoo0@000Goo0Goo00000goo001oo`0HOol0
0g`0Oomoo`0>Ool00g`0Oomoo`0POol01G`0OomoogooO0000goo00=l07ooOol0lgoo2T`O6goo00<0
07ooOol0J7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0=Ool00g`0Oomoo`0QOol01G`0
OomoogooO0000goo00=l07ooOol0lgoo2T`O77oo0P00J7oo0@000Goo0Goo00000goo001oo`0HOol0
0g`0Oomoo`0<Ool00g`0Oomoo`0ROol01G`0OomoogooO0000goo00=l07ooOol0lgoo2T`O7Woo00<0
07ooOol0IGoo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`0;Ool00g`0Oomoo`0SOol01G`0
OomoogooO00017oo00=l07ooOol0lWoo2T`O7goo00<007ooOol0I7oo0@000Goo0Goo00000goo001o
o`0HOol00g`0Oomoo`0:Ool00g`0Oomoo`0UOol017`0Oomoog`017oo00=l07ooOol0lGoo2d`O87oo
0P00I7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`09Ool00g`0Oomoo`0VOol017`0Oomo
og`017oo00=l07ooOol0lGoo2T`O8goo00<007ooOol0HGoo0@000Goo0Goo00000goo001oo`0HOol0
0g`0Oomoo`08Ool00g`0Oomoo`0WOol017`0Oomoog`017oo00=l07ooOol0lGoo2T`O97oo00<007oo
Ool0H7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`08Ool00g`0Oomoo`0XOol00g`0Ooml
0004Ool00g`0Oomoo`3aOol:C1lUOol2001POol10001Ool1Ool00003Ool007oo01Qoo`03O01oogoo
00Moo`03O01oogoo02Uoo`03O01oog`000Eoo`03O01oogoo0?1oo`Y<7bMoo`03001oogoo05eoo`40
005oo`5oo`0000=oo`00Ool067oo00=l07ooOol01Woo00=l07ooOol0:Woo00=l07ooO0001Goo00=l
07ooOol0l7oo2T`O:7oo00<007ooOol0G7oo0@000Goo0Goo00000goo001oo`0HOol00g`0Oomoo`05
Ool00g`0Oomoo`0[Ool00g`0Ooml0005Ool00g`0Oomoo`3`Ool:C1lYOol2001LOol10001Ool1Ool0
0003Ool007oo01Qoo`03O01oogoo00Aoo`03O01oogoo02eoo`9l00Eoo`03O01oogoo0?1oo`Y<7b]o
o`03001oogoo05Uoo`40005oo`5oo`0000=oo`00Ool067oo00=l07ooOol00goo00=l07ooOol0;Woo
00=l07ooO0001Goo00=l07ooOol0kWoo2d`O;7oo00<007ooOol0F7oo0@000Goo0Goo00000goo001o
o`0HOol00g`0Oomoo`02Ool00g`0Oomoo`0_Ool00g`0Ooml0005Ool00g`0Oomoo`3^Ool:C1l^Ool2
001HOol10001Ool1Ool00003Ool007oo01Qoo`05O01oogooOoml000cOol2O005Ool00g`0Oomoo`3^
Ool:C1l`Ool00`00Oomoo`1EOol10001Ool1Ool00003Ool007oo01Qoo`05O01oogooOoml000cOol2
O005Ool00g`0Oomoo`3^Ool:C1laOol00`00Oomoo`1DOol10001Ool1Ool00003Ool007oo01Qoo`04
O01oogooO00dOol2O006Ool00g`0Oomoo`3]Ool:C1lbOol2001DOol10001Ool1Ool00003Ool007oo
00]oo`<000=oo`<000Aoo`03O01oog`003Eoo`9l00Ioo`03O01oogoo0>eoo`Y<7cAoo`03001oogoo
055oo`40005oo`5oo`0000=oo`00Ool037oo00<007ooOol00Woo00<007ooOol017oo0W`0=goo00=l
07ooOol017oo00=l07ooOol0kGoo2T`O=Goo00<007ooOol0D7oo0@000Goo0Goo00000goo001oo`0<
Ool30003Ool00`00Oomoo`03OoljO006Ool00g`0Oomoo`3TOol40004Ool;C1lfOol2001@Ool10001
Ool1Ool00003Ool007oo00aoo`04001oogoo0002Ool00`00Oomoo`0lOol00`00O01oo`05Ool00g`0
Oomoo`3WOol60008C1liOol00`00Oomoo`1=Ool10001Ool1Ool00003Ool007oo00aoo`08001oogoo
001oo`00Ool003ioo`03O01oogoo00Aoo`03O01oogoo0>]oo`9<7`L00003C1moogoo03Qoo`03001o
ogoo04aoo`40005oo`5oo`0000=oo`00Ool02goo10000goo00<007ooOol0?Woo00=l07ooOol00goo
00=l07ooOol0jgoo2D`O1P00=Woo0P00C7oo0@000Goo0Goo00000goo001oo`1DOol00g`0Oomoo`02
Ool00g`0Oomoo`3[Ool:C1l5Ool7000aOol00`00Oomoo`19Ool10001Ool1Ool00003Ool007oo05Eo
o`03O01oogoo009oo`03O01oogoo0>Yoo`Y<7`aoo`L002]oo`03001oogoo04Qoo`40005oo`5oo`00
00=oo`00Ool0EGoo00=l07ooOol00Woo00=l07ooOol0jWoo2T`O4goo1P009Woo0P00B7oo0@000Goo
0Goo00000goo001oo`1FOol01G`0OomoogooO000jgoo2d`O6Goo1`008Goo00<007ooOol0AGoo0@00
0Goo0Goo00000goo001oo`1GOol017`0Oomoog`0jgoo2T`O8Goo1P0077oo00<007ooOol0A7oo0@00
0Goo0Goo00000goo001oo`15Ool30004Ool30009Ool017`0Oomoog`0jWoo2T`O9goo1`005Woo0P00
A7oo0@000Goo0Goo00000goo001oo`16Ool00`00Oomoo`04Ool00`00Oomoo`08Ool017`0Oomoog`0
jWoo2T`O;Woo1P004Woo00<007ooOol0@Goo0@000Goo0Goo00000goo001oo`16Ool30002Ool4000:
Ool00g`0Ooml003ZOol:C1ldOol7000<Ool00`00Oomoo`10Ool10001Ool1Ool00003Ool007oo04Io
o`08001oogoo001oo`00Ool000aoo`9l0>Yoo`Y<7c]oo`L000Ioo`80041oo`40005oo`5oo`0000=o
o`00Ool0AWoo00@007ooOol0009oo`8000eoo`9l0>Uoo`Y<7d9oo`H0009oo`03001oogoo03eoo`40
005oo`5oo`0000=oo`00Ool0AGoo100017oo00<007ooOol02goo0W`0j7oo2d`OB7oo1000?Woo0@00
0Goo0Goo00000goo001oo`1KOol00`00O01oo`3oOommOol10001Ool1Ool00003Ool007oo0?moom]o
o`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1
Ool00003Ool007oo0?moohIoo`<0009oo`<004eoo`40005oo`5oo`0000=oo`00Ool0ogooQgoo00<0
07ooOol00Woo00<007ooOol0C7oo0@000Goo0Goo00000goo001oo`3oOon3Ool20002Ool30002Ool3
0003Ool20002Ool30006Ool200000goo00000006Ool400002Woo00000000Ool007oo001oo`008goo
0@000Goo0Goo00000goo001oo`1GOol30003Ool2003oOolSOol01P00Oomoo`00Ool0009oo`03001o
o`00009oo`03001oo`0000Eoo`03001oogoo00Eoo`05001oogooOol00006Ool30003Ool02000Oomo
o`00Ool007oo000SOol10001Ool1Ool00003Ool007oo05Qoo`03001oogoo009oo`03001oo`000=io
o`<00006Ool00000001oo`000Woo0P000Woo0`0000Aoo`00001oo`8002]oo`06001oogoo001oo`00
0Woo00<007oo00000Woo00<007oo00000P000goo00<007ooOol01Woo0`000Woo0`0017oo00D007oo
Oomoo`00009oo`05001oo`00Ool0000SOol10001Ool1Ool00003Ool007oo05Qoo`<0009oo`03001o
o`000=ioo`03001oo`00009oo`06001oogoo001oo`000Woo00<007oo000017oo00<007oo0000;7oo
00<007ooOol01@0000=oo`0000000P000Woo0`000Woo10001Woo00<007oo000027oo0P000Woo1P00
00=oo`00Ool08goo0@000Goo0Goo00000goo001oo`1HOol01@00Oomoo`00Ool00P00hGoo00@007oo
Ool0009oo`03001oo`00009oo`03001oo`0000Aoo`<002aoo`04001oogoo000KOol00`00Oomoo`0g
Ool10001Ool1Ool00003Ool007oo05Qoo`06001oogoo001oo`00hGoo00@007ooOomoo`<000=oo`80
009oo`<0009oo`04001oo`00000ZOol200000goo0000000JOol2000iOol10001Ool1Ool00003Ool0
07oo05Moo`@000=oo`800=ioo`03001oo`00009oo`03001oogoo00aoo`03001oogoo08Eoo`40005o
o`5oo`0000=oo`00Ool0ogoo?goo0`0000=oo`0000003Goo0P00Qgoo0@000Goo0Goo00000goo001o
o`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo
0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5o
o`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool0
07oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooK
Ool10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo
0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=o
o`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?mo
om]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001
Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo0000
0goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0
ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40
005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool0
0003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001o
o`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo
0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5o
o`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooKOol10001Ool1Ool00003Ool0
07oo0?moom]oo`40005oo`5oo`0000=oo`00Ool0ogoofgoo0@000Goo0Goo00000goo001oo`3oOooK
Ool10001Ool1Ool00003Ool007oo0?moom]oo`40005oo`5oo`0000=oo`000000o`00g0000Woo0000
\
\>"],
  ImageRangeCache->{{{0, 479}, {366, 0}} -> {-0.0563018, -0.0404415, 
  0.00441045, 0.00441045}, {{12.75, 228.688}, {356.813, 191.25}} -> {-3.77152,
   -3.27722, 0.138931, 0.138931}, {{250.25, 466.188}, {356.813, 191.25}} ->
   {-36.7675, -3.27722, 0.138931, 0.138931}, {{12.75, 228.688}, {174.688, 
  9.125}} -> {-3.77152, -28.58, 0.138931, 0.138931}, {{250.25, 466.188}, {
  174.688, 9.125}} -> {-36.7675, -28.58, 0.138931, 0.138931}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package and defines names for each of the bodies in the model."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(chassis = 2; \)\), 
    \(\(carrier = 3; \)\), 
    \(\(rocker = 4; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the four body objects for the pull-rod model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
bd[ground] = Body[ground, PointList-> 
  {(*P1*) {0,  0},
   (*P2*) {0, 10}} ];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
bd[chassis] = Body[chassis, PointList->
  {(*P1*) { 0  ,  0    },
   (*P2*) { 0  , 10    },
   (*P3*) { 7.5,  4    },
   (*P4*) { 8  , 10    },
   (*P5*) { 6  ,  3.125},
   (*P6*) { 9.5, 12    }},
  InitialGuess->{{0, 2.5}, 0}];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
bd[carrier] = Body[carrier, PointList->
  {(*P1*) { 0   , 0    },
   (*P2*) {-1   , 9    },
   (*P3*) { 1.25,-5.5  }},
  InitialGuess->{{22.0, 5.5}, 0}];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
bd[rocker] = Body[rocker, PointList->
  {(*P1*) { 0  , 0   },
   (*P2*) { 4.1, 2.6 },
   (*P3*) { 2.5, 0   }},
  InitialGuess->{{6.0, 6.6}, -0.7}];\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The body objects must be incorporated into the current model with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[chassis], bd[carrier], bd[rocker]]\)], "Input",\

  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Seven constraints, one of which is a driving constraint with explicit \
dependence on time, are used to model the pull-rod suspension."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, used as a driving constraint, controls the vertical position \
of the chassis. This constraint is a driving constraint because it is \
functionally dependent on the time variable ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " prismatic constraint controls the chassis rotation and horizontal \
position and allows the chassis to move only vertically relative to the \
ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the upper A-arm."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the lower A-arm."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the bottom of the tire to remain in contact with the \
ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint places the axis of the rocker arm."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the pull-rod. The length of the pull-rod is specified \
by ",
  StyleBox["rodlength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which must be given a numerical value before ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attempts to find a solution."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the seven constraint objects for the pull-rod model."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(rodlength =. \), 
    \(\(cs[1] = RelativeY1[1, Point[chassis, 1], T]; \)\), 
    \(cs[2] = Translate2[2, \n\t\tLine[ground, 2, 1], Line[chassis, 2, 1]]; \n
    cs[3] = RelativeDistance1[3, \n\t\tPoint[chassis, 3], Point[carrier, 1], 
        14.6]; \n\(cs[4] = 
      RelativeDistance1[4, \n\t\tPoint[chassis, 4], Point[carrier, 2], 13.0]; 
    \n\(cs[5] = RelativeY1[5, Point[carrier, 3], 0]; \)\)\), 
    \(\(cs[6] = Revolute2[6, Point[chassis, 5], Point[rocker, 1]]; \)\), 
    \(\(cs[7] = 
      RelativeDistance1[7, Point[carrier, 2], Point[rocker, 3], rodlength]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The constraint objects must be incorporated into the current model with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 7]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Note that the explicit symbol that is used to represent time in ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default) may be changed. The ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a nested list of strings that determines the basis for all of the ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " symbols created by ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Redefining the first element of ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " changes the symbol that is recognized as the time variable. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the basis for all ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " global symbols."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[SymbolBasis /. Options[SetSymbols]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    TagBox[
      StyleBox[
        \(List["\<T\>", List["\<X\>", "\<Y\>"], List["\<Ei\>", "\<Ej\>"], 
          "\<Th\>", "\<Lmb\>", "\<d\>"]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True],
      FullForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Before the model can be run, the symbol ",
  StyleBox["rodlength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which determines the length of the pull-rod, must be defined. Because of \
the presence of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the driving constraint (constraint 1), the model can be run through \
its intended range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the first argument to the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The way that this model is defined, the numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the distance between the chassis and the ground."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The symbol ",
  StyleBox["rodlength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be defined."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(rodlength = 15.5; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.5] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 2.5`\), ",", \(Th2 \[Rule] 0\), ",", 
        \(X3 \[Rule] 22.063575988270867`\), ",", 
        \(Y3 \[Rule] 5.46934271755340084`\), ",", 
        \(Th3 \[Rule] 0.0233305089099814466`\), ",", \(X4 \[Rule] 6.`\), ",", 
        \(Y4 \[Rule] 5.625`\), ",", 
        \(Th4 \[Rule] \(-0.193488790091837152`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the pull-rod suspension model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
  
  
%%Creator: Mathematica 
  
  
%%AspectRatio: .75862  
  
  
MathPictureStart 
  
  
%% Graphics 
  
  
/Courier findfont 10  scalefont  setfont 
  
  
% Scaling calculations 
  
  
0.0344828 0.0344828 0.0344828 0.0344828 [ 
  
  
[(0)] .03448 0 0 2 Msboxa 
  
  
[(5)] .2069 0 0 2 Msboxa 
  
  
[(10)] .37931 0 0 2 Msboxa 
  
  
[(15)] .55172 0 0 2 Msboxa 
  
  
[(20)] .72414 0 0 2 Msboxa 
  
  
[(25)] .89655 0 0 2 Msboxa 
  
  
[(0)] -0.0125 .03448 1 0 Msboxa 
  
  
[(5)] -0.0125 .2069 1 0 Msboxa 
  
  
[(10)] -0.0125 .37931 1 0 Msboxa 
  
  
[(15)] -0.0125 .55172 1 0 Msboxa 
  
  
[(20)] -0.0125 .72414 1 0 Msboxa 
  
  
[ -0.001 -0.001 0 0 ] 
  
  
[ 1.001 .75962 0 0 ] 
  
  
] MathScale 
  
  
% Start of Graphics 
  
  
1 setlinecap 
  
  
1 setlinejoin 
  
  
newpath 
  
  
[ ] 0 setdash 
  
  
0 g 
  
  
p 
  
  
p 
  
  
.002 w 
  
  
.03448 0 m 
  
  
.03448 .00625 L 
  
  
s 
  
  
P 
  
  
[(0)] .03448 0 0 2 Mshowa 
  
  
p 
  
  
.002 w 
  
  
.2069 0 m 
  
  
.2069 .00625 L 
  
  
s 
  
  
P 
  
  
[(5)] .2069 0 0 2 Mshowa 
  
  
p 
  
  
.002 w 
  
  
.37931 0 m 
  
  
.37931 .00625 L 
  
  
s 
  
  
P 
  
  
[(10)] .37931 0 0 2 Mshowa 
  
  
p 
  
  
.002 w 
  
  
.55172 0 m 
  
  
.55172 .00625 L 
  
  
s 
  
  
P 
  
  
[(15)] .55172 0 0 2 Mshowa 
  
  
p 
  
  
.002 w 
  
  
.72414 0 m 
  
  
.72414 .00625 L 
  
  
s 
  
  
P 
  
  
[(20)] .72414 0 0 2 Mshowa 
  
  
p 
  
  
.002 w 
  
  
.89655 0 m 
  
  
.89655 .00625 L 
  
  
s 
  
  
P 
  
  
[(25)] .89655 0 0 2 Mshowa 
  
  
p 
  
  
.001 w 
  
  
.06897 0 m 
  
  
.06897 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.10345 0 m 
  
  
.10345 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.13793 0 m 
  
  
.13793 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.17241 0 m 
  
  
.17241 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.24138 0 m 
  
  
.24138 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.27586 0 m 
  
  
.27586 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.31034 0 m 
  
  
.31034 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.34483 0 m 
  
  
.34483 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.41379 0 m 
  
  
.41379 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.44828 0 m 
  
  
.44828 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.48276 0 m 
  
  
.48276 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.51724 0 m 
  
  
.51724 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.58621 0 m 
  
  
.58621 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.62069 0 m 
  
  
.62069 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.65517 0 m 
  
  
.65517 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.68966 0 m 
  
  
.68966 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.75862 0 m 
  
  
.75862 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.7931 0 m 
  
  
.7931 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.82759 0 m 
  
  
.82759 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.86207 0 m 
  
  
.86207 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.93103 0 m 
  
  
.93103 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.96552 0 m 
  
  
.96552 .00375 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
0 0 m 
  
  
1 0 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
0 .03448 m 
  
  
.00625 .03448 L 
  
  
s 
  
  
P 
  
  
[(0)] -0.0125 .03448 1 0 Mshowa 
  
  
p 
  
  
.002 w 
  
  
0 .2069 m 
  
  
.00625 .2069 L 
  
  
s 
  
  
P 
  
  
[(5)] -0.0125 .2069 1 0 Mshowa 
  
  
p 
  
  
.002 w 
  
  
0 .37931 m 
  
  
.00625 .37931 L 
  
  
s 
  
  
P 
  
  
[(10)] -0.0125 .37931 1 0 Mshowa 
  
  
p 
  
  
.002 w 
  
  
0 .55172 m 
  
  
.00625 .55172 L 
  
  
s 
  
  
P 
  
  
[(15)] -0.0125 .55172 1 0 Mshowa 
  
  
p 
  
  
.002 w 
  
  
0 .72414 m 
  
  
.00625 .72414 L 
  
  
s 
  
  
P 
  
  
[(20)] -0.0125 .72414 1 0 Mshowa 
  
  
p 
  
  
.001 w 
  
  
0 .06897 m 
  
  
.00375 .06897 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .10345 m 
  
  
.00375 .10345 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .13793 m 
  
  
.00375 .13793 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .17241 m 
  
  
.00375 .17241 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .24138 m 
  
  
.00375 .24138 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .27586 m 
  
  
.00375 .27586 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .31034 m 
  
  
.00375 .31034 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .34483 m 
  
  
.00375 .34483 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .41379 m 
  
  
.00375 .41379 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .44828 m 
  
  
.00375 .44828 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .48276 m 
  
  
.00375 .48276 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .51724 m 
  
  
.00375 .51724 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .58621 m 
  
  
.00375 .58621 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .62069 m 
  
  
.00375 .62069 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .65517 m 
  
  
.00375 .65517 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
0 .68966 m 
  
  
.00375 .68966 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
0 0 m 
  
  
0 .75862 L 
  
  
s 
  
  
P 
  
  
P 
  
  
p 
  
  
p 
  
  
.002 w 
  
  
.03448 .75237 m 
  
  
.03448 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.2069 .75237 m 
  
  
.2069 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.37931 .75237 m 
  
  
.37931 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.55172 .75237 m 
  
  
.55172 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.72414 .75237 m 
  
  
.72414 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.89655 .75237 m 
  
  
.89655 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.06897 .75487 m 
  
  
.06897 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.10345 .75487 m 
  
  
.10345 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.13793 .75487 m 
  
  
.13793 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.17241 .75487 m 
  
  
.17241 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.24138 .75487 m 
  
  
.24138 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.27586 .75487 m 
  
  
.27586 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.31034 .75487 m 
  
  
.31034 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.34483 .75487 m 
  
  
.34483 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.41379 .75487 m 
  
  
.41379 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.44828 .75487 m 
  
  
.44828 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.48276 .75487 m 
  
  
.48276 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.51724 .75487 m 
  
  
.51724 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.58621 .75487 m 
  
  
.58621 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.62069 .75487 m 
  
  
.62069 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.65517 .75487 m 
  
  
.65517 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.68966 .75487 m 
  
  
.68966 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.75862 .75487 m 
  
  
.75862 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.7931 .75487 m 
  
  
.7931 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.82759 .75487 m 
  
  
.82759 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.86207 .75487 m 
  
  
.86207 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.93103 .75487 m 
  
  
.93103 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.96552 .75487 m 
  
  
.96552 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
0 .75862 m 
  
  
1 .75862 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.99375 .03448 m 
  
  
1 .03448 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.99375 .2069 m 
  
  
1 .2069 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.99375 .37931 m 
  
  
1 .37931 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.99375 .55172 m 
  
  
1 .55172 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
.99375 .72414 m 
  
  
1 .72414 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .06897 m 
  
  
1 .06897 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .10345 m 
  
  
1 .10345 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .13793 m 
  
  
1 .13793 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .17241 m 
  
  
1 .17241 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .24138 m 
  
  
1 .24138 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .27586 m 
  
  
1 .27586 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .31034 m 
  
  
1 .31034 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .34483 m 
  
  
1 .34483 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .41379 m 
  
  
1 .41379 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .44828 m 
  
  
1 .44828 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .48276 m 
  
  
1 .48276 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .51724 m 
  
  
1 .51724 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .58621 m 
  
  
1 .58621 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .62069 m 
  
  
1 .62069 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .65517 m 
  
  
1 .65517 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.001 w 
  
  
.99625 .68966 m 
  
  
1 .68966 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.002 w 
  
  
1 0 m 
  
  
1 .75862 L 
  
  
s 
  
  
P 
  
  
P 
  
  
p 
  
  
P 
  
  
0 0 m 
  
  
1 0 L 
  
  
1 .75862 L 
  
  
0 .75862 L 
  
  
closepath 
  
  
clip 
  
  
newpath 
  
  
p 
  
  
p 
  
  
.02 w 
  
  
.03448 .03448 m 
  
  
.96552 .03448 L 
  
  
s 
  
  
P 
  
  
p 
  
  
1 0 0 r 
  
  
p 
  
  
.006 w 
  
  
.03448 .46552 m 
  
  
.31034 .46552 L 
  
  
.2931 .25862 L 
  
  
.03448 .12069 L 
  
  
.03448 .46552 L 
  
  
.2931 .25862 L 
  
  
s 
  
  
.31034 .46552 m 
  
  
.24138 .22845 L 
  
  
.2931 .25862 L 
  
  
s 
  
  
.31034 .46552 m 
  
  
.36207 .53448 L 
  
  
.2931 .25862 L 
  
  
s 
  
  
P 
  
  
P 
  
  
p 
  
  
0 0 1 r 
  
  
p 
  
  
.7953 .22308 m 
  
  
.75358 .53254 L 
  
  
.81925 .37885 L 
  
  
F 
  
  
P 
  
  
p 
  
  
.03 w 
  
  
.83477 .37922 m 
  
  
.81925 .37885 L 
  
  
s 
  
  
P 
  
  
P 
  
  
p 
  
  
p 
  
  
.01 w 
  
  
.40092 .27916 Mdot 
  
  
.33142 .20475 Mdot 
  
  
.24138 .22845 Mdot 
  
  
P 
  
  
p 
  
  
.01 w 
  
  
.7953 .22308 Mdot 
  
  
.75358 .53254 Mdot 
  
  
P 
  
  
p 
  
  
.01 w 
  
  
.36207 .53448 Mdot 
  
  
P 
  
  
0 .8 .2 r 
  
  
p 
  
  
.24138 .22845 m 
  
  
.40092 .27916 L 
  
  
.33142 .20475 L 
  
  
F 
  
  
P 
  
  
P 
  
  
p 
  
  
.6 0 1 r 
  
  
.37706 .27553 m 
  
  
.42479 .28279 L 
  
  
.38593 .53811 L 
  
  
.33821 .53085 L 
  
  
F 
  
  
P 
  
  
p 
  
  
.007 w 
  
  
.75358 .53254 m 
  
  
.33142 .20475 L 
  
  
s 
  
  
.2931 .25862 m 
  
  
.7953 .22308 L 
  
  
s 
  
  
.31034 .46552 m 
  
  
.75358 .53254 L 
  
  
s 
  
  
P 
  
  
p 
  
  
.3 .3 .2 r 
  
  
.84281 .03448 m 
  
  
.98071 .0377 L 
  
  
.96462 .72717 L 
  
  
.82672 .72395 L 
  
  
F 
  
  
P 
  
  
P 
  
  
% End of Graphics 
  
  
MathPictureEnd 
  
  
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{300, 228},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0000i1000`40O003h00Oogoo;Goo003oOol]
Ool00?moobeoo`00ogoo;Goo000KOol00`00Oomoo`0/Ool00`00Oomoo`0XOol50002Ool00`00Oomo
o`0VOol50002Ool00`00Oomoo`0VOol30003Ool00`00Oomoo`0WOol30003Ool00`00Oomoo`0NOol0
01Yoo`03001oo`0002aoo`03001oo`0002]oo`07001oogooOol007oo0000:Goo00L007ooOomoo`00
Ool0000WOol00`00Oomoo`02Ool00`00Ool0000XOol00`00Oomoo`02Ool00`00Ool0000OOol001Yo
o`03001oo`0002ioo`03001oogoo02Uoo`07001oogooOol007oo0000:Goo00<007ooOol00goo00<0
07ooOol09Woo00L007ooOomoo`00Ool0000YOol00`00Oomoo`03Ool00`00Oomoo`0MOol001Yoo`03
001oo`0002aoo`8002aoo`07001oogooOol007oo0000:Goo00@007ooOomoo`8002Uoo`07001oogoo
Ool007oo0000:Goo00@007ooOomoo`80021oo`006Woo00<007oo0000;7oo00<007ooOol0:goo00L0
07ooOomoo`00Ool0000YOol01@00Oomoogoo0000:Goo00<007oo00000Woo00<007oo0000:7oo00<0
07oo00000Woo00<007ooOol07goo000KOol00`00Oomoo`0[Ool3000ZOol20004Ool00`00Oomoo`0W
Ool20003Ool3000XOol00`00Oomoo`02Ool00`00Oomoo`0XOol01000Oomoogoo0`007goo003oOol]
Ool00?moobeoo`00ogoo;Goo003oOol]Ool00?moobeoo`00ogoo;Goo003oOol]Ool00?moobeoo`00
4Wooo`005@001Woo000BOol00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03
001oogoo00Ioo`03001oogoo00Aoo`004Woo00<007ooOol0ogoo4Goo00<007ooOol017oo000BOol0
0`00Oomoo`3oOolAOol00`00Oomoo`04Ool0019oo`03001oogoo0?mooa5oo`03001oogoo00Aoo`00
4Woo00<007ooOol0ogoo4Goo00<007ooOol017oo000BOol00`00Oomoo`3oOolAOol00`00Oomoo`04
Ool000aoo`03001oogoo00=oo`03001oogoo00Eoool000H000Ioo`03001oogoo00Aoo`002goo00<0
07oo000017oo00<007ooOol01Gooo`001P001Woo00<007ooOol017oo000;Ool00`00Ool00004Ool3
0005Oooo00060004Ool30006Ool000]oo`03001oo`0000Aoo`03001oogoo00Eoon0002HU9PEoo`03
001oogoo00Aoo`002goo00<007oo000017oo00<007ooOol01Gooh0009RDV1Goo00<007ooOol017oo
000<Ool00`00Oomoo`03Ool00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo
0>EoobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol0iGoo9RDV1Goo00<007ooOol017oo000B
Ool00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo0>EoobHU9PEoo`03001o
ogoo00Aoo`004Woo00<007ooOol0iGoo9RDV1Goo00<007ooOol017oo000BOol2003VOolV9BH4Ool2
0006Ool0019oo`03001oogoo0>EoobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol0iGoo9RDV
1Goo00<007ooOol017oo000BOol00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001o
ogoo0>EoobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol0iGoo9RDV1Goo00<007ooOol017oo
000BOol00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo0>EoobHU9PEoo`03
001oogoo00Aoo`004Woo00<007ooOol0iGoo9RDV1Goo00<007ooOol017oo000BOol00`00Oomoo`3U
OolV9BH5Ool00`00Oomoo`04Ool0019oo`800>IoobHU9PAoo`8000Ioo`004Woo00<007ooOol0iGoo
9RDV1Goo00<007ooOol017oo000BOol00`00Oomoo`3UOolV9BH5Ool00`00Oomoo`04Ool0019oo`03
001oogoo0>EoobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol0iGoo9RDV1Goo00<007ooOol0
17oo000BOol00`00Oomoo`07Ool00g`0Oomoo`3KOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001o
ogoo00Moo`=l0=]oobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol00W`0
fGoo9RDV1Goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`02Ool2O03GOolV9BH5
Ool00`00Oomoo`04Ool0019oo`8000Qoo`03O01oogoo00Aoo`9l0=EoobHU9PAoo`8000Ioo`004Woo
00<007ooOol01goo00=l07ooOol01Woo0W`0dgoo9RDV1Goo00<007ooOol017oo000BOol00`00Oomo
o`07Ool00g`0Oomoo`08Ool2O03AOolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03
O01oogoo00Yoo`9l0<moobHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0
37oo00=l07ooOol0c7oo9RDV1Goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0=
Ool2O03<OolV9BH5Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo00moo`9l0<Yo
obHU9PEoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol04Goo0W`0b7oo9RDV1Goo
00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0COol2O036OolV9BH5Ool00`00Oomo
o`04Ool0019oo`03001oogoo00Moo`03O01oogoo01Eoo`9l0<AoobHU9PEoo`03001oogoo00Aoo`00
4Woo0P0027oo00=l07ooOol05goo0W`0`Goo9bDV17oo0P001Woo000BOol00`00Oomoo`07Ool00g`0
Oomoo`0IOol00g`0Oomoo`2nOolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01o
ogoo01Yoo`9l0;ioobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol077oo
0W`0_7oo9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0NOol2O02jOolV
9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo021oo`9l0;QoobHU9PIoo`03
001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol08Woo0W`0]Woo9RDV1Woo00<007ooOol0
17oo000<Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00g`0Oomoo`0TOol2O02dOolV9BH6Ool00`00
Oomoo`04Ool000]oo`03001oo`0000Aoo`03001oogoo00Moo`03O01oogoo02Ioo`9l0;9oobHU9PIo
o`03001oogoo00Aoo`003Goo00<007ooOol00Woo0`001goo00=l07ooOol0:7oo00=l07ooOol08goo
00<007ooOol0RGoo9RDV17oo0`001Woo000;Ool20005Ool00`00Oomoo`07Ool00g`0Oomoo`0YOol2
O00OOol50bH00`00Oomoo`28OolV9BH6Ool00`00Oomoo`04Ool000]oo`03001oogoo00Aoo`03001o
ogoo00Moo`03O01oogoo02]oo`9l01Uoo`X39P8008QoobHU9PIoo`03001oogoo00Aoo`002goo0`00
17oo00<007ooOol01goo00=l07ooOol0;Goo0W`04goo3`<V00=oo`00Ool0QWoo9RDV1Woo00<007oo
Ool017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0_Ool2O00=OolD0bH00goo001oo`25OolV9BH6
Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo035oo`9l00MooaT39P03Ool00000
079oo`L000]oobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0<goo0W`0
7`<V0Woo00<007ooOol0HGoo3P001Goo00<0000OOol02Woo9RDV1Woo00<007ooOol017oo000BOol0
0`00Oomoo`07Ool00g`0Oomoo`0eOol01000O01l07oo70<V0Woo00<007ooOol0DWoo3P0057oo00<0
7gooOol02Goo9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0fOol4O002
OolJ0bH2Ool00`00Oomoo`13Ool>000ROol00`0OOomoo`09OolV9BH6Ool00`00Oomoo`04Ool0019o
o`03001oogoo00Moo`03O01oogoo03Ioo`03O01oog`0009l00AooaP39P9oo`8003Eoo`h0031oo`03
01moogoo00UoobHU9PIoo`03001oogoo00Aoo`004Woo0P0027oo00=l07ooOol0=Woo00Al07ooOomo
o`=l00EooaH39P=oo`03001oogoo02Eoo`d003ioo`0301moogoo00UoobHU9PEoo`8000Ioo`004Woo
00<007ooOol01goo00=l07ooOol0=Woo00=l07ooOol00goo0g`01Woo50<V0goo00<007ooOol05Woo
3P00Bgoo00<07gooOol02Goo9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomo
o`0gOol00g`0Oomoo`04Ool2O008OolB0bH3Ool20008Ool>001IOol00`0OOomoo`09OolV9BH6Ool0
0`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03Moo`03O01oogoo00Ioo`9l00Uoo`h3
9Ph006Ioo`<07`YoobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0=goo
00=l07ooOol027oo0W`01goo3P000`<V17oo00<007ooOol0JWoo0`0O2Woo9RDV1Woo00<007ooOol0
17oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0hOol00g`0Oomoo`09Ool70007Ool;0bH4Ool00`00
Oomoo`1YOol301l:OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03Qo
o`03O01oogoo00Qoo`9l011oo`T39PAoo`8006Uoo`<07`YoobHU9PIoo`03001oogoo00Aoo`004Woo
00<007ooOol01goo00=l07ooOol0>7oo00=l07ooOol01Woo0W`000=oog`0Ool04Woo1`<V1Goo00<0
07ooOol0IWoo0`0O2Woo9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0h
Ool00g`0Oomoo`05Ool017`0Oomoogoo0W`05Goo1@<V1Goo00<007ooOol0IGoo0`0O2Woo9RDV1Woo
00<007ooOol017oo000BOol20008Ool00g`0Oomoo`0iOol00g`0Oomoo`03Ool00g`0Oomoo`02Ool2
O00HOol30bH5Ool2001UOol301l:OolV9BH5Ool20006Ool0019oo`03001oogoo00Moo`03O01oogoo
03Uoo`03O01oogoo009oo`03O01oogoo00=oo`9l01Eoo`M<7`Ioo`03001oogoo065oo`D07`UoobHU
9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0>Goo00=l07ooOol00W`01Woo
0W`05Goo3D`O00=oo`00Ool0HGoo1@0O2Goo9RDV1Woo00<007ooOol017oo000BOol00`00Oomoo`07
Ool00g`0Oomoo`0jOol2O008Ool00g`0Ooml000DOol=C1l2Ool00`00Oomoo`1OOol501l9OolV9BH6
Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03Yoo`03O01oogoo00Qoo`9l01Ao
o`e<7`=oo`8005moo`D07`UoobHU9PIoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07oo
Ool0>Goo0W`02Woo0W`057oo3D`O1Goo00<007ooOol0G7oo1@0O2Goo9RDV1Woo00<007ooOol017oo
000BOol00`00Oomoo`07Ool00g`0Oomoo`0gOol2O0000gooO01oo`09Ool2O00DOol=C1l6Ool00`00
Oomoo`1KOol501l9OolV9BH6Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo03Io
o`03O01oogoo009oo`03O01oogoo00Moo`03O01oog`0019oo`i<7`Moo`8005]oo`D07`UoobHU9PIo
o`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0=Goo00=l07ooOol00goo00=l07oo
Ool01goo00=l07ooO0004Woo3T`O2Goo00<007ooOol0Egoo1`0O27oo9RDV1Woo00<007ooOol017oo
000BOol00`00Oomoo`07Ool00g`0Oomoo`0dOol00g`0Oomoo`04Ool00g`0Oomoo`07Ool00g`0Ooml
000BOol=C1l;Ool00`00Oomoo`1FOol701l8OolV9BH6Ool00`00Oomoo`04Ool0019oo`8000Qoo`03
O01oogoo039oo`9l00Qoo`03O01oogoo00Ioo`03O01oog`0019oo`e<7`aoo`8005Ioo`L07`MoobLU
9PEoo`8000Ioo`004Woo00<007ooOol01goo00=l07ooOol0<Goo00=l07ooOol027oo00=l07ooOol0
1Woo00Al07ooOoml015oo`e<7`ioo`03001oogoo05=oo`L07`MoobHU9PMoo`03001oogoo00Aoo`00
4Woo00<007ooOol01goo00=l07ooOol0<7oo00=l07ooOol02Goo00=l07ooOol01Woo00Al07ooOoml
015oo`e<7`moo`03001oogoo059oo`L07`MoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol0
1goo00=l07ooOol0;goo00=l07ooOol02Woo00=l07ooOol01Woo00Al07ooOoml011oo`i<7a1oo`03
001oogoo055oo`L07`MoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0
;Goo0W`03Woo00=l07ooOol01Goo00Al07ooOoml011oo`i<7a5oo`80055oo`L07`MoobHU9PMoo`03
001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0;7oo00=l07ooOol03Woo00=l07ooOol0
1Goo00El07ooOomoog`000moo`e<7aAoo`03001oogoo04eoo`T07`IoobHU9PMoo`03001oogoo00Ao
o`004Woo00<007ooOol01goo00=l07ooOol0:goo00=l07ooOol03goo00=l07ooOol01Goo00El07oo
Oomoog`000moo`e<7aEoo`03001oogoo04aoo`T07`IoobHU9PMoo`03001oogoo00Aoo`004Woo00<0
07ooOol01goo00=l07ooOol0:Woo00=l07ooOol04Goo00=l07ooOol017oo00El07ooOomoog`000mo
o`e<7aIoo`8004aoo`T07`IoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07oo
Ool0:7oo0W`057oo00=l07ooOol01Goo00Al07ooOoml00moo`e<7aQoo`03001oogoo04Uoo`T07`Io
obHU9PMoo`03001oogoo00Aoo`004Woo0P0027oo00=l07ooOol09goo00=l07ooOol057oo00=l07oo
Ool01Goo00El07ooOomoog`000ioo`e<7aUoo`03001oogoo04Qoo`T07`IoobHU9PIoo`8000Ioo`00
4Woo00<007ooOol01goo00=l07ooOol09Woo00=l07ooOol05Goo00=l07ooOol01Goo00El07ooOomo
og`000eoo`i<7aYoo`03001oogoo04Moo`T07`IoobHU9PMoo`03001oogoo00Aoo`004Woo00<007oo
Ool01goo00=l07ooOol09Goo00=l07ooOol05goo00=l07ooOol017oo00El07ooOomoog`000eoo`i<
7a]oo`8004Moo`T07`IoobHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol0
8goo0W`06Woo00=l07ooOol017oo00El07ooOomoog`000eoo`e<7aioo`03001oogoo04=oo`/07`Eo
obHU9PMoo`03001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol08Woo00=l07ooOol06Woo
00=l07ooOol017oo00=l07ooOol00Woo00=l07ooOol02Woo3D`O7goo00<007ooOol0@Woo2`0O1Goo
9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`0QOol00g`0Oomoo`0LOol0
0g`0Oomoo`03Ool00g`0Oomoo`02Ool00g`0Oomoo`0:Ool=C1lPOol20012Ool;01l5OolV9BH7Ool0
0`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo021oo`03O01oogoo01eoo`03O01oogoo
00=oo`03O01oogoo009oo`03O01oogoo00Yoo`e<7b9oo`03001oogoo03moo`/07`EoobHU9PMoo`03
001oogoo00Aoo`004Woo00<007ooOol01goo00=l07ooOol07goo00=l07ooOol07Woo00=l07ooOol0
0goo00=l07ooOol00Woo00=l07ooOol02Goo3T`O8goo00<007ooOol0?Woo400O9RDV1goo00<007oo
Ool017oo0005Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00g`0Oomoo`0MOol2O00ROol0
0g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomoo`08Ool>C1lTOol00`00Oomoo`0mOol@01lV9BH7
Ool00`00Oomoo`04Ool000Moo`07001oogooOol007oo000017oo00<007ooOol01goo00=l07ooOol0
77oo00=l07ooOol08Woo00=l07ooOol00Woo00=l07ooOol00goo00=l07ooOol027oo3D`O9Woo0P00
?Goo400O9RDV1goo00<007ooOol017oo0007Ool01`00Oomoogoo001oo`0000Aoo`<000Moo`03O01o
ogoo01]oo`03O01oogoo02=oo`03O01oogoo009oo`03O01oogoo00=oo`03O01oogoo00Qoo`e<7bQo
o`03001oogoo03Uooa407bHU9PEoo`<000Ioo`001goo00L007ooOomoo`00Ool00004Ool00`00Oomo
o`07Ool00g`0Oomoo`0JOol00g`0Oomoo`0TOol00g`0Oomoo`02Ool00g`0Oomoo`03Ool00g`0Oomo
o`08Ool=C1lYOol00`00Oomoo`0hOolA01lV9BH7Ool00`00Oomoo`04Ool000Moo`07001oogooOol0
07oo000017oo00<007ooOol01goo00=l07ooOol067oo0W`0:7oo00El07ooOomoog`000Ioo`03O01o
ogoo00Moo`e<7bYoo`8003Qooa407bHU9PMoo`03001oogoo00Aoo`001Woo0P0017oo00<007ooOol0
0goo00<007ooOol01goo00=l07ooOol05goo00=l07ooOol0:7oo00=l07ooOol00Woo00=l07ooOol0
0goo00=l07ooOol01goo3D`O;7oo00<007ooOol0=Goo4@0O9RDV1goo00<007ooOol017oo000BOol0
0`00Oomoo`07Ool00g`0Oomoo`0FOol00g`0Oomoo`0YOol00g`0Oomoo`02Ool00g`0Oomoo`03Ool0
0g`0Oomoo`06Ool>C1l]Ool00`00Oomoo`0dOolA01lV9BH7Ool00`00Oomoo`04Ool0019oo`03001o
ogoo00Moo`03O01oogoo01Eoo`03O01oogoo02]oo`05O01oogooOoml0005Ool00g`0Oomoo`06Ool>
C1l^Ool00`00Oomoo`0cOol:01l7OolV9BH7Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03
O01oogoo01=oo`9l02ioo`05O01oogooOoml0006Ool00g`0Oomoo`05Ool=C1l`Ool2000cOol:01l7
OolV9BH7Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo019oo`03O01oogoo02io
o`05O01oogooOoml0006Ool00g`0Oomoo`05Ool=C1lbOol00`00Oomoo`0_Ool:01l8OolV9BH7Ool0
0`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo015oo`03O01oogoo02moo`05O01oogoo
Ooml0006Ool00g`0Oomoo`05Ool=C1lcOol00`00Oomoo`0^Ool:01l8OolV9BH7Ool00`00Oomoo`04
Ool0019oo`8000Qoo`03O01oogoo011oo`03O01oogoo035oo`04O01oogooO006Ool00g`0Oomoo`05
Ool=C1ldOol2000^Ool:01l8OolV9BH6Ool20006Ool0019oo`03001oogoo00Moo`03O01oogoo00io
o`9l03Aoo`04O01oogooO007Ool00g`0Oomoo`03Ool>C1lfOol00`00Oomoo`0[Ool901l9OolV9BH7
Ool00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo00eoo`03O01oogoo03Aoo`04O01o
ogooO007Ool00g`0Oomoo`03Ool>C1lgOol00`00Oomoo`0ZOol901l9OolV9BH7Ool00`00Oomoo`04
Ool0019oo`03001oogoo00Moo`03O01oogoo00aoo`03O01oogoo03Ioo`03O01oog`000Moo`03O01o
ogoo00=oo`e<7cUoo`03001oogoo02Uoo`P07`YoobHU9PMoo`03001oogoo00Aoo`004Woo00<007oo
Ool01goo00=l07ooOol02goo00=l07ooOol0=goo00=l07ooO0001goo00=l07ooOol00goo3D`O>Woo
0P00:Goo200O2Woo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`09Ool2
O00jOol00g`0Ooml0008Ool00g`0Oomoo`02Ool=C1llOol00`00Oomoo`0UOol801l;OolV9BH7Ool0
0`00Oomoo`04Ool0019oo`03001oogoo00Moo`03O01oogoo00Qoo`03O01oogoo03Yoo`03O01oog`0
00Qoo`03O01oogoo009oo`e<7ceoo`03001oogoo02Aoo`P07`]oobHU9PMoo`03001oogoo00Aoo`00
4Woo00<007ooOol01goo00=l07ooOol01goo00=l07ooOol0?7oo0W`027oo00=l07ooOol00Woo3D`O
?Woo0P0097oo200O2goo9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`06
Ool00g`0Oomoo`0mOol00g`0Ooml0007Ool017`0Oomoogoo3T`O@7oo00<007ooOol08Goo1`0O37oo
9RDV1goo00<007ooOol017oo000BOol00`00Oomoo`07Ool00g`0Oomoo`04Ool2O010Ool00g`0Ooml
0008Ool00g`0Oomoo`0>C1m1Ool00`00Oomoo`0POol701l<OolV9BH7Ool00`00Oomoo`04Ool0019o
o`8000Qoo`03O01oogoo00=oo`03O01oogoo045oo`9l00Qoo`03O01oogoo00e<7d=oo`03001oogoo
01moo`H07`aoobLU9PIoo`8000Ioo`004Woo00<007ooOol01goo00=l07ooOol00Woo00=l07ooOol0
@Woo0W`027oo00=l07ooOol03D`OA7oo0P007goo1P0O37oo9RDV27oo00<007ooOol017oo000BOol0
0`00Oomoo`07Ool01G`0OomoogooO000AGoo0W`027oo00=l07ooOol03D`OAWoo00<007ooOol06goo
1P0O3Goo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`07Ool017`0Ooml07`0AWoo0W`02Goo
00=l07ooC1l034`OAgoo00<007ooOol06Woo1P0O3Goo9RDV27oo00<007ooOol017oo000BOol00`00
Oomoo`07Ool2O019Ool00g`0Oomoo`07Ool00g`0C1m<7`0<C1m8Ool2000JOol601l=OolV9BH8Ool0
0`00Oomoo`04Ool0019oo`03001oogoo00Mood]l00@000Ioo`03O01<7d`O00a<7dYoo`03001oogoo
01Moo`D07`ioobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0Dgoo00=l07ooOol01`003D`O
C7oo00<007ooOol05Woo1@0O3Woo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`1DOol00g`0
Oomoo`06Ool60007C1m=Ool2000FOol401l?OolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo
05Aoo`03O01oogoo00Ioo`I<7`L004moo`03001oogoo01=oo`@07`moobHU9PQoo`03001oogoo00Ao
o`004Woo0P00EWoo00=l07ooOol01Goo3D`O1`00BGoo00<007ooOol04Goo100O47oo9RDV1goo0P00
1Woo000BOol00`00Oomoo`1FOol00g`0Oomoo`04Ool=C1l7Ool70013Ool00`00Oomoo`0@Ool401l@
OolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo05Moo`03O01oogoo009oo`i<7`ioo`L003eo
o`80011oo`@07a1oobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0F7oo00Al07ooOomoo`i<
7aEoo`H003Uoo`03001oogoo00eoo`<07a5oobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0
F7oo00Al07ooOomoo`e<7aaoo`L003=oo`03001oogoo00aoo`<07a5oobHU9PQoo`03001oogoo00Ao
o`004Woo00<007ooOol0FGoo00=l07ooOol03D`O8goo1`00;Goo0P0037oo0P0O4Woo9RDV27oo00<0
07ooOol017oo000BOol00`00Oomoo`1JOol00g`0Oom<7`0<C1lZOol7000XOol00`00Oomoo`09Ool2
01lBOolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo05]oo`03O01<7d`O00]<7c5oo`H002=o
o`03001oogoo00Moo`807a=oobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0Fgoo3T`O=goo
1`007Goo00<007ooOol01Woo0P0O4goo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`1KOol>
C1lnOol7000GOol20006Ool201lCOolV9BH8Ool00`00Oomoo`04Ool0019oo`8005aoo`e<7dIoo`L0
019oo`03001oogoo00=oo`0301moogoo019oobHU9PMoo`8000Ioo`004Woo00<007ooOol0Fgoo3D`O
CGoo1`0037oo00<007ooOol00Woo00<07gooOol04Woo9RDV27oo00<007ooOol017oo000BOol00`00
Oomoo`1KOol=C1mDOol60007Ool2000GOolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo05]o
o`e<7eYoo`L0009oo`03001oogoo01AoobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0FWoo
3T`OHGoo10005Goo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`1POol00`00C1m<7`05C1mS
Ool00`00Oomoo`0DOolV9BH8Ool00`00Oomoo`04Ool0019oo`03001oogoo0>9oobHU9PQoo`03001o
ogoo00Aoo`001Goo1@000Woo00<007ooOol00goo00<007ooOol0hWoo9RDV27oo00<007ooOol017oo
0007Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0>9oobHU9PQoo`03001oogoo00Aoo`001goo
00<007ooOol00goo00<007ooOol00Woo0`00hWoo9RDV1Woo0`001Woo0007Ool01000Oomoogoo0P00
1Goo00<007ooOol0hWoo9RDV27oo00<007ooOol017oo0007Ool01@00Oomoogoo00001Woo00<007oo
Ool0hWoo9RDV27oo00<007ooOol017oo0006Ool20003Ool30004Ool00`00Oomoo`3ROolV9BH8Ool0
0`00Oomoo`04Ool0019oo`03001oogoo0>9oobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0
hWoo9RDV27oo00<007ooOol017oo000BOol00`00Oomoo`3ROolV9BH8Ool00`00Oomoo`04Ool0019o
o`03001oogoo0>9oobHU9PQoo`03001oogoo00Aoo`004Woo00<007ooOol0hWoo9RDV27oo00<007oo
Ool017oo000BOol00`00Oomoo`3ROolV9BH8Ool00`00Oomoo`04Ool0019oo`800>9oobLU9PMoo`80
00Ioo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9
Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007oo
Ool0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0
019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo00<0
07ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`800>9oobHU9PQo
o`8000Ioo`004Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV
9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<0
07ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04
Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV2Goo
00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo
0>5oobHU9PUoo`03001oogoo00Aoo`004Woo0P00hWoo9RDV27oo0P001Woo000BOol00`00Oomoo`3Q
OolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo
00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomo
o`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo9RDV
2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001o
ogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo0P00hWoo9RDV27oo0P001Woo000BOol00`00Oomo
o`3QOolV9BH9Ool00`00Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`00
4Woo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00
Oomoo`04Ool0019oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`004Woo00<007ooOol0hGoo
9RDV2Goo00<007ooOol017oo000BOol00`00Oomoo`3QOolV9BH9Ool00`00Oomoo`04Ool000Ioo`<0
00=oo`03001oogoo00=oo`03001oogoo0>5oobHU9PUoo`03001oogoo00Aoo`001Woo00<007ooOol0
0Woo00<007oo000017oo00<007ooOol0hGoo9RDV2Goo00<007ooOol017oo0007Ool01`00Oomoogoo
001oo`0000Aoo`<00>1oobLU9PMoo`<000Ioo`001goo00L007ooOomoo`00Ool00004Ool00`00Oomo
o`3oOolAOol00`00Oomoo`04Ool000Ioo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo0?mo
oa5oo`03001oogoo00Aoo`001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0ogoo4Goo
00<007ooOol017oo000BOol00`00Oomoo`3oOolAOol00`00Oomoo`04Ool0019oo`03001oogoo0?mo
oa5oo`03001oogoo00Aoo`004Woo00<007ooOol0ogoo4Goo00<007ooOol017oo000BOol00`00Oomo
o`3oOolAOol00`00Oomoo`04Ool0019oo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Aoo`004Wooo`005@001Woo0000\
\>"],
  ImageRangeCache->{{{0, 299}, {227, 0}} -> {-2.95149, -2.89736, 0.105403, 
  0.105403}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["The Solution Option"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model is constructed with a functional dependence on the time variable ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " its time-domain motion is fully defined. Thus, nothing further needs to \
be done to generate velocity and acceleration solutions other than to ask for \
them. This is done with the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and several other ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify the solution level sought by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["Solution->Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies that only the location of the mechanism bodies should be \
calculated.\n\n",
  StyleBox["Solution->Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies that the location and velocity of each mechanism body should be \
calculated.\n\n",
  StyleBox["Solution->Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies that the location, velocity, and acceleration of each mechanism \
body should be calculated.\n\nThe default setting is ",
  StyleBox["Solution->Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " pull-rod suspension model defined in the previous subsection is used to \
demonstrate the velocity and acceleration solutions. The ",
  StyleBox["Solution->Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to calculate the location and velocity of each body in the model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This finds the location and velocity of each body at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 3.0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[3.0, Solution \[Rule] Velocity] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["3.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 3.`\), ",", \(Th2 \[Rule] 0\), ",", 
        \(X3 \[Rule] 22.0211888136693367`\), ",", 
        \(Y3 \[Rule] 5.48504936127612996`\), ",", 
        \(Th3 \[Rule] 0.0116615945508929086`\), ",", \(X4 \[Rule] 6.`\), ",", 
        \(Y4 \[Rule] 6.125`\), ",", 
        \(Th4 \[Rule] \(-0.311793157525018749`\)\), ",", \(X2d \[Rule] 0\), 
        ",", \(Y2d \[Rule] 1.`\), ",", \(Th2d \[Rule] 0\), ",", 
        \(X3d \[Rule] \(-0.101142646640752253`\)\), ",", 
        \(Y3d \[Rule] 0.0305218985736837922`\), ",", 
        \(Th3d \[Rule] \(-0.0232273084320082201`\)\), ",", \(X4d \[Rule] 0\), 
        ",", \(Y4d \[Rule] 1.`\), ",", 
        \(Th4d \[Rule] \(-0.23171725280974833`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " creates a new set of symbols to represent the velocities and \
accelerations by appending a lower case ",
  StyleBox["d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to each of the symbols that were used to represent body locations. Thus, \
while ",
  StyleBox["{X2, Y2}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " represents the location of the origin of body 2, ",
  StyleBox["{X2d, Y2d}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " represents the velocity of the origin of body 2.\n\nNote that in this \
case, ",
  StyleBox["{X2d, Y2d}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equal to {0, 1}. This is expected since the driving constraint forces \
the height of the chassis to be ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; therefore, its vertical velocity is equal to one. \n\nThe ",
  StyleBox["Solution->Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to calculate the location, velocity, and acceleration of each body in the \
model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This finds the location, velocity, and acceleration of each body at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 3.0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[3.0, Solution \[Rule] Acceleration] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["3.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 3.`\), ",", \(Th2 \[Rule] 0\), ",", 
        \(X3 \[Rule] 22.0211888136693367`\), ",", 
        \(Y3 \[Rule] 5.48504936127612996`\), ",", 
        \(Th3 \[Rule] 0.0116615945508929086`\), ",", \(X4 \[Rule] 6.`\), ",", 
        \(Y4 \[Rule] 6.125`\), ",", 
        \(Th4 \[Rule] \(-0.311793157525018749`\)\), ",", \(X2d \[Rule] 0\), 
        ",", \(Y2d \[Rule] 1.`\), ",", \(Th2d \[Rule] 0\), ",", 
        \(X3d \[Rule] \(-0.101142646640752253`\)\), ",", 
        \(Y3d \[Rule] 0.0305218985736837922`\), ",", 
        \(Th3d \[Rule] \(-0.0232273084320082201`\)\), ",", \(X4d \[Rule] 0\), 
        ",", \(Y4d \[Rule] 1.`\), ",", 
        \(Th4d \[Rule] \(-0.23171725280974833`\)\), ",", \(X2dd \[Rule] 0\), 
        ",", \(Y2dd \[Rule] 0\), ",", \(Th2dd \[Rule] 0\), ",", 
        \(X3dd \[Rule] \(-0.0657943213383619251`\)\), ",", 
        \(Y3dd \[Rule] \(-0.00349459498652423272`\)\), ",", 
        \(Th3dd \[Rule] 0.000407417384555385542`\), ",", \(X4dd \[Rule] 0\), 
        ",", \(Y4dd \[Rule] 0\), ",", 
        \(Th4dd \[Rule] 0.0165601048219932378`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"The location, velocity, and acceleration of the rocker (body 4) reflect the \
fact that its origin is stationary on the chassis, but its rotation is \
controlled in a nonlinear manner by the suspension linkage."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the rocker location, velocity, and acceleration."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[{{X4, Y4, Th4}, {X4d, Y4d, Th4d}, {X4dd, Y4dd, Th4dd}} /. 
        LastSolve[]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"6.`", "6.125`", \(-0.311793157525018749`\)},
            {"0.`", "1.`", \(-0.23171725280974833`\)},
            {"0.`", "0.`", "0.0165601048219932378`"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "When ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called to build the mathematical model, all of the expressions \
required for the velocity and acceleration solutions are not immediately \
built. Some parts of the mathematical model are built only when they are \
needed for the first time by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Thus, the first time that ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called requestin",
  StyleBox[
  "g a velocity or acceleration solution, it may take much longer to ",
    FontFamily->"Times"],
  "return a result than in any subsequent calls.\n\n",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to force the modeling equations to be built to any level \
immediately, instead of waiting until they are needed."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies which parts of the mathematical model are built \
immediately. ",
  StyleBox["BuildMech->",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["level",
    FontSlant->"Italic"],
  " specifies that the equations required by ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "..., ",
  StyleBox["Solution->",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["level",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be built immediately. Valid settings include ",
  StyleBox["None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["BuildMech->Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["BuildMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["level",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be called to force a build of the modeling equations to the specified \
",
  StyleBox["level",
    FontSlant->"Italic"],
  " at any time."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to build a model's velocity and acceleration equations before \
all of the symbolic parameters in the model have been defined, so that the \
parameters will remain variable in the model. If undefined parameters are \
present in a model, ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cannot be called to seek a solution, but ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can still build the required equations. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package so that ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be loaded. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " example model is developed to demonstrate the different angular velocity \
and acceleration formulations used by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This model is of a MacPherson strut automotive front suspension.\n\nThe \
model consists of only two moving bodies: the chassis and the wheel carrier. \
The wheel carrier is attached to the chassis by a lower A-arm, a MacPherson \
strut, and a steering tie rod that controls the steer angle of the wheel \
carrier. The A-arm, strut, and tie rod are not modeled as independent bodies \
in the model. They are each modeled as constraints that entirely represent \
the function they perform in the suspension. The input to the model is the \
chassis being moved vertically relative to the ground.\n\nA MacPherson strut \
is attached to the chassis of a car by a ball joint, but it is attached to \
the wheel carrier in a cantilever fashion, not by another ball joint such as \
would be used in a more conventional double A-arm suspension. Thus, the \
MacPherson strut not only provides vertical support for the wheel carrier, it \
also provides the axis about which the wheel carrier pivots for steering. \
Since the strut cannot pivot with respect to the wheel carrier, it is modeled \
simply by forcing a ray on the wheel carrier to pass through a point on the \
chassis (the upper mounting point of the strut)."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a 3D MacPherson strut front suspension model graphic."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92634 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0239737 0.998999 0.0101371 0.998999 [
[ 0 0 0 0 ]
[ 1 .92634 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .92634 L
0 .92634 L
closepath
clip
newpath
p
.002 w
.05539 .25301 m
.02497 .86356 L
s
.02497 .86356 m
.71776 .90137 L
s
.71776 .90137 m
.7027 .33665 L
s
.7027 .33665 m
.05539 .25301 L
s
.17583 .02497 m
.93792 .14641 L
s
.93792 .14641 m
.97503 .81474 L
s
.97503 .81474 m
.14905 .75824 L
s
.14905 .75824 m
.17583 .02497 L
s
.05539 .25301 m
.02497 .86356 L
s
.02497 .86356 m
.14905 .75824 L
s
.14905 .75824 m
.17583 .02497 L
s
.17583 .02497 m
.05539 .25301 L
s
.7027 .33665 m
.93792 .14641 L
s
.93792 .14641 m
.97503 .81474 L
s
.97503 .81474 m
.71776 .90137 L
s
.71776 .90137 m
.7027 .33665 L
s
P
p
.002 w
.89281 .16303 m .66319 .352 L .62115 .34668 L p
.584 .802 .983 r
F P
s
P
p
.002 w
.62115 .34668 m .07772 .27793 L p
.26055 .06432 L .584 .802 .983 r
F P
s
P
p
.002 w
.26055 .06432 m .89281 .16303 L p
.62115 .34668 L .584 .802 .983 r
F P
s
P
p
.002 w
.66993 .35206 m .61799 .42929 L .58814 .41382 L p
.61 .527 .736 r
F P
s
P
p
.002 w
.58814 .41382 m .64727 .32484 L .66993 .35206 L p
.61 .527 .736 r
F P
s
P
p
.002 w
.64727 .32484 m .58814 .41382 L .55665 .40147 L p
.713 .668 .804 r
F P
s
P
p
.002 w
.55762 .52209 m .58814 .41382 L .61799 .42929 L p
.641 .508 .685 r
F P
s
P
p
.002 w
.58814 .41382 m .55762 .52209 L .52447 .51557 L p
.755 .627 .718 r
F P
s
P
p
.002 w
.52447 .51557 m .55665 .40147 L .58814 .41382 L p
.755 .627 .718 r
F P
s
P
p
.002 w
.61799 .42929 m .59137 .52377 L .55762 .52209 L p
.641 .508 .685 r
F P
s
P
p
.002 w
.56241 .62601 m .55762 .52209 L .59137 .52377 L p
.641 .456 .618 r
F P
s
P
p
.002 w
.55762 .52209 m .56241 .62601 L .52888 .62508 L p
.768 .555 .61 r
F P
s
P
p
.002 w
.52888 .62508 m .52447 .51557 L .55762 .52209 L p
.768 .555 .61 r
F P
s
P
p
.002 w
.61843 .30737 m .55665 .40147 L .53496 .39676 L p
.827 .841 .858 r
F P
s
P
p
.002 w
.55665 .40147 m .61843 .30737 L .64727 .32484 L p
.713 .668 .804 r
F P
s
P
p
.002 w
.55665 .40147 m .52447 .51557 L .504 .50655 L p
.882 .768 .731 r
F P
s
P
p
.002 w
.504 .50655 m .53496 .39676 L .55665 .40147 L p
.882 .768 .731 r
F P
s
P
p
.002 w
.52447 .51557 m .52888 .62508 L .50786 .61167 L p
.915 .674 .559 r
F P
s
P
p
.002 w
.50786 .61167 m .504 .50655 L .52447 .51557 L p
.915 .674 .559 r
F P
s
P
p
.002 w
.67809 .37911 m .63528 .44226 L .61799 .42929 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.61799 .42929 m .66993 .35206 L .67809 .37911 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.59137 .52377 m .61799 .42929 L .63528 .44226 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.63528 .44226 m .6134 .51994 L .59137 .52377 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.59608 .61426 m .59137 .52377 L .6134 .51994 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.59137 .52377 m .59608 .61426 L .56241 .62601 L p
.641 .456 .618 r
F P
s
P
p
.002 w
.53496 .39676 m .59397 .3062 L .61843 .30737 L p
.827 .841 .858 r
F P
s
P
p
.002 w
.59397 .3062 m .53496 .39676 L .53149 .40167 L p
.608 .813 .404 r
F P
s
P
p
.002 w
.53496 .39676 m .504 .50655 L .50423 .49832 L p
.815 .818 .337 r
F P
s
P
p
.002 w
.50423 .49832 m .53149 .40167 L .53496 .39676 L p
.815 .818 .337 r
F P
s
P
p
.002 w
.504 .50655 m .50786 .61167 L .50762 .59052 L p
0 0 .058 r
F P
s
P
p
.002 w
.50762 .59052 m .50423 .49832 L .504 .50655 L p
0 0 .058 r
F P
s
P
p
.002 w
.6134 .51994 m .62369 .48341 L p
.63314 .44779 L .722 .746 .234 r
F P
s
P
p
.002 w
.62369 .48341 m .63528 .44226 L .63314 .44779 L p
.722 .746 .234 r
F P
s
P
p
.002 w
.66836 .39585 m .63314 .44779 L .63528 .44226 L p
0 0 0 r
F P
s
P
p
.002 w
.63528 .44226 m .67809 .37911 L .66836 .39585 L p
0 0 0 r
F P
s
P
p
.002 w
.63314 .44779 m .66836 .39585 L .647 .39558 L p
.831 .856 .864 r
F P
s
P
p
.002 w
.647 .39558 m .64398 .39554 L p
.63314 .44779 L .831 .856 .864 r
F P
s
P
p
.002 w
.61509 .51188 m .59506 .50258 L p
.60709 .5386 L .925 .677 .544 r
F P
s
P
p
.002 w
.61509 .51188 m .6134 .51994 L p
.62112 .49173 L .722 .746 .234 r
F P
s
P
p
.002 w
.61754 .59408 m .6134 .51994 L .61509 .51188 L p
0 0 .165 r
F P
s
P
p
.002 w
.6134 .51994 m .61754 .59408 L .59608 .61426 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.61852 .57282 m .61754 .59408 L p
.61658 .56168 L 0 0 .165 r
F P
s
P
p
.002 w
.61509 .51188 m .61852 .57282 L p
.61658 .56168 L 0 0 .165 r
F P
s
P
p
.002 w
.64768 .64663 m .61754 .59408 L .61852 .57282 L p
0 .086 .615 r
F P
s
P
p
.002 w
.61852 .57282 m .59802 .55867 L p
.62111 .58769 L .847 .385 .063 r
F P
s
P
p
.002 w
.64324 .61551 m .64768 .64663 L p
.6361 .61733 L 0 .086 .615 r
F P
s
P
p
.002 w
.61852 .57282 m .64324 .61551 L p
.6361 .61733 L 0 .086 .615 r
F P
s
P
p
.002 w
.64324 .61551 m .61852 .57282 L p
.62111 .58769 L .847 .385 .063 r
F P
s
P
p
.002 w
.62042 .59771 m .64324 .61551 L p
.62433 .59173 L .847 .385 .063 r
F P
s
P
p
.002 w
.59802 .55867 m .62042 .59771 L p
.62433 .59173 L .847 .385 .063 r
F P
s
P
p
.002 w
.63241 .67927 m .59608 .61426 L .61754 .59408 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.61754 .59408 m .64768 .64663 L .63241 .67927 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.62042 .59771 m .58764 .60041 L p
.61642 .60383 L .412 0 0 r
F P
s
P
p
.002 w
.64324 .61551 m .62042 .59771 L p
.65278 .61307 L .068 .478 .891 r
F P
s
P
p
.002 w
.65736 .6087 m .68395 .62787 L p
.6573 .61522 L .068 .478 .891 r
F P
s
P
p
.002 w
.62042 .59771 m .65736 .6087 L p
.6573 .61522 L .068 .478 .891 r
F P
s
P
p
.002 w
.65736 .6087 m .62042 .59771 L p
.61642 .60383 L .412 0 0 r
F P
s
P
p
.002 w
.59608 .61426 m .63241 .67927 L .60323 .70138 L p
.598 .357 .523 r
F P
s
P
p
.002 w
.62772 .61262 m .60637 .63864 L p
.63274 .6191 L .112 0 .076 r
F P
s
P
p
.002 w
.62772 .61262 m .65736 .6087 L p
.62137 .60442 L .412 0 0 r
F P
s
P
p
.002 w
.65736 .6087 m .62772 .61262 L p
.65742 .60203 L .561 .916 .96 r
F P
s
P
p
.002 w
.67375 .5887 m .69947 .58702 L p
.66251 .60021 L .561 .916 .96 r
F P
s
P
p
.002 w
.62772 .61262 m .67375 .5887 L p
.66251 .60021 L .561 .916 .96 r
F P
s
P
p
.002 w
.69947 .58702 m .65736 .6087 L p
.65742 .60203 L .561 .916 .96 r
F P
s
P
p
.002 w
.73038 .60461 m .68395 .62787 L .65736 .6087 L p
.581 .69 .916 r
F P
s
P
p
.002 w
.65736 .6087 m .69947 .58702 L .73038 .60461 L p
.581 .69 .916 r
F P
s
P
p
.002 w
.73484 .53732 m .69947 .58702 L .67375 .5887 L p
.838 .888 .877 r
F P
s
P
p
.002 w
.71266 .53364 m .73484 .53732 L p
.70352 .56367 L .838 .888 .877 r
F P
s
P
p
.002 w
.67375 .5887 m .71266 .53364 L p
.70352 .56367 L .838 .888 .877 r
F P
s
P
p
.002 w
.74799 .41462 m .75278 .47355 L .73254 .46297 L p
.945 .681 .504 r
F P
s
P
p
.002 w
.71266 .53364 m .73254 .46297 L .75278 .47355 L p
.91 .8 .726 r
F P
s
P
p
.002 w
.73622 .4531 m .73254 .46297 L p
.71983 .51008 L 0 0 0 r
F P
s
P
p
.002 w
.75278 .47355 m .73484 .53732 L .71266 .53364 L p
.91 .8 .726 r
F P
s
P
p
.002 w
.71142 .5412 m .72456 .49452 L p
.71983 .51008 L 0 0 0 r
F P
s
P
p
.002 w
.72456 .49452 m .73622 .4531 L p
.71983 .51008 L 0 0 0 r
F P
s
P
p
.002 w
.67375 .5887 m .66308 .60954 L p
.68263 .57961 L 0 0 0 r
F P
s
P
p
.002 w
.71266 .53364 m .67375 .5887 L p
.68263 .57961 L 0 0 0 r
F P
s
P
p
.002 w
.67375 .5887 m .62772 .61262 L p
.63274 .6191 L .112 0 .076 r
F P
s
P
p
.62137 .60442 m .60216 .60214 L .62772 .61262 L .412 0 0 r
F
P
p
.002 w
.58764 .60041 m .59988 .60414 L p
.60216 .60214 L .412 0 0 r
F P
s
P
p
.002 w
.59988 .60414 m .62772 .61262 L p
.60216 .60214 L .412 0 0 r
F P
s
P
p
.002 w
.60323 .70138 m .56241 .62601 L .59608 .61426 L p
.598 .357 .523 r
F P
s
P
p
.002 w
.56241 .62601 m .60323 .70138 L .57086 .70471 L p
.732 .404 .424 r
F P
s
P
p
.002 w
.57086 .70471 m .52888 .62508 L .56241 .62601 L p
.732 .404 .424 r
F P
s
P
p
.002 w
.52888 .62508 m .57086 .70471 L .54747 .68768 L p
.865 .423 .139 r
F P
s
P
p
.002 w
.64348 .73135 m .57086 .70471 L .60323 .70138 L p
.467 0 0 r
F P
s
P
p
.002 w
.61615 .71254 m .54747 .68768 L .57086 .70471 L p
0 .429 .85 r
F P
s
P
p
.002 w
.67304 .7264 m .60323 .70138 L .63241 .67927 L p
.474 .175 .378 r
F P
s
P
p
.002 w
.60323 .70138 m .67304 .7264 L .64348 .73135 L p
.467 0 0 r
F P
s
P
p
.002 w
.54747 .68768 m .61615 .71254 L .60188 .67697 L p
.3 .37 .768 r
F P
s
P
p
.002 w
.54227 .6564 m .54747 .68768 L p
.5692 .6834 L .3 .37 .768 r
F P
s
P
p
.002 w
.60188 .67697 m .57246 .66682 L p
.5692 .6834 L .3 .37 .768 r
F P
s
P
p
.002 w
.57246 .66682 m .54227 .6564 L p
.5692 .6834 L .3 .37 .768 r
F P
s
P
p
.002 w
.61852 .57282 m .61509 .51188 L p
.60709 .5386 L .925 .677 .544 r
F P
s
P
p
.002 w
.59506 .50258 m .59802 .55867 L .61852 .57282 L p
.925 .677 .544 r
F P
s
P
p
.002 w
.62042 .59771 m .59802 .55867 L .56361 .55739 L p
.731 .39 .403 r
F P
s
P
p
.002 w
.52886 .56966 m .55763 .62291 L .58764 .60041 L p
.59 .344 .512 r
F P
s
P
p
.002 w
.58764 .60041 m .56361 .55739 L .52886 .56966 L p
.59 .344 .512 r
F P
s
P
p
.002 w
.56361 .55739 m .58764 .60041 L .62042 .59771 L p
.731 .39 .403 r
F P
s
P
p
.002 w
.54747 .68768 m .50786 .61167 L .52888 .62508 L p
.865 .423 .139 r
F P
s
P
p
.002 w
.50786 .61167 m .54747 .68768 L .54227 .6564 L p
0 .018 .573 r
F P
s
P
p
.002 w
.59802 .55867 m .59506 .50258 L .56072 .49573 L p
.77 .554 .605 r
F P
s
P
p
.002 w
.56072 .49573 m .56361 .55739 L .59802 .55867 L p
.77 .554 .605 r
F P
s
P
p
.002 w
.54227 .6564 m .60188 .67697 L .60637 .63864 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.60637 .63864 m .55763 .62291 L .54227 .6564 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.62772 .61262 m .58764 .60041 L .55763 .62291 L p
.451 .141 .348 r
F P
s
P
p
.002 w
.55763 .62291 m .60637 .63864 L .62772 .61262 L p
.451 .141 .348 r
F P
s
P
p
.002 w
.61042 .52078 m .626 .51935 L .52694 .73987 L p
.419 .188 .454 r
F P
s
P
p
.002 w
.61042 .52078 m .626 .51935 L .62676 .50919 L p
.437 .634 .938 r
F P
s
P
p
.002 w
.626 .51935 m .62676 .50919 L .58536 .60121 L p
.904 .922 .534 r
F P
s
P
p
.002 w
.52694 .73987 m .51143 .73984 L .61042 .52078 L p
.419 .188 .454 r
F P
s
P
p
.002 w
.58536 .60121 m .52692 .73112 L p
.58367 .60983 L .904 .922 .534 r
F P
s
P
p
.626 .51935 m .58536 .60121 L .58367 .60983 L .904 .922 .534 r
F
P
p
.002 w
.52692 .73112 m .52694 .73987 L .58019 .62134 L p
.904 .922 .534 r
F P
s
P
p
.002 w
.58019 .62134 m .626 .51935 L p
.57696 .62416 L .904 .922 .534 r
F P
s
P
p
.57696 .62416 m .52692 .73112 L .58019 .62134 L .904 .922 .534 r
F
P
p
.002 w
.68395 .62787 m .64324 .61551 L p
.65278 .61307 L .068 .478 .891 r
F P
s
P
p
.002 w
.63314 .44779 m .61509 .51188 L p
.62112 .49173 L .722 .746 .234 r
F P
s
P
p
.002 w
.73609 .311 m .66993 .35206 L .64727 .32484 L p
.536 .508 .772 r
F P
s
P
p
.002 w
.64727 .32484 m .72284 .2766 L .73609 .311 L p
.536 .508 .772 r
F P
s
P
p
.002 w
.72284 .2766 m .64727 .32484 L .61843 .30737 L p
.61 .678 .889 r
F P
s
P
p
.002 w
.73224 .34623 m .67809 .37911 L .66993 .35206 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.66993 .35206 m .73609 .311 L .73224 .34623 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.69731 .25579 m .61843 .30737 L .59397 .3062 L p
.663 .904 .979 r
F P
s
P
p
.002 w
.61843 .30737 m .69731 .25579 L .72284 .2766 L p
.61 .678 .889 r
F P
s
P
p
.002 w
.53149 .40167 m .58327 .32219 L .59397 .3062 L p
.608 .813 .404 r
F P
s
P
p
.002 w
.58327 .32219 m .53149 .40167 L .54821 .41463 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.53149 .40167 m .50423 .49832 L .52579 .49412 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.52579 .49412 m .54821 .41463 L .53149 .40167 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.50423 .49832 m .50762 .59052 L .52886 .56966 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.52886 .56966 m .52579 .49412 L .50423 .49832 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.71259 .36921 m .66836 .39585 L .67809 .37911 L p
.043 0 .004 r
F P
s
P
p
.002 w
.67809 .37911 m .73224 .34623 L .71259 .36921 L p
.043 0 .004 r
F P
s
P
p
.002 w
.64398 .39554 m .61172 .44346 L .63314 .44779 L p
.831 .856 .864 r
F P
s
P
p
.002 w
.61509 .51188 m .63314 .44779 L .61172 .44346 L p
.891 .778 .73 r
F P
s
P
p
.002 w
.61172 .44346 m .59506 .50258 L .61509 .51188 L p
.891 .778 .73 r
F P
s
P
p
.002 w
.59397 .3062 m .66892 .25663 L .69731 .25579 L p
.663 .904 .979 r
F P
s
P
p
.002 w
.66892 .25663 m .59397 .3062 L .58327 .32219 L p
0 0 0 r
F P
s
P
p
.002 w
.07772 .27793 m .20292 .05532 L .26055 .06432 L p
.584 .802 .983 r
F P
s
P
p
.002 w
.54227 .6564 m .50762 .59052 L .50786 .61167 L p
0 .018 .573 r
F P
s
P
p
.002 w
.54821 .41463 m .59089 .34963 L .58327 .32219 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.59089 .34963 m .54821 .41463 L .57904 .43072 L p
.605 .525 .737 r
F P
s
P
p
.002 w
.54821 .41463 m .52579 .49412 L .56072 .49573 L p
.638 .505 .684 r
F P
s
P
p
.002 w
.56072 .49573 m .57904 .43072 L .54821 .41463 L p
.638 .505 .684 r
F P
s
P
p
.002 w
.52579 .49412 m .52886 .56966 L .56361 .55739 L p
.637 .45 .613 r
F P
s
P
p
.002 w
.56361 .55739 m .56072 .49573 L .52579 .49412 L p
.637 .45 .613 r
F P
s
P
p
.002 w
.68427 .371 m .64398 .39554 L .66836 .39585 L p
.639 .913 .981 r
F P
s
P
p
.002 w
.66836 .39585 m .71259 .36921 L .68427 .371 L p
.639 .913 .981 r
F P
s
P
p
.002 w
.6142 .37784 m .57904 .43072 L .61172 .44346 L p
.712 .672 .808 r
F P
s
P
p
.002 w
.61172 .44346 m .64398 .39554 L .6142 .37784 L p
.712 .672 .808 r
F P
s
P
p
.002 w
.59506 .50258 m .61172 .44346 L .57904 .43072 L p
.757 .629 .718 r
F P
s
P
p
.002 w
.57904 .43072 m .56072 .49573 L .59506 .50258 L p
.757 .629 .718 r
F P
s
P
p
.002 w
.58327 .32219 m .64854 .27928 L .66892 .25663 L p
0 0 0 r
F P
s
P
p
.002 w
.64854 .27928 m .58327 .32219 L .59089 .34963 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.57904 .43072 m .6142 .37784 L .59089 .34963 L p
.605 .525 .737 r
F P
s
P
p
.002 w
.50762 .59052 m .54227 .6564 L .55763 .62291 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.55763 .62291 m .52886 .56966 L .50762 .59052 L p
.402 .269 .583 r
F P
s
P
p
1 0 0 r
.008 w
.07732 .68333 m
.07985 .32518 L
s
P
p
1 0 0 r
.008 w
.07985 .32518 m
.19388 .13242 L
s
P
p
.002 w
.65806 .35045 m .6142 .37784 L .64398 .39554 L p
.602 .682 .898 r
F P
s
P
p
.002 w
.64398 .39554 m .68427 .371 L .65806 .35045 L p
.602 .682 .898 r
F P
s
P
p
.002 w
.65754 .37984 m .65966 .36112 L p
.65989 .36195 L 0 0 .259 r
F P
s
P
p
.002 w
.65966 .36112 m .65967 .36096 L .65989 .36194 L p
0 0 .259 r
F P
s
P
p
.002 w
.65989 .36194 m .65989 .36195 L p
.65966 .36112 L 0 0 .259 r
F P
s
P
p
.002 w
.65967 .36096 m .65754 .37984 L .63455 .37863 L p
.706 .658 .799 r
F P
s
P
p
.002 w
.64431 .31526 m .59089 .34963 L .6142 .37784 L p
.526 .503 .774 r
F P
s
P
p
.002 w
.6142 .37784 m .65806 .35045 L .64431 .31526 L p
.526 .503 .774 r
F P
s
P
p
.002 w
.63455 .37863 m .29065 .36051 L p
.65185 .36095 L .706 .658 .799 r
F P
s
P
p
.65185 .36095 m .65967 .36096 L .63455 .37863 L .706 .658 .799 r
F
P
p
.6598 .36521 m .65754 .37984 L .65989 .36195 L 0 0 .259 r
F
P
p
.002 w
.65989 .36195 m .66884 .3705 L p
.65955 .37476 L .413 .305 .621 r
F P
s
P
p
.002 w
.67095 .48861 m .65388 .48714 L p
.65895 .38666 L .601 .488 .696 r
F P
s
P
p
.65899 .38669 m .67095 .48861 L .65895 .38666 L .601 .488 .696 r
F
P
p
.002 w
.66078 .38703 m .67095 .48861 L p
.65896 .38645 L .601 .488 .696 r
F P
s
P
p
.002 w
.65754 .37984 m .65896 .38645 L p
.65822 .38621 L .636 .224 .245 r
F P
s
P
p
.65694 .3858 m .65358 .37972 L .65822 .38621 L .636 .224 .245 r
F
P
p
.64908 .37959 m .65358 .37972 L .65694 .3858 L .636 .224 .245 r
F
P
p
.65358 .37972 m .65754 .37984 L .65822 .38621 L .636 .224 .245 r
F
P
p
.002 w
.65955 .37476 m .66078 .38703 L p
.65896 .38645 L .601 .488 .696 r
F P
s
P
p
.65955 .37476 m .65919 .38732 L .65754 .37984 L 0 0 .259 r
F
P
p
.002 w
.65955 .37476 m .66086 .38785 L p
.65918 .38752 L .838 .661 .663 r
F P
s
P
p
.002 w
.66086 .38785 m .66129 .39218 L p
.65918 .38752 L .838 .661 .663 r
F P
s
P
p
.002 w
.66129 .39218 m .67095 .48861 L p
.65969 .39182 L .838 .661 .663 r
F P
s
P
p
.66129 .39218 m .65969 .39182 L .65918 .38752 L .838 .661 .663 r
F
P
p
.002 w
.65388 .48714 m .63345 .48537 L p
.65203 .4066 L .601 .488 .696 r
F P
s
P
p
.002 w
.65896 .38645 m .65754 .37984 L p
.65897 .3863 L 0 0 .259 r
F P
s
P
p
.65955 .37476 m .65845 .39661 L .65203 .4066 L .601 .488 .696 r
F
P
p
.002 w
.67095 .48861 m .65644 .48415 L p
.65906 .39173 L .838 .661 .663 r
F P
s
P
p
.65918 .38752 m .65976 .3925 L .65906 .39173 L .838 .661 .663 r
F
P
p
.65976 .3925 m .67095 .48861 L .65906 .39173 L .838 .661 .663 r
F
P
p
.65845 .39661 m .65388 .48714 L .65203 .4066 L .601 .488 .696 r
F
P
p
.65955 .37476 m .65754 .37984 L .6598 .36521 L 0 0 .259 r
F
P
p
.002 w
.63345 .48537 m .5382 .47715 L p
.64934 .38337 L .601 .488 .696 r
F P
s
P
p
.002 w
.63455 .37863 m .65754 .37984 L p
.63643 .37923 L .636 .224 .245 r
F P
s
P
p
.002 w
.65229 .38088 m .65034 .37898 L p
.65955 .37476 L .413 .305 .621 r
F P
s
P
p
.63643 .37923 m .64908 .37959 L .65694 .3858 L .636 .224 .245 r
F
P
p
.002 w
.65034 .37898 m .65702 .38547 L p
.64507 .37805 L .718 .233 .093 r
F P
s
P
p
.65116 .38183 m .65694 .3858 L .64934 .38337 L .601 .488 .696 r
F
P
p
.65955 .37476 m .65702 .38547 L .65116 .38183 L .601 .488 .696 r
F
P
p
.65702 .38547 m .65694 .3858 L .65116 .38183 L .601 .488 .696 r
F
P
p
.65694 .3858 m .63345 .48537 L .64934 .38337 L .601 .488 .696 r
F
P
p
.002 w
.28995 .36921 m .29065 .36051 L .63455 .37863 L p
.636 .224 .245 r
F P
s
P
p
.28995 .36921 m .63455 .37863 L .63643 .37923 L .636 .224 .245 r
F
P
p
.002 w
.58582 .42846 m .65955 .37476 L p
.5382 .47715 L .601 .488 .696 r
F P
s
P
p
.28995 .36921 m .63643 .37923 L .65776 .38793 L .636 .224 .245 r
F
P
p
.002 w
.65644 .48415 m .63769 .47837 L .65655 .38895 L p
.838 .661 .663 r
F P
s
P
p
.002 w
.65655 .38895 m .6567 .38824 L p
.6567 .38911 L .838 .661 .663 r
F P
s
P
p
.6567 .38911 m .65644 .48415 L .65655 .38895 L .838 .661 .663 r
F
P
p
.002 w
.65608 .38842 m .28995 .36921 L p
.65776 .38793 L .636 .224 .245 r
F P
s
P
p
.002 w
.29065 .36051 m .29146 .34141 L .65967 .36096 L p
.706 .658 .799 r
F P
s
P
p
.002 w
.29065 .36051 m .29146 .34141 L .29077 .35 L p
.741 .633 .07 r
F P
s
P
p
.002 w
.29077 .35 m .28995 .36921 L .29065 .36051 L p
.741 .633 .07 r
F P
s
P
p
.002 w
.29077 .35 m .28995 .36921 L .65608 .38842 L p
.706 .658 .8 r
F P
s
P
p
.65694 .38817 m .65644 .48415 L .6567 .38824 L .838 .661 .663 r
F
P
p
.65918 .38752 m .65644 .48415 L .65654 .46496 L .838 .661 .663 r
F
P
p
.63643 .37923 m .65822 .38621 L .65913 .38748 L .636 .224 .245 r
F
P
p
.65912 .38752 m .65654 .46496 L .65694 .38817 L .838 .661 .663 r
F
P
p
.63643 .37923 m .65918 .3875 L .65776 .38793 L .636 .224 .245 r
F
P
p
.65918 .38752 m .65654 .46496 L .65912 .38751 L .838 .661 .663 r
F
P
p
.002 w
.65918 .3875 m .65942 .3886 L p
.65776 .38793 L .636 .224 .245 r
F P
s
P
p
.65912 .38751 m .65912 .38752 L .65695 .38708 L .838 .661 .663 r
F
P
p
.65912 .38752 m .65694 .38817 L .65695 .38708 L .838 .661 .663 r
F
P
p
.002 w
.65702 .38547 m .6592 .38759 L p
.64507 .37805 L .718 .233 .093 r
F P
s
P
p
.002 w
.6592 .38759 m .66036 .38871 L p
.65965 .38822 L .718 .233 .093 r
F P
s
P
p
.002 w
.65944 .38844 m .65942 .3886 L .6592 .38759 L p
0 0 .259 r
F P
s
P
p
.64507 .37805 m .6592 .38759 L .65965 .38822 L .718 .233 .093 r
F
P
p
.002 w
.65896 .38645 m .65918 .3875 L p
.65913 .38748 L .636 .224 .245 r
F P
s
P
p
.65896 .38645 m .65899 .38669 L .65895 .38666 L .601 .488 .696 r
F
P
p
.65822 .38621 m .65896 .38645 L .65913 .38748 L .636 .224 .245 r
F
P
p
.65787 .38786 m .65965 .38822 L .65995 .38863 L .718 .233 .093 r
F
P
p
.002 w
.66884 .3705 m .66036 .38871 L .6592 .38759 L p
.413 .305 .621 r
F P
s
P
p
.66884 .3705 m .6592 .38759 L .65955 .37476 L .413 .305 .621 r
F
P
p
.002 w
.6592 .38759 m .65896 .38645 L p
.65944 .38844 L 0 0 .259 r
F P
s
P
p
.65944 .38844 m .65896 .38645 L .65897 .3863 L 0 0 .259 r
F
P
p
.002 w
.65912 .38751 m .65702 .38547 L p
.65955 .37476 L .413 .305 .621 r
F P
s
P
p
.65437 .38657 m .64507 .37805 L .65844 .38738 L .718 .233 .093 r
F
P
p
.002 w
.59971 .36635 m .29077 .35 L p
.61047 .38216 L .706 .658 .8 r
F P
s
P
p
.61047 .38216 m .65442 .38658 L .6136 .37148 L .706 .658 .8 r
F
P
p
.61047 .38216 m .6136 .37148 L .59971 .36635 L .706 .658 .8 r
F
P
p
.002 w
.65034 .37898 m .6136 .37148 L p
.65722 .3612 L .797 .755 .815 r
F P
s
P
p
.002 w
.65867 .361 m .65034 .37898 L p
.65722 .3612 L .797 .755 .815 r
F P
s
P
p
.59423 .35829 m .6199 .36644 L .65418 .36163 L .633 .218 .237 r
F
P
p
.29146 .34141 m .59868 .36482 L .59423 .35829 L .633 .218 .237 r
F
P
p
.59868 .36482 m .6199 .36644 L .59423 .35829 L .633 .218 .237 r
F
P
p
.60707 .37716 m .61884 .37342 L .65437 .38657 L .718 .233 .093 r
F
P
p
.002 w
.65854 .3609 m .59366 .35745 L p
.65418 .36163 L .633 .218 .237 r
F P
s
P
p
.002 w
.59366 .35745 m .29146 .34141 L p
.59423 .35829 L .633 .218 .237 r
F P
s
P
p
.59423 .35829 m .65418 .36163 L .59366 .35745 L .633 .218 .237 r
F
P
p
.29077 .35 m .65591 .38823 L .65442 .38658 L .706 .658 .8 r
F
P
p
.65724 .38808 m .65776 .38793 L .65904 .38844 L .636 .224 .245 r
F
P
p
.65724 .38808 m .65904 .38844 L .65942 .3886 L .636 .224 .245 r
F
P
p
.002 w
.65942 .3886 m .65608 .38842 L p
.65724 .38808 L .636 .224 .245 r
F P
s
P
p
.002 w
.6567 .38824 m .65695 .38708 L p
.65694 .38817 L .838 .661 .663 r
F P
s
P
p
.002 w
.65942 .3886 m .65943 .38852 L p
.65931 .3885 L .706 .658 .8 r
F P
s
P
p
.002 w
.65943 .38852 m .65944 .38844 L p
.65931 .3885 L .706 .658 .8 r
F P
s
P
p
.65913 .38833 m .65931 .3885 L .65944 .38844 L .706 .658 .8 r
F
P
p
.002 w
.29146 .34141 m .29077 .35 L .59971 .36635 L p
.633 .218 .237 r
F P
s
P
p
.61488 .36715 m .65722 .3612 L .6136 .37148 L .797 .755 .815 r
F
P
p
.59868 .36482 m .61488 .36715 L .6199 .36644 L .633 .218 .237 r
F
P
p
.33947 .31556 m .61841 .35512 L .61488 .36715 L .797 .755 .815 r
F
P
p
.65437 .38657 m .65844 .38738 L .65442 .38658 L .718 .233 .093 r
F
P
p
.61884 .37342 m .64507 .37805 L .65437 .38657 L .718 .233 .093 r
F
P
p
.29146 .34141 m .59971 .36635 L .59868 .36482 L .633 .218 .237 r
F
P
p
.002 w
.34834 .32571 m .33947 .31556 L .65034 .37898 L p
.718 .233 .093 r
F P
s
P
p
.002 w
.63796 .36837 m .59971 .36635 L p
.65442 .38658 L .706 .658 .8 r
F P
s
P
p
.002 w
.6136 .37148 m .60153 .36902 L p
.61488 .36715 L .797 .755 .815 r
F P
s
P
p
.002 w
.59971 .36635 m .61488 .36715 L p
.59868 .36482 L .633 .218 .237 r
F P
s
P
p
.002 w
.60153 .36902 m .33947 .31556 L p
.61488 .36715 L .797 .755 .815 r
F P
s
P
p
.65955 .37476 m .6598 .36521 L .66014 .36306 L 0 0 .259 r
F
P
p
.002 w
.65989 .36195 m .65967 .36096 L .65854 .3609 L p
.633 .218 .237 r
F P
s
P
p
.002 w
.65874 .36084 m .65989 .36195 L p
.65989 .36195 L .413 .305 .621 r
F P
s
P
p
.002 w
.65034 .37898 m .65867 .361 L p
.65989 .36195 L .413 .305 .621 r
F P
s
P
p
.002 w
.65867 .361 m .65874 .36084 L p
.65989 .36195 L .413 .305 .621 r
F P
s
P
p
.65955 .37476 m .65034 .37898 L .65989 .36195 L .413 .305 .621 r
F
P
p
.002 w
.66014 .36306 m .66158 .36962 L p
.65955 .37476 L 0 0 .259 r
F P
s
P
p
.002 w
.61488 .36715 m .66158 .36962 L p
.6199 .36644 L .633 .218 .237 r
F P
s
P
p
.34834 .32571 m .60707 .37716 L .52877 .36184 L .718 .233 .093 r
F
P
p
.60707 .37716 m .65437 .38657 L .60714 .37727 L .718 .233 .093 r
F
P
p
.60707 .37716 m .60714 .37727 L .52877 .36184 L .718 .233 .093 r
F
P
p
.65437 .38657 m .65442 .38658 L .52877 .36184 L .718 .233 .093 r
F
P
p
.65591 .38823 m .65942 .3886 L .65913 .38833 L .706 .658 .8 r
F
P
p
.002 w
.65695 .38708 m .65709 .3864 L p
.65804 .3873 L .838 .661 .663 r
F P
s
P
p
.65591 .38823 m .65913 .38833 L .65442 .38658 L .706 .658 .8 r
F
P
p
.52877 .36184 m .65844 .38738 L .65931 .38798 L .718 .233 .093 r
F
P
p
.34834 .32571 m .65931 .38798 L .65936 .38816 L .718 .233 .093 r
F
P
p
.65442 .38658 m .65913 .38833 L .63796 .36837 L .706 .658 .8 r
F
P
p
.002 w
.65709 .3864 m .65955 .37476 L p
.65804 .3873 L .838 .661 .663 r
F P
s
P
p
.65955 .37476 m .65918 .38752 L .65804 .3873 L .838 .661 .663 r
F
P
p
.002 w
.65995 .38863 m .60769 .37808 L p
.65787 .38786 L .718 .233 .093 r
F P
s
P
p
.002 w
.60769 .37808 m .46842 .34995 L p
.60749 .37778 L .718 .233 .093 r
F P
s
P
p
.60749 .37778 m .65787 .38786 L .60769 .37808 L .718 .233 .093 r
F
P
p
.65418 .36163 m .65867 .361 L .65854 .3609 L .633 .218 .237 r
F
P
p
.61841 .35512 m .65874 .36084 L .65722 .3612 L .797 .755 .815 r
F
P
p
.61841 .35512 m .65722 .3612 L .61488 .36715 L .797 .755 .815 r
F
P
p
.65418 .36163 m .65989 .36195 L .65867 .361 L .633 .218 .237 r
F
P
p
.34834 .32571 m .60257 .37055 L .60707 .37716 L .718 .233 .093 r
F
P
p
.60257 .37055 m .61884 .37342 L .60707 .37716 L .718 .233 .093 r
F
P
p
.002 w
.65989 .36195 m .66014 .36306 L p
.6598 .36521 L 0 0 .259 r
F P
s
P
p
.002 w
.66158 .36962 m .65989 .36195 L p
.65418 .36163 L .633 .218 .237 r
F P
s
P
p
.6199 .36644 m .66158 .36962 L .65418 .36163 L .633 .218 .237 r
F
P
p
.002 w
.65874 .36084 m .65867 .361 L p
.65722 .3612 L .797 .755 .815 r
F P
s
P
p
.65947 .38818 m .65948 .3881 L .65965 .38822 L .718 .233 .093 r
F
P
p
.65936 .38816 m .65948 .3881 L .65947 .38818 L .718 .233 .093 r
F
P
p
.65936 .38816 m .65931 .38798 L .65948 .3881 L .718 .233 .093 r
F
P
p
.002 w
.66158 .36962 m .65944 .38844 L p
.65919 .38732 L 0 0 .259 r
F P
s
P
p
.66158 .36962 m .65919 .38732 L .65955 .37476 L 0 0 .259 r
F
P
p
.002 w
.6592 .38759 m .65912 .38751 L p
.65955 .37476 L .413 .305 .621 r
F P
s
P
p
.002 w
.65608 .38842 m .65942 .3886 L p
.65591 .38823 L .706 .658 .8 r
F P
s
P
p
.29077 .35 m .65608 .38842 L .65591 .38823 L .706 .658 .8 r
F
P
p
.002 w
.46842 .34995 m .34834 .32571 L p
.50329 .35682 L .718 .233 .093 r
F P
s
P
p
.50329 .35682 m .65787 .38786 L .46842 .34995 L .718 .233 .093 r
F
P
p
.65787 .38786 m .65995 .38863 L .65995 .38863 L .718 .233 .093 r
F
P
p
.002 w
.66158 .36962 m .63796 .36837 L p
.65913 .38833 L .706 .658 .8 r
F P
s
P
p
.002 w
.65944 .38844 m .66158 .36962 L p
.65913 .38833 L .706 .658 .8 r
F P
s
P
p
.002 w
.66036 .38871 m .65995 .38863 L p
.65965 .38822 L .718 .233 .093 r
F P
s
P
p
.002 w
.64431 .31526 m .64854 .27928 L p
.60953 .32687 L .402 .269 .583 r
F P
s
P
p
.002 w
.59089 .34963 m .61593 .33352 L p
.60953 .32687 L .402 .269 .583 r
F P
s
P
p
.002 w
.61593 .33352 m .64431 .31526 L p
.60953 .32687 L .402 .269 .583 r
F P
s
P
p
.002 w
.33947 .31556 m .34763 .2957 L .65874 .36084 L p
.797 .755 .815 r
F P
s
P
p
.002 w
.65874 .36084 m .63808 .35652 L p
.66186 .36887 L .714 .225 .08 r
F P
s
P
p
.002 w
.63808 .35652 m .34763 .2957 L p
.64654 .3653 L .714 .225 .08 r
F P
s
P
p
.64654 .3653 m .66186 .36887 L .63808 .35652 L .714 .225 .08 r
F
P
p
.002 w
.35658 .30575 m .34911 .32384 L p
.66036 .38871 L .797 .757 .816 r
F P
s
P
p
.002 w
.34911 .32384 m .34834 .32571 L .46842 .34995 L p
.797 .757 .816 r
F P
s
P
p
.002 w
.46842 .34995 m .66036 .38871 L p
.34911 .32384 L .797 .757 .816 r
F P
s
P
p
.002 w
.5382 .47715 m .52102 .47566 L .58582 .42846 L p
.601 .488 .696 r
F P
s
P
p
.002 w
.66884 .3705 m .65989 .36195 L p
.66186 .36887 L .714 .225 .08 r
F P
s
P
p
.002 w
.65989 .36195 m .65874 .36084 L p
.66186 .36887 L .714 .225 .08 r
F P
s
P
p
.002 w
.63769 .47837 m .67095 .48861 L .52102 .47566 L closepath p
.276 .704 .967 r
F P
s
P
p
.002 w
.78452 .35404 m .73224 .34623 L .73609 .311 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.73609 .311 m .8007 .31945 L .78452 .35404 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.8007 .31945 m .73609 .311 L .72284 .2766 L p
.389 .42 .772 r
F P
s
P
p
.002 w
.6936 .7001 m .63241 .67927 L .64768 .64663 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.63241 .67927 m .6936 .7001 L .67304 .7264 L p
.474 .175 .378 r
F P
s
P
p
.002 w
.72284 .2766 m .79723 .28506 L .8007 .31945 L p
.389 .42 .772 r
F P
s
P
p
.002 w
.79723 .28506 m .72284 .2766 L .69731 .25579 L p
.278 .563 .933 r
F P
s
P
p
.002 w
.75481 .37609 m .71259 .36921 L .73224 .34623 L p
.428 .108 .319 r
F P
s
P
p
.002 w
.73224 .34623 m .78452 .35404 L .75481 .37609 L p
.428 .108 .319 r
F P
s
P
p
.002 w
.6977 .66263 m .64768 .64663 L .64324 .61551 L p
.336 .391 .771 r
F P
s
P
p
.002 w
.64768 .64663 m .6977 .66263 L .6936 .7001 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.69731 .25579 m .77504 .26389 L .79723 .28506 L p
.278 .563 .933 r
F P
s
P
p
.002 w
.77504 .26389 m .69731 .25579 L .66892 .25663 L p
.167 0 0 r
F P
s
P
p
.002 w
.57086 .70471 m .64348 .73135 L .61615 .71254 L p
0 .429 .85 r
F P
s
P
p
.002 w
.72248 .37736 m .68427 .371 L .71259 .36921 L p
.263 0 0 r
F P
s
P
p
.002 w
.72747 .39785 m .71764 .3834 L p
.72248 .37736 L .774 .279 0 r
F P
s
P
p
.002 w
.71259 .36921 m .72713 .37158 L p
.72248 .37736 L .263 0 0 r
F P
s
P
p
.002 w
.68427 .371 m .72248 .37736 L .69969 .35701 L p
.22 .543 .928 r
F P
s
P
p
.002 w
.71764 .3834 m .69969 .35701 L .72248 .37736 L p
.774 .279 0 r
F P
s
P
p
.002 w
.72713 .37158 m .75481 .37609 L .72248 .37736 L p
.263 0 0 r
F P
s
P
p
.002 w
.64324 .61551 m .68395 .62787 L .6977 .66263 L p
.336 .391 .771 r
F P
s
P
p
.002 w
.08937 .44725 m .09022 .42828 L .30659 .45171 L p
.772 .583 .643 r
F P
s
P
p
.002 w
.30659 .45171 m .30623 .47023 L .08937 .44725 L p
.772 .583 .643 r
F P
s
P
p
.002 w
.31145 .43746 m .30659 .45171 L .09022 .42828 L p
.726 .739 .862 r
F P
s
P
p
.002 w
.30659 .45171 m .30623 .47023 L p
.31602 .4417 L 0 0 .445 r
F P
s
P
p
.002 w
.31602 .4417 m .31145 .43746 L .30659 .45171 L p
0 0 .445 r
F P
s
P
p
.002 w
.66892 .25663 m .74232 .26443 L .77504 .26389 L p
.167 0 0 r
F P
s
P
p
.002 w
.74232 .26443 m .66892 .25663 L .64854 .27928 L p
.397 .063 .278 r
F P
s
P
p
.002 w
.09248 .45167 m .08937 .44725 L .30623 .47023 L p
.511 0 0 r
F P
s
P
p
.002 w
.30623 .47023 m .31075 .47469 L .09248 .45167 L p
.511 0 0 r
F P
s
P
p
.002 w
.30623 .47023 m .31075 .47469 L p
.31602 .4417 L 0 0 .445 r
F P
s
P
p
0 0 1 r
.015 w
.31369 .45628 m
.52102 .47566 L
s
P
p
.002 w
.69969 .35701 m .65806 .35045 L .68427 .371 L p
.22 .543 .928 r
F P
s
P
p
.002 w
.09022 .42828 m .09418 .41352 L .31145 .43746 L p
.726 .739 .862 r
F P
s
P
p
.002 w
.31602 .4417 m .31145 .43746 L .09418 .41352 L p
.495 0 0 r
F P
s
P
p
.002 w
.64854 .27928 m .71174 .28685 L .74232 .26443 L p
.397 .063 .278 r
F P
s
P
p
.002 w
.71174 .28685 m .64854 .27928 L .64431 .31526 L p
.402 .269 .583 r
F P
s
P
p
1 0 0 r
.008 w
.26904 .35219 m
.29055 .35526 L
s
P
p
1 0 0 r
.008 w
.07985 .32518 m
.26904 .35219 L
s
P
p
.002 w
.09648 .43689 m .09248 .45167 L .31075 .47469 L p
.726 .741 .864 r
F P
s
P
p
.002 w
.31075 .47469 m .31567 .46041 L .31602 .4417 L p
0 0 .445 r
F P
s
P
p
.002 w
.31075 .47469 m .31567 .46041 L .09648 .43689 L p
.726 .741 .864 r
F P
s
P
p
.002 w
.69544 .3224 m .64431 .31526 L .65806 .35045 L p
.362 .405 .772 r
F P
s
P
p
.002 w
.65806 .35045 m .69969 .35701 L .69544 .3224 L p
.362 .405 .772 r
F P
s
P
p
.015 w
.6155 .47155 m
.6529 .38937 L
s
P
p
.002 w
.64431 .31526 m .69544 .3224 L .71174 .28685 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.31567 .46041 m .31602 .4417 L .09733 .41771 L p
.773 .583 .642 r
F P
s
P
p
.002 w
.09418 .41352 m .09733 .41771 L .31602 .4417 L p
.495 0 0 r
F P
s
P
p
.002 w
.66036 .38871 m .66884 .3705 L .35658 .30575 L p
.797 .757 .816 r
F P
s
P
p
.015 w
.6529 .38937 m
.6538 .38739 L
s
P
p
.002 w
.60047 .50459 m .67095 .48861 L .63769 .47837 L closepath p
.838 .661 .663 r
F P
s
P
p
.002 w
.09733 .41771 m .09648 .43689 L .31567 .46041 L p
.773 .583 .642 r
F P
s
P
p
.002 w
.78325 .41667 m .75481 .37609 L .78452 .35404 L p
.583 .331 .5 r
F P
s
P
p
.002 w
.78452 .35404 m .82025 .40346 L .78325 .41667 L p
.583 .331 .5 r
F P
s
P
p
.002 w
.82025 .40346 m .78452 .35404 L .8007 .31945 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.34763 .2957 m .35658 .30575 L .66884 .3705 L p
.714 .225 .08 r
F P
s
P
p
.002 w
.75518 .63483 m .6977 .66263 L .68395 .62787 L p
.516 .499 .776 r
F P
s
P
p
.002 w
.6977 .66263 m .75518 .63483 L .7648 .66673 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.7648 .66673 m .6936 .7001 L .6977 .66263 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.74799 .41462 m .72248 .37736 L .75481 .37609 L p
.725 .355 .349 r
F P
s
P
p
.002 w
.75481 .37609 m .78325 .41667 L .74799 .41462 L p
.725 .355 .349 r
F P
s
P
p
.002 w
.68395 .62787 m .73038 .60461 L .75518 .63483 L p
.516 .499 .776 r
F P
s
P
p
.002 w
.8007 .31945 m .84551 .37971 L .82025 .40346 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.84551 .37971 m .8007 .31945 L .79723 .28506 L p
.099 .185 .666 r
F P
s
P
p
.002 w
.6936 .7001 m .7648 .66673 L .75528 .68844 L p
.182 0 .148 r
F P
s
P
p
.002 w
.75528 .68844 m .67304 .7264 L .6936 .7001 L p
.182 0 .148 r
F P
s
P
p
1 0 0 r
.008 w
.29773 .36767 m
.29952 .37083 L
s
P
p
1 0 0 r
.008 w
.32606 .41767 m
.34957 .45916 L
s
P
p
1 0 0 r
.008 w
.30799 .38578 m
.32606 .41767 L
s
P
p
1 0 0 r
.008 w
.34957 .45916 m
.37455 .50325 L
s
P
p
1 0 0 r
.008 w
.37455 .50325 m
.37864 .51046 L
s
P
p
1 0 0 r
.008 w
.29952 .37083 m
.30799 .38578 L
s
P
p
1 0 0 r
.008 w
.2823 .36821 m
.29053 .35555 L
s
P
p
1 0 0 r
.008 w
.23809 .43618 m
.26352 .39709 L
s
P
p
1 0 0 r
.008 w
.21598 .47017 m
.2351 .44076 L
s
P
p
1 0 0 r
.008 w
.2351 .44076 m
.23809 .43618 L
s
P
p
1 0 0 r
.008 w
.09985 .64868 m
.21598 .47017 L
s
P
p
1 0 0 r
.008 w
.26352 .39709 m
.2823 .36821 L
s
P
p
1 0 0 r
.008 w
.07732 .68333 m
.09985 .64868 L
s
P
p
1 0 0 r
.008 w
.2955 .35155 m
.34038 .3166 L
s
P
p
1 0 0 r
.008 w
.2944 .35241 m
.2955 .35155 L
s
P
p
.002 w
.72248 .37736 m .74799 .41462 L .72747 .39785 L p
.774 .279 0 r
F P
s
P
p
.002 w
.51143 .73984 m .48953 .73119 L .5892 .51282 L p
.696 .489 .603 r
F P
s
P
p
.002 w
.5892 .51282 m .61042 .52078 L .51143 .73984 L p
.696 .489 .603 r
F P
s
P
p
.002 w
.57448 .50004 m .5892 .51282 L .48953 .73119 L p
.854 .683 .67 r
F P
s
P
p
1 0 0 r
.008 w
.37864 .51046 m
.47248 .67607 L
s
P
p
.002 w
.5892 .51282 m .61042 .52078 L p
.62676 .50919 L .437 .634 .938 r
F P
s
P
p
.002 w
.57448 .50004 m .5892 .51282 L p
.62676 .50919 L .437 .634 .938 r
F P
s
P
p
.002 w
.79723 .28506 m .8493 .35406 L .84551 .37971 L p
.099 .185 .666 r
F P
s
P
p
.002 w
.8493 .35406 m .79723 .28506 L .77504 .26389 L p
.71 .207 0 r
F P
s
P
p
.002 w
.67304 .7264 m .75528 .68844 L .72967 .69123 L p
.503 .901 .931 r
F P
s
P
p
.002 w
.72967 .69123 m .64348 .73135 L .67304 .7264 L p
.503 .901 .931 r
F P
s
P
p
.002 w
.09022 .42828 m .08937 .44725 L p
.09733 .41771 L 0 0 .333 r
F P
s
P
p
.002 w
.09733 .41771 m .09418 .41352 L .09022 .42828 L p
0 0 .333 r
F P
s
P
p
.002 w
.48953 .73119 m .47378 .71889 L .57448 .50004 L p
.854 .683 .67 r
F P
s
P
p
.002 w
.57483 .48978 m .57448 .50004 L .47378 .71889 L p
.923 .931 .564 r
F P
s
P
p
.002 w
.57483 .48978 m .57448 .50004 L p
.62676 .50919 L .437 .634 .938 r
F P
s
P
p
.015 w
.6025 .50012 m
.6155 .47155 L
s
P
p
.002 w
.08937 .44725 m .09248 .45167 L p
.09733 .41771 L 0 0 .333 r
F P
s
P
p
.002 w
.72986 .3723 m .69544 .3224 L .69969 .35701 L p
.028 .135 .642 r
F P
s
P
p
.002 w
.69969 .35701 m .72747 .39785 L .72986 .3723 L p
.028 .135 .642 r
F P
s
P
p
.002 w
.82949 .33634 m .77504 .26389 L .74232 .26443 L p
.72 .333 .315 r
F P
s
P
p
.002 w
.77504 .26389 m .82949 .33634 L .8493 .35406 L p
.71 .207 0 r
F P
s
P
p
.002 w
.64348 .73135 m .72967 .69123 L .69769 .67348 L p
.567 .694 .926 r
F P
s
P
p
.002 w
.69769 .67348 m .61615 .71254 L .64348 .73135 L p
.567 .694 .926 r
F P
s
P
p
.002 w
.09248 .45167 m .09648 .43689 L .09733 .41771 L p
0 0 .333 r
F P
s
P
p
.002 w
.75278 .47355 m .74799 .41462 L .78325 .41667 L p
.776 .55 .593 r
F P
s
P
p
.002 w
.78325 .41667 m .78889 .481 L .75278 .47355 L p
.776 .55 .593 r
F P
s
P
p
.002 w
.78889 .481 m .78325 .41667 L .82025 .40346 L p
.634 .444 .609 r
F P
s
P
p
.002 w
.47378 .71889 m .47332 .71 L .57483 .48978 L p
.923 .931 .564 r
F P
s
P
p
.002 w
.59034 .48811 m .57483 .48978 L p
.62676 .50919 L .437 .634 .938 r
F P
s
P
p
.002 w
.59034 .48811 m .57483 .48978 L .47332 .71 L p
.407 .173 .444 r
F P
s
P
p
.002 w
.76932 .55058 m .73038 .60461 L .69947 .58702 L p
.712 .68 .818 r
F P
s
P
p
.002 w
.73038 .60461 m .76932 .55058 L .8036 .56856 L p
.6 .522 .738 r
F P
s
P
p
.002 w
.8036 .56856 m .75518 .63483 L .73038 .60461 L p
.6 .522 .738 r
F P
s
P
p
.002 w
.82025 .40346 m .82774 .48267 L .78889 .481 L p
.634 .444 .609 r
F P
s
P
p
.002 w
.82774 .48267 m .82025 .40346 L .84551 .37971 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.75495 .34766 m .71174 .28685 L .69544 .3224 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.69544 .3224 m .72986 .3723 L .75495 .34766 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.75518 .63483 m .8036 .56856 L .82524 .58479 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.82524 .58479 m .7648 .66673 L .75518 .63483 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.66308 .60954 m .60637 .63864 L .60188 .67697 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.60637 .63864 m .66308 .60954 L .67375 .5887 L p
.112 0 .076 r
F P
s
P
p
.002 w
.74232 .26443 m .79326 .33379 L .82949 .33634 L p
.72 .333 .315 r
F P
s
P
p
.002 w
.79326 .33379 m .74232 .26443 L .71174 .28685 L p
.573 .314 .485 r
F P
s
P
p
.002 w
.51106 .71861 m .52692 .73112 L .62676 .50919 L p
.857 .685 .668 r
F P
s
P
p
.002 w
.62676 .50919 m .61197 .49619 L .59034 .48811 L p
.437 .634 .938 r
F P
s
P
p
.002 w
.62676 .50919 m .61197 .49619 L .51106 .71861 L p
.857 .685 .668 r
F P
s
P
p
.002 w
.61615 .71254 m .69769 .67348 L .6721 .64203 L p
.503 .492 .778 r
F P
s
P
p
.002 w
.6721 .64203 m .60188 .67697 L .61615 .71254 L p
.503 .492 .778 r
F P
s
P
p
.002 w
.73254 .46297 m .72747 .39785 L .74799 .41462 L p
.945 .681 .504 r
F P
s
P
p
.002 w
.69947 .58702 m .73484 .53732 L .76932 .55058 L p
.712 .68 .818 r
F P
s
P
p
.002 w
.71174 .28685 m .75495 .34766 L .79326 .33379 L p
.573 .314 .485 r
F P
s
P
p
.002 w
.47332 .71 m .48873 .70982 L .59034 .48811 L p
.407 .173 .444 r
F P
s
P
p
1 0 0 r
.008 w
.47751 .68496 m
.48156 .69211 L
s
P
p
1 0 0 r
.008 w
.47248 .67607 m
.47751 .68496 L
s
P
p
.002 w
.61197 .49619 m .59034 .48811 L .48873 .70982 L p
.696 .487 .601 r
F P
s
P
p
.002 w
.60188 .67697 m .6721 .64203 L .66308 .60954 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.48873 .70982 m .51106 .71861 L .61197 .49619 L p
.696 .487 .601 r
F P
s
P
p
.002 w
.84551 .37971 m .85528 .47788 L .82774 .48267 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.85528 .47788 m .84551 .37971 L .8493 .35406 L p
0 0 .334 r
F P
s
P
p
.002 w
.73484 .53732 m .75278 .47355 L .78889 .481 L p
.762 .634 .719 r
F P
s
P
p
.002 w
.78889 .481 m .76932 .55058 L .73484 .53732 L p
.762 .634 .719 r
F P
s
P
p
.002 w
.76932 .55058 m .78889 .481 L .82774 .48267 L p
.636 .502 .683 r
F P
s
P
p
.002 w
.82774 .48267 m .8036 .56856 L .76932 .55058 L p
.636 .502 .683 r
F P
s
P
p
.002 w
.7648 .66673 m .82524 .58479 L .8257 .59314 L p
0 0 0 r
F P
s
P
p
.002 w
.8257 .59314 m .75528 .68844 L .7648 .66673 L p
0 0 0 r
F P
s
P
p
.002 w
.73622 .4531 m .72986 .3723 L .72747 .39785 L p
0 0 .249 r
F P
s
P
p
.002 w
.72747 .39785 m .73254 .46297 L .73622 .4531 L p
0 0 .249 r
F P
s
P
p
.002 w
.8036 .56856 m .82774 .48267 L .85528 .47788 L p
.424 .29 .594 r
F P
s
P
p
.002 w
.85528 .47788 m .82524 .58479 L .8036 .56856 L p
.424 .29 .594 r
F P
s
P
p
1 0 0 r
.008 w
.1585 .59547 m
.07732 .68333 L
s
P
p
1 0 0 r
.008 w
.07732 .68333 m
.46038 .72105 L
s
P
p
.002 w
.8493 .35406 m .8608 .46822 L .85528 .47788 L p
0 0 .334 r
F P
s
P
p
.002 w
.8608 .46822 m .8493 .35406 L .82949 .33634 L p
.955 .682 .478 r
F P
s
P
p
.002 w
.75528 .68844 m .8257 .59314 L .80396 .59001 L p
.841 .907 .882 r
F P
s
P
p
.002 w
.80396 .59001 m .72967 .69123 L .75528 .68844 L p
.841 .907 .882 r
F P
s
P
p
.002 w
.48953 .73119 m .51143 .73984 L p
.52692 .73112 L .355 .62 .951 r
F P
s
P
p
.002 w
.47378 .71889 m .48953 .73119 L p
.52692 .73112 L .355 .62 .951 r
F P
s
P
p
.002 w
.73254 .46297 m .71266 .53364 L .71142 .5412 L p
0 0 0 r
F P
s
P
p
.002 w
.66308 .60954 m .71142 .5412 L .71266 .53364 L p
0 0 0 r
F P
s
P
p
.002 w
.76333 .44781 m .75495 .34766 L .72986 .3723 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.72986 .3723 m .73622 .4531 L .76333 .44781 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.71142 .5412 m .66308 .60954 L .6721 .64203 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.51143 .73984 m .52694 .73987 L .52692 .73112 L p
.355 .62 .951 r
F P
s
P
p
.002 w
.82524 .58479 m .85528 .47788 L .8608 .46822 L p
0 0 0 r
F P
s
P
p
.002 w
.8608 .46822 m .8257 .59314 L .82524 .58479 L p
0 0 0 r
F P
s
P
p
.002 w
.47332 .71 m .47378 .71889 L p
.52692 .73112 L .355 .62 .951 r
F P
s
P
p
1 0 0 r
.008 w
.49243 .71128 m
.49699 .71933 L
s
P
p
1 0 0 r
.008 w
.46038 .72105 m
.50018 .72497 L
s
P
p
.002 w
.84128 .45727 m .82949 .33634 L .79326 .33379 L p
.779 .548 .586 r
F P
s
P
p
.002 w
.82949 .33634 m .84128 .45727 L .8608 .46822 L p
.955 .682 .478 r
F P
s
P
p
.002 w
.72967 .69123 m .80396 .59001 L .76807 .57632 L p
.712 .685 .823 r
F P
s
P
p
.002 w
.76807 .57632 m .69769 .67348 L .72967 .69123 L p
.712 .685 .823 r
F P
s
P
p
.002 w
.80377 .44938 m .79326 .33379 L .75495 .34766 L p
.63 .437 .603 r
F P
s
P
p
.002 w
.75495 .34766 m .76333 .44781 L .80377 .44938 L p
.63 .437 .603 r
F P
s
P
p
.002 w
.73246 .55751 m .6721 .64203 L .69769 .67348 L p
.594 .519 .739 r
F P
s
P
p
.002 w
.6721 .64203 m .73246 .55751 L .71142 .5412 L p
.402 .269 .583 r
F P
s
P
p
1 0 0 r
.008 w
.48418 .68141 m
.48783 .69134 L
s
P
p
1 0 0 r
.008 w
.49562 .71253 m
.4983 .71984 L
s
P
p
1 0 0 r
.008 w
.35526 .33048 m
.48418 .68141 L
s
P
p
1 0 0 r
.008 w
.35392 .32684 m
.35526 .33048 L
s
P
p
1 0 0 r
.008 w
.46806 .71279 m
.47163 .71414 L
s
P
p
1 0 0 r
.008 w
.1585 .59547 m
.46806 .71279 L
s
P
p
.002 w
.79326 .33379 m .80377 .44938 L .84128 .45727 L p
.779 .548 .586 r
F P
s
P
p
.002 w
.48873 .70982 m .47332 .71 L p
.52692 .73112 L .355 .62 .951 r
F P
s
P
p
.002 w
.69769 .67348 m .76807 .57632 L .73246 .55751 L p
.594 .519 .739 r
F P
s
P
p
.002 w
.73246 .55751 m .76333 .44781 L .73622 .4531 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.73622 .4531 m .71142 .5412 L .73246 .55751 L p
.402 .269 .583 r
F P
s
P
p
.002 w
.8257 .59314 m .8608 .46822 L .84128 .45727 L p
.92 .813 .723 r
F P
s
P
p
.002 w
.52692 .73112 m .51106 .71861 L .48873 .70982 L p
.355 .62 .951 r
F P
s
P
p
1 0 0 r
.008 w
.47163 .71414 m
.50018 .72497 L
s
P
p
.002 w
.84128 .45727 m .80396 .59001 L .8257 .59314 L p
.92 .813 .723 r
F P
s
P
p
.002 w
.33947 .31556 m .34763 .2957 L .35658 .30575 L p
.326 .226 .585 r
F P
s
P
p
.002 w
.35658 .30575 m .34834 .32571 L .33947 .31556 L p
.326 .226 .585 r
F P
s
P
p
.002 w
.76807 .57632 m .80377 .44938 L .76333 .44781 L p
.632 .498 .682 r
F P
s
P
p
.002 w
.76333 .44781 m .73246 .55751 L .76807 .57632 L p
.632 .498 .682 r
F P
s
P
p
1 0 0 r
.008 w
.33888 .32437 m
.34799 .31068 L
s
P
p
1 0 0 r
.008 w
.1585 .59547 m
.33888 .32437 L
s
P
p
1 0 0 r
.008 w
.19388 .13242 m
.3366 .29751 L
s
P
p
1 0 0 r
.008 w
.3366 .29751 m
.34799 .31068 L
s
P
p
.002 w
.80396 .59001 m .84128 .45727 L .80377 .44938 L p
.765 .637 .72 r
F P
s
P
p
.002 w
.80377 .44938 m .76807 .57632 L .80396 .59001 L p
.765 .637 .72 r
F P
s
P
p
1 0 0 r
.008 w
.1585 .59547 m
.19388 .13242 L
s
P
p
.002 w
.17583 .02497 m
.93792 .14641 L
s
.93792 .14641 m
.97503 .81474 L
s
.97503 .81474 m
.14905 .75824 L
s
.14905 .75824 m
.17583 .02497 L
s
.05539 .25301 m
.02497 .86356 L
s
.02497 .86356 m
.14905 .75824 L
s
.14905 .75824 m
.17583 .02497 L
s
.17583 .02497 m
.05539 .25301 L
s
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 261},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00011A000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol0035oo`@00>Eo
o`00<7oo0P000goo1P00ggoo000`Ool20009Ool6003IOol002moo`03001oo`0000moo`L00=9oo`00
;goo00<007oo00005Woo1P00c7oo000^Ool01000Oomoo`0077oo1P00aWoo000^Ool01000Oomoo`00
8Woo1P00`7oo000]Ool01@00Oomoogoo0000:7oo1`00^Goo000]Ool01@00Oomoogoo00001goo0`00
9Goo1P00/goo000/Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Bcm;?d/o1@009Woo1P00[Goo
000/Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Bcm;?`06Bcl6000VOol7002VOol002]oo`03
001oogoo00=oo`03001oogoo00=oo`03001;?d/o00e;?`H002Moo`H00:1oo`00:goo00<007ooOol0
0goo00<007ooOol00goo00<004/oBcl04d/o1P009goo1P00VWoo000ZOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Bcm;?`0JBcl7000VOol6002DOol002Yoo`03001oogoo00Aoo`03001oogoo009o
o`03001;?d/o025;?`H002Ioo`L008eoo`00:Goo00<007ooOol017oo00<007ooOol00Woo00<004/o
Bcl0:4/o1`009Woo1P00Qgoo000XOol00`00Oomoo`05Ool01@00Oomoogoo0000<T/o1`009Goo1P00
PGoo000XOol00`00Oomoo`05Ool01@00Oomoogoo0000>D/o1P009Goo1`00NWoo000WOol00`00Oomo
o`06Ool01000Oomoo`00@4/o1`009Goo1P00M7oo000WOol00`00Oomoo`06Ool01000Oomoo`00Ad/o
1P009Goo1P00KWoo000VOol00`00Oomoo`07Ool00`00Ool0001>Bcl7000TOol7001WOol002Ioo`03
001oogoo00Moo`03001oo`0005E;?`H002Eoo`H0065oo`009Goo00<007ooOol027oo0P00G4/o1`00
97oo1P00Fgoo000UOol00`00Oomoo`08Ool00`00Bcm;?`1RBcl6000TOol6001EOol002Aoo`03001o
ogoo00Uoo`03001;?d/o06Q;?`L002=oo`L004ioo`0097oo00<007ooOol027oo0P00LD/o1`008goo
1P00B7oo000SOol00`00Oomoo`09Ool2001hBcl6000SOol60012Ool002=oo`03001oogoo00Qoo`03
001;?`0007i;?`L0029oo`L003]oo`008Woo00<007ooOol02Goo00<004/o0000QD/o1P008goo1P00
=Goo000ROol00`00Oomoo`08Ool01000Bcm;?`001D/o00=l04/oBcl0Pd/o1`008Woo1P00;goo000Q
Ool00`00Oomoo`08Ool01@00Bcm;?d/o000014/o0g`0Rd/o1P008Woo1P00:Goo000QOol00`00Oomo
o`08Ool01@00Bcm;?d/o000014/o17`0T4/o1`008Goo1`008Woo000POol00`00Oomoo`08Ool00`00
Bcm;?`02Bcl00`00Bcm;?`02Bcl5O02FBcl6000ROol6000LOol001moo`03001oogoo00Uoo`03001;
?d/o009;?`04001;?d/oBcl3O0000d/oO01l002LBcl7000QOol6000FOol001moo`03001oogoo00Qo
o`03001;?d/o00=;?`03001;?d/o00Al009;?`9l0:9;?`L0021oo`@0019oo`007Woo00<007ooOol0
2Goo00<004/oBcl00d/o00D004/oBcml04/o009l009;?`=l0:Q;?`H001aoo`80019oo`007Woo00<0
07ooOol027oo00<004/oBcl014/o00D004/oO01l04/o009l00=;?`=l0:e;?`L001=oo`800003Ool0
07oo015oo`007Goo00<007ooOol027oo00<004/oBcl01D/o00<004/oO0000T/o0W`014/o0g`0/d/o
1P0037oo00D007ooOomoo`00019oo`007Goo00<007ooOol027oo00<004/oBcl01D/o00<007`0O000
0T/o0W`01D/o0g`0^4/o10001goo00<007ooOol00Woo00<007ooOol047oo000LOol00`00Oomoo`08
Ool00`00Bcm;?`06Bcl00`00O01;?`02Bcl2O006Bcl3O02iBcl00`00Oomoo`05Ool00`00Oomoo`03
Ool00`00Oomoo`0@Ool001aoo`03001oogoo00Qoo`03001;?d/o00I;?`03001;?d/o009;?`9l00M;
?`=l0;M;?`03001oogoo00Aoo`8000Ioo`03001oogoo011oo`006goo00<007ooOol027oo00<004/o
Bcl01T/o00=l0000Bcl00d/o0W`024/o0W`0]D/o00<007ooOol01Goo00<007ooOol01Woo00<007oo
Ool047oo000KOol00`00Oomoo`08Ool00`00Bcm;?`06Bcl00g`0001;?`03Bcl2O009Bcl2O02cBcl0
0`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool001Yoo`03001oogoo00Qoo`03001;?d/o
00I;?`9l0004001;?d/oBcl2O00:Bcl3O02aBcl00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomo
o`0@Ool001Yoo`03001oogoo00Moo`03001;?d/o00I;?`9l0003001;?d/o009;?`9l00];?`=l0:m;
?`03001oogoo00Aoo`8000aoo`03001oogoo00moo`006Goo00<007ooOol027oo00<004/oBcl01T/o
00=l04/o000014/o0W`034/o0g`0[4/o0P001Woo00<007ooOol037oo00<007ooOol03goo000IOol0
0`00Oomoo`07Ool00`00Bcm;?`06Bcl2O0000d/o001;?`03Bcl2O00=Bcl3O02ZBcl00`00Oomoo`05
Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool001Qoo`03001oogoo00Qoo`03001;?d/o00I;?`04O01;
?d/o0004Bcl2O00>Bcl3O02XBcl00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool001Mo
o`03001oogoo00Qoo`03001;?d/o00I;?`9l009;?`03001;?d/o009;?`9l00m;?`=l0:I;?`03001o
ogoo00Aoo`80015oo`03001oogoo00moo`005goo00<007ooOol027oo00<004/oBcl01D/o0W`00d/o
00<004/oBcl00T/o0W`044/o0W`0YD/o00<007ooOol017oo00<007ooOol04Goo00<007ooOol03goo
000FOol00`00Oomoo`08Ool00`00Bcm;?`06Bcl00g`0Bcm;?`02Bcl00`00Bcm;?`02Bcl2O00ABcl2
O02RBcl20006Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool001Ioo`03001oogoo00Moo`03001;?d/o
00I;?`9l00A;?`03001;?d/o009;?`9l015;?`=l0:1;?`03001oogoo00Eoo`03001oogoo01=oo`03
001oogoo00moo`005Goo00<007ooOol027oo00<004/oBcl01T/o00=l04/oBcl00d/o00<004/oBcl0
0T/o0W`04T/o0g`0WT/o00<007ooOol017oo0P005Woo00<007ooOol03goo000EOol00`00Oomoo`07
Ool00`00Bcm;?`06Bcl2O005Bcl00`00Bcm;?`02Bcl2O00CBcl3O02LBcl00`00Oomoo`04Ool00`00
Oomoo`0FOol00`00Oomoo`0?Ool001Aoo`03001oogoo00Qoo`03001;?d/o00E;?`9l00I;?`03001;
?d/o009;?`9l01A;?`=l09Y;?`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00moo`0057oo
00<007ooOol01goo00<004/oBcl01T/o00=l04/oBcl01D/o00<004/oBcl00T/o0W`05D/o0g`0Ud/o
0P001Woo00<007ooOol067oo00<007ooOol03goo000COol00`00Oomoo`08Ool00`00Bcm;?`05Bcl2
O007Bcl01000Bcm;?d/o0W`05d/o0W`0UT/o00<007ooOol017oo0P006goo00<007ooOol03goo000C
Ool00`00Oomoo`07Ool00`00Bcm;?`06Bcl00g`0Bcm;?`06Bcl01000Bcm;?d/o0W`064/o0W`0U4/o
00<007ooOol017oo00<007ooOol06goo00<007ooOol03goo000BOol00`00Oomoo`07Ool00`00Bcm;
?`06Bcl2O008Bcl01000Bcm;?d/o0W`064/o0g`0TT/o00<007ooOol017oo00<007ooOol077oo00<0
07ooOol03goo000BOol00`00Oomoo`07Ool00`00Bcm;?`06Bcl00g`0Bcm;?`07Bcl01000Bcm;?d/o
0W`06D/o0g`0T4/o00<007ooOol017oo00<007ooOol07Goo00<007ooOol03goo000AOol00`00Oomo
o`07Ool00`00Bcm;?`06Bcl2O009Bcl01000Bcm;?d/o0W`06T/o0g`0SD/o0P001Woo00<007ooOol0
7Woo00<007ooOol03goo000AOol00`00Oomoo`07Ool00`00Bcm;?`05Bcl2O00:Bcl01000Bcm;?d/o
0W`06d/o0g`0Rd/o00<007ooOol017oo0P008Goo00<007ooOol03goo000@Ool00`00Oomoo`07Ool0
0`00Bcm;?`06Bcl00g`0Bcm;?`09Bcl01000Bcm;?d/o0W`074/o0g`0RD/o00<007ooOol017oo00<0
07ooOol08Goo00<007ooOol03goo000@Ool00`00Oomoo`07Ool00`00Bcm;?`05Bcl2O00;Bcl01000
Bcm;?d/o0W`07D/o0g`0Qd/o00<007ooOol017oo00<007ooOol08goo00<007ooOol03Woo000?Ool4
0006Ool00`00Bcm;?`06Bcl00g`0Bcm;?`0:Bcl01000Bcm;?d/o0W`07T/o0W`0Jd/o1`0054/o00<0
07ooOol017oo00<007ooOol097oo00<007ooOol03Woo000?Ool01000Oomoogoo1P0024/o0W`034/o
00@004/oBcm;?`9l01m;?`9l06E;?`H000HD00L000];?`8000Eoo`8002Moo`03001oogoo00ioo`00
3goo00<007ooOol01Woo00<004/oBcl01D/o0W`03D/o00@004/oBcm;?`9l01m;?`=l069;?`8000H`
B0X000<D00P0009;?`03001oogoo00Aoo`03001oogoo02Moo`03001oogoo00ioo`003goo00<007oo
Ool01Goo00<004/oBcl01T/o00=l04/oBcl034/o00@004/oBcm;?`9l021;?`=l05m;?`<0014`B0l0
00Aoo`03001oogoo02Qoo`03001oogoo00ioo`003goo00<007ooOol01Goo00<004/oBcl01D/o0W`0
3T/o00@004/oBcm;?`9l025;?`=l05e;?`<001D`B0800003BDl005e:00MMBP04001oogoo000[Ool0
0`00Oomoo`0>Ool000moo`03001oogoo00Aoo`03001;?d/o00I;?`03O01;?d/o00e;?`03001;?d/o
009l02=;?`=l05Y;?`D001@`B0050019CdU?BDl00008GDX3000/Ool00`00Oomoo`0>Ool000moo`03
001oogoo00Aoo`03001;?d/o00E;?`9l00m;?`03001;?d/o009l02A;?`=l05Q;?`D001<`B08000E9
C`03001MBUe:00IMBP8002aoo`03001oogoo00ioo`003goo00<007ooOol00goo1@000d/o0W`044/o
00<004/oBcl00W`09D/o0W`0ET/o2P003c1800<004U?BDl01TU?00<005e:GDX01Ue:0P00:goo00<0
07ooOol03Woo000?Ool00`00Oomoo`08Ool300000g`000000002000=Bcl00`00Bcm;?`02O00VBcl2
O01CBcl80004<A880005<4P2000:BDl00`00GDYMBP06GDX2000ZOol00`00Oomoo`0>Ool000moo`03
001oogoo00Yoo`9l00Aoo`P000E;?`03001;?d/o009l02I;?`=l055;?`H0008a4P03000a4S4B00Xa
4PD000a9C`03001MBUe:00IMBP03001H`00002Uoo`03001oogoo00ioo`003goo00<007ooOol02Woo
00=l07ooOol02goo20000W`09d/o0g`0CT/o1`000c4B00<0034B<A803S4B0P0034U?00<005e:GDX0
1Ue:00<005S00000:7oo00<007ooOol03Woo000>Ool00`00Oomoo`0:Ool2O00AOol01000Oomoogoo
0W`01P008T/o0g`00T/o0`00Ad/o1P001C4B00<0034B<A803C4B00@0034B<A8000a9C`03001MBUe:
00IMBP03001H`00002Moo`03001oogoo00ioo`003Woo00<007ooOol02Goo0W`04Woo00@007ooOomo
o`9l00Ioo`P001];?`9l009;?`8000=HhP80045;?`H000Ha4P03000a4S4B00ha4P04000a4S4B000=
BDl00`00GDYMBP06GDX2000WOol00`00Oomoo`0>Ool000ioo`03001oogoo00Uoo`03O01oogoo015o
o`04001oogooOol2O00>Ool8000DBcl2O0001000:?8XlP001USR0`00>T/o1`001c4B00<0034B<A80
3C4B00<0034B<A800S4B00<004U?BDl02TU?00<005e:GDX01Ue:00<005S000009Woo00<007ooOol0
3Woo000>Ool00`00Oomoo`08Ool2O00COol01000Oomoogoo0W`05Woo20003D/o0W`00bSb0`001eSR
1000=4/o1P002C4B00<0034B<A803C4B00<0034B<A800c4B00<004U?BDl02TU?00<005e:GDX01Ue:
00<005S000009Goo00<007ooOol03Woo000>Ool00`00Oomoo`08Ool00g`0Oomoo`0BOol01000Oomo
ogoo0W`07Woo20001T/o0W`000<XlP0000000VLJ1@001eSR0`00;d/o1P002S4B00<0034B<A803C4B
00<0034B<A80134B00<004U?BDl02TU?00<005e:GDX01Ue:00<005S0000097oo00<007ooOol03Woo
000>Ool00`00Oomoo`07Ool2O00DOol01000Oomoogoo0W`09Woo1P0000@XlW`0:?8000QW6PD000IH
hP@002Y;?`@000`a4P03000a4S4B00`a4P03000a4S4B00Da4P030019CdU?00]9C`03001MBUe:00IM
BP03001H`00002=oo`03001oogoo00ioo`003Woo00<007ooOol01Woo0W`05Goo00@007ooOomoo`9l
02Yoo`04O00007`0O002000=IaX40006F>85000TBcl3000><A84000;<A800`00<A8a4P06<A800`00
BDm9C`0:BDl00`00GDYMBP06GDX00`00F<00000TOol00`00Oomoo`0=Ool000ioo`03001oogoo00Io
o`03O01oogoo01Aoo`03001oogoo009l02Yoo`Al0003:?8006LJ015W6PD000EHhPD0021;?`8000da
4P<000<]V0L000<a4P03000a4S4B00Pa4P030019CdU?00Y9C`03001MBUe:00IMBP03001H`00002=o
o`03001oogoo00eoo`003Woo00<007ooOol017oo0g`05Woo00<007ooOol00W`0:7oo1W`00P005fLJ
1@001ESR1@006T/o00<0034B<A80334B00D0048H@QQ2600000T]V0@000/a4P030019CdU?00Y9C`03
001MBUe:00IMBP03001H`000029oo`03001oogoo00eoo`003Woo00<007ooOol017oo2G`047oo00<0
07ooOol00W`09goo17`000Aoog`0Ool0009l01]W6PD000AHhPD001E;?`8000`a4P8000A26003000]
V2fH00X]V08000Xa4P030019CdU?00]9C`03001MBUe:00IMBP03001H`000025oo`03001oogoo00eo
o`003Woo00<007ooOol017oo4G`027oo00<007ooOol00W`09Woo0g`00Woo0W`00Woo0g`010006fLJ
1@0015SR1@0044/o00<0034B00002C4B0P001T8H00<002fH;IP02RfH0P002c4B00<004U?BDl02TU?
00<005e:GDX01Ue:00<005S0F<008Goo00<007ooOol03Goo000>Ool00`00Oomoo`04Ool2O007Ool?
O00017oo001oogoo0W`09Goo0g`00Woo0W`00goo0g`017oo1@006fLJ1@000eSR1P002T/o00@0034B
<A8000Pa4P8000M26003000]V2fH00X]V0030000U00000/a4P030019CdU?00U9C`H000AMBP03001H
`000021oo`03001oogoo00eoo`003Woo00<007ooOol017oo0W`03goo27`000<007`0O00017`08Woo
0g`00goo00=l07ooOol00goo0W`02Goo100076LJ100015SR1@001D/o00D0034B<A8a4P0000Ha4P80
00Y26003000]V2fH00T]V0040000U02D000;<A800`00BDm9C`06BDl200000e6c001R<P03HS860000
0eS0001oo`0NOol00`00Oomoo`0=Ool000ioo`03001oogoo00Aoo`9l01Ioo`03O00007`000al01Eo
o`@000Al0003001oogoo009l00Eoo`=l00aoo`D001]W6PD000=HhPL000@a4P03000a4S4B008a4P80
00]26003000]V2fH00T]V0050000U02D09@0000:<A800`00BDm9C`03BDl30003DK<00`00HS9R<P07
HS8200000eS0001oo`0MOol00`00Oomoo`0=Ool000ioo`03001oogoo00Aoo`9l01Moo`03001oogoo
009l009oo`ml00eoo`03001@ae3700Al00=@a`9l0003D<L0000000@0009l00D000aoo`@001aW6PD0
00=HhPL000<a4P030012648H00]26003000]V2fH00X]V0040000U02D000;<A800`00BDm9C`020006
DK<00`00HS9R<P07HS801@00NZl005S000007Goo00<007ooOol03Goo000>Ool00`00Oomoo`04Ool2
O00GOol00`00Oomoo`02O009Ool@O005Ool00`00D<Ml0002O005D<L00g`0D<M@a`06D<L3O004D<LD
000MIaX50003F>85000?@QP00`00;IP]V009;IP01@0009@0U02D00002c4B0P00256c00<0068bHS80
1f8b00<007Z_NZl00P007Goo00<007ooOol03Goo000>Ool00`00Oomoo`04Ool2O00GOol00`00Oomo
o`02O00AOolAO0050002O009D<L2O00ED<L:000KIaX50002F>86000:@QP30009;IP00`0009@0U002
09@00`00<A8a4P07<A820009DK<00`00HS9R<P07HS800`00NZmj[`02NZl00`00Oomoo`0JOol00`00
Oomoo`0=Ool000ioo`03001oogoo00Aoo`9l01Moo`03001oogoo009l01Uoo`Ql00EJ^@9l0003F[T0
000000L0009l00/001A@a`D001]W6PD0009HhPH000=260800003C[`001hm00H000<]V0030000U02D
0080U003000a4S4B00Ha4P03000a4P0000YA/`03001R<V8b00MR<P03001j[gZ_009j[`03001oogoo
01Uoo`03001oogoo00eoo`003Woo00<007ooOol017oo0W`05goo00<007ooOol00W`07Goo0W`01eZi
00=l05ZiF[T02EZi0g`02UZi5P000e371@006fLJ10000USR1P000djl0P001Ahm10001@2D00<0034B
<A80134B00@0034B<A8000YA/`03001R<V8b00MR<P03001j[gZ_009j[`03001oogoo01Uoo`03001o
ogoo00eoo`003Woo00<007ooOol017oo0W`05goo00<007ooOol00W`07Goo00=l0000F[T01EZi0W`0
35Zi0W`085Zi3@006VLJ1@000USR10000Tjl00<001hm7Sd01Qhm00<0002D09@00`2D00<0034B<A80
0S4B00D0034B<A8a4P0000YA/`03001R<V8b00MR<P03001j[gZ_009j[`03001oogoo01Uoo`03001o
ogoo00eoo`003Woo00<007ooOol017oo0W`05goo00@007ooO01l01eoo`9l0003001J^G`000=J^@9l
00eJ^@9l02eJ^@D001YW6PD00005F>8004jlC[`000077Sd00`0009@0U00409@01000<A8a4P00134B
00<0056cDK<0256c00<0068bHS801f8b00<007Z_NZl00WZ_00<007ooOol06Goo00<007ooOol03Goo
000>Ool00`00Oomoo`04Ool2O00GOol01000Ooml07`07Goo00=l07oo00000g`00P0000=l00000000
35Zi0g`0<5Zi1@006fLJ0`000Tjl0P001Qhm00<0002D09@00`2D00<0034B00001C4B00<0056cDK<0
256c00<0068bHS801f8b00<007Z_NZl00WZ_00<007ooOol06Goo00<007ooOol03Goo000=Ool00`00
Oomoo`05Ool2O00GOol01000Ooml07`077oo0W`00goo1G`00Woo3@000W`00P00<eZi1@0066LJ00<0
04jlC[`00Tjl1@000Qhm00<0002D09@00`2D00<0034B<A80134B00<0056cDK<0256c00<0068bHS80
1f8b00<007Z_NZl00WZ_00<007ooOol06Goo00<007ooOol03Goo000=Ool00`00Oomoo`05Ool2O00G
Ool01000Ooml07`06goo0W`01Goo0g`047oo0g`000=oo`0000003`009eZi1@004VLJ00@004jlC[a>
_08000AC_`D000@0U003000a4S4B00Da4P03001A/e6c00MA/`03001R<V8b00MR<P03001j[gZ_00=j
[`03001oogoo01Qoo`03001oogoo00eoo`003Goo00<007ooOol01Goo0W`05goo00@007ooO01l01]o
o`03O01oogoo00Eoo`03O01oogoo011oo`9l019ooa8001YJ^@D000eW6P04001>_0000005Dkl00`00
Ool00002Ool00`0009@0U00209@00`00<A8a4P05<A800`00DK=A/`07DK<00`00HS9R<P07HS800`00
NZmj[`03NZl00`00Oomoo`0HOol00`00Oomoo`0=Ool000eoo`03001oogoo00Eoo`9l01Moo`04001o
og`0O00JOol2O006Ool3O00AOol2O00TOolA000>F[T50003IaX400000fLJ00000005Dkl20002Ool0
1@00Oomoogoo00000`2D00<0034B<A801C4B00<0056cDK<01e6c00<0068bHS80268b00<007Z_NZl0
0WZ_00<007ooOol06Goo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2O00GOol01000Ooml07`0
6Woo00=l07ooOol017oo0W`000=oog`0Ool047oo0g`0;Goo00<0034B<A80134B40000eZi2@001E>o
00<007ooOol00Woo00<007ooOol00Woo00@0002D000000La4P03001A/e6c00MA/`03001R<V8b00QR
<P03001j[gZ_009j[`03001oogoo01Uoo`03001oogoo00aoo`003Goo00<007ooOol01Goo0W`05goo
00@007ooO01l01Uoo`9l00Ioo`03O01oogoo009l015oo`9l02aoo`03000a4S4B00Da4P03001>5dhG
00Q>5`03001J^EZi00=J^@X000AC_`8000Eoo`03001oogoo009oo`@000La4P03001A/e6c00MA/`03
001R<V8b00QR<P03001j[gZ_009j[`03001oogoo01Uoo`03001oogoo00aoo`003Goo00<007ooOol0
1Goo0W`05Woo00<007ooOol00W`067oo0W`01Woo0W`00goo00=l07ooOol03goo0W`0:goo00<0034B
<A801C4B00<004hGCQL024hG00<005ZiF[T01UZi00<004gfCOH0100000=Z]E>oDkl00P001goo00<0
07ooOol00goo0`001c4B00<0056cDK<0256c00<0068bHS801f8b00<007Z_NZl00WZ_00<007ooOol0
6Goo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2O00FOol00`00Oomoo`02O00HOol00g`0Oomo
o`04Ool2O004Ool2O00@Ool3O00ZOol00`00<A8a4P04<A800`00CQM>5`08CQL00`00F[UJ^@05F[T2
0003COH400000fZe00000009Ool00`00Oomoo`04Ool20007<A800`00DK=A/`08DK<00`00HS9R<P07
HS800`00NZmj[`02NZl00`00Oomoo`0IOol00`00Oomoo`0<Ool000eoo`03001oogoo00Eoo`9l01Io
o`03001oogoo009l01Moo`9l00Ioo`03O01oogoo00Aoo`03O01oogoo00moo`9l02Uoo`03000a4S4B
00Da4P03001>5dhG00Q>5`03001J^EZi00AJ^@03001=mTgf009=mP@0009Z]@03001oogoo00Qoo`03
001oogoo00Aoo`8000La4P03001A/e6c00QA/`03001R<V8b00MR<P03001j[gZ_009j[`03001oogoo
01Uoo`03001oogoo00aoo`003Goo00<007ooOol01Goo0W`05Woo00<007ooOol00W`05Woo0W`01Woo
0W`01Woo0W`047oo0g`0:7oo00<a4P00<A80134B00<004hGCQL024hG00<005ZiF[T015Zi00<004gf
COH00dgf10000VZe00<007ooOol027oo00<007ooOol017oo0P001c4B00<0056cDK<0256c00<0068b
HS801f8b00<007Z_NZl00WZ_00<007ooOol06Goo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2
O00FOol00`00Oomoo`02O00EOol2O006Ool2O008Ool2O00@Ool2O00WOol00`00<A8a4P020002<A80
0`00CQM>5`08CQL00`00F[UJ^@03F[T20005COH50002J[D00`00Oomoo`09Ool00`00Oomoo`03Ool2
0007<A800`00DK=A/`08DK<00`00HS9R<P07HS800`00NZmj[`02NZl00`00Oomoo`0IOol00`00Oomo
o`0<Ool000eoo`03001oogoo00Eoo`9l01Ioo`03001oogoo009l01Eoo`03O01oogoo00Eoo`03O01o
ogoo00Qoo`03O01oogoo00ioo`9l02Moo`03000a4S4B008a4P03000a4P0000Y>5`03001J^EZi009J
^@03001=mTgf00E=mPD0009Z]@03001oogoo00Uoo`03001oogoo00=oo`8000La4P03001A/e6c00QA
/`03001R<V8b00MR<P03001j[gZ_009j[`03001oogoo01Uoo`03001oogoo00aoo`003Goo00<007oo
Ool01Goo0W`00goo1P003Goo00@007ooO01l01Eoo`9l00Ioo`9l00Yoo`9l00moo`=l02Ioo`03000a
4S4B00<a4P03001>5dhG00Q>5`04001J^EZiF[T20007COH400001F]k001Z]FZe00002goo00<007oo
Ool00goo00<0000700001S4B00<0056cDK<0256c00<0068bHS80268b00<007Z_NZl00WZ_00<007oo
Ool067oo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2O003Ool70002?0070003Ool01000Ooml
07`057oo0W`01Woo0W`037oo00=l07ooOol03Woo0W`09Woo00<0034B<A800c4B0`001dhG00D005Zi
F[UJ^@0000U=mPD000=Z]@03001oogoo00Uoo`03001oogoo00=oo`0300001`0000Ha4P03001A/e6c
00QA/`03001R<V8b00QR<P03001j[gZ_009j[`03001oogoo01Qoo`03001oogoo00aoo`003Goo00<0
07ooOol01Goo0W`00Woo00<0000:00001F9D2P0000@l00000000009l00<0015oo`03O01oogoo00Eo
o`03O01oogoo00]oo`9l00moo`9l02Eoo`03000a4S4B00<a4P04001B5E8EDQD20004CQL01@00F[UJ
^EZi00002Dgf100000==mP00J[D00VZe00<007ooOol02Goo00<007ooOol00goo00<0000700001S4B
00<0056cDK<0256c00<0068bHS80268b00<007Z_NZl00WZ_00<007ooOol067oo00<007ooOol037oo
000=Ool00`00Oomoo`05Ool2O002Ool00`0000X0000?HU@40002O00=0006Ool2O006Ool2O00>Ool2
O00>Ool3O00TOol00`00<A8a4P03<A800`00DQEB5@03DQD20002CQL01000F[T000002Tgf100000==
mP00J[D00fZe2goo00<007ooOol00goo00<0000700001c4B00<0056cDK<01e6c00<0068bHS80268b
00<007Z_NZl00WZ_00<007ooOol067oo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2O002Ool0
0`0000X0000AHU@01000HUAl07`0169D3P000W`00`000goo0W`047oo00=l07ooOol03Goo0W`097oo
00<0034B<A800c4B00<0058EDQD01E8E10002dgf100000==mP00000016Ze2goo00<007ooOol00goo
00<0000700001c4B00<0056cDK<01e6c00<0068bHS80268b00<007Z_NZl00WZ_00<007ooOol067oo
00<007ooOol037oo000=Ool00`00Oomoo`05Ool2O002Ool00`0000X0000AHU@01000HUAl07`03V9D
0`000W`01`0000=l0000000010002goo0W`03Woo0g`08Woo00<0034B<A800c4B00<0058EDQD01e8E
0P0034gf100000==mWoo000016Ze2goo00<007ooOol017oo0P001c4B00<0056cDK<0256c00<0068b
HS801f8b00<007Z_NZl00WZ_00<007ooOol067oo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2
O002Ool00`0000X00004000=HU@01000HUAl07`0469D0W`01V9D00<007`0O00030001Woo00=l07oo
Ool03Goo0W`08Woo00<0034B<A800c4B00<0058EDQD01U8E00<004gfCOH02dgf10000Tgf00<006Ze
J[D00fZe2goo00<007ooOol017oo0P001c4B00<0056cDK<0256c00<0068bHS801f8b00<007Z_NZl0
0WZ_00<007ooOol067oo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2O002Ool00`0000X00004
G_/90004HU@01000HUAl07`0469D0W`01V9D0W`0269D1P001Goo0W`03Woo0W`08Woo00<0034B<A80
0c4B00<0058EDQD01E8E00<004gfCOH034gf10000Tgf00<006ZeJ[D00fZe00<007ooOol027oo00<0
07ooOol017oo0P001c4B00<0056cDK<0256c00<0068bHS801f8b00<007Z_NZl00WZ_00<007ooOol0
67oo00<007ooOol037oo000=Ool00`00Oomoo`05Ool2O002Ool2000>G_/60002O00@HU@2O006HU@0
0g`0HUARE00<HU@00`00Oomoo`04Ool2O00=Ool3O00POol00`00<A8a4P03<A800`00DQEB5@04DQD2
000>COH40002COH00goo001Z]@04J[D00`00Oomoo`08Ool00`00Oomoo`04Ool20007<A800`00DK=A
/`08DK<00`00HS9R<P08HS801@00NZmj[gZ_00006Woo00<007ooOol037oo000<Ool00`00Oomoo`06
Ool2O002Ool2000BG_/01000G_]l07`02@001V9D0W`01V9D0W`03V9D00<007ooOol01Goo00=l07oo
Ool037oo0W`087oo00<0034B<A800c4B00<0058EDQD00e8E00<004gfCOH03Tgf10000dgf00<006Ze
J[D00fZe00<007ooOol027oo00<007ooOol017oo0P001S4B1`001E6c00<0068bHS80268b00D007Z_
NZmj[`0001Yoo`03001oogoo00aoo`0037oo00<007ooOol01Woo0W`00goo1@003Ukk00@005kkO01l
00UNn`D0009l008000ARE09l00mRE003001oogoo00Eoo`9l00eoo`9l021oo`03000a4S4B00<a4P03
001B5E8E009B5@03001=mTgf00i=mP@000A=mP03001Z]FZe00=Z]@03001oogoo00Qoo`03001oogoo
00Aoo`80008a4P@00003<A80057e00AAm@P000QR<P03001j[gZ_009j[`03001oogoo01Qoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo0W`027oo2@001Ekk00@005kkO01l00iNn`04O01NnekkG_/4
000017`0000000003F9D00<0000O01l01P0O0W`000<07gooOol02Goo0g`07goo00<0034B<A800S4B
00@0058EDQEB5@80015=mP@000==mP03001Z]FZe00AZ]@03001oogoo00Qoo`03001oogoo00Aoo`@0
00@a4P03001AmE7e00UAm@03001RUf:G00H0009R<P03001j[gZ_009j[`03001oogoo01Qoo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo0W`04Goo1`000W`03Ekk0W`01Ukk0W`00ekk2@00169D00<0
000O01l01`0O00=l000O01l02`0O0W`07Woo00<0034B<A800c4B00@0058EDQD0019=mP@000==mP03
Ool006Ze00IZ]@Yoo`03001oogoo00Aoo`8000Ha4P03001AmE7e00QAm@03001RUf:G00MRU`<000Aj
[`03001oogoo01Qoo`03001oogoo00]oo`0037oo00<007ooOol01Woo0W`05Woo00<007`0O0002@00
15kk0W`01Ukk0W`03Ekk1@002@0O0W`0300O0g`0200O5Goo00<0034B<A800c4B0`004dgf100014gf
00<006ZeJ[D01FZe2Woo00<007ooOol017oo00<0034B<A801C4B00<0057eDOD0257e00<006:GHYL0
2F:G0`000WZ_00<007ooOol067oo00<007ooOol02goo000<Ool00`00Oomoo`06Ool2O00FOol00`00
O01l0009Ool30002O0040002G_/2O00BG_/00`0001l07`0801l00g`001l07`0;01l2O00D01l9Ool0
0`00<A8a4P03<A800`00COI=mP0BCOH40005COH00`00J[EZ]@05J[D:Ool00`00Oomoo`04Ool00`00
<A8a4P05<A800`00DOEAm@08DOD00`00HYMRU`08HYL01000MeMgEgMG0`006Woo00<007ooOol02goo
000<Ool00`00Oomoo`06Ool2O00FOol00`00O01l000<Ool00g`0Oomoo`03Ool200000g`000000003
000=G_/00`00Oomoo`09Ool2O00<01l2O00O01l3<A800`00COI=mP0BCOH50005COH00`00J[EZ]@05
J[D:Ool00`00Oomoo`03Ool20006<A800`00DOEAm@09DOD00`00HYMRU`08HYL00`00MeMgE`03MeL0
0`00Oomoo`0HOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`9l01Ioo`03001l07`000]oo`9l
00Ioo`9l00Eoo`P000ENn`03001oogoo00Yoo`03O01oogoo00Uoo`0401ml07`0O00P01l00`00COI=
mP0CCOH50003COH00goo001Z]@07J[D:Ool00`00Oomoo`03Ool20006<A800`00DOEAm@08DOD00`00
HYMRU`09HYL00`00MeMgE`03MeL00`00Oomoo`0HOol00`00Oomoo`0;Ool000aoo`03001oogoo00Io
o`9l01Ioo`03001l07`000Yoo`9l00Ioo`9l00moo`D000aoo`9l00aoo`9l00MooaT07`l000M=mP@0
00E=mP03001Z]FZe00IZ]@03001oogoo00Moo`03001oogoo00=oo`03000a4S4B00Da4P03001AmE7e
00QAm@03001RUf:G00URU`03001gEgMG009gE`03001oogoo01Uoo`03001oogoo00]oo`0037oo00<0
07ooOol01Woo0W`05Woo00<007`0O0002Woo00=l07ooOol01Goo00=l07ooOol087oo00=l07ooOol0
2Woo0W`04goo3@0O00@0058EDQEB5@X000038]h00000014000IZ]@03001oogoo00Moo`03001oogoo
00=oo`03000a4S4B00@a4P03001AmE7e00UAm@03001RUf:G00QRU`03001gEgMG00=gE`03001oogoo
01Uoo`03001oogoo00]oo`0037oo00<007ooOol01Woo0W`05Woo00<007`0O0002Goo0W`01Woo0W`0
8Woo0W`02goo0g`06Goo00@0034B<A8a4P807`03001B5E8E00MB5@04001RUV:FHYH<00038]h20002
J[D30004J[D00`00Oomoo`07Ool00`00Oomoo`02Ool20006<A800`00DOEAm@08DOD00`00HYMRU`09
HYL00`00MeMgE`03MeL00`00Oomoo`0IOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`9l01Io
o`03001l07`000Uoo`03O01oogoo00Aoo`9l02Aoo`9l00]oo`9l01Uoo`03000a4S4B00<a4P03001B
5E8E00MB5@03001RUV:F00=RUP80009RUPT000MZ]@<00003J[D007oo00Qoo`03001oogoo009oo`03
000a4S4B00Da4P03001AmE7e00QAm@03001RUf:G00URU`03001gEgMG00=gE`03001oogoo01Uoo`03
001oogoo00]oo`0037oo00<007ooOol01Woo0W`05Woo00<007`0O00027oo0W`01Woo00=l07ooOol0
97oo00=l07ooOol02Goo0g`067oo00<0034B<A800S4B00<0058EDQD0258E00<006:FHYH00`0000<d
[P0000001P0000=c5`0000002VZe0`002Goo00<007ooOol00Woo00<0034B<A801C4B00<0057eDOD0
257e00<006:GHYL026:G00<007MGMeL00gMG00<007ooOol06Woo00<007ooOol02goo000<Ool00`00
Oomoo`06Ool2O00FOol00`00O01l0007Ool2O006Ool2O00VOol2O00;Ool2O00GOol01000<A8a4S4B
1`001E8E00D006:FHYIRUP00008d[P04001IleWcFO<60007J[D5000<Ool00`00Oomoo`02Ool00`00
<A8a4P04<A800`00DOEAm@09DOD00`00HYMRU`08HYL00`00MeMgE`03MeL00`00Oomoo`0JOol00`00
Oomoo`0;Ool000aoo`03001oogoo00Ioo`9l01Eoo`04001oog`0O007Ool00g`0Oomoo`04Ool2O00X
Ool00g`0Oomoo`09Ool2O00GOol40002<A800`00DM=Ad`02DM<90003=:h00`00FO=Il`03FO<20004
J[D5000AOol01@00Oomoogoo00001c4B00<0057eDOD0257e00<006:GHYL02F:G00<007MGMeL00gMG
00<007ooOol06Woo00<007ooOol02goo000<Ool00`00Oomoo`06Ool2O00EOol01000Ooml07`01Woo
0W`01Woo00=l07ooOol09goo0W`02Woo0g`05Woo00<0034B<A800c4B00<0057CDM<01e7C00@0068c
HS<0008d[P03001IleWc00EIl`D001Ioo`05001oogooOol00007<A800`00DOEAm@08DOD00`00HYMR
U`08HYL00`00MeMgE`03MeL00`00Oomoo`0KOol00`00Oomoo`0;Ool000aoo`03001oogoo00Ioo`9l
01Eoo`04001oog`0O005Ool2O006Ool2O00ZOol00g`0Oomoo`09Ool2O00FOol00`00<A8a4P03<A80
0`00DM=Ad`07DM<00`00HS<00003=:h00`00FO=Il`04FO<01000K[E^]Fje0P005Woo00D007ooOomo
o`0000Ha4P03001AmE7e00UAm@03001RUf:G00QRU`03001gEgMG00=gE`03001oogoo01]oo`03001o
ogoo00]oo`0037oo00<007ooOol01Woo0W`05Goo00<007`0O0001Woo00=l07ooOol017oo0W`0:goo
0W`02Woo0W`05Woo00<0034B<A800c4B00<0057CDM<01e7C00<0068c00000SB^00<005WcFO<01EWc
00<006jeK[D00fje00<007ooOol04goo00D007ooOomoo`0000Ha4P03001AmE7e00QAm@03001RUf:G
00URU`03001gEgMG00=gE`03001oogoo01]oo`03001oogoo00]oo`0037oo00<007ooOol01Woo0W`0
5Goo00<007`0O0001Goo0W`01Woo00=l07ooOol0:goo00=l07ooOol027oo0g`05Goo00<0034B<A80
0c4B00<0057CDM<01e7C0P000cB^00<005WcFO<015Wc00<006jeK[D016je00<007ooOol04goo00@0
07ooOol000La4P03001AmE7e00QAm@03001RUf:G00URU`03001gEgMG00=gE`03001oogoo01]oo`03
001oogoo00]oo`0037oo00<007ooOol01Woo0W`05Goo00<007`0O0001Goo00=l07ooOol017oo0W`0
;Goo0W`02Woo0W`05Goo00<0034B<A800c4B00<0057CDM<01e7C0P000SB^00<005WcFO<01EWc00<0
06jeK[D00fje00<007ooOol057oo00@007ooOol000Ha4P03001AmE7e00UAm@03001RUf:G00QRU`03
001gEgMG00=gE`03001oogoo01eoo`03001oogoo00Yoo`0037oo00<007ooOol01Woo0W`05Goo00<0
07`0O00017oo0W`01Goo0W`0;goo00=l07ooOol027oo0W`05Goo00<0034B<A800c4B00<0057CDM<0
1e7C00D003B^=:hd[P0000IIl`03001^]Fje00A^]@03001oogoo01Aoo`04001oogoo0006<A800`00
DOEAm@09DOD00`00HYMRU`08HYL00`00MeMgE`03MeL00`00Oomoo`0MOol00`00Oomoo`0:Ool000]o
o`03001oogoo00Moo`9l01Eoo`03001l07`000=oo`9l00Ioo`03O01oogoo02ioo`9l00Uoo`=l01Ao
o`03000a4S4B00<a4P03001Ade7C00MAd`05000d[SB^=:h00006FO<00`00K[E^]@03K[D2000FOol0
0`00Ool00007<A800`00DOEAm@08DOD00`00HYMRU`09HYL00`00MeMgE`03MeL00`00Oomoo`0MOol0
0`00Oomoo`0:Ool000]oo`03001oogoo00Moo`9l01Eoo`03001l07`000=oo`03O01oogoo00Aoo`9l
035oo`9l00Uoo`9l01Aoo`03000a4S4B00<a4P03001Ade7C00IAd`05000d[SB^=:h00006FO<00`00
K[E^]@04K[D00`00Oomoo`0EOol00`00Ool00007<A800`00DOEAm@08DOD00`00HYMRU`08HYL00`00
MeMgE`03MeL00`00Oomoo`0NOol00`00Oomoo`0:Ool000]oo`03001oogoo00Moo`9l01Eoo`03001l
07`0009oo`9l00Eoo`9l03=oo`03O01oogoo00Moo`=l01=oo`03000a4S4B00<a4P03001Ade7C00IA
d`05000d[SB^=:h00006FO<00`00K[E^]@03K[D2000GOol00`00Ool00006<A800`00DOEAm@09DOD0
0`00HYMRU`08HYL00`00MeMgE`03MeL00`00Oomoo`0NOol00`00Oomoo`0:Ool000]oo`03001oogoo
00Moo`9l01Eoo`04001l07`0Ool2O006Ool00g`0Oomoo`0bOol2O009Ool2O00COol00`00<A8a4P04
<A800`00DM=Ad`05DM<01000=:hd[P001UWc00<006jeK[D016je00<007ooOol05Woo00<007oo0000
1S4B00<0057eDOD0257e00<006:GHYL02F:G00<007MGMeL00gMG00<007ooOol07Woo00<007ooOol0
2Woo000;Ool00`00Oomoo`07Ool2O00EOol01@00O01l07ooO0001Woo0W`0=Goo00=l07ooOol01goo
0W`04goo00<0034B<A80134B00<0057CDM<0157C00D003B^=:hd[P0000IIl`03001^]Fje00=^]@80
01Qoo`8000La4P03001AmE7e00QAm@03001RUf:G00QRU`03001gEgMG00AgE`03001oogoo01ioo`03
001oogoo00Yoo`002goo00<007ooOol01goo0W`05Goo00<007`0O0000W`01Goo0W`0=Woo0W`027oo
0g`04Woo00<0034B<A80134B00<0057CDM<0157C00@003B^=:h000MIl`03001^]Fje00=^]@8001Qo
o`8000Ha4P03001AmE7e00UAm@03001RUf:G00QRU`03001gEgMG00=gE`03001oogoo01moo`03001o
ogoo00Yoo`002goo00<007ooOol01goo0W`05Goo00@007`0O01l00Ioo`03O01oogoo03Ioo`03O01o
ogoo00Moo`9l019oo`03000a4S4B00@a4P03001Ade7C00=Ad`05000d[SB^=:h00006FO<00`00K[E^
]@04K[D2000HOol00`00<A800005<A800`00DOEAm@09DOD00`00HYMRU`08HYL00`00MeMgE`03MeL0
0`00Oomoo`0OOol00`00Oomoo`0:Ool000]oo`03001oogoo00Moo`9l01Eoo`04001l07`0O005Ool2
O00hOol2O008Ool2O00BOol20005<A800`00DM=Ad`03DM<01000=:hd[P001eWc00<006jeK[D00fje
0`005goo0P000S4B00<0034B<A800S4B00<0057eDOD0257e00<006:GHYL02F:G00<007MGMeL00gMG
00<007ooOol07goo00<007ooOol02Woo000;Ool00`00Oomoo`07Ool2O00EOol00`00O01l0005Ool2
O00jOol00g`0Oomoo`06Ool3O00AOol20005<A800`00DM=Ad`02DM<01@00=:hd[SB^00001UWc00<0
06jeK[D016je00<007Ja00005goo00<0034B<A800S4B0P000S4B00<0057eDOD0257e00<006:GHYL0
26:G00<007MGMeL00gMG00<007ooOol087oo00<007ooOol02Woo000;Ool00`00Oomoo`07Ool2O00E
Ool00`00O01oo`05Ool00g`0Oomoo`0iOol2O008Ool2O00AOol20005<A800`00DM=Ad`02DM<01@00
=:hd[SB^00001UWc00<006jeK[D00fje0P0000=f/@00Ool05Goo00<0034B<A801C4B0P002e7e00<0
06:GHYL026:G00<007MGMeL00gMG00<007ooOol087oo00<007ooOol02Woo000;Ool00`00Oomoo`07
Ool2O00EOol00`00O01oo`04Ool2O00lOol2O007Ool3O00@Ool20005<A801@00DM=Ade7C00000cB^
00<005WcFO<015Wc00<006jeK[D016je00@007JaM[4001Eoo`8000Pa4P03001AmE7e00QAm@03001R
Uf:G00URU`03001gEgMG00=gE`03001oogoo021oo`03001oogoo00Yoo`002goo00<007ooOol01goo
0W`057oo00=l0000O00017oo0W`0?Woo00=l07ooOol01Woo0W`04Goo00<0034B<A800c4B00D0057C
DM=Ad`0000<d[P03001IleWc00AIl`03001^]Fje00=^]@80009f/@03001oogoo019oo`8000Pa4P04
001>5`000008DOD00`00HYMRU`08HYL00`00MeMgE`04MeL00`00Oomoo`0POol00`00Oomoo`0:Ool0
00]oo`03001oogoo00Moo`9l01Aoo`03O00007`000Aoo`03O01oogoo03eoo`9l00Moo`9l015oo`03
000a4S4B00<a4P03001Ad`000080008d[P03001IleWc00AIl`03001^]Fje00A^]@<00003M[4007oo
01=oo`03000a4S4B00La4P04001>5dhGCQL20006DOD00`00HYMRU`08HYL00`00MeMgE`03MeL00`00
Oomoo`0QOol00`00Oomoo`0:Ool000]oo`03001oogoo00Moo`9l01=oo`9l0003001l07oo009oo`9l
041oo`03O01oogoo00Eoo`=l011oo`03000a4S4B00<a4P800003BG0003B^008d[P03001IleWc00AI
l`03001^]Fje00=^]@<00003KH80000001=oo`8000Pa4P03001>5dhG00A>5`8000AAm@03001RUf:G
00QRU`03001gEgMG00=gE`03001oogoo025oo`03001oogoo00Yoo`002goo00<007ooOol01goo0W`0
4Woo0W`000=oo`00O0000Woo0W`0@Goo0W`01goo0W`047oo00<0034B<A800S4B00D0034B0019L000
008d[P03001IleWc00EIl`03001^]Fje00=^]@<0009]PP03001oogoo011oo`8000Pa4P03001>5dhG
00M>5`800003DOD006:G00URU`03001gEgMG00AgE`03001oogoo025oo`03001oogoo00Yoo`002goo
00<007ooOol01goo0W`04Woo00El07ooOol007`0009oo`03O01oogoo045oo`03O01oogoo00Eoo`9l
011oo`05000a4S4B<A800002<A820003=:h00`00FO=Il`04FO<00`00K[E^]@04K[D01000GHaMS000
0Vf200<007ooOol03goo00<0034B<A801S4B00<004hGCQL02ThG0`002F:G00<007MGMeL00gMG00<0
07ooOol08Woo00<007ooOol02Woo000;Ool00`00Oomoo`07Ool2O00AOol2O002Ool00`00O01oo`02
O013Ool2O006Ool3O00?Ool01000<A8a4P00134B00@003B^=:h000MIl`03001^]Fje00=^]@80009M
S004001]PVf2000@Ool20008<A800`00CQM>5`0:CQL00`00F[YJ^P020007HYL00`00MeMgE`03MeL0
0`00Oomoo`0ROol00`00Oomoo`0:Ool000]oo`03001oogoo00Moo`9l015oo`05O01oogooOol00003
O015Ool2O006Ool2O00?Ool00`00<A800004<A801@00=:hd[SB^00001UWc00<006jeK[D016je0P00
0ef<0P0000=]PP00Ool03Goo0P00234B00<004hGCQL02dhG00<005ZjF[X00UZj0`0016:G00<007MG
MeL00gMG00<007ooOol08goo00<007ooOol02Goo000;Ool00`00Oomoo`07Ool2O00@Ool2O003Ool0
0`00O01l0017Ool00g`0Oomoo`04Ool3O00>Ool20005<A801@00=:hd[SB^00001UWc00<006jeK[D0
0fje0P0015f<00@006f2KH8000ioo`8000La4P03001>5dhG00]>5`03001J^UZj00IJ^P800003HYL0
07MG00EgE`03001oogoo02=oo`03001oogoo00Uoo`002goo00<007ooOol01goo0W`03goo0W`017oo
00<007`0O000Agoo0W`01Woo0W`03Woo00<0034B<A800c4B00D003B^=:hd[P0000IIl`03001^]Fje
00A^]@8000EMS004001]PVf2000;Ool30008<A800`00CQM>5`0:CQL00`00F[YJ^P09F[X40004MeLV
Ool00`00Oomoo`09Ool000]oo`03001oogoo00Moo`9l00moo`03O01oogoo00=oo`03001l07oo04Qo
o`03O01oogoo00Aoo`9l00ioo`8000@a4P05000d[SB^=:h00006FO<00`00K[E^]@03K[D20006GH`0
1000KH80D`002Goo1000234B00<004hGCQL02ThG00<005ZjF[X02UZj00@006^lJka[_0@002Ioo`03
001oogoo00Uoo`002goo00<007ooOol01goo0W`03Woo0W`017oo00=l0000O0000W`0Agoo0W`01Goo
0g`03Goo0P000c4B00D003B^=:hd[P0000IIl`03001^]Fje00A^]@8000=MS0H0000305<007oo00Eo
o`800004Akh<0P000007<A800`00CQM>5`0;CQL00`00F[YJ^P0:F[X00`00Jka[_003Jk`00`00Oomo
o`0UOol00`00Oomoo`09Ool000Yoo`03001oogoo00Qoo`9l00eoo`9l00Aoo`9l0003001l07`000=l
04Ioo`03O01oogoo00Aoo`9l00eoo`0300004P00008a4P05000d[SB^=:h00006FO<00`00K[E^]@03
K[D60006=0030003Ool2000330820007<A800`00CQM>5`0;CQL00`00F[YJ^P0:F[X00`00Jka[_004
Jk`00`00Oomoo`0UOol00`00Oomoo`09Ool000Yoo`03001oogoo00Qoo`9l00eoo`03O01oogoo009o
o`9l0004001oogooOol6O013Ool2O005Ool2O00=Ool00`0001800002<A801000=:hd[P001UWc00<0
06jeK[D016je0P0000<hR`0000000P000SDc1S@00`0000<<0TNn30800P`200<0034B<A801S4B00<0
04hGCQL02ThG00<005ZjF[X02UZj00<006^lJk`016^l00<007ooOol09Woo00<007ooOol02Goo000:
Ool00`00Oomoo`08Ool2O00<Ool2O003Ool3O0000`00Oomoo`03Ool7O011Ool2O004Ool3O00<Ool0
0`0001804P020003=:h00`00FO=Il`04FO<00`00K[E^]@04K[D20005>8/40003=002000230801000
308<0P`20P001c4B00<004hGCQL02dhG00<005ZjF[X02EZj00<006^lJk`016^l00<007ooOol09goo
00<007ooOol02Goo000:Ool00`00Oomoo`08Ool2O00<Ool017`0Oomoogoo0g`000=oo`00Ool01goo
1W`0@7oo00=l07ooOol00goo0W`037oo00<0000B01800P000SB^00<005WcFO<01EWc00<006jeK[D0
0fje0P002SR;0`000P`200<000`230800``200<0034B<A801C4B00<004hGCQL02dhG00<005ZjF[X0
2UZj00<006^lJk`00f^l00<007ooOol0:7oo00<007ooOol02Goo000:Ool00`00Oomoo`08Ool2O00;
Ool2O002Ool3O002Ool00`00Oomoo`09Ool6O00mOol2O004Ool3O00;Ool0100001804P000cB^00<0
05WcFO<015Wc00<006jeK[D016je0P002SR;00D000`2308<0P1C00@<0P<000La4P03001>5dhG00Y>
5`03001J^UZj00YJ^P03001[_6^l00A[_003001oogoo02Qoo`03001oogoo00Uoo`002Woo00<007oo
Ool027oo0W`02Woo0W`00Woo0g`00goo00<007ooOol02goo1W`0?7oo00=l07ooOol00goo0W`037oo
00<0000B00000cB^00<005WcFO<015Wc00<006jeK[D00fje0P002SR;00D000`23080001C00<<0P80
008a4P03000a4S4B00@a4P03001>5dhG00Y>5`03001J^UZj00YJ^P03001[_6^l00A[_003001oogoo
02Uoo`03001oogoo00Uoo`002Woo00<007ooOol027oo0W`02Woo00=l07ooOol00g`017oo00<007oo
Ool03Woo1W`0>Goo0W`017oo0W`037oo0P000cB^00<005WcFO<015Wc00<006jeK[D016je0P002SR;
00<000`2=C<00``20P001C4B00<0034B<A800S4B00<004hGCQL02dhG00<005ZjF[X02EZj00<006^l
Jk`016^l00<007ooOol0:Woo00<007ooOol02Goo000:Ool00`00Oomoo`08Ool2O009Ool2O00017oo
O01l07`01Goo00<007ooOol047oo1g`0=goo00=l07ooOol00Woo0g`037oo00D003B^=:hd[P0000II
l`03001^]Fje00=^]@03001c/@0000ThR`03000<0SDc008<0P8000La4P03000a4S4B008a4P03001>
5dhG00Y>5`03001J^UZj00YJ^P03001[_6^l00A[_003001oogoo02Yoo`03001oogoo00Uoo`002Woo
00<007ooOol027oo0W`027oo0W`000Aoog`0O01l00Ioo`03001oogoo01=oo`Il03Eoo`9l00Aoo`9l
00]oo`05000d[SB^=:h00006FO<00`00K[E^]@04K[D00`00Lk4hR`08>8/01000308e<``20P002C4B
00D0034B<A8a4P0000a>5`03001J^UZj00YJ^P03001[_6^l00A[_003001oogoo02]oo`03001oogoo
00Uoo`002Woo00<007ooOol027oo0W`027oo00=l07ooO0000W`01goo00<007ooOol05Woo1W`0<goo
0W`00goo0W`02goo00D003B^=:hd[P0000IIl`03001^]Fje00=^]@H000DhR`03000<0P`2008000/a
4P04000a4S4B000=CQL00`00F[YJ^P09F[X00`00Jka[_004Jk`00`00Oomoo`0/Ool00`00Oomoo`09
Ool000Yoo`03001oogoo00Qoo`9l00Moo`El00Qoo`03001oogoo01Qoo`Ml035oo`04O01oogooOol3
O009Ool01@00=:hd[SB^00001UWc00<006jeK[D016je00<007>a<A800c4B0`000SR;0`003S4B0P00
3DhG00<005ZjF[X02UZj00<006^lJk`016^l00<007ooOol0;7oo00<007ooOol02Goo000:Ool00`00
Oomoo`08Ool2O007Ool017`0Ooml07`02Goo00<007ooOol06goo1W`0;goo0W`00goo0W`02Goo00D0
03B^=:hd[P0000IIl`03001^]Fje00A^]@8000La4P<0010a4P8000a>5`03001J^UZj00YJ^P03001[
_6^l00A[_003001oogoo02eoo`03001oogoo00Uoo`002Woo00<007ooOol027oo0W`01Woo17`02Woo
00<007ooOol07Woo1W`0;Goo00Al07ooOomoo`=l00Qoo`04000d[SB^0006FO<00`00K[E^]@04K[D0
0`00Lk4a4P08<A800`00<A8a4P0?<A800`00CQM>5`0:CQL00`00F[YJ^P0:F[X00`00Jka[_004Jk`0
0`00Oomoo`0^Ool00`00Oomoo`09Ool000Yoo`03001oogoo00Qoo`9l00Eoo`El00Yoo`03001oogoo
021oo`Ml02Yoo`9l00=oo`9l00Moo`05000d[SB^=:h00006FO<00`00K[E^]@04K[D20009<A800`00
<A8a4P0=<A8200000d7h001>5`0:CQL00`00F[YJ^P09F[X00`00Jka[_004Jk`00`00Oomoo`0_Ool0
0`00Oomoo`09Ool000Yoo`03001oogoo00Qoo`9l00Eoo`Al00]oo`03001oogoo02=oo`Il02Uoo`04
O01oogooOol2O007Ool01@00=:hd[SB^00001UWc00<006jeK[D00fje00<007>a<A802C4B00<0034B
<A802c4B0P00147h00<004hGCQL01dhG00<005ZjF[X02UZj00<006^lJk`016^l00<007ooOol0<7oo
00<007ooOol027oo000:Ool00`00Oomoo`08Ool2O004Ool4O00<Ool00`00Oomoo`0VOol6O00VOol2
O002Ool3O005Ool01@00=:hd[SB^00001UWc00<006jeK[D016je0P002S4B00<0034B<A802C4B0P00
1T7h00<004hGCQL01ThG00<005ZjF[X02UZj00<006^lJk`016^l00<007ooOol0<Goo00<007ooOol0
27oo000:Ool00`00Oomoo`08Ool2O003Ool4O00=Ool00`00Oomoo`0XOol6O00UOol017`0Oomoogoo
0W`01Goo00D003B^=:hd[P0000IIl`03001^]Fje00=^]@03001c/C4B00Xa4P03000a4S4B00La4P80
00U1n003001>5dhG00E>5`03001J^UZj00UJ^P03001[_6^l00A[_003001oogoo039oo`03001oogoo
00Qoo`002Woo00<007ooOol027oo0W`00Woo17`03Woo00<007ooOol0:goo1W`08Woo0W`00Woo0W`0
17oo00D003B^=:hd[P0000IIl`03001^]Fje00A^]@8000Xa4P03000a4S4B00Ha4P8000a1n003001>
5dhG00=>5`03001J^UZj00YJ^P03001[_6^l00A[_003001oogoo039oo`03001oogoo00Qoo`002Woo
00<007ooOol027oo0W`000=oog`0O0000W`03goo00<007ooOol0;Goo1g`087oo0W`000Aoog`0O01l
00=oo`05000d[SB^=:h00006FO<00`00K[E^]@03K[D01000Lk4000002C4B00<0034B<A80134B0P00
3d7h00D004hGCQM>5`0000aJ^P03001[_6^l00A[_003001oogoo03=oo`03001oogoo00Qoo`002Woo
00<007ooOol027oo0W`000Aoog`0O01l011oo`03001oogoo031oo`Il01moo`03O01oogoo009l009o
o`05000d[SB^=:h00006FO<00`00K[E^]@04K[D2000012Eh000000001c4B00<0034B<A800S4B0P00
4D7h00@004hGCQL000aJ^P03001[_6^l00A[_003001oogoo03Aoo`03001oogoo00Qoo`002Woo00<0
07ooOol027oo1G`04Goo00<007ooOol0<goo1W`077oo0W`000Ioog`0O01l07oo0003=:h00`00FO=I
l`04FO<00`00K[E^]@04K[D200049GP30004<A800`00<A8a4P02000D@OP00`00CQL0000;F[X00`00
Jka[_005Jk`00`00Oomoo`0dOol00`00Oomoo`08Ool000Uoo`03001oogoo00Uoo`Al019oo`03001o
ogoo03Eoo`Ml01Yoo`03O01oogoo009l0005Ool003B^=:h00006FO<00`00K[E^]@04K[D200089GP3
0000134B000000005T7h0P0035Zj00<006^lJk`016^l00<007ooOol0=Goo00<007ooOol027oo0009
Ool00`00Oomoo`08Ool4O00COol00`00Oomoo`0hOol6O00HOol2O00017ooO01l00000cB^00<005Wc
FO<015Wc00<006jeK[D016je0P002bEh0P005T7h0P000T[M0P002EZj00<006^lJk`016^l00<007oo
Ool0=Woo00<007ooOol027oo0009Ool00`00Oomoo`08Ool;O00<Ool00`00Oomoo`0kOol6O00FOol5
O003=:h00`00FO=Il`04FO<00`00K[E^]@03K[D200039GP5GHd59GP00`00@OQ1n00B@OP20006B]d2
0006F[X00`00Jka[_004Jk`00`00Oomoo`0gOol00`00Oomoo`08Ool000Uoo`03001oogoo00QooaEl
009oo`03001oogoo03eoo`Ml01Aoo`04O01oog`0O002=:h00`00FO=Il`04FO<00`00K[E^]@04K[D2
00000ffT001MS@0;9GP00`00@OQ1n00?@OP2000:B]d20003F[X00`00Jka[_005Jk`00`00Oomoo`0g
Ool00`00Oomoo`08Ool000Uoo`03001oogoo01=oo`al0003001l07`000El03]oo`Il019oo`Al008d
[P03001IleWc00AIl`03001^]Fje00=^]@8000lUN0030011n47h00e1n08000i:g@800003F[X006^l
009[_0@003Yoo`03001oogoo00Qoo`002Goo00<007ooOol07Goo0W`000<007`0O0003g`0=7oo1W`0
47oo17`000<005WcFO<015Wc00<006jeK[D016je1@003BEh00<0047h@OP02D7h0`004D[M2000?7oo
00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`05OolDO00/Ool6O00>Ool01G`0=:il
03B^00001UWc00<006jeK[D00fje0P000Woo1P002BEh00<0047h@OP01d7h0P004T[M0P0014>M0P00
?Woo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0?OolCO00VOol6O00:Ool01@00
=:hd[SB^00001UWc00<006jeK[D016je0P0017oo0P000P6k0`001bEh00<0047h@OP0147h0P004T[M
0P000d>M0`00@7oo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0IOolCO00NOol7
O007Ool01@00=:hd[SB^00001UWc00<006jeK[D016je0P001Woo0P000`6k0`0012Eh00<0047h@OP0
0T7h0P004T[M0P000d>M0P00@goo00<007ooOol027oo0009Ool00`00Oomoo`0NOol00`00Oomoo`0S
OolDO00GOol6O004Ool01@00=:hd[SB^00000W`015Wc00<006jeK[D016je0P002Goo0P00106k1000
00<UN000@OP00P004T[M0P000d>M0P00AGoo00<007ooOol027oo0009Ool00`00Oomoo`0NOol00`00
Oomoo`0]OolDO00@Ool7O0060002O003FO<00`00K[E^]@04K[D2000;Ool300060K/2000BB]d20003
@id30016Ool00`00Oomoo`08Ool000Uoo`03001oogoo01ioo`03001oogoo03Mooa=l00Uoo`Ql00<^
OP<00003FO<006je00E^]@8000moo`8000D1^`03001:gD[M00e:g@<00093W@<0009oo`03001oogoo
04Eoo`03001oogoo00Moo`002Goo00<007ooOol07Woo00<007ooOol0@Goo4g`000=oog`0O0001W`0
12in0P001Vje0P004Goo0`000`6k00<004[MB]d02T[M0P000d>M0P001Goo00<007ooOol0AGoo00<0
07ooOol01goo0009Ool00`00Oomoo`0NOol00`00Oomoo`1:OolFO003;Wh00`00K[E^]@02K[D2000E
Ool200020K/20008B]d20003@id20007Ool00`00Oomoo`15Ool00`00Oomoo`07Ool000Uoo`03001o
ogoo01ioo`03001oogoo05Aoo`el00<^OP80009^]@8001Moo`<000030K/004[M00A:g@800003@id0
0000008000Uoo`03001oogoo04Eoo`03001oogoo00Moo`002Goo00<007ooOol07Woo00<007ooOol0
Fgoo00D002in;Wh^OW`000H^OP<001]oo`<0009:g@D000eoo`03001oogoo04Eoo`03001oogoo00Mo
o`002Goo00<007ooOol07Woo00<007ooOol0G7oo00<002in;Wh022in0P007Goo10004Goo00<007oo
Ool0AGoo00<007ooOol01goo0009Ool00`00Oomoo`0NOol00`00Oomoo`1NOol30006;Wh00`00Oomo
o`0aOol00`00Oomoo`15Ool00`00Oomoo`07Ool000Uoo`03001oogoo01ioo`03001oogoo065oo`L0
03=oo`03001oogoo04Eoo`03001oogoo00Moo`002Goo00<007ooOol07Woo00<007ooOol0Vgoo00<0
07ooOol0AGoo00<007ooOol01goo0009Ool00`00Oomoo`0NOol00`00Oomoo`2KOol00`00Oomoo`15
Ool00`00Oomoo`07Ool000Qoo`03001oogoo01moo`03001oogoo09]oo`03001oogoo04Eoo`03001o
ogoo00Moo`0027oo00<007ooOol07goo00<007ooOol0Vgoo00<007ooOol0AGoo00<007ooOol01goo
0008Ool00`00Oomoo`0OOol8002FOol00`00Oomoo`15Ool00`00Oomoo`07Ool000Qoo`03001oogoo
01ioo`03001oogoo00Ioo`h008Qoo`03001oogoo04Eoo`03001oogoo00Moo`0027oo00<007ooOol0
7Goo00<007ooOol05Goo3`00NGoo00<007ooOol0AGoo00<007ooOol01goo0008Ool00`00Oomoo`0K
Ool2000WOol>001[Ool00`00Oomoo`15Ool00`00Oomoo`07Ool000Qoo`03001oogoo01Yoo`03001o
ogoo03Eoo`h005eoo`03001oogoo04Eoo`03001oogoo00Moo`0027oo00<007ooOol06Goo00<007oo
Ool0A7oo3`00CWoo00<007ooOol0AGoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00`00Oomo
o`1DOol>0010Ool00`00Oomoo`15Ool00`00Oomoo`07Ool000Qoo`03001oogoo01Moo`03001oogoo
06=oo`l0035oo`03001oogoo04Ioo`03001oogoo00Ioo`0027oo00<007ooOol05Woo00<007ooOol0
Lgoo3P008goo00<007ooOol0AWoo00<007ooOol01Woo0008Ool00`00Oomoo`0DOol20024Ool?000D
Ool00`00Oomoo`16Ool00`00Oomoo`06Ool000Qoo`03001oogoo01=oo`03001oogoo09=oo`h000Io
o`03001oogoo04Ioo`03001oogoo00Ioo`0027oo00<007ooOol04Woo00<007ooOol0XWoo3`00@7oo
00<007ooOol01Woo0008Ool00`00Oomoo`0AOol00`00Oomoo`2YOol00`00Oomoo`06Ool>000bOol0
0`00Oomoo`06Ool000Qoo`03001oogoo011oo`03001oogoo0:Yoo`03001oogoo01Aoo`h002Aoo`03
001oogoo00Ioo`0027oo00<007ooOol03goo00<007ooOol0Zgoo00<007ooOol08Woo3`005Goo00<0
07ooOol01Woo0008Ool00`00Oomoo`0=Ool2002^Ool00`00Oomoo`0aOol>0007Ool00`00Oomoo`06
Ool000Qoo`03001oogoo00aoo`03001oogoo0:ioo`03001oogoo03moo`P000Qoo`0027oo00<007oo
Ool02goo00<007ooOol0[goo00<007ooOol0@Woo0`002Woo0008Ool00`00Oomoo`0:Ool00`00Oomo
o`2`Ool00`00Oomoo`0oOol3000=Ool000Qoo`03001oogoo00Uoo`03001oogoo0;5oo`03001oogoo
03aoo`<0011oo`001goo00<007ooOol02Goo00<007ooOol0/Woo00<007ooOol0>Goo0`004goo0007
Ool00`00Oomoo`07Ool2002fOol00`00Oomoo`0eOol3000FOol000Moo`03001oogoo00Ioo`03001o
ogoo0;Ioo`03001oogoo039oo`<001Uoo`001goo00<007ooOol01Goo00<007ooOol0]goo00<007oo
Ool0;goo0`0077oo0007Ool00`00Oomoo`04Ool00`00Oomoo`2hOol00`00Oomoo`0/Ool3000OOol0
00Moo`03001oogoo00=oo`03001oogoo0;Uoo`03001oogoo02Uoo`<0029oo`001goo00<007ooOol0
0Woo00<007ooOol0^Woo00<007ooOol09Woo0`009Goo0007Ool00`00Oomoo`02002mOol00`00Oomo
o`0SOol3000XOol000Moo`03001oo`000;moo`03001oogoo021oo`<002]oo`001goo0P00`7oo00<0
07ooOol07Goo0`00;Woo0007Ool:002hOol00`00Oomoo`0JOol3000aOol0015ooa@00:Aoo`03001o
ogoo01Moo`<003Aoo`009Goo4`00TGoo00<007ooOol057oo0`00=goo000hOolC001nOol00`00Oomo
o`0AOol3000jOol004]ooa@006Yoo`03001oogoo00ioo`<003eoo`00Ggoo4`00Egoo00<007ooOol0
2goo0`00@7oo001bOolD0013Ool00`00Oomoo`08Ool30013Ool008Iooa<0031oo`03001oogoo00Eo
o`<004Ioo`00VGoo4`007Goo00<007ooOol00Woo0`00BGoo002/OolD0009Ool00`00Ool00002001<
Ool00<1oo`/004moo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {260, 0}} -> {0.0234122, -0.0101519, 
  0.00356645, 0.00356645}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three body objects are defined for the MacPherson strut front suspension \
model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ground body (body 1) requires four point definitions.\nP1 is the \
origin of the ground body.\nP2 is a point directly above P1 that is used in \
conjunction with P1 to define a vertical translation axis for the chassis.\n\
P3 is a point on the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis that is used with P1 to define a longitudinal axis that references \
the rotational orientation of the chassis.\nP4 is a point on the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axis that is used with P1 and P3 to define the horizontal plane of the \
ground upon which the tire rests."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The chassis (body 2) requires seven local point definitions.\nP1 is the \
origin of the chassis. This point lies at the center of the bottom of the \
chassis.\nP2 is used in conjunction with P1 to define the vertical \
translation line of the chassis.\nP3 is used with P1 to define a transverse \
axis on the chassis that is used to reference the rotational orientation of \
the chassis.\nP4 and P5 are the two attachment points of the lower A-arm.\nP6 \
is the upper mounting point of the MacPherson strut.\nP7 is the attachment \
point of the steering tie rod. This point has a symbolic definition so that \
it can be moved in a transverse direction to steer the car."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The wheel carrier (body 3) requires five local point definitions.\nP1 is the \
local origin, which is the attachment point of the lower A-arm.\nP2 is used \
with P1 to define the axis of the MacPherson strut on the carrier.\nP3 is the \
center of the tire.\nP4 is used with P3 to define the axis of the tire.\nP5 \
is the attachment point of the steering tie rod on the wheel carrier."], 
  "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names for each of the body numbers in the model are defined. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(chassis = 2; \)\), 
    \(\(carrier = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the three body objects used in the MacPherson strut model."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
bd[ground] = Body[ground, PointList->
  {(*P1*) {0,0,0},
   (*P2*) {0,0,1},
   (*P3*) {1,0,0},
   (*P4*) {0,1,0}}];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
bd[chassis] = Body[chassis, PointList->
  {(*P1*) { 0  , 0  , 0  },
   (*P2*) { 0  , 0  , 1  },
   (*P3*) { 0  , 1  , 0  },
   (*P4*) { 4. , 7.5, 5.5},
   (*P5*) {-4. , 7.5, 4.5},
   (*P6*) { 0  ,15.0,20.0},
   (*P7*) {-6  , 9. , 8.0}},
  InitialGuess->{{0, 0, 2.5},{1, 0, 0, 0}}];\
\>", "Input",
  AspectRatioFixed->True],

Cell["\<\
bd[carrier] = Body[carrier, PointList->
  {(*P1*) { 0  , 0   ,0  },
   (*P2*) { 0  ,-2.2 ,6.0},
   (*P3*) { 0  , 1.25,4.5},
   (*P4*) { 0  ,-0.5 ,4.5},
   (*P5*) {-6  ,-2   ,4  }},
  InitialGuess->{{0, 22., 5.0},{1, 0, 0, 0}}];\
\>", "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The body objects are incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[chassis], bd[carrier]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Eight constraints, including a driving constraint that is explicitly \
dependent on the time variable, are required to model the MacPherson strut \
front suspension."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces a vertical axis on the ground to be coincident with a \
vertical axis on the chassis, effectively allowing the chassis to slide up \
and down on a post."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An ",
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces a longitudinal line on the ground to be orthogonal to a \
transverse line on the chassis. This constraint prevents the chassis from \
rotating about the vertical axis of rotation allowed by constraint 1."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeZ1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the vertical position of the chassis. This constraint \
is a function of the time variable ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so it is the driving constraint."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the front of the lower A-arm."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the back of the lower A-arm."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of the MacPherson strut to pass through its \
upper mounting point on the chassis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PlaneToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the bottom of the tire to remain in contact with the \
ground. ",
  StyleBox["PlaneToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " places the surface of a torus (or a circle) in contact with a plane."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the steering tie rod."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the eight constraint objects for the MacPherson strut model."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(cs[1] = Cylindrical4[1, \n\t\tLine[ground, 1, 2], Line[chassis, 1, 2]]; 
    \n\(cs[2] = 
      Orthogonal1[2, \n\t\tLine[ground, 1, 3], Line[chassis, 1, 3]]; \n
    \(cs[3] = RelativeZ1[3, Point[chassis, 1], T]; \)\)\), 
    \(\(cs[4] = 
      RelativeDistance1[4, Point[chassis, 4], Point[carrier, 1], 15.0]; \)\), 
  
    \(\(cs[5] = 
      RelativeDistance1[5, Point[chassis, 5], Point[carrier, 1], 15.0]; \)\), 
  
    \(cs[6] = PointOnLine2[6, \n\t\tPoint[chassis, 6], Line[carrier, 1, 2]]; 
    \n\(cs[7] = 
      PlaneToCircle1[7, Plane[ground, 1, 3, 4], Line[carrier, 3, 4], 7.5, 
        2.5]; \)\), 
    \(\(cs[8] = 
      RelativeDistance1[8, Point[chassis, 7], Point[carrier, 5], 11]; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The constraints are incorporated into the current model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 8]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Note that the explicit symbol used to represent time in ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default) may be changed. The ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a nested list of strings that determines the basis for all of the \
symbols created by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the ",
  StyleBox["Global`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context. Changing the first element of ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " changes the symbol that is recognized as the time variable. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the basis for ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatic symbols. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[SymbolBasis /. Options[SetSymbols]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    TagBox[
      StyleBox[
        \(List["\<T\>", List["\<X\>", "\<Y\>", "\<Z\>"], 
          List["\<Eo\>", "\<Ei\>", "\<Ej\>", "\<Ek\>"], 
          List["\<Wx\>", "\<Wy\>", "\<Wz\>"], "\<Lmb\>", "\<d\>"]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True],
      FullForm]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because of the presence of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the driving constraint (constraint 3) the model can be run through its \
intended range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the first argument to the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The way that this model is defined, the numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the distance between the chassis and the ground."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.5] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 2.5`\), ",", \(Eo2 \[Rule] 1.`\), 
        ",", \(Ei2 \[Rule] 0\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 0.254625171239336278`\), ",", 
        \(Y3 \[Rule] 21.8016010097176637`\), ",", 
        \(Z3 \[Rule] 5.46299863008530728`\), ",", 
        \(Eo3 \[Rule] 0.999669793128668082`\), ",", 
        \(Ei3 \[Rule] 0.0143329932622434474`\), ",", 
        \(Ej3 \[Rule] 0.000731365473970143042`\), ",", 
        \(Ek3 \[Rule] \(-0.0213151381818196128`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the MacPherson strut front suspension image at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .92634  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.0239737 0.998999 0.0101371 0.998999 [ 
[ 0 0 0 0 ] 
[ 1 .92634 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 .92634 L 
0 .92634 L 
closepath 
clip 
newpath 
p 
.002 w 
.05539 .25301 m 
.02497 .86356 L 
s 
.02497 .86356 m 
.71776 .90137 L 
s 
.71776 .90137 m 
.7027 .33665 L 
s 
.7027 .33665 m 
.05539 .25301 L 
s 
.17583 .02497 m 
.93792 .14641 L 
s 
.93792 .14641 m 
.97503 .81474 L 
s 
.97503 .81474 m 
.14905 .75824 L 
s 
.14905 .75824 m 
.17583 .02497 L 
s 
.05539 .25301 m 
.02497 .86356 L 
s 
.02497 .86356 m 
.14905 .75824 L 
s 
.14905 .75824 m 
.17583 .02497 L 
s 
.17583 .02497 m 
.05539 .25301 L 
s 
.7027 .33665 m 
.93792 .14641 L 
s 
.93792 .14641 m 
.97503 .81474 L 
s 
.97503 .81474 m 
.71776 .90137 L 
s 
.71776 .90137 m 
.7027 .33665 L 
s 
P 
p 
.002 w 
.89281 .16303 m .66319 .352 L .62115 .34668 L p 
.584 .802 .983 r 
F P 
s 
P 
p 
.002 w 
.62115 .34668 m .07772 .27793 L p 
.26055 .06432 L .584 .802 .983 r 
F P 
s 
P 
p 
.002 w 
.26055 .06432 m .89281 .16303 L p 
.62115 .34668 L .584 .802 .983 r 
F P 
s 
P 
p 
.002 w 
.6449 .32357 m .61481 .43026 L .58619 .42843 L p 
.802 .752 .807 r 
F P 
s 
P 
p 
.002 w 
.67886 .33514 m .64957 .43657 L .61481 .43026 L p 
.681 .624 .785 r 
F P 
s 
P 
p 
.002 w 
.61481 .43026 m .6449 .32357 L .67886 .33514 L p 
.681 .624 .785 r 
F P 
s 
P 
p 
.002 w 
.61481 .43026 m .60307 .54777 L .57486 .54114 L p 
.82 .671 .699 r 
F P 
s 
P 
p 
.002 w 
.57486 .54114 m .58619 .42843 L .61481 .43026 L p 
.82 .671 .699 r 
F P 
s 
P 
p 
.002 w 
.60307 .54777 m .61481 .43026 L .64957 .43657 L p 
.703 .566 .697 r 
F P 
s 
P 
p 
.002 w 
.70397 .3566 m .67791 .44508 L .64957 .43657 L p 
.541 .479 .735 r 
F P 
s 
P 
p 
.002 w 
.64957 .43657 m .67886 .33514 L .70397 .3566 L p 
.541 .479 .735 r 
F P 
s 
P 
p 
.002 w 
.63847 .54851 m .64957 .43657 L .67791 .44508 L p 
.565 .443 .672 r 
F P 
s 
P 
p 
.002 w 
.64957 .43657 m .63847 .54851 L .60307 .54777 L p 
.703 .566 .697 r 
F P 
s 
P 
p 
.002 w 
.60307 .54777 m .61225 .65165 L .58301 .64053 L p 
.83 .578 .558 r 
F P 
s 
P 
p 
.002 w 
.58301 .64053 m .57486 .54114 L .60307 .54777 L p 
.83 .578 .558 r 
F P 
s 
P 
p 
.002 w 
.61225 .65165 m .60307 .54777 L .63847 .54851 L p 
.696 .478 .587 r 
F P 
s 
P 
p 
.002 w 
.67791 .44508 m .66824 .54311 L .63847 .54851 L p 
.565 .443 .672 r 
F P 
s 
P 
p 
.002 w 
.64802 .64737 m .63847 .54851 L .66824 .54311 L p 
.545 .367 .59 r 
F P 
s 
P 
p 
.002 w 
.63847 .54851 m .64802 .64737 L .61225 .65165 L p 
.696 .478 .587 r 
F P 
s 
P 
p 
.002 w 
.58619 .42843 m .61449 .32613 L .6449 .32357 L p 
.802 .752 .807 r 
F P 
s 
P 
p 
.002 w 
.61449 .32613 m .58619 .42843 L .57439 .43184 L p 
.96 .938 .71 r 
F P 
s 
P 
p 
.002 w 
.58619 .42843 m .57486 .54114 L .56441 .53096 L p 
.989 .836 .599 r 
F P 
s 
P 
p 
.002 w 
.56441 .53096 m .57439 .43184 L .58619 .42843 L p 
.989 .836 .599 r 
F P 
s 
P 
p 
.002 w 
.71076 .38012 m .6892 .45269 L .67791 .44508 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.67791 .44508 m .70397 .3566 L .71076 .38012 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.66824 .54311 m .67791 .44508 L .6892 .45269 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.57486 .54114 m .58301 .64053 L .57134 .61792 L p 
.985 .708 .361 r 
F P 
s 
P 
p 
.002 w 
.57134 .61792 m .56441 .53096 L .57486 .54114 L p 
.985 .708 .361 r 
F P 
s 
P 
p 
.002 w 
.6892 .45269 m .68126 .53342 L .66824 .54311 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.67718 .6293 m .66824 .54311 L .68126 .53342 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.66824 .54311 m .67718 .6293 L .64802 .64737 L p 
.545 .367 .59 r 
F P 
s 
P 
p 
.002 w 
.74124 .2983 m .70397 .3566 L .67886 .33514 L p 
.457 .47 .784 r 
F P 
s 
P 
p 
.002 w 
.67886 .33514 m .72081 .26734 L .74124 .2983 L p 
.457 .47 .784 r 
F P 
s 
P 
p 
.002 w 
.72081 .26734 m .67886 .33514 L .6449 .32357 L p 
.607 .668 .882 r 
F P 
s 
P 
p 
.002 w 
.68775 .25175 m .6449 .32357 L .61449 .32613 L p 
.747 .859 .931 r 
F P 
s 
P 
p 
.002 w 
.6449 .32357 m .68775 .25175 L .72081 .26734 L p 
.607 .668 .882 r 
F P 
s 
P 
p 
.002 w 
.57439 .43184 m .59903 .34211 L .61449 .32613 L p 
.96 .938 .71 r 
F P 
s 
P 
p 
.002 w 
.59903 .34211 m .57439 .43184 L .58447 .43937 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.57439 .43184 m .56441 .53096 L .57626 .52101 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.57626 .52101 m .58447 .43937 L .57439 .43184 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.69616 .39681 m .67855 .45646 L .6892 .45269 L p 
.957 .948 .686 r 
F P 
s 
P 
p 
.002 w 
.6892 .45269 m .71076 .38012 L .69616 .39681 L p 
.957 .948 .686 r 
F P 
s 
P 
p 
.002 w 
.68126 .53342 m .6892 .45269 L .67855 .45646 L p 
.996 .844 .573 r 
F P 
s 
P 
p 
.002 w 
.56441 .53096 m .57134 .61792 L .58215 .59219 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.58215 .59219 m .57626 .52101 L .56441 .53096 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.67855 .45646 m .67199 .52301 L .68126 .53342 L p 
.996 .844 .573 r 
F P 
s 
P 
p 
.002 w 
.68126 .53342 m .68881 .60397 L .67718 .6293 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.68881 .60397 m .68126 .53342 L .67199 .52301 L p 
.976 .692 .3 r 
F P 
s 
P 
p 
.002 w 
.74137 .33312 m .71076 .38012 L .70397 .3566 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.70397 .3566 m .74124 .2983 L .74137 .33312 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.67741 .70986 m .64802 .64737 L .67718 .6293 L p 
.454 .213 .458 r 
F P 
s 
P 
p 
.002 w 
.64802 .64737 m .67741 .70986 L .64174 .71763 L p 
.629 .289 .376 r 
F P 
s 
P 
p 
.002 w 
.64174 .71763 m .61225 .65165 L .64802 .64737 L p 
.629 .289 .376 r 
F P 
s 
P 
p 
.002 w 
.61449 .32613 m .65439 .25749 L .68775 .25175 L p 
.747 .859 .931 r 
F P 
s 
P 
p 
.002 w 
.65439 .25749 m .61449 .32613 L .59903 .34211 L p 
.776 .959 .647 r 
F P 
s 
P 
p 
.002 w 
.61225 .65165 m .64174 .71763 L .61007 .70322 L p 
.794 .363 .224 r 
F P 
s 
P 
p 
.002 w 
.61007 .70322 m .58301 .64053 L .61225 .65165 L p 
.794 .363 .224 r 
F P 
s 
P 
p 
.002 w 
.7037 .68297 m .67718 .6293 L .68881 .60397 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.67718 .6293 m .7037 .68297 L .67741 .70986 L p 
.454 .213 .458 r 
F P 
s 
P 
p 
.002 w 
.07772 .27793 m .20292 .05532 L .26055 .06432 L p 
.584 .802 .983 r 
F P 
s 
P 
p 
.002 w 
.58301 .64053 m .61007 .70322 L .59455 .67185 L p 
.706 .327 0 r 
F P 
s 
P 
p 
.002 w 
.59455 .67185 m .57134 .61792 L .58301 .64053 L p 
.706 .327 0 r 
F P 
s 
P 
p 
.002 w 
.58447 .43937 m .60485 .36577 L .59903 .34211 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.60485 .36577 m .58447 .43937 L .6132 .44818 L p 
.532 .473 .735 r 
F P 
s 
P 
p 
.002 w 
.58447 .43937 m .57626 .52101 L .60651 .5152 L p 
.558 .436 .67 r 
F P 
s 
P 
p 
.002 w 
.60651 .5152 m .6132 .44818 L .58447 .43937 L p 
.558 .436 .67 r 
F P 
s 
P 
p 
.002 w 
.66531 .39993 m .64942 .45477 L .67855 .45646 L p 
.806 .761 .811 r 
F P 
s 
P 
p 
.002 w 
.67855 .45646 m .69616 .39681 L .66531 .39993 L p 
.806 .761 .811 r 
F P 
s 
P 
p 
.002 w 
.67855 .45646 m .64942 .45477 L p 
.66804 .51107 L .825 .675 .698 r 
F P 
s 
P 
p 
.002 w 
.67306 .51215 m .67855 .45646 L p 
.66804 .51107 L .825 .675 .698 r 
F P 
s 
P 
p 
.002 w 
.64942 .45477 m .64335 .51597 L .67199 .52301 L p 
.825 .675 .698 r 
F P 
s 
P 
p 
.002 w 
.6132 .44818 m .60651 .5152 L .64335 .51597 L p 
.703 .565 .696 r 
F P 
s 
P 
p 
.002 w 
.64335 .51597 m .64942 .45477 L .6132 .44818 L p 
.703 .565 .696 r 
F P 
s 
P 
p 
.002 w 
.6132 .44818 m .63021 .388 L .60485 .36577 L p 
.532 .473 .735 r 
F P 
s 
P 
p 
.002 w 
.63021 .388 m .6132 .44818 L .64942 .45477 L p 
.68 .626 .788 r 
F P 
s 
P 
p 
.002 w 
.64942 .45477 m .66531 .39993 L .63021 .388 L p 
.68 .626 .788 r 
F P 
s 
P 
p 
.002 w 
.68743 .365 m .66531 .39993 L .69616 .39681 L p 
.743 .874 .94 r 
F P 
s 
P 
p 
.002 w 
.65376 .34939 m .63021 .388 L .66531 .39993 L p 
.599 .671 .891 r 
F P 
s 
P 
p 
.002 w 
.66531 .39993 m .68743 .365 L .65376 .34939 L p 
.599 .671 .891 r 
F P 
s 
P 
p 
.002 w 
.68711 .48144 m .66939 .48444 L p 
.65988 .38525 L .51 .418 .687 r 
F P 
s 
P 
p 
.65987 .38517 m .6599 .38526 L .65988 .38525 L .51 .418 .687 r 
F 
P 
p 
.6599 .38526 m .68711 .48144 L .65988 .38525 L .51 .418 .687 r 
F 
P 
p 
.002 w 
.66223 .38623 m .68711 .48144 L p 
.65987 .38517 L .51 .418 .687 r 
F P 
s 
P 
p 
.002 w 
.65688 .37717 m .65987 .38517 L p 
.65951 .38501 L .614 .234 .299 r 
F P 
s 
P 
p 
.65845 .38453 m .65299 .37759 L .65951 .38501 L .614 .234 .299 r 
F 
P 
p 
.64847 .37807 m .65299 .37759 L .65845 .38453 L .614 .234 .299 r 
F 
P 
p 
.65299 .37759 m .65688 .37717 L .65951 .38501 L .614 .234 .299 r 
F 
P 
p 
.002 w 
.65987 .38517 m .65688 .37717 L p 
.65867 .3726 L 0 0 .391 r 
F P 
s 
P 
p 
.002 w 
.66939 .48444 m .6566 .48661 L p 
.65867 .3726 L .51 .418 .687 r 
F P 
s 
P 
p 
.002 w 
.65688 .37717 m .65692 .35875 L p 
.65732 .35967 L 0 0 .391 r 
F P 
s 
P 
p 
.65867 .3726 m .65732 .35967 L .66771 .36779 L .427 .349 .666 r 
F 
P 
p 
.002 w 
.65732 .35966 m .6574 .35972 L p 
.65732 .35967 L .427 .349 .666 r 
F P 
s 
P 
p 
.002 w 
.6574 .35972 m .66771 .36779 L p 
.65732 .35967 L .427 .349 .666 r 
F P 
s 
P 
p 
.002 w 
.6582 .3681 m .66047 .36797 L p 
.65867 .3726 L 0 0 .391 r 
F P 
s 
P 
p 
.65688 .37717 m .65732 .35967 L .65867 .3726 L 0 0 .391 r 
F 
P 
p 
.002 w 
.65692 .35875 m .65692 .35861 L .6573 .3596 L p 
0 0 .391 r 
F P 
s 
P 
p 
.002 w 
.6573 .3596 m .65732 .35967 L p 
.65692 .35875 L 0 0 .391 r 
F P 
s 
P 
p 
.002 w 
.65692 .35861 m .65688 .37717 L .64431 .37818 L p 
.722 .679 .808 r 
F P 
s 
P 
p 
.002 w 
.59903 .34211 m .63341 .28265 L .65439 .25749 L p 
.776 .959 .647 r 
F P 
s 
P 
p 
.002 w 
.63341 .28265 m .59903 .34211 L .60485 .36577 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.60485 .36577 m .63307 .31782 L .63341 .28265 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.63307 .31782 m .60485 .36577 L .63021 .388 L p 
.438 .461 .786 r 
F P 
s 
P 
p 
.002 w 
.63021 .388 m .65376 .34939 L .63307 .31782 L p 
.438 .461 .786 r 
F P 
s 
P 
p 
.002 w 
.64431 .37818 m .28989 .40655 L p 
.65457 .35891 L .722 .679 .808 r 
F P 
s 
P 
p 
.65457 .35891 m .65692 .35861 L .64431 .37818 L .722 .679 .808 r 
F 
P 
p 
.002 w 
.29093 .41632 m .28989 .40655 L .64431 .37818 L p 
.614 .234 .299 r 
F P 
s 
P 
p 
.002 w 
.64431 .37818 m .65688 .37717 L p 
.64492 .37845 L .614 .234 .299 r 
F P 
s 
P 
p 
.29093 .41632 m .64431 .37818 L .64492 .37845 L .614 .234 .299 r 
F 
P 
p 
.002 w 
.6566 .48661 m .57967 .49965 L p 
.65282 .382 L .51 .418 .687 r 
F P 
s 
P 
p 
.65845 .38453 m .6566 .48661 L .65282 .382 L .51 .418 .687 r 
F 
P 
p 
.002 w 
.65845 .38432 m .6497 .37736 L p 
.65846 .38416 L .427 .349 .666 r 
F P 
s 
P 
p 
.6497 .37736 m .65867 .3726 L .65375 .38051 L .427 .349 .666 r 
F 
P 
p 
.64492 .37845 m .64847 .37807 L .65845 .38453 L .614 .234 .299 r 
F 
P 
p 
.002 w 
.6497 .37736 m .65845 .38432 L p 
.64782 .37735 L .688 .222 .141 r 
F P 
s 
P 
p 
.002 w 
.61811 .42742 m .65276 .38059 L p 
.57967 .49965 L .51 .418 .687 r 
F P 
s 
P 
p 
.002 w 
.65276 .38059 m .65867 .3726 L p 
.65343 .38102 L .51 .418 .687 r 
F P 
s 
P 
p 
.65343 .38102 m .57967 .49965 L .65276 .38059 L .51 .418 .687 r 
F 
P 
p 
.64492 .37845 m .65845 .38453 L .66042 .38663 L .614 .234 .299 r 
F 
P 
p 
.002 w 
.65987 .38517 m .66001 .38554 L p 
.65845 .38453 L .614 .234 .299 r 
F P 
s 
P 
p 
.65867 .3726 m .65845 .38453 L .65282 .382 L .51 .418 .687 r 
F 
P 
p 
.002 w 
.65845 .38432 m .65993 .38549 L p 
.64782 .37735 L .688 .222 .141 r 
F P 
s 
P 
p 
.66027 .38588 m .66004 .38561 L .66134 .38661 L .688 .222 .141 r 
F 
P 
p 
.002 w 
.66001 .38556 m .66134 .38661 L p 
.66004 .38561 L .688 .222 .141 r 
F P 
s 
P 
p 
.002 w 
.66042 .38663 m .66004 .38561 L p 
.66041 .38648 L 0 0 .391 r 
F P 
s 
P 
p 
.002 w 
.65993 .38549 m .65845 .38432 L p 
.66 .38543 L .427 .349 .666 r 
F P 
s 
P 
p 
.66 .38543 m .6614 .38644 L .66001 .38554 L .427 .349 .666 r 
F 
P 
p 
.66 .38543 m .66001 .38554 L .65993 .38549 L .427 .349 .666 r 
F 
P 
p 
.65846 .38416 m .65999 .38535 L .65845 .38432 L .427 .349 .666 r 
F 
P 
p 
.65999 .38535 m .6614 .38644 L .66 .38543 L .427 .349 .666 r 
F 
P 
p 
.002 w 
.66001 .38554 m .65987 .38517 L p 
.66001 .38549 L 0 0 .391 r 
F P 
s 
P 
p 
.65999 .38535 m .66 .38543 L .65845 .38432 L .427 .349 .666 r 
F 
P 
p 
.002 w 
.65867 .3726 m .66223 .38623 L p 
.65987 .38517 L .51 .418 .687 r 
F P 
s 
P 
p 
.002 w 
.65867 .3726 m .6622 .38611 L p 
.6614 .38642 L .767 .575 .639 r 
F P 
s 
P 
p 
.002 w 
.6614 .38644 m .66134 .38661 L .65993 .38549 L p 
.427 .349 .666 r 
F P 
s 
P 
p 
.002 w 
.66134 .38661 m .6614 .38642 L p 
.66101 .38658 L .819 .775 .811 r 
F P 
s 
P 
p 
.65987 .38517 m .6599 .38445 L .66001 .38549 L 0 0 .391 r 
F 
P 
p 
.65999 .38535 m .66031 .38089 L .6614 .38644 L .427 .349 .666 r 
F 
P 
p 
.65867 .3726 m .6599 .38445 L .65987 .38517 L 0 0 .391 r 
F 
P 
p 
.65846 .38416 m .65965 .38205 L .65999 .38535 L .427 .349 .666 r 
F 
P 
p 
.65965 .38205 m .66031 .38089 L .65999 .38535 L .427 .349 .666 r 
F 
P 
p 
.002 w 
.6614 .38642 m .6614 .38644 L p 
.66031 .38089 L .427 .349 .666 r 
F P 
s 
P 
p 
.65867 .3726 m .66771 .36779 L .65846 .38416 L .427 .349 .666 r 
F 
P 
p 
.002 w 
.66134 .38661 m .66096 .3866 L p 
.66027 .38588 L .688 .222 .141 r 
F P 
s 
P 
p 
.66146 .3867 m .68001 .48056 L .66048 .38679 L .767 .575 .639 r 
F 
P 
p 
.66096 .3866 m .66048 .38679 L .66041 .38648 L .767 .575 .639 r 
F 
P 
p 
.66146 .3867 m .66048 .38679 L .66096 .3866 L .767 .575 .639 r 
F 
P 
p 
.002 w 
.68001 .48056 m .67214 .47959 L p 
.66042 .3865 L .767 .575 .639 r 
F P 
s 
P 
p 
.66041 .38648 m .66042 .38651 L .66042 .3865 L .767 .575 .639 r 
F 
P 
p 
.66042 .38651 m .68001 .48056 L .66042 .3865 L .767 .575 .639 r 
F 
P 
p 
.002 w 
.66042 .3865 m .66042 .38663 L p 
.66041 .38648 L 0 0 .391 r 
F P 
s 
P 
p 
.65845 .38453 m .65993 .38549 L .66042 .38663 L .614 .234 .299 r 
F 
P 
p 
.002 w 
.66004 .38561 m .66042 .38663 L p 
.65993 .38549 L .614 .234 .299 r 
F P 
s 
P 
p 
.002 w 
.66042 .38663 m .29093 .41632 L p 
.53345 .39037 L .614 .234 .299 r 
F P 
s 
P 
p 
.002 w 
.66019 .38651 m .53452 .39026 L p 
.64492 .37845 L .614 .234 .299 r 
F P 
s 
P 
p 
.002 w 
.28989 .40655 m .28846 .38789 L .65692 .35861 L p 
.722 .679 .808 r 
F P 
s 
P 
p 
.002 w 
.66042 .38663 m .66042 .3865 L p 
.2895 .39757 L .723 .68 .808 r 
F P 
s 
P 
p 
.66089 .38658 m .66027 .38588 L .66096 .3866 L .688 .222 .141 r 
F 
P 
p 
.002 w 
.66096 .3866 m .66134 .38661 L p 
.66101 .38658 L .819 .775 .811 r 
F P 
s 
P 
p 
.002 w 
.66042 .38649 m .66042 .3865 L p 
.66041 .38648 L 0 0 .391 r 
F P 
s 
P 
p 
.65723 .38578 m .66027 .38588 L .6609 .38659 L .688 .222 .141 r 
F 
P 
p 
.2895 .39757 m .66042 .3865 L .65918 .38621 L .723 .68 .808 r 
F 
P 
p 
.002 w 
.59885 .37289 m .2895 .39757 L p 
.6109 .3877 L .723 .68 .808 r 
F P 
s 
P 
p 
.6109 .3877 m .65918 .38621 L .61304 .37602 L .723 .68 .808 r 
F 
P 
p 
.6109 .3877 m .61304 .37602 L .59885 .37289 L .723 .68 .808 r 
F 
P 
p 
.002 w 
.65732 .35967 m .65692 .35861 L .65643 .35864 L p 
.612 .228 .292 r 
F P 
s 
P 
p 
.002 w 
.65643 .35864 m .65579 .35869 L p 
.65594 .35879 L .612 .228 .292 r 
F P 
s 
P 
p 
.65594 .35879 m .65732 .35967 L .65643 .35864 L .612 .228 .292 r 
F 
P 
p 
.002 w 
.6497 .37736 m .61304 .37602 L p 
.65446 .35925 L .819 .773 .81 r 
F P 
s 
P 
p 
.002 w 
.65594 .35879 m .6497 .37736 L p 
.65446 .35925 L .819 .773 .81 r 
F P 
s 
P 
p 
.002 w 
.2895 .39757 m .29093 .41632 L .66042 .38663 L p 
.723 .68 .808 r 
F P 
s 
P 
p 
.65918 .38621 m .67214 .47959 L .6571 .38576 L .767 .575 .639 r 
F 
P 
p 
.002 w 
.67214 .47959 m .64631 .47638 L .6571 .38576 L p 
.767 .575 .639 r 
F P 
s 
P 
p 
.6084 .38423 m .64782 .37735 L .66027 .38588 L .688 .222 .141 r 
F 
P 
p 
.002 w 
.59122 .36383 m .28846 .38789 L p 
.59194 .36467 L .612 .228 .292 r 
F P 
s 
P 
p 
.61383 .3717 m .65446 .35925 L .61304 .37602 L .819 .773 .81 r 
F 
P 
p 
.002 w 
.656 .35862 m .65732 .35966 L p 
.65732 .35967 L .427 .349 .666 r 
F P 
s 
P 
p 
.002 w 
.6497 .37736 m .65594 .35879 L p 
.65732 .35967 L .427 .349 .666 r 
F P 
s 
P 
p 
.002 w 
.65594 .35879 m .656 .35862 L p 
.65732 .35967 L .427 .349 .666 r 
F P 
s 
P 
p 
.6497 .37736 m .65732 .35966 L .65867 .3726 L .427 .349 .666 r 
F 
P 
p 
.002 w 
.66047 .36797 m .65732 .35967 L p 
.65167 .3601 L .612 .228 .292 r 
F P 
s 
P 
p 
.66041 .38648 m .66042 .3865 L .65918 .38621 L .767 .575 .639 r 
F 
P 
p 
.66042 .3865 m .67214 .47959 L .65918 .38621 L .767 .575 .639 r 
F 
P 
p 
.002 w 
.66042 .3865 m .66042 .38649 L p 
.65952 .38629 L .723 .68 .808 r 
F P 
s 
P 
p 
.002 w 
.66042 .38649 m .66042 .38649 L p 
.65952 .38629 L .723 .68 .808 r 
F P 
s 
P 
p 
.65918 .38621 m .65952 .38629 L .66042 .38649 L .723 .68 .808 r 
F 
P 
p 
.002 w 
.6609 .38659 m .6089 .38482 L p 
.65717 .38578 L .688 .222 .141 r 
F P 
s 
P 
p 
.28846 .38789 m .59755 .37134 L .59194 .36467 L .612 .228 .292 r 
F 
P 
p 
.002 w 
.28846 .38789 m .2895 .39757 L .59885 .37289 L p 
.612 .228 .292 r 
F P 
s 
P 
p 
.002 w 
.59885 .37289 m .66047 .36797 L p 
.59755 .37134 L .612 .228 .292 r 
F P 
s 
P 
p 
.28846 .38789 m .59885 .37289 L .59755 .37134 L .612 .228 .292 r 
F 
P 
p 
.002 w 
.3497 .37601 m .33895 .36601 L .60112 .37559 L p 
.688 .222 .141 r 
F P 
s 
P 
p 
.002 w 
.60112 .37559 m .6497 .37736 L p 
.60244 .37715 L .688 .222 .141 r 
F P 
s 
P 
p 
.3497 .37601 m .60112 .37559 L .60244 .37715 L .688 .222 .141 r 
F 
P 
p 
.002 w 
.6089 .38482 m .3497 .37601 L p 
.6084 .38423 L .688 .222 .141 r 
F P 
s 
P 
p 
.6084 .38423 m .65717 .38578 L .6089 .38482 L .688 .222 .141 r 
F 
P 
p 
.59194 .36467 m .61867 .37021 L .65167 .3601 L .612 .228 .292 r 
F 
P 
p 
.59755 .37134 m .61867 .37021 L .59194 .36467 L .612 .228 .292 r 
F 
P 
p 
.61867 .37021 m .66047 .36797 L .65167 .3601 L .612 .228 .292 r 
F 
P 
p 
.002 w 
.65579 .35869 m .59122 .36383 L p 
.65167 .3601 L .612 .228 .292 r 
F P 
s 
P 
p 
.65167 .3601 m .65594 .35879 L .65579 .35869 L .612 .228 .292 r 
F 
P 
p 
.61605 .35955 m .656 .35862 L .65446 .35925 L .819 .773 .81 r 
F 
P 
p 
.59194 .36467 m .65167 .3601 L .59122 .36383 L .612 .228 .292 r 
F 
P 
p 
.61605 .35955 m .65446 .35925 L .61383 .3717 L .819 .773 .81 r 
F 
P 
p 
.3497 .37601 m .60244 .37715 L .6084 .38423 L .688 .222 .141 r 
F 
P 
p 
.60244 .37715 m .64782 .37735 L .6084 .38423 L .688 .222 .141 r 
F 
P 
p 
.65167 .3601 m .65732 .35967 L .65594 .35879 L .612 .228 .292 r 
F 
P 
p 
.33895 .36601 m .61605 .35955 L .61383 .3717 L .819 .773 .81 r 
F 
P 
p 
.002 w 
.60179 .37266 m .59885 .37289 L p 
.65918 .38621 L .723 .68 .808 r 
F P 
s 
P 
p 
.65717 .38578 m .65723 .38578 L .65906 .38619 L .688 .222 .141 r 
F 
P 
p 
.65867 .3726 m .65995 .38282 L .6599 .38445 L 0 0 .391 r 
F 
P 
p 
.002 w 
.66004 .38561 m .66001 .38554 L p 
.66042 .38649 L 0 0 .391 r 
F P 
s 
P 
p 
.66001 .38549 m .66042 .38649 L .66001 .38554 L 0 0 .391 r 
F 
P 
p 
.66001 .38549 m .66006 .38363 L .66041 .38648 L 0 0 .391 r 
F 
P 
p 
.65867 .3726 m .66146 .3867 L .66041 .38648 L .767 .575 .639 r 
F 
P 
p 
.6599 .38445 m .65995 .38282 L .66001 .38549 L 0 0 .391 r 
F 
P 
p 
.65995 .38282 m .66047 .36797 L .66006 .38363 L 0 0 .391 r 
F 
P 
p 
.65995 .38282 m .66006 .38363 L .66001 .38549 L 0 0 .391 r 
F 
P 
p 
.64782 .37735 m .65734 .38375 L .65733 .38386 L .688 .222 .141 r 
F 
P 
p 
.65734 .38375 m .65993 .38549 L .65733 .38386 L .688 .222 .141 r 
F 
P 
p 
.65733 .38386 m .65993 .38549 L .66027 .38588 L .688 .222 .141 r 
F 
P 
p 
.002 w 
.65993 .38549 m .66001 .38556 L p 
.66004 .38561 L .688 .222 .141 r 
F P 
s 
P 
p 
.002 w 
.66001 .38554 m .66004 .38561 L p 
.65993 .38549 L .614 .234 .299 r 
F P 
s 
P 
p 
.002 w 
.6571 .38576 m .65867 .3726 L p 
.66041 .38648 L .767 .575 .639 r 
F P 
s 
P 
p 
.65867 .3726 m .66047 .36797 L .65995 .38282 L 0 0 .391 r 
F 
P 
p 
.002 w 
.66047 .36797 m .60179 .37266 L p 
.65918 .38621 L .723 .68 .808 r 
F P 
s 
P 
p 
.002 w 
.61304 .37602 m .60112 .37559 L p 
.61383 .3717 L .819 .773 .81 r 
F P 
s 
P 
p 
.002 w 
.60112 .37559 m .33895 .36601 L p 
.61383 .3717 L .819 .773 .81 r 
F P 
s 
P 
p 
.002 w 
.656 .35862 m .65594 .35879 L p 
.65446 .35925 L .819 .773 .81 r 
F P 
s 
P 
p 
.65717 .38578 m .65906 .38619 L .6609 .38659 L .688 .222 .141 r 
F 
P 
p 
.65723 .38578 m .6609 .38659 L .6609 .38659 L .688 .222 .141 r 
F 
P 
p 
.002 w 
.66771 .36779 m .6614 .38642 L p 
.66031 .38089 L .427 .349 .666 r 
F P 
s 
P 
p 
.002 w 
.66047 .36797 m .66042 .38649 L p 
.66041 .38648 L 0 0 .391 r 
F P 
s 
P 
p 
.66006 .38363 m .66047 .36797 L .66041 .38648 L 0 0 .391 r 
F 
P 
p 
.002 w 
.66042 .38649 m .66047 .36797 L p 
.65918 .38621 L .723 .68 .808 r 
F P 
s 
P 
p 
.002 w 
.33895 .36601 m .34477 .34559 L .656 .35862 L p 
.819 .773 .81 r 
F P 
s 
P 
p 
.002 w 
.35559 .35549 m .3497 .37601 L .66096 .3866 L p 
.819 .775 .811 r 
F P 
s 
P 
p 
.002 w 
.66096 .3866 m .6609 .38659 L p 
.66089 .38658 L .688 .222 .141 r 
F P 
s 
P 
p 
.35559 .35549 m .66096 .3866 L .66101 .38658 L .819 .775 .811 r 
F 
P 
p 
.002 w 
.66771 .36779 m .35559 .35549 L p 
.66101 .38658 L .819 .775 .811 r 
F P 
s 
P 
p 
.002 w 
.6614 .38642 m .66771 .36779 L p 
.66101 .38658 L .819 .775 .811 r 
F P 
s 
P 
p 
.002 w 
.68711 .48144 m .68001 .48056 L p 
.6614 .38642 L .767 .575 .639 r 
F P 
s 
P 
p 
.002 w 
.6622 .38611 m .68711 .48144 L p 
.6614 .38642 L .767 .575 .639 r 
F P 
s 
P 
p 
.002 w 
.57967 .49965 m .56252 .50255 L .61811 .42742 L p 
.51 .418 .687 r 
F P 
s 
P 
p 
.002 w 
.656 .35862 m .34477 .34559 L p 
.66072 .36731 L .684 .214 .13 r 
F P 
s 
P 
p 
.002 w 
.66771 .36779 m .65732 .35966 L p 
.66072 .36731 L .684 .214 .13 r 
F P 
s 
P 
p 
.002 w 
.65732 .35966 m .656 .35862 L p 
.66072 .36731 L .684 .214 .13 r 
F P 
s 
P 
p 
.002 w 
.64631 .47638 m .68711 .48144 L .59932 .49632 L p 
.435 .791 .997 r 
F P 
s 
P 
p 
.002 w 
.59932 .49632 m .56252 .50255 L .58935 .49418 L p 
.435 .791 .997 r 
F P 
s 
P 
p 
.002 w 
.58935 .49418 m .64631 .47638 L p 
.59932 .49632 L .435 .791 .997 r 
F P 
s 
P 
p 
.002 w 
.67199 .52301 m .67306 .51215 L p 
.66804 .51107 L .825 .675 .698 r 
F P 
s 
P 
p 
.002 w 
.57626 .52101 m .58215 .59219 L .61173 .57337 L p 
.535 .354 .582 r 
F P 
s 
P 
p 
.002 w 
.61173 .57337 m .60651 .5152 L .57626 .52101 L p 
.535 .354 .582 r 
F P 
s 
P 
p 
.002 w 
.72092 .35867 m .69616 .39681 L .71076 .38012 L p 
.7 .912 .566 r 
F P 
s 
P 
p 
.002 w 
.72496 .35832 m .74137 .33312 L .72092 .35867 L p 
.7 .912 .566 r 
F P 
s 
P 
p 
.002 w 
.7469 .35309 m .72092 .35867 L .74137 .33312 L p 
.035 0 .044 r 
F P 
s 
P 
p 
.002 w 
.72092 .35867 m .7469 .35309 L .71491 .35919 L p 
.155 .693 .715 r 
F P 
s 
P 
p 
.002 w 
.71491 .35919 m .71043 .36004 L p 
.72092 .35867 L .155 .693 .715 r 
F P 
s 
P 
p 
.002 w 
.71076 .38012 m .72496 .35832 L p 
.72092 .35867 L .7 .912 .566 r 
F P 
s 
P 
p 
.002 w 
.67807 .58086 m .67199 .52301 L .64335 .51597 L p 
.835 .577 .548 r 
F P 
s 
P 
p 
.002 w 
.67807 .58086 m .64858 .56904 L p 
.6726 .59272 L .786 .333 .17 r 
F P 
s 
P 
p 
.002 w 
.67807 .58086 m .68881 .60397 L p 
.68216 .57198 L .976 .692 .3 r 
F P 
s 
P 
p 
.002 w 
.71076 .64705 m .68881 .60397 L .67807 .58086 L p 
0 0 .345 r 
F P 
s 
P 
p 
.002 w 
.68881 .60397 m .71076 .64705 L .7037 .68297 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.69578 .61557 m .71076 .64705 L p 
.69773 .62068 L 0 0 .345 r 
F P 
s 
P 
p 
.002 w 
.67807 .58086 m .69578 .61557 L p 
.69773 .62068 L 0 0 .345 r 
F P 
s 
P 
p 
.002 w 
.69578 .61557 m .67807 .58086 L p 
.6726 .59272 L .786 .333 .17 r 
F P 
s 
P 
p 
.002 w 
.66421 .60062 m .69578 .61557 L p 
.67596 .59602 L .786 .333 .17 r 
F P 
s 
P 
p 
.002 w 
.64858 .56904 m .66421 .60062 L p 
.67596 .59602 L .786 .333 .17 r 
F P 
s 
P 
p 
.002 w 
.66421 .60062 m .62807 .60817 L p 
.6522 .60532 L .06 0 0 r 
F P 
s 
P 
p 
.002 w 
.69578 .61557 m .66421 .60062 L p 
.69316 .60874 L .05 .524 .89 r 
F P 
s 
P 
p 
.002 w 
.68677 .60123 m .72124 .61663 L p 
.69722 .60988 L .05 .524 .89 r 
F P 
s 
P 
p 
.002 w 
.66421 .60062 m .68677 .60123 L p 
.69722 .60988 L .05 .524 .89 r 
F P 
s 
P 
p 
.002 w 
.68677 .60123 m .66421 .60062 L p 
.6522 .60532 L .06 0 0 r 
F P 
s 
P 
p 
.002 w 
.66421 .60062 m .64858 .56904 L .61173 .57337 L p 
.619 .266 .349 r 
F P 
s 
P 
p 
.002 w 
.61173 .57337 m .62807 .60817 L .66421 .60062 L p 
.619 .266 .349 r 
F P 
s 
P 
p 
.002 w 
.65196 .60904 m .68677 .60123 L p 
.65636 .60483 L .06 0 0 r 
F P 
s 
P 
p 
.002 w 
.62807 .60817 m .65196 .60904 L p 
.65636 .60483 L .06 0 0 r 
F P 
s 
P 
p 
.002 w 
.60138 .63546 m .63005 .63741 L .65196 .60904 L p 
.104 0 .112 r 
F P 
s 
P 
p 
.002 w 
.65196 .60904 m .63005 .63741 L p 
.64848 .61238 L .619 .853 .482 r 
F P 
s 
P 
p 
.002 w 
.67199 .52301 m .67807 .58086 L p 
.68216 .57198 L .976 .692 .3 r 
F P 
s 
P 
p 
.002 w 
.64335 .51597 m .64858 .56904 L .67807 .58086 L p 
.835 .577 .548 r 
F P 
s 
P 
p 
.002 w 
.65196 .60904 m .62807 .60817 L .60138 .63546 L p 
.104 0 .112 r 
F P 
s 
P 
p 
.002 w 
.67728 .57327 m .65196 .60904 L p 
.64848 .61238 L .619 .853 .482 r 
F P 
s 
P 
p 
.002 w 
.68677 .60123 m .65196 .60904 L p 
.67608 .59238 L .727 .905 .957 r 
F P 
s 
P 
p 
.002 w 
.71042 .56865 m .68677 .60123 L p 
.67608 .59238 L .727 .905 .957 r 
F P 
s 
P 
p 
.002 w 
.72124 .61663 m .69578 .61557 L p 
.69316 .60874 L .05 .524 .89 r 
F P 
s 
P 
p 
.002 w 
.57134 .61792 m .59455 .67185 L .60138 .63546 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.60138 .63546 m .58215 .59219 L .57134 .61792 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.60651 .5152 m .61173 .57337 L .64858 .56904 L p 
.695 .472 .581 r 
F P 
s 
P 
p 
.002 w 
.64858 .56904 m .64335 .51597 L .60651 .5152 L p 
.695 .472 .581 r 
F P 
s 
P 
p 
.002 w 
.69616 .39681 m .72092 .35867 L .68743 .365 L p 
.743 .874 .94 r 
F P 
s 
P 
p 
.002 w 
.58215 .59219 m .60138 .63546 L .62807 .60817 L p 
.433 .185 .437 r 
F P 
s 
P 
p 
.002 w 
.62807 .60817 m .61173 .57337 L .58215 .59219 L p 
.433 .185 .437 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.07506 .73364 m 
.07775 .37022 L 
s 
P 
p 
1 0 0 r 
.008 w 
.07775 .37022 m 
.27095 .39927 L 
s 
P 
p 
1 0 0 r 
.008 w 
.07775 .37022 m 
.19209 .18509 L 
s 
P 
p 
.002 w 
.78138 .2875 m .74124 .2983 L .72081 .26734 L p 
.228 .361 .791 r 
F P 
s 
P 
p 
.002 w 
.72081 .26734 m .76631 .25344 L .78138 .2875 L p 
.228 .361 .791 r 
F P 
s 
P 
p 
.002 w 
.76631 .25344 m .72081 .26734 L .68775 .25175 L p 
.281 .62 .959 r 
F P 
s 
P 
p 
.002 w 
.77392 .32546 m .74137 .33312 L .74124 .2983 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.74124 .2983 m .78138 .2875 L .77392 .32546 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.73418 .23635 m .68775 .25175 L .65439 .25749 L p 
.259 .769 .811 r 
F P 
s 
P 
p 
.002 w 
.68775 .25175 m .73418 .23635 L .76631 .25344 L p 
.281 .62 .959 r 
F P 
s 
P 
p 
.002 w 
.74137 .33312 m .77392 .32546 L .7469 .35309 L p 
.035 0 .044 r 
F P 
s 
P 
p 
.002 w 
.65439 .25749 m .69722 .24305 L .73418 .23635 L p 
.259 .769 .811 r 
F P 
s 
P 
p 
.002 w 
.69722 .24305 m .65439 .25749 L .63341 .28265 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.7427 .68723 m .7037 .68297 L .71076 .64705 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.7037 .68297 m .7427 .68723 L .72137 .71601 L p 
.173 0 .18 r 
F P 
s 
P 
p 
.002 w 
.72137 .71601 m .67741 .70986 L .7037 .68297 L p 
.173 0 .18 r 
F P 
s 
P 
p 
.002 w 
.67741 .70986 m .72137 .71601 L .68642 .7245 L p 
.157 0 0 r 
F P 
s 
P 
p 
.002 w 
.68642 .7245 m .64174 .71763 L .67741 .70986 L p 
.157 0 0 r 
F P 
s 
P 
p 
.002 w 
.71043 .36004 m .68743 .365 L .72092 .35867 L p 
.155 .693 .715 r 
F P 
s 
P 
p 
.002 w 
.74256 .64935 m .71076 .64705 L .69578 .61557 L p 
.122 .302 .773 r 
F P 
s 
P 
p 
.002 w 
.71076 .64705 m .74256 .64935 L .7427 .68723 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.64174 .71763 m .68642 .7245 L .65127 .70911 L p 
0 .466 .832 r 
F P 
s 
P 
p 
.002 w 
.65127 .70911 m .61007 .70322 L .64174 .71763 L p 
0 .466 .832 r 
F P 
s 
P 
p 
.002 w 
.63341 .28265 m .66978 .2711 L .69722 .24305 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.66978 .2711 m .63341 .28265 L .63307 .31782 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.08723 .49505 m .08809 .47587 L .30568 .49816 L p 
.772 .583 .643 r 
F P 
s 
P 
p 
.002 w 
.30568 .49816 m .30532 .51688 L .08723 .49505 L p 
.772 .583 .643 r 
F P 
s 
P 
p 
.002 w 
.31057 .48405 m .30568 .49816 L .08809 .47587 L p 
.726 .742 .864 r 
F P 
s 
P 
p 
.002 w 
.31057 .48405 m .30568 .49816 L .30532 .51688 L p 
0 0 .445 r 
F P 
s 
P 
p 
.002 w 
.09035 .49984 m .08723 .49505 L .30532 .51688 L p 
.53 0 0 r 
F P 
s 
P 
p 
.002 w 
.30532 .51688 m .30985 .52169 L .09035 .49984 L p 
.53 0 0 r 
F P 
s 
P 
p 
.002 w 
.31515 .48864 m .31057 .48405 L p 
.30532 .51688 L 0 0 .445 r 
F P 
s 
P 
p 
.002 w 
.3148 .50756 m .31515 .48864 L p 
.30532 .51688 L 0 0 .445 r 
F P 
s 
P 
p 
0 0 1 r 
.015 w 
.31489 .50282 m 
.56252 .50255 L 
s 
P 
p 
.002 w 
.30532 .51688 m .30985 .52169 L .3148 .50756 L p 
0 0 .445 r 
F P 
s 
P 
p 
.002 w 
.67819 .34353 m .65376 .34939 L .68743 .365 L p 
.217 .598 .949 r 
F P 
s 
P 
p 
.002 w 
.68743 .365 m .71043 .36004 L .67819 .34353 L p 
.217 .598 .949 r 
F P 
s 
P 
p 
.002 w 
.69578 .61557 m .72124 .61663 L .74256 .64935 L p 
.122 .302 .773 r 
F P 
s 
P 
p 
.002 w 
.61007 .70322 m .65127 .70911 L .62968 .67572 L p 
.049 .259 .755 r 
F P 
s 
P 
p 
.002 w 
.62968 .67572 m .59455 .67185 L .61007 .70322 L p 
.049 .259 .755 r 
F P 
s 
P 
p 
.002 w 
.63307 .31782 m .66256 .30958 L .66978 .2711 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.66256 .30958 m .63307 .31782 L .65376 .34939 L p 
.175 .332 .783 r 
F P 
s 
P 
p 
.002 w 
.08809 .47587 m .09206 .46126 L .31057 .48405 L p 
.726 .742 .864 r 
F P 
s 
P 
p 
.002 w 
.31515 .48864 m .31057 .48405 L .09206 .46126 L p 
.515 0 0 r 
F P 
s 
P 
p 
.002 w 
.65376 .34939 m .67819 .34353 L .66256 .30958 L p 
.175 .332 .783 r 
F P 
s 
P 
p 
.015 w 
.65231 .38882 m 
.65328 .38633 L 
s 
P 
p 
.015 w 
.6193 .47304 m 
.65231 .38882 L 
s 
P 
p 
.002 w 
.59455 .67185 m .62968 .67572 L .63005 .63741 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.63005 .63741 m .60138 .63546 L .59455 .67185 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.09436 .48521 m .09035 .49984 L .30985 .52169 L p 
.726 .744 .866 r 
F P 
s 
P 
p 
.002 w 
.30985 .52169 m .3148 .50756 L .09436 .48521 L p 
.726 .744 .866 r 
F P 
s 
P 
p 
.002 w 
.09206 .46126 m .09521 .46581 L .31515 .48864 L p 
.515 0 0 r 
F P 
s 
P 
p 
.002 w 
.3148 .50756 m .31515 .48864 L .09521 .46581 L p 
.773 .583 .642 r 
F P 
s 
P 
p 
.002 w 
.34477 .34559 m .35559 .35549 L .66771 .36779 L p 
.684 .214 .13 r 
F P 
s 
P 
p 
.002 w 
.2895 .39757 m .29093 .41632 L .28989 .40655 L p 
0 0 .09 r 
F P 
s 
P 
p 
.002 w 
.28989 .40655 m .28846 .38789 L .2895 .39757 L p 
0 0 .09 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.27095 .39927 m 
.28969 .40208 L 
s 
P 
p 
.002 w 
.09521 .46581 m .09436 .48521 L .3148 .50756 L p 
.773 .583 .642 r 
F P 
s 
P 
p 
.002 w 
.60588 .50728 m .68711 .48144 L .64631 .47638 L closepath p 
.767 .575 .639 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.2962 .41366 m 
.29824 .41728 L 
s 
P 
p 
1 0 0 r 
.008 w 
.32523 .46526 m 
.34886 .50728 L 
s 
P 
p 
1 0 0 r 
.008 w 
.30707 .43297 m 
.32523 .46526 L 
s 
P 
p 
1 0 0 r 
.008 w 
.34886 .50728 m 
.37398 .55194 L 
s 
P 
p 
1 0 0 r 
.008 w 
.29824 .41728 m 
.30707 .43297 L 
s 
P 
p 
1 0 0 r 
.008 w 
.23677 .48383 m 
.26235 .44433 L 
s 
P 
p 
1 0 0 r 
.008 w 
.21454 .51818 m 
.23377 .48846 L 
s 
P 
p 
1 0 0 r 
.008 w 
.23377 .48846 m 
.23677 .48383 L 
s 
P 
p 
1 0 0 r 
.008 w 
.09773 .69862 m 
.21454 .51818 L 
s 
P 
p 
1 0 0 r 
.008 w 
.26235 .44433 m 
.27954 .41777 L 
s 
P 
p 
1 0 0 r 
.008 w 
.07506 .73364 m 
.09773 .69862 L 
s 
P 
p 
1 0 0 r 
.008 w 
.27954 .41777 m 
.28969 .40208 L 
s 
P 
p 
1 0 0 r 
.008 w 
.29451 .39863 m 
.33938 .36641 L 
s 
P 
p 
1 0 0 r 
.008 w 
.2934 .39942 m 
.29451 .39863 L 
s 
P 
p 
.002 w 
.51202 .78974 m .48961 .78183 L .59454 .51508 L p 
.696 .495 .612 r 
F P 
s 
P 
p 
.002 w 
.59454 .51508 m .61615 .52227 L .51202 .78974 L p 
.696 .495 .612 r 
F P 
s 
P 
p 
.002 w 
.57946 .50333 m .59454 .51508 L .48961 .78183 L p 
.856 .684 .668 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.37398 .55194 m 
.47237 .72686 L 
s 
P 
p 
.002 w 
.57946 .50333 m .59454 .51508 L .61615 .52227 L p 
.436 .654 .951 r 
F P 
s 
P 
p 
.002 w 
.52779 .79002 m .51202 .78974 L .61615 .52227 L p 
.429 .214 .483 r 
F P 
s 
P 
p 
.002 w 
.61615 .52227 m .63193 .52075 L .52779 .79002 L p 
.429 .214 .483 r 
F P 
s 
P 
p 
.002 w 
.61615 .52227 m .63193 .52075 L p 
.57946 .50333 L .436 .654 .951 r 
F P 
s 
P 
p 
.002 w 
.76702 .38397 m .7469 .35309 L .77392 .32546 L p 
.411 .157 .416 r 
F P 
s 
P 
p 
.002 w 
.77392 .32546 m .79956 .36278 L .76702 .38397 L p 
.411 .157 .416 r 
F P 
s 
P 
p 
.002 w 
.79956 .36278 m .77392 .32546 L .78138 .2875 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.72802 .3884 m .71043 .36004 L .7469 .35309 L p 
.593 .208 .282 r 
F P 
s 
P 
p 
.002 w 
.7469 .35309 m .76702 .38397 L .72802 .3884 L p 
.593 .208 .282 r 
F P 
s 
P 
p 
.002 w 
.57971 .49375 m .57946 .50333 L .47337 .77083 L p 
.907 .907 .503 r 
F P 
s 
P 
p 
.002 w 
.48961 .78183 m .47337 .77083 L .57946 .50333 L p 
.856 .684 .668 r 
F P 
s 
P 
p 
.002 w 
.59542 .49203 m .57971 .49375 L .57946 .50333 L p 
.436 .654 .951 r 
F P 
s 
P 
p 
.002 w 
.61745 .49932 m .59542 .49203 L p 
.57946 .50333 L .436 .654 .951 r 
F P 
s 
P 
p 
.015 w 
.60997 .49684 m 
.6193 .47304 L 
s 
P 
p 
.002 w 
.63259 .51128 m .61745 .49932 L p 
.57946 .50333 L .436 .654 .951 r 
F P 
s 
P 
p 
.002 w 
.63193 .52075 m .63259 .51128 L p 
.57946 .50333 L .436 .654 .951 r 
F P 
s 
P 
p 
.002 w 
.78138 .2875 m .81348 .33246 L .79956 .36278 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.81348 .33246 m .78138 .2875 L .76631 .25344 L p 
0 0 .521 r 
F P 
s 
P 
p 
.002 w 
.69375 .42237 m .68971 .38654 L p 
.69684 .37442 L .958 .67 .236 r 
F P 
s 
P 
p 
.002 w 
.69684 .37442 m .67819 .34353 L .70649 .35802 L p 
.753 .252 .029 r 
F P 
s 
P 
p 
.002 w 
.67819 .34353 m .69684 .37442 L .68523 .34691 L p 
0 0 .432 r 
F P 
s 
P 
p 
.002 w 
.68971 .38654 m .68523 .34691 L .69684 .37442 L p 
.958 .67 .236 r 
F P 
s 
P 
p 
.002 w 
.70649 .35802 m .71043 .36004 L p 
.69684 .37442 L .753 .252 .029 r 
F P 
s 
P 
p 
.002 w 
.71043 .36004 m .72802 .3884 L .69684 .37442 L p 
.753 .252 .029 r 
F P 
s 
P 
p 
.002 w 
.09206 .46126 m .08809 .47587 L .08723 .49505 L p 
0 0 .333 r 
F P 
s 
P 
p 
.002 w 
.52761 .78238 m .52779 .79002 L .63193 .52075 L p 
.883 .891 .468 r 
F P 
s 
P 
p 
.002 w 
.63193 .52075 m .63259 .51128 L .52761 .78238 L p 
.883 .891 .468 r 
F P 
s 
P 
p 
.002 w 
.74791 .5813 m .72124 .61663 L .68677 .60123 L p 
.578 .678 .908 r 
F P 
s 
P 
p 
.002 w 
.72124 .61663 m .74791 .5813 L .77609 .60658 L p 
.42 .452 .788 r 
F P 
s 
P 
p 
.002 w 
.77609 .60658 m .74256 .64935 L .72124 .61663 L p 
.42 .452 .788 r 
F P 
s 
P 
p 
.002 w 
.09521 .46581 m .09206 .46126 L p 
.08723 .49505 L 0 0 .333 r 
F P 
s 
P 
p 
.002 w 
.09436 .48521 m .09521 .46581 L p 
.08723 .49505 L 0 0 .333 r 
F P 
s 
P 
p 
.002 w 
.08723 .49505 m .09035 .49984 L .09436 .48521 L p 
0 0 .333 r 
F P 
s 
P 
p 
.002 w 
.74256 .64935 m .77609 .60658 L .7844 .63535 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.7844 .63535 m .7427 .68723 L .74256 .64935 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.76631 .25344 m .80301 .30431 L .81348 .33246 L p 
0 0 .521 r 
F P 
s 
P 
p 
.002 w 
.80301 .30431 m .76631 .25344 L .73418 .23635 L p 
.723 .197 0 r 
F P 
s 
P 
p 
.002 w 
.68523 .34691 m .66256 .30958 L .67819 .34353 L p 
0 0 .432 r 
F P 
s 
P 
p 
.002 w 
.68677 .60123 m .71042 .56865 L .74791 .5813 L p 
.578 .678 .908 r 
F P 
s 
P 
p 
.002 w 
.47337 .77083 m .47274 .76306 L .57971 .49375 L p 
.907 .907 .503 r 
F P 
s 
P 
p 
.002 w 
.59542 .49203 m .57971 .49375 L .47274 .76306 L p 
.418 .2 .474 r 
F P 
s 
P 
p 
.002 w 
.7427 .68723 m .7844 .63535 L .76907 .65676 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.76907 .65676 m .72137 .71601 L .7427 .68723 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.77157 .28939 m .73418 .23635 L .69722 .24305 L p 
.576 .172 .24 r 
F P 
s 
P 
p 
.002 w 
.73418 .23635 m .77157 .28939 L .80301 .30431 L p 
.723 .197 0 r 
F P 
s 
P 
p 
.002 w 
.69821 .31605 m .66978 .2711 L .66256 .30958 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.66256 .30958 m .68523 .34691 L .69821 .31605 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.51127 .7712 m .52761 .78238 L .63259 .51128 L p 
.86 .687 .666 r 
F P 
s 
P 
p 
.002 w 
.63259 .51128 m .61745 .49932 L .51127 .7712 L p 
.86 .687 .666 r 
F P 
s 
P 
p 
.002 w 
.65196 .60904 m .67728 .57327 L .71042 .56865 L p 
.727 .905 .957 r 
F P 
s 
P 
p 
.002 w 
.69722 .24305 m .73129 .29388 L .77157 .28939 L p 
.576 .172 .24 r 
F P 
s 
P 
p 
.002 w 
.73129 .29388 m .69722 .24305 L .66978 .2711 L p 
.382 .12 .387 r 
F P 
s 
P 
p 
.002 w 
.66978 .2711 m .69821 .31605 L .73129 .29388 L p 
.382 .12 .387 r 
F P 
s 
P 
p 
.002 w 
.47274 .76306 m .48841 .76316 L .59542 .49203 L p 
.418 .2 .474 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.47605 .73341 m 
.48101 .74223 L 
s 
P 
p 
1 0 0 r 
.008 w 
.47237 .72686 m 
.47605 .73341 L 
s 
P 
p 
.002 w 
.61745 .49932 m .59542 .49203 L .48841 .76316 L p 
.696 .493 .61 r 
F P 
s 
P 
p 
.002 w 
.72137 .71601 m .76907 .65676 L .73542 .66217 L p 
.714 .92 .963 r 
F P 
s 
P 
p 
.002 w 
.73542 .66217 m .68642 .7245 L .72137 .71601 L p 
.714 .92 .963 r 
F P 
s 
P 
p 
.002 w 
.48841 .76316 m .51127 .7712 L .61745 .49932 L p 
.696 .493 .61 r 
F P 
s 
P 
p 
.002 w 
.63005 .63741 m .66089 .59376 L .67728 .57327 L p 
.619 .853 .482 r 
F P 
s 
P 
p 
.002 w 
.66089 .59376 m .63005 .63741 L .62968 .67572 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.68642 .7245 m .73542 .66217 L .69655 .6491 L p 
.565 .682 .918 r 
F P 
s 
P 
p 
.002 w 
.69655 .6491 m .65127 .70911 L .68642 .7245 L p 
.565 .682 .918 r 
F P 
s 
P 
p 
.002 w 
.73479 .44381 m .72802 .3884 L .76702 .38397 L p 
.693 .461 .566 r 
F P 
s 
P 
p 
.002 w 
.76702 .38397 m .77501 .44462 L .73479 .44381 L p 
.693 .461 .566 r 
F P 
s 
P 
p 
.002 w 
.77501 .44462 m .76702 .38397 L .79956 .36278 L p 
.525 .342 .575 r 
F P 
s 
P 
p 
.002 w 
.66802 .62277 m .62968 .67572 L .65127 .70911 L p 
.396 .44 .789 r 
F P 
s 
P 
p 
.002 w 
.62968 .67572 m .66802 .62277 L .66089 .59376 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.70384 .43542 m .69684 .37442 L .72802 .3884 L p 
.847 .573 .522 r 
F P 
s 
P 
p 
.002 w 
.72802 .3884 m .73479 .44381 L .70384 .43542 L p 
.847 .573 .522 r 
F P 
s 
P 
p 
.002 w 
.65127 .70911 m .69655 .6491 L .66802 .62277 L p 
.396 .44 .789 r 
F P 
s 
P 
p 
.002 w 
.76794 .51782 m .74791 .5813 L .71042 .56865 L p 
.676 .63 .796 r 
F P 
s 
P 
p 
.002 w 
.74791 .5813 m .76794 .51782 L .80135 .52827 L p 
.523 .467 .735 r 
F P 
s 
P 
p 
.002 w 
.80135 .52827 m .77609 .60658 L .74791 .5813 L p 
.523 .467 .735 r 
F P 
s 
P 
p 
.002 w 
.72828 .51059 m .71042 .56865 L .67728 .57327 L p 
.815 .781 .821 r 
F P 
s 
P 
p 
.002 w 
.71042 .56865 m .72828 .51059 L .76794 .51782 L p 
.676 .63 .796 r 
F P 
s 
P 
p 
.002 w 
.79956 .36278 m .81004 .43756 L .77501 .44462 L p 
.525 .342 .575 r 
F P 
s 
P 
p 
.002 w 
.81004 .43756 m .79956 .36278 L .81348 .33246 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.15645 .65228 m 
.07506 .73364 L 
s 
P 
p 
1 0 0 r 
.008 w 
.07506 .73364 m 
.46061 .77256 L 
s 
P 
p 
.002 w 
.69684 .37442 m .70384 .43542 L .69375 .42237 L p 
.958 .67 .236 r 
F P 
s 
P 
p 
.002 w 
.77609 .60658 m .80135 .52827 L .81606 .53819 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.81606 .53819 m .7844 .63535 L .77609 .60658 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.69661 .50918 m .67728 .57327 L .66089 .59376 L p 
.948 .953 .657 r 
F P 
s 
P 
p 
.002 w 
.67728 .57327 m .69661 .50918 L .72828 .51059 L p 
.815 .781 .821 r 
F P 
s 
P 
p 
.002 w 
.69661 .50918 m .70384 .43542 L .73479 .44381 L p 
.836 .685 .695 r 
F P 
s 
P 
p 
.002 w 
.73479 .44381 m .72828 .51059 L .69661 .50918 L p 
.836 .685 .695 r 
F P 
s 
P 
p 
.002 w 
.72828 .51059 m .73479 .44381 L .77501 .44462 L p 
.702 .564 .695 r 
F P 
s 
P 
p 
.002 w 
.77501 .44462 m .76794 .51782 L .72828 .51059 L p 
.702 .564 .695 r 
F P 
s 
P 
p 
.002 w 
.76794 .51782 m .77501 .44462 L .81004 .43756 L p 
.551 .429 .668 r 
F P 
s 
P 
p 
.002 w 
.81348 .33246 m .82687 .42503 L .81004 .43756 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.82687 .42503 m .81348 .33246 L .80301 .30431 L p 
.921 .632 .149 r 
F P 
s 
P 
p 
.002 w 
.81004 .43756 m .80135 .52827 L .76794 .51782 L p 
.551 .429 .668 r 
F P 
s 
P 
p 
.002 w 
.47337 .77083 m .48961 .78183 L .51202 .78974 L p 
.328 .635 .963 r 
F P 
s 
P 
p 
.002 w 
.51202 .78974 m .52779 .79002 L p 
.47337 .77083 L .328 .635 .963 r 
F P 
s 
P 
p 
.002 w 
.70913 .40946 m .69821 .31605 L .68523 .34691 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.68523 .34691 m .69375 .42237 L .70913 .40946 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.7844 .63535 m .81606 .53819 L .80572 .54375 L p 
.926 .949 .612 r 
F P 
s 
P 
p 
.002 w 
.80572 .54375 m .76907 .65676 L .7844 .63535 L p 
.926 .949 .612 r 
F P 
s 
P 
p 
.002 w 
.48841 .76316 m .47274 .76306 L .47337 .77083 L p 
.328 .635 .963 r 
F P 
s 
P 
p 
.002 w 
.51127 .7712 m .48841 .76316 L p 
.47337 .77083 L .328 .635 .963 r 
F P 
s 
P 
p 
.002 w 
.52761 .78238 m .51127 .7712 L p 
.47337 .77083 L .328 .635 .963 r 
F P 
s 
P 
p 
.002 w 
.52779 .79002 m .52761 .78238 L p 
.47337 .77083 L .328 .635 .963 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.46061 .77256 m 
.50033 .77657 L 
s 
P 
p 
.002 w 
.68472 .51424 m .69375 .42237 L .70384 .43542 L p 
.998 .848 .544 r 
F P 
s 
P 
p 
.002 w 
.70384 .43542 m .69661 .50918 L .68472 .51424 L p 
.998 .848 .544 r 
F P 
s 
P 
p 
.002 w 
.66089 .59376 m .68472 .51424 L .69661 .50918 L p 
.948 .953 .657 r 
F P 
s 
P 
p 
.002 w 
.68472 .51424 m .66089 .59376 L .66802 .62277 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.80135 .52827 m .81004 .43756 L .82687 .42503 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.82687 .42503 m .81606 .53819 L .80135 .52827 L p 
.155 .087 .521 r 
F P 
s 
P 
p 
.002 w 
.80301 .30431 m .81837 .41163 L .82687 .42503 L p 
.921 .632 .149 r 
F P 
s 
P 
p 
.002 w 
.81837 .41163 m .80301 .30431 L .77157 .28939 L p 
.854 .57 .506 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.48358 .73109 m 
.48735 .74134 L 
s 
P 
p 
1 0 0 r 
.008 w 
.35446 .38041 m 
.48358 .73109 L 
s 
P 
p 
1 0 0 r 
.008 w 
.35288 .37612 m 
.35446 .38041 L 
s 
P 
p 
1 0 0 r 
.008 w 
.46875 .76516 m 
.47178 .76625 L 
s 
P 
p 
1 0 0 r 
.008 w 
.47178 .76625 m 
.50033 .77657 L 
s 
P 
p 
1 0 0 r 
.008 w 
.15645 .65228 m 
.46875 .76516 L 
s 
P 
p 
.002 w 
.74486 .40181 m .73129 .29388 L .69821 .31605 L p 
.513 .327 .566 r 
F P 
s 
P 
p 
.002 w 
.69821 .31605 m .70913 .40946 L .74486 .40181 L p 
.513 .327 .566 r 
F P 
s 
P 
p 
.002 w 
.78695 .40264 m .77157 .28939 L .73129 .29388 L p 
.692 .454 .558 r 
F P 
s 
P 
p 
.002 w 
.77157 .28939 m .78695 .40264 L .81837 .41163 L p 
.854 .57 .506 r 
F P 
s 
P 
p 
.002 w 
.76907 .65676 m .80572 .54375 L .77346 .54258 L p 
.82 .792 .826 r 
F P 
s 
P 
p 
.002 w 
.77346 .54258 m .73542 .66217 L .76907 .65676 L p 
.82 .792 .826 r 
F P 
s 
P 
p 
.002 w 
.73129 .29388 m .74486 .40181 L .78695 .40264 L p 
.692 .454 .558 r 
F P 
s 
P 
p 
.002 w 
.69789 .52408 m .66802 .62277 L .69655 .6491 L p 
.511 .46 .736 r 
F P 
s 
P 
p 
.002 w 
.66802 .62277 m .69789 .52408 L .68472 .51424 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.69789 .52408 m .70913 .40946 L .69375 .42237 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.69375 .42237 m .68472 .51424 L .69789 .52408 L p 
.093 .033 .49 r 
F P 
s 
P 
p 
.002 w 
.81606 .53819 m .82687 .42503 L .81837 .41163 L p 
.995 .848 .501 r 
F P 
s 
P 
p 
.002 w 
.81837 .41163 m .80572 .54375 L .81606 .53819 L p 
.995 .848 .501 r 
F P 
s 
P 
p 
.002 w 
.73542 .66217 m .77346 .54258 L .7319 .53499 L p 
.674 .632 .8 r 
F P 
s 
P 
p 
.002 w 
.7319 .53499 m .69655 .6491 L .73542 .66217 L p 
.674 .632 .8 r 
F P 
s 
P 
p 
.002 w 
.35559 .35549 m .3497 .37601 L .33895 .36601 L p 
.347 .284 .643 r 
F P 
s 
P 
p 
.002 w 
.33895 .36601 m .34477 .34559 L .35559 .35549 L p 
.347 .284 .643 r 
F P 
s 
P 
p 
.002 w 
.69655 .6491 m .7319 .53499 L .69789 .52408 L p 
.511 .46 .736 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.33723 .37606 m 
.34723 .36078 L 
s 
P 
p 
1 0 0 r 
.008 w 
.15645 .65228 m 
.33723 .37606 L 
s 
P 
p 
1 0 0 r 
.008 w 
.19209 .18509 m 
.33742 .34967 L 
s 
P 
p 
1 0 0 r 
.008 w 
.33742 .34967 m 
.34723 .36078 L 
s 
P 
p 
.002 w 
.7319 .53499 m .74486 .40181 L .70913 .40946 L p 
.541 .421 .665 r 
F P 
s 
P 
p 
.002 w 
.70913 .40946 m .69789 .52408 L .7319 .53499 L p 
.541 .421 .665 r 
F P 
s 
P 
p 
.002 w 
.80572 .54375 m .81837 .41163 L .78695 .40264 L p 
.843 .691 .694 r 
F P 
s 
P 
p 
.002 w 
.78695 .40264 m .77346 .54258 L .80572 .54375 L p 
.843 .691 .694 r 
F P 
s 
P 
p 
.002 w 
.77346 .54258 m .78695 .40264 L .74486 .40181 L p 
.702 .563 .695 r 
F P 
s 
P 
p 
.002 w 
.74486 .40181 m .7319 .53499 L .77346 .54258 L p 
.702 .563 .695 r 
F P 
s 
P 
p 
1 0 0 r 
.008 w 
.19209 .18509 m 
.15645 .65228 L 
s 
P 
p 
.002 w 
.17583 .02497 m 
.93792 .14641 L 
s 
.93792 .14641 m 
.97503 .81474 L 
s 
.97503 .81474 m 
.14905 .75824 L 
s 
.14905 .75824 m 
.17583 .02497 L 
s 
.05539 .25301 m 
.02497 .86356 L 
s 
.02497 .86356 m 
.14905 .75824 L 
s 
.14905 .75824 m 
.17583 .02497 L 
s 
.17583 .02497 m 
.05539 .25301 L 
s 
P 
p 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 261},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J00011A000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol0035oo`@00>Eo
o`00<7oo0P000goo1P00ggoo000`Ool20009Ool6003IOol002moo`03001oo`0000moo`L00=9oo`00
;goo00<007oo00005Woo1P00c7oo000^Ool01000Oomoo`0077oo1P00aWoo000^Ool01000Oomoo`00
8Woo1P00`7oo000]Ool01@00Oomoogoo0000:7oo1`00^Goo000]Ool01@00Oomoogoo00001goo0`00
9Goo1P00/goo000/Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000Bcm;?d/o1@009Woo1P00[Goo
000/Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Bcm;?`06Bcl6000VOol7002VOol002]oo`03
001oogoo00=oo`03001oogoo00=oo`03001;?d/o00e;?`H002Moo`H00:1oo`00:goo00<007ooOol0
0goo00<007ooOol00goo00<004/oBcl04d/o1P009goo1P00VWoo000ZOol00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Bcm;?`0JBcl7000VOol6002DOol002Yoo`03001oogoo00Aoo`03001oogoo009o
o`03001;?d/o025;?`H002Ioo`L008eoo`00:Goo00<007ooOol017oo00<007ooOol00Woo00<004/o
Bcl0:4/o1`009Woo1P00Qgoo000XOol00`00Oomoo`05Ool01@00Oomoogoo0000<T/o1`009Goo1P00
PGoo000XOol00`00Oomoo`05Ool01@00Oomoogoo0000>D/o1P009Goo1`00NWoo000WOol00`00Oomo
o`06Ool01000Oomoo`00@4/o1`009Goo1P00M7oo000WOol00`00Oomoo`06Ool01000Oomoo`00Ad/o
1P009Goo1P00KWoo000VOol00`00Oomoo`07Ool00`00Ool0001>Bcl7000TOol7001WOol002Ioo`03
001oogoo00Moo`03001oo`0005E;?`H002Eoo`H0065oo`009Goo00<007ooOol027oo0P00G4/o1`00
97oo1P00Fgoo000UOol00`00Oomoo`08Ool00`00Bcm;?`1RBcl6000TOol6001EOol002Aoo`03001o
ogoo00Uoo`03001;?d/o06Q;?`L002=oo`L004ioo`0097oo00<007ooOol027oo0P00LD/o1`008goo
1P00B7oo000SOol00`00Oomoo`09Ool2001hBcl6000SOol60012Ool002=oo`03001oogoo00Qoo`03
001;?`0007i;?`L0029oo`L003]oo`008Woo00<007ooOol02Goo00<004/o0000QD/o1P008goo1P00
=Goo000ROol00`00Oomoo`08Ool01000Bcm;?`00Rd/o1`008Woo1P00;goo000QOol00`00Oomoo`08
Ool01@00Bcm;?d/o0000TT/o1P008Woo1P00:Goo000QOol00`00Oomoo`08Ool01@00Bcm;?d/o0000
V4/o1`008Goo1`008Woo000POol00`00Oomoo`08Ool00`00Bcm;?`02Bcl00`00Bcm;?`2MBcl6000R
Ool6000LOol001moo`03001oogoo00Uoo`03001;?d/o009;?`03001;?d/o0:=;?`L0025oo`H001Io
o`007goo00<007ooOol027oo00<004/oBcl00d/o00<004/oBcl0ZT/o1`0087oo10004Woo000NOol0
0`00Oomoo`09Ool00`00Bcm;?`03Bcl00`00Bcm;?`2aBcl6000LOol2000BOol001ioo`03001oogoo
00Qoo`03001;?d/o00A;?`03001;?d/o0;M;?`L001=oo`800003Ool007oo015oo`007Goo00<007oo
Ool027oo00<004/oBcl01D/o00<004/oBcl0_T/o1P0037oo00D007ooOomoo`00019oo`007Goo00<0
07ooOol027oo00<004/oBcl01D/o00<004/oBcl0a4/o10001goo00<007ooOol00Woo00<007ooOol0
47oo000LOol00`00Oomoo`08Ool00`00Bcm;?`06Bcl00`00Bcm;?`36Bcl00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`0@Ool001aoo`03001oogoo00Qoo`03001;?d/o00I;?`03001;?d/o0<E;
?`03001oogoo00Aoo`8000Ioo`03001oogoo011oo`006goo00<007ooOol027oo00<004/oBcl01d/o
00<004/oBcl0`d/o00<007ooOol01Goo00<007ooOol01Woo00<007ooOol047oo000KOol00`00Oomo
o`08Ool00`00Bcm;?`07Bcl00`00Bcm;?`32Bcl00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomo
o`0@Ool001Yoo`03001oogoo00Qoo`03001;?d/o00Q;?`03001;?d/o00=;?`03O01;?d/o0;];?`03
001oogoo00Eoo`03001oogoo00Qoo`03001oogoo011oo`006Woo00<007ooOol01goo00<004/oBcl0
24/o00<004/oBcl00d/o0g`0^d/o00<007ooOol017oo0P0037oo00<007ooOol03goo000IOol00`00
Oomoo`08Ool00`00Bcm;?`08Bcl00`00Bcm;?`03Bcl4O02hBcl20006Ool00`00Oomoo`0<Ool00`00
Oomoo`0?Ool001Uoo`03001oogoo00Moo`03001;?d/o00U;?`03001;?d/o009;?`Il0;I;?`03001o
ogoo00Eoo`03001oogoo00eoo`03001oogoo00moo`0067oo00<007ooOol027oo00<004/oBcl02D/o
00<004/oBcl00T/o0g`000=;?g`0O000]D/o00<007ooOol01Goo00<007ooOol03Woo00<007ooOol0
3goo000GOol00`00Oomoo`08Ool00`00Bcm;?`0:Bcl01000Bcm;?d/o17`00T/o0W`0/d/o00<007oo
Ool017oo0P004Goo00<007ooOol03goo000GOol00`00Oomoo`08Ool00`00Bcm;?`0:Bcl01P00Bcm;
?d/oO01;?`9l009;?`=l0;5;?`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00moo`005Woo
00<007ooOol027oo00<004/oBcl02d/o00<004/oBcl00W`000=;?g`0O0000d/o0g`0[T/o0P001Woo
00<007ooOol04Woo00<007ooOol03goo000FOol00`00Oomoo`07Ool00`00Bcm;?`0<Bcl01000Bcml
07`00T/o0W`014/o0g`0[4/o00<007ooOol01Goo00<007ooOol04goo00<007ooOol03goo000EOol0
0`00Oomoo`08Ool00`00Bcm;?`0<Bcl00`00Bcml0003Bcl2O005Bcl3O02ZBcl00`00Oomoo`04Ool2
000FOol00`00Oomoo`0?Ool001Eoo`03001oogoo00Moo`03001;?d/o00e;?`03001l07`000=;?`9l
00I;?`=l0:Q;?`03001oogoo00Aoo`03001oogoo01Ioo`03001oogoo00moo`0057oo00<007ooOol0
27oo00<004/oBcl03D/o00<007`0Bcl00d/o0W`01d/o0W`0Yd/o00<007ooOol017oo00<007ooOol0
5goo00<007ooOol03goo000DOol00`00Oomoo`07Ool00`00Bcm;?`0>Bcl00`00Bcm;?`03Bcl2O008
Bcl2O02TBcl20006Ool00`00Oomoo`0HOol00`00Oomoo`0?Ool001=oo`03001oogoo00Qoo`03001;
?d/o00e;?`03O00004/o00A;?`9l00Q;?`=l0:9;?`03001oogoo00Aoo`8001]oo`03001oogoo00mo
o`004goo00<007ooOol01goo00<004/oBcl03D/o0W`000<004/oBcl00d/o0W`02D/o0g`0X4/o00<0
07ooOol017oo00<007ooOol06goo00<007ooOol03goo000BOol00`00Oomoo`07Ool00`00Bcm;?`0>
Bcl00g`0Bcl00004Bcl2O00;Bcl3O02NBcl00`00Oomoo`04Ool00`00Oomoo`0LOol00`00Oomoo`0?
Ool0019oo`03001oogoo00Moo`03001;?d/o00e;?`9l0003Bcl004/o00=;?`9l00a;?`=l08M;?`<0
019;?`03001oogoo00Aoo`03001oogoo01eoo`03001oogoo00moo`004Goo00<007ooOol01goo00<0
04/oBcl03T/o00Al04/oBcl000A;?`9l00e;?`9l085;?`H000=8Y`8000i;?`8000Ioo`03001oogoo
01ioo`03001oogoo00moo`004Goo00<007ooOol01goo00<004/oBcl03D/o0W`00T/o00<004/oBcl0
0T/o0W`03T/o0W`0O4/o10002DRW00@005c0000000];?`03001oogoo00Aoo`80025oo`03001oogoo
00moo`0047oo00<007ooOol01goo00<004/oBcl03D/o0W`00d/o00<004/oBcl00T/o0W`03T/o0g`0
N4/o100000<`K000B:L02TRW00<005c0G<000P0024/o00<007ooOol017oo00<007ooOol08Goo00<0
07ooOol03goo000@Ool00`00Oomoo`07Ool00`00Bcm;?`0=Bcl00g`0Bcm;?`02Bcl00`00Bcm;?`02
Bcl2O00?Bcl3O01dBcl60002<6`00`00B:M8Y`0:B:L01000G<1L`5c00P001D/o00<007ooOol017oo
00<007ooOol08goo00<007ooOol03Woo000?Ool40006Ool00`00Bcm;?`0=Bcl2O004Bcl00`00Bcm;
?`02Bcl2O00@Bcl3O01`Bcl80004<6`00`00B:M8Y`09B:L00`00G<1L`003G<001@00Bcm;?d/o0000
1Woo00<007ooOol097oo00<007ooOol03Woo000?Ool01000Oomoogoo1P003d/o0W`01D/o00<004/o
Bcl00T/o0W`04D/o0g`0KD/o2@001S1/00<004RWB:L02DRW00<005c0G<000ec00`001Goo0P009goo
00<007ooOol03Woo000?Ool00`00Oomoo`06Ool00`00Bcm;?`0=Bcl00g`0Bcm;?`04Bcl00`00Bcm;
?`02Bcl2O00BBcl3O01[Bcl:0007<6`00`00B:M8Y`09B:L00`00G<1L`002G<000`00Oomoo`04Ool0
0`00Oomoo`0WOol00`00Oomoo`0>Ool000moo`03001oogoo00Eoo`03001;?d/o00e;?`9l00I;?`03
001;?d/o009;?`9l01=;?`9l06Y;?`X000P`K0030018YdRW00U8Y`03001L`5c000=L`003001oogoo
009oo`03001oogoo02Qoo`03001oogoo00ioo`003goo00<007ooOol01Goo00<004/oBcl034/o0W`0
1d/o00<004/oBcl00T/o0W`054/o0W`0J4/o2P002S1/00<004RWB:L02DRW00<005c0G<000ec000@0
07ooOol002]oo`03001oogoo00ioo`003goo00<007ooOol017oo00<004/oBcl03D/o00=l04/oBcl0
1T/o00<004/oBcl00T/o0W`054/o0g`0Id/o2@00331/00<004RWB:L02DRW00<005c0G<000ec00P00
;7oo00<007ooOol03Woo000?Ool00`00Oomoo`04Ool00`00Bcm;?`0<Bcl2O008Bcl00`00Bcm;?`02
Bcl2O00EBcl3O01UBcl800000`P_0000000;<6`00`00B:M8Y`09B:L00`00G<1L`003G<000`00Oomo
o`0[Ool00`00Oomoo`0>Ool000moo`03001oogoo00=oo`D000];?`03O01;?d/o00M;?`04001;?d/o
Bcl2O00GBcl3O01SBcl5000522l2000<<6`00`00B:M8Y`09B:L00`00G<1L`003G<000`00Oomoo`0Z
Ool00`00Oomoo`0>Ool000moo`03001oogoo00Qoo`P0009;?`9l00U;?`04001;?d/oBcl2O00HBcl3
O01QBcl2000822l0100022l8;`00331/00<004RWB:L02DRW00<005c0G<000ec000<007ooOol0:Goo
00<007ooOol03Woo000?Ool00`00Oomoo`0@Ool00`00O01l00050005Bcl01000Bcm;?d/o0W`06D/o
0g`0Gd/o0P002@P_00D000P_22l8;`0000``K0030018YdRW00Q8Y`03001L`5c000=L`003001oogoo
02Uoo`03001oogoo00ioo`003goo00<007ooOol04Goo00=l07ooOol017oo200000=;?g`0O0006T/o
0W`0Gd/o0P002@P_00D000P_22l8;`0000``K0030018YdRW00A8Y`L000AL`003001oogoo02Qoo`03
001oogoo00ioo`003Woo00<007ooOol04Goo0W`02Woo00D007ooOomoo`00009l00D001I;?`9l05e;
?`030008;`0000T8;`030008;`P_0088;`03000`K31/00X`K0H000EId@04001^D0000003G<000`00
Oomoo`0WOol00`00Oomoo`0>Ool000ioo`03001oogoo011oo`9l00]oo`03001oogoo009oo`9l00Eo
o`P000i;?`=l05a;?`030008;`0000T8;`030008;`P_00<8;`03000`K31/00L`K0<000YId@04001^
D6i@KU020002G<000`00Oomoo`0VOol00`00Oomoo`0>Ool000ioo`03001oogoo011oo`03O01oogoo
00Yoo`03001oogoo009oo`9l00eoo`P000M;?`=l05Y;?`040008;`P_000822l00`0022l8;`0422l0
0`00<6``K006<6`01000@E91DP002UWA00<006i@KU000fi@0`00:7oo00<007ooOol03Woo000>Ool0
0`00Oomoo`0?Ool2O00<Ool00`00Oomoo`02Ool2O00EOol80003O01IBcl0100022l8;`0020P_00<0
00P_22l01@P_00<0031/<6`00c1/0P000d5B00<005WAFM402EWA00<006i@KU0016i@0P009goo00<0
07ooOol03Woo000>Ool00`00Oomoo`0>Ool2O00=Ool00`00Oomoo`02Ool2O00MOol01000O01l07`0
1000Dd/o00D000P_22l8;`0000L8;`8000P8;`05000`K31/<6`00006@E800`00FM5Id@08FM400`00
KU1^D005KU000`00Oomoo`0UOol00`00Oomoo`0>Ool000ioo`03001oogoo00ioo`03O01oogoo00ao
o`03001oogoo009oo`9l01moo`9l00Aoo`P004];?`050008;`P_22l0000422l300000aEI00000007
22l01000<6`000001d5B00<005WAFM4025WA00<006i@KU001Fi@0P009Woo00<007ooOol03Woo000>
Ool00`00Oomoo`0=Ool2O00>Ool00`00Oomoo`02Ool2O00POol2O00;Ool80012Bcl00`0022l8;`02
22l00`0022l0000200055ET00`0022l8;`0622l00`00@E91DP07@E800`00FM5Id@08FM400`00KU1^
D005KU02000WOol00`00Oomoo`0=Ool000ioo`03001oogoo00eoo`03O01oogoo00eoo`03001oogoo
009oo`9l021oo`=l019oo`P003Y;?`030008;`P_0088;`8000PEF@8000L8;`030011DT5B00M1DP03
001IdEWA00QId@03001^D6i@00I^D003001oogoo02Eoo`03001oogoo00eoo`003Woo00<007ooOol0
37oo0W`03goo00<007ooOol00Woo0W`08Goo0g`06Goo2000<D/o00<000P_22l00PP_00<003WI0000
2AEI00<000P_22l010P_0P002D5B00<005WAFM4025WA00<006i@KU001Vi@0P009Woo00<007ooOol0
3Goo000>Ool00`00Oomoo`0;Ool2O00@Ool01000Oomoogoo0W`08goo0g`087oo2000:D/o00<000P_
22l00PP_00<003WI00002AEI0P001@P_0P002D5B00<005WAFM402EWA00<006i@KU001Fi@0P009Woo
00<007ooOol03Goo000>Ool00`00Oomoo`0;Ool00g`0Oomoo`0?Ool01000Oomoogoo0W`097oo0g`0
9goo200084/o00<000P_22l00PP_00D003WI>MTif@0000PEF@8000@8;`030008;`0000U1DP03001I
dEWA00UId@03001^D6i@00E^D003001fQ00002Eoo`03001oogoo00eoo`003Woo00<007ooOol02Woo
0W`04Goo00@007ooOomoo`9l02Eoo`=l02ioo`P001Q;?`030008;`P_0088;`03000ifCWI008if@03
000EFAEI00HEF@8000<8;`040008;`P_0008@E800`00FM5Id@09FM400`00KU1^D005KU000`00MX@0
000UOol00`00Oomoo`0=Ool000ioo`03001oogoo00Uoo`9l019oo`04001oogooOol2O00VOol2O00f
Ool8000?Bcl00`0022l8;`0222l00`00>MTif@03>MT00`005ETEF@065ET2000222l01@0022l8;`P_
00002D5B00<005WAFM4025WA00<006i@KU001Fi@00<007J400009Goo00<007ooOol03Goo000>Ool0
0`00Oomoo`09Ool00g`0Oomoo`0AOol01000Oomoogoo0W`09goo0W`0?Goo20001d/o00D000P_22l8
;`0000Lif@03000EFAEI00HEF@80000322l000P_0088;`030011DT5B00M1DP03001IdEWA00QId@03
001^D6i@00E^D003001fQ00002Eoo`03001oogoo00eoo`003Woo00<007ooOol027oo0W`04goo00@0
07ooOomoo`9l02Moo`=l009oo`/003Moo`L000@8;`03000ifCWI00Hif@03000EFAEI00@EF@@000@8
;`030011DT5B00M1DP03001IdEWA00QId@03001^D6i@00E^D003001fQ00002Eoo`03001oogoo00eo
o`003Woo00<007ooOol01goo0W`057oo00@007ooOomoo`9l02Qoo`=l0003Ool0000000]Da1@002Mo
o`050008;`P_22l00009>MT00`005ETEF@0400026Wh2000422l00`00@E91DP07@E800`00FM5Id@08
FM400`00KU1^D006KU000`00MX@0000TOol00`00Oomoo`0=Ool000ioo`03001oogoo00Moo`03O01o
ogoo01=oo`04001oogooOol2O00YOol3O0000`00;C@0000NE<@F000@Ool2000222l00`00>MTif@09
>MT200066Wh2000422l00`00@E91DP07@E800`00FM5Id@09FM400`00KU1^D005KU000`00MX@0000T
Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Ioo`9l01Eoo`04001oogooOol2O00ZOol3O002;C@;
000YE<@F0009>MT00`00C[a>_00200056Wh00`0022l8;`0222l00`00@E91DP07@E800`00FM5Id@09
FM400`00KU1^D005KU000`00MX@0000TOol00`00Oomoo`0=Ool000ioo`03001oogoo00Ioo`03O01o
ogoo01Aoo`04001oogooOol2O00[Ool3O0000bdd001[6@09JaTF000YE<@<0002C[`300026Wh00`00
22l8;`0222l00`00@E91DP07@E800`00FM5Id@09FM400`00KU1^D005KU000`00MX@0000TOol00`00
Oomoo`0=Ool000ioo`03001oogoo00Eoo`9l01Ioo`04001oogooOol2O00[Ool01@00O01l07`00000
86/I5P007eC400<004jlC[`00Tjl0`0010P_00<0045B@E80245B00<005WAFM4025WA00<006i@KU00
1Fi@00<007J4000097oo00<007ooOol03Goo000>Ool00`00Oomoo`03Ool3O00GOol01000Oomoogoo
0W`0:Woo00El0000O01l000003M[6AH000YDa003001>_4jl00=>_0030008;`P_00<8;`030011DT5B
00M1DP03001IdEWA00QId@03001^D6i@00E^D003001fQ00002Aoo`03001oogoo00eoo`003Woo00<0
07ooOol00goo27`04Woo00@007ooOomoo`9l02Qoo`El0003;C@006/I04a[6@`000A>_08000@8;`03
0011DT5B00M1DP03001IdEWA00QId@03001^D6i@00E^D004001fQ7J4000SOol00`00Oomoo`0=Ool0
00eoo`03001oogoo00Aoo`il00aoo`03001oogoo009l02Qoo`El0003Ool0000005Q[6@03001>_4jl
009>_08000@8;`030011DT5B00M1DP03001IdEWA00UId@03001^D6i@00E^D003001fQ00002=oo`03
001oogoo00eoo`003Goo00<007ooOol017oo0W`01Woo37`01Woo00<007ooOol00W`09Woo17`000=o
og`0Ool00Woo00<007`000003000BF/I00<004jlC[`00Tjl00<005mn000010P_00<0045B@E801d5B
00<005WAFM402EWA00<006i@KU001Fi@00<007J400008goo00<007ooOol03Goo000=Ool00`00Oomo
o`04Ool2O00<Ool<O0000`00Oomoo`02O00UOol4O0000gooO01l0003Ool3O00900000dcY0000000M
000/JaT01@00C[a>_4jl00000Umn00<000P_22l00PP_00<0045B@E801d5B00<005WAFM402EWA00<0
06i@KU001Fi@00<007J400008goo00<007ooOol03Goo000=Ool00`00Oomoo`04Ool2O00BOol6O000
0`00O01l0003O00ROol4O0020002O0020002C>T3O00HC>T^000:JaT60002C[`01@00GgiOOUmn0000
10P_00<0045B@E801d5B00<005WAFM402EWA00<006i@KU001Fi@00<007J4000097oo00<007ooOol0
37oo000=Ool00`00Oomoo`04Ool2O00HOol00`00O01l0009O00GOol01000C>U<jDcY17`00dcY00=l
04cYC>T014cY0W`034cY30008Uji70000Tjl00D005mnGgiOOP0000@8;`030011DT5B00M1DP03001I
dEWA00UId@03001^D6i@00E^D003001fQ00002Aoo`03001oogoo00aoo`003Goo00<007ooOol017oo
0W`067oo00<007ooOol00W`000=oog`0O0002W`04Goo00<004cYO0000g`014cY0W`01TcY0g`02`00
75ji200000=<j@00G[T03Uji5@0000=>_000Ggh00emn00<000P_22l00PP_00<0045B@E80245B00<0
05WAFM4025WA00<006i@KU001Fi@00<007J4000097oo00<007ooOol037oo000=Ool00`00Oomoo`04
Ool2O00GOol01000Oomoogoo0W`01goo37`02goo00<007`0O0000W`00TcY0`0000=l000000001P00
0W`0<eji3@0000<8;`00AOL01dGg00@005JIEYUFV@H00003HU@005mn00AOOP030008;`P_00<8;`03
0011DT5B00M1DP03001IdEWA00UId@03001^D6i@00A^D004001fQ7J4000SOol00`00Oomoo`0<Ool0
00eoo`03001oogoo00Aoo`9l01Moo`04001oogooOol2O00=Ool<O005Ool3O0040002G[T2O008G[T3
O00UG[T=000;Ool0100022l8;`0024Gg00<005JIEYT01P000V9D00@005mnGgiOOP<000D8;`030011
DT5B00M1DP03001IdEWA00UId@03001^D6i@00A^D004001fQ7J4000SOol00`00Oomoo`0<Ool000eo
o`03001oogoo00Aoo`9l01Moo`04001oogooOol2O00COol=O006G[T2O00:G[T2O00HG[T=000HOol0
100022l8;`0024Gg00@005JI0011]@D0009RE0@0009W6@030008;`P_00<8;`030011DT5B00E1DPP0
00IId@03001^D6i@00E^D003001fQ00002=oo`03001oogoo00aoo`003Goo00<007ooOol017oo0W`0
5goo00@007ooOomoo`9l01Qoo`Ql00IN^@03O01N^Eji00UN^@9l00]N^@d002Aoo`040008;`P_0009
AOL00`00EYT000050003HU@00`00IaUW6@03IaT2000422l00`00@E91DP050002AKD00`00FUIJEP03
FUH80006KU000`00MX@0000SOol00`00Oomoo`0<Ool000eoo`03001oogoo00Aoo`9l01Moo`04001o
ogooOol2O00LOol2O0000`00G[UN^@04G[T2O00;G[T3O00:000aOol0100022l8;`0024Gg00@005JI
0011]@D000ARE003001W6FLI00=W6@030008;`P_0088;`<000M5]@03001JEUYF00UJEP03001ZeP00
00<0009^D003001fQ00002=oo`03001oogoo00aoo`003Goo00<007ooOol017oo0W`05goo00@007oo
Oomoo`9l01aoo`03O01oo`0000EN^@9l00`00003Ooml07`003]oo`040008;`P_0008AOL200000d6e
000000040004HU@00`00IaUW6@03IaT0100022l8;`P_0P002DFe00<005YFFUH02EYF00<006[FJ]H0
0f[F0`000WJ48goo00<007ooOol037oo000=Ool00`00Oomoo`04Ool2O00GOol01000Oomoogoo0W`0
6goo0W`000Aoo`00O01l00<00003O01oogoo00aoo`9l03Yoo`050008;`P_22l00008AOL00`00@KEF
V@060004HU@00`00IaUW6@03IaT01P0022l0000022l000U5]@03001JEUYF00UJEP03001ZeV[F00EZ
eP800003MX@007oo025oo`03001oogoo00aoo`003Goo00<007ooOol017oo0W`05goo00<007ooOol0
0W`077oo00Al07ooOomoo`9l009oo`9l00ioo`=l03Uoo`040008;`P_0008AOL20002@KD400000d6e
001RE003HU@00`00IaUW6@02IaT3000322l00`00AKE5]@06AKD00`00FUIJEP0:FUH00`00J]IZeP05
J]H200000gJ4001oo`0QOol00`00Oomoo`0<Ool000eoo`03001oogoo00Aoo`9l01Moo`03001oogoo
009l01]oo`9l00=oo`El011oo`9l03Uoo`040008;`P_0008AOL00`00@KE1]@0500000d6e001RE004
HU@01000IaUW6FLI0P0010P_00<004FeAKD01TFe00<005YFFUH02EYF00<006[FJ]H01V[F00@007m`
0000029oo`03001oogoo00aoo`003Goo00<007ooOol017oo0W`05goo00<007ooOol00W`06Woo0W`0
1Woo0W`04Goo0W`0>Goo00@000P_22l000M5m`040011]EJI@KD500000d6e001RE004HU@01000IaUW
6FLI0P0010P_00<004FeAKD01TFe00<005YFFUH02EYF00<006[FJ]H01V[F00@007m`Og00029oo`03
001oogoo00aoo`003Goo00<007ooOol017oo0W`05goo00<007ooOol00W`06Goo0W`01goo0g`047oo
0g`0=goo00D000P_22l8;`0000I5m`040011]D6e@KD50002@KD00`00HUARE003HU@01P00IaUW6@00
NmD000<8;`030015]DFe00M5]@03001JEUYF00UJEP03001ZeV[F00IZeP04001oL7m`000ROol00`00
Oomoo`0<Ool000eoo`03001oogoo00Aoo`9l01Moo`03001oogoo009l01Uoo`03O01oogoo00Eoo`9l
0003Ooml07oo011oo`9l03Moo`040008;`P_0007AOL01000@KEFVD6e1@0000=1]@00HU@01F9D00H0
06LIIaT007_E000322l00`00AKE5]@07AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1oL000
8Woo00<007ooOol037oo000=Ool00`00Oomoo`04Ool2O00GOol00`00Oomoo`02O00HOol2O007Ool0
0g`0Oomoo`02O00@Ool3O00fOol010P_000000001TGg00@0046e@KE1]@D00091]@03001RE69D00ER
E005001W6@00NmD0000322l00`00AKE5]@07AKD00`00FUIJEP09FUH00`00J]IZeP05J]H01@00Og1o
L7m`00008Woo00<007ooOol037oo000=Ool00`00Oomoo`04Ool2O00GOol00`00Oomoo`02O00GOol2
O007Ool2O003Ool00g`0Oomoo`0?Ool2O00fOol322l20004AOL00`00@KE1]@02@KD50002@KD00`00
HUARE005HU@20002NmD01@0022l8;`P_00002DFe00<005YFFUH02EYF00<006[FJ]H01F[F00D007m`
Og1oL000029oo`03001oogoo00aoo`003Goo00<007ooOol017oo0W`05goo00<007ooOol00W`05goo
00=l07ooOol01Woo00=l07ooOol00Woo0W`047oo0W`0=Woo0`P_00<004Fe0000100000A1]@00@KE1
]@@000=1]@03001RE69D00ERE080009ke@050008;`P_22l00009AKD00`00FUIJEP09FUH00`00J]IZ
eP05J]H01@00Og1oL7m`00008Woo00<007ooOol037oo000<Ool00`00Oomoo`05Ool2O00GOol00`00
Oomoo`02O00FOol2O007Ool2O005Ool00g`0Oomoo`0>Ool3O00eOol322l00`00AKE5]@02AKD00`00
@KE1]@02@KD50003@KD00`00HUARE005HU@200000g_E0008;`0322l00`00AKE5]@07AKD00`00FUIJ
EP09FUH00`00J]IZeP05J]H01000Og1oL0008goo00<007ooOol037oo000<Ool00`00Oomoo`05Ool2
O00GOol00`00Oomoo`02O00EOol2O007Ool2O006Ool2O00@Ool2O00dOol01@0022l8;`P_00000dFe
00<0046e@KD00d6e1@000d6e00<0069DHU@01V9D00<007_E000010P_00<004FeAKD01dFe00<005YF
FUH02EYF00<006[FJ]H01F[F00@007m`Og0002Aoo`03001oogoo00]oo`0037oo00<007ooOol01Goo
0W`05goo00<007ooOol00W`05Goo00=l07ooOol01Woo00=l07ooOol01Woo0W`03goo0W`0=7oo00@0
00P_22l000A5]@030011]D6e0091]@D000A1]@03001RE69D00IRE0<000@8;`030015]DFe00I5]@03
001JEUYF00YJEP03001ZeV[F00EZeP04001oL7m`000TOol00`00Oomoo`0;Ool000aoo`03001oogoo
00Eoo`9l01Moo`03001oogoo009l01Aoo`9l00Moo`9l00Uoo`03O01oogoo00eoo`=l03=oo`040008
;`P_0003AKD00`00@KE1]@03@KD50004@KD00`00HUARE006HU@00`00Og80000422l00`00AKE5]@06
AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1oL00097oo00<007ooOol02goo000<Ool00`00
Oomoo`05Ool2O004Ool6000=Ool00`00Oomoo`02O00COol2O007Ool2O00:Ool2O00?Ool2O00cOol0
100022l8;`000TFe00<0046e@KD00d6e1@00146e00<0069DHU@01f9D00<007mb000010P_00<004Fe
AKD01TFe00<005YFFUH02EYF00<006[FJ]H01V[F00@007m`Og0002Aoo`03001oogoo00]oo`0037oo
00<007ooOol01Goo0W`00goo1P000d0020000goo00<007ooOol00W`04goo00=l07ooOol01Woo00=l
07ooOol02Woo00=l07ooOol03Goo0W`0<goo00H000P_22l004Fe0006@KD50004@KD00`00HUARE008
HU@2000422l00`00AKE5]@06AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1oL00097oo00<0
07ooOol02goo000<Ool00`00Oomoo`05Ool2O003Ool20005HU@80002@0050002O003000@Ool2O007
Ool2O00<Ool2O00>Ool3O00bOol01P0022l8;`00AKD000E1]@D000E1]@03001RE69D00QRE08000<8
;`030015]DFe00M5]@03001JEUYF00UJEP03001ZeV[F00IZeP04001oL7m`000TOol00`00Oomoo`0;
Ool000aoo`03001oogoo00Eoo`9l009oo`0300002P0000eRE0L0009l00=000X000Ioo`03O01oogoo
00Eoo`9l00ioo`03O01oogoo00eoo`9l039oo`030008;`P_00800091]@04AKE1]D6e@KD50005@KD0
0`00HUARE008HU@2000322l00`00AKE5]@07AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1o
L00097oo00<007ooOol02goo000<Ool00`00Oomoo`05Ool2O002Ool00`0000X0000BHU@01000HUAl
07`020001D001@000W`00`0017oo00=l07ooOol03Goo0W`03Woo0g`0<Goo00@000P_22l000M1]@@0
00E1]@D000MRE08000<8;`030015]DFe00M5]@03001JEUYF00UJEP03001ZeV[F00IZeP04001oL7m`
000TOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`9l009oo`0300002P00019RE004001RE7`0
O008HU@90002O004@0030002O005000;Ool2O00>Ool2O00aOol0100022l8;`001d6e10000T6e1000
0f9D200000=RE00022l00PP_00<004FeAKD01dFe00<005YFFUH02EYF00<006[FJ]H01F[F00D007m`
Og1oL00002Aoo`03001oogoo00]oo`0037oo00<007ooOol01Goo0W`00Woo00<0000:00004V9D00@0
069DO01l015RE003O000000000D0009l00I000H000Ioo`03O01oogoo00aoo`9l031oo`040008;`P_
0007@KD700000cLo0000000:HU@4000322l00`00AKE5]@07AKD00`00FUIJEP09FUH00`00J]IZeP05
J]H01000Og1oL0009Goo00<007ooOol02goo000<Ool00`00Oomoo`05Ool2O002Ool00`0000X00005
000=HU@01000HUAl07`0469D0W`01f9D00=l000000001`000d0000<007ooOol017oo0W`03Goo0g`0
;goo00<000P_0000246e10000cLo00<0069DHU@02F9D1@000`P_00<004FeAKD01TFe00<005YFFUH0
2UYF00<006[FJ]H01F[F00@007m`Og0002Eoo`03001oogoo00]oo`0037oo00<007ooOol01Goo0W`0
0Woo00<0000:00001Ekk2P000f9D00@0069DO01l011RE003O01RE69D00ERE09l00URE0D000Ioo`03
O01oogoo00aoo`9l02moo`030008;`0000E1]@L0008g?`03001RE69D00IRE0D0009oLP8000<8;`03
0015]DFe00I5]@03001JEUYF00YJEP03001ZeV[F00EZeP04001oL7m`000UOol00`00Oomoo`0;Ool0
00aoo`03001oogoo00Eoo`9l009oo`80011Nn`D0009l00<000aRE09l00MRE003O01RE69D00aRE003
001oogoo00Aoo`9l00eoo`9l02moo`800003@KD0000000D00003=cl0000000@000IRE0<000AZ]P04
001oLWmb000422l00`00AKE5]@06AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1oL0009Goo
00<007ooOol02goo000<Ool00`00Oomoo`05Ool2O002Ool2000BG_/00`00G_]Nn`02O003G_/;0002
O007HU@2O00>HU@00`00Oomoo`05Ool2O00<Ool3O00^Ool01000@KE1]@0013C?00<005Wc00001@00
169D0`001fZf00@007mbOg8000@8;`030015]DFe00I5]@03001JEUYF00UJEP03001ZeV[F00IZeP04
001oL7m`000UOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`9l00=oo`H000eNn`03001Nnekk
009l00iNn`03O000000000D0009l00mRE00300007`0O00H07`03O0007`0O00/07`9l02l07`8000@d
c`03001IleWc00=Il`800003HU@0000000800003FUH006Zf00MZ]P04001oLWmb000422l00`00AKE5
]@06AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1oL0009Goo00<007ooOol02goo000<Ool0
0`00Oomoo`05Ool2O009Ool:0003G_/00`00G_]Nn`02O00=G_/2O007G_/00g`0G_/000090005HU@0
0`0001l07`0601l2O00<01l2O00_01l20004=<l00`00FO=Il`04FO<20005FUH00`00J[IZ]P06J[H0
1000Og9oLP0010P_00<004FeAKD01TFe00<005YFFUH02EYF00<006[FJ]H01V[F00@007m`Og0002Eo
o`03001oogoo00]oo`0037oo00<007ooOol01Goo0W`04goo1P000W`00P002ekk00=l05kkG_/01Ekk
0W`02ekk1P002@0O00=l000O01l02P0O0g`0;P0O00<003C?=<l00SC?00<005WcFO<015Wc00<006je
K[D00P000eYF00<006ZfJ[H01VZf00@007mbOg8000<8;`030015]DFe00M5]@03001JEUYF00UJEP03
001ZeV[F00IZeP04001oL7m`000UOol00`00Oomoo`0;Ool000aoo`03001oogoo00Eoo`9l01Ioo`03
001oogoo009l009oo`X0009l00INn`9l015Nn`0300007`0O00L07`9l00`07`9l02h07`03000dccC?
008dc`03001IleWc00AIl`03001^]Fje009^]@04001JEUYF0008J[H01000Og9oLP000`P_00<004Fe
AKD01dFe00<005YFFUH02EYF00<006[FJ]H01V[F00@007m`Og0002Eoo`03001oogoo00]oo`0037oo
00<007ooOol01Goo0W`05Woo00@007ooO01l00aoo`9l00L00003O000000000mNn`03001oogoo00Uo
o`03O01oogoo00Yoo`=l02aoo`8000@dc`03001IleWc00=Il`03001^]Fje00=^]@D000MZ]P04001o
LP00000322l00`00AKE5]@07AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1oL0009Woo00<0
07ooOol02Woo000<Ool00`00Oomoo`05Ool2O00FOol01000Ooml07`037oo00=l07ooOol01Goo0W`0
0Woo2@001Ukk00<007ooOol02Goo0W`037oo0W`0:goo0P0013C?00<005WcFO<015Wc00<006jeK[D0
0fje00D005WbFO8006YA00@0009Z]P06001oLWmb0008;`000PP_00<004FeAKD01dFe00<005YFFUH0
2EYF00<006[FJ]H01V[F00@007m`Og0002Ioo`03001oogoo00Yoo`002goo00<007ooOol01Woo0W`0
5Woo00@007ooO01l00]oo`9l00Ioo`9l00eoo`H000aoo`9l00]oo`9l02]oo`8000@dc`03001IleWc
00AIl`03001^]Fje009^]@80009IlP03001ZDFYA00=ZD@<0009oLP030008;`P_00<000Q5]@03001J
EUYF00YJEP03001ZeV[F00EZeP04001oL7m`000WOol00`00Oomoo`0:Ool000]oo`03001oogoo00Io
o`9l01Ioo`04001oog`0O00:Ool2O007Ool00g`0Oomoo`0OOol00g`0Oomoo`09Ool3O00ZOol00`00
=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@03K[D01G>>001IlUWb00001fYA0P0000=oLP0022l0
0`P_0P001dFe00<005YFFUH02UYF00<006[FJ]H01F[F00@007m`Og0002Moo`03001oogoo00Yoo`00
2goo00<007ooOol01Woo0W`05Woo00@007ooO01l00Yoo`03O01oogoo00Eoo`9l025oo`9l00]oo`9l
02Yoo`03000dccC?008dc`03001IleWc00AIl`03001^]Fje009^]@03001cSUWb00=IlP03001ZDFYA
00AZD@04001nb@00000422l2@ML30004AKD00`00FUIJEP09FUH00`00J]IZeP06J]H01000Og1oL000
9goo00<007ooOol02Woo000;Ool00`00Oomoo`06Ool2O00FOol01000Ooml07`02Goo0W`01Woo0W`0
8goo00=l07ooOol02Goo0W`0:Woo00<003C?=<l00SC?00<005WcFO<00eWc00<006jeK[D00fje0P00
15Wb00<006YAJU4016YA00<007k9000010P_00<0047G@ML00d7G0`0000=5]@00FUH02UYF00<006[F
J]H01V[F00@007m`Og0002Moo`03001oogoo00Yoo`002goo00<007ooOol01Woo0W`05Woo00@007oo
O01l00Qoo`9l00Moo`03O01oogoo029oo`9l00Yoo`=l02Qoo`03000dccC?008dc`03001IleWc00AI
l`03001^]Fje009^]@03001cSUWb00AIlP03001ZDFYA00AZD@03001nb@0000@8;`030011ed7G00I1
e`@000UJEP03001ZeV[F00IZeP04001oL7m`000WOol00`00Oomoo`0:Ool000]oo`03001oogoo00Io
o`9l01Ioo`04001oog`0O008Ool00g`0Oomoo`05Ool2O00UOol2O00:Ool2O00XOol00`00=<ldc`02
=<l00`00FO=Il`04FO<00`00K[E^]@02K[D00`00LhiIlP04FO800`00JU5ZD@05JU42000422l00`00
@MM1e`07@ML00`00EYUFV@060003FUH00`00J]IZeP06J]H01000Og0000009goo00<007ooOol02Woo
000;Ool00`00Oomoo`06Ool2O00FOol01000Ooml07`01goo0W`01goo00=l07ooOol09Goo00=l07oo
Ool027oo0W`09goo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00fje0P001EWb00<006YA
JU401FYA00<000P_22l00PP_00<0047G@ML01d7G00<005JIEYT01eJI3P0000=gd`00Ool09Woo00<0
07ooOol02Woo000;Ool00`00Oomoo`06Ool2O00FOol01000Ooml07`01goo00=l07ooOol01Goo0W`0
9goo0W`02Goo0g`09Woo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00Vje00<007>>FO80
1EWb00<006YAJU401FYA00<000P_22l00PP_00<0047G@ML01d7G00<005JIEYT02UJI00<006/jJcX0
1V/j00<007OC0000:7oo00<007ooOol02Woo000;Ool00`00Oomoo`06Ool2O00FOol01000Ooml07`0
1Woo0W`01Woo0W`0:Goo00=l07ooOol027oo0W`09Woo00<003C?=<l00SC?00<005WcFO<00eWc00<0
06jeK[D00fje0P001UWb00<006YAJU401FYA00<000P_22l00PP_00<0047G@ML01d7G00<005JIEYT0
2EJI00<006/jJcX01V/j00@007OCMm<002Qoo`03001oogoo00Yoo`002goo00<007ooOol01Woo0W`0
5Woo00@007ooO01l00Eoo`9l00Moo`03O01oogoo02Qoo`9l00Uoo`9l02Eoo`03000dccC?008dc`03
001IleWc00AIl`03001^]Fje009^]@03001cSP0000IIlP03001ZDFYA00AZD@030008;`P_0088;`03
0011ed7G00M1e`03001FVEJI00YFV@03001[>V/j00I[>P04001gdgOC000XOol00`00Oomoo`0:Ool0
00]oo`03001oogoo00Ioo`9l01Ioo`04001oog`0O005Ool00g`0Oomoo`05Ool2O00[Ool00g`0Oomo
o`07Ool3O00TOol00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@02K[D00`00LhiIlP07FO80
0`00JU5ZD@03JU400`0022l8;`0222l00`00@MM1e`07@ML00`00EYUFV@0:EYT00`00JcY[>P06JcX0
0`00Mm<0000YOol00`00Oomoo`0:Ool000]oo`03001oogoo00Ioo`9l01Ioo`03001l07`000Eoo`9l
00Ioo`9l02aoo`9l00Uoo`9l02=oo`03000dccC?008dc`03001IleWc00AIl`03001^]Fje00=^]@80
00QIlP03001ZDFYA00=ZD@030008;`P_0088;`030011ed7G00M1e`03001FVEJI00UFV@03001[>V/j
00I[>P04001gdgOC000YOol00`00Oomoo`0:Ool000]oo`03001oogoo00Ioo`9l01Ioo`03001l07`0
00Aoo`9l00Moo`03O01oogoo02aoo`03O01oogoo00Moo`=l029oo`03000dccC?008dc`03001IleWc
00AIl`03001^]Fje009^]@03001cSUWb00QIlP03001ZDFYA00=ZD@050008;`P_22l00009@ML00`00
EYUFV@0:EYT00`00JcY[>P06JcX01000Mm=gd`00:Goo00<007ooOol02Woo000;Ool00`00Oomoo`06
Ool2O00FOol00`00O01l0004Ool00g`0Oomoo`05Ool2O00^Ool2O009Ool2O00ROol00`00=<ldc`02
=<l00`00FO=Il`03FO<00`00K[E^]@03K[D20004FO860004JU400`0022l8;`0222l00`00@MM1e`07
@ML00`00EYUFV@0:EYT00`00JcY[>P06JcX00`00Mm<0000ZOol00`00Oomoo`0:Ool000]oo`03001o
ogoo00Ioo`9l01Ioo`03001l07`000=oo`9l00Ioo`9l031oo`03O01oogoo00Moo`9l025oo`03000d
ccC?008dc`03001IleWc00AIl`03001^]Fje00=^]@H000E=2`<0009ZD@030008;`P_0088;`030011
ed7G00M1e`03001FVEJI00UFV@03001[>V/j00I[>P04001gdgOC000ZOol00`00Oomoo`0:Ool000]o
o`03001oogoo00Ioo`9l01Ioo`03001l07`0009oo`9l00Moo`03O01oogoo02moo`9l00Qoo`=l021o
o`03000dccC?008dc`03001IleWc00AIl`03001^]Fje009^]@03001cSTd;00Y=2`03001UA@000080
00<8;`030011ed7G00Q1e`03001FVEJI00UFV@03001[>V/j00I[>P04001gdgOC000ZOol00`00Oomo
o`0:Ool000]oo`03001oogoo00Ioo`9l01Ioo`03001l07`0009oo`03O01oogoo00Eoo`9l039oo`9l
00Qoo`9l021oo`03000dccC?008dc`03001IleWc00=Il`03001^]Fje00=^]@<000Y=2`04001UAFE5
000422l00`00@MM1e`07@ML00`00EYUFV@0:EYT00`00JcY[>P06JcX00`00Mm<0000[Ool00`00Oomo
o`0:Ool000]oo`03001oogoo00Ioo`9l01Ioo`04001l07`0Ool2O006Ool2O00dOol00g`0Oomoo`06
Ool2O00OOol00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@02K[D01000Lhhd[@002dd;00<0
06E5000010P_00<0047G@ML01d7G00<005JIEYT02EJI00<006/jJcX01f/j00<007OC0000;7oo00<0
07ooOol02Goo000;Ool00`00Oomoo`06Ool2O00FOol00`00O01l0002O007Ool00g`0Oomoo`0cOol2
O007Ool3O00NOol00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@02K[D20002=:d00`00C@]=
2`08C@/00`00IDD0000322l00`00@MM1e`08@ML00`00EYUFV@09EYT00`00JcY[>P06JcX01000Mm=g
d`00;7oo00<007ooOol02Goo000;Ool00`00Oomoo`06Ool2O00FOol01000O01l07`01goo0W`0=Woo
00=l07ooOol01Woo0W`07Goo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00fje0P000SB]
00<004d;C@/02Dd;00<000P_22l00PP_00<0047G@ML01d7G00<005JIEYT02UJI00<006/jJcX01V/j
00<007OC0000;Goo00<007ooOol02Goo000;Ool00`00Oomoo`06Ool2O00FOol01000O01l07`01goo
00=l07ooOol0=Goo0W`01goo0W`07Goo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00Vje
00<007>>=:d00cB]00<004d;C@/024d;00<000P_22l00PP_00<0047G@ML01d7G00<005JIEYT02EJI
00<006/jJcX01f/j00<007OC0000;Goo00<007ooOol02Goo000;Ool00`00Oomoo`06Ool2O00FOol0
0`00O01l0007Ool2O00hOol00g`0Oomoo`05Ool3O00LOol00`00=<ldc`02=<l00`00FO=Il`03FO<0
0`00K[E^]@03K[D20004=:d00`00C@]=2`07C@/2000322l00`00@MM1e`08@ML00`00EYUFV@09EYT0
0`00JcY[>P06JcX01000Mm=gd`00;Goo00<007ooOol02Goo000:Ool00`00Oomoo`07Ool2O00FOol0
0`00O01l0006Ool2O00iOol2O007Ool2O00KOol00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^
]@02K[D00`00Lhhd[@05=:d00`00C@]=2`06C@/2000322l00`00@MM1e`07@ML00`00EYUFV@0:EYT0
0`00JcY[>P06JcX00`00Mm<0000^Ool00`00Oomoo`09Ool000Yoo`03001oogoo00Moo`9l01Eoo`04
001l07`0O006Ool00g`0Oomoo`0iOol00g`0Oomoo`05Ool3O00JOol00`00=<ldc`02=<l00`00FO=I
l`04FO<00`00K[E^]@02K[D20006=:d01000C@]=2dd;1@000PP_00@000P_22l000U1e`03001FVEJI
00UFV@03001[>V/j00M[>P03001gd`0002ioo`03001oogoo00Uoo`002Woo00<007ooOol01goo0W`0
5Goo00<007`0O0001Woo0W`0>goo0W`01goo0W`06Goo00<003C?=<l00SC?00<005WcFO<015Wc00<0
06jeK[D00fje0P001cB]1`000`P_00<000P_00002T7G00<005JIEYT02EJI00<006/jJcX01V/j00@0
07OCMm<002ioo`03001oogoo00Uoo`002Woo00<007ooOol01goo0W`05Goo00<007`0O0001Goo0W`0
?Goo00=l07ooOol01Goo0W`06Goo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00Vje00<0
07>>=:d01SB]00<000`330<010`300L000P_22l8;`0022l00009@ML00`00EYUFV@0:EYT00`00JcY[
>P06JcX00`00Mm<0000_Ool00`00Oomoo`09Ool000Yoo`03001oogoo00Moo`9l01Aoo`04O00007`0
O005Ool00g`0Oomoo`0lOol2O006Ool3O00HOol00`00=<ldc`02=<l00`00FO=Il`03FO<00`00K[E^
]@03K[D20006=:d00`0030<<0`0430<00`0022l8;`0222l00`0022l00009@ML00`00EYUFV@09EYT0
0`00JcY[>P07JcX00`00Mm<0000_Ool00`00Oomoo`09Ool000Yoo`03001oogoo00Moo`9l01Aoo`04
O00007`0O004Ool2O00oOol2O006Ool2O00GOol00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^
]@03K[D20005=:d00`0030<<0`0430<00`0022l8;`0422l00`00@MM1e`08@ML00`00EYUFV@09EYT0
0`00JcY[>P06JcX01000Mm=gd`00;goo00<007ooOol02Goo000:Ool00`00Oomoo`07Ool2O00COol2
O0000`00O01l0003Ool2O011Ool00g`0Oomoo`04Ool2O00GOol00`00=<ldc`02=<l00`00FO=Il`04
FO<00`00K[E^]@02K[D20005=:d00`0030<<0`0530<00`0022l8;`0422l00`00@MM1e`07@ML00`00
EYUFV@0:EYT00`00JcY[>P06JcX00`00Mm<0000`Ool00`00Oomoo`09Ool000Yoo`03001oogoo00Mo
o`9l019oo`9l0004Ool007`0O003Ool00g`0Oomoo`10Ool2O005Ool3O00EOol00`00=<ldc`02=<l0
0`00FO=Il`04FO<00`00K[E^]@03K[D30003=:d00`0030<<0`0530<00`0022l8;`0422l00`00<MT0
0008@ML00`00EYUFV@09EYT00`00JcY[>P07JcX00`00Mm<0000`Ool00`00Oomoo`09Ool000Yoo`03
001oogoo00Moo`9l019oo`04O01oogoo0002O002Ool2O013Ool00g`0Oomoo`04Ool2O00EOol00`00
=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@02K[D01000Lhh8;`000SB]00<000`330<01@`300<0
00P_22l01@P_00@0037I<MT000M1e`03001FVEJI00UFV@03001[>V/j00I[>P04001gdgOC000`Ool0
0`00Oomoo`09Ool000Yoo`03001oogoo00Moo`9l015oo`9l009oo`04001l07`0Ool2O014Ool2O005
Ool2O00EOol00`00=<ldc`02=<l00`00FO=Il`03FO<00`00K[E^]@03K[D2000222l2000830<00`00
22l8;`0422l00`00<MTaf@02<MT00`00@MM1e`04@ML00`00EYUFV@09EYT00`00JcY[>P06JcX00`00
Mm=gd`0aOol00`00Oomoo`09Ool000Yoo`03001oogoo00Moo`9l011oo`9l00=oo`05001l07`0Ooml
0016Ool00g`0Oomoo`03Ool3O00COol00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@03K[D2
000222l:000622l00`00<MTaf@04<MT00`00@MM1e`02@ML00`00EYUFV@09EYT00`00JcY[>P07JcX0
0`00Mm<0000aOol00`00Oomoo`09Ool000Yoo`03001oogoo00Moo`9l011oo`03O01oogoo009oo`03
001l07`0009l04Ioo`9l00Eoo`9l01=oo`03000dccC?008dc`03001IleWc00AIl`03001^]Fje009^
]@8000<8;`030008;`P_00H8;`030008;`P_00<8;`03000afC7I00Haf@050011ed7G@ML0000;EYT0
0`00JcY[>P07JcX2000bOol00`00Oomoo`09Ool000Yoo`03001oogoo00Moo`9l00moo`9l00Aoo`04
001l07`0O018Ool00g`0Oomoo`03Ool3O00AOol00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^
]@03K[D2000322l00`0022l8;`0622l00`0022l8;`0322l00`00<MTaf@07<MT01000@MM1e`002eJI
00<006/jJcX01V/j00<007OC0000<Woo00<007ooOol02Goo000:Ool00`00Oomoo`07Ool2O00>Ool2
O005Ool01000O01l07`0B7oo0W`01Goo0W`04Goo00<003C?=<l00SC?00<005WcFO<015Wc00<006je
K[D00Vje00<007>>00000`P_00<000P_22l01PP_00<000P_22l00PP_00<0037I<MT02C7I0P002eJI
00<006/jJcX01f/j0P00<goo00<007ooOol02Goo000:Ool00`00Oomoo`07Ool2O00>Ool00g`0Oomo
o`04Ool00`00O01l001:Ool00g`0Oomoo`03Ool2O00AOol00`00=<ldc`02=<l00`00FO=Il`03FO<0
0`00K[E^]@03K[D3000322l00`0022l8;`0622l01@0022l8;`P_00003C7I0P002UJI00<006/jJcX0
1f/j00<007ooOol0<goo00<007ooOol027oo000:Ool00`00Oomoo`07Ool2O00=Ool2O006Ool00`00
O01l0002O018Ool2O004Ool3O00?Ool00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@03K[D2
000017oo0008;`002@P_00@000P_22l000daf@03001:_DZm00@000IFV@03001[>V/j00M[>P03001o
ogoo03=oo`03001oogoo00Qoo`002Woo00<007ooOol01goo0W`037oo0W`01Woo00=l0000O0001W`0
AWoo00=l07ooOol00goo0W`03goo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00Vje0P00
0Woo00<000P_000020P_00D000P_22l8;`0000`af@03001:_DZm00E:_@@00003EYT006/j00A[>PD0
03Ioo`03001oogoo00Qoo`002Woo00<007ooOol01goo0W`037oo00=l07ooOol017oo0W`000@007oo
Oomoo`Il04Aoo`9l00Aoo`9l00ioo`03000dccC?008dc`03001IleWc00AIl`03001^]Fje00=^]@80
00=oo`8000P8;`040008;`P_000=<MT00`00B[e:_@09B[d70003Fkh00`00Oomoo`0eOol00`00Oomo
o`08Ool000Yoo`03001oogoo00Moo`9l00]oo`9l00Eoo`=l0003001oogoo00Aoo`Il049oo`9l00=o
o`=l00eoo`03000dccC?008dc`03001IleWc00AIl`03001^]Fje00=^]@8000=oo`8000P8;`030008
;`0000daf@03001:_DZm00Y:_@03001K_U^n00IK_P03001oogoo03Ioo`03001oogoo00Qoo`002Woo
00<007ooOol01goo0W`02Woo0W`01Goo0g`000=oo`00Ool01goo1g`0@7oo00=l07ooOol00Woo0W`0
3Goo00<003C?=<l00SC?00<005WcFO<00eWc00<006jeK[D00fje0P001Goo00<000P_22l01PP_0P00
3C7I00<004ZmB[d02TZm00<005^nFkh01U^n00<007ooOol0=goo00<007ooOol027oo000:Ool00`00
Oomoo`07Ool2O00:Ool00g`0Oomoo`03Ool3O002Ool00`00Oomoo`09Ool7O00mOol2O003Ool2O00<
Ool00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@03K[D20005Ool5000422l2000<<MT00`00
B[e:_@0;B[d00`00FkiK_P05Fkh00`00Oomoo`0hOol00`00Oomoo`08Ool000Uoo`03001oogoo00Qo
o`9l00Uoo`9l00Aoo`=l00=oo`03001oogoo00aoo`Ml03]oo`04O01oogooOol3O00;Ool00`00=<ld
c`02=<l00`00FO=Il`04FO<00`00K[E^]@02K[D20006Ool00`001AP560021AP5000=<MT00`00B[e:
_@0:B[d00`00FkiK_P06Fkh00`00Oomoo`0hOol00`00Oomoo`08Ool000Uoo`03001oogoo00Qoo`9l
00Uoo`03O01oogoo009oo`=l00Aoo`03001oogoo00moo`Il03Uoo`9l00=oo`9l00Yoo`03000dccC?
008dc`03001IleWc00AIl`03001^]Fje00=^]@8000Moo`03000560DH00H56003000afC7I00Taf@03
001:_DZm00Y:_@03001K_U^n00IK_P03001oogoo03Uoo`03001oogoo00Qoo`002Goo00<007ooOol0
27oo0W`027oo0W`00goo0g`01Goo00<007ooOol04Woo1W`0=goo00Al07ooOomoo`=l00Uoo`03000d
ccC?008dc`03001IleWc00AIl`03001^]Fje00=^]@8000Moo`03000560DH00H56003000afC7I00Pa
f@03001:_DZm00Y:_@03001K_U^n00IK_P03001oogoo03Yoo`03001oogoo00Qoo`002Goo00<007oo
Ool027oo0W`01goo0W`00goo0g`01Woo00<007ooOol057oo1g`0=7oo0W`00goo0W`02Goo00<003C?
=<l00SC?00<005WcFO<00eWc00<006jeK[D00fje0P002Goo00<000DH1AP01PDH00<0037I<MT01S7I
00<004ZmB[d02dZm00<005^nFkh01E^n00<007ooOol0>goo00<007ooOol027oo0009Ool00`00Oomo
o`08Ool2O007Ool00g`0Oomoo`04O007Ool00`00Oomoo`0GOol7O00bOol017`0Oomoogoo0W`027oo
00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00fje0P002Goo00<000DH1AP01PDH00<0037I
<MT01S7I00<004ZmB[d02TZm00<005^nFkh01E^n00<007ooOol0?7oo00<007ooOol027oo0009Ool0
0`00Oomoo`08Ool2O006Ool2O0000gooO01l0002O008Ool00`00Oomoo`0JOol7O00_Ool2O002Ool3
O007Ool00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@03K[D00`00Oomoo`09Ool00`001AP5
60061AP00`00<MTaf@04<MT00`00B[e:_@0:B[d00`00FkiK_P05Fkh00`00Oomoo`0mOol00`00Oomo
o`08Ool000Uoo`03001oogoo00Qoo`9l00Eoo`9l0004Ooml07`0O00:Ool00`00Oomoo`0MOol6O00^
Ool017`0Oomoogoo0W`01Woo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00fje0P002goo
00<000DH1AP01`DH00<0037I<MT00S7I00<004ZmB[d02TZm00<005^nFkh01E^n00<007ooOol0?Woo
00<007ooOol027oo0009Ool00`00Oomoo`08Ool2O005Ool00g`0Ooml0002O00;Ool00`00Oomoo`0P
Ool6O00[Ool2O002Ool2O006Ool00`00=<ldc`02=<l00`00FO=Il`04FO<00`00K[E^]@03K[D2000<
Ool00`001AP560061AP01@00<MTafC7I000034Zm00<005^nFkh01E^n00<007ooOol0?goo00<007oo
Ool027oo0009Ool00`00Oomoo`08Ool2O004Ool5O00<Ool00`00Oomoo`0ROol7O00YOol2O00017oo
O01l07`01Goo00<003C?=<l00SC?00<005WcFO<00eWc00<006jeK[D00fje0P003Goo0`001`DH00@0
037I<MT000a:_@03001K_U^n00EK_P03001oogoo03moo`03001oogoo00Qoo`002Goo00<007ooOol0
27oo0W`00goo1G`037oo00<007ooOol09Woo1g`09goo00=l07ooOol00W`017oo00<003C?=<l00SC?
00<005WcFO<015Wc00<006jeK[D00fje0P003goo1`0000@56000<MT000a:_@03001K_U^n00EK_P03
001oogoo041oo`03001oogoo00Qoo`002Goo00<007ooOol027oo0W`00goo17`03Goo00<007ooOol0
:Goo1g`097oo0W`000=oog`0O00017oo00<003C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00fje
0P004Goo0P000`7J10002dZm00<005^nFkh01E^n00<007ooOol0@Goo00<007ooOol027oo0009Ool0
0`00Oomoo`08Ool2O002Ool4O00>Ool00`00Oomoo`0/Ool7O00ROol00g`0Ooml0002O003Ool00`00
=<ldc`02=<l00`00FO=Il`03FO<00`00K[E^]@03K[D2000DOol200050MX20008B[d00`00FkiK_P04
Fkh20015Ool00`00Oomoo`07Ool000Uoo`03001oogoo00Qoo`9l0003Ooml07`0009l00moo`03001o
ogoo02moo`Il021oo`9l0003Ooml07`0009oo`03000dccC?008dc`03001IleWc00AIl`03001^]Fje
00=^]@8001Ioo`@000<1fP<000E:_@04001K_U^nFkh30017Ool00`00Oomoo`07Ool000Uoo`03001o
ogoo00Qoo`9l0004Ooml07`0O00@Ool00`00Oomoo`0bOol6O00NOol00g`0Ooml0002O0000goo000d
c`03=<l00`00FO=Il`04FO<00`00K[E^]@02K[D2000KOol80002B[d50002Ool00`00Oomoo`15Ool0
0`00Oomoo`07Ool000Uoo`03001oogoo00Qoo`El015oo`03001oogoo03Aoo`Ml01]oo`9l0004Ooml
07`00004=<l00`00FO=Il`04FO<00`00K[E^]@03K[D2000QOol50006Ool00`00Oomoo`15Ool00`00
Oomoo`07Ool000Uoo`03001oogoo00Qoo`Al019oo`03001oogoo03Moo`Ml01Qoo`El0003000dccC?
008dc`03001IleWc00AIl`03001^]Fje00=^]@8002aoo`03001oogoo04Eoo`03001oogoo00Moo`00
2Goo00<007ooOol027oo2g`02goo00<007ooOol0>Woo1g`05Woo1G`013C?00<005WcFO<00eWc00<0
06jeK[D00fje0P00;Goo00<007ooOol0AGoo00<007ooOol01goo0009Ool00`00Oomoo`08OolEO000
0goo001oo`0nOol6O00EOol4O003=<l00`00FO=Il`04FO<00`00K[E^]@03K[D2000]Ool00`00Oomo
o`15Ool00`00Oomoo`07Ool000Uoo`03001oogoo01=oo`]l0003001l07`000Il03Yoo`Il01=oo`=l
00<dc`03001IleWc00AIl`03001^]Fje00=^]@03001oogoo02aoo`03001oogoo04Eoo`03001oogoo
00Moo`002Goo00<007ooOol07Goo00=l0000O0004G`0<Woo1g`047oo00H007`0O01l03C?0006FO<0
0`00K[E^]@03K[D2000^Ool00`00Oomoo`15Ool00`00Oomoo`07Ool000Uoo`03001oogoo01ioo`03
001oogoo00IooaAl02]oo`Ml00eoo`03001l07`0008dc`03001IleWc00AIl`03001^]Fje00=^]@80
02ioo`03001oogoo04Eoo`03001oogoo00Moo`0027oo00<007ooOol07goo00<007ooOol047oo4g`0
9Goo1g`02Woo1CC?1UWc00<006jeK[D00fje0P00;goo00<007ooOol0AGoo00<007ooOol01goo0008
Ool00`00Oomoo`0OOol00`00Oomoo`0JOolCO00NOol6O007Ool00`00=<ldc`02=<l00`00FO=Il`04
FO<00`00K[E^]@03K[D2000_Ool00`00Oomoo`15Ool00`00Oomoo`07Ool000Qoo`03001oogoo01mo
o`P001iooaAl01Moo`Il00Aoo`Ddc`MIl`03001^]Fje00=^]@03001oogoo02ioo`03001oogoo04Eo
o`03001oogoo00Moo`0027oo00<007ooOol07Woo00<007ooOol01Woo3P006Woo57`03goo1g`000<0
03C?=<l00SC?00<005WcFO<015Wc00<006jeK[D00fje0P00<7oo00<007ooOol0AGoo00<007ooOol0
1goo0008Ool00`00Oomoo`0MOol00`00Oomoo`0EOol?000EOolCO009Ool5O0060005FO<00`00K[E^
]@03K[D2000`Ool00`00Oomoo`15Ool00`00Oomoo`07Ool000Qoo`03001oogoo01]oo`8002Moo`h0
015ooa=l009oo`El00<ZWP<00003FO<006je00E^]@03001oogoo02moo`03001oogoo04Eoo`03001o
ogoo00Moo`0027oo00<007ooOol06Woo00<007ooOol0=Goo3P0037oo5W`000<ZWP0000001Fje0P00
<Goo00<007ooOol0AGoo00<007ooOol01goo0008Ool00`00Oomoo`0IOol00`00Oomoo`14Ool?0007
Ool<O003:Yh20003K[D2000aOol00`00Oomoo`15Ool00`00Oomoo`07Ool000Qoo`03001oogoo01Qo
o`03001oogoo05Aoo`l000<ZWP03O00ZWRZN00<ZWP@0039oo`03001oogoo04Eoo`03001oogoo00Mo
o`0027oo00<007ooOol05goo00<007ooOol0Hgoo3`00<Goo00<007ooOol0AWoo00<007ooOol01Woo
0008Ool00`00Oomoo`0FOol00`00Oomoo`1WOol20007:Yh00`00Oomoo`0>000SOol00`00Oomoo`16
Ool00`00Oomoo`06Ool000Qoo`03001oogoo01Aoo`8006eoo`L0011oo`l001Aoo`03001oogoo04Io
o`03001oogoo00Ioo`0027oo00<007ooOol04goo00<007ooOol0Tgoo3P001Woo00<007ooOol0AWoo
00<007ooOol01Woo0008Ool00`00Oomoo`0BOol00`00Oomoo`2ROol?0010Ool00`00Oomoo`06Ool0
00Qoo`03001oogoo015oo`03001oogoo0:Uoo`03001oogoo00Ioo`h0039oo`03001oogoo00Ioo`00
27oo00<007ooOol047oo00<007ooOol0ZWoo00<007ooOol057oo3P0097oo00<007ooOol01Woo0008
Ool00`00Oomoo`0?Ool00`00Oomoo`2[Ool00`00Oomoo`0ROol?000EOol00`00Oomoo`06Ool000Qo
o`03001oogoo00eoo`800:ioo`03001oogoo035oo`h000Moo`03001oogoo00Ioo`0027oo00<007oo
Ool037oo00<007ooOol0[Woo00<007ooOol0?goo200027oo0008Ool00`00Oomoo`0;Ool00`00Oomo
o`2_Ool00`00Oomoo`12Ool3000:Ool000Qoo`03001oogoo00Yoo`03001oogoo0;1oo`03001oogoo
03moo`<000eoo`0027oo00<007ooOol02Goo00<007ooOol0/Goo00<007ooOol0?7oo0`0047oo0007
Ool00`00Oomoo`09Ool00`00Oomoo`2bOol00`00Oomoo`0iOol3000COol000Moo`03001oogoo00Mo
o`800;Ioo`03001oogoo03Eoo`<001Ioo`001goo00<007ooOol01Woo00<007ooOol0]Woo00<007oo
Ool0<Woo0`006Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`2gOol00`00Oomoo`0_Ool3000LOol0
00Moo`03001oogoo00Aoo`03001oogoo0;Qoo`03001oogoo02aoo`<001moo`001goo00<007ooOol0
0goo00<007ooOol0^Goo00<007ooOol0:Goo0`008Woo0007Ool00`00Oomoo`02Ool00`00Oomoo`2j
Ool00`00Oomoo`0VOol3000UOol000Moo`03001oogoo00800;eoo`03001oogoo02=oo`<002Qoo`00
1goo00<007oo0000_goo00<007ooOol087oo0`00:goo0007Ool20030Ool00`00Oomoo`0MOol3000^
Ool000Moo`X00;Qoo`03001oogoo01Yoo`<0035oo`004Goo5000Y7oo00<007ooOol05goo0`00=7oo
000UOolC002AOol00`00Oomoo`0DOol3000gOol003Qooa<007ioo`03001oogoo015oo`<003Yoo`00
Bgoo5000JWoo00<007ooOol03Woo0`00?Goo001OOolC001GOol00`00Oomoo`0;Ool30010Ool0079o
oa@004=oo`03001oogoo00Qoo`<004=oo`00QWoo4`00<7oo00<007ooOol01Goo0`00AWoo002IOolC
000MOol00`00Oomoo`02Ool30019Ool00:aooa@000Uoo`03001oo`00008004aoo`00`7oo2`00Cgoo
003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00001
\
\>"],
  ImageRangeCache->{{{0, 281}, {260, 0}} -> {0.0234122, -0.0101519, 
  0.00356645, 0.00356645}}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Euler and Angular Formulations"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Velocity and acceleration solutions are calculated in a 3D model in the \
same manner as in a 2D model. However, there are three options in a 3D model \
as to how the higher-order data are represented.\n\nSince the angular \
orientation of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " bodies is specified by four Euler generalized parameters, {",
  StyleBox["Eon",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Ein",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Ejn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Ekn",
    FontSlant->"Italic"],
  "}, one way of representing the angular velocity and acceleration of a body \
in 3-space is with the first and second derivatives of the Euler parameters, \
{",
  StyleBox["Eond",
    FontSlant->"Italic"],
  ", ...} and {",
  StyleBox["Eondd",
    FontSlant->"Italic"],
  ",...}. Another more familiar way of representing angular velocity and \
acceleration is with the angular velocity and acceleration vectors, {",
  StyleBox["omegaX",
    FontSlant->"Italic"],
  ", ",
  StyleBox["omegaY",
    FontSlant->"Italic"],
  ", ",
  StyleBox["omegaZ",
    FontSlant->"Italic"],
  "} and {",
  StyleBox["alphaX",
    FontSlant->"Italic"],
  ", ",
  StyleBox["alphaY",
    FontSlant->"Italic"],
  ", ",
  StyleBox["alphaZ",
    FontSlant->"Italic"],
  "}, in either global coordinates or local coordinates attached to each \
individual body. ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can formulate the higher-order solutions in any of these representations, \
each of which requires that different sets of equations be built by the ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. Which formulation is used is specified with the ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetSymbols[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify what symbolic form is used to represent angular \
coordinates in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A system set-up function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may also be used with ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to specify angular coordinates or a degenerate version of Euler \
coordinates, although the Euler coordinates are seldom used in 2D models. \
Specifying ",
  StyleBox["Method->Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model causes the angular orientation of each body to be represented by a \
pair of coordinates {",
  StyleBox["Ejn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Ekn",
    FontSlant->"Italic"],
  "} = {cos(",
  StyleBox["Thn",
    FontSlant->"Italic"],
  "), sin(",
  StyleBox["Thn",
    FontSlant->"Italic"],
  ")} instead of a single coordinate, ",
  StyleBox["Thn",
    FontSlant->"Italic"],
  ". Velocity and acceleration are also represented by the coordinate pairs \
{",
  StyleBox["Ejnd",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Eknd",
    FontSlant->"Italic"],
  "} and {",
  StyleBox["Ejndd, Ekndd",
    FontSlant->"Italic"],
  "}. The inclusion of this feature in ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is largely academic; specifying ",
  StyleBox["Method->Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes four equations to be generated for each body, instead of only \
three, and usually slows down the solution phase. There are two advantages \
afforded by 2D degenerate Euler coordinates: no trigonometric functions are \
generated in the constraint expressions so all of the constraints are purely \
algebraic, and the second derivative of a 2D rotation matrix is very simple \
which leads to faster solutions in some dynamical systems."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2D/3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and other built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions. ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify whether the higher-order solutions are represented by \
",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " velocities and accelerations or by derivatives of ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " parameters.\n\n",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes derivatives of Euler parameters to be used to represent \
angular velocity.\n\n",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes angular velocity and acceleration to be used directly for \
first- and second-order coordinates.\n\nIn ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the default setting is ",
  StyleBox["Method->Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\nIn ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the default setting is ",
  StyleBox["Method->Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether angular velocity and acceleration coordinates are \
calculated in the ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " reference frame or the ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " reference frame with respect to each individual body. The ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is only relevant when used with the ",
  StyleBox["Method->Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. The default setting is ",
  StyleBox["Coordinates->Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The MacPherson strut front model defined in the previous subsection is \
used to demonstrate the 3D velocity and acceleration solutions. The ",
  StyleBox["Solution->Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to calculate the location and velocity of each body in the model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This finds the location and velocity of each body at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.5, Solution \[Rule] Velocity] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 2.5`\), ",", \(Eo2 \[Rule] 1.`\), 
        ",", \(Ei2 \[Rule] 0\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 0.254625171239336278`\), ",", 
        \(Y3 \[Rule] 21.8016010097176637`\), ",", 
        \(Z3 \[Rule] 5.46299863008530728`\), ",", 
        \(Eo3 \[Rule] 0.999669793128668082`\), ",", 
        \(Ei3 \[Rule] 0.0143329932622434474`\), ",", 
        \(Ej3 \[Rule] 0.000731365473970143042`\), ",", 
        \(Ek3 \[Rule] \(-0.0213151381818196128`\)\), ",", \(X2d \[Rule] 0\), 
        ",", \(Y2d \[Rule] 0\), ",", \(Z2d \[Rule] 1.`\), ",", 
        \(Eo2d \[Rule] 0\), ",", \(Ei2d \[Rule] 0\), ",", \(Ej2d \[Rule] 0\), 
        ",", \(Ek2d \[Rule] 0\), ",", \(X3d \[Rule] 0.120626194671606001`\), 
        ",", \(Y3d \[Rule] \(-0.139595577758527111`\)\), ",", 
        \(Z3d \[Rule] 0.0349904426271510615`\), ",", 
        \(Eo3d \[Rule] 0.000309409766362983384`\), ",", 
        \(Ei3d \[Rule] \(-0.0132679396903164215`\)\), ",", 
        \(Ej3d \[Rule] \(-0.0055323025297288062`\)\), ",", 
        \(Ek3d \[Rule] 0.00539955082173851508`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that the angular velocities were returned in the form of first \
derivatives of the Euler parameters, ",
  StyleBox["Eo2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Ej3d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on. This is because the constraint equations were built in the \
previous section with all default options for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If the model is rebuilt with the ",
  StyleBox["Method->Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the first derivatives of the Euler parameters will be converted into \
angular velocities. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This rebuilds the constraints with angular velocity formulation."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular]\), 
    \(SetConstraints[Array[cs, 8]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now find the velocity solution at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.0. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.0, Solution \[Rule] Velocity] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 2.`\), ",", \(Eo2 \[Rule] 1.`\), 
        ",", \(Ei2 \[Rule] 0\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 0.194309226223794411`\), ",", 
        \(Y3 \[Rule] 21.8630029972593176`\), ",", 
        \(Z3 \[Rule] 5.44552619020964367`\), ",", 
        \(Eo3 \[Rule] 0.999493583614048652`\), ",", 
        \(Ei3 \[Rule] 0.0208988457956214412`\), ",", 
        \(Ej3 \[Rule] 0.00345310750527855248`\), ",", 
        \(Ek3 \[Rule] \(-0.0237463809308858397`\)\), ",", \(X2d \[Rule] 0\), 
        ",", \(Y2d \[Rule] 0\), ",", \(Z2d \[Rule] 0.999999999999999822`\), 
        ",", \(Wx2 \[Rule] 0\), ",", \(Wy2 \[Rule] 0\), ",", 
        \(Wz2 \[Rule] 0\), ",", \(X3d \[Rule] 0.120637687959979333`\), ",", 
        \(Y3d \[Rule] \(-0.106082692272031464`\)\), ",", 
        \(Z3d \[Rule] 0.0348984963201651732`\), ",", 
        \(Wx3 \[Rule] \(-0.0262206580749703377`\)\), ",", 
        \(Wy3 \[Rule] \(-0.0102694467389916765`\)\), ",", 
        \(Wz3 \[Rule] 0.00853952118348031952`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The angular velocity of the chassis in global coordinates \
{\[CapitalOmega]",
  StyleBox["X2",
    FontSlant->"Italic"],
  ", \[CapitalOmega]",
  StyleBox["Y2",
    FontSlant->"Italic"],
  ", \[CapitalOmega]",
  StyleBox["Z2",
    FontSlant->"Italic"],
  "} is represented by the symbols ",
  StyleBox["{Wx2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Wy2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Wz2}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\nThe ",
  StyleBox["Solution->Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to calculate the location, velocity, and acceleration of each body in the \
model. Note that it takes more time to execute the following command the \
first time than it will on all subsequent executions. This is because the \
acceleration equations must be built the first time through. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now find the acceleration of the bodies at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.0, Solution \[Rule] Acceleration] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 2.`\), ",", \(Eo2 \[Rule] 1.`\), 
        ",", \(Ei2 \[Rule] 0\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 0.194309226223794411`\), ",", 
        \(Y3 \[Rule] 21.8630029972593176`\), ",", 
        \(Z3 \[Rule] 5.44552619020964367`\), ",", 
        \(Eo3 \[Rule] 0.999493583614048652`\), ",", 
        \(Ei3 \[Rule] 0.0208988457956214412`\), ",", 
        \(Ej3 \[Rule] 0.00345310750527855248`\), ",", 
        \(Ek3 \[Rule] \(-0.0237463809308858397`\)\), ",", \(X2d \[Rule] 0\), 
        ",", \(Y2d \[Rule] 0\), ",", \(Z2d \[Rule] 0.999999999999999822`\), 
        ",", \(Wx2 \[Rule] 0\), ",", \(Wy2 \[Rule] 0\), ",", 
        \(Wz2 \[Rule] 0\), ",", \(X3d \[Rule] 0.120637687959979333`\), ",", 
        \(Y3d \[Rule] \(-0.106082692272031464`\)\), ",", 
        \(Z3d \[Rule] 0.0348984963201651732`\), ",", 
        \(Wx3 \[Rule] \(-0.0262206580749703377`\)\), ",", 
        \(Wy3 \[Rule] \(-0.0102694467389916765`\)\), ",", 
        \(Wz3 \[Rule] 0.00853952118348031952`\), ",", \(X2dd \[Rule] 0\), ",",
         \(Y2dd \[Rule] 0\), ",", \(Z2dd \[Rule] 0\), ",", \(Wx2d \[Rule] 0\),
         ",", \(Wy2d \[Rule] 0\), ",", \(Wz2d \[Rule] 0\), ",", 
        \(X3dd \[Rule] \(-0.0000235304948374162314`\)\), ",", 
        \(Y3dd \[Rule] \(-0.0666246960644506991`\)\), ",", 
        \(Z3dd \[Rule] 0.000188243958699345483`\), ",", 
        \(Wx3d \[Rule] \(-0.00106964737606097548`\)\), ",", 
        \(Wy3d \[Rule] \(-0.000779857426537538955`\)\), ",", 
        \(Wz3d \[Rule] 0.00421225943496291677`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Since angular acceleration is the first derivative of angular velocity, \
the angular acceleration vector of the carrier, {",
  StyleBox["alphaX",
    FontSlant->"Italic"],
  ", ",
  StyleBox["alphaY",
    FontSlant->"Italic"],
  ", ",
  StyleBox["alphaZ",
    FontSlant->"Italic"],
  "}, is represented directly by ",
  StyleBox["{Wx3d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Wy3d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Wz3d}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nThe model is now rebuilt with the ",
  StyleBox["Coordinates->Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option so that angular velocity is represented in local, instead of \
global, coordinates."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This rebuilds the constraints with a local angular velocity formulation."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular, Coordinates \[Rule] Local]\), 
    \(SetConstraints[Array[cs, 8]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now find the velocity solution at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.0. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.0, Solution \[Rule] Velocity] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 2.`\), ",", \(Eo2 \[Rule] 1.`\), 
        ",", \(Ei2 \[Rule] 0\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 0.194309226223794411`\), ",", 
        \(Y3 \[Rule] 21.8630029972593176`\), ",", 
        \(Z3 \[Rule] 5.44552619020964367`\), ",", 
        \(Eo3 \[Rule] 0.999493583614048652`\), ",", 
        \(Ei3 \[Rule] 0.0208988457956214412`\), ",", 
        \(Ej3 \[Rule] 0.00345310750527855248`\), ",", 
        \(Ek3 \[Rule] \(-0.0237463809308858397`\)\), ",", \(X2d \[Rule] 0\), 
        ",", \(Y2d \[Rule] 0\), ",", \(Z2d \[Rule] 1.`\), ",", 
        \(Wx2 \[Rule] 0\), ",", \(Wy2 \[Rule] 0\), ",", \(Wz2 \[Rule] 0\), 
        ",", \(X3d \[Rule] 0.120637687959979245`\), ",", 
        \(Y3d \[Rule] \(-0.10608269227203142`\)\), ",", 
        \(Z3d \[Rule] 0.0348984963201651687`\), ",", 
        \(Wx3 \[Rule] \(-0.0257718881666369803`\)\), ",", 
        \(Wy3 \[Rule] \(-0.0111419887031725606`\)\), ",", 
        \(Wz3 \[Rule] 0.00880759537656761004`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that the local angular velocity of body 3 is only slightly different \
from the global angular velocity. This is because the angular orientation of \
the wheel carrier is very close to being aligned with the global coordinate \
system."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Pull-rod Suspension Graphics"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Needs[\"Mech`Mech2D`\"]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"conrodsGr:=Graphics[{\n {Thickness[.02],Line[{{0,0},{27,0}}]},\n \
{RGBColor[.6,0,1],\n    Bar[Line[rocker, 2, chassis, 6], .7]},\n \
{Thickness[.007],\n    Line[{Location[carrier,2], Location[rocker, 3]}],\n    \
Line[{Location[chassis,3], Location[carrier,1]}],\n    \
Line[{Location[chassis,4], Location[carrier,2]}] }}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"conrodsTx=Graphics[{\n  Text[\"Shock\",      Location[chassis,6],{ 0  \
,-1.8}],\n  Text[\"Upper A-arm\",Location[carrier,2],{ 0  ,-1.5}],\n  \
Text[\"Lower A-arm\",Location[carrier,1],{ 0  , 1.5}],\n  Text[\"Pull-Rod\",  \
 Location[carrier,2],{ 0.4, 9.2}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"chassisGr:=Graphics[{\n  {RGBColor[1,0,0], Thickness[.006],\n  Edge[chassis, \
{2,4,3,1,2,5}, {4,5}, {4,6,3}]},\n  PointSize[.01],Vertex[chassis, {3,4,6}] \
}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
chassisTx=Graphics[{
  Text[\"P1\",Location[chassis,1],{ 1.5, 0  }],
  Text[\"P2\",Location[chassis,2],{ 1.5, 0  }],
  Text[\"P3\",Location[chassis,3],{-1.5, 1.2}],
  Text[\"P4\",Location[chassis,4],{ 1.5,-1.8}],
  Text[\"P5\",Location[chassis,5],{-1.5, 1.2}],
  Text[\"P6\",Location[chassis,6],{ 0  ,-1.6}] }];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
carrierGr:=Graphics[{
  {RGBColor[0,0,1], Facet[carrier, {1,2,{0.8,4.5}}]},
  Thickness[.03],  Edge[carrier, {{1.25,4.5},{0.8,4.5}}],
  {RGBColor[.3,.3,.2],
  Bar[Line[carrier, 3, {1.25,14.5}], 0, 4]},
  PointSize[.01],Vertex[carrier, {1,2}]} ];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"carrierTx=Graphics[{\n  Text[\"P1\",Location[carrier,1],{ 1  , 1.6}],\n  \
Text[\"P2\",Location[carrier,2],{ 1  ,-1.6}],\n  \
Text[\"P3\",Location[carrier,3],{ 0  , 1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"rockerGr:=Graphics[{\n  PointSize[.01], Vertex[rocker, {2,3,1}],\n  \
RGBColor[0,.8,.2], Facet[rocker, {1,2,3}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"rockerTx=Graphics[{\n  Text[\"P1\",Location[rocker,1],{ 1.6, 0  }],\n  Text[\
\"P2\",Location[rocker,2],{-1.6, 0  }],\n  Text[\"P3\",Location[rocker,3],{ 0 \
 , 1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{conrodsGr,chassisGr,carrierGr,rockerGr}/.LastSolve[],\n\
Frame->True,PlotRange->{{-2,28},{-2,21}},\nAspectRatio->Automatic];"], "Input",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"pl1=Show[{chassisGr,chassisTx}/.LastSolve[],\nPlotRange->{{-2,28},{-2,21}},\n\
AspectRatio->Automatic];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"pl2=Show[{carrierGr,carrierTx}/.LastSolve[],\nPlotRange->{{-2,28},{-2,21}},\n\
AspectRatio->Automatic];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"pl3=Show[{rockerGr,rockerTx}/.LastSolve[],\nPlotRange->{{-2,28},{-2,21}},\n\
AspectRatio->Automatic];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"pl4=Show[{conrodsGr,conrodsTx}/.LastSolve[],\nPlotRange->{{-2,28},{-2,21}},\n\
AspectRatio->Automatic];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[{{pl1,pl4},{pl2,pl3}}],Frame->True];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["MacPherson Graphics "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Needs[\"Mech`Mech3D`\"] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
conrodsGr=Graphics3D[{ 
(* Strut *) {  
  Bar[Line[carrier, 2, chassis, 6], 1.2, 8]},  
(* A-arms*) { 
  Bar[Line[chassis, 4, carrier, 1], .6, 4], 
  Bar[Line[chassis, 5, carrier, 1], .6, 4]}, 
(* Tie Rod *) { 
  RGBColor[0, 0, 1],Thickness[.015], 
  Line[{Location[chassis, 7], Location[carrier, 5]}] }}];  \
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"groundGr=Graphics3D[{ \n  \
Polygon[{{13,0,0},{13,27,0},{-13,27,0},{-13,0,0}}]}];  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"chassisGr=Graphics3D[{RGBColor[1,0,0], Thickness[.008], \n  Edge[chassis, {  \
\n  a={10, 0, 2}, a*{-1,1,1}, 5, 4, a, \n  b={7, 0, 18}, 6, b*{-1,1,1}, \n  \
5, 6, 4, b, b*{-1,1,1}, a*{-1,1,1}}], \n  Bar[Line[chassis,7,chassis,  \n     \
      PointList[chassis,7]*{1,0,1}], 0.8, 6]}];  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"carrierGr=Graphics3D[{Thickness[.015], \n  Edge[carrier, {2, 1}],  \n  \
Torus[Line[carrier, 3, 4], 7.5, 2.5, {12, 10}],  \n  Facet[carrier, {1, 3, \
4}, {2, 3, 4}, {4, 3, 5}, {1, 3, 5}]}];  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{conrodsGr,groundGr,chassisGr,carrierGr}/.LastSolve[],  \n  \
PlotRange->{{-11,11},{-1,29},{-1,25}},  \n  ViewPoint->{3.1,-1.1,1.0}];  "], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["4.2  Velocity and Acceleration Output"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now that the velocity and acceleration of each mechanism body has been \
calculated, useful output may be generated by developing expressions that are \
functions of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " velocity and acceleration variables, and subjecting those expressions to \
the standard solution rules produced by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["3D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The 3D MacPherson strut suspension model is used to demonstrate various \
methods of producing velocity and acceleration output with ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ". The model is redefined as follows in abbreviated form."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"The complete MacPherson strut suspension model follows. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      Body[ground = 1, 
        PointList \[Rule] \n
          \t\t\t{{0, 0, 0}, {0, 0, 1}, {1, 0, 0}, {0, 1, 0}}], \n\t
      Body[chassis = 2, 
        PointList 
          \[Rule] {{0, 0, 0}, {0, 0, 1}, {0, 1, 0}, {4.0, 7.5, 5.5}, {
              \(-4.0\), 7.5, 4.5}, {0, 15., 20.}, {\(-6.\), 9., 8.}}, 
        InitialGuess \[Rule] {{0, 0, 2.5}, {1, 0, 0, 0}}], \n\t
      Body[carrier = 3, 
        PointList 
          \[Rule] {{0, 0, 0}, {0, \(-2.2\), 6.}, {0, 1.25, 4.5}, {0, 
              \(-0.5\), 4.5}, {\(-6\), \(-2\), 4}}, 
        InitialGuess \[Rule] {{0, 22., 5.0}, {1, 0, 0, 0}}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[
      cons = {\n\t\t\t
          Cylindrical4[1, \n\t\t\t\tLine[ground, 1, 2], Line[chassis, 1, 2]], 
          \n\t\t\tOrthogonal1[2, \n\t\t\t\tLine[ground, 1, 3], 
            Line[chassis, 1, 3]], \n\t\t\t
          RelativeZ1[3, Point[chassis, 1], T], \n\t\t\t
          RelativeDistance1[4, \n\t\t\t\tPoint[chassis, 4], 
            Point[carrier, 1], 15.0], \n\t\t\t
          RelativeDistance1[5, \n\t\t\t\tPoint[chassis, 5], 
            Point[carrier, 1], 15.0], \n\t\t\t
          PointOnLine2[6, \n\t\t\t\tPoint[chassis, 6], Line[carrier, 1, 2]], 
          \n\t\t\tPlaneToCircle1[7, Plane[ground, 1, 3, 4], 
            Line[carrier, 3, 4], 7.5, 2.5], \n\t\t\t
          RelativeDistance1[8, \n\t\t\t\tPoint[chassis, 7], 
            Point[carrier, 5], 11]}]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5 to prove that it still works. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.5] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 2.5`\), ",", \(Eo2 \[Rule] 1.`\), 
        ",", \(Ei2 \[Rule] 0\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 0.254625171239336278`\), ",", 
        \(Y3 \[Rule] 21.8016010097176637`\), ",", 
        \(Z3 \[Rule] 5.46299863008530728`\), ",", 
        \(Eo3 \[Rule] 0.999669793128668082`\), ",", 
        \(Ei3 \[Rule] 0.0143329932622434474`\), ",", 
        \(Ej3 \[Rule] 0.000731365473970143042`\), ",", 
        \(Ek3 \[Rule] \(-0.0213151381818196128`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Output Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "While ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " provides a wide array of output functions that return various quantities \
related to mechanism body locations, only a small subset of those output \
functions are available that are related to mechanism velocities or \
accelerations. The most basic of those are the two higher-order analogies of \
the ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. For each of the following functions, the ",
  StyleBox["point",
    FontSlant->"Italic"],
  " argument can be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " point object or just the arguments to a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " point object. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global velocity vector of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".\n \n",
  StyleBox["Acceleration[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global acceleration vector of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Velocity and acceleration output functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[
"The velocity of the steering tie rod attachment point on the wheel carrier \
is very near zero in the global reference frame because the chassis is \
allowed to move up and down while the bottom of the tire (the carrier body) \
remains in contact with the ground. Thus the motion of the carrier with \
respect to the ground is just a small tipping about the bottom of the tire."],
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This calculates the velocity of a point."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Velocity[Point[carrier, 5]] /. 
      SolveMech[2.0, Solution \[Rule] Velocity]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.0960176631852608508`, \(-0.0540237065095396751`\), 
      0.0219075724195789245`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeVelocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the velocity of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", in global coordinates. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A related velocity function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The velocity of the steering tie rod attachment point with respect to the \
chassis has a much larger vertical component, while the longitudinal and \
transverse components remain the same. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"The velocity of a point, relative to another body, is shown here."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(RelativeVelocity[chassis, Point[carrier, 5]] /. LastSolve[]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \({0.0960176631852607265`, \(-0.0540237065095396218`\), 
      \(-0.978092427580421208`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Two functions provide the higher-order analogies to the ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Rotation[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angular coordinate of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Omega[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angular velocity of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Alpha[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angular acceleration of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2D angular velocity and acceleration functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Rotation[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list {angle, axis} of the rotation angle and axis that uniquely \
specifies the angular orientation of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Omega[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global angular velocity vector of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Alpha[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global angular acceleration vector of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["3D angular velocity and acceleration functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Note that all ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output functions formulate expressions in terms of derivatives of Euler \
parameters, ",
  StyleBox["or",
    FontSlant->"Italic"],
  " global angular velocities and accelerations, ",
  StyleBox["or",
    FontSlant->"Italic"],
  " local angular velocities and accelerations. Which form is returned \
depends on the settings of the ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that were in effect the last time that the model was built.\n\nFor \
example, the current model was built with the default ",
  StyleBox["Method->Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting in ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; therefore, all output functions will return expressions in terms of \
derivatives of Euler parameters that can be replaced by a solution rule."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the angular velocity of the wheel carrier."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Omega[carrier]\), 
    \(% /. SolveMech[2.0, Solution \[Rule] Velocity]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2\ \((\(-Ej3d\)\ Ek3 + Ej3\ Ek3d + Ei3d\ Eo3 - Ei3\ Eo3d)\), 
      2\ \((Ei3d\ Ek3 - Ei3\ Ek3d + Ej3d\ Eo3 - Ej3\ Eo3d)\), 
      2\ \((\(-Ei3d\)\ Ej3 + Ei3\ Ej3d + Ek3d\ Eo3 - Ek3\ Eo3d)\)}\)], 
  "Output"],

Cell[BoxData[
    \({\(-0.0262206580749783801`\), \(-0.0102694467389842158`\), 
      0.00853952118346590438`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Method->Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is now used with ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This changes the formulation of the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " output functions, but the numbers remain the same. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is rebuilt with the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option setting. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular]\), 
    \(SetConstraints[cons]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The angular velocity of the wheel carrier is the same."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Omega[carrier]\), 
    \(% /. SolveMech[2.0, Solution \[Rule] Velocity]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({Wx3, Wy3, Wz3}\)], "Output"],

Cell[BoxData[
    \({\(-0.0262206580749703377`\), \(-0.0102694467389916765`\), 
      0.00853952118348031952`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Again, the internal representation of the angular velocity can be changed to \
local coordinates, but the numerical results from the output functions remain \
the same."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"The model is rebuilt again with local angular velocity representation. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular, Coordinates \[Rule] Local]\), 
    \(SetConstraints[cons]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The angular velocity of the wheel carrier is still the same."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Omega[carrier]\), 
    \(% /. SolveMech[2.0, Solution \[Rule] Velocity]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2\ \((\(-\(1\/2\)\) + Ei3\^2 + Eo3\^2)\)\ Wx3 + 
        2\ \((Ei3\ Ej3 - Ek3\ Eo3)\)\ Wy3 + 
        2\ \((Ei3\ Ek3 + Ej3\ Eo3)\)\ Wz3, 
      2\ \((Ei3\ Ej3 + Ek3\ Eo3)\)\ Wx3 + 
        2\ \((\(-\(1\/2\)\) + Ej3\^2 + Eo3\^2)\)\ Wy3 + 
        2\ \((Ej3\ Ek3 - Ei3\ Eo3)\)\ Wz3, 
      2\ \((Ei3\ Ek3 - Ej3\ Eo3)\)\ Wx3 + 2\ \((Ej3\ Ek3 + Ei3\ Eo3)\)\ Wy3 + 
        2\ \((\(-\(1\/2\)\) + Ek3\^2 + Eo3\^2)\)\ Wz3}\)], "Output"],

Cell[BoxData[
    \({\(-0.0262206580749703466`\), \(-0.0102694467389916788`\), 
      0.00853952118348032307`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The only other output functions that are defined by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " are the higher-order analogies to the ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. These two functions are defined largely for academic reasons, \
because they can be reproduced simply by differentiating the ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, as is shown in the next subsection."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Distance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the absolute distance between the two ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["DDistanceDT[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the first time derivative of the absolute distance between the \
two ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["D2DistanceDT2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the second time derivative of the absolute distance between the \
two ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Two more higher-order output functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "There is a slight difference between using the velocity output functions ",
  
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DDistanceDT",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on, and simply differentiating their first-order counterparts ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The first- and second-order output functions use the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " operator to differentiate the local coordinates of each point, thereby \
assuming that the local coordinates are constant unless they are explicitly \
functions of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here are the length, and the first and second derivatives of the length of \
the strut. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({Distance[Point[chassis, 6], Point[carrier, 2]], 
        DDistanceDT[Point[chassis, 6], Point[carrier, 2]], 
        D2DistanceDT2[Point[chassis, 6], Point[carrier, 2]]} /. 
      SolveMech[2.0, Solution \[Rule] Acceleration]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({11.5311331674860806`, 0.852156828833247992`, 
      \(-0.0127950497750734548`\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Differentiating Expressions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Although ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " provides only a small number of predefined output functions that relate \
to velocity and acceleration, any expression that is written in terms of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " dependent variables can be differentiated with ",
  StyleBox["Dt",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because definitions have been automatically made for ",
  StyleBox["Dt[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X",
    FontSlant->"Italic"],
  StyleBox[", T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["X",
    FontSlant->"Italic"],
  " is any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " dependent variable. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is rebuilt with the ",
  StyleBox["Method->Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Euler]\), 
    \(SetConstraints[cons]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the rate of change of the camber angle."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(IncludedAngle[Line[carrier, 3, 4], Vector[ground, {0, 0, 1}]]\), 
    \(Dt[%, T]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ArcCos[
      0.571428571428571352`\ 
        \((\(-3.5`\)\ \((Ej3\ Ek3 + Ei3\ Eo3)\) + 
            0.`\ \((\(-\(1\/2\)\) + Ek3\^2 + Eo3\^2)\))\)]\)], "Output"],

Cell[BoxData[
    \(\(-\(\((
          0.571428571428571352`\ 
            \((\(-3.5`\)\ 
                  \((Ej3d\ Ek3 + Ej3\ Ek3d + Ei3d\ Eo3 + Ei3\ Eo3d)\) + 
                0.`\ \((2\ Ek3\ Ek3d + 2\ Eo3\ Eo3d)\))\))\)/
        \((\[Sqrt]\((
              1 - 0.326530612244897922`\ 
                  \((\(-3.5`\)\ \((Ej3\ Ek3 + Ei3\ Eo3)\) + 
                        0.`\ \((\(-\(1\/2\)\) + Ek3\^2 + Eo3\^2)\))\)\^2)\))
          \)\)\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This generates a numerical result at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({%%, %} /. SolveMech[2.5, Solution \[Rule] Velocity]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1.599425580060017`, \(-0.0262852772584644256`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that ",
  StyleBox["Dt",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatically replaced derivatives of dependent variables with the \
appropriate symbols. This form of differentiation is valid even when crossing \
from Euler to angular coordinates. \n\nConsider the following example. With \
the ",
  StyleBox["Method->Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", differentiating the seven ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " location coordinates associated with body 3 with respect to ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has the apparent effect of appending a ",
  StyleBox["d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the name of each variable. These new symbols are explicitly included \
in the solution rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\nHowever, with the ",
  StyleBox["Method->Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option set, differentiating the seven ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " symbols with respect to ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " produces different symbolic results. This shows the functional \
relationship between the Euler parameters and the angular velocity. After \
replacement with a ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution rule, the results are numerically identical. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This shows the derivatives of dependent variables."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Location[carrier]\), 
    \(Dt[Location[carrier], T]\), 
    \(% /. SolveMech[2.5, Solution \[Rule] Velocity]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X3, Y3, Z3, Eo3, Ei3, Ej3, Ek3}\)], "Output"],

Cell[BoxData[
    \({X3d, Y3d, Z3d, Eo3d, Ei3d, Ej3d, Ek3d}\)], "Output"],

Cell[BoxData[
    \({0.120626194671606001`, \(-0.139595577758527111`\), 
      0.0349904426271510615`, 0.000309409766362983384`, 
      \(-0.0132679396903164215`\), \(-0.0055323025297288062`\), 
      0.00539955082173851508`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is rebuilt with the ",
  StyleBox["Method->Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular]\), 
    \(SetConstraints[cons]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The derivatives of dependent variables have changed form, but their values \
remain the same."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Location[carrier]\), 
    \(Dt[Location[carrier], T]\), 
    \(% /. SolveMech[2.5, Solution \[Rule] Velocity]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X3, Y3, Z3, Eo3, Ei3, Ej3, Ek3}\)], "Output"],

Cell[BoxData[
    \({X3d, Y3d, Z3d, 
      \(-\(\(Ei3\ Wx3\)\/2\)\) - \(Ej3\ Wy3\)\/2 - \(Ek3\ Wz3\)\/2, 
      \(Eo3\ Wx3\)\/2 + \(Ek3\ Wy3\)\/2 - \(Ej3\ Wz3\)\/2, 
      \(-\(\(Ek3\ Wx3\)\/2\)\) + \(Eo3\ Wy3\)\/2 + \(Ei3\ Wz3\)\/2, 
      \(Ej3\ Wx3\)\/2 - \(Ei3\ Wy3\)\/2 + \(Eo3\ Wz3\)\/2}\)], "Output"],

Cell[BoxData[
    \({0.120626194671606734`, \(-0.139595577758527799`\), 
      0.0349904426271462654`, 0.000309409766362696903`, 
      \(-0.0132679396903039625`\), \(-0.00553230252972424274`\), 
      0.00539955082173361766`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The same holds true for the local coordinate formulation."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular, Coordinates \[Rule] Local]\), 
    \(SetConstraints[cons]\), 
    \(Location[carrier]\), 
    \(Dt[Location[carrier], T]\), 
    \(% /. SolveMech[2.5, Solution \[Rule] Velocity]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X3, Y3, Z3, Eo3, Ei3, Ej3, Ek3}\)], "Output"],

Cell[BoxData[
    \({X3d, Y3d, Z3d, 
      \(-\(\(Ei3\ Wx3\)\/2\)\) - \(Ej3\ Wy3\)\/2 - \(Ek3\ Wz3\)\/2, 
      \(Eo3\ Wx3\)\/2 - \(Ek3\ Wy3\)\/2 + \(Ej3\ Wz3\)\/2, 
      \(Ek3\ Wx3\)\/2 + \(Eo3\ Wy3\)\/2 - \(Ei3\ Wz3\)\/2, 
      \(-\(\(Ej3\ Wx3\)\/2\)\) + \(Ei3\ Wy3\)\/2 + \(Eo3\ Wz3\)\/2}\)], 
  "Output"],

Cell[BoxData[
    \({0.120626194671606756`, \(-0.139595577758527822`\), 
      0.0349904426271462476`, 0.000309409766362696547`, 
      \(-0.0132679396903041735`\), \(-0.00553230252972385194`\), 
      0.005399550821733472`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that the only difference between the derivatives of the Euler \
parameters in terms of global or local coordinates is that a few of the signs \
are swapped."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Euler's Angles"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "As shown in the previous subsections, Euler parameters and their \
derivatives are directly related to the angular velocity vector of a spatial \
body, and a direct conversion between angular velocity and the derivatives of \
Euler parameters is possible. However, there is no vector representation of \
spatial angular orientation so other representations must be used.\n\nOne \
method of representing the angular orientation of a spatial body is to define \
a sequence of three finite rotations about three fixed axes that take a body \
from one orientation to another. These three rotations are called Euler's \
angles. Angular orientations represented by Euler's angles are readily \
converted to and from Euler parameters with a combination of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " output functions. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " does not provide a single function to make this conversion, because there \
are many possible combinations of successive rotations that can be used to \
represent the angular orientation of a body.\n\nThe following example shows \
the general procedure required to convert an angular orientation from a \
sequence of finite rotations to a set of Euler parameters. In this particular \
case, the sequence of rotations are the most commonly used Euler's angles."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Rotation 1 is a rotation ",
  StyleBox["phi",
    FontSlant->"Italic"],
  " about the global Z axis.\nRotation 2 is a rotation ",
  StyleBox["theta",
    FontSlant->"Italic"],
  " about the X axis in the new reference frame created by rotation 1. \n\
Rotation 3 is a rotation ",
  StyleBox["psi",
    FontSlant->"Italic"],
  " about the Z axis in the new reference frame created by rotation 2. "
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the three rotation angles, and vector constants for each axis."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(phi = 0.2; \)\), 
    \(\(theta = 1.1; \)\), 
    \(\(psi = 1.7; \)\), 
    \(\(X = {1, 0, 0}; \)\), 
    \(\(Y = {0, 1, 0}; \)\), 
    \(\(Z = {0, 0, 1}; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"A single rotation matrix that combines the three successive rotations is \
created by multiplying the rotation matrices associated with each. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(rotmat = 
      RotationMatrix[{phi, Z}].RotationMatrix[{theta, X}].RotationMatrix[{
            psi, Z}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(-0.215640689569704679`\), \(-0.960286633353053353`\), 
        0.177055569823038538`}, {0.415251503814056022`, 
        \(-0.254291770920438686`\), \(-0.87344254752233823`\)}, {
        0.883778977789168251`, \(-0.114827161619565187`\), 
        0.453596121425577347`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["EulerParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to convert the rotation matrix to a set of Euler \
parameters."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(eulpars = EulerParameters[rotmat]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.495899097835293911`, 0.382444427311066057`, 
      \(-0.356283874608327222`\), 0.693456664456352545`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The conversion of Euler parameters to a sequence of finite rotations is \
not such a straightforward process. The general procedure is to measure the \
angle between an appropriate pair of axes located in the global and local \
reference frames. The following example shows how to convert the Euler \
parameters ",
  StyleBox["eulpars",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " back to three Euler's angles. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Since ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output functions that return expressions in terms of the symbolic Euler \
parameters are used, a list of replacement rules is needed."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(eulrule = Thread[EulerParameters[2] \[Rule] eulpars]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({Eo2 \[Rule] 0.495899097835293911`, Ei2 \[Rule] 0.382444427311066057`, 
      Ej2 \[Rule] \(-0.356283874608327222`\), 
      Ek2 \[Rule] 0.693456664456352545`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the second Euler an",
  StyleBox["gle ",
    FontFamily->"Times"],
  StyleBox["theta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[". It is",
    FontFamily->"Times"],
  " the included angle between the two ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axes in the global and local reference frames."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(IncludedAngle[Z, Vector[2, Z]]\), 
    \(% /. eulrule\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ArcCos[2\ \((\(-\(1\/2\)\) + Ek2\^2 + Eo2\^2)\)]\)], "Output"],

Cell[BoxData[
    \(1.09999999999999985`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the first Euler an",
  StyleBox["gle ",
    FontFamily->"Times"],
  StyleBox["phi",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[". It is ",
    FontFamily->"Times"],
  "the angle between the local ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis and the global ",
  StyleBox["-Y",
    FontSlant->"Italic"],
  " axis, as viewed looking down onto the global ",
  StyleBox["X-Y",
    FontSlant->"Italic"],
  " plane."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ProjectedAngle[Vector[2, Z], \(-Y\), Z]\), 
    \(% /. eulrule\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ArcTan[\(-2\)\ \((Ej2\ Ek2 - Ei2\ Eo2)\), 2\ \((Ei2\ Ek2 + Ej2\ Eo2)\)]
      \)], "Output"],

Cell[BoxData[
    \(0.200000000000000266`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the last Euler ang",
  StyleBox["le ",
    FontFamily->"Times"],
  StyleBox["psi",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[". I",
    FontFamily->"Times"],
  "t is the angle between the local ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axis and the global ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis, as viewed looking down onto the local ",
  StyleBox["X-Y",
    FontSlant->"Italic"],
  " plane."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ProjectedAngle[Vector[2, Y], Z, Vector[2, Z]]\), 
    \(% /. eulrule\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(ArcTan[2\ \((Ej2\ Ek2 + Ei2\ Eo2)\), 2\ \((Ei2\ Ek2 - Ej2\ Eo2)\)]\)], 
  "Output"],

Cell[BoxData[
    \(1.70000000000000017`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Any angular orientation can be represented by a single finite rotation \
about a fixed axis. This single rotation angle and axis are directly related \
to the Euler parameters so a direct conversion can be made with the ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the single rotation about a fixed axis that is equivalent to the \
three successive rotations ",
  StyleBox["phi",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["theta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["psi",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rotation[rotmat]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.10385285467917793`, {0.440411296076454483`, 
        \(-0.4102856043442058`\), 0.798563468458310943`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Some readers may be more familiar with the use of quaternions to represent \
the orientations of spatial bodies. Quaternions are four-dimensional complex \
quantities, with associated rules for multiplication, that allow them to be \
used much like 3D rotation matrices. The numerical values of the four \
elements of the quaternion ",
  StyleBox["qw",
    FontSlant->"Italic"],
  " + ",
  StyleBox["qx",
    FontSlant->"Italic"],
  " ",
  StyleBox["i",
    FontWeight->"Bold"],
  " + ",
  StyleBox["qy",
    FontSlant->"Italic"],
  " ",
  StyleBox["j",
    FontWeight->"Bold"],
  " + ",
  StyleBox["qz",
    FontSlant->"Italic"],
  " ",
  StyleBox["k",
    FontWeight->"Bold"],
  " are equivalent to the numerical values of the four Euler parameters {",
  StyleBox["eo, ei, ej, ek",
    FontSlant->"Italic"],
  "} representing the same orientation. Quaternions and Euler parameters are \
notationally and conceptually quite different, but they are computationally \
equivalent."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The 2D pull-rod suspension model that was presented in Section 4.1 is used \
to demonstrate various methods of producing velocity and acceleration output \
with ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ". The model is redefined as follows in abbreviated form."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the complete pull-rod suspension model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\tBody[ground = 1, PointList \[Rule] {{0, 0}, {0, 10}}], \n
      \tBody[chassis = 2, 
        PointList 
          \[Rule] {{0, 0}, {0, 10}, {7.5, 4}, {8, 10}, {6, 3.125}, {9.5, 
              12}}, InitialGuess \[Rule] {{0, 2.5}, 0}], \n\t
      Body[carrier = 3, \n\t\t
        PointList \[Rule] {{0, 0}, {\(-1\), 9}, {1.25, \(-5.5\)}}, 
        InitialGuess \[Rule] {{22.0, 5.5}, 0}], \n\t
      Body[rocker = 4, \n\t\t
        PointList \[Rule] {{0, 0}, {4.1, \(-1.2\)}, {2., 0}}, 
        InitialGuess \[Rule] {{6.0, 5.6}, \(-.1\)}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[{
    \(rodlength =. \), 
    \(SetConstraints[\n\tRelativeY1[1, Point[chassis, 1], T], \n\t
      Translate2[2, Line[ground, 2, 1], Line[chassis, 2, 1]], \n\t
      RelativeDistance1[3, \n\t\tPoint[chassis, 3], Point[carrier, 1], 14.6], 
      \n\tRelativeDistance1[4, \n\t\tPoint[chassis, 4], Point[carrier, 2], 
        13.0], \n\tRelativeY1[5, Point[carrier, 3], 0], \n\t
      Revolute2[6, Point[chassis, 5], Point[rocker, 1]], \n\t
      RelativeDistance1[7, \n\t\tPoint[carrier, 2], Point[rocker, 3], 
        rodlength]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5 to prove that it still works. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rodlength = 16.2; \)\), 
    \(SolveMech[2.5] // Chop\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 2.5`\), ",", \(Th2 \[Rule] 0\), ",", 
        \(X3 \[Rule] 22.063575988270867`\), ",", 
        \(Y3 \[Rule] 5.46934271755340084`\), ",", 
        \(Th3 \[Rule] 0.0233305089099814511`\), ",", \(X4 \[Rule] 6.`\), ",", 
        \(Y4 \[Rule] 5.625`\), ",", 
        \(Th4 \[Rule] \(-0.418280852047447293`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Interpolation"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " provides a function that enhances the functionality of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function when used with a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. This function is described in Section 3.2, but this subsection \
covers its capability of automatically including higher-order data into the \
interpolated results."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TimeInterpolate[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["exp",
    FontSlant->"Italic"],
  StyleBox["r, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules1, rules2, ..., rulesn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object representing ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " as a function of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Each of the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  " must be a list of rules containing numerical replacements for all \
variables occurring in ",
  StyleBox["expr",
    FontSlant->"Italic"],
  ", as well as a numerical replacement for ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If velocity and acceleration terms are included in the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  ", ",
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " utilizes the higher-order data to generate a more accurate ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Interpolation utilities."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", we must have an expression to interpolate and a list of rules to \
interpolate it over."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["shocklength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the length of the damper in the pull-rod suspension model."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(shocklength = Distance[Point[chassis, 6], Point[rocker, 2]]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a list of three location solutions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(loctab = SolveMech[{3.0, 0.0}, 3]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The following plot shows a course representation of the shock length \
versus time. Only three data points were calculated by the previous call to ",
  
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 3, 1.5, and 0, so the ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphic consists of only two straight line segments."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here is a plot of the shock length versus time. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot1 = 
      ListPlot[{T, shocklength} /. loctab, PlotJoined \[Rule] True, 
        Frame \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 -1.40527 0.166814 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01265 -18 -4.5 ]
[-0.0125 .01265 0 4.5 ]
[-0.0125 .09606 -6 -4.5 ]
[-0.0125 .09606 0 4.5 ]
[-0.0125 .17947 -18 -4.5 ]
[-0.0125 .17947 0 4.5 ]
[-0.0125 .26287 -12 -4.5 ]
[-0.0125 .26287 0 4.5 ]
[-0.0125 .34628 -24 -4.5 ]
[-0.0125 .34628 0 4.5 ]
[-0.0125 .42969 -12 -4.5 ]
[-0.0125 .42969 0 4.5 ]
[-0.0125 .51309 -24 -4.5 ]
[-0.0125 .51309 0 4.5 ]
[-0.0125 .5965 -12 -4.5 ]
[-0.0125 .5965 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01265 m
.00625 .01265 L
s
[(8.5)] -0.0125 .01265 1 0 Mshowa
0 .09606 m
.00625 .09606 L
s
[(9)] -0.0125 .09606 1 0 Mshowa
0 .17947 m
.00625 .17947 L
s
[(9.5)] -0.0125 .17947 1 0 Mshowa
0 .26287 m
.00625 .26287 L
s
[(10)] -0.0125 .26287 1 0 Mshowa
0 .34628 m
.00625 .34628 L
s
[(10.5)] -0.0125 .34628 1 0 Mshowa
0 .42969 m
.00625 .42969 L
s
[(11)] -0.0125 .42969 1 0 Mshowa
0 .51309 m
.00625 .51309 L
s
[(11.5)] -0.0125 .51309 1 0 Mshowa
0 .5965 m
.00625 .5965 L
s
[(12)] -0.0125 .5965 1 0 Mshowa
.125 Mabswid
0 .02933 m
.00375 .02933 L
s
0 .04601 m
.00375 .04601 L
s
0 .0627 m
.00375 .0627 L
s
0 .07938 m
.00375 .07938 L
s
0 .11274 m
.00375 .11274 L
s
0 .12942 m
.00375 .12942 L
s
0 .1461 m
.00375 .1461 L
s
0 .16278 m
.00375 .16278 L
s
0 .19615 m
.00375 .19615 L
s
0 .21283 m
.00375 .21283 L
s
0 .22951 m
.00375 .22951 L
s
0 .24619 m
.00375 .24619 L
s
0 .27955 m
.00375 .27955 L
s
0 .29624 m
.00375 .29624 L
s
0 .31292 m
.00375 .31292 L
s
0 .3296 m
.00375 .3296 L
s
0 .36296 m
.00375 .36296 L
s
0 .37964 m
.00375 .37964 L
s
0 .39632 m
.00375 .39632 L
s
0 .41301 m
.00375 .41301 L
s
0 .44637 m
.00375 .44637 L
s
0 .46305 m
.00375 .46305 L
s
0 .47973 m
.00375 .47973 L
s
0 .49641 m
.00375 .49641 L
s
0 .52978 m
.00375 .52978 L
s
0 .54646 m
.00375 .54646 L
s
0 .56314 m
.00375 .56314 L
s
0 .57982 m
.00375 .57982 L
s
0 .61318 m
.00375 .61318 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01265 m
1 .01265 L
s
.99375 .09606 m
1 .09606 L
s
.99375 .17947 m
1 .17947 L
s
.99375 .26287 m
1 .26287 L
s
.99375 .34628 m
1 .34628 L
s
.99375 .42969 m
1 .42969 L
s
.99375 .51309 m
1 .51309 L
s
.99375 .5965 m
1 .5965 L
s
.125 Mabswid
.99625 .02933 m
1 .02933 L
s
.99625 .04601 m
1 .04601 L
s
.99625 .0627 m
1 .0627 L
s
.99625 .07938 m
1 .07938 L
s
.99625 .11274 m
1 .11274 L
s
.99625 .12942 m
1 .12942 L
s
.99625 .1461 m
1 .1461 L
s
.99625 .16278 m
1 .16278 L
s
.99625 .19615 m
1 .19615 L
s
.99625 .21283 m
1 .21283 L
s
.99625 .22951 m
1 .22951 L
s
.99625 .24619 m
1 .24619 L
s
.99625 .27955 m
1 .27955 L
s
.99625 .29624 m
1 .29624 L
s
.99625 .31292 m
1 .31292 L
s
.99625 .3296 m
1 .3296 L
s
.99625 .36296 m
1 .36296 L
s
.99625 .37964 m
1 .37964 L
s
.99625 .39632 m
1 .39632 L
s
.99625 .41301 m
1 .41301 L
s
.99625 .44637 m
1 .44637 L
s
.99625 .46305 m
1 .46305 L
s
.99625 .47973 m
1 .47973 L
s
.99625 .49641 m
1 .49641 L
s
.99625 .52978 m
1 .52978 L
s
.99625 .54646 m
1 .54646 L
s
.99625 .56314 m
1 .56314 L
s
.99625 .57982 m
1 .57982 L
s
.99625 .61318 m
1 .61318 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .60332 m
.5 .37794 L
.02381 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo000POol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0NOol5000NOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0OOol3000POol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0OOol20007Ool001moo`03001oo`00021oo`03001oo`0000Moo`03
001oo`00025oo`03001oogoo021oo`03001oogoo00Ioo`03001oo`00021oo`03001oogoo021oo`03
001oogoo00Moo`03001oo`00029oo`03001oogoo00Aoo`007goo00<007oo000087oo00<007oo0000
2Goo00<007ooOol07goo00<007ooOol087oo00<007ooOol027oo00<007ooOol07goo00<007ooOol0
87oo00<007ooOol027oo00<007ooOol07goo00<007ooOol01Goo000OOol00`00Ool0000POol00`00
Ool00007Ool2000ROol00`00Oomoo`0POol00`00Oomoo`06Ool2000ROol00`00Oomoo`0POol00`00
Oomoo`06Ool2000SOol00`00Oomoo`04Ool001moo`03001oo`00021oo`03001oo`0000Moo`03001o
ogoo025oo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo021oo`03001oo`00021oo`03001o
o`0000Moo`03001oogoo021oo`03001oo`0000Ioo`0087oo00<007ooOol087oo00<007ooOol01Woo
0`0087oo0P008Goo0P0027oo0`008Goo00<007ooOol087oo00<007ooOol01Woo0`008Goo00<007oo
Ool01Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`006gooo0000Goo000;
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool10001Ool000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0?Qoo`40005oo`002Woo
00<007oo00002Goo00<007ooOol00Woo0P0017oo00<007ooOol0lGoo0P000Goo000;Ool00`00Oomo
o`06Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`3aOol10001Ool000Yoo`03001oo`0000Moo`03
001oogoo00Aoo`03001oogoo00Eoo`800?5oo`40005oo`002goo00<007ooOol01Woo0`0017oo00<0
07ooOol01goo00<007ooOol0kWoo0@000Goo000KOol20009Ool00`00Oomoo`3/Ool20001Ool001]o
o`03001oogoo00Uoo`800>eoo`40005oo`006goo00<007ooOol02goo00<007ooOol0jWoo0@000Goo
000KOol00`00Oomoo`0<Ool00`00Oomoo`3YOol10001Ool001]oo`8000ioo`800>Qoo`80005oo`00
6goo00<007ooOol03goo00<007ooOol0iWoo0@000Goo000KOol00`00Oomoo`0@Ool00`00Oomoo`3U
Ool10001Ool001]oo`03001oogoo015oo`03001oogoo0>Aoo`40005oo`006goo00<007ooOol04Woo
0P00i7oo0@000Goo000KOol2000EOol00`00Oomoo`3POol20001Ool001]oo`03001oogoo01Eoo`03
001oogoo0>1oo`40005oo`006goo00<007ooOol05Woo0P00h7oo0@000Goo000KOol00`00Oomoo`0H
Ool00`00Oomoo`3MOol10001Ool001]oo`8001Yoo`03001oogoo0=]oo`80005oo`006goo00<007oo
Ool06Woo0P00g7oo0@000Goo000DOol20005Ool00`00Oomoo`0LOol00`00Oomoo`3IOol10001Ool0
01Ioo`03001oogoo009oo`03001oogoo01eoo`03001oogoo0=Qoo`40005oo`005Goo0P0017oo0P00
7goo0P00egoo0P000Goo000DOol00`00Ool00004Ool00`00Oomoo`0POol00`00Oomoo`3EOol10001
Ool001Aoo`03001oo`0000Aoo`03001oogoo025oo`03001oogoo0=Aoo`40005oo`005Goo0P0017oo
00<007ooOol08Woo00<007ooOol0dgoo0@000Goo000KOol2000TOol2003BOol20001Ool001]oo`03
001oogoo02Eoo`03001oogoo0=1oo`40005oo`006goo00<007ooOol09Woo00<007ooOol0cgoo0@00
0Goo000KOol00`00Oomoo`0WOol2003?Ool10001Ool001]oo`8002Yoo`03001oogoo0<]oo`80005o
o`006goo00<007ooOol0:Woo00<007ooOol0bgoo0@000Goo000KOol00`00Oomoo`0[Ool2003;Ool1
0001Ool001]oo`03001oogoo02eoo`03001oogoo0<Qoo`40005oo`006goo00<007ooOol0;Woo00<0
07ooOol0agoo0@000Goo000KOol2000`Ool00`00Oomoo`35Ool20001Ool001]oo`03001oogoo031o
o`800<Ioo`40005oo`006goo00<007ooOol0<Woo00<007ooOol0`goo0@000Goo000KOol00`00Oomo
o`0cOol00`00Oomoo`32Ool10001Ool001]oo`8003Eoo`800<5oo`80005oo`006goo00<007ooOol0
=Woo00<007ooOol0_goo0@000Goo000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`0gOol00`00Oomoo`2nOol10001Ool000aoo`03001oogoo00Eoo`03001oo`0000Aoo`03001o
ogoo03Qoo`800;ioo`40005oo`002goo0P002Goo00<007ooOol00Woo0P00>goo00<007ooOol0^Woo
0P000Goo000:Ool00`00Ool00007Ool20005Ool00`00Oomoo`0kOol00`00Oomoo`2jOol10001Ool0
00Yoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo03aoo`800;Yoo`40005oo`002goo0P00
1goo0`0017oo00<007ooOol0?Woo00<007ooOol0]goo0@000Goo000KOol20010Ool00`00Oomoo`2e
Ool20001Ool001]oo`03001oogoo041oo`03001oogoo0;Eoo`40005oo`006goo00<007ooOol0@Goo
0P00]Goo0@000Goo000KOol00`00Oomoo`13Ool00`00Oomoo`2bOol10001Ool001]oo`8004Eoo`03
001oogoo0;1oo`80005oo`006goo00<007ooOol0AGoo0P00/Goo0@000Goo000KOol00`00Oomoo`17
Ool00`00Oomoo`2^Ool10001Ool001]oo`03001oogoo04Qoo`03001oogoo0:eoo`40005oo`006goo
00<007ooOol0BGoo0P00[Goo0@000Goo000KOol2001<Ool00`00Oomoo`2YOol20001Ool001]oo`03
001oogoo04aoo`03001oogoo0:Uoo`40005oo`006goo00<007ooOol0CGoo00<007ooOol0Z7oo0@00
0Goo000KOol00`00Oomoo`1>Ool2002XOol10001Ool001]oo`80055oo`03001oogoo0:Aoo`80005o
o`006goo00<007ooOol0DGoo00<007ooOol0Y7oo0@000Goo000>Ool50002Ool00`00Oomoo`03Ool0
0`00Oomoo`1BOol2002TOol10001Ool0011oo`07001oogooOol007oo000017oo00<007ooOol0E7oo
00<007ooOol0XGoo0@000Goo000@Ool01`00Oomoogoo001oo`0000Aoo`8005Ioo`03001oogoo09mo
o`80005oo`0047oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1FOol2002POol10001Ool0011o
o`07001oogooOol007oo000017oo00<007ooOol0F7oo00<007ooOol0WGoo0@000Goo000?Ool20004
Ool00`00Oomoo`03Ool00`00Oomoo`1IOol00`00Oomoo`2LOol10001Ool001]oo`8005]oo`8009]o
o`80005oo`006goo00<007ooOol0G7oo00<007ooOol0VGoo0@000Goo000KOol00`00Oomoo`1MOol0
0`00Oomoo`2HOol10001Ool001]oo`03001oogoo05ioo`03001oogoo09Moo`40005oo`006goo0P00
H7oo0P00UWoo0P000Goo000KOol00`00Oomoo`1QOol00`00Oomoo`2DOol10001Ool001]oo`03001o
ogoo069oo`03001oogoo09=oo`40005oo`006goo00<007ooOol0Hgoo0P00Tgoo0@000Goo000KOol0
0`00Oomoo`1UOol00`00Oomoo`2@Ool10001Ool001]oo`8006Moo`03001oogoo08ioo`80005oo`00
6goo00<007ooOol0Igoo0P00Sgoo0@000Goo000KOol00`00Oomoo`1YOol00`00Oomoo`2<Ool10001
Ool001]oo`03001oogoo06Yoo`03001oogoo08]oo`40005oo`006goo0P00K7oo00<007ooOol0RGoo
0P000Goo000KOol00`00Oomoo`1/Ool2002:Ool10001Ool000Aoo`D0009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo06ioo`03001oogoo08Moo`40005oo`001Woo00L0
07ooOomoo`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`1_Ool00`00Oomoo`26Ool10001Ool0
00Ioo`07001oogooOol007oo00002Goo00<007ooOol00Woo0P00LGoo0P00QGoo0P000Goo0006Ool0
1`00Oomoogoo001oo`0000Moo`8000Eoo`03001oogoo079oo`03001oogoo08=oo`40005oo`001Woo
00L007ooOomoo`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`1cOol00`00Oomoo`22Ool10001
Ool000Eoo`8000Aoo`03001oogoo00Ioo`<000Aoo`03001oogoo07Aoo`80089oo`40005oo`006goo
0P00Mgoo00<007ooOol0OWoo0P000Goo000KOol00`00Oomoo`1gOol00`00Oomoo`1nOol10001Ool0
01]oo`03001oogoo07Qoo`8007ioo`40005oo`006goo00<007ooOol0NWoo00<007ooOol0Ngoo0@00
0Goo000KOol2001lOol2001jOol20001Ool001]oo`03001oogoo07eoo`8007Uoo`40005oo`006goo
00<007ooOol0Ogoo0P00Mgoo0@000Goo000KOol00`00Oomoo`21Ool2001eOol10001Ool001]oo`03
001oogoo08=oo`8007=oo`40005oo`006goo0P00QWoo0P00L7oo0P000Goo000KOol00`00Oomoo`27
Ool2001_Ool10001Ool001]oo`03001oogoo08Uoo`8006eoo`40005oo`006goo00<007ooOol0Rgoo
0P00Jgoo0@000Goo000KOol2002>Ool2001XOol20001Ool001]oo`03001oogoo08moo`8006Moo`40
005oo`003Woo2P000goo00<007ooOol0TGoo0`00I7oo0@000Goo000@Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`2DOol2001ROol10001Ool0011oo`03001oogoo009oo`03001oogoo00=o
o`8009Moo`8005moo`80005oo`0047oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0V7oo
0P00GWoo0@000Goo000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`2JOol2001LOol1
0001Ool000moo`8000=oo`8000Eoo`03001oogoo09aoo`8005Yoo`40005oo`006goo0P00Wgoo0P00
Egoo0P000Goo000KOol00`00Oomoo`2POol2001FOol10001Ool001]oo`03001oogoo0:9oo`8005Ao
o`40005oo`006goo00<007ooOol0Y7oo0P00DWoo0@000Goo000KOol2002WOol2001?Ool20001Ool0
01]oo`03001oogoo0:Qoo`8004ioo`40005oo`006goo00<007ooOol0ZWoo0`00Bgoo0@000Goo000K
Ool00`00Oomoo`2]Ool20019Ool10001Ool001]oo`03001oogoo0:moo`8004Moo`40005oo`006goo
0P00/Woo0P00A7oo0P000Goo000KOol00`00Oomoo`2cOol20013Ool10001Ool001]oo`03001oogoo
0;Eoo`80045oo`40005oo`006goo00<007ooOol0]goo0P00?goo0@000Goo000KOol2002jOol2000l
Ool20001Ool001]oo`03001oogoo0;]oo`8003]oo`40005oo`0017oo2P000Woo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol0_Goo0P00>Goo0@000Goo0006Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Ool00004Ool00`00Oomoo`2oOol2000gOol10001Ool000Ioo`03001oogoo009oo`03
001oogoo00Qoo`03001oogoo009oo`800<9oo`<003=oo`80005oo`001Woo00<007ooOol00Woo00<0
07ooOol01Woo0P001Goo00<007ooOol0a7oo0P00<Woo0@000Goo0006Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`36Ool2000`Ool10001Ool000Eoo`8000=oo`8000Qo
o`<000Aoo`03001oogoo0<Qoo`8002ioo`40005oo`006goo0P00bgoo0P00:goo0P000Goo000KOol0
0`00Oomoo`3<Ool2000ZOol10001Ool001]oo`03001oogoo0<ioo`8002Qoo`40005oo`006goo00<0
07ooOol0d7oo0P009Woo0@000Goo000KOol2003COol2000SOol20001Ool001]oo`03001oogoo0=Ao
o`80029oo`40005oo`006goo00<007ooOol0eWoo0P0087oo0@000Goo000KOol00`00Oomoo`3HOol2
000NOol10001Ool001]oo`03001oogoo0=Yoo`<001]oo`40005oo`006goo0P00gWoo0P0067oo0P00
0Goo000KOol00`00Oomoo`3OOol2000GOol10001Ool001]oo`03001oogoo0>5oo`8001Eoo`40005o
o`006goo00<007ooOol0hgoo0P004goo0@000Goo000KOol2003VOol2000@Ool20001Ool001]oo`03
001oogoo0>Moo`8000moo`40005oo`003Woo1@0000Aoo`00000000Aoo`03001oogoo0>Uoo`8000eo
o`40005oo`0047oo00D007ooOomoo`0000Ioo`03001oogoo0>]oo`8000]oo`40005oo`0047oo00<0
07ooOol00Woo00<007ooOol00goo0P00kWoo0P0027oo0P000Goo000@Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`3_Ool20007Ool10001Ool0011oo`07001oogooOol007oo000017oo00<0
07ooOol0lGoo0P001Goo0@000Goo000?Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`3hOol10001
Ool001]oo`8000Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo009oo`80005oo`006gooo0000Goo003oOolIOol00?mooaUoo`00
\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.414718, 8.08396, 0.0125136, 
  0.0238144}}]
}, Open  ]],

Cell[TextData[{
  "If we use ",
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to interpolate among the three points, the curve looks much smoother, but \
it is still a very poor representation, because there is no way for the ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to know that the curvature increases as ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " approaches zero."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here we interpolate the shock length function with a default ",
  StyleBox["InterpolationOrder",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is too high."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(intshocklen = TimeInterpolate[shocklength, loctab]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Interpolation::"inhr" \( : \ \) 
      "Requested order is too high; order has been reduced to \!\({2}\)."\)], 
  "Message"],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 3.`}}, "<>"]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Here is a plot of the zeroth order representation of ",
  StyleBox["shocklength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot2 = Plot[intshocklen[T], {T, 0, 3}, Frame \[Rule] True]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 -1.40527 0.166814 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01265 -18 -4.5 ]
[-0.0125 .01265 0 4.5 ]
[-0.0125 .09606 -6 -4.5 ]
[-0.0125 .09606 0 4.5 ]
[-0.0125 .17947 -18 -4.5 ]
[-0.0125 .17947 0 4.5 ]
[-0.0125 .26287 -12 -4.5 ]
[-0.0125 .26287 0 4.5 ]
[-0.0125 .34628 -24 -4.5 ]
[-0.0125 .34628 0 4.5 ]
[-0.0125 .42969 -12 -4.5 ]
[-0.0125 .42969 0 4.5 ]
[-0.0125 .51309 -24 -4.5 ]
[-0.0125 .51309 0 4.5 ]
[-0.0125 .5965 -12 -4.5 ]
[-0.0125 .5965 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01265 m
.00625 .01265 L
s
[(8.5)] -0.0125 .01265 1 0 Mshowa
0 .09606 m
.00625 .09606 L
s
[(9)] -0.0125 .09606 1 0 Mshowa
0 .17947 m
.00625 .17947 L
s
[(9.5)] -0.0125 .17947 1 0 Mshowa
0 .26287 m
.00625 .26287 L
s
[(10)] -0.0125 .26287 1 0 Mshowa
0 .34628 m
.00625 .34628 L
s
[(10.5)] -0.0125 .34628 1 0 Mshowa
0 .42969 m
.00625 .42969 L
s
[(11)] -0.0125 .42969 1 0 Mshowa
0 .51309 m
.00625 .51309 L
s
[(11.5)] -0.0125 .51309 1 0 Mshowa
0 .5965 m
.00625 .5965 L
s
[(12)] -0.0125 .5965 1 0 Mshowa
.125 Mabswid
0 .02933 m
.00375 .02933 L
s
0 .04601 m
.00375 .04601 L
s
0 .0627 m
.00375 .0627 L
s
0 .07938 m
.00375 .07938 L
s
0 .11274 m
.00375 .11274 L
s
0 .12942 m
.00375 .12942 L
s
0 .1461 m
.00375 .1461 L
s
0 .16278 m
.00375 .16278 L
s
0 .19615 m
.00375 .19615 L
s
0 .21283 m
.00375 .21283 L
s
0 .22951 m
.00375 .22951 L
s
0 .24619 m
.00375 .24619 L
s
0 .27955 m
.00375 .27955 L
s
0 .29624 m
.00375 .29624 L
s
0 .31292 m
.00375 .31292 L
s
0 .3296 m
.00375 .3296 L
s
0 .36296 m
.00375 .36296 L
s
0 .37964 m
.00375 .37964 L
s
0 .39632 m
.00375 .39632 L
s
0 .41301 m
.00375 .41301 L
s
0 .44637 m
.00375 .44637 L
s
0 .46305 m
.00375 .46305 L
s
0 .47973 m
.00375 .47973 L
s
0 .49641 m
.00375 .49641 L
s
0 .52978 m
.00375 .52978 L
s
0 .54646 m
.00375 .54646 L
s
0 .56314 m
.00375 .56314 L
s
0 .57982 m
.00375 .57982 L
s
0 .61318 m
.00375 .61318 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01265 m
1 .01265 L
s
.99375 .09606 m
1 .09606 L
s
.99375 .17947 m
1 .17947 L
s
.99375 .26287 m
1 .26287 L
s
.99375 .34628 m
1 .34628 L
s
.99375 .42969 m
1 .42969 L
s
.99375 .51309 m
1 .51309 L
s
.99375 .5965 m
1 .5965 L
s
.125 Mabswid
.99625 .02933 m
1 .02933 L
s
.99625 .04601 m
1 .04601 L
s
.99625 .0627 m
1 .0627 L
s
.99625 .07938 m
1 .07938 L
s
.99625 .11274 m
1 .11274 L
s
.99625 .12942 m
1 .12942 L
s
.99625 .1461 m
1 .1461 L
s
.99625 .16278 m
1 .16278 L
s
.99625 .19615 m
1 .19615 L
s
.99625 .21283 m
1 .21283 L
s
.99625 .22951 m
1 .22951 L
s
.99625 .24619 m
1 .24619 L
s
.99625 .27955 m
1 .27955 L
s
.99625 .29624 m
1 .29624 L
s
.99625 .31292 m
1 .31292 L
s
.99625 .3296 m
1 .3296 L
s
.99625 .36296 m
1 .36296 L
s
.99625 .37964 m
1 .37964 L
s
.99625 .39632 m
1 .39632 L
s
.99625 .41301 m
1 .41301 L
s
.99625 .44637 m
1 .44637 L
s
.99625 .46305 m
1 .46305 L
s
.99625 .47973 m
1 .47973 L
s
.99625 .49641 m
1 .49641 L
s
.99625 .52978 m
1 .52978 L
s
.99625 .54646 m
1 .54646 L
s
.99625 .56314 m
1 .56314 L
s
.99625 .57982 m
1 .57982 L
s
.99625 .61318 m
1 .61318 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .04932 L
.10458 .08603 L
.14415 .11953 L
.18221 .15084 L
.22272 .1832 L
.26171 .21341 L
.30316 .24451 L
.34309 .27348 L
.3815 .30043 L
.42237 .32813 L
.46172 .35383 L
.49955 .37766 L
.53984 .40208 L
.57861 .42465 L
.61984 .44764 L
.65954 .46881 L
.69774 .48826 L
.73838 .508 L
.77751 .52604 L
.81909 .5442 L
.85916 .56071 L
.89771 .57566 L
.93871 .59058 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo000POol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0NOol5000NOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0OOol3000POol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0OOol20007Ool001moo`03001oo`00021oo`03001oo`0000Moo`03
001oo`00025oo`03001oogoo021oo`03001oogoo00Ioo`03001oo`00021oo`03001oogoo021oo`03
001oogoo00Moo`03001oo`00029oo`03001oogoo00Aoo`007goo00<007oo000087oo00<007oo0000
2Goo00<007ooOol07goo00<007ooOol087oo00<007ooOol027oo00<007ooOol07goo00<007ooOol0
87oo00<007ooOol027oo00<007ooOol07goo00<007ooOol01Goo000OOol00`00Ool0000POol00`00
Ool00007Ool2000ROol00`00Oomoo`0POol00`00Oomoo`06Ool2000ROol00`00Oomoo`0POol00`00
Oomoo`06Ool2000SOol00`00Oomoo`04Ool001moo`03001oo`00021oo`03001oo`0000Moo`03001o
ogoo025oo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo021oo`03001oo`00021oo`03001o
o`0000Moo`03001oogoo021oo`03001oo`0000Ioo`0087oo00<007ooOol087oo00<007ooOol01Woo
0`0087oo0P008Goo0P0027oo0`008Goo00<007ooOol087oo00<007ooOol01Woo0`008Goo00<007oo
Ool01Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`006gooo0000Goo000;
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool10001Ool000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0?Qoo`40005oo`002Woo
00<007oo00002Goo00<007ooOol00Woo0P0017oo00<007ooOol0lGoo0P000Goo000;Ool00`00Oomo
o`06Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`3aOol10001Ool000Yoo`03001oo`0000Moo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo0?1oo`40005oo`002goo00<007ooOol01Woo0`00
17oo00<007ooOol01Woo00<007ooOol0kgoo0@000Goo000KOol20008Ool00`00Oomoo`3]Ool20001
Ool001]oo`03001oogoo00Qoo`03001oogoo0>eoo`40005oo`006goo00<007ooOol02Goo00<007oo
Ool0k7oo0@000Goo000KOol00`00Oomoo`0:Ool00`00Oomoo`3[Ool10001Ool001]oo`8000aoo`03
001oogoo0>Uoo`80005oo`006goo00<007ooOol037oo00<007ooOol0jGoo0@000Goo000KOol00`00
Oomoo`0=Ool00`00Oomoo`3XOol10001Ool001]oo`03001oogoo00ioo`800>Qoo`40005oo`006goo
00<007ooOol047oo00<007ooOol0iGoo0@000Goo000KOol2000BOol00`00Oomoo`3SOol20001Ool0
01]oo`03001oogoo019oo`03001oogoo0>=oo`40005oo`006goo00<007ooOol04goo00<007ooOol0
hWoo0@000Goo000KOol00`00Oomoo`0DOol2003ROol10001Ool001]oo`8001Moo`03001oogoo0=io
o`80005oo`006goo00<007ooOol05goo00<007ooOol0gWoo0@000Goo000DOol20005Ool00`00Oomo
o`0HOol00`00Oomoo`3MOol10001Ool001Ioo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo
0=aoo`40005oo`005Goo0P0017oo0P006goo00<007ooOol0fWoo0P000Goo000DOol00`00Ool00004
Ool00`00Oomoo`0KOol00`00Oomoo`3JOol10001Ool001Aoo`03001oo`0000Aoo`03001oogoo01ao
o`800=Yoo`40005oo`005Goo0P0017oo00<007ooOol07Woo00<007ooOol0egoo0@000Goo000KOol2
000POol00`00Oomoo`3EOol20001Ool001]oo`03001oogoo021oo`03001oogoo0=Eoo`40005oo`00
6goo00<007ooOol08Goo00<007ooOol0e7oo0@000Goo000KOol00`00Oomoo`0ROol00`00Oomoo`3C
Ool10001Ool001]oo`8002Aoo`800=9oo`80005oo`006goo00<007ooOol09Goo00<007ooOol0d7oo
0@000Goo000KOol00`00Oomoo`0VOol00`00Oomoo`3?Ool10001Ool001]oo`03001oogoo02Moo`03
001oogoo0<ioo`40005oo`006goo00<007ooOol0:7oo0P00cWoo0@000Goo000KOol2000[Ool00`00
Oomoo`3:Ool20001Ool001]oo`03001oogoo02]oo`03001oogoo0<Yoo`40005oo`006goo00<007oo
Ool0;7oo00<007ooOol0bGoo0@000Goo000KOol00`00Oomoo`0]Ool20039Ool10001Ool001]oo`80
031oo`03001oogoo0<Eoo`80005oo`006goo00<007ooOol0<7oo00<007ooOol0aGoo0@000Goo000:
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0aOol00`00Oomoo`34Ool10001
Ool000aoo`03001oogoo00Eoo`03001oo`0000Aoo`03001oogoo039oo`800<Aoo`40005oo`002goo
0P002Goo00<007ooOol00Woo0P00=Goo00<007ooOol0`7oo0P000Goo000:Ool00`00Ool00007Ool2
0005Ool00`00Oomoo`0eOol00`00Oomoo`30Ool10001Ool000Yoo`03001oo`0000Moo`03001oogoo
00Aoo`03001oogoo03Ioo`03001oogoo0;moo`40005oo`002goo0P001goo0`0017oo00<007ooOol0
=goo0P00_goo0@000Goo000KOol2000jOol00`00Oomoo`2kOol20001Ool001]oo`03001oogoo03Yo
o`03001oogoo0;]oo`40005oo`006goo00<007ooOol0>goo00<007ooOol0^Woo0@000Goo000KOol0
0`00Oomoo`0lOol2002jOol10001Ool001]oo`8003moo`03001oogoo0;Ioo`80005oo`006goo00<0
07ooOol0?goo00<007ooOol0]Woo0@000Goo000KOol00`00Oomoo`10Ool2002fOol10001Ool001]o
o`03001oogoo049oo`03001oogoo0;=oo`40005oo`006goo00<007ooOol0@goo00<007ooOol0/Woo
0@000Goo000KOol20015Ool2002aOol20001Ool001]oo`03001oogoo04Ioo`03001oogoo0:moo`40
005oo`006goo00<007ooOol0Agoo0P00[goo0@000Goo000KOol00`00Oomoo`19Ool00`00Oomoo`2/
Ool10001Ool001]oo`8004]oo`03001oogoo0:Yoo`80005oo`006goo00<007ooOol0Bgoo0P00Zgoo
0@000Goo000>Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`1=Ool00`00Oomoo`2XOol10001Ool0
011oo`07001oogooOol007oo000017oo00<007ooOol0CWoo00<007ooOol0Ygoo0@000Goo000@Ool0
1`00Oomoogoo001oo`0000Aoo`80051oo`03001oogoo0:Eoo`80005oo`0047oo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`1@Ool2002VOol10001Ool0011oo`07001oogooOol007oo000017oo00<0
07ooOol0DWoo00<007ooOol0Xgoo0@000Goo000?Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`1C
Ool00`00Oomoo`2ROol10001Ool001]oo`8005Eoo`800:5oo`80005oo`006goo00<007ooOol0EWoo
0P00X7oo0@000Goo000KOol00`00Oomoo`1HOol00`00Oomoo`2MOol10001Ool001]oo`03001oogoo
05Uoo`8009eoo`40005oo`006goo0P00G7oo0P00VWoo0P000Goo000KOol00`00Oomoo`1MOol00`00
Oomoo`2HOol10001Ool001]oo`03001oogoo05ioo`8009Qoo`40005oo`006goo00<007ooOol0H7oo
00<007ooOol0UGoo0@000Goo000KOol00`00Oomoo`1QOol00`00Oomoo`2DOol10001Ool001]oo`80
06=oo`8009=oo`80005oo`006goo00<007ooOol0I7oo00<007ooOol0TGoo0@000Goo000KOol00`00
Oomoo`1UOol2002AOol10001Ool001]oo`03001oogoo06Moo`03001oogoo08ioo`40005oo`006goo
0P00JGoo0P00SGoo0P000Goo000KOol00`00Oomoo`1ZOol00`00Oomoo`2;Ool10001Ool000Aoo`D0
009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo06]oo`03001oogoo
08Yoo`40005oo`001Woo00L007ooOomoo`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`1/Ool2
002:Ool10001Ool000Ioo`07001oogooOol007oo00002Goo00<007ooOol00Woo0P00Kgoo00<007oo
Ool0QWoo0P000Goo0006Ool01`00Oomoogoo001oo`0000Moo`8000Eoo`03001oogoo06moo`8008Mo
o`40005oo`001Woo00L007ooOomoo`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`1aOol00`00
Oomoo`24Ool10001Ool000Eoo`8000Aoo`03001oogoo00Ioo`<000Aoo`03001oogoo079oo`8008Ao
o`40005oo`006goo0P00MGoo00<007ooOol0P7oo0P000Goo000KOol00`00Oomoo`1eOol20021Ool1
0001Ool001]oo`03001oogoo07Moo`03001oogoo07ioo`40005oo`006goo00<007ooOol0N7oo0P00
OWoo0@000Goo000KOol2001kOol00`00Oomoo`1jOol20001Ool001]oo`03001oogoo07]oo`8007]o
o`40005oo`006goo00<007ooOol0OGoo0P00NGoo0@000Goo000KOol00`00Oomoo`1oOol2001gOol1
0001Ool001]oo`03001oogoo085oo`8007Eoo`40005oo`006goo0P00Q7oo0P00LWoo0P000Goo000K
Ool00`00Oomoo`25Ool00`00Oomoo`1`Ool10001Ool001]oo`03001oogoo08Ioo`80071oo`40005o
o`006goo00<007ooOol0R7oo00<007ooOol0KGoo0@000Goo000KOol2002:Ool2001/Ool20001Ool0
01]oo`03001oogoo08]oo`03001oogoo06Yoo`40005oo`003Woo2P000goo00<007ooOol0S7oo0P00
JWoo0@000Goo000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`2>Ool2001XOol10001
Ool0011oo`03001oogoo009oo`03001oogoo00=oo`80095oo`8006Eoo`80005oo`0047oo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0TWoo0P00I7oo0@000Goo000@Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2DOol2001ROol10001Ool000moo`8000=oo`8000Eoo`03001oogoo
09Ioo`80061oo`40005oo`006goo0P00VGoo0P00GGoo0P000Goo000KOol00`00Oomoo`2JOol2001L
Ool10001Ool001]oo`03001oogoo09aoo`8005Yoo`40005oo`006goo00<007ooOol0WWoo00<007oo
Ool0Egoo0@000Goo000KOol2002POol2001FOol20001Ool001]oo`03001oogoo0:5oo`8005Eoo`40
005oo`006goo00<007ooOol0Xgoo00<007ooOol0DWoo0@000Goo000KOol00`00Oomoo`2TOol2001B
Ool10001Ool001]oo`03001oogoo0:Ioo`80051oo`40005oo`006goo0P00ZGoo0P00CGoo0P000Goo
000KOol00`00Oomoo`2ZOol2001<Ool10001Ool001]oo`03001oogoo0:aoo`8004Yoo`40005oo`00
6goo00<007ooOol0[Woo0P00B7oo0@000Goo000KOol2002aOol20015Ool20001Ool001]oo`03001o
ogoo0;9oo`8004Aoo`40005oo`0017oo2P000Woo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool0]7oo0P00@Woo0@000Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00004Ool0
0`00Oomoo`2fOol3000oOol10001Ool000Ioo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo
009oo`800;Yoo`8003aoo`80005oo`001Woo00<007ooOol00Woo00<007ooOol01Woo0P001Goo00<0
07ooOol0^goo0P00>goo0@000Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`2mOol2000iOol10001Ool000Eoo`8000=oo`8000Qoo`<000Aoo`03001oogoo0;mo
o`<003Ioo`40005oo`006goo0P00`goo0P00<goo0P000Goo000KOol00`00Oomoo`34Ool2000bOol1
0001Ool001]oo`03001oogoo0<Ioo`80031oo`40005oo`006goo00<007ooOol0b7oo0P00;Woo0@00
0Goo000KOol2003;Ool3000ZOol20001Ool001]oo`03001oogoo0<eoo`8002Uoo`40005oo`006goo
00<007ooOol0cgoo0`009Woo0@000Goo000KOol00`00Oomoo`3BOol2000TOol10001Ool001]oo`03
001oogoo0=Aoo`<0025oo`40005oo`006goo0P00f7oo0P007Woo0P000Goo000KOol00`00Oomoo`3I
Ool3000LOol10001Ool001]oo`03001oogoo0=aoo`8001Yoo`40005oo`006goo00<007ooOol0gWoo
0`005goo0@000Goo000KOol2003ROol3000COol20001Ool001]oo`03001oogoo0>Aoo`@0011oo`40
005oo`003Woo1@0000Aoo`00000000Aoo`03001oogoo0>Qoo`<000eoo`40005oo`0047oo00D007oo
Oomoo`0000Ioo`03001oogoo0>]oo`8000]oo`40005oo`0047oo00<007ooOol00Woo00<007ooOol0
0goo0P00kWoo0P0027oo0P000Goo000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3_
Ool20007Ool10001Ool0011oo`07001oogooOol007oo000017oo00<007ooOol0lGoo0P001Goo0@00
0Goo000?Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`3hOol10001Ool001]oo`8000Aoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo009oo`80005oo`006gooo0000Goo003oOolIOol00?mooaUoo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.414718, 8.08396, 0.0125136, 
  0.0238144}}]
}, Open  ]],

Cell[TextData[{
  "A new table of three solution rules is calculated, but this time velocity \
and acceleration data are included. To avoid recalculating all of the \
location solution points, ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is passed the list of location solutions that have already been \
generated. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This generates a new list of solution rules using the existing rules as \
initial guesses. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(acctab = SolveMech[loctab, Solution \[Rule] Acceleration]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The higher-order slope and curvature information contained in ",
  StyleBox["acctab",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is automatically included in the new ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object returned by ",
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Again, we interpolate the ",
  StyleBox["shocklength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(intshocklen = TimeInterpolate[shocklength, acctab]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a plot of the second-order representation of ",
  StyleBox["shocklength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot3 = Plot[intshocklen[T], {T, 0, 3}, Frame \[Rule] True]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 -1.40527 0.166814 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01265 -18 -4.5 ]
[-0.0125 .01265 0 4.5 ]
[-0.0125 .09606 -6 -4.5 ]
[-0.0125 .09606 0 4.5 ]
[-0.0125 .17947 -18 -4.5 ]
[-0.0125 .17947 0 4.5 ]
[-0.0125 .26287 -12 -4.5 ]
[-0.0125 .26287 0 4.5 ]
[-0.0125 .34628 -24 -4.5 ]
[-0.0125 .34628 0 4.5 ]
[-0.0125 .42969 -12 -4.5 ]
[-0.0125 .42969 0 4.5 ]
[-0.0125 .51309 -24 -4.5 ]
[-0.0125 .51309 0 4.5 ]
[-0.0125 .5965 -12 -4.5 ]
[-0.0125 .5965 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01265 m
.00625 .01265 L
s
[(8.5)] -0.0125 .01265 1 0 Mshowa
0 .09606 m
.00625 .09606 L
s
[(9)] -0.0125 .09606 1 0 Mshowa
0 .17947 m
.00625 .17947 L
s
[(9.5)] -0.0125 .17947 1 0 Mshowa
0 .26287 m
.00625 .26287 L
s
[(10)] -0.0125 .26287 1 0 Mshowa
0 .34628 m
.00625 .34628 L
s
[(10.5)] -0.0125 .34628 1 0 Mshowa
0 .42969 m
.00625 .42969 L
s
[(11)] -0.0125 .42969 1 0 Mshowa
0 .51309 m
.00625 .51309 L
s
[(11.5)] -0.0125 .51309 1 0 Mshowa
0 .5965 m
.00625 .5965 L
s
[(12)] -0.0125 .5965 1 0 Mshowa
.125 Mabswid
0 .02933 m
.00375 .02933 L
s
0 .04601 m
.00375 .04601 L
s
0 .0627 m
.00375 .0627 L
s
0 .07938 m
.00375 .07938 L
s
0 .11274 m
.00375 .11274 L
s
0 .12942 m
.00375 .12942 L
s
0 .1461 m
.00375 .1461 L
s
0 .16278 m
.00375 .16278 L
s
0 .19615 m
.00375 .19615 L
s
0 .21283 m
.00375 .21283 L
s
0 .22951 m
.00375 .22951 L
s
0 .24619 m
.00375 .24619 L
s
0 .27955 m
.00375 .27955 L
s
0 .29624 m
.00375 .29624 L
s
0 .31292 m
.00375 .31292 L
s
0 .3296 m
.00375 .3296 L
s
0 .36296 m
.00375 .36296 L
s
0 .37964 m
.00375 .37964 L
s
0 .39632 m
.00375 .39632 L
s
0 .41301 m
.00375 .41301 L
s
0 .44637 m
.00375 .44637 L
s
0 .46305 m
.00375 .46305 L
s
0 .47973 m
.00375 .47973 L
s
0 .49641 m
.00375 .49641 L
s
0 .52978 m
.00375 .52978 L
s
0 .54646 m
.00375 .54646 L
s
0 .56314 m
.00375 .56314 L
s
0 .57982 m
.00375 .57982 L
s
0 .61318 m
.00375 .61318 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01265 m
1 .01265 L
s
.99375 .09606 m
1 .09606 L
s
.99375 .17947 m
1 .17947 L
s
.99375 .26287 m
1 .26287 L
s
.99375 .34628 m
1 .34628 L
s
.99375 .42969 m
1 .42969 L
s
.99375 .51309 m
1 .51309 L
s
.99375 .5965 m
1 .5965 L
s
.125 Mabswid
.99625 .02933 m
1 .02933 L
s
.99625 .04601 m
1 .04601 L
s
.99625 .0627 m
1 .0627 L
s
.99625 .07938 m
1 .07938 L
s
.99625 .11274 m
1 .11274 L
s
.99625 .12942 m
1 .12942 L
s
.99625 .1461 m
1 .1461 L
s
.99625 .16278 m
1 .16278 L
s
.99625 .19615 m
1 .19615 L
s
.99625 .21283 m
1 .21283 L
s
.99625 .22951 m
1 .22951 L
s
.99625 .24619 m
1 .24619 L
s
.99625 .27955 m
1 .27955 L
s
.99625 .29624 m
1 .29624 L
s
.99625 .31292 m
1 .31292 L
s
.99625 .3296 m
1 .3296 L
s
.99625 .36296 m
1 .36296 L
s
.99625 .37964 m
1 .37964 L
s
.99625 .39632 m
1 .39632 L
s
.99625 .41301 m
1 .41301 L
s
.99625 .44637 m
1 .44637 L
s
.99625 .46305 m
1 .46305 L
s
.99625 .47973 m
1 .47973 L
s
.99625 .49641 m
1 .49641 L
s
.99625 .52978 m
1 .52978 L
s
.99625 .54646 m
1 .54646 L
s
.99625 .56314 m
1 .56314 L
s
.99625 .57982 m
1 .57982 L
s
.99625 .61318 m
1 .61318 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .05996 L
.10458 .1046 L
.14415 .14232 L
.18221 .17514 L
.22272 .20683 L
.26171 .23473 L
.30316 .26218 L
.34309 .28705 L
.3815 .31 L
.42237 .33377 L
.46172 .35629 L
.49955 .37769 L
.53984 .40011 L
.57861 .42119 L
.61984 .44296 L
.65954 .46326 L
.69774 .48212 L
.73838 .5015 L
.77751 .51951 L
.81909 .538 L
.85916 .55526 L
.89771 .57142 L
.93871 .58823 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo000POol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0NOol5000NOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0OOol3000POol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0OOol20007Ool001moo`03001oo`00021oo`03001oo`0000Moo`03
001oo`00025oo`03001oogoo021oo`03001oogoo00Ioo`03001oo`00021oo`03001oogoo021oo`03
001oogoo00Moo`03001oo`00029oo`03001oogoo00Aoo`007goo00<007oo000087oo00<007oo0000
2Goo00<007ooOol07goo00<007ooOol087oo00<007ooOol027oo00<007ooOol07goo00<007ooOol0
87oo00<007ooOol027oo00<007ooOol07goo00<007ooOol01Goo000OOol00`00Ool0000POol00`00
Ool00007Ool2000ROol00`00Oomoo`0POol00`00Oomoo`06Ool2000ROol00`00Oomoo`0POol00`00
Oomoo`06Ool2000SOol00`00Oomoo`04Ool001moo`03001oo`00021oo`03001oo`0000Moo`03001o
ogoo025oo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo021oo`03001oo`00021oo`03001o
o`0000Moo`03001oogoo021oo`03001oo`0000Ioo`0087oo00<007ooOol087oo00<007ooOol01Woo
0`0087oo0P008Goo0P0027oo0`008Goo00<007ooOol087oo00<007ooOol01Woo0`008Goo00<007oo
Ool01Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`006gooo0000Goo000;
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool10001Ool000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0?Qoo`40005oo`002Woo
00<007oo00002Goo00<007ooOol00Woo0P0017oo00<007ooOol0lGoo0P000Goo000;Ool00`00Oomo
o`06Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`3aOol10001Ool000Yoo`03001oo`0000Moo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo0?5oo`40005oo`002goo00<007ooOol01Woo0`00
17oo00<007ooOol01Goo00<007ooOol0l7oo0@000Goo000KOol20007Ool00`00Oomoo`3^Ool20001
Ool001]oo`03001oogoo00Moo`03001oogoo0>ioo`40005oo`006goo00<007ooOol01goo00<007oo
Ool0kWoo0@000Goo000KOol00`00Oomoo`08Ool00`00Oomoo`3]Ool10001Ool001]oo`8000Yoo`03
001oogoo0>]oo`80005oo`006goo00<007ooOol02Woo00<007ooOol0jgoo0@000Goo000KOol00`00
Oomoo`0:Ool00`00Oomoo`3[Ool10001Ool001]oo`03001oogoo00]oo`03001oogoo0>Yoo`40005o
o`006goo00<007ooOol037oo00<007ooOol0jGoo0@000Goo000KOol2000>Ool00`00Oomoo`3WOol2
0001Ool001]oo`03001oogoo00ioo`03001oogoo0>Moo`40005oo`006goo00<007ooOol03goo00<0
07ooOol0iWoo0@000Goo000KOol00`00Oomoo`0@Ool00`00Oomoo`3UOol10001Ool001]oo`80019o
o`03001oogoo0>=oo`80005oo`006goo00<007ooOol04Woo00<007ooOol0hgoo0@000Goo000DOol2
0005Ool00`00Oomoo`0COol00`00Oomoo`3ROol10001Ool001Ioo`03001oogoo009oo`03001oogoo
01Aoo`03001oogoo0>5oo`40005oo`005Goo0P0017oo0P005Woo00<007ooOol0ggoo0P000Goo000D
Ool00`00Ool00004Ool00`00Oomoo`0FOol00`00Oomoo`3OOol10001Ool001Aoo`03001oo`0000Ao
o`03001oogoo01Moo`03001oogoo0=ioo`40005oo`005Goo0P0017oo00<007ooOol067oo00<007oo
Ool0gGoo0@000Goo000KOol2000JOol00`00Oomoo`3KOol20001Ool001]oo`03001oogoo01Yoo`03
001oogoo0=]oo`40005oo`006goo00<007ooOol06goo00<007ooOol0fWoo0@000Goo000KOol00`00
Oomoo`0LOol00`00Oomoo`3IOol10001Ool001]oo`8001ioo`03001oogoo0=Moo`80005oo`006goo
00<007ooOol07Woo00<007ooOol0egoo0@000Goo000KOol00`00Oomoo`0OOol00`00Oomoo`3FOol1
0001Ool001]oo`03001oogoo021oo`03001oogoo0=Eoo`40005oo`006goo00<007ooOol08Goo00<0
07ooOol0e7oo0@000Goo000KOol2000SOol00`00Oomoo`3BOol20001Ool001]oo`03001oogoo02=o
o`800==oo`40005oo`006goo00<007ooOol09Goo00<007ooOol0d7oo0@000Goo000KOol00`00Oomo
o`0VOol00`00Oomoo`3?Ool10001Ool001]oo`8002Qoo`03001oogoo0<eoo`80005oo`006goo00<0
07ooOol0:7oo0P00cWoo0@000Goo000:Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`0ZOol00`00Oomoo`3;Ool10001Ool000aoo`03001oogoo00Eoo`03001oo`0000Aoo`03001o
ogoo02]oo`03001oogoo0<Yoo`40005oo`002goo0P002Goo00<007ooOol00Woo0P00;Goo00<007oo
Ool0b7oo0P000Goo000:Ool00`00Ool00007Ool20005Ool00`00Oomoo`0]Ool20039Ool10001Ool0
00Yoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo02moo`03001oogoo0<Ioo`40005oo`00
2goo0P001goo0`0017oo00<007ooOol0<7oo00<007ooOol0aGoo0@000Goo000KOol2000bOol00`00
Oomoo`33Ool20001Ool001]oo`03001oogoo039oo`800<Aoo`40005oo`006goo00<007ooOol0=7oo
00<007ooOol0`Goo0@000Goo000KOol00`00Oomoo`0eOol00`00Oomoo`30Ool10001Ool001]oo`80
03Moo`800;moo`80005oo`006goo00<007ooOol0>7oo00<007ooOol0_Goo0@000Goo000KOol00`00
Oomoo`0iOol00`00Oomoo`2lOol10001Ool001]oo`03001oogoo03Yoo`800;aoo`40005oo`006goo
00<007ooOol0?7oo00<007ooOol0^Goo0@000Goo000KOol2000nOol2002hOol20001Ool001]oo`03
001oogoo03moo`03001oogoo0;Ioo`40005oo`006goo00<007ooOol0@7oo0P00]Woo0@000Goo000K
Ool00`00Oomoo`12Ool00`00Oomoo`2cOol10001Ool001]oo`8004Aoo`03001oogoo0;5oo`80005o
o`006goo00<007ooOol0A7oo0P00/Woo0@000Goo000>Ool50002Ool00`00Oomoo`03Ool00`00Oomo
o`16Ool00`00Oomoo`2_Ool10001Ool0011oo`07001oogooOol007oo000017oo00<007ooOol0Agoo
0P00[goo0@000Goo000@Ool01`00Oomoogoo001oo`0000Aoo`8004Yoo`03001oogoo0:]oo`80005o
o`0047oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1:Ool2002/Ool10001Ool0011oo`07001o
ogooOol007oo000017oo00<007ooOol0C7oo0P00ZWoo0@000Goo000?Ool20004Ool00`00Oomoo`03
Ool00`00Oomoo`1>Ool00`00Oomoo`2WOol10001Ool001]oo`80051oo`800:Ioo`80005oo`006goo
00<007ooOol0DGoo0P00YGoo0@000Goo000KOol00`00Oomoo`1COol00`00Oomoo`2ROol10001Ool0
01]oo`03001oogoo05Aoo`800:9oo`40005oo`006goo0P00Egoo0P00Wgoo0P000Goo000KOol00`00
Oomoo`1HOol00`00Oomoo`2MOol10001Ool001]oo`03001oogoo05Uoo`8009eoo`40005oo`006goo
00<007ooOol0Fgoo0P00Vgoo0@000Goo000KOol00`00Oomoo`1MOol00`00Oomoo`2HOol10001Ool0
01]oo`8005moo`8009Moo`80005oo`006goo00<007ooOol0H7oo0P00UWoo0@000Goo000KOol00`00
Oomoo`1ROol00`00Oomoo`2COol10001Ool001]oo`03001oogoo06=oo`8009=oo`40005oo`006goo
0P00IWoo0P00T7oo0P000Goo000KOol00`00Oomoo`1WOol00`00Oomoo`2>Ool10001Ool000Aoo`D0
009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo06Qoo`8008ioo`40
005oo`001Woo00L007ooOomoo`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`1ZOol2002<Ool1
0001Ool000Ioo`07001oogooOol007oo00002Goo00<007ooOol00Woo0P00KGoo0P00RGoo0P000Goo
0006Ool01`00Oomoogoo001oo`0000Moo`8000Eoo`03001oogoo06ioo`8008Qoo`40005oo`001Woo
00L007ooOomoo`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`1`Ool20026Ool10001Ool000Eo
o`8000Aoo`03001oogoo00Ioo`<000Aoo`03001oogoo079oo`8008Aoo`40005oo`006goo0P00MGoo
00<007ooOol0P7oo0P000Goo000KOol00`00Oomoo`1eOol20021Ool10001Ool001]oo`03001oogoo
07Moo`03001oogoo07ioo`40005oo`006goo00<007ooOol0N7oo0P00OWoo0@000Goo000KOol2001k
Ool00`00Oomoo`1jOol20001Ool001]oo`03001oogoo07]oo`8007]oo`40005oo`006goo00<007oo
Ool0OGoo0P00NGoo0@000Goo000KOol00`00Oomoo`1oOol2001gOol10001Ool001]oo`03001oogoo
085oo`8007Eoo`40005oo`006goo0P00Q7oo0P00LWoo0P000Goo000KOol00`00Oomoo`25Ool00`00
Oomoo`1`Ool10001Ool001]oo`03001oogoo08Ioo`80071oo`40005oo`006goo00<007ooOol0R7oo
0P00KWoo0@000Goo000KOol2002;Ool2001[Ool20001Ool001]oo`03001oogoo08aoo`8006Yoo`40
005oo`003Woo2P000goo00<007ooOol0SWoo0P00J7oo0@000Goo000@Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`2@Ool2001VOol10001Ool0011oo`03001oogoo009oo`03001oogoo00=o
o`8009=oo`8006=oo`80005oo`0047oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0U7oo
0P00HWoo0@000Goo000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`2FOol2001POol1
0001Ool000moo`8000=oo`8000Eoo`03001oogoo09Qoo`8005ioo`40005oo`006goo0P00Vgoo0P00
Fgoo0P000Goo000KOol00`00Oomoo`2LOol2001JOol10001Ool001]oo`03001oogoo09ioo`8005Qo
o`40005oo`006goo00<007ooOol0X7oo0P00EWoo0@000Goo000KOol2002SOol2001COol20001Ool0
01]oo`03001oogoo0:Aoo`80059oo`40005oo`006goo00<007ooOol0YWoo0P00D7oo0@000Goo000K
Ool00`00Oomoo`2XOol2001>Ool10001Ool001]oo`03001oogoo0:Yoo`8004aoo`40005oo`006goo
0P00[Goo0P00BGoo0P000Goo000KOol00`00Oomoo`2^Ool20018Ool10001Ool001]oo`03001oogoo
0;1oo`8004Ioo`40005oo`006goo00<007ooOol0/Woo0P00A7oo0@000Goo000KOol2002eOol20011
Ool20001Ool001]oo`03001oogoo0;Ioo`80041oo`40005oo`0017oo2P000Woo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol0^7oo0P00?Woo0@000Goo0006Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Ool00004Ool00`00Oomoo`2jOol2000lOol10001Ool000Ioo`03001oogoo009oo`03
001oogoo00Qoo`03001oogoo009oo`800;eoo`8003Uoo`80005oo`001Woo00<007ooOol00Woo00<0
07ooOol01Woo0P001Goo00<007ooOol0_Woo0P00>7oo0@000Goo0006Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`30Ool2000fOol10001Ool000Eoo`8000=oo`8000Qo
o`<000Aoo`03001oogoo0<9oo`<003=oo`40005oo`006goo0P00aWoo0P00<7oo0P000Goo000KOol0
0`00Oomoo`37Ool3000^Ool10001Ool001]oo`03001oogoo0<Yoo`8002aoo`40005oo`006goo00<0
07ooOol0c7oo0P00:Woo0@000Goo000KOol2003?Ool2000WOol20001Ool001]oo`03001oogoo0=1o
o`8002Ioo`40005oo`006goo00<007ooOol0dWoo0P0097oo0@000Goo000KOol00`00Oomoo`3DOol3
000QOol10001Ool001]oo`03001oogoo0=Moo`8001moo`40005oo`006goo0P00fWoo0`006goo0P00
0Goo000KOol00`00Oomoo`3LOol2000JOol10001Ool001]oo`03001oogoo0=ioo`<001Moo`40005o
o`006goo00<007ooOol0hGoo0P005Goo0@000Goo000KOol2003TOol3000AOol20001Ool001]oo`03
001oogoo0>Ioo`80011oo`40005oo`003Woo1@0000Aoo`00000000Aoo`03001oogoo0>Qoo`<000eo
o`40005oo`0047oo00D007ooOomoo`0000Ioo`03001oogoo0>]oo`8000]oo`40005oo`0047oo00<0
07ooOol00Woo00<007ooOol00goo0P00kWoo0P0027oo0P000Goo000@Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`3_Ool20007Ool10001Ool0011oo`07001oogooOol007oo000017oo00<0
07ooOol0lGoo0P001Goo0@000Goo000?Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`3hOol10001
Ool001]oo`8000Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo00Eoo`03001oogoo009oo`80005oo`006gooo0000Goo003oOolIOol00?mooaUoo`00
\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.414718, 8.08396, 0.0125136, 
  0.0238144}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now we show the three plots together. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[{plot1, plot2, plot3}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 -1.40527 0.166814 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.18254 -0.0125 -9 -9 ]
[.18254 -0.0125 9 0 ]
[.34127 -0.0125 -3 -9 ]
[.34127 -0.0125 3 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.65873 -0.0125 -3 -9 ]
[.65873 -0.0125 3 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01265 -18 -4.5 ]
[-0.0125 .01265 0 4.5 ]
[-0.0125 .09606 -6 -4.5 ]
[-0.0125 .09606 0 4.5 ]
[-0.0125 .17947 -18 -4.5 ]
[-0.0125 .17947 0 4.5 ]
[-0.0125 .26287 -12 -4.5 ]
[-0.0125 .26287 0 4.5 ]
[-0.0125 .34628 -24 -4.5 ]
[-0.0125 .34628 0 4.5 ]
[-0.0125 .42969 -12 -4.5 ]
[-0.0125 .42969 0 4.5 ]
[-0.0125 .51309 -24 -4.5 ]
[-0.0125 .51309 0 4.5 ]
[-0.0125 .5965 -12 -4.5 ]
[-0.0125 .5965 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.18254 0 m
.18254 .00625 L
s
[(0.5)] .18254 -0.0125 0 1 Mshowa
.34127 0 m
.34127 .00625 L
s
[(1)] .34127 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(1.5)] .5 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(2)] .65873 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(2.5)] .81746 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(3)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01265 m
.00625 .01265 L
s
[(8.5)] -0.0125 .01265 1 0 Mshowa
0 .09606 m
.00625 .09606 L
s
[(9)] -0.0125 .09606 1 0 Mshowa
0 .17947 m
.00625 .17947 L
s
[(9.5)] -0.0125 .17947 1 0 Mshowa
0 .26287 m
.00625 .26287 L
s
[(10)] -0.0125 .26287 1 0 Mshowa
0 .34628 m
.00625 .34628 L
s
[(10.5)] -0.0125 .34628 1 0 Mshowa
0 .42969 m
.00625 .42969 L
s
[(11)] -0.0125 .42969 1 0 Mshowa
0 .51309 m
.00625 .51309 L
s
[(11.5)] -0.0125 .51309 1 0 Mshowa
0 .5965 m
.00625 .5965 L
s
[(12)] -0.0125 .5965 1 0 Mshowa
.125 Mabswid
0 .02933 m
.00375 .02933 L
s
0 .04601 m
.00375 .04601 L
s
0 .0627 m
.00375 .0627 L
s
0 .07938 m
.00375 .07938 L
s
0 .11274 m
.00375 .11274 L
s
0 .12942 m
.00375 .12942 L
s
0 .1461 m
.00375 .1461 L
s
0 .16278 m
.00375 .16278 L
s
0 .19615 m
.00375 .19615 L
s
0 .21283 m
.00375 .21283 L
s
0 .22951 m
.00375 .22951 L
s
0 .24619 m
.00375 .24619 L
s
0 .27955 m
.00375 .27955 L
s
0 .29624 m
.00375 .29624 L
s
0 .31292 m
.00375 .31292 L
s
0 .3296 m
.00375 .3296 L
s
0 .36296 m
.00375 .36296 L
s
0 .37964 m
.00375 .37964 L
s
0 .39632 m
.00375 .39632 L
s
0 .41301 m
.00375 .41301 L
s
0 .44637 m
.00375 .44637 L
s
0 .46305 m
.00375 .46305 L
s
0 .47973 m
.00375 .47973 L
s
0 .49641 m
.00375 .49641 L
s
0 .52978 m
.00375 .52978 L
s
0 .54646 m
.00375 .54646 L
s
0 .56314 m
.00375 .56314 L
s
0 .57982 m
.00375 .57982 L
s
0 .61318 m
.00375 .61318 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01265 m
1 .01265 L
s
.99375 .09606 m
1 .09606 L
s
.99375 .17947 m
1 .17947 L
s
.99375 .26287 m
1 .26287 L
s
.99375 .34628 m
1 .34628 L
s
.99375 .42969 m
1 .42969 L
s
.99375 .51309 m
1 .51309 L
s
.99375 .5965 m
1 .5965 L
s
.125 Mabswid
.99625 .02933 m
1 .02933 L
s
.99625 .04601 m
1 .04601 L
s
.99625 .0627 m
1 .0627 L
s
.99625 .07938 m
1 .07938 L
s
.99625 .11274 m
1 .11274 L
s
.99625 .12942 m
1 .12942 L
s
.99625 .1461 m
1 .1461 L
s
.99625 .16278 m
1 .16278 L
s
.99625 .19615 m
1 .19615 L
s
.99625 .21283 m
1 .21283 L
s
.99625 .22951 m
1 .22951 L
s
.99625 .24619 m
1 .24619 L
s
.99625 .27955 m
1 .27955 L
s
.99625 .29624 m
1 .29624 L
s
.99625 .31292 m
1 .31292 L
s
.99625 .3296 m
1 .3296 L
s
.99625 .36296 m
1 .36296 L
s
.99625 .37964 m
1 .37964 L
s
.99625 .39632 m
1 .39632 L
s
.99625 .41301 m
1 .41301 L
s
.99625 .44637 m
1 .44637 L
s
.99625 .46305 m
1 .46305 L
s
.99625 .47973 m
1 .47973 L
s
.99625 .49641 m
1 .49641 L
s
.99625 .52978 m
1 .52978 L
s
.99625 .54646 m
1 .54646 L
s
.99625 .56314 m
1 .56314 L
s
.99625 .57982 m
1 .57982 L
s
.99625 .61318 m
1 .61318 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.97619 .60332 m
.5 .37794 L
.02381 .01472 L
s
.02381 .01472 m
.06244 .04932 L
.10458 .08603 L
.14415 .11953 L
.18221 .15084 L
.22272 .1832 L
.26171 .21341 L
.30316 .24451 L
.34309 .27348 L
.3815 .30043 L
.42237 .32813 L
.46172 .35383 L
.49955 .37766 L
.53984 .40208 L
.57861 .42465 L
.61984 .44764 L
.65954 .46881 L
.69774 .48826 L
.73838 .508 L
.77751 .52604 L
.81909 .5442 L
.85916 .56071 L
.89771 .57566 L
.93871 .59058 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .05996 L
.10458 .1046 L
.14415 .14232 L
.18221 .17514 L
.22272 .20683 L
.26171 .23473 L
.30316 .26218 L
.34309 .28705 L
.3815 .31 L
.42237 .33377 L
.46172 .35629 L
.49955 .37769 L
.53984 .40011 L
.57861 .42119 L
.61984 .44296 L
.65954 .46326 L
.69774 .48212 L
.73838 .5015 L
.77751 .51951 L
.81909 .538 L
.85916 .55526 L
.89771 .57142 L
.93871 .58823 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo000POol00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0NOol5000NOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0OOol3000POol30003Ool0
0`00Oomoo`02Ool00`00Oomoo`0OOol20007Ool001moo`03001oo`00021oo`03001oo`0000Moo`03
001oo`00025oo`03001oogoo021oo`03001oogoo00Ioo`03001oo`00021oo`03001oogoo021oo`03
001oogoo00Moo`03001oo`00029oo`03001oogoo00Aoo`007goo00<007oo000087oo00<007oo0000
2Goo00<007ooOol07goo00<007ooOol087oo00<007ooOol027oo00<007ooOol07goo00<007ooOol0
87oo00<007ooOol027oo00<007ooOol07goo00<007ooOol01Goo000OOol00`00Ool0000POol00`00
Ool00007Ool2000ROol00`00Oomoo`0POol00`00Oomoo`06Ool2000ROol00`00Oomoo`0POol00`00
Oomoo`06Ool2000SOol00`00Oomoo`04Ool001moo`03001oo`00021oo`03001oo`0000Moo`03001o
ogoo025oo`03001oogoo021oo`03001oogoo00Ioo`03001oogoo021oo`03001oo`00021oo`03001o
o`0000Moo`03001oogoo021oo`03001oo`0000Ioo`0087oo00<007ooOol087oo00<007ooOol01Woo
0`0087oo0P008Goo0P0027oo0`008Goo00<007ooOol087oo00<007ooOol01Woo0`008Goo00<007oo
Ool01Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`006gooo0000Goo000;
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool10001Ool000Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo0?Qoo`40005oo`002Woo
00<007oo00002Goo00<007ooOol00Woo0P0017oo00<007ooOol0lGoo0P000Goo000;Ool00`00Oomo
o`06Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`3aOol10001Ool000Yoo`03001oo`0000Moo`03
001oogoo00Aoo`03001oogoo00Aoo`<00?5oo`40005oo`002goo00<007ooOol01Woo0`0017oo00<0
07ooOol01Goo0`00l7oo0@000Goo000KOol20007Ool3003^Ool20001Ool001]oo`03001oogoo00Mo
o`@00>eoo`40005oo`006goo00<007ooOol01goo00D007oo001oo`000>aoo`40005oo`006goo00<0
07ooOol027oo00D007oo001oo`000>]oo`40005oo`006goo0P002Woo00@007oo001oo`800>Qoo`80
005oo`006goo00<007ooOol02Woo00<007oo00000Woo00<007ooOol0iWoo0@000Goo000KOol00`00
Oomoo`0:Ool01000Oomoo`000Woo00<007ooOol0iGoo0@000Goo000KOol00`00Oomoo`0;Ool00`00
Oomoo`0200000goo001oo`3UOol10001Ool001]oo`03001oogoo00aoo`06001oogooOol007oo0P00
i7oo0@000Goo000KOol2000>Ool01@00Oomoogoo00000Woo00<007ooOol0h7oo0P000Goo000KOol0
0`00Oomoo`0>Ool01@00Oomoogoo00000Woo00<007ooOol0h7oo0@000Goo000KOol00`00Oomoo`0?
Ool01@00Oomoogoo00000Woo0P00h7oo0@000Goo000KOol00`00Oomoo`0@Ool01000Oomoogoo0P00
0Woo00<007ooOol0gGoo0@000Goo000KOol2000BOol00`00Oomoo`02Ool01000Oomoo`00gGoo0P00
0Goo000KOol00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`02003LOol10001Ool001Aoo`80
00Eoo`03001oogoo01=oo`03001oogoo009oo`05001oogooOol0003KOol10001Ool001Ioo`03001o
ogoo009oo`03001oogoo01Aoo`03001oogoo009oo`05001oogooOol0003JOol10001Ool001Eoo`80
00Aoo`8001Ioo`03001oogoo009oo`04001oogooOol2003GOol20001Ool001Aoo`03001oo`0000Ao
o`03001oogoo01Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo0=Eoo`40005oo`0057oo
00<007oo000017oo00<007ooOol05goo00<007ooOol00Woo0P000goo00<007ooOol0e7oo0@000Goo
000EOol20004Ool00`00Oomoo`0HOol00`00Oomoo`03Ool01@00Oomoogoo0000eGoo0@000Goo000K
Ool2000JOol00`00Oomoo`03Ool01000Oomoogoo0P00dWoo0P000Goo000KOol00`00Oomoo`0JOol0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`3@Ool10001Ool001]oo`03001oogoo01]oo`03
001oogoo00=oo`03001oogoo009oo`03001oogoo0<moo`40005oo`006goo00<007ooOol077oo00<0
07ooOol00goo00<007ooOol00Woo0P00cgoo0@000Goo000KOol2000NOol00`00Oomoo`03Ool20004
Ool00`00Oomoo`3;Ool20001Ool001]oo`03001oogoo01ioo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo0<]oo`40005oo`006goo00<007ooOol07goo00<007ooOol017oo00<007ooOol00Woo
0P00bgoo0@000Goo000KOol00`00Oomoo`0POol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`38Ool10001Ool001]oo`03001oogoo025oo`03001oogoo00Aoo`8000Aoo`03001oogoo0<Moo`40
005oo`006goo0P008goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0aGoo0P000Goo000K
Ool00`00Oomoo`0SOol20006Ool00`00Oomoo`02Ool20036Ool10001Ool001]oo`03001oogoo02Eo
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo0<=oo`40005oo`006goo00<007ooOol09Woo
00<007ooOol017oo0P0017oo00<007ooOol0`Woo0@000Goo000KOol2000XOol00`00Oomoo`05Ool0
0`00Oomoo`02Ool20031Ool20001Ool001]oo`03001oogoo02Qoo`8000Ioo`03001oogoo00=oo`03
001oogoo0;moo`40005oo`002Woo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
:Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol0_Woo0@000Goo000<Ool00`00Oomoo`05
Ool00`00Ool00004Ool00`00Oomoo`0[Ool00`00Oomoo`04Ool20004Ool2002nOol10001Ool000]o
o`8000Uoo`03001oogoo009oo`8002eoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo0;Yo
o`80005oo`002Woo00<007oo00001goo0P001Goo00<007ooOol0;Goo0P001Woo00<007ooOol00goo
00<007ooOol0^Woo0@000Goo000:Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0_Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool2002jOol10001Ool000]oo`8000Moo`<000Aoo`03001oogoo
031oo`03001oogoo00Aoo`8000Eoo`03001oogoo0;Moo`40005oo`006goo0P00<Woo00<007ooOol0
1Goo00<007ooOol00goo00<007ooOol0]Goo0P000Goo000KOol00`00Oomoo`0bOol20006Ool00`00
Oomoo`03Ool00`00Oomoo`2eOol10001Ool001]oo`03001oogoo03Aoo`03001oogoo00Aoo`03001o
ogoo00=oo`800;Eoo`40005oo`006goo00<007ooOol0=Goo00<007ooOol017oo0P001Goo00<007oo
Ool0/Woo0@000Goo000KOol2000gOol20006Ool00`00Oomoo`03Ool00`00Oomoo`2`Ool20001Ool0
01]oo`03001oogoo03Qoo`03001oogoo00Aoo`03001oogoo00=oo`800;5oo`40005oo`006goo00<0
07ooOol0>Goo00<007ooOol017oo0P001Goo00<007ooOol0[Woo0@000Goo000KOol00`00Oomoo`0j
Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`2]Ool10001Ool001]oo`03001oogoo03aoo`03001o
ogoo00Aoo`03001oogoo00=oo`800:eoo`40005oo`006goo0P00?Woo0P001Goo0P001Goo00<007oo
Ool0ZGoo0P000Goo000KOol00`00Oomoo`0oOol00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`2YOol10001Ool001]oo`03001oogoo041oo`8000Eoo`8000Aoo`03001oogoo0:Qoo`40005oo`00
6goo00<007ooOol0@Woo00<007ooOol017oo00<007ooOol00Woo0P00Z7oo0@000Goo000KOol20014
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`2TOol20001Ool001]oo`03001oogoo04Ao
o`8000Eoo`8000Aoo`03001oogoo0:Aoo`40005oo`003Woo1@000Woo00<007ooOol00goo00<007oo
Ool0AWoo00<007ooOol017oo00<007ooOol00Woo0P00Y7oo0@000Goo000@Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo04Moo`8000Eoo`03001oogoo00=oo`03001oogoo0:5oo`40005oo`0047oo
00L007ooOomoo`00Ool00004Ool2001:Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`2O
Ool20001Ool0011oo`07001oogooOol007oo000017oo00<007ooOol0BWoo0P0017oo0P0017oo0P00
X7oo0@000Goo000@Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo04aoo`8000Aoo`03001oogoo
00=oo`03001oogoo09eoo`40005oo`003goo0P0017oo00<007ooOol00goo00<007ooOol0CWoo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0W7oo0@000Goo000KOol2001@Ool20003Ool20004
Ool2002KOol20001Ool001]oo`03001oogoo055oo`8000=oo`8000Aoo`03001oogoo09Uoo`40005o
o`006goo00<007ooOol0Dgoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0V7oo0@000Goo
000KOol00`00Oomoo`1DOol20003Ool20003Ool00`00Oomoo`2GOol10001Ool001]oo`8005Moo`80
00=oo`80009oo`8009Ioo`80005oo`006goo00<007ooOol0F7oo00<007ooOol00Woo00D007ooOomo
o`0009Ioo`40005oo`006goo00<007ooOol0FGoo0P000goo0P000Woo00<007ooOol0Tgoo0@000Goo
000KOol00`00Oomoo`1KOol20003Ool00`00Oomoo`02002COol10001Ool001]oo`03001oogoo05eo
o`05001oogooOol00003Ool00`00Oomoo`2@Ool10001Ool001]oo`8005moo`80009oo`80009oo`03
001oogoo08ioo`80005oo`006goo00<007ooOol0H7oo0P000Woo00<007ooOol00P00Sgoo0@000Goo
000KOol00`00Oomoo`1ROol00`00Oomoo`020002Ool00`00Oomoo`2<Ool10001Ool001]oo`03001o
ogoo06=oo`80009oo`04001oogoo002=Ool10001Ool001]oo`8006Ioo`800005Ool00000Ool0002;
Ool20001Ool001]oo`03001oogoo06Moo`05001oogoo001oo`02002:Ool10001Ool000Aoo`D0009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo06Qoo`800005Ool007oo
Ool00029Ool10001Ool000Ioo`07001oogooOol007oo00001goo00<007oo000017oo00<007ooOol0
JWoo100000=oo`00Ool0Qgoo0@000Goo0006Ool01`00Oomoogoo001oo`0000Uoo`03001oogoo009o
o`8006eoo`<00003Ool0000008Eoo`80005oo`001Woo00L007ooOomoo`00Ool00007Ool20005Ool0
0`00Oomoo`1^Ool300000goo001oo`24Ool10001Ool000Ioo`07001oogooOol007oo00001goo00<0
07ooOol017oo00<007ooOol0L7oo0P0000=oo`00Ool0Pgoo0@000Goo0005Ool20004Ool00`00Oomo
o`06Ool30004Ool00`00Oomoo`1bOol40022Ool10001Ool001]oo`8007Eoo`03001oo`00081oo`80
005oo`006goo00<007ooOol0MGoo0`00P7oo0@000Goo000KOol00`00Oomoo`1gOol3001nOol10001
Ool001]oo`03001oogoo07Qoo`<007eoo`40005oo`006goo0P00Ngoo0`00NWoo0P000Goo000KOol0
0`00Oomoo`1kOol4001iOol10001Ool001]oo`03001oogoo07eoo`@007Moo`40005oo`006goo00<0
07ooOol0Ogoo1000MGoo0@000Goo000KOol00`00Oomoo`21Ool4001cOol10001Ool001]oo`8008Ao
o`@0071oo`80005oo`006goo00<007ooOol0QGoo00@007oo000006moo`40005oo`006goo00<007oo
Ool0QWoo0P0000=oo`000000KGoo0@000Goo000KOol00`00Oomoo`28Ool200000goo0000001[Ool1
0001Ool001]oo`8008Yoo`<00003Ool0000006Qoo`80005oo`006goo00<007ooOol0Rgoo0`0000=o
o`000000Igoo0@000Goo000>Ool:0003Ool00`00Oomoo`2<Ool4000017oo00000000I7oo0@000Goo
000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`2>Ool40002Ool2001ROol10001Ool0
011oo`03001oogoo009oo`03001oogoo00=oo`80095oo`@0009oo`8005moo`80005oo`0047oo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol0TWoo10000Woo0P00GWoo0@000Goo000@Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`2DOol40002Ool2001LOol10001Ool000moo`8000=o
o`8000Eoo`03001oogoo09Ioo`@0009oo`8005Yoo`40005oo`006goo0P00VGoo10000Woo0P00Egoo
0P000Goo000KOol00`00Oomoo`2JOol40002Ool2001FOol10001Ool001]oo`03001oogoo09aoo`@0
009oo`8005Aoo`40005oo`006goo00<007ooOol0WWoo00@007oo0000009oo`80059oo`40005oo`00
6goo0P00X7oo0P0000=oo`0000000Woo0P00Cgoo0P000Goo000KOol00`00Oomoo`2QOol200000goo
00000002Ool2001>Ool10001Ool001]oo`03001oogoo0:=oo`03001oogoo0080009oo`<004]oo`40
005oo`006goo00<007ooOol0Y7oo0P000Woo0P000goo0P00BGoo0@000Goo000KOol00`00Oomoo`2V
Ool20002Ool20003Ool20017Ool10001Ool001]oo`800:Uoo`80009oo`8000=oo`8004Aoo`80005o
o`006goo00<007ooOol0ZWoo0P000Woo0P000goo0P00@goo0@000Goo000KOol00`00Oomoo`2/Ool2
0002Ool20003Ool20011Ool10001Ool001]oo`03001oogoo0:ioo`80009oo`8000=oo`8003moo`40
005oo`006goo0P00/Goo0P000Woo0P000goo0P00?7oo0P000Goo000KOol00`00Oomoo`2bOol20002
Ool20003Ool2000kOol10001Ool000Aoo`X0009oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo0;Aoo`80009oo`8000=oo`8003Uoo`40005oo`001Woo00<007ooOol00Woo00<007ooOol01Woo
00<007oo000017oo00<007ooOol0]Woo0`0000=oo`0000000goo0P00=goo0@000Goo0006Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2002jOol200000goo00000003Ool3000cOol2
0001Ool000Ioo`03001oogoo009oo`03001oogoo00Ioo`8000Eoo`03001oogoo0;]oo`800003Ool0
000000Aoo`80039oo`40005oo`001Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo
00<007ooOol0_Goo0P0000=oo`00000017oo0P00<7oo0@000Goo0005Ool20003Ool20008Ool30004
Ool00`00Oomoo`2oOol60003Ool2000^Ool10001Ool001]oo`800<=oo`800003Ool0000000=oo`80
02]oo`80005oo`006goo00<007ooOol0a7oo0P0000Aoo`000000009oo`8002Yoo`40005oo`006goo
00<007ooOol0aWoo0P000Woo0P000Woo0P00:7oo0@000Goo000KOol00`00Oomoo`38Ool20002Ool2
0002Ool2000VOol10001Ool001]oo`800<]oo`<00003Ool00000009oo`8002=oo`80005oo`006goo
00<007ooOol0cGoo0P0000=oo`0000000Woo0P008Woo0@000Goo000KOol00`00Oomoo`3?Ool50002
Ool2000POol10001Ool001]oo`03001oogoo0=9oo`D00003Ool0000001ioo`40005oo`006goo00<0
07ooOol0e7oo1@0000Aoo`00000001]oo`40005oo`006goo0P00f7oo1@0000=oo`00000067oo0P00
0Goo000KOol00`00Oomoo`3IOol500000goo0000000GOol10001Ool001]oo`03001oogoo0=aoo`L0
01Eoo`40005oo`006goo00<007ooOol0gWoo1`004goo0@000Goo000KOol2003ROol6000@Ool20001
Ool001]oo`03001oogoo0>Aoo`D000moo`40005oo`003Woo1@0000Aoo`00000000Aoo`03001oogoo
0>Qoo`<000eoo`40005oo`0047oo00D007ooOomoo`0000Ioo`03001oogoo0>]oo`8000]oo`40005o
o`0047oo00<007ooOol00Woo00<007ooOol00goo0P00kWoo0P0027oo0P000Goo000@Ool00`00Oomo
o`02Ool00`00Oomoo`03Ool00`00Oomoo`3_Ool20007Ool10001Ool0011oo`07001oogooOol007oo
000017oo00<007ooOol0lGoo0P001Goo0@000Goo000?Ool20004Ool00`00Oomoo`03Ool00`00Oomo
o`3hOol10001Ool001]oo`8000Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`80005oo`006gooo0000Goo003oOolIOol0
0?mooaUoo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.414718, 8.08396, 0.0125136, 
  0.0238144}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Interpolating Solutions"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another method of applying interpolation is to directly interpolate the \
rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the symbol ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as an option name to tell ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to interpolate the rules it returns. Note that ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not interpolate variables that are constant."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be given as an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to specify that the returned solution rules are to be interpolated. The \
default setting is ",
  StyleBox["Interpolation->False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that determines which dependent variables are interpolated. The default \
setting causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects representing location only.\n\n",
  StyleBox["FunctionOfTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes returned ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects to be explicitly functions of time. The default setting is ",
  StyleBox["FunctionOfTime->True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because the ",
  StyleBox["Solution->Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is given in the following example, the ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects returned contain slope and curvature information from the \
velocity and acceleration solutions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here is a set of interpolated solution rules."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetGuess[]; \)\), 
    \(intrules = 
      SolveMech[{0, 3}, 5, Solution \[Rule] Acceleration, 
        Interpolation \[Rule] True]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"X2", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"Y2", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", \(Th2 \[Rule] 0.`\), 
        ",", 
        RowBox[{"X3", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"Y3", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"Th3", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"X4", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"Y4", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", 
        RowBox[{"Th4", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 3.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here is another plot of ",
  StyleBox["shocklength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[shocklength /. intrules, {T, 0, 3}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 -1.40527 0.166814 [
[.18254 .08356 -9 -9 ]
[.18254 .08356 9 0 ]
[.34127 .08356 -3 -9 ]
[.34127 .08356 3 0 ]
[.5 .08356 -9 -9 ]
[.5 .08356 9 0 ]
[.65873 .08356 -3 -9 ]
[.65873 .08356 3 0 ]
[.81746 .08356 -9 -9 ]
[.81746 .08356 9 0 ]
[.97619 .08356 -3 -9 ]
[.97619 .08356 3 0 ]
[.01131 .01265 -18 -4.5 ]
[.01131 .01265 0 4.5 ]
[.01131 .17947 -18 -4.5 ]
[.01131 .17947 0 4.5 ]
[.01131 .26287 -12 -4.5 ]
[.01131 .26287 0 4.5 ]
[.01131 .34628 -24 -4.5 ]
[.01131 .34628 0 4.5 ]
[.01131 .42969 -12 -4.5 ]
[.01131 .42969 0 4.5 ]
[.01131 .51309 -24 -4.5 ]
[.01131 .51309 0 4.5 ]
[.01131 .5965 -12 -4.5 ]
[.01131 .5965 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.18254 .09606 m
.18254 .10231 L
s
[(0.5)] .18254 .08356 0 1 Mshowa
.34127 .09606 m
.34127 .10231 L
s
[(1)] .34127 .08356 0 1 Mshowa
.5 .09606 m
.5 .10231 L
s
[(1.5)] .5 .08356 0 1 Mshowa
.65873 .09606 m
.65873 .10231 L
s
[(2)] .65873 .08356 0 1 Mshowa
.81746 .09606 m
.81746 .10231 L
s
[(2.5)] .81746 .08356 0 1 Mshowa
.97619 .09606 m
.97619 .10231 L
s
[(3)] .97619 .08356 0 1 Mshowa
.125 Mabswid
.05556 .09606 m
.05556 .09981 L
s
.0873 .09606 m
.0873 .09981 L
s
.11905 .09606 m
.11905 .09981 L
s
.15079 .09606 m
.15079 .09981 L
s
.21429 .09606 m
.21429 .09981 L
s
.24603 .09606 m
.24603 .09981 L
s
.27778 .09606 m
.27778 .09981 L
s
.30952 .09606 m
.30952 .09981 L
s
.37302 .09606 m
.37302 .09981 L
s
.40476 .09606 m
.40476 .09981 L
s
.43651 .09606 m
.43651 .09981 L
s
.46825 .09606 m
.46825 .09981 L
s
.53175 .09606 m
.53175 .09981 L
s
.56349 .09606 m
.56349 .09981 L
s
.59524 .09606 m
.59524 .09981 L
s
.62698 .09606 m
.62698 .09981 L
s
.69048 .09606 m
.69048 .09981 L
s
.72222 .09606 m
.72222 .09981 L
s
.75397 .09606 m
.75397 .09981 L
s
.78571 .09606 m
.78571 .09981 L
s
.84921 .09606 m
.84921 .09981 L
s
.88095 .09606 m
.88095 .09981 L
s
.9127 .09606 m
.9127 .09981 L
s
.94444 .09606 m
.94444 .09981 L
s
.25 Mabswid
0 .09606 m
1 .09606 L
s
.02381 .01265 m
.03006 .01265 L
s
[(8.5)] .01131 .01265 1 0 Mshowa
.02381 .17947 m
.03006 .17947 L
s
[(9.5)] .01131 .17947 1 0 Mshowa
.02381 .26287 m
.03006 .26287 L
s
[(10)] .01131 .26287 1 0 Mshowa
.02381 .34628 m
.03006 .34628 L
s
[(10.5)] .01131 .34628 1 0 Mshowa
.02381 .42969 m
.03006 .42969 L
s
[(11)] .01131 .42969 1 0 Mshowa
.02381 .51309 m
.03006 .51309 L
s
[(11.5)] .01131 .51309 1 0 Mshowa
.02381 .5965 m
.03006 .5965 L
s
[(12)] .01131 .5965 1 0 Mshowa
.125 Mabswid
.02381 .02933 m
.02756 .02933 L
s
.02381 .04601 m
.02756 .04601 L
s
.02381 .0627 m
.02756 .0627 L
s
.02381 .07938 m
.02756 .07938 L
s
.02381 .11274 m
.02756 .11274 L
s
.02381 .12942 m
.02756 .12942 L
s
.02381 .1461 m
.02756 .1461 L
s
.02381 .16278 m
.02756 .16278 L
s
.02381 .19615 m
.02756 .19615 L
s
.02381 .21283 m
.02756 .21283 L
s
.02381 .22951 m
.02756 .22951 L
s
.02381 .24619 m
.02756 .24619 L
s
.02381 .27955 m
.02756 .27955 L
s
.02381 .29624 m
.02756 .29624 L
s
.02381 .31292 m
.02756 .31292 L
s
.02381 .3296 m
.02756 .3296 L
s
.02381 .36296 m
.02756 .36296 L
s
.02381 .37964 m
.02756 .37964 L
s
.02381 .39632 m
.02756 .39632 L
s
.02381 .41301 m
.02756 .41301 L
s
.02381 .44637 m
.02756 .44637 L
s
.02381 .46305 m
.02756 .46305 L
s
.02381 .47973 m
.02756 .47973 L
s
.02381 .49641 m
.02756 .49641 L
s
.02381 .52978 m
.02756 .52978 L
s
.02381 .54646 m
.02756 .54646 L
s
.02381 .56314 m
.02756 .56314 L
s
.02381 .57982 m
.02756 .57982 L
s
.02381 .61318 m
.02756 .61318 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .05971 L
.10458 .10292 L
.14415 .13839 L
.18221 .16907 L
.22272 .19955 L
.26171 .22784 L
.30316 .25693 L
.34309 .2837 L
.3815 .30822 L
.42237 .33312 L
.46172 .35617 L
.49955 .37769 L
.53984 .40002 L
.57861 .42086 L
.61984 .44229 L
.65954 .46224 L
.69774 .48088 L
.73838 .50021 L
.77751 .51836 L
.81909 .53714 L
.85916 .5547 L
.89771 .57114 L
.93871 .58816 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo000KOol00`00Oomoo`3jOol0
01]oo`03001oogoo0?Yoo`002goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol0nWoo000:Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`3jOol000Yoo`03001o
o`0000Uoo`03001oogoo009oo`800?]oo`002goo00<007ooOol01Woo0P001Goo0P00ngoo000:Ool0
0`00Ool00007Ool00`00Oomoo`04Ool00`00Ool0003jOol000]oo`03001oogoo00Ioo`<000Aoo`03
001oo`000?Yoo`006goo0P0000=oo`00Ool0n7oo000KOol01@00Oomoogoo0000n7oo000KOol00`00
Oomoo`02Ool00`00Oomoo`3eOol001]oo`03001oogoo00=oo`03001oogoo0?Aoo`006goo0P001Goo
00<007ooOol0lgoo000KOol00`00Oomoo`04Ool00`00Oomoo`3cOol001]oo`03001oogoo00Eoo`03
001oogoo01Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo01moo`D001moo`D0009oo`03
001oogoo009oo`03001oogoo021oo`<0025oo`<000=oo`03001oogoo009oo`03001oogoo021oo`80
00Moo`006goo00<007ooOol01Woo00<007ooOol05Woo00<007oo00001goo00<007oo00008Woo00<0
07ooOol08Goo00<007ooOol01Woo00<007oo00008Goo00<007ooOol08Goo00<007ooOol01goo00<0
07oo00008goo00<007ooOol017oo000KOol00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Ool00009
Ool00`00Oomoo`0POol00`00Oomoo`0QOol00`00Oomoo`08Ool00`00Oomoo`0POol00`00Oomoo`0Q
Ool00`00Oomoo`08Ool00`00Oomoo`0POol00`00Oomoo`05Ool001]oo`8000Uoo`03001oogoo01Ao
o`03001oo`0000Moo`8002=oo`03001oogoo025oo`03001oogoo00Ioo`8002=oo`03001oogoo025o
o`03001oogoo00Ioo`8002Aoo`03001oogoo00Aoo`006goo00<007ooOol02Goo00<007ooOol04goo
00<007oo00001goo00<007ooOol08Woo00<007ooOol08Goo00<007ooOol01Woo00<007ooOol08Goo
00<007oo00008Goo00<007oo00001goo00<007ooOol08Goo00<007oo00001Woo000KOol00`00Oomo
o`0:Ool00`00Oomoo`0COol00`00Oomoo`06Ool3000QOol2000ROol20008Ool3000ROol00`00Oomo
o`0QOol00`00Oomoo`06Ool3000ROol00`00Oomoo`05Ool001]oo`03001oogoo00]oo`03001oogoo
0>aoo`006goo0P003Goo00<007ooOol0jgoo000KOol00`00Oomoo`0=Ool00`00Oomoo`3ZOol001]o
o`03001oogoo00ioo`03001oogoo0>Uoo`006goo00<007ooOol03goo00<007ooOol0j7oo000EOooo
0004000001]oo`03001oogoo00Eoo`03001oogoo00Eoo`05001oogooOol00003Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool001]oo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo02Ioo`03001oogoo02Ioo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo02Ioo`03001o
ogoo00Eoo`006goo00<007ooOol04goo00<007ooOol0i7oo000KOol2000EOol00`00Oomoo`3SOol0
01]oo`03001oogoo01Eoo`03001oogoo0>9oo`006goo00<007ooOol05Woo00<007ooOol0hGoo000K
Ool00`00Oomoo`0GOol2003QOol001]oo`03001oogoo01Uoo`03001oogoo0=ioo`006goo0P006goo
00<007ooOol0gGoo000KOol00`00Oomoo`0KOol00`00Oomoo`3LOol001]oo`03001oogoo01aoo`03
001oogoo0=]oo`006goo00<007ooOol07Goo00<007ooOol0fWoo000KOol2000OOol2003JOol001]o
o`03001oogoo021oo`03001oogoo0=Moo`006goo00<007ooOol08Goo00<007ooOol0eWoo000KOol0
0`00Oomoo`0ROol00`00Oomoo`3EOol001]oo`8002Aoo`800=Eoo`006goo00<007ooOol09Goo00<0
07ooOol0dWoo000KOol00`00Oomoo`0VOol00`00Oomoo`3AOol000Yoo`8000Aoo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo02Moo`03001oogoo0=1oo`0037oo00<007ooOol01Goo00<007oo
000017oo00<007ooOol0:7oo0P00d7oo000;Ool20009Ool00`00Oomoo`02Ool2000[Ool00`00Oomo
o`3=Ool000Yoo`03001oo`0000Moo`8000Eoo`03001oogoo02]oo`03001oogoo0<aoo`002Woo00<0
07oo00001goo00<007ooOol017oo00<007ooOol0;7oo00<007ooOol0bgoo000;Ool20007Ool30004
Ool00`00Oomoo`0]Ool2003;Ool001]oo`80031oo`03001oogoo0<Qoo`006goo00<007ooOol0<7oo
00<007ooOol0agoo000KOol00`00Oomoo`0aOol20037Ool001]oo`03001oogoo03=oo`03001oogoo
0<Aoo`006goo0P00=Goo00<007ooOol0`goo000KOol00`00Oomoo`0eOol20033Ool001]oo`03001o
ogoo03Moo`03001oogoo0<1oo`006goo00<007ooOol0>7oo0P00`7oo000KOol00`00Oomoo`0jOol0
0`00Oomoo`2mOol001]oo`8003aoo`800;eoo`006goo00<007ooOol0?Goo00<007ooOol0^Woo000K
Ool00`00Oomoo`0nOol00`00Oomoo`2iOol001]oo`03001oogoo03moo`800;Uoo`006goo0P00@Woo
00<007ooOol0]Woo000KOol00`00Oomoo`12Ool00`00Oomoo`2eOol000ioo`D0009oo`03001oogoo
00=oo`03001oogoo04=oo`800;Eoo`0047oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`15Ool0
0`00Oomoo`2bOol0011oo`07001oogooOol007oo000017oo0P00Agoo0P00/Woo000@Ool01`00Oomo
ogoo001oo`0000Aoo`03001oogoo04Qoo`03001oogoo0:moo`0047oo00L007ooOomoo`00Ool00004
Ool00`00Oomoo`19Ool00`00Oomoo`2^Ool000moo`8000Aoo`03001oogoo00=oo`03001oogoo04Yo
o`800:ioo`006goo00<007ooOol0C7oo00<007ooOol0Zgoo000KOol2001>Ool2002[Ool001]oo`03
001oogoo04moo`03001oogoo0:Qoo`006goo00<007ooOol0D7oo0P00Z7oo000KOol00`00Oomoo`1B
Ool2002VOol001]oo`8005Eoo`03001oogoo0:=oo`006goo00<007ooOol0EGoo0P00Xgoo000KOol0
0`00Oomoo`1GOol2002QOol001]oo`03001oogoo05Uoo`03001oogoo09ioo`006goo0P00Fgoo0P00
WWoo000KOol00`00Oomoo`1LOol2002LOol001]oo`03001oogoo05ioo`8009Yoo`006goo00<007oo
Ool0H7oo0P00V7oo000KOol2001SOol2002FOol001]oo`03001oogoo06Aoo`03001oogoo09=oo`00
6goo00<007ooOol0IGoo0P00Tgoo0004Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`1WOol2002AOol000Ioo`07001oogooOol007oo00001goo00<007oo0000
17oo00<007ooOol0JGoo00<007ooOol0SWoo0006Ool01`00Oomoogoo001oo`0000Uoo`03001oogoo
009oo`8006]oo`8008ioo`001Woo00L007ooOomoo`00Ool00007Ool20005Ool00`00Oomoo`1/Ool2
002<Ool000Ioo`07001oogooOol007oo00001goo00<007ooOol017oo00<007ooOol0KWoo00<007oo
Ool0RGoo0005Ool20004Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`1_Ool20029Ool001]oo`80
079oo`03001oogoo08Ioo`006goo00<007ooOol0LWoo0P00QWoo000KOol00`00Oomoo`1dOol00`00
Oomoo`23Ool001]oo`03001oogoo07Eoo`8008=oo`006goo0P00N7oo00<007ooOol0P7oo000KOol0
0`00Oomoo`1hOol20020Ool001]oo`03001oogoo07Yoo`8007ioo`006goo00<007ooOol0O7oo0P00
O7oo000KOol00`00Oomoo`1nOol2001jOol001]oo`80085oo`8007Qoo`006goo00<007ooOol0PWoo
00<007ooOol0MGoo000KOol00`00Oomoo`23Ool2001eOol001]oo`03001oogoo08Eoo`8007=oo`00
6goo0P00R7oo0P00LGoo000KOol00`00Oomoo`29Ool2001_Ool000ioo`X000=oo`03001oogoo08]o
o`8006eoo`0047oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0SGoo0P00Jgoo000@Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool2002@Ool2001YOol0011oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo095oo`8006Moo`0047oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
Tgoo0P00IGoo000?Ool20003Ool20005Ool00`00Oomoo`2EOol2001SOol001]oo`03001oogoo09Mo
o`80065oo`006goo0P00VWoo0P00Ggoo000KOol00`00Oomoo`2KOol2001MOol001]oo`03001oogoo
09eoo`8005]oo`006goo00<007ooOol0Wgoo0P00FGoo000KOol2002ROol2001GOol001]oo`03001o
ogoo0:=oo`8005Eoo`006goo00<007ooOol0YGoo0`00DWoo000KOol00`00Oomoo`2XOol2001@Ool0
01]oo`800:]oo`8004ioo`006goo00<007ooOol0[7oo0P00C7oo000KOol00`00Oomoo`2^Ool2001:
Ool001]oo`03001oogoo0;1oo`8004Qoo`006goo0P00/goo0P00AWoo000KOol00`00Oomoo`2dOol2
0014Ool001]oo`03001oogoo0;Ioo`80049oo`0017oo2P000Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol0^7oo0P00@7oo0006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00004
Ool00`00Oomoo`2jOol2000nOol000Ioo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo009o
o`800;eoo`8003aoo`001Woo00<007ooOol00Woo00<007ooOol01Woo0P001Goo00<007ooOol0_Woo
0`00>Goo0006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`31Ool2
000gOol000Eoo`8000=oo`8000Qoo`<000Aoo`03001oogoo0<=oo`8003Eoo`006goo0P00aWoo0P00
<goo000KOol00`00Oomoo`37Ool2000aOol001]oo`03001oogoo0<Uoo`<002ioo`006goo00<007oo
Ool0c7oo0P00;7oo000KOol2003?Ool3000YOol001]oo`03001oogoo0=5oo`8002Moo`006goo00<0
07ooOol0dgoo0P009Goo000KOol00`00Oomoo`3EOol2000SOol001]oo`03001oogoo0=Moo`80025o
o`006goo0P00fWoo0P007goo000KOol00`00Oomoo`3KOol2000MOol001]oo`03001oogoo0=eoo`<0
01Yoo`006goo00<007ooOol0h7oo0`005goo000KOol2003TOol2000EOol001]oo`03001oogoo0>Eo
o`<0019oo`003Woo1@0000Aoo`00000000Aoo`03001oogoo0>Qoo`<000moo`0047oo00D007ooOomo
o`0000Ioo`03001oogoo0>]oo`8000eoo`0047oo00<007ooOol00Woo00<007ooOol00goo0P00kWoo
0P002goo000@Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3_Ool20009Ool0011oo`07
001oogooOol007oo000017oo00<007ooOol0lGoo0P001goo000?Ool20004Ool00`00Oomoo`03Ool0
0`00Oomoo`3jOol001]oo`03001oogoo0?Yoo`006goo0P00ngoo000KOol00`00Oomoo`3jOol00?mo
oaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.33251, 8.26335, 0.0122134, 
  0.023243}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 700},
WindowMargins->{{20, Automatic}, {16, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 94, 2, 150, "Title"],

Cell[CellGroupData[{
Cell[1850, 57, 88, 2, 47, "Subsection"],
Cell[1941, 61, 997, 25, 168, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2975, 91, 131, 3, 33, "Section",
  PageBreakAbove->True],
Cell[3109, 96, 654, 15, 110, "Text"],

Cell[CellGroupData[{
Cell[3788, 115, 100, 2, 47, "Subsection"],
Cell[3891, 119, 1868, 29, 489, "Text"],

Cell[CellGroupData[{
Cell[5784, 152, 134, 3, 24, "SmallText"],
Cell[5921, 157, 38103, 4842, 236, 17593, 4584, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44061, 5004, 89, 2, 43, "Subsubsection"],
Cell[44153, 5008, 139, 3, 33, "Text"],
Cell[44295, 5013, 291, 5, 76, "Special1"],
Cell[44589, 5020, 489, 8, 127, "Special1"],
Cell[45081, 5030, 355, 6, 76, "Special1"],
Cell[45439, 5038, 325, 6, 76, "Special1"],

Cell[CellGroupData[{
Cell[45789, 5048, 130, 3, 24, "SmallText"],
Cell[45922, 5053, 27374, 603, 375, 3670, 305, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73333, 5661, 242, 8, 24, "SmallText"],
Cell[73578, 5671, 196, 6, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73811, 5682, 135, 3, 24, "SmallText"],
Cell[73949, 5687, 130, 5, 61, "Input"],
Cell[74082, 5694, 279, 10, 151, "Input"],
Cell[74364, 5706, 204, 7, 97, "Input"],
Cell[74571, 5715, 198, 7, 97, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74806, 5727, 234, 8, 24, "SmallText"],
Cell[75043, 5737, 120, 3, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[75212, 5746, 94, 2, 29, "Subsubsection"],
Cell[75309, 5750, 209, 4, 52, "Text"],
Cell[75521, 5756, 436, 14, 61, "Special1"],
Cell[75960, 5772, 319, 10, 43, "Special1"],
Cell[76282, 5784, 211, 8, 26, "Special1"],
Cell[76496, 5794, 211, 8, 26, "Special1"],
Cell[76710, 5804, 250, 9, 43, "Special1"],
Cell[76963, 5815, 214, 8, 26, "Special1"],
Cell[77180, 5825, 491, 17, 61, "Special1"],

Cell[CellGroupData[{
Cell[77696, 5846, 143, 4, 24, "SmallText"],
Cell[77842, 5852, 639, 12, 245, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78518, 5869, 245, 8, 24, "SmallText"],
Cell[78766, 5879, 87, 2, 25, "Input"]
}, Open  ]],
Cell[78868, 5884, 939, 32, 113, "Text"],

Cell[CellGroupData[{
Cell[79832, 5920, 280, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[80137, 5935, 103, 2, 25, "Input"],
Cell[80243, 5939, 262, 7, 62, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[80566, 5953, 91, 2, 29, "Subsubsection"],
Cell[80660, 5957, 882, 26, 133, "Text"],

Cell[CellGroupData[{
Cell[81567, 5987, 195, 8, 24, "SmallText"],
Cell[81765, 5997, 81, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81883, 6004, 190, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[82098, 6016, 81, 2, 25, "Input"],
Cell[82182, 6020, 555, 12, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[82786, 6038, 207, 8, 24, "SmallText"],
Cell[82996, 6048, 31893, 2547, 236, 11476, 2290, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[114950, 8602, 99, 2, 31, "Subsection"],
Cell[115052, 8606, 643, 21, 93, "Text"],

Cell[CellGroupData[{
Cell[115720, 8631, 1269, 42, 225, "Special3"],
Cell[116992, 8675, 206, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[117213, 8687, 550, 17, 74, "Text"],

Cell[CellGroupData[{
Cell[117788, 8708, 219, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[118032, 8720, 108, 2, 25, "Input"],
Cell[118143, 8724, 927, 18, 105, "Output"]
}, Open  ]]
}, Open  ]],
Cell[119097, 8746, 1358, 43, 229, "Text"],

Cell[CellGroupData[{
Cell[120480, 8793, 234, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[120739, 8805, 112, 2, 25, "Input"],
Cell[120854, 8809, 1306, 24, 162, "Output"]
}, Open  ]]
}, Open  ]],
Cell[122187, 8837, 285, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[122497, 8846, 136, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[122658, 8853, 149, 3, 65, "Input"],
Cell[122810, 8858, 281, 7, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[123118, 8869, 1100, 32, 189, "Text"],
Cell[124221, 8903, 1674, 65, 150, "Special3"],
Cell[125898, 8970, 211, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[126112, 8981, 653, 18, 93, "Text"],

Cell[CellGroupData[{
Cell[126790, 9003, 293, 12, 24, "SmallText"],
Cell[127086, 9017, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[127204, 9025, 100, 2, 31, "Subsection"],
Cell[127307, 9029, 1566, 28, 358, "Text"],

Cell[CellGroupData[{
Cell[128898, 9061, 189, 8, 24, "SmallText"],
Cell[129090, 9071, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129211, 9078, 143, 4, 24, "SmallText"],
Cell[129357, 9084, 82956, 4087, 269, 42647, 3584, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212350, 13176, 89, 2, 43, "Subsubsection"],
Cell[212442, 13180, 156, 4, 33, "Text"],
Cell[212601, 13186, 675, 15, 144, "Special1"],
Cell[213279, 13203, 748, 11, 161, "Special1"],
Cell[214030, 13216, 466, 8, 110, "Special1"],

Cell[CellGroupData[{
Cell[214521, 13228, 143, 4, 24, "SmallText"],
Cell[214667, 13234, 133, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214837, 13243, 150, 4, 24, "SmallText"],
Cell[214990, 13249, 166, 7, 97, "Input"],
Cell[215159, 13258, 332, 11, 169, "Input"],
Cell[215494, 13271, 278, 9, 133, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215809, 13285, 137, 3, 24, "SmallText"],
Cell[215949, 13290, 106, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[216104, 13298, 94, 2, 29, "Subsubsection"],
Cell[216201, 13302, 240, 5, 52, "Text"],
Cell[216444, 13309, 342, 10, 43, "Special1"],
Cell[216789, 13321, 393, 10, 60, "Special1"],
Cell[217185, 13333, 388, 13, 44, "Special1"],
Cell[217576, 13348, 224, 8, 26, "Special1"],
Cell[217803, 13358, 223, 8, 26, "Special1"],
Cell[218029, 13368, 281, 9, 43, "Special1"],
Cell[218313, 13379, 411, 13, 61, "Special1"],
Cell[218727, 13394, 216, 8, 26, "Special1"],

Cell[CellGroupData[{
Cell[218968, 13406, 152, 4, 24, "SmallText"],
Cell[219123, 13412, 764, 18, 305, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219924, 13435, 137, 3, 24, "SmallText"],
Cell[220064, 13440, 87, 2, 25, "Input"]
}, Open  ]],
Cell[220166, 13445, 946, 33, 113, "Text"],

Cell[CellGroupData[{
Cell[221137, 13482, 287, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[221449, 13497, 103, 2, 25, "Input"],
Cell[221555, 13501, 328, 8, 81, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[221944, 13516, 91, 2, 29, "Subsubsection"],
Cell[222038, 13520, 693, 21, 93, "Text"],

Cell[CellGroupData[{
Cell[222756, 13545, 190, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[222971, 13557, 81, 2, 25, "Input"],
Cell[223055, 13561, 762, 15, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[223866, 13582, 221, 8, 24, "SmallText"],
Cell[224090, 13592, 85373, 4001, 269, 45242, 3500, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[309524, 17600, 113, 2, 31, "Subsection"],
Cell[309640, 17604, 2139, 72, 284, "Text"],
Cell[311782, 17678, 423, 16, 55, "Special3"],
Cell[312208, 17696, 128, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[312339, 17701, 2007, 65, 245, "Text"],
Cell[314349, 17768, 83, 2, 23, "Special5"],

Cell[CellGroupData[{
Cell[314457, 17774, 1711, 62, 211, "Special3"],
Cell[316171, 17838, 207, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[316393, 17850, 80, 2, 23, "Special5"],
Cell[316476, 17854, 938, 32, 104, "Special3"],
Cell[317417, 17888, 207, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[317627, 17899, 476, 13, 92, "Text"],

Cell[CellGroupData[{
Cell[318128, 17916, 219, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[318372, 17928, 108, 2, 25, "Input"],
Cell[318483, 17932, 1352, 24, 143, "Output"]
}, Open  ]]
}, Open  ]],
Cell[319862, 17960, 857, 27, 112, "Text"],

Cell[CellGroupData[{
Cell[320744, 17991, 147, 4, 24, "SmallText"],
Cell[320894, 17997, 134, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[321065, 18005, 201, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[321291, 18017, 108, 2, 25, "Input"],
Cell[321402, 18021, 1279, 23, 143, "Output"]
}, Open  ]]
}, Open  ]],
Cell[322708, 18048, 1164, 39, 149, "Text"],

Cell[CellGroupData[{
Cell[323897, 18091, 209, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[324131, 18103, 112, 2, 25, "Input"],
Cell[324246, 18107, 1806, 31, 219, "Output"]
}, Open  ]]
}, Open  ]],
Cell[326079, 18142, 924, 33, 131, "Text"],

Cell[CellGroupData[{
Cell[327028, 18179, 155, 4, 24, "SmallText"],
Cell[327186, 18185, 161, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[327384, 18193, 201, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[327610, 18205, 108, 2, 25, "Input"],
Cell[327721, 18209, 1260, 23, 143, "Output"]
}, Open  ]]
}, Open  ]],
Cell[329008, 18236, 315, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[329348, 18246, 190, 8, 24, "SmallText"],
Cell[329541, 18256, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[329659, 18264, 91, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[329775, 18270, 111, 2, 43, "Subsubsection"],
Cell[329889, 18274, 98, 2, 25, "Input"],
Cell[329990, 18278, 400, 7, 151, "Input"],
Cell[330393, 18287, 336, 6, 97, "Input"],
Cell[330732, 18295, 236, 5, 79, "Input"],
Cell[330971, 18302, 384, 10, 133, "Input"],
Cell[331358, 18314, 318, 9, 115, "Input"],
Cell[331679, 18325, 249, 5, 79, "Input"],
Cell[331931, 18332, 190, 4, 61, "Input"],
Cell[332124, 18338, 245, 5, 79, "Input"],
Cell[332372, 18345, 208, 5, 79, "Input"],
Cell[332583, 18352, 179, 4, 61, "Input"],
Cell[332765, 18358, 179, 4, 61, "Input"],
Cell[332947, 18364, 177, 4, 61, "Input"],
Cell[333127, 18370, 179, 4, 61, "Input"],
Cell[333309, 18376, 131, 3, 25, "Input"],
Cell[333443, 18381, 85, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333565, 18388, 103, 2, 43, "Subsubsection"],
Cell[333671, 18392, 99, 2, 25, "Input"],
Cell[333773, 18396, 381, 12, 187, "Input"],
Cell[334157, 18410, 159, 4, 43, "Input"],
Cell[334319, 18416, 362, 6, 133, "Input"],
Cell[334684, 18424, 267, 5, 97, "Input"],
Cell[334954, 18431, 219, 5, 79, "Input"],
Cell[335176, 18438, 86, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[335323, 18447, 138, 3, 33, "Section",
  PageBreakAbove->True],
Cell[335464, 18452, 496, 14, 91, "Text"],

Cell[CellGroupData[{
Cell[335985, 18470, 100, 2, 47, "Subsection"],
Cell[336088, 18474, 320, 8, 71, "Text"],

Cell[CellGroupData[{
Cell[336433, 18486, 136, 3, 24, "SmallText"],
Cell[336572, 18491, 84, 2, 25, "Input"],
Cell[336659, 18495, 672, 15, 205, "Input"],
Cell[337334, 18512, 845, 16, 325, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[338216, 18533, 221, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[338462, 18545, 81, 2, 25, "Input"],
Cell[338546, 18549, 762, 15, 86, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[339369, 18571, 96, 2, 31, "Subsection"],
Cell[339468, 18575, 803, 24, 110, "Text"],
Cell[340274, 18601, 957, 39, 102, "Special3"],
Cell[341234, 18642, 146, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[341383, 18647, 455, 8, 90, "Text"],

Cell[CellGroupData[{
Cell[341863, 18659, 119, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[342007, 18665, 138, 3, 45, "Input"],
Cell[342148, 18670, 118, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[342315, 18678, 592, 24, 55, "Special3"],
Cell[342910, 18704, 131, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[343056, 18710, 265, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[343346, 18719, 148, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[343519, 18727, 120, 3, 45, "Input"],
Cell[343642, 18732, 122, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[343791, 18738, 228, 8, 34, "Text"],
Cell[344022, 18748, 80, 2, 23, "Special5"],

Cell[CellGroupData[{
Cell[344127, 18754, 945, 39, 102, "Special3"],
Cell[345075, 18795, 150, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[345240, 18801, 80, 2, 23, "Special5"],

Cell[CellGroupData[{
Cell[345345, 18807, 1052, 40, 117, "Special3"],
Cell[346400, 18849, 150, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[346565, 18855, 1190, 37, 189, "Text"],

Cell[CellGroupData[{
Cell[347780, 18896, 130, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[347935, 18903, 132, 3, 45, "Input"],
Cell[348070, 18908, 229, 4, 67, "Output"],
Cell[348302, 18914, 124, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[348453, 18920, 449, 16, 54, "Text"],

Cell[CellGroupData[{
Cell[348927, 18940, 212, 8, 24, "SmallText"],
Cell[349142, 18950, 126, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[349305, 18958, 134, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[349464, 18965, 132, 3, 45, "Input"],
Cell[349599, 18970, 49, 1, 29, "Output"],
Cell[349651, 18973, 124, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[349802, 18979, 243, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[350070, 18988, 154, 4, 24, "SmallText"],
Cell[350227, 18994, 153, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350417, 19002, 140, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[350582, 19009, 132, 3, 45, "Input"],
Cell[350717, 19014, 450, 8, 148, "Output"],
Cell[351170, 19024, 124, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[351321, 19030, 566, 16, 92, "Text"],

Cell[CellGroupData[{
Cell[351912, 19050, 1476, 59, 132, "Special3"],
Cell[353391, 19111, 142, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[353548, 19117, 994, 34, 134, "Text"],
Cell[354545, 19153, 168, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[354738, 19161, 285, 5, 85, "Input"],
Cell[355026, 19168, 115, 2, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[355190, 19176, 107, 2, 31, "Subsection"],
Cell[355300, 19180, 841, 30, 92, "Text"],

Cell[CellGroupData[{
Cell[356166, 19214, 215, 8, 24, "SmallText"],
Cell[356384, 19224, 124, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[356545, 19232, 126, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[356696, 19238, 141, 3, 65, "Input"],
Cell[356840, 19243, 181, 4, 67, "Output"],
Cell[357024, 19249, 457, 10, 128, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[357530, 19265, 203, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[357758, 19277, 111, 2, 25, "Input"],
Cell[357872, 19281, 83, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[357982, 19286, 1753, 54, 269, "Text"],

Cell[CellGroupData[{
Cell[359760, 19344, 130, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[359915, 19351, 170, 4, 65, "Input"],
Cell[360088, 19357, 66, 1, 29, "Output"],
Cell[360157, 19360, 73, 1, 29, "Output"],
Cell[360233, 19363, 239, 4, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[360521, 19373, 215, 8, 24, "SmallText"],
Cell[360739, 19383, 126, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[360902, 19391, 173, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[361100, 19399, 170, 4, 65, "Input"],
Cell[361273, 19405, 66, 1, 29, "Output"],
Cell[361342, 19408, 307, 5, 110, "Output"],
Cell[361652, 19415, 240, 4, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[361941, 19425, 137, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[362103, 19432, 273, 6, 105, "Input"],
Cell[362379, 19440, 66, 1, 29, "Output"],
Cell[362448, 19443, 310, 6, 110, "Output"],
Cell[362761, 19451, 238, 4, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[363026, 19459, 236, 5, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[363299, 19469, 94, 2, 31, "Subsection"],
Cell[363396, 19473, 1438, 25, 320, "Text"],
Cell[364837, 19500, 478, 14, 76, "Special2"],

Cell[CellGroupData[{
Cell[365340, 19518, 154, 4, 24, "SmallText"],
Cell[365497, 19524, 220, 7, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[365754, 19536, 225, 5, 40, "SmallText"],

Cell[CellGroupData[{
Cell[366004, 19545, 164, 4, 45, "Input"],
Cell[366171, 19551, 307, 5, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[366527, 19562, 257, 9, 24, "SmallText"],

Cell[CellGroupData[{
Cell[366809, 19575, 92, 2, 25, "Input"],
Cell[366904, 19579, 138, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[367069, 19585, 503, 12, 91, "Text"],

Cell[CellGroupData[{
Cell[367597, 19601, 276, 8, 40, "SmallText"],

Cell[CellGroupData[{
Cell[367898, 19613, 111, 2, 25, "Input"],
Cell[368012, 19617, 193, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[368254, 19626, 413, 15, 41, "SmallText"],

Cell[CellGroupData[{
Cell[368692, 19645, 114, 3, 45, "Input"],
Cell[368809, 19650, 82, 1, 42, "Output"],
Cell[368894, 19653, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[368997, 19660, 529, 21, 41, "SmallText"],

Cell[CellGroupData[{
Cell[369551, 19685, 123, 3, 45, "Input"],
Cell[369677, 19690, 112, 2, 29, "Output"],
Cell[369792, 19694, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[369896, 19701, 526, 21, 41, "SmallText"],

Cell[CellGroupData[{
Cell[370447, 19726, 129, 3, 45, "Input"],
Cell[370579, 19731, 103, 2, 29, "Output"],
Cell[370685, 19735, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[370766, 19740, 391, 10, 72, "Text"],

Cell[CellGroupData[{
Cell[371182, 19754, 426, 17, 40, "SmallText"],

Cell[CellGroupData[{
Cell[371633, 19775, 75, 2, 25, "Input"],
Cell[371711, 19779, 139, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[371877, 19785, 1058, 34, 147, "Text"],

Cell[CellGroupData[{
Cell[372960, 19823, 190, 8, 24, "SmallText"],
Cell[373153, 19833, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[373271, 19841, 100, 2, 31, "Subsection"],
Cell[373374, 19845, 348, 9, 71, "Text"],

Cell[CellGroupData[{
Cell[373747, 19858, 126, 2, 24, "SmallText"],
Cell[373876, 19862, 84, 2, 25, "Input"],
Cell[373963, 19866, 610, 12, 225, "Input"],
Cell[374576, 19880, 581, 10, 245, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[375194, 19895, 221, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[375440, 19907, 116, 3, 45, "Input"],
Cell[375559, 19912, 555, 12, 67, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[376175, 19931, 93, 2, 31, "Subsection"],
Cell[376271, 19935, 594, 18, 92, "Text"],
Cell[376868, 19955, 1465, 54, 119, "Special3"],
Cell[378336, 20011, 127, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[378466, 20016, 283, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[378774, 20029, 225, 7, 24, "SmallText"],
Cell[379002, 20038, 127, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[379166, 20046, 122, 2, 24, "SmallText"],
Cell[379291, 20050, 98, 2, 25, "Input"]
}, Open  ]],
Cell[379404, 20055, 547, 18, 73, "Text"],
Cell[379954, 20075, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[380106, 20081, 170, 4, 45, "Input"],
Cell[380279, 20087, 16215, 649, 181, 6131, 518, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[396509, 20739, 553, 17, 74, "Text"],

Cell[CellGroupData[{
Cell[397087, 20760, 255, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[397367, 20772, 109, 2, 25, "Input"],
Cell[397479, 20776, 144, 3, 44, "Message"],
Cell[397626, 20781, 119, 3, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[397772, 20788, 223, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[398020, 20800, 127, 3, 25, "Input"],
Cell[398150, 20805, 16622, 671, 181, 6482, 540, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[414787, 21479, 414, 11, 72, "Text"],

Cell[CellGroupData[{
Cell[415226, 21494, 171, 4, 24, "SmallText"],
Cell[415400, 21500, 125, 3, 25, "Input"]
}, Open  ]],
Cell[415540, 21506, 462, 16, 74, "Text"],

Cell[CellGroupData[{
Cell[416027, 21526, 205, 8, 24, "SmallText"],
Cell[416235, 21536, 115, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[416387, 21543, 223, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[416635, 21555, 127, 3, 25, "Input"],
Cell[416765, 21560, 16563, 671, 181, 6479, 540, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[433377, 22237, 117, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[433519, 22243, 92, 2, 25, "Input"],
Cell[433614, 22247, 19448, 731, 181, 6922, 570, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[453089, 22982, 106, 2, 43, "Subsubsection"],
Cell[453198, 22986, 733, 25, 93, "Text"],
Cell[453934, 23013, 1433, 49, 182, "Special3"],
Cell[455370, 23064, 206, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[455579, 23075, 433, 13, 73, "Text"],
Cell[456015, 23090, 124, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[456164, 23096, 194, 5, 65, "Input"],
Cell[456361, 23103, 1657, 43, 162, "Output"]
}, Open  ]],
Cell[458033, 23149, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[458252, 23161, 105, 2, 25, "Input"],
Cell[458360, 23165, 12579, 418, 181, 4308, 310, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470976, 23588, 190, 8, 24, "SmallText"],
Cell[471169, 23598, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

