(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    355843,      30188]*)
(*NotebookOutlinePosition[    356785,      30220]*)
(*  CellTagsIndexPosition[    356741,      30216]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5.  Multistage Mechanisms", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Overview"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers one of the more advanced methods of kinematic modeling \
supported by ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  ". Stage switches and time switches are ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s method of allowing a mechanism to \"jump\" from one constraint type to \
another as it moves through its range of motion. These functions enable the \
modeling of components such as a pin that slides in a track with a sharp \
\"jog\" in it, or a bumper that swings through an arc until it strikes a \
stationary pad and starts it in motion. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " also supports multistage load functions, which are covered in Chapter 7."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["5.1  Stage Switching Constraints"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is nothing more than a compound constraint that contains \
several normal ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraints and lets the user specify which one is active. This function \
can be used to model any mechanism that has more than one mode of operation, \
and it is desired to automatically switch the model from one mode to another. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["StageSwitch"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["StageSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["test1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["constraint1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["test2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["constraint2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ...",
    FontFamily->"Times"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a compound ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint object that is used in place of a single constraint object. ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates each of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " in turn, and applies the ",
  StyleBox["constrainti",
    FontSlant->"Italic"],
  " corresponding to the first ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " that returns ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions analogously to ",
  StyleBox["Which",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A multistage mechanism constraint-switching function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "A ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint returns an error if any of the test expressions fail to return \
either ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time. Because ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["does",
    FontSlant->"Italic"],
  " evaluate its own arguments immediately, unlike ",
  StyleBox["Which",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["If",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", test expressions such as ",
  StyleBox["SameQ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should not be used. This is because ",
  StyleBox["SameQ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates immediately to ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " instead of waiting until some future condition changes. Also, a ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is invalid if all of the test expressions return ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time because no constraint is applied to the model.\n\nEach of the \
constraints supplied to the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint objects or lists of constraint objects. Each constraint or \
list of constraints must constrain the same number of degrees of freedom. \
Note that the constraint numbers of the constraints that are inside of the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are irrelevant. The constraint number of the entire ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the only one that is used to reference the constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Examples "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The following example shows how a ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (constraint 1) might be used to model a pin on a slider that slides in \
one of two straight tracks on the ground body. Which track to use is \
determined by the value of the user-defined symbol ",
  StyleBox["whichtrack",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which must be either 1 or 2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a valid ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(slider = 2; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(StageSwitch[1, \n\twhichtrack == 1, \n\t
      PointOnLine1[1, Point[slider, {0, 1}], Line[ground, {0, 0}, {5, 0}]], \n
      \twhichtrack == 2, \n\t
      PointOnLine1[1, Point[slider, {0, 1}], Line[ground, {0, 0}, {5, 2}]]]
      \)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["StageSwitch", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The following example shows how a ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that constrains two degrees of freedom might be implemented. The first \
constraint in the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " forces the origin of the slider to be coincident with the origin of the \
ground. If the value of the user-defined symbol ",
  StyleBox["pressure",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rises above 100 units, the second constraint pair becomes active and \
forces the origin of the slider to lie upon a line and be positioned as a \
function of the value of ",
  StyleBox["pressure",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is another ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(StageSwitch[1, \n\tpressure < 100, \n\t
      Revolute2[1, \n\t\tPoint[slider, {0, 0}], Point[ground, {0, 0}]], \n\t
      pressure \[GreaterEqual] 100, \n
      \t{PointOnLine1[1, Point[slider, {0, 0}], 
          Axis[ground, {0, 0}, {1, 1}]], \n\t\t
        RelativeY1[1, \n\t\t\tPoint[slider, {0, 0}], 
          k\ \((pressure - 100)\)]}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["StageSwitch", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Rocker Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, a 2D model of a rocker arm driven by an eccentric is developed. \
The model consists of two moving bodies, the eccentric and the rocker. \n\n\
This mechanism has two distinct modes of operation that are toggled via the ",
  
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The first mode of operation is for the eccentric to be rotated \
about a stationary axis, forcing the rocker to reciprocate by its contact \
with the eccentric. The second mode is for the eccentric to be rotated about \
an axis that is unconstrained in the vertical direction while the rocker is \
restrained to be stationary. This causes the eccentric to rise and fall as a \
result of its rotation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the 2D rocker model graphic. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.416667 0.166667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
p
p
.004 w
.08333 .16667 m
.08333 .75 L
.91667 .75 L
.91667 .08333 L
.08333 .08333 L
.08333 .16667 L
.16667 .25 L
.08333 .33333 L
s
.5 .75 m
.5 .08333 L
s
.02 w
.5 .41667 Mdot
.16667 .25 Mdot
P
p
p
.7 0 0 r
.004 w
.5 .41667 m
.5 .41667 .25 0 365.73 arc
F
P
p
1 .6 .6 r
.004 w
.54898 .34925 m
.54898 .34925 .16667 0 365.73 arc
F
P
p
p
.02 w
.5 .41667 Mdot
.54898 .34925 Mdot
P
P
P
p
p
.2 .2 1 r
.16667 .25 m
.15914 .20902 L
.81484 .08861 L
.82237 .12959 L
F
.004 w
.16667 .25 m
.16667 .25 .04167 0 365.73 arc
F
p
.81484 .08861 m
.76634 .05516 L
.73288 .10366 L
F
P
P
p
p
.02 w
.16667 .25 Mdot
.76634 .05516 Mdot
.82237 .12959 Mdot
P
P
P
p
p
p
/Courier findfont 8 scalefont setfont
[(x)] .56857 .32228 -2.0952 .19911 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .59439 .48524 -2.0952 .19911 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(2)] .5 .41667 -2.0952 .19911 Mshowa
P
.004 w
.56857 .32228 m
.5 .41667 L
.59439 .48524 L
s
.54542 .3343 m
.56857 .32228 L
.5643 .34802 L
s
.56865 .48097 m
.59439 .48524 L
.58237 .46209 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 234},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000jQ000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00eGoo0P00@goo003D
Ool40012Ool00=Aoo`@0049oo`00eGoo0P000aSO@7oo003DOol76=loOol00=Aoo`THgceoo`00dgoo
2aSO?7oo003BOol>6=ljOol00=9oo`lHgcUoo`0067oo^@004QSO7`0067oo000HOol00`00Oomoo`1a
Ool00`00Oomoo`11OolD6=lMOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo045o
oaDHgaaoo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0@7oo2QSO00=ooaSO6=l0
2ASO77oo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`0oOol56=l00goo6=lHg`0?
6=lLOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo041ooaHHgaaoo`03001oogoo
01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0>goo6aSO77oo00<007ooOol05Woo000HOol00`00
Oomoo`1aOol00`00Oomoo`0eOolQ6=lLOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001o
ogoo031oobLHga]oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0:Woo;ASO6goo
00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`0UOolb6=lKOol00`00Oomoo`0FOol0
01Qoo`03001oogoo075oo`03001oogoo021oocLHga]oo`03001oogoo01Ioo`0067oo00<007ooOol0
LGoo00<007ooOol06Woo?1SO0P006Woo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomo
o`0EOom06=l4000IOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo011ood8Hg`=o
o`@001Uoo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol02Woo@QSO2Woo0P006Woo
00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`05Oom26=l[Ool00`00Oomoo`0FOol0
01Qoo`03001oogoo075oo`03001ooaSO044Hgc5oo`03001oogoo01Ioo`0067oo00<007ooOol0KWoo
@QSO=Woo00<007ooOol05Woo000HOol00`00Oomoo`1YOom16=llOol00`00Oomoo`0FOol001Qoo`03
001oogoo06=ood8Hgd5oo`03001oogoo01Ioo`0067oo00<007ooOol0GWoo@ASOAgoo00<007ooOol0
5Woo000HOol00`00Oomoo`1HOom26=m<Ool00`00Oomoo`0FOol001Qoo`03001oogoo05=ood4Hge9o
o`03001oogoo01Ioo`0067oo0P00Cgoo@1SOF7oo00<007ooOol05Woo000HOol00`00Ool00018Oom1
6=mMOol00`00Oomoo`0FOol001Qoo`04001oogoo0012Oom06=l00eP0Oomoo`1POol00`00Oomoo`0F
Ool001Qoo`05001oogooOol0000lOom06=l9F01OOol00`00Oomoo`0FOol001Qoo`03001oogoo009o
o`03001oogoo03=ood0Hga=H05]oo`03001oogoo01Ioo`0067oo00<007ooOol00goo00<007ooOol0
;Goo@1SO00=H07icOW<04gic0eP0FWoo00<007ooOol05Woo000HOol00`00Oomoo`04Ool00`00Oomo
o`0VOom06=l3F00NOW<00eP0Oomoo`1EOol00`00Oomoo`0FOol001Qoo`03001oogoo00Eoo`03001o
ogoo021ood0Hg`IH029nL`03F01oogoo05=oo`03001oogoo01Ioo`0067oo00<007ooOol01Woo00<0
07ooOol06Woo?aSO2UP09WicE7oo00<007ooOol05Woo000HOol00`00Oomoo`07Ool00`00Oomoo`0C
Oom06=l<F00[OW<2F01@Ool00`00Oomoo`0FOol001Qoo`03001oogoo00Qoo`03001oogoo00eooclH
ga1H02mnL`03F01oogoo04eoo`03001oogoo01Ioo`0067oo00<007ooOol02Goo00<007ooOol01Woo
?aSO55P0<gic00=H07ooOol0Bgoo00<007ooOol05Woo000HOol00`00Oomoo`0:Ool01000Oomoogoo
?QSO65P0=WicC7oo00<007ooOol05Woo000HOol00`00Oomoo`0;Ool00`00OolHg`0h6=l00gooF01H
000JF00hOW<00eP0Oomoo`18Ool00`00Oomoo`0FOol001Qoo`03001oogoo00aoocDHg`AooaeH03Yn
L`03F01oogoo04Moo`03001oogoo01Ioo`0067oo00<007ooOol02goo<1SO2Woo6eP0?WicB7oo00<0
07ooOol05Woo000HOol00`00Oomoo`0:Ool/6=l>OolKF010OW=7Ool00`00Oomoo`0FOol001Qoo`03
001oogoo00UoobLHga=ooa]H045nLdMoo`03001oogoo01Ioo`0067oo00<007ooOol02Goo8QSO5goo
6eP0A7icAGoo00<007ooOol05Woo000HOol00`00Oomoo`09OolL6=lKOolLF016OW=4Ool00`00Oomo
o`0FOol001Qoo`03001oogoo00UooaLHgamooaaH04MnL`03F01oogoo045oo`03001oogoo01Ioo`00
67oo00<007ooOol02Goo5QSO7goo7EP0B7ic00=H07ooOol0@7oo00<007ooOol05Woo000HOol00`00
Oomoo`08Ool;6=l2000:6=lNOolMF01:OW<00eP0Oomoo`0oOol00`00Oomoo`0FOol001Qoo`03001o
ogoo00Qoo`XHg`@000THgaeooaeH04anL`03F01oogoo03ioo`03001oogoo01Ioo`0067oo00<007oo
Ool027oo2QSO10002ASO77oo7EP0CGic0UP0?goo00<007ooOol05Woo000HOol00`00Oomoo`09Ool:
6=l2000:6=lLOolMF01>OW<2F00nOol00`00Oomoo`0FOol001Qoo`03001oogoo00UooaHHga]ooaeH
04mnL`=H03eoo`03001oogoo01Ioo`0067oo00<007ooOol02Woo5ASO6Woo7UP0D7ic0UP0?Goo00<0
07ooOol05Woo000HOol00`00Oomoo`0:OolD6=lKOolMF01BOW<2F00lOol00`00Oomoo`0FOol001Qo
o`03001oogoo00]ooa8Hga]ooaiH05=nL`9H03]oo`03001oogoo01Ioo`0067oo00<007ooOol02goo
4QSO6Woo7UP0E7ic0UP0>goo00<007ooOol05Woo000HOol00`00Oomoo`0;Ool00`006=lHg`0>6=lK
OolNF01EOW<2F00jOol00`00Oomoo`0FOol001Qoo`03001oogoo00Yoo`03001oogoo00dHgaaooaiH
05InL`=H03Uoo`03001oogoo01Ioo`0067oo00<007ooOol02Goo00<007ooOol00goo2ASO7Goo7eP0
EWic0eP0>Goo00<007ooOol05Woo000HOol00`00Oomoo`08Ool00`00Oomoo`06Ool56=lOOolNF01G
OW<4F00hOol00`00Oomoo`0FOol001Qoo`03001oogoo00Qoo`03001oogoo02YooaiH05QnL`=H03Qo
o`03001oogoo01Ioo`0067oo00<007ooOol01goo00<007ooOol0:Woo7UP0FGic0eP0>7oo00<007oo
Ool05Woo000HOol00`00Oomoo`06Ool00`00Oomoo`0ZOolOF01JOW<3F00gOol00`00Oomoo`0FOol0
01Qoo`03001oogoo00Eoo`03001oogoo02]ooamH05YnL`AH03Ioo`03001oogoo01Ioo`0067oo00<0
07ooOol017oo00<007ooOol0:goo85P0FWic15P0=Woo00<007ooOol05Woo000HOol00`00Oomoo`03
Ool00`00Oomoo`0[OolQF01JOW<5F00eOol00`00Oomoo`0FOol001Qoo`03001oogoo009oo`03001o
ogoo02aoob1H03InL`800003OW<007ic021nL`EH03Eoo`03001oogoo01Ioo`0067oo00D007ooOomo
o`0002moob1H03QnL`03001nLgic025nL`AH03Eoo`03001oogoo01Ioo`0067oo00@007ooOol002mo
ob5H03=nL`07001nLgicOW<007ic00008Wic1EP0=7oo00<007ooOol05Woo000HOol00`00Ool0000`
OolQF00aOW<3000XOW<6F00cOol00`00Oomoo`0FOol001Qoo`80031oob9H02mnL`800003OW<00000
02QnL`IH03=oo`03001oogoo01Ioo`0067oo00<007ooOol0;goo8EP0;Wic0P000Wic00<007ic0000
:7ic1UP0<goo00<007ooOol05Woo000HOol00`00Oomoo`0_OolQF00aOW<00`00OW<0000YOW<6F00c
Ool00`00Oomoo`0FOol001Qoo`03001oogoo02ioob9H031nL`04001nLgic000YOW<7F00bOol00`00
Oomoo`0FOol001Qoo`03001oogoo02ioob9H02enL`800005OW<007icOW<0000YOW<7F00bOol00`00
Oomoo`0FOol001Qoo`03001oogoo02ioob9H02anL`@000=nL`03001nLgic02MnL`MH039oo`03001o
ogoo01Ioo`0067oo00<007ooOol0;Woo8UP0;7ic1000;Gic25P0<Goo00<007ooOol05Woo000HOol0
0`00Oomoo`0]OolSF00]OW<2000^OW<8F00aOol00`00Oomoo`0FOol001Qoo`03001oogoo02eoob=H
02enL`03001nLgic02enL`QH035oo`03001oogoo01Ioo`0067oo00<007ooOol0;Goo8eP0;7ic00<0
07icOW<0;Wic2EP0<7oo00<007ooOol05Woo000HOol00`00Oomoo`0/OolTF00[OW<00`00OW=nL`0_
OW<9F00`Ool00`00Oomoo`0FOol001Qoo`03001oogoo02aoobEH02UnL`03001nLgic031nL`UH031o
o`03001oogoo01Ioo`0067oo00<007ooOol0;7oo9EP0:Gic00<007icOW<0<7ic2EP0<7oo00<007oo
Ool05Woo000HOol00`00Oomoo`0/OolUF00XOW<00`00OW=nL`0aOW<9F00`Ool00`00Oomoo`0FOol0
01Qoo`03001oogoo02aoobEH02MnL`03001nLgic035nL`YH031oo`03001oogoo01Ioo`0067oo00<0
07ooOol0;7oo9UP09Wic00<007icOW<0<Gic2UP0<7oo00<007ooOol05Woo000HOol00`00Oomoo`0/
OolVF00UOW<00`00OW=nL`0bOW<;F00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobMH02An
L`03001nLgic03=nL`]H02moo`03001oogoo01Ioo`0067oo00<007ooOol0:goo9eP08gic00<007ic
OW<0=7ic2eP0;goo00<007ooOol05Woo000HOol00`00Oomoo`0[OolWF00SOW<00`00OW=nL`0cOW<<
F00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobQH025nL`03001nLgic03AnL`aH02moo`03
001oogoo01Ioo`0067oo00<007ooOol0:goo:5P087ic00<007icOW<0=7ic3EP0;goo00<007ooOol0
5Woo000HOol00`00Oomoo`0[OolYF00NOW<00`00OW=nL`03000bOW<=F00_Ool00`00Oomoo`0FOol0
01Qoo`03001oogoo02]oobUH01anL`<0009nL`8003=nL`eH02moo`03001oogoo01Ioo`0067oo00<0
07ooOol0:goo:UP06Wic100017ic00<007icOW<0<7ic3EP0;goo00<007ooOol05Woo000HOol00`00
Oomoo`0[OolZF00JOW<50003OW<00`00OW=nL`0_OW<>F00_Ool00`00Oomoo`0FOol001Qoo`03001o
ogoo02]oob]H01YnL`80009nL`@0035nL`iH02moo`03001oogoo01Ioo`0067oo00<007ooOol0:goo
:eP07gic00<007icOW<0<7ic3eP0;goo00<007ooOol05Woo000HOol00`00Oomoo`0[Ool/F00OOW<2
000_OW<@F00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobaH025nL`03001nLgic02]nLa5H
02moo`03001oogoo01Ioo`0067oo00<007ooOol0:goo;EP08Gic00<007icOW<0:Wic4EP0;goo00<0
07ooOol05Woo000HOol00`00Oomoo`0[Ool]F00ROW<2000YOW<BF00_Ool00`00Oomoo`0FOol001Qo
o`03001oogoo02aoobeH02=nL`03001nLgic02InLa9H02moo`03001oogoo01Ioo`0067oo00<007oo
Ool0;7oo;UP08gic00<007icOW<097ic4UP0<7oo00<007ooOol05Woo000HOol00`00Oomoo`0/Ool_
F00SOW<2000SOW<CF00`Ool00`00Oomoo`0FOol001Qoo`03001oogoo02aoobmH02EnL`03001nLgic
01mnLaAH031oo`03001oogoo01Ioo`0067oo00<007ooOol0;7oo<5P09Gic0P007gic55P0<7oo00<0
07ooOol05Woo000HOol00`00Oomoo`0/OolaF00VOW<00`00OW=nL`02OW<00`00OW=nL`0FOW<EF00`
Ool00`00Oomoo`0FOol001Qoo`03001oogoo02aooc9H02InL`05001nLgicOW<0000GOW<FF00`Ool0
0`00Oomoo`0FOol001Qoo`03001oogoo02eooc5H02MnL`80009nL`03001nLgic00=nL`8000inLaMH
031oo`03001oogoo01Ioo`0067oo00<007ooOol0;Goo<eP09gic00<007ic00001Wic00<007icOW<0
2gic5eP0<Goo00<007ooOol05Woo000HOol00`00Oomoo`0]OoldF00WOW<00`00OW<00005OW<00`00
OW=nL`0:OW<HF00aOol00`00Oomoo`0FOol001Qoo`03001oogoo02ioocAH029nL`@00003OW<00000
00AnL`03001nL`0000YnLaUH035oo`03001oogoo01Ioo`0067oo00<007ooOol0;Woo=EP09Gic1000
0gic00@007ic000000MnLaYH039oo`03001oogoo01Ioo`0067oo00<007ooOol0;Woo=eP0<gic75P0
<Woo00<007ooOol05Woo000HOol00`00Oomoo`0^OolhF00aOW<MF00bOol00`00Oomoo`0FOol001Qo
o`03001oogoo02moocQH02mnLaeH03=oo`03001oogoo01Ioo`0067oo00<007ooOol0;goo>UP0:gic
7eP0<goo00<007ooOol05Woo000HOol00`00Oomoo`0_OolmF00VOW<QF00cOol00`00Oomoo`0FOol0
01Qoo`03001oogoo031oociH029nLb=H03=oo`03001oogoo01Ioo`0067oo00<007ooOol0<7oo@UP0
6Gic9eP0=7oo00<007ooOol05Woo000HOol00`00Oomoo`0aOom3F00EOW<XF00eOol00`00Oomoo`0F
Ool001Qoo`03001oogoo035oodYH00MnLbmH03Eoo`03001oogoo01Ioo`0067oo00<007ooOol0<Goo
P5P0=Goo00<007ooOol05Woo000HOol00`00Oomoo`0bOomnF00fOol00`00Oomoo`0FOol001Qoo`03
001oogoo03=oogeH03Ioo`03001oogoo01Ioo`0067oo00<007ooOol0<gooO5P0=goo00<007ooOol0
5Woo000HOol00`00Oomoo`0dOomjF00hOol00`00Oomoo`0FOol001Qoo`03001oogoo03AoogYH03Qo
o`03001oogoo01Ioo`0067oo00<007ooOol0=7ooNUP0>7oo00<007ooOol05Woo000HOol00`00Oomo
o`0eOomhF00iOol00`00Oomoo`0FOol001Qoo`03001oogoo03IoogMH03Uoo`03001oogoo01Ioo`00
67oo00<007ooOol0=gooMEP0>Woo00<007ooOol05Woo000HOol00`00Oomoo`0gOomdF00kOol00`00
Oomoo`0FOol001Qoo`03001oogoo03Qoog=H03]oo`03001oogoo01Ioo`0067oo00<007ooOol0>Goo
LEP0?7oo00<007ooOol05Woo000HOol00`00Oomoo`0iOom`F00mOol00`00Oomoo`0FOol001Qoo`03
001oogoo03YoofmH03eoo`03001oogoo01Ioo`0067oo00<007ooOol0>gooKEP0?Woo00<007ooOol0
5Woo000HOol00`00Oomoo`0kOom/F00oOol00`00Oomoo`0FOol001Qoo`03001oogoo03aoofYH041o
o`03001oogoo01Ioo`0067oo00<007ooOol0?GooJ5P0@Goo00<007ooOol05Woo000HOol00`00Oomo
o`0nOomVF012Ool00`00Oomoo`0FOol001Qoo`03001oogoo03moofAH04=oo`03001oogoo01Ioo`00
67oo00<007ooOol0@7ooHUP0A7oo00<007ooOol05Woo000HOol00`00Oomoo`12OomOF015Ool00`00
Oomoo`0FOol001Qoo`03001oogoo04=ooeaH04Moo`03001oogoo01Ioo`0067oo00<007ooOol0A7oo
FeP0Agoo00<007ooOol05Woo000HOol00`00Oomoo`15OomIF018Ool00`00Oomoo`0FOol001Qoo`03
001oogoo04EooeQH04Uoo`03001oogoo01Ioo`0067oo00<007ooOol0AgooEEP0BWoo00<007ooOol0
5Woo000HOol00`00Oomoo`18OomBF01<Ool00`00Oomoo`0FOol001Qoo`03001oogoo04YoodmH04eo
o`03001oogoo01Ioo`0067oo00<007ooOol0BgooC5P0Cgoo00<007ooOol05Woo000HOol00`00Oomo
o`1=Oom9F01@Ool00`00Oomoo`0FOol001Qoo`03001oogoo04ioodIH059oo`03001oogoo01Ioo`00
67oo00<007ooOol0DGoo@5P0EGoo00<007ooOol05Woo000HOol00`00Oomoo`1COollF01GOol00`00
Oomoo`0FOol001Qoo`03001oogoo05AoocYH05Qoo`03001oogoo01Ioo`0067oo00<007ooOol0Egoo
=5P0Fgoo00<007ooOol05Woo000HOol00`00Oomoo`1IOol`F01MOol00`00Oomoo`0FOol001Qoo`03
001oogoo05aoobYH061oo`03001oogoo01Ioo`0067oo00<007ooOol0H7oo8UP0I7oo00<007ooOol0
5Woo000HOol00`00Oomoo`1SOolLF01WOol00`00Oomoo`0FOol001Qoo`03001oogoo06Yoo`iH06io
o`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol0
0`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo
079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000H
Ool00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001o
ogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo
000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03
001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol0
5Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075o
o`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007oo
Ool05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo
075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<0
07ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001o
ogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo
00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03
001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0
LWoo00<007ooOol05Woo000HOooZ000HOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {233, 0}} -> {-3.015, -2.5, 0.0214591, 
  0.0214591}}]
}, Open  ]],

Cell[TextData["Bodies "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Three bodies are used in the rocker mechanism model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground (body 1) requires two points.\nP1 is the rotational axis of the \
eccentric at {0, 0}.\nP2 is the rotational axis of the rocker at {-2, -1}."], 
  "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The eccentric (body2) requires two points.\nP1 is the rotational axis of the \
eccentric at local coordinates {0, 0}.\nP2 is the center of the eccentric \
disk at local coordinates {0.5, 0}."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The rocker (body 3) requires two points.\nP1 is the rotational axis of the \
rocker at local coordinates {0, 0}.\nP2 is the right end of the rocker face \
at local coordinates {4, 0}."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here are all of the bodies in the rocker model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2.5 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0595238 0.952381 [
[ -0.001 -0.001 0 0 ]
[ 1.001 2.501 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 2.5 L
s
P
P
p
p
.002 w
0 2.5 m
1 2.5 L
s
P
p
.002 w
1 0 m
1 2.5 L
s
P
P
p
P
0 0 m
1 0 L
1 2.5 L
0 2.5 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0595238 0.97619 0.853175 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.416667 0.166667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
p
p
p
.2 .2 1 r
.16667 .25 m
.16667 .20833 L
.83333 .20833 L
.83333 .25 L
F
.004 w
.16667 .25 m
.16667 .25 .04167 0 365.73 arc
F
p
.83333 .20833 m
.79167 .16667 L
.75 .20833 L
F
P
P
p
p
.02 w
.16667 .25 Mdot
.79167 .16667 Mdot
.83333 .25 Mdot
P
P
P
p
[(P1 {0,0})] .16667 .25 -0.3 -4 Mshowa
[({4,0})] .83333 .25 -1.2 1.7 Mshowa
[(P2)] .83333 .25 -1.7 -1.7 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.853175 0.97619 1.64683 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.416667 0.166667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
p
p
p
1 0 0 r
.004 w
.5 .41667 m
.5 .41667 .25 0 365.73 arc
F
P
p
1 .7 .7 r
.004 w
.58333 .41667 m
.58333 .41667 .16667 0 365.73 arc
F
P
p
p
.02 w
.5 .41667 Mdot
.58333 .41667 Mdot
P
P
P
p
[({0,0})] .5 .41667 .4 1.7 Mshowa
[(P1)] .5 .41667 0 -1.7 Mshowa
[({.5,0})] .58333 .41667 -0.6 1.7 Mshowa
[(P2)] .58333 .41667 0 -1.7 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 1.64683 0.97619 2.44048 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.416667 0.166667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
p
p
.004 w
.08333 .16667 m
.08333 .75 L
.91667 .75 L
.91667 .08333 L
.08333 .08333 L
.08333 .16667 L
.16667 .25 L
.08333 .33333 L
s
.5 .75 m
.5 .08333 L
s
.02 w
.5 .41667 Mdot
.16667 .25 Mdot
P
p
[({0,0})] .5 .41667 -1.1 1.7 Mshowa
[(P1)] .5 .41667 -1.7 -1.7 Mshowa
[({-2,-1})] .16667 .25 -1.1 1.7 Mshowa
[(P2)] .16667 .25 -1.7 -1.7 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{220, 550},
  ImageMargins->{{50, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L00029Q000`40O003h00Og7oo003LOol00=/0
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`2VOol00`00Oomoo`0^Ool10001Ool00003
001oogoo0:Eoo`<002moo`40005oo`0000<007ooOol0YWoo00<001SOOol0;Woo0@000Goo00000`00
Oomoo`2UOol46=l^Ool10001Ool00003001oogoo0:Aoo`HHgbeoo`40005oo`0000<007ooOol0Xgoo
21SO2Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol03Goo0@000Goo00000`00Oomoo`2R
Ool:6=l8Ool00`00Oomoo`02Ool30002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool10001Ool00003001oogoo0:5oo``Hg`Moo`03001oogoo00=oo`03001oogoo009oo`06001oogoo
001oo`000goo00<007ooOol037oo0@000Goo00000`00Oomoo`2POol>6=l5Ool20003Ool40006Ool0
0`00Ool00003Ool2000=Ool10001Ool00003001oogoo09iooa4Hg`Eoo`07001oogooOol007oo0000
1goo00<007oo00000goo00<007ooOol037oo0@000Goo00000`00Oomoo`0ROon=6=l5Ool00`00Oomo
o`02Ool20007Ool00`00Ool00003Ool00`00Oomoo`0<Ool10001Ool00003001oogoo01mooi0Hg`Io
o`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol0000?Ool10001Ool00003001oogoo01mo
oi0HgbQoo`40005oo`0000<007ooOol07WooTASO:7oo0@000Goo00000`00Oomoo`0MOonB6=lXOol1
0001Ool00003001oogoo01eooi8HgbQoo`40005oo`0000<007ooOol077ooTaSO:7oo0@000Goo0000
0`00Oomoo`0LOol86=l00`006=lHg`286=l00`00Oomoo`0UOol10001Ool00003001oogoo01aoo`LH
g`<008PHg`<002Ioo`40005oo`0000<007ooOol077oo21SO00<001SO6=l01QSOPWoo00<007ooOol0
9Goo0@000Goo00000`00Oomoo`0LOolA6=nZOol10001Ool00003001oogoo01aooa4HgjYoo`40005o
o`0000<007ooOol07Goo41SOZWoo0@000Goo00000`00Oomoo`0NOol>6=n[Ool10001Ool00003001o
ogoo01ioo`dHgjaoo`40005oo`0000<007ooOol087oo2QSO[Goo0@000Goo00000`00Oomoo`0QOol7
6=n;Ool30003Ool3000KOol10001Ool00003001oogoo0;Aoo`03001oogoo009oo`03001oogoo01]o
o`40005oo`0000<007ooOol0]7oo0`000goo00<007ooOol06Woo0@000Goo00000`00Oomoo`2dOol0
1000Oomoo`000Woo00<007ooOol06Woo0@000Goo00000`00Oomoo`2dOol02000Oomoo`00Ool007oo
000KOol10001Ool00003001oogoo0;=oo`@000=oo`03001oogoo01Yoo`40005oo`0000<007ooOol0
egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0
egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0
egoo0@000Goo00000`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`2IOol1
0001Ool00003001oogoo01Moo`<0009oo`D000Moo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo09Qoo`40005oo`0000<007ooOol067oo00<007ooOol0
0goo00<007ooOol01goo00L007ooOomoo`00Ool00004Ool01P00Oomoo`00Ool000=oo`03001oogoo
09Qoo`40005oo`0000<007ooOol067oo0`000goo00<007ooOol01Woo0P000goo00<007oo00001goo
00<007oo00000goo0P00VGoo0@000Goo00000`00Oomoo`0HOol01000Oomoo`000Woo00<007ooOol0
1goo00L007ooOomoo`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`2HOol10001Ool00003001o
ogoo01Qoo`04001oogoo0002Ool00`00Oomoo`07Ool01`00Oomoogoo001oo`0000Moo`03001oo`00
00=oo`03001oogoo09Qoo`40005oo`0000<007ooOol05goo10000Woo0P002Woo00D007ooOomoo`00
00Uoo`05001oogooOol0002KOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40005oo`0000<007ooOol0egoo
0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo065ooa9l06Aoo`40005oo`0000<007oo
Ool0G7oo77`0Ggoo0@000Goo00000`00Oomoo`1IOolRO01LOol10001Ool00003001oogoo05MoobIl
05Yoo`40005oo`0000<007ooOol0EGoo:W`0F7oo0@000Goo00000`00Oomoo`1BOol`O01EOol10001
Ool00003001oogoo051oocAl05=oo`40005oo`0000<007ooOol0CWoo>7`0DGoo0@000Goo00000`00
Oomoo`1=OoljO01@Ool10001Ool00003001oogoo04aoocal04moo`40005oo`0000<007ooOol0BWoo
@7`0CGoo0@000Goo00000`00Oomoo`19Oom2O01<Ool10001Ool00003001oogoo04QoodAl04]oo`40
005oo`0000<007ooOol0AgooAW`0BWoo0@000Goo00000`00Oomoo`16Oom8O019Ool10001Ool00003
001oogoo04EoodYl04Qoo`40005oo`0000<007ooOol0A7ooC7`0Agoo0@000Goo00000`00Oomoo`13
OoldO009O]HAO016Ool10001Ool00003001oogoo049ooc1l01=nePel04Eoo`40005oo`0000<007oo
Ool0@Woo;G`06GkF2g`0A7oo0@000Goo00000`00Oomoo`11OolZO00PO]H8O014Ool10001Ool00003
001oogoo041oobYl02=nePMl04=oo`40005oo`0000<007ooOol0?goo:W`09GkF1g`0@Woo0@000Goo
00000`00Oomoo`0oOolXO00YO]H6O011Ool10001Ool00003001oogoo03ioobQl02]nePEl045oo`40
005oo`0000<007ooOol0?Goo9g`0;gkF17`0@7oo0@000Goo00000`00Oomoo`0lOolWO00aO]H4O00o
Ool10001Ool00003001oogoo03aoobIl03=nePAl03ioo`40005oo`0000<007ooOol0>goo9g`0=7kF
0g`0?Woo0@000Goo00000`00Oomoo`0kOolVO00eO]H4O00mOol10001Ool00003001oogoo03]oobEl
03MneP=l03eoo`40005oo`0000<007ooOol0>Woo9W`0>7kF0W`0?Goo0@000Goo00000`00Oomoo`0j
OolUO00jO]H2O00lOol10001Ool00003001oogoo03UoobEl03aneP03O01oogoo03Yoo`40005oo`00
00<007ooOol0>Goo97`0?GkF0W`0>goo0@000Goo00000`00Oomoo`0iOolTO00nO]H00g`0Oomoo`0i
Ool10001Ool00003001oogoo03QoobAl03mneP03O01oogoo03Uoo`40005oo`0000<007ooOol0>7oo
97`0?gkF00=l07ooOol0>Goo0@000Goo00000`00Oomoo`0hOolSO0000`00O]IneP06O]H00`00O]In
eP06O]H00`00O]IneP08O]H00`00O]IneP0;O]H00`00O]IneP06O]H00`00O]IneP09O]H00g`0Oomo
o`0iOol10001Ool00003001oogoo03Qoob9l0003001neWkF009neP03001neWkF009neP03001neWkF
009neP03001neWkF009neP03001neWkF00IneP03001neWkF009neP03001neWkF009neP03001neWkF
009neP03001neWkF009neP03001neWkF009neP03001neWkF00UneP03O01oogoo03Qoo`40005oo`00
00<007ooOol0>7oo8W`000L007kFO]IneP00O]H00004O]H01P00O]IneP00O]H000=neP03001neWkF
00IneP03001neWkF00IneP03001neP0000AneP06001neWkF001neP000gkF00<007kFO]H02GkF00=l
07ooOol0>7oo0@000Goo00000`00Oomoo`0gOolRO0020003O]H00`00O]H00007O]H00`00O]H00003
O]H20006O]H2000:O]H00`00O]IneP05O]H00`00O]H00003O]H2000:O]H00g`0Oomoo`0hOol10001
Ool00003001oogoo03Moob=l0007001neWkFO]H007kF00001gkF00<007kF00000gkF00<007kFO]H0
1WkF00<007kFO]H01WkF0P0027kF00<007kF00000gkF00<007kFO]H02WkF>Woo0@000Goo00000`00
Oomoo`0gOolSO0001`00O]IneWkF001neP0000MneP03001neP0000=neP03001neWkF00IneP03001n
eWkF00IneP03001neWkF00MneP03001neP0000=neP03001neWkF00YneSYoo`40005oo`0000<007oo
Ool0=goo8W`00WkF00D007kFO]IneP0000UneP05001neWkFO]H0000:O]H00`00O]IneP05O]H30008
O]H01@00O]IneWkF00003GkF00=l07ooOol0=goo0@000Goo00000`00Oomoo`0gOolRO015O]HiOol1
0001Ool00003001oogoo03Ioob=l04EneSUoo`40005oo`0000<007ooOol0=Woo8g`0AGkF>Goo0@00
0Goo00000`00Oomoo`0fOolSO015O]HiOol10001Ool00003001oogoo03Ioob=l04EneSUoo`40005o
o`0000<007ooOol0=Woo8g`0AGkF>Goo0@000Goo00000`00Oomoo`0fOolSO00@O]H00`00O]IneP0?
O]H00`00O]IneP0PO]HiOol10001Ool00003001oogoo03Ioob=l00mneP<000mneP<0025neSUoo`40
005oo`0000<007ooOol0=Woo8g`047kF00<007kFO]H03gkF00<007kFO]H087kF>Goo0@000Goo0000
0`00Oomoo`0fOolSO015O]HiOol10001Ool00003001oogoo03Ioob=l04EneSUoo`40005oo`0000<0
07ooOol0=Woo8g`0AGkF>Goo0@000Goo00000`00Oomoo`0gOolRO015O]HiOol10001Ool00003001o
ogoo03Moob9l04AneP03O01oogoo03Moo`40005oo`0000<007ooOol0=goo8g`02gkF0`000WkF1@00
1gkF0`000gkF0`007WkF>Woo0@000Goo00000`00Oomoo`0gOolSO00<O]H00`00O]IneP03O]H00`00
O]IneP08O]H00`00O]IneP02O]H00`00O]IneP0NO]HjOol10001Ool00003001oogoo03Moob=l00an
eP<000=neP03001neWkF00QneP<000=neP03001neWkF01aneP03O01oogoo03Qoo`40005oo`0000<0
07ooOol0>7oo8g`02gkF00@007kFO]H0009neP03001neWkF00QneP04001neWkF0002O]H00`00O]In
eP0LO]H00g`0Oomoo`0hOol10001Ool00003001oogoo03Qoob=l00]neP04001neWkF0002O]H00`00
O]IneP08O]H02000O]IneP00O]H007kF000MO]H00g`0Oomoo`0hOol10001Ool00003001oogoo03Qo
ob=l00YneP@0009neP8000UneP@000=neP03001neWkF01aneS]oo`40005oo`0000<007ooOol0>7oo
8g`0@7kF00=l07ooOol0>Goo0@000Goo00000`00Oomoo`0hOolTO00oO]H00g`0Oomoo`0iOol10001
Ool00003001oogoo03UoobAl03ineP03O01oogoo03Uoo`40005oo`0000<007ooOol0>Goo97`0?GkF
0W`0>goo0@000Goo00000`00Oomoo`0iOolUO00lO]H00g`0Oomoo`0jOol10001Ool00003001oogoo
03YoobEl03YneP9l03aoo`40005oo`0000<007ooOol0>Woo9W`0>7kF0W`0?Goo0@000Goo00000`00
Oomoo`0kOolUO00gO]H3O00mOol10001Ool00003001oogoo03]oobIl03EnePAl03eoo`40005oo`00
00<007ooOol0>goo9g`0=7kF0g`0?Woo0@000Goo00000`00Oomoo`0lOolVO00cO]H4O00nOol10001
Ool00003001oogoo03aoobMl035nePAl03moo`40005oo`0000<007ooOol0?Goo9g`0;gkF17`0@7oo
0@000Goo00000`00Oomoo`0nOolXO00[O]H5O011Ool10001Ool00003001oogoo03moobQl02UnePIl
045oo`40005oo`0000<007ooOol0?goo:W`09GkF1g`0@Woo0@000Goo00000`00Oomoo`10OolZO00S
O]H7O013Ool10001Ool00003001oogoo041oob]l021nePQl04Aoo`40005oo`0000<007ooOol0@Goo
;7`07GkF2G`0A7oo0@000Goo00000`00Oomoo`12Ool^O00FO]H<O015Ool10001Ool00003001oogoo
04=ooc5l00mnePil04Ioo`40005oo`0000<007ooOol0A7oo=G`01GkF4W`0Agoo0@000Goo00000`00
Oomoo`15Oom:O018Ool10001Ool00003001oogoo04IoodQl04Uoo`40005oo`0000<007ooOol0Agoo
AW`0BWoo0@000Goo00000`00Oomoo`18Oom4O01;Ool10001Ool00003001oogoo04Uood9l04aoo`40
005oo`0000<007ooOol0BWoo@7`0CGoo0@000Goo00000`00Oomoo`1<OollO01?Ool10001Ool00003
001oogoo04eoocYl051oo`40005oo`0000<007ooOol0CWoo>7`0DGoo0@000Goo00000`00Oomoo`1@
OoldO01COol10001Ool00003001oogoo059ooc1l05Eoo`40005oo`0000<007ooOol0EGoo:W`0F7oo
0@000Goo00000`00Oomoo`1GOolVO01JOol10001Ool00003001oogoo05Uoob9l05aoo`40005oo`00
00<007ooOol0G7oo77`0Ggoo0@000Goo00000`00Oomoo`1NOolHO01QOol10001Ool00003001oogoo
06=oo`el06Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003
001oogoo0=Moo`40005oo`0000<007ooOol04goo[`005Goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo
05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo
00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00
Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo
05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo
00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00
Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo
01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo
0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001
Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`00
00<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00
Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo
01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo
00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo
05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo0P00EGoo00<007oo
Ool0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Ool0001DOol00`00Oomoo`1D
Ool00`00Oomoo`0COol10001Ool00003001oogoo01=oo`04001oogoo001COol00`00Oomoo`1DOol0
0`00Oomoo`0COol10001Ool00003001oogoo01=oo`05001oogooOol0001BOol00`00Oomoo`1DOol0
0`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo009oo`03001oogoo00ioo`03001o
ogoo00]oo`03001oogoo00]oo`03001oogoo029oo`03001oogoo05Aoo`03001oogoo01=oo`40005o
o`0000<007ooOol04goo00<007ooOol00goo00<007ooOol037oo00<007ooOol01Woo0`000goo00<0
07ooOol01Goo1@000Woo00<007ooOol08Goo00<007ooOol0E7oo00<007ooOol04goo0@000Goo0000
0`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`1DOol00`00Oomoo`0COol1
0001Ool00003001oogoo01=oo`03001oogoo00Eoo`03001oogoo00Uoo`8000=oo`<000=oo`03001o
ogoo00Ioo`<000=oo`03001oogoo009oo`80029oo`03001oogoo05Aoo`03001oogoo01=oo`40005o
o`0000<007ooOol04goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0
37oo00<007ooOol00Woo00<007ooOol08Goo00<007ooOol0E7oo00<007ooOol04goo0@000Goo0000
0`00Oomoo`0COol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Ool0000=Ool0
0`00Oomoo`02Ool00`00Oomoo`0QOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001o
ogoo01=oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00]oo`8000=o
o`03001oogoo029oo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<0
07ooOol02Goo00<007ooOol0B7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomo
o`0COol00`00Oomoo`0:Ool00`00Oomoo`17Ool00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool0
0003001oogoo01=oo`03001oogoo00]oo`03001oogoo04Ioo`03001oogoo05Aoo`03001oogoo01=o
o`40005oo`0000<007ooOol04goo00<007ooOol037oo00<007ooOol0AGoo00<007ooOol0E7oo00<0
07ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomo
o`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo00ioo`03001oogoo04=o
o`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol03Goo0`00
A7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`0>Ool0
0`00Oomoo`13Ool00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol0
4goo00<007ooOol037oo00<007ooOol0AGoo00<007ooOol0E7oo00<007ooOol04goo0@000Goo0000
0`00Oomoo`0COol00`00Oomoo`0;Ool00`00Oomoo`16Ool00`00Oomoo`1DOol00`00Oomoo`0COol1
0001Ool00003001oogoo01=oo`03001oogoo00Yoo`03001oogoo04Moo`03001oogoo05Aoo`03001o
ogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol02Goo00<007ooOol0B7oo00<007ooOol0
E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`19Ool0
0`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo00Moo`03001o
ogoo00Qoo`<000=oo`<003Uoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol0
4goo00<007ooOol01Goo0P0037oo00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol0E7oo00<0
07ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0<Ool30003Ool0
0`00Oomoo`0hOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001o
ogoo00=oo`03001oogoo00eoo`04001oogoo0002Ool00`00Oomoo`0hOol00`00Oomoo`1DOol00`00
Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo009oo`03001oogoo00ioo`08001oogoo
001oo`00Ool003Uoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00D0
07ooOomoo`00011oo`@000=oo`03001oogoo03Qoo`03001oogoo05Aoo`03001oogoo01=oo`40005o
o`0000<007ooOol04goo00@007ooOol005=oo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`00
00<007ooOol04goo00<007oo0000E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00
Oomoo`0COol2001EOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03
001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007oo
Ool0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1D
Ool00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03
001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00D007oo
Oomoo`0000Qoo`03001oogoo00Ioo`03001oogoo03ioo`03001oogoo01=oo`40005oo`0000<007oo
Ool04goo00<007ooOol0E7oo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo03eoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0
E7oo00@007ooOol000=oo`03001oo`0000Aoo`06001oogoo001oo`000goo00<007ooOol0?Goo00<0
07ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol01000Ool000000goo00<007oo
00001goo00<007oo00000goo0P00?Woo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1DOol01000Oomoo`000goo00<007oo00001goo00<007oo00000goo00<007ooOol0?Goo00<0
07ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol01000Oomoo`000goo00<007oo
00001goo00<007oo00000goo00<007ooOol0?Goo00<007ooOol04goo0@000Goo00000`00Oomoo`0C
Ool00`00Oomoo`1DOol01@00Oomoogoo00000goo00<007ooOol01goo00D007ooOomoo`00041oo`03
001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007oo
Ool04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0C
Ool10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40
005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo
00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003
001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007oo
Ool04goo00<007ooOol0Dgoo0P00EWoo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1BOol3001FOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05=oo`80
05Ioo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo
00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00
Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo
01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo
0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001
Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`00
00<007ooOol04goo00<007ooOol0E7oo00<007ooOol00`000Woo1@00BWoo00<007ooOol04goo0@00
0Goo00000`00Oomoo`0COol00`00Oomoo`1DOol01@00Oomoogoo00001Goo00<007ooOol0BWoo00<0
07ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol01000Oomoogoo0`000goo00<0
07ooOol0BWoo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol01@00Oomo
ogoo00000Woo00@007ooOol004aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007oo
Ool0E7oo00D007ooOomoo`00009oo`04001oogoo001<Ool00`00Oomoo`0COol10001Ool00003001o
ogoo01=oo`03001oogoo05Aoo`03001oogoo00@0009oo`8004aoo`03001oogoo01=oo`40005oo`00
00<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00
Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo
01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo
00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo
05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo
00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00
Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo
05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo
00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00
Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo
01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo
0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001
Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`00
00<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00
Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo
01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo
00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo
05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo
00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00
Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo
05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo
00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00
Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo
01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo
0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001
Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`00
00<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00
Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo
01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo
00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo
05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo
00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00
Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo
05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo
00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00
Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo
01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo
0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001
Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`00
00<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00
Oomoo`0COol00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo
01=oo`03001oogoo05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo
00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00
Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo
05Aoo`03001oogoo05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo
00<007ooOol0E7oo00<007ooOol04goo0@000Goo00000`00Oomoo`0COol00`00Oomoo`1DOol00`00
Oomoo`1DOol00`00Oomoo`0COol10001Ool00003001oogoo01=oo`03001oogoo05Aoo`03001oogoo
05Aoo`03001oogoo01=oo`40005oo`0000<007ooOol04goo00<007ooOol0E7oo00<007ooOol0E7oo
00<007ooOol04goo0@000Goo00000`00Oomoo`0COon_000EOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo00000`00Oomoo`3GOol10001Ool00003001oogoo0=Moo`40
005oo`0000<007ooOol0egoo0@000Goo003K0001Ool00=aoo`00\
\>"],
  ImageRangeCache->{{{0, 219}, {549, 0}} -> {-0.0260552, -0.0687413, 
  0.00480416, 0.00480416}, {{5.375, 213.563}, {534.688, 361.188}} ->
   {-3.15493, -2.91267, 0.0288204, 0.0288204}, {{5.375, 213.563}, {361.188, 
  187.75}} -> {-3.15587, -7.91446, 0.0288289, 0.0288289}, {{5.375, 213.563}, {
  187.75, 14.25}} -> {-3.15493, -12.9116, 0.0288204, 0.0288204}}],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(eccentric = 2; \)\), 
    \(\(rocker = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used only to set a nonzero initial guess for the rocker."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[Body[rocker, InitialGuess \[Rule] {{\(-2\), \(-1\)}, 0}]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Four regular constraints and one ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are used to model the rocker mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of the rocker to be coincident with its pivot \
point on the ground. This constrains two degrees of freedom, ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " displacement of the rocker."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the rotational axis of the eccentric."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the angular coordinate of the eccentric. This driving \
constraint is used to specify the rotation of the eccentric as a function of \
",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint enforces that the surface of the eccentric disk, which has a \
radius of one unit, remains in contact with the face of the rocker."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with two stages constrains the remaining one degree of freedom. Which \
mode of operation is active is determined by the boolean value of ",
  StyleBox["rockerfree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["rockerfree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of the axis of the eccentric, leaving the rocker free to \
reciprocate."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["rockerfree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint enforces that the rocker does not rotate, leaving the \
eccentric free to reciprocate vertically. "
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the complete rocker mechanism, built in one step."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(rockerfree =. \), 
    \(SetConstraints[\n\t
      Revolute2[1, Point[ground, {\(-2\), \(-1\)}], Point[rocker, 0]], \n\t
      RelativeX1[2, Point[eccentric, 0], 0], \n\t
      RotationLock1[3, eccentric, 2\ N[\[Pi]]\ T], \n\t
      PointOnLine1[4, Point[eccentric, {0.5, 0}], Line[rocker, 0, {4, 0}], 
        1.0], \n\t
      StageSwitch[5, \n\t\trockerfree, \n\t\t
        RelativeY1[1, Point[eccentric, 0], 0], \n\t\t\(! rockerfree\), \n\t\t
        RotationLock1[2, rocker, 0]]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The rocker mechanism model is first run with ",
  StyleBox["rockerfree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " set to ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This enables the first stage of the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is first run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.15 with the rocker free to rotate."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rockerfree = True; \)\), 
    \(SolveMech[.15] // Chop\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.15`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 0.942477796076937934`\), ",", 
        \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] \(-1.`\)\), ",", 
        \(Th3 \[Rule] 0.168468994032337953`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the rocker mechanism with ",
  StyleBox["rockerfree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.416667 0.166667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
p
p
.004 w
.08333 .16667 m
.08333 .75 L
.91667 .75 L
.91667 .08333 L
.08333 .08333 L
.08333 .16667 L
.16667 .25 L
.08333 .33333 L
s
.5 .75 m
.5 .08333 L
s
.02 w
.5 .41667 Mdot
.16667 .25 Mdot
P
p
p
.7 0 0 r
.004 w
.5 .41667 m
.5 .41667 .25 0 365.73 arc
F
P
p
1 .6 .6 r
.004 w
.54898 .48408 m
.54898 .48408 .16667 0 365.73 arc
F
P
p
p
.02 w
.5 .41667 Mdot
.54898 .48408 Mdot
P
P
P
p
p
.2 .2 1 r
.16667 .25 m
.17365 .20892 L
.83088 .32071 L
.8239 .36178 L
F
.004 w
.16667 .25 m
.16667 .25 .04167 0 365.73 arc
F
p
.83088 .32071 m
.79679 .27264 L
.74873 .30673 L
F
P
P
p
p
.02 w
.16667 .25 Mdot
.79679 .27264 Mdot
.8239 .36178 Mdot
P
P
P
p
p
p
/Courier findfont 8 scalefont setfont
[(x)] .56857 .51105 .33185 -1.25712 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .40561 .48524 .33185 -1.25712 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(2)] .5 .41667 .33185 -1.25712 Mshowa
P
.004 w
.56857 .51105 m
.5 .41667 L
.40561 .48524 L
s
.5643 .48532 m
.56857 .51105 L
.54542 .49903 L
s
.41763 .46209 m
.40561 .48524 L
.43135 .48097 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 234},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000jQ000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
67oojP0067oo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001o
ogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo
00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03
001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0
LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qo
o`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007oo
Ool0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol0
01Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<0
07ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0F
Ool001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo
00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomo
o`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0
LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00
Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007oo
Ool0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol0
0`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo0P00
JGoo4UP0K7oo00<007ooOol05Woo000HOol00`00Ool0001QOolPF01UOol00`00Oomoo`0FOol001Qo
o`04001oogoo001MOolVF01ROol00`00Oomoo`0FOol001Qoo`05001oogooOol0001IOol/F01OOol0
0`00Oomoo`0FOol001Qoo`03001oogoo009oo`03001oogoo059oocAH05]oo`03001oogoo01Ioo`00
67oo00<007ooOol00goo00<007ooOol0D7oo=UP0FWoo00<007ooOol05Woo000HOol00`00Oomoo`04
Ool00`00Oomoo`1<OollF01GOol00`00Oomoo`0FOol001Qoo`03001oogoo00Eoo`03001oogoo04Uo
od1H05Eoo`03001oogoo01Ioo`0067oo00<007ooOol01Woo00<007ooOol0Agoo@UP0E7oo00<007oo
Ool05Woo000HOol00`00Oomoo`07Ool00`00Oomoo`13Oom9F01@Ool00`00Oomoo`0FOol001Qoo`03
001oogoo00Qoo`03001oogoo041oodaH04moo`03001oogoo01Ioo`0067oo00<007ooOol02Goo00<0
07ooOol0?WooCeP0CGoo00<007ooOol05Woo000HOol00`00Oomoo`0:Ool01000Oomoogoo3QSO;7oo
DUP0C7oo00<007ooOol05Woo000HOol00`00Oomoo`0;Ool00`00OolHg`0D6=lUOomEF01:Ool00`00
Oomoo`0FOol001Qoo`03001oogoo00aooa`HgaeooeQH04Uoo`03001oogoo01Ioo`0067oo00<007oo
Ool02goo8aSO5gooFEP0B7oo00<007ooOol05Woo000HOol00`00Oomoo`0:OolZ6=l@OomKF017Ool0
0`00Oomoo`0FOol001Qoo`03001oogoo00Uooc4Hg`UooeaH04Moo`03001oogoo01Ioo`0067oo00<0
07ooOol02Goo=aSO0WooGeP0AGoo00<007ooOol05Woo000HOol00`00Oomoo`09Oolm6=mLF014Ool0
0`00Oomoo`0FOol001Qoo`03001oogoo00Uood<HgeMH04=oo`03001oogoo01Ioo`0067oo00<007oo
Ool02GooBASODUP0@Woo00<007ooOol05Woo000HOol00`00Oomoo`08Ool;6=l200136=m=F011Ool0
0`00Oomoo`0FOol001Qoo`03001oogoo00Qoo`XHg`@004PHgdQH041oo`03001oogoo01Ioo`0067oo
00<007ooOol027oo2QSO10002ASO00=ooaSO6=l0@QSO@eP0?goo00<007ooOol05Woo000HOol00`00
Oomoo`09Ool:6=l2000:6=l7Oom46=lnF00nOol00`00Oomoo`0FOol001Qoo`03001oogoo00UooaHH
g`aoodDHgcUH03eoo`03001oogoo01Ioo`0067oo00<007ooOol02Woo5ASO4WooA1SO=5P0?Goo00<0
07ooOol05Woo000HOol00`00Oomoo`0:OolD6=lIOom46=l_F00IOol2000QOol00`00Oomoo`0FOol0
01Qoo`03001oogoo00]ooa8Hga]oo`EH04@HgbYH01Moo`@0021oo`03001oogoo01Ioo`0067oo00<0
07ooOol02goo4QSO6Woo2eP0AASO95P05goo100087oo00<007ooOol05Woo000HOol00`00Oomoo`0;
Ool00`006=lHg`0>6=lKOolAF0156=lOF00FOol011SO000001SO87oo00<007ooOol05Woo000HOol0
0`00Oomoo`0:Ool00`00Oomoo`0=6=lLOolHF0156=lJF00COol76=lOOol00`00Oomoo`0FOol001Qo
o`03001oogoo00Uoo`03001oogoo00=oo`THgaeooamH04DHgaAH019oo`THgaioo`03001oogoo01Io
o`0067oo00<007ooOol027oo00<007ooOol01Woo1ASO7goo95P0AQSO3eP03goo2aSO7Woo00<007oo
Ool05Woo000HOol00`00Oomoo`08Ool00`00Oomoo`0ZOolZF0166=l9F00>Ool=6=lMOol00`00Oomo
o`0FOol001Qoo`03001oogoo00Moo`03001oogoo02Yooc5H04HHg`=H00aooa0Hgaaoo`03001oogoo
01Ioo`0067oo00<007ooOol01Woo00<007ooOol0:Woo>5P0AQSO27oo4QSO6goo00<007ooOol05Woo
000HOol00`00Oomoo`05Ool00`00Oomoo`0[OolmF01K6=lKOol00`00Oomoo`0FOol001Qoo`03001o
ogoo00Aoo`03001oogoo02]oodAH05HHgaYoo`03001oogoo01Ioo`0067oo00<007ooOol00goo00<0
07ooOol0:gooBeP0DASO6Goo00<007ooOol05Woo000HOol00`00Oomoo`02Ool00`00Oomoo`0/OomA
F01<6=lHOol00`00Oomoo`0FOol001Qoo`05001oogooOol0000_Oom8F00<OW<2F0176=lHOol00`00
Oomoo`0FOol001Qoo`04001oogoo000_Oom2F00IOW<2F0116=lHOol00`00Oomoo`0FOol001Qoo`03
001oo`00031ood1H01inL`EH03/HgaQoo`03001oogoo01Ioo`0067oo0P00<7oo?EP09Wic1eP0=ASO
67oo00<007ooOol05Woo000HOol00`00Oomoo`0_OoljF00[OW<:F00`6=lHOol00`00Oomoo`0FOol0
01Qoo`03001oogoo02moocQH02mnL`iH02XHgaQoo`03001oogoo01Ioo`0067oo00<007ooOol0;Woo
>5P0<Gic4eP08aSO6Goo00<007ooOol05Woo000HOol00`00Oomoo`0^OolgF00cOW<HF00M6=lIOol0
0`00Oomoo`0FOol001Qoo`03001oogoo02ioocIH03InLaYH0003OolHgaSO01HHgaUoo`03001oogoo
01Ioo`0067oo00<007ooOol0;Woo=5P0>Wic6EP01Woo4QSO6Goo00<007ooOol05Woo000HOol00`00
Oomoo`0]OoldF00lOW<HF00<Ool<6=lIOol00`00Oomoo`0FOol001Qoo`03001oogoo02eooc=H03in
LaMH019oo`<Hg`8000036=moogoo01Moo`03001oogoo01Ioo`0067oo00<007ooOol0;Goo<EP0@Gic
5eP04goo10006Goo00<007ooOol05Woo000HOol00`00Oomoo`0/OolbF012OW<FF00COol4000IOol0
0`00Oomoo`0FOol001Qoo`03001oogoo02aooc5H04AnLaEH01Aoo`8001Yoo`03001oogoo01Ioo`00
67oo00<007ooOol0;7oo<5P0AWic55P0<7oo00<007ooOol05Woo000HOol00`00Oomoo`0/Ool_F017
OW<DF00`Ool00`00Oomoo`0FOol001Qoo`03001oogoo02aoobmH04QnLa=H031oo`03001oogoo01Io
o`0067oo00<007ooOol0;7oo;UP0BWic4UP0<7oo00<007ooOol05Woo000HOol00`00Oomoo`0/Ool]
F01<OW<BF00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobeH04enLa9H02moo`03001oogoo
01Ioo`0067oo00<007ooOol0:goo;EP0CWic4EP0;goo00<007ooOol05Woo000HOol00`00Oomoo`0[
Ool/F01?OW<AF00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobaH051nLa1H02moo`03001o
ogoo01Ioo`0067oo00<007ooOol0:goo:eP0DWic3eP0;goo00<007ooOol05Woo000HOol00`00Oomo
o`0[Ool[F01COW<>F00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobYH01]nL`8003MnL`iH
02moo`03001oogoo01Ioo`0067oo00<007ooOol0:goo:UP06Wic1000=gic3EP0;goo00<007ooOol0
5Woo000HOol00`00Oomoo`0[OolYF00KOW<4000gOW<=F00_Ool00`00Oomoo`0FOol001Qoo`03001o
ogoo02]oobUH01YnL`03001nL`00008003MnL`eH02moo`03001oogoo01Ioo`0067oo00<007ooOol0
:goo:5P06Wic00<007icOW<00gic00<007icOW<0=7ic3EP0;goo00<007ooOol05Woo000HOol00`00
Oomoo`0[OolXF00HOW<20002OW<30002OW<00`00OW=nL`0dOW<<F00_Ool00`00Oomoo`0FOol001Qo
o`03001oogoo02]oobMH01QnL`03001nLgic009nL`8000AnL`03001nLgic03=nL`aH02moo`03001o
ogoo01Ioo`0067oo00<007ooOol0:goo9eP05gic00<007icOW<01Gic00D007icOW=nL`0003InL`]H
02moo`03001oogoo01Ioo`0067oo00<007ooOol0:goo9eP05Gic0P0027ic00<007icOW<00Wic00<0
07icOW<0<gic2eP0;goo00<007ooOol05Woo000HOol00`00Oomoo`0/OolVF00DOW<00`00OW=nL`06
OW<30005OW<00`00OW=nL`0bOW<;F00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02aoobIH01=n
L`03001nLgic011nL`03001nLgic035nL`YH031oo`03001oogoo01Ioo`0067oo00<007ooOol0;7oo
9EP04Wic0P004gic00<007icOW<0<Gic2UP0<7oo00<007ooOol05Woo000HOol00`00Oomoo`0/OolU
F00AOW<00`00OW=nL`0DOW<00`00OW=nL`0aOW<9F00`Ool00`00Oomoo`0FOol001Qoo`03001oogoo
02aoobEH00mnL`8001QnL`03001nLgic031nL`UH031oo`03001oogoo01Ioo`0067oo00<007ooOol0
;7oo9EP02Gic00<007icOW<00Wic00<007icOW<067ic00<007icOW<0<7ic2EP0<7oo00<007ooOol0
5Woo000HOol00`00Oomoo`0/OolTF009OW<00`00OW=nL`02OW<00`00OW=nL`0JOW<00`00OW=nL`0_
OW<9F00`Ool00`00Oomoo`0FOol001Qoo`03001oogoo02eoob=H00UnL`03001nLgic008001inL`03
001nLgic02inL`UH031oo`03001oogoo01Ioo`0067oo00<007ooOol0;Goo8eP027ic00@007icOW<0
025nL`03001nLgic02enL`QH035oo`03001oogoo01Ioo`0067oo00<007ooOol0;Goo8eP027ic00<0
07ic00008Wic00<007icOW<0;Gic25P0<Goo00<007ooOol05Woo000HOol00`00Oomoo`0^OolRF007
OW<300000gic00000002000NOW<2000^OW<8F00aOol00`00Oomoo`0FOol001Qoo`03001oogoo02io
ob9H00MnL`@0025nL`@000=nL`03001nLgic02MnL`MH039oo`03001oogoo01Ioo`0067oo00<007oo
Ool0;Woo8UP0;7ic1@000Wic00<007icOW<09gic1eP0<Woo00<007ooOol05Woo000HOol00`00Oomo
o`0^OolRF004OW<2000WOW<200001Gic001nLgic0000:Gic1eP0<Woo00<007ooOol05Woo000HOol0
0`00Oomoo`0_OolQF005OW<00`00OW=nL`0YOW<00`00OW<0000YOW<6F00cOol00`00Oomoo`0FOol0
01Qoo`03001oogoo02moob5H00EnL`03001nLgic02InL`07001nLgicOW<007ic0000:7ic1UP0<goo
00<007ooOol05Woo000HOol00`00Oomoo`0_OolRF003OW<00`00OW<0000XOW<20002OW<2000XOW<6
F00cOol00`00Oomoo`0FOol001Qoo`03001oogoo031oob5H00=nL`04001nL`00000YOW<4000XOW<6
F00cOol00`00Oomoo`0FOol001Qoo`03001oogoo031oob5H039nL`8002QnL`EH03Aoo`03001oogoo
01Ioo`0067oo00<007ooOol0<Goo85P0G7ic15P0=Goo00<007ooOol05Woo000HOol00`00Oomoo`0a
OolPF01KOW<5F00eOol00`00Oomoo`0FOol001Qoo`03001oogoo035oob5H05YnL`EH03Eoo`03001o
ogoo01Ioo`0067oo00<007ooOol0<Woo85P0;gic0P0000=nL`00OW<09Wic15P0=Woo00<007ooOol0
5Woo000HOol00`00Oomoo`0cOolOF00aOW<00`00OW=nL`0VOW<4F00fOol00`00Oomoo`0FOol001Qo
o`03001oogoo03=ooamH031nL`03001nL`0002MnL`=H03Moo`03001oogoo01Ioo`0067oo00<007oo
Ool0=7oo7UP0FGic0eP0>7oo00<007ooOol05Woo000HOol00`00Oomoo`0dOolOF01HOW<3F00hOol0
0`00Oomoo`0FOol001Qoo`03001oogoo03AooamH05MnL`AH03Qoo`03001oogoo01Ioo`0067oo00<0
07ooOol0=Goo7eP0EWic0eP0>Goo00<007ooOol05Woo000HOol00`00Oomoo`0fOolNF01FOW<3F00i
Ool00`00Oomoo`0FOol001Qoo`03001oogoo03MooaiH05EnL`9H03Yoo`03001oogoo01Ioo`0067oo
00<007ooOol0=goo7UP0E7ic0UP0>goo00<007ooOol05Woo000HOol00`00Oomoo`0hOolNF01COW<2
F00kOol00`00Oomoo`0FOol001Qoo`03001oogoo03UooaeH059nL`9H03aoo`03001oogoo01Ioo`00
67oo00<007ooOol0>Goo7UP0D7ic0UP0?Goo00<007ooOol05Woo000HOol00`00Oomoo`0jOolMF01?
OW<3F00mOol00`00Oomoo`0FOol001Qoo`03001oogoo03]ooaeH04inL`9H03ioo`03001oogoo01Io
o`0067oo00<007ooOol0>goo7EP0CGic0UP0?goo00<007ooOol05Woo000HOol00`00Oomoo`0lOolM
F01<OW<00eP0Oomoo`0nOol00`00Oomoo`0FOol001Qoo`03001oogoo03eooaeH04YnL`03F01oogoo
03moo`03001oogoo01Ioo`0067oo00<007ooOol0?Woo7EP0B7ic00=H07ooOol0@7oo00<007ooOol0
5Woo000HOol00`00Oomoo`0oOolLF017OW<00eP0Oomoo`11Ool00`00Oomoo`0FOol001Qoo`03001o
ogoo041ooaaH04InLdAoo`03001oogoo01Ioo`0067oo00<007ooOol0@Woo6eP0A7icAGoo00<007oo
Ool05Woo000HOol00`00Oomoo`13OolKF011OW=7Ool00`00Oomoo`0FOol001Qoo`03001oogoo04Ao
oa]H041nLdMoo`03001oogoo01Ioo`0067oo00<007ooOol0AGoo6eP0?WicB7oo00<007ooOol05Woo
000HOol00`00Oomoo`15OolMF00jOW<00eP0Oomoo`17Ool00`00Oomoo`0FOol001Qoo`03001oogoo
04MooaaH03QnL`03F01oogoo04Qoo`03001oogoo01Ioo`0067oo00<007ooOol0B7oo6eP0=gicC7oo
00<007ooOol05Woo000HOol00`00Oomoo`1:OolKF00cOW<00eP0Oomoo`1;Ool00`00Oomoo`0FOol0
01Qoo`03001oogoo04]ooaaH02mnL`03F01oogoo04eoo`03001oogoo01Ioo`0067oo00<007ooOol0
CGoo75P0:gic0UP0D7oo00<007ooOol05Woo000HOol00`00Oomoo`1>OolNF00VOW<2F01BOol00`00
Oomoo`0FOol001Qoo`03001oogoo055ooaeH029nL`03F01oogoo05=oo`03001oogoo01Ioo`0067oo
00<007ooOol0Dgoo7EP07Wic00=H07ooOol0EGoo00<007ooOol05Woo000HOol00`00Oomoo`1DOolN
F00IOW<3F01HOol00`00Oomoo`0FOol001Qoo`03001oogoo05Moob1H011nL`AH05]oo`03001oogoo
01Ioo`0067oo00<007ooOol0FGoo<5P0GGoo00<007ooOol05Woo000HOol00`00Oomoo`1LOolZF01P
Ool00`00Oomoo`0FOol001Qoo`03001oogoo061oob9H06Aoo`03001oogoo01Ioo`0067oo00<007oo
Ool0Hgoo75P0Igoo00<007ooOol05Woo000HOol00`00Oomoo`1ZOol>F01^Ool00`00Oomoo`0FOol0
01Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<0
07ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0F
Ool001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo
00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomo
o`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0
LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00
Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007oo
Ool0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol0
0`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<0
07ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1b
Ool00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo
00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomo
o`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`00
67oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00
Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Io
o`0067oojP0067oo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo
003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mo
oa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo
003oOolKOol00?mooa]oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {233, 0}} -> {-3.015, -2.5, 0.0214591, 
  0.0214591}}]
}, Open  ]],

Cell[TextData[{
  "Now the mechanism model is run with ",
  StyleBox["rockerfree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " set to ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This enables the second stage of the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is now run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.15 with the rocker fixed."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(rockerfree = False; \)\), 
    \(SolveMech[.15]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.15`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] \(-0.404508497187473814`\)\), ",", 
        \(Th2 \[Rule] 0.942477796076937934`\), ",", \(X3 \[Rule] \(-2.`\)\), 
        ",", \(Y3 \[Rule] \(-1.`\)\), ",", \(Th3 \[Rule] 0.`\)}], "}"}]], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the rocker mechanism with ",
  StyleBox["rockerfree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83333 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0.416667 0.166667 [
[ 0 0 0 0 ]
[ 1 .83333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .83333 L
0 .83333 L
closepath
clip
newpath
p
p
.004 w
.08333 .16667 m
.08333 .75 L
.91667 .75 L
.91667 .08333 L
.08333 .08333 L
.08333 .16667 L
.16667 .25 L
.08333 .33333 L
s
.5 .75 m
.5 .08333 L
s
.02 w
.5 .41667 Mdot
.16667 .25 Mdot
P
p
p
.7 0 0 r
.004 w
.5 .34925 m
.5 .34925 .25 0 365.73 arc
F
P
p
1 .6 .6 r
.004 w
.54898 .41667 m
.54898 .41667 .16667 0 365.73 arc
F
P
p
p
.02 w
.5 .34925 Mdot
.54898 .41667 Mdot
P
P
P
p
p
.2 .2 1 r
.16667 .25 m
.16667 .20833 L
.83333 .20833 L
.83333 .25 L
F
.004 w
.16667 .25 m
.16667 .25 .04167 0 365.73 arc
F
p
.83333 .20833 m
.79167 .16667 L
.75 .20833 L
F
P
P
p
p
.02 w
.16667 .25 Mdot
.79167 .16667 Mdot
.83333 .25 Mdot
P
P
P
p
p
p
/Courier findfont 8 scalefont setfont
[(x)] .56857 .44363 .33185 -1.25712 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .40561 .41782 .33185 -1.25712 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(2)] .5 .34925 .33185 -1.25712 Mshowa
P
.004 w
.56857 .44363 m
.5 .34925 L
.40561 .41782 L
s
.5643 .4179 m
.56857 .44363 L
.54542 .43161 L
s
.41763 .39467 m
.40561 .41782 L
.43135 .41355 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 234},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000jQ000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
67oojP0067oo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001o
ogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo
00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03
001oogoo06Yoo`iH06ioo`03001oogoo01Ioo`0067oo00<007ooOol0Hgoo75P0Igoo00<007ooOol0
5Woo000HOol00`00Oomoo`1NOolVF01ROol00`00Oomoo`0FOol001Qoo`03001oogoo05]oobaH05mo
o`03001oogoo01Ioo`0067oo00<007ooOol0Egoo=5P0Fgoo00<007ooOol05Woo000HOol00`00Oomo
o`1FOolfF01JOol00`00Oomoo`0FOol001Qoo`03001oogoo05=oocaH05Moo`03001oogoo01Ioo`00
67oo00<007ooOol0DGoo@5P0EGoo00<007ooOol05Woo000HOol00`00Oomoo`1@Oom2F01DOol00`00
Oomoo`0FOol001Qoo`03001oogoo04ioodIH059oo`03001oogoo01Ioo`0067oo00<007ooOol0Bgoo
C5P0Cgoo00<007ooOol05Woo000HOol00`00Oomoo`1:Oom?F01=Ool00`00Oomoo`0FOol001Qoo`03
001oogoo04Qooe9H04aoo`03001oogoo01Ioo`0067oo00<007ooOol0AgooE5P0Bgoo00<007ooOol0
5Woo000HOol00`00Oomoo`15OomGF01:Ool00`00Oomoo`0FOol001Qoo`03001oogoo04EooeQH04Uo
o`03001oogoo01Ioo`0067oo00<007ooOol0A7ooFUP0B7oo00<007ooOol05Woo000HOol00`00Oomo
o`13OomLF00ROol2000SOol00`00Oomoo`0FOol001Qoo`03001oogoo049ooemH01moo`@0029oo`03
001oogoo01Ioo`0067oo0P00@GooHUP07Woo10008Woo00<007ooOol05Woo000HOol00`00Ool00010
OomSF00NOol200026=lQOol00`00Oomoo`0FOol001Qoo`04001oogoo000nOomUF00LOol66=lPOol0
0`00Oomoo`0FOol001Qoo`05001oogooOol0000lOomVF00KOol86=lOOol00`00Oomoo`0FOol001Qo
o`03001oogoo009oo`03001oogoo03QoofUH01Qoo`XHgaioo`03001oogoo01Ioo`0067oo00<007oo
Ool00goo00<007ooOol0=GooK5P05Woo31SO7Goo00<007ooOol05Woo000HOol00`00Oomoo`04Ool0
0`00Oomoo`0dOom]F00DOol>6=lLOol00`00Oomoo`0FOol001Qoo`03001oogoo00Eoo`03001oogoo
039oofmH019ooa0Hga]oo`03001oogoo01Ioo`0067oo00<007ooOol01Woo00<007ooOol0<7ooL5P0
4Goo4QSO6Woo00<007ooOol05Woo000HOol00`00Oomoo`07Ool00`00Oomoo`0_OomaF00?OolD6=lI
Ool00`00Oomoo`0FOol001Qoo`03001oogoo00Qoo`03001oogoo02eoog=H00eooaHHgaQoo`03001o
ogoo01Ioo`0067oo00<007ooOol02Goo00<007ooOol0:gooM5P037oo5aSO67oo00<007ooOol05Woo
000HOol00`00Oomoo`0:Ool01000Oomoogoo`1SO67oo00<007ooOol05Woo000HOol00`00Oomoo`0;
Ool00`00OolHg`306=lHOol00`00Oomoo`0FOol001Qoo`03001oogoo00aool8HgaQoo`03001oogoo
01Ioo`0067oo00<007ooOol02goo`aSO67oo00<007ooOol05Woo000HOol00`00Oomoo`0:Ooo46=lH
Ool00`00Oomoo`0FOol001Qoo`03001oogoo00UoolDHgaQoo`03001oogoo01Ioo`0067oo00<007oo
Ool02GooaASO67oo00<007ooOol05Woo000HOol00`00Oomoo`09Ooo56=lHOol00`00Oomoo`0FOol0
01Qoo`03001oogoo00UoolDHgaQoo`03001oogoo01Ioo`0067oo00<007ooOol02GooaASO67oo00<0
07ooOol05Woo000HOol00`00Oomoo`08Ool;6=l2002h6=l2000GOol00`00Oomoo`0FOol001Qoo`03
001oogoo00Qoo`XHg`@000THga9oodYH00MnLbmH01]oo`@001Ioo`03001oogoo01Ioo`0067oo00<0
07ooOol027oo2QSO10002ASO4Woo@eP05Gic:EP06Woo10005Woo00<007ooOol05Woo000HOol00`00
Oomoo`09Ool:6=l2000:6=lAOom0F00NOW<TF00KOol2000GOol00`00Oomoo`0FOol001Qoo`03001o
ogoo00UooaHHga1oocmH029nLb=H03=oo`03001oogoo01Ioo`0067oo00<007ooOol02Woo5ASO47oo
?EP09Wic8EP0<goo00<007ooOol05Woo000HOol00`00Oomoo`0:OolD6=lAOoljF00[OW<OF00cOol0
0`00Oomoo`0FOol001Qoo`03001oogoo00]ooa8Hga9oocQH02mnLaiH039oo`03001oogoo01Ioo`00
67oo00<007ooOol02goo4QSO4Goo=eP0<gic75P0<Woo00<007ooOol05Woo000HOol00`00Oomoo`0;
Ool00`006=lHg`0>6=lBOolfF00fOW<JF00bOol00`00Oomoo`0FOol001Qoo`03001oogoo00Yoo`03
001oogoo00dHgaAoocEH03QnLaYH035oo`03001oogoo01Ioo`0067oo00<007ooOol02Goo00<007oo
Ool00goo2ASO5Goo=EP0>Wic6EP0<Goo00<007ooOol05Woo000HOol00`00Oomoo`08Ool00`00Oomo
o`06Ool56=lGOolcF00nOW<GF00aOol00`00Oomoo`0FOol001Qoo`03001oogoo00Qoo`03001oogoo
029ooc9H041nLaIH035oo`03001oogoo01Ioo`0067oo00<007ooOol01goo00<007ooOol08Woo<UP0
@Gic5eP0<7oo00<007ooOol05Woo000HOol00`00Oomoo`06Ool00`00Oomoo`0SOolaF014OW<EF00`
Ool00`00Oomoo`0FOol001Qoo`03001oogoo00Eoo`03001oogoo02Aooc1H04InLaAH031oo`03001o
ogoo01Ioo`0067oo00<007ooOol017oo00<007ooOol09Goo;eP0Agic55P0<7oo00<007ooOol05Woo
000HOol00`00Oomoo`03Ool00`00Oomoo`0VOol_F018OW<CF00`Ool00`00Oomoo`0FOol001Qoo`03
001oogoo009oo`03001oogoo02MoobiH04YnLa9H031oo`03001oogoo01Ioo`0067oo00D007ooOomo
o`0002YoobeH04anLa9H02moo`03001oogoo01Ioo`0067oo00@007ooOol002YoobeH04enLa9H02mo
o`03001oogoo01Ioo`0067oo00<007oo0000:goo;EP0CWic4EP0;goo00<007ooOol05Woo000HOol2
000/Ool/F01?OW<AF00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobaH051nLa1H02moo`03
001oogoo01Ioo`0067oo00<007ooOol0:goo:eP0DWic3eP0;goo00<007ooOol05Woo000HOol00`00
Oomoo`0[Ool[F01COW<>F00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02]oobYH01]nL`8003Mn
L`iH02moo`03001oogoo01Ioo`0067oo00<007ooOol0:goo:UP06Wic1000=gic3EP0;goo00<007oo
Ool05Woo000HOol00`00Oomoo`0[OolYF00KOW<4000gOW<=F00_Ool00`00Oomoo`0FOol001Qoo`03
001oogoo02]oobUH01YnL`03001nL`00008003MnL`eH02moo`03001oogoo01Ioo`0067oo00<007oo
Ool0:goo:5P06Wic00<007icOW<00gic00<007icOW<0=7ic3EP0;goo00<007ooOol05Woo000HOol0
0`00Oomoo`0[OolXF00HOW<20002OW<30002OW<00`00OW=nL`0dOW<<F00_Ool00`00Oomoo`0FOol0
01Qoo`03001oogoo02]oobMH01QnL`03001nLgic009nL`8000AnL`03001nLgic03=nL`aH02moo`03
001oogoo01Ioo`0067oo00<007ooOol0:goo9eP05gic00<007icOW<01Gic00D007icOW=nL`0003In
L`]H02moo`03001oogoo01Ioo`0067oo00<007ooOol0:goo9eP05Gic0P0027ic00<007icOW<00Wic
00<007icOW<0<gic2eP0;goo00<007ooOol05Woo000HOol00`00Oomoo`0/OolVF00DOW<00`00OW=n
L`06OW<30005OW<00`00OW=nL`0bOW<;F00_Ool00`00Oomoo`0FOol001Qoo`03001oogoo02aoobIH
01=nL`03001nLgic00mnL`03001nLgic039nL`YH031oo`03001oogoo01Ioo`0067oo00<007ooOol0
;7oo9EP04Wic0P004gic00<007icOW<0<Gic2UP0<7oo00<007ooOol05Woo000HOol00`00Oomoo`0/
OolUF00AOW<00`00OW=nL`0DOW<00`00OW=nL`0aOW<9F00`Ool00`00Oomoo`0FOol001Qoo`03001o
ogoo02aoobEH00mnL`8001MnL`03001nLgic035nL`UH031oo`03001oogoo01Ioo`0067oo00<007oo
Ool0;7oo9EP02Gic00<007icOW<00Wic00<007icOW<067ic00<007icOW<0<7ic2EP0<7oo00<007oo
Ool05Woo000HOol00`00Oomoo`0/OolTF009OW<00`00OW=nL`02OW<00`00OW=nL`0JOW<00`00OW=n
L`0_OW<9F00`Ool00`00Oomoo`0FOol001Qoo`03001oogoo02eoob=H00UnL`03001nLgic008001in
L`03001nLgic02inL`UH031oo`03001oogoo01Ioo`0067oo00<007ooOol0;Goo8eP027ic00@007ic
OW<0021nL`03001nLgic02inL`QH035oo`03001oogoo01Ioo`0067oo00<007ooOol0;Goo8eP027ic
00<007ic00008Wic00<007icOW<0;Gic25P0<Goo00<007ooOol05Woo000HOol00`00Oomoo`0^OolR
F007OW<300000gic00000002000NOW<2000^OW<8F00aOol00`00Oomoo`0FOol001Qoo`03001oogoo
02ioob9H00MnL`@0025nL`@000=nL`03001nLgic02MnL`MH039oo`03001oogoo01Ioo`0067oo00<0
07ooOol0;Woo8UP0;7ic10000gic00<007icOW<09gic1eP0<Woo00<007ooOol05Woo000HOol00`00
Oomoo`0^OolRF004OW<2000WOW<200001Gic001nLgic0000:Gic1eP0<Woo00<007ooOol05Woo000H
Ool00`00Oomoo`0_OolQF005OW<00`00OW=nL`0XOW<01000OW=nL`00:Gic1UP0<goo00<007ooOol0
5Woo000HOol00`00Oomoo`0_OolQF005OW<00`00OW=nL`0VOW<01P00OW=nL`00OW<002UnL`IH03=o
o`03001oogoo01Ioo`0067oo00<007ooOol0;goo8EP017ic00<007ic0000:7ic0P0000AnL`00OW<0
02QnL`IH03=oo`03001oogoo01Ioo`0067oo00<007ooOol0<7oo8EP00gic00@007ic000002UnL`04
001nL`00000XOW<6F00cOol00`00Oomoo`0FOol001Qoo`03001oogoo031oob5H035nL`<002QnL`EH
03Aoo`03001oogoo01Ioo`0067oo00<007ooOol0<Goo85P0<gic00<007icOW<09Wic15P0=Goo00<0
07ooOol05Woo000HOol00`00Oomoo`0aOolPF01KOW<5F00eOol00`00Oomoo`0FOol001Qoo`03001o
ogoo035oob5H05YnL`EH03Eoo`03001oogoo01Ioo`0067oo00<007ooOol0<Woo85P0FWic15P0=Woo
00<007ooOol05Woo000HOol00`00Oomoo`0cOolOF00_OW<200000gic001nL`0VOW<4F00fOol00`00
Oomoo`0FOol001Qoo`03001oogoo03=ooamH035nL`03001nLgic02InL`=H03Moo`03001oogoo01Io
o`0067oo00<007ooOol0=7oo7UP0<7ic00<007ic00009Wic15P0=goo00<007ooOol05Woo000HOol0
0`00Oomoo`0dOolOF01HOW<3F00hOol00`00Oomoo`0FOol001Qoo`03001oogoo03AooamH05MnL`AH
03Qoo`03001oogoo01Ioo`0067oo00<007ooOol0=Goo7eP0EWic15P0>7oo00<007ooOol05Woo000H
Ool00`00Oomoo`0eOolOF01FOW<3F00iOol00`00Oomoo`0FOol001Qoo`03001oogoo03IooamH05En
L`=H03Uoo`03001oogoo01Ioo`0067oo00<007ooOol0=goo7UP0E7ic0eP0>Woo00<007ooOol05Woo
000HOol00`00Oomoo`0gOolOF01COW<2F00kOol00`00Oomoo`0FOol001Qoo`03001oogoo03QooaiH
059nL`9H03aoo`03001oogoo01Ioo`0067oo00<007ooOol0>Goo7UP0D7ic0UP0?Goo00<007ooOol0
5Woo000HOol00`00Oomoo`0jOolMF01?OW<3F00mOol00`00Oomoo`0FOol001Qoo`03001oogoo03]o
oaeH04inL`9H03ioo`03001oogoo01Ioo`0067oo00<007ooOol0>goo7EP0CGic0UP0?goo00<007oo
Ool05Woo000HOol00`00Oomoo`0lOolMF01<OW<00eP0Oomoo`0nOol00`00Oomoo`0FOol001Qoo`03
001oogoo03eooaeH04YnL`03F01oogoo03moo`03001oogoo01Ioo`0067oo00<007ooOol0?Woo7EP0
B7ic00=H07ooOol0@7oo00<007ooOol05Woo000HOol00`00Oomoo`0oOolLF017OW<00eP0Oomoo`11
Ool00`00Oomoo`0FOol001Qoo`03001oogoo041ooaaH04InLdAoo`03001oogoo01Ioo`0067oo00<0
07ooOol0@Goo75P0A7icAGoo00<007ooOol05Woo000HOol00`00Oomoo`12OolLF011OW<00eP0Oomo
o`14Ool00`00Oomoo`0FOol001Qoo`03001oogoo04=ooaaH041nLdMoo`03001oogoo01Ioo`0067oo
00<007ooOol0A7oo75P0?WicB7oo00<007ooOol05Woo000HOol00`00Oomoo`15OolMF00jOW<00eP0
Oomoo`17Ool00`00Oomoo`0FOol001Qoo`03001oogoo04MooaaH03QnL`03F01oogoo04Qoo`03001o
ogoo01Ioo`0067oo00<007ooOol0B7oo6eP0=gicC7oo00<007ooOol05Woo000HOol00`00Oomoo`1:
OolKF00cOW<00eP0Oomoo`1;Ool00`00Oomoo`0FOol001Qoo`03001oogoo04]ooaaH02mnL`03F01o
ogoo04eoo`03001oogoo01Ioo`0067oo00<007ooOol0CGoo75P0:gic0UP0D7oo00<007ooOol05Woo
000HOol00`00Oomoo`1>OolNF00VOW<2F01BOol00`00Oomoo`0FOol001Qoo`03001oogoo051ooaiH
029nL`9H05Aoo`03001oogoo01Ioo`0067oo00<007ooOol0Dgoo7EP07Wic00=H07ooOol0EGoo00<0
07ooOol05Woo000HOol00`00Oomoo`1DOolNF00IOW<3F01HOol00`00Oomoo`0FOol001Qoo`03001o
ogoo05Ioob5H011nL`EH05Yoo`03001oogoo01Ioo`0067oo00<007ooOol0FGoo9EP00Wic2EP0GGoo
00<007ooOol05Woo000HOol00`00Oomoo`1LOolZF01POol00`00Oomoo`0FOol001Qoo`03001oogoo
061oob9H06Aoo`03001oogoo01Ioo`0067oo00<007ooOol0Hgoo75P0Igoo00<007ooOol05Woo000H
Ool00`00Oomoo`1XOolBF01/Ool00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079o
o`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol0
0`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo
079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000H
Ool00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001o
ogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo
000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075oo`03
001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007ooOol0
5Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo075o
o`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<007oo
Ool05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001oogoo
075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo00<0
07ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03001o
ogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0LWoo
00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qoo`03
001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007ooOol0
LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol001Qo
o`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<007oo
Ool0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0FOol0
01Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo00<0
07ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomoo`0F
Ool001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0LGoo
00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00Oomo
o`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007ooOol0
LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol00`00
Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<007oo
Ool0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOol00`00Oomoo`1aOol00`00Oomoo`1bOol0
0`00Oomoo`0FOol001Qoo`03001oogoo075oo`03001oogoo079oo`03001oogoo01Ioo`0067oo00<0
07ooOol0LGoo00<007ooOol0LWoo00<007ooOol05Woo000HOooZ000HOol00?mooa]oo`00ogoo6goo
003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mo
oa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo
003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {233, 0}} -> {-3.015, -2.5, 0.0214591, 
  0.0214591}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Slider-Ramp Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another usage of the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is to switch from one stage of operation to another when such \
switching is the normal progression of operation of the mechanism. To \
demonstrate this usage a 2D model of a slider on a ramp is developed. The \
model has only one moving body, the slider. \n\nThis mechanism has two \
distinct modes of operation. First, the slider travels across a horizontal \
surface until it encounters an inclined ramp. As the slider progresses \
further, its front edge leaves the horizontal plane and begins to slide up \
the inclined ramp. The ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to switch between these modes by defining the test expressions in \
the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to test explicitly whether or not the corner of the slider has traveled \
beyond the bottom of the ramp."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the 2D slider-ramp model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
 
 
  
%%Creator: Mathematica
 
 
 
  
%%AspectRatio: .4 
 
 
 
  
MathPictureStart
 
 
 
  
%% Graphics
 
 
 
  
/Courier findfont 10  scalefont  setfont
 
 
 
  
% Scaling calculations
 
 
 
  
0.0666667 0.133333 0.0666667 0.133333 [
 
 
 
  
[(0)] .06667 0 0 2 Msboxa
 
 
 
  
[(1)] .2 0 0 2 Msboxa
 
 
 
  
[(2)] .33333 0 0 2 Msboxa
 
 
 
  
[(3)] .46667 0 0 2 Msboxa
 
 
 
  
[(4)] .6 0 0 2 Msboxa
 
 
 
  
[(5)] .73333 0 0 2 Msboxa
 
 
 
  
[(6)] .86667 0 0 2 Msboxa
 
 
 
  
[(7)] 1 0 0 2 Msboxa
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Msboxa
 
 
 
  
[(0)] -0.0125 .06667 1 0 Msboxa
 
 
 
  
[(0.5)] -0.0125 .13333 1 0 Msboxa
 
 
 
  
[(1)] -0.0125 .2 1 0 Msboxa
 
 
 
  
[(1.5)] -0.0125 .26667 1 0 Msboxa
 
 
 
  
[(2)] -0.0125 .33333 1 0 Msboxa
 
 
 
  
[(2.5)] -0.0125 .4 1 0 Msboxa
 
 
 
  
[ -0.001 -0.001 0 0 ]
 
 
 
  
[ 1.001 .401 0 0 ]
 
 
 
  
] MathScale
 
 
 
  
% Start of Graphics
 
 
 
  
1 setlinecap
 
 
 
  
1 setlinejoin
 
 
 
  
newpath
 
 
 
  
[ ] 0 setdash
 
 
 
  
0 g
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.06667 0 m
 
 
 
  
.06667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0)] .06667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.2 0 m
 
 
 
  
.2 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1)] .2 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.33333 0 m
 
 
 
  
.33333 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2)] .33333 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.46667 0 m
 
 
 
  
.46667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(3)] .46667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.6 0 m
 
 
 
  
.6 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(4)] .6 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.73333 0 m
 
 
 
  
.73333 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(5)] .73333 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.86667 0 m
 
 
 
  
.86667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(6)] .86667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 0 m
 
 
 
  
1 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(7)] 1 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.09333 0 m
 
 
 
  
.09333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.12 0 m
 
 
 
  
.12 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.14667 0 m
 
 
 
  
.14667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.17333 0 m
 
 
 
  
.17333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.22667 0 m
 
 
 
  
.22667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.25333 0 m
 
 
 
  
.25333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.28 0 m
 
 
 
  
.28 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.30667 0 m
 
 
 
  
.30667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.36 0 m
 
 
 
  
.36 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.38667 0 m
 
 
 
  
.38667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.41333 0 m
 
 
 
  
.41333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.44 0 m
 
 
 
  
.44 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.49333 0 m
 
 
 
  
.49333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.52 0 m
 
 
 
  
.52 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.54667 0 m
 
 
 
  
.54667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.57333 0 m
 
 
 
  
.57333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.62667 0 m
 
 
 
  
.62667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.65333 0 m
 
 
 
  
.65333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.68 0 m
 
 
 
  
.68 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.70667 0 m
 
 
 
  
.70667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.76 0 m
 
 
 
  
.76 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.78667 0 m
 
 
 
  
.78667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.81333 0 m
 
 
 
  
.81333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.84 0 m
 
 
 
  
.84 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.89333 0 m
 
 
 
  
.89333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.92 0 m
 
 
 
  
.92 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.94667 0 m
 
 
 
  
.94667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.97333 0 m
 
 
 
  
.97333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.04 0 m
 
 
 
  
.04 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.01333 0 m
 
 
 
  
.01333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
1 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
.00625 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .06667 m
 
 
 
  
.00625 .06667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0)] -0.0125 .06667 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .13333 m
 
 
 
  
.00625 .13333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0.5)] -0.0125 .13333 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .2 m
 
 
 
  
.00625 .2 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1)] -0.0125 .2 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .26667 m
 
 
 
  
.00625 .26667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1.5)] -0.0125 .26667 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .33333 m
 
 
 
  
.00625 .33333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2)] -0.0125 .33333 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .4 m
 
 
 
  
.00625 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2.5)] -0.0125 .4 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .01333 m
 
 
 
  
.00375 .01333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .02667 m
 
 
 
  
.00375 .02667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .04 m
 
 
 
  
.00375 .04 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .05333 m
 
 
 
  
.00375 .05333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .08 m
 
 
 
  
.00375 .08 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .09333 m
 
 
 
  
.00375 .09333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .10667 m
 
 
 
  
.00375 .10667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .12 m
 
 
 
  
.00375 .12 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .14667 m
 
 
 
  
.00375 .14667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .16 m
 
 
 
  
.00375 .16 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .17333 m
 
 
 
  
.00375 .17333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .18667 m
 
 
 
  
.00375 .18667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .21333 m
 
 
 
  
.00375 .21333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .22667 m
 
 
 
  
.00375 .22667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .24 m
 
 
 
  
.00375 .24 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .25333 m
 
 
 
  
.00375 .25333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .28 m
 
 
 
  
.00375 .28 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .29333 m
 
 
 
  
.00375 .29333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .30667 m
 
 
 
  
.00375 .30667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .32 m
 
 
 
  
.00375 .32 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .34667 m
 
 
 
  
.00375 .34667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .36 m
 
 
 
  
.00375 .36 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .37333 m
 
 
 
  
.00375 .37333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .38667 m
 
 
 
  
.00375 .38667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
0 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.06667 .39375 m
 
 
 
  
.06667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.2 .39375 m
 
 
 
  
.2 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.33333 .39375 m
 
 
 
  
.33333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.46667 .39375 m
 
 
 
  
.46667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.6 .39375 m
 
 
 
  
.6 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.73333 .39375 m
 
 
 
  
.73333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.86667 .39375 m
 
 
 
  
.86667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 .39375 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.09333 .39625 m
 
 
 
  
.09333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.12 .39625 m
 
 
 
  
.12 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.14667 .39625 m
 
 
 
  
.14667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.17333 .39625 m
 
 
 
  
.17333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.22667 .39625 m
 
 
 
  
.22667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.25333 .39625 m
 
 
 
  
.25333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.28 .39625 m
 
 
 
  
.28 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.30667 .39625 m
 
 
 
  
.30667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.36 .39625 m
 
 
 
  
.36 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.38667 .39625 m
 
 
 
  
.38667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.41333 .39625 m
 
 
 
  
.41333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.44 .39625 m
 
 
 
  
.44 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.49333 .39625 m
 
 
 
  
.49333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.52 .39625 m
 
 
 
  
.52 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.54667 .39625 m
 
 
 
  
.54667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.57333 .39625 m
 
 
 
  
.57333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.62667 .39625 m
 
 
 
  
.62667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.65333 .39625 m
 
 
 
  
.65333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.68 .39625 m
 
 
 
  
.68 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.70667 .39625 m
 
 
 
  
.70667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.76 .39625 m
 
 
 
  
.76 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.78667 .39625 m
 
 
 
  
.78667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.81333 .39625 m
 
 
 
  
.81333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.84 .39625 m
 
 
 
  
.84 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.89333 .39625 m
 
 
 
  
.89333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.92 .39625 m
 
 
 
  
.92 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.94667 .39625 m
 
 
 
  
.94667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.97333 .39625 m
 
 
 
  
.97333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.04 .39625 m
 
 
 
  
.04 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.01333 .39625 m
 
 
 
  
.01333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .4 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 0 m
 
 
 
  
1 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .06667 m
 
 
 
  
1 .06667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .13333 m
 
 
 
  
1 .13333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .2 m
 
 
 
  
1 .2 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .26667 m
 
 
 
  
1 .26667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .33333 m
 
 
 
  
1 .33333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .4 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .01333 m
 
 
 
  
1 .01333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .02667 m
 
 
 
  
1 .02667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .04 m
 
 
 
  
1 .04 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .05333 m
 
 
 
  
1 .05333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .08 m
 
 
 
  
1 .08 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .09333 m
 
 
 
  
1 .09333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .10667 m
 
 
 
  
1 .10667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .12 m
 
 
 
  
1 .12 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .14667 m
 
 
 
  
1 .14667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .16 m
 
 
 
  
1 .16 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .17333 m
 
 
 
  
1 .17333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .18667 m
 
 
 
  
1 .18667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .21333 m
 
 
 
  
1 .21333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .22667 m
 
 
 
  
1 .22667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .24 m
 
 
 
  
1 .24 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .25333 m
 
 
 
  
1 .25333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .28 m
 
 
 
  
1 .28 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .29333 m
 
 
 
  
1 .29333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .30667 m
 
 
 
  
1 .30667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .32 m
 
 
 
  
1 .32 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .34667 m
 
 
 
  
1 .34667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .36 m
 
 
 
  
1 .36 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .37333 m
 
 
 
  
1 .37333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .38667 m
 
 
 
  
1 .38667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 0 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
P
 
 
 
  
p
 
 
 
  
P
 
 
 
  
0 0 m
 
 
 
  
1 0 L
 
 
 
  
1 .4 L
 
 
 
  
0 .4 L
 
 
 
  
closepath
 
 
 
  
clip
 
 
 
  
newpath
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.004 w
 
 
 
  
.06667 .06667 m
 
 
 
  
.6 .06667 L
 
 
 
  
.86667 .33333 L
 
 
 
  
s
 
 
 
  
.02 w
 
 
 
  
.06667 .06667 Mdot
 
 
 
  
.6 .06667 Mdot
 
 
 
  
.86667 .33333 Mdot
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.5 0 0 r
 
 
 
  
.38503 .13163 m
 
 
 
  
.4 .06667 L
 
 
 
  
.65986 .12653 L
 
 
 
  
.6449 .19149 L
 
 
 
  
F
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.02 w
 
 
 
  
.4 .06667 Mdot
 
 
 
  
.65986 .12653 Mdot
 
 
 
  
P
 
 
 
  
P
 
 
 
  
P
 
 
 
  
P
 
 
 
  
% End of Graphics
 
 
 
  
MathPictureEnd
 
 
 
  

 
 
 
  
 
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 112},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000L1000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo000gOol00`00Oomoo`0HOol5000IOol3000JOol2000LOol3000JOol0
0`00Oomoo`0IOol2000LOol00`00Oomoo`0EOol003Ioo`03001oo`0001]oo`03001oogoo01Uoo`03
001oogoo01aoo`03001oogoo01Yoo`03001oogoo01Qoo`03001oo`0001Yoo`03001oo`0001]oo`03
001oogoo01Eoo`00=Woo00<007oo00006goo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol0
6Goo10006goo00<007ooOol067oo00<007oo00006goo00<007ooOol05Goo000fOol00`00Ool0000K
Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Ool0000JOol2000KOol2000M
Ool00`00Oomoo`0DOol003Ioo`03001oo`0001]oo`03001oogoo01Uoo`03001oo`0001Yoo`03001o
o`0001]oo`8001Yoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oo`0001Ioo`00=goo00<007oo
Ool06Goo0P0077oo00<007ooOol06Woo00<007ooOol06goo00<007ooOol067oo0`006goo0P006Woo
0`005Woo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000JOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3cOol001Uoo`03001oo`0000Moo`03001oo`00
0?Aoo`0057oo0`000Woo00<007oo00002Goo00@007ooOomoom/001Ioo`006Goo00<007oo00001goo
0P0017oo00@007ooOol000Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01Aoo`006Goo00<007oo00001goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo
00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol057oo
000JOol00`00Oomoo`06Ool30003Ool2003GOol2000FOol002Uoo`03001oogoo0=Moo`03001oogoo
01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2000FOol002Uoo`03001o
ogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2
000FOol002Uoo`03001oogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol0
57oo000YOol2003GOol2000FOol002Aoo`03001oogoo009oo`03001oogoo0=Moo`03001oogoo01Ao
o`008goo00<007oo00000goo00<007ooOol0egoo00<007ooOol057oo000SOol00`00Ool00003Ool3
000;Oomf001EOol2000FOol002=oo`03001oo`0000=oo`03001oogoo00Yoo`<004Ioo`<000<l02Eo
o`@005Eoo`03001oogoo01Aoo`008goo00<007oo00000goo00<007ooOol02goo00<007ooOol0AWoo
00<003`0?0001S`08Woo00@007ooOol005Aoo`03001oogoo01Aoo`0097oo00<007ooOol00Woo0P00
EGoo3S`08Goo00<007ooOol0D7oo0P005Woo000YOol00`00Oomoo`1DOolB?00NOol00`00Oomoo`1@
Ool00`00Oomoo`0DOol002Uoo`03001oogoo05=ooaLl01]oo`03001oogoo04moo`03001oogoo01Ao
o`00:Goo0P00E7oo73`05goo00<007ooOol0CGoo0P005Woo000YOol00`00Oomoo`1COolP?00DOol0
0`00Oomoo`1=Ool00`00Oomoo`0DOol002Uoo`03001oogoo05=oobDl011oo`03001oogoo04aoo`03
001oogoo01Aoo`00:Goo0P00E7oo:C`03Goo00<007ooOol0BWoo0P005Woo000YOol00`00Oomoo`1B
Ool^?00:Ool00`00Oomoo`1:Ool00`00Oomoo`0DOol002Uoo`03001oogoo059ooc<l00Ioo`03001o
ogoo04Uoo`03001oogoo01Aoo`006Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
0P00Dgoo=c`00goo00<007ooOol0Agoo0P005Woo000IOol00`00Ool00007Ool00`00Ool00003Ool0
0`00Oomoo`1BOolj?0020019Ool00`00Oomoo`0DOol001Uoo`03001oo`0000Uoo`04001oogooOol3
001AOolj?0040017Ool2000FOol001Uoo`03001oo`0000Moo`8000Aoo`03001oogoo05IoocHl0004
001oogoo0017Ool00`00Oomoo`0DOol001Uoo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo
05Yooc<l00=oo`03001oogoo04Aoo`03001oogoo01Aoo`006Woo00<007ooOol01Woo0`000goo0P00
H7oo;S`017oo00<007ooOol0@Woo0P005Woo000YOol00`00Oomoo`1SOolY?006Ool00`00Oomoo`12
Ool00`00Oomoo`0DOol002Uoo`03001oogoo06MoobDl00Moo`03001oogoo045oo`03001oogoo01Ao
o`00:Goo0P00KGoo83`027oo00<007ooOol0?goo0P005Woo000YOol00`00Oomoo`1`OolL?009Ool0
0`00Oomoo`0oOol00`00Oomoo`0DOol002Uoo`03001oogoo07EooaLl00Yoo`03001oogoo03ioo`03
001oogoo01Aoo`00:Goo0P00NWoo4S`037oo00<007ooOol0?7oo0P005Woo000YOol00`00Oomoo`1m
Ool>?00=Ool00`00Oomoo`0lOol00`00Oomoo`0DOol002Uoo`03001oogoo089oo`Tl00ioo`03001o
ogoo03]oo`03001oogoo01Aoo`00:Goo0P00Qgoo1C`03goo00<007ooOol0>Goo0P005Woo000ROol5
0002Ool00`00Oomoo`2KOol00`00Oomoo`0iOol00`00Oomoo`0DOol002Aoo`03001oogoo009oo`03
001oogoo09aoo`03001oogoo03Qoo`03001oogoo01Aoo`0097oo00<007ooOol00Woo0`00WGoo00<0
07ooOol0=Woo0P005Woo000TOol00`00Oomoo`02Ool00`00Oomoo`2NOol00`00Oomoo`0fOol00`00
Oomoo`0DOol002Aoo`03001oogoo009oo`03001oogoo09moo`03001oogoo03Eoo`03001oogoo01Ao
o`008goo0P0017oo0P00XGoo00<007ooOol0<goo0P005Woo000YOol00`00Oomoo`2QOol00`00Oomo
o`0cOol00`00Oomoo`0DOol002Uoo`03001oogoo0:9oo`03001oogoo039oo`03001oogoo01Aoo`00
:Goo0P00Y7oo00<007ooOol0<7oo0P005Woo000YOol00`00Oomoo`2TOol00`00Oomoo`0`Ool00`00
Oomoo`0DOol002Uoo`03001oogoo0:Eoo`03001oogoo02moo`03001oogoo01Aoo`00:Goo0P00Ygoo
00<007ooOol0;Goo0P005Woo000YOol00`00Oomoo`2WOol00`00Oomoo`0]Ool00`00Oomoo`0DOol0
02Uoo`03001oogoo0:Qoo`03001oogoo02aoo`03001oogoo01Aoo`0067oo1@000Woo00<007ooOol0
0Woo00<007ooOol00Woo0P00ZWoo00<007ooOol0:Woo0P005Woo000JOol00`00Oomoo`06Ool00`00
Ool00003Ool00`00Oomoo`2ZOol00`00Oomoo`0ZOol00`00Oomoo`0DOol001Yoo`03001oogoo00Qo
o`04001oogooOol3002[Ool00`00Oomoo`0XOol2000FOol001Yoo`03001oogoo00Ioo`8000Aoo`03
001oogoo0:aoo`03001oogoo02Qoo`03001oogoo01Aoo`006Woo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol0[Goo00<007ooOol09goo00<007ooOol057oo000IOol20008Ool30003Ool2002_
Ool00`00Oomoo`0UOol2000FOol002Uoo`03001oogoo0:moo`03001oogoo02Eoo`03001oogoo01Ao
o`00:Goo00<007ooOol0/7oo00<007ooOol097oo00<007ooOol057oo000YOol2002bOol00`00Oomo
o`0ROol2000FOol002Uoo`03001oogoo0;9oo`03001oogoo029oo`03001oogoo01Aoo`00:Goo00<0
07ooOol0/goo00<007ooOol08Goo00<007ooOol057oo000YOol2002eOol00`00Oomoo`0OOol2000F
Ool002Uoo`03001oogoo0;Eoo`03001oogoo01moo`03001oogoo01Aoo`00:Goo00<007ooOol0]Woo
00<007ooOol07Woo00<007ooOol057oo000YOol2002hOol00`00Oomoo`0LOol2000FOol002=oo`<0
00=oo`03001oogoo0;Qoo`03001oogoo01aoo`03001oogoo01Aoo`008goo00<007ooOol00goo00<0
07ooOol0^Goo00<007ooOol06goo00<007ooOol057oo000TOol00`00Oomoo`02Ool3002iOol2000K
Ool2000FOol002Aoo`03001oogoo009oo`03001oogoo0;Qoo`<001aoo`03001oogoo01Aoo`008goo
00<007oo00000goo00<007ooOol0^Goo00<007ooOol06goo00<007ooOol057oo000TOol00`00Oomo
o`02Ool2003GOol2000FOol002Uoo`03001oogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0
egoo00<007ooOol057oo000YOol2003GOol2000FOol002Uoo`03001oogoo0=Moo`03001oogoo01Ao
o`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2000FOol002Uoo`03001oogoo
0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000IOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool2003GOol2000FOol001Uoo`03001oogoo00Moo`03001oo`0000=o
o`03001oogoo00aoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Yo
o`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Aoo`006Woo00<007oo
Ool027oo00@007ooOomoom/001Ioo`006Woo00<007ooOol01Woo0P00mGoo000IOol00`00Ool00007
Ool00`00Oomoo`3dOol001Yoo`03001oogoo00Ioo`<00?Aoo`00ogoo6goo003oOolKOol00?mooa]o
o`00\
\>"],
  ImageRangeCache->{{{0, 281}, {111, 0}} -> {-1.94348, -1.12071, 0.0344832, 
  0.0344832}}]
}, Open  ]],

Cell[TextData["Bodies "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two bodies are needed in the slider-ramp mechanism model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground (body 1) requires three points.\nP1 is the beginning of the \
horizontal ramp at {0, 0}.\nP2 is the end of the horizontal ramp and the \
beginning of the inclined ramp at {4,0}.\nP3 is the end of the inclined ramp \
at {6, 2}."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider (body 2) requires two points.\nP1 is the left bottom corner of \
the slider at local coordinates {0, 0}.\nP2 is the right bottom corner of the \
slider at local coordinates {2, 0}."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here are both the bodies in the slider-ramp model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0190476 0.952381 [
[ -0.001 -0.001 0 0 ]
[ 1.001 .801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 .8 L
s
P
P
p
p
.002 w
0 .8 m
1 .8 L
s
P
p
.002 w
1 0 m
1 .8 L
s
P
P
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0190476 0.97619 0.4 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.133333 0.0666667 0.133333 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
p
p
p
.5 0 0 r
.2 .13333 m
.2 .06667 L
.46667 .06667 L
.46667 .13333 L
F
P
p
p
.02 w
.2 .06667 Mdot
.46667 .06667 Mdot
P
P
P
p
[({0,0})] .2 .06667 0 1.8 Mshowa
[(P1)] .2 .06667 1.7 -1.8 Mshowa
[({2,0})] .46667 .06667 0 1.8 Mshowa
[(P2)] .46667 .06667 -1.7 -1.8 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.4 0.97619 0.780952 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0666667 0.133333 0.0666667 0.133333 [
[ 0 0 0 0 ]
[ 1 .4 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .4 L
0 .4 L
closepath
clip
newpath
p
p
.004 w
.06667 .06667 m
.6 .06667 L
.86667 .33333 L
s
.02 w
.06667 .06667 Mdot
.6 .06667 Mdot
.86667 .33333 Mdot
P
p
[({0,0})] .06667 .06667 0 1.8 Mshowa
[(P1)] .06667 .06667 0 -2.2 Mshowa
[({4,0})] .6 .06667 0 1.8 Mshowa
[(P2)] .6 .06667 1.7 -2.2 Mshowa
[({6,2})] .86667 .33333 -1.4 1.6 Mshowa
[(P3)] .86667 .33333 -2.4 -1.6 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{340, 271},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005D00013a000`40O003h00OogooEGoo00000goo
0000003o001@0002Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@00
0Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`00
00=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo
0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool1
0001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo
00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00
Ool0?7oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0@Goo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol0Ygoo0@000Goo0Goo00000goo001oo`0kOol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0oOol01000Oomoogoo0`000goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol0YWoo0@000Goo0Goo00000goo001oo`0kOol01`00
Oomoogoo001oo`0000Aoo`06001oogoo001oo`000goo00<007ooOol0?goo00D007ooOomoo`0000Io
o`06001oogoo001oo`000goo00<007ooOol0YWoo0@000Goo0Goo00000goo001oo`0jOol20003Ool0
0`00Ool00007Ool00`00Ool00003Ool2000oOol20004Ool00`00Oomoo`06Ool00`00Ool00003Ool2
002WOol10001Ool1Ool00003Ool007oo03]oo`07001oogooOol007oo00001goo00<007oo00000goo
00<007ooOol0?goo00<007ooOol00Woo00<007ooOol01Woo00<007oo00000goo00<007ooOol0YWoo
0@000Goo0Goo00000goo001oo`0kOol01`00Oomoogoo001oo`0000Moo`03001oo`0000=oo`03001o
ogoo03moo`07001oogooOol007oo00001goo00<007oo00000goo00<007ooOol0YWoo0@000Goo0Goo
00000goo001oo`0lOol01@00Oomoogoo00002Goo00D007ooOomoo`0004=oo`05001oogooOol00009
Ool01@00Oomoogoo0000ZGoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool0
07oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?
Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0AGoo00<007ooOol0
Dgoo00<007ooOol0/7oo0@000Goo0Goo00000goo001oo`14Ool3001COol3002aOol10001Ool1Ool0
0003Ool007oo04=oo`D0055oo`D00;1oo`40005oo`5oo`0000=oo`00Ool0A7oo0`00Dc`00`00/Goo
0@000Goo0Goo00000goo001oo`15Ool00`00?00l001C?0000`00Oomoo`2`Ool10001Ool1Ool00003
Ool007oo04IooeDl0;=oo`40005oo`5oo`0000=oo`00Ool0AWooEC`0/goo0@000Goo0Goo00000goo
001oo`16OomE?02cOol10001Ool1Ool00003Ool007oo04IooeDl0;=oo`40005oo`5oo`0000=oo`00
Ool0AWooEC`0/goo0@000Goo0Goo00000goo001oo`0hOol30002Ool50004OomE?004Ool30003Ool3
002VOol10001Ool1Ool00003Ool007oo03Uoo`03001oogoo00=oo`03001oogoo00AooeDl00Eoo`03
001oogoo009oo`03001oogoo0:Ioo`40005oo`5oo`0000=oo`00Ool0>Goo0`000goo00<007ooOol0
17ooEC`01Goo0`000goo00<007ooOol0YGoo0@000Goo0Goo00000goo001oo`0iOol01000Oomoo`00
0Woo00<007ooOol017ooEC`01Goo00@007ooOol0009oo`03001oogoo0:Eoo`40005oo`5oo`0000=o
o`00Ool0>Goo00@007ooOol0009oo`03001oogoo00AooeDl00Eoo`08001oogoo001oo`00Ool00:Io
o`40005oo`5oo`0000=oo`00Ool0>7oo10000Woo0P001WooEC`017oo10000goo00<007ooOol0YGoo
0@000Goo0Goo00000goo001oo`16OomE?02cOol10001Ool1Ool00003Ool007oo04IooeDl0;=oo`40
005oo`5oo`0000=oo`00Ool0AWooEC`0/goo0@000Goo0Goo00000goo001oo`16OomE?02cOol10001
Ool1Ool00003Ool007oo04IooeDl0;=oo`40005oo`5oo`0000=oo`00Ool0AWooEC`0/goo0@000Goo
0Goo00000goo001oo`16OomE?02cOol10001Ool1Ool00003Ool007oo04IooeDl0;=oo`40005oo`5o
o`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool0
07oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?
Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo
0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=o
o`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?mo
odmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001
Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo0000
0goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0
ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40
005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool0
0003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001o
o`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo
0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5o
o`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool0
07oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?
Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo
0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=o
o`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?mo
odmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001
Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo0000
0goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0
ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40
005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool0
0003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001o
o`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo
0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5o
o`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool0
07oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?
Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo
0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=o
o`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?mo
odmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001
Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo0000
0goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0
ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40
005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool0
0003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001o
o`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo
0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5o
o`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool0
07oo019oo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo09Ioo`03001oogoo00Ioo`03001o
ogoo00Ioo`03001oogoo07aoo`40005oo`5oo`0000=oo`00Ool04Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0U7oo00<007ooOol00Woo0`000Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0Ngoo0@000Goo0Goo00000goo001oo`0AOol0
1`00Oomoogoo001oo`0000Aoo`06001oogoo001oo`000goo00<007ooOol0U7oo00<007ooOol00goo
00<007ooOol00Woo00H007ooOol007oo0003Ool00`00Oomoo`1kOol10001Ool1Ool00003Ool007oo
011oo`8000=oo`03001oo`0000Moo`03001oo`0000=oo`8009Aoo`8000=oo`@000Ioo`03001oo`00
00=oo`8007aoo`40005oo`5oo`0000=oo`00Ool04Goo00L007ooOomoo`00Ool00007Ool00`00Ool0
0003Ool00`00Oomoo`2DOol01`00Oomoogoo001oo`0000Moo`03001oo`0000=oo`03001oogoo07]o
o`40005oo`5oo`0000=oo`00Ool04Goo00L007ooOomoo`00Ool00007Ool00`00Ool00003Ool00`00
Oomoo`2DOol00`00Oomoo`02Ool20007Ool00`00Ool00003Ool00`00Oomoo`1kOol10001Ool1Ool0
0003Ool007oo019oo`05001oogooOol00009Ool01@00Oomoogoo0000V7oo00<007ooOol00Woo00<0
07ooOol01Woo00D007ooOomoo`0007ioo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo
00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00
Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmo
o`40005oo`5oo`0000=oo`00Ool06Woo00<007ooOol0Z7oo00<007ooOol0QWoo0@000Goo0Goo0000
0goo001oo`0IOon^0027Ool10001Ool1Ool00003Ool007oo01Qoo`D00:Ioo`D008Ioo`40005oo`5o
o`0000=oo`00Ool06Goo0`00Z7oo0`0000=oo`00Ool0Q7oo0@000Goo0Goo00000goo001oo`0JOol0
0`00Oomoo`2XOol01@00Oomoogoo0000Q7oo0@000Goo0Goo00000goo001oo`3:Ool00`00Oomoo`21
Ool10001Ool1Ool00003Ool007oo0<]oo`03001oogoo081oo`40005oo`5oo`0000=oo`00Ool0c7oo
00<007ooOol0Ogoo0@000Goo0Goo00000goo001oo`3=Ool00`00Oomoo`1nOol10001Ool1Ool00003
Ool007oo0<ioo`03001oogoo07eoo`40005oo`5oo`0000=oo`00Ool0cgoo00<007ooOol0O7oo0@00
0Goo0Goo00000goo001oo`3@Ool00`00Oomoo`1kOol10001Ool1Ool00003Ool007oo01Ioo`<0009o
o`D009Uoo`<000=oo`<000moo`03001oogoo07Yoo`40005oo`5oo`0000=oo`00Ool05goo00<007oo
Ool00goo00<007ooOol0VWoo00<007ooOol00Woo00<007ooOol047oo00<007ooOol0NGoo0@000Goo
0Goo00000goo001oo`0GOol30003Ool00`00Oomoo`2JOol30003Ool00`00Oomoo`0@Ool00`00Oomo
o`1hOol10001Ool1Ool00003Ool007oo01Moo`04001oogoo0002Ool00`00Oomoo`2JOol01000Oomo
o`000Woo00<007ooOol04Goo00<007ooOol0Mgoo0@000Goo0Goo00000goo001oo`0GOol01000Oomo
o`000Woo00<007ooOol0VWoo00P007ooOol007oo001oo`004goo00<007ooOol0MWoo0@000Goo0Goo
00000goo001oo`0FOol40002Ool2002KOol40003Ool00`00Oomoo`0COol00`00Oomoo`1eOol10001
Ool1Ool00003Ool007oo0=Moo`03001oogoo07Aoo`40005oo`5oo`0000=oo`00Ool0f7oo00<007oo
Ool0Lgoo0@000Goo0Goo00000goo001oo`3IOol00`00Oomoo`1bOol10001Ool1Ool00003Ool007oo
0=Yoo`03001oogoo075oo`40005oo`5oo`0000=oo`00Ool0fgoo00<007ooOol0L7oo0@000Goo0Goo
00000goo001oo`3LOol00`00Oomoo`1_Ool10001Ool1Ool00003Ool007oo0=eoo`03001oogoo06io
o`40005oo`5oo`0000=oo`00Ool0gWoo00<007ooOol0KGoo0@000Goo0Goo00000goo001oo`3OOol0
0`00Oomoo`1/Ool10001Ool1Ool00003Ool007oo0>1oo`03001oogoo06]oo`40005oo`5oo`0000=o
o`00Ool0hGoo00<007ooOol0JWoo0@000Goo0Goo00000goo001oo`3ROol00`00Oomoo`1YOol10001
Ool1Ool00003Ool007oo0>=oo`03001oogoo06Qoo`40005oo`5oo`0000=oo`00Ool0i7oo00<007oo
Ool0Igoo0@000Goo0Goo00000goo001oo`3UOol00`00Oomoo`1VOol10001Ool1Ool00003Ool007oo
0>Ioo`03001oogoo06Eoo`40005oo`5oo`0000=oo`00Ool0igoo00<007ooOol0I7oo0@000Goo0Goo
00000goo001oo`3XOol00`00Oomoo`1SOol10001Ool1Ool00003Ool007oo0>Uoo`03001oogoo069o
o`40005oo`5oo`0000=oo`00Ool0jWoo00<007ooOol0HGoo0@000Goo0Goo00000goo001oo`3[Ool0
0`00Oomoo`1POol10001Ool1Ool00003Ool007oo0>aoo`03001oogoo05moo`40005oo`5oo`0000=o
o`00Ool0kGoo00<007ooOol0GWoo0@000Goo0Goo00000goo001oo`3^Ool00`00Oomoo`1MOol10001
Ool1Ool00003Ool007oo0>moo`03001oogoo05aoo`40005oo`5oo`0000=oo`00Ool0l7oo00<007oo
Ool0Fgoo0@000Goo0Goo00000goo001oo`3aOol2001KOol10001Ool1Ool00003Ool007oo0?=oo`03
001oogoo05Qoo`40005oo`5oo`0000=oo`00Ool0m7oo00<007ooOol0Egoo0@000Goo0Goo00000goo
001oo`3eOol00`00Oomoo`1FOol10001Ool1Ool00003Ool007oo0?Ioo`03001oogoo05Eoo`40005o
o`5oo`0000=oo`00Ool0mgoo00<007ooOol0E7oo0@000Goo0Goo00000goo001oo`3hOol00`00Oomo
o`1COol10001Ool1Ool00003Ool007oo0?Uoo`03001oogoo059oo`40005oo`5oo`0000=oo`00Ool0
nWoo00<007ooOol0DGoo0@000Goo0Goo00000goo001oo`3kOol00`00Oomoo`1@Ool10001Ool1Ool0
0003Ool007oo0?aoo`03001oogoo04moo`40005oo`5oo`0000=oo`00Ool0oGoo00<007ooOol0CWoo
0@000Goo0Goo00000goo001oo`3nOol00`00Oomoo`1=Ool10001Ool1Ool00003Ool007oo0?moo`03
001oogoo04aoo`40005oo`5oo`0000=oo`00Ool0ogoo0Goo00<007ooOol0Bgoo0@000Goo0Goo0000
0goo001oo`3oOol2Ool00`00Oomoo`1:Ool10001Ool1Ool00003Ool007oo0?moo`=oo`03001oogoo
04Uoo`40005oo`5oo`0000=oo`00Ool0ogoo17oo00<007ooOol0B7oo0@000Goo0Goo00000goo001o
o`3oOol5Ool00`00Oomoo`17Ool10001Ool1Ool00003Ool007oo0?moo`Ioo`03001oogoo04Ioo`40
005oo`5oo`0000=oo`00Ool0ogoo1goo00<007ooOol0AGoo0@000Goo0Goo00000goo001oo`3oOol8
Ool00`00Oomoo`14Ool10001Ool1Ool00003Ool007oo0?moo`Uoo`03001oogoo04=oo`40005oo`5o
o`0000=oo`00Ool0ogoo2Woo00<007ooOol0@Woo0@000Goo0Goo00000goo001oo`3oOol;Ool00`00
Oomoo`11Ool10001Ool1Ool00003Ool007oo0?moo`aoo`03001oogoo041oo`40005oo`5oo`0000=o
o`00Ool0ogoo3Goo00<007ooOol0?goo0@000Goo0Goo00000goo001oo`3oOol>Ool00`00Oomoo`0n
Ool10001Ool1Ool00003Ool007oo0?moo`moo`03001oogoo03eoo`40005oo`5oo`0000=oo`00Ool0
ogoo47oo00<007ooOol0?7oo0@000Goo0Goo00000goo001oo`3oOolAOol00`00Oomoo`0AOol00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0EOol10001Ool1Ool00003Ool007oo0?mooa9oo`03
001oogoo00moo`04001oogooOol20004Ool01000Oomoogoo0`000goo00<007ooOol057oo0@000Goo
0Goo00000goo001oo`3oOolCOol00`00Oomoo`0>Ool01`00Oomoogoo001oo`0000Aoo`04001oogoo
0005Ool00`00Oomoo`0DOol10001Ool1Ool00003Ool007oo0?mooaAoo`03001oogoo00aoo`8000=o
o`03001oo`0000Qoo`03001oogoo009oo`8001Eoo`40005oo`5oo`0000=oo`00Ool0ogoo5Goo00<0
07ooOol037oo00@007ooOomoo`8000Uoo`03001oogoo009oo`03001oogoo01Aoo`40005oo`5oo`00
00=oo`00Ool0ogoo5Woo00<007ooOol02goo00D007ooOomoo`0000Uoo`03001oo`0000=oo`03001o
ogoo01Aoo`40005oo`5oo`0000=oo`00Ool0ogoo5goo00<007ooOol02goo00@007ooOomoo`8000Qo
o`05001oogooOol0000GOol10001Ool1Ool00003Ool007oo0?mooaQoo`03001oogoo03Aoo`40005o
o`5oo`0000=oo`00Ool0ogoo6Goo00<007ooOol0<goo0@000Goo0Goo00000goo001oo`3oOolJOol0
0`00Oomoo`0bOol10001Ool1Ool00003Ool007oo0?mooa]oo`03001oogoo035oo`40005oo`5oo`00
00=oo`00Ool0ogoo77oo00<007ooOol0<7oo0@000Goo0Goo00000goo001oo`3oOolKOol3000aOol1
0001Ool1Ool00003Ool007oo0?mooaYoo`D0031oo`40005oo`5oo`0000=oo`00Ool0ogoo6goo0`00
<Goo0@000Goo0Goo00000goo001oo`3oOolLOol00`00Oomoo`0`Ool10001Ool1Ool00003Ool007oo
0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool1
0001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogoo97oo0`000goo0P00
8goo0@000Goo0Goo00000goo001oo`3oOolUOol00`00Oomoo`04Ool00`00Oomoo`0POol10001Ool1
Ool00003Ool007oo0?moobEoo`<000=oo`03001oogoo025oo`40005oo`5oo`0000=oo`00Ool0ogoo
9Goo00@007ooOol000=oo`03001oogoo021oo`40005oo`5oo`0000=oo`00Ool0ogoo9Goo00P007oo
Ool007oo001oo`008Woo0@000Goo0Goo00000goo001oo`3oOolTOol40003Ool00`00Oomoo`0QOol1
0001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo
00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00
Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmo
o`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo001oo`3oOom?Ool10001Ool1
Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogooCgoo0@000Goo0Goo00000goo
001oo`3oOom?Ool10001Ool1Ool00003Ool007oo0?moodmoo`40005oo`5oo`0000=oo`00Ool0ogoo
Cgoo0@000Goo0Goo00000goo0000003o001@0002Ool00001\
\>"],
  ImageRangeCache->{{{0, 339}, {270, 0}} -> {-0.0286569, -0.0210542, 
  0.00311892, 0.00311892}, {{9.1875, 329.813}, {263.25, 135}} -> {-0.714954,
   -0.657913, 0.0233921, 0.0233921}, {{9.1875, 329.813}, {135, 6.75}} ->
   {-0.714954, -3.65795, 0.0233921, 0.0233921}}],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(slider = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Two regular constraints and one ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are used to model the slider-ramp mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the left bottom corner of the slider as a function of time \
",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint enforces that the left bottom corner of the slider remains in \
contact with the horizontal surface of the ramp."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint with two stages eliminates the one remaining degree of \
freedom."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used to place the right bottom corner of the slider on the \
horizontal surface if it is still to the left of the ramp."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used to place the right bottom corner of the slider on the \
inclined ramp if it has passed to the right of the ramp."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Which stage of operation is active is determined by the value of a test \
expression that is a function of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " dependent variables. The test expression measures whether or not the \
right bottom corner of the slider has progressed far enough to the right to \
be on the inclined ramp."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the slider-ramp mechanism built in one step."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRelativeX1[1, Point[slider, 0], T], \n\t
      PointOnLine1[2, \n\t\tPoint[slider, 0], Line[ground, 0, {4, 0}]], \n\t
      StageSwitch[3, \n\t\t
        \(Location[slider, {2, 0}]\)\[LeftDoubleBracket]1
            \[RightDoubleBracket] < 4, \n\t\t
        PointOnLine1[1, \n\t\t\tPoint[slider, {2, 0}], 
          Line[ground, 0, {4, 0}]], \n\t\tTrue, \n\t\t
        PointOnLine1[1, Point[slider, {2, 0}], Line[ground, {4, 0}, {6, 2}]]]]
      \)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The slider-ramp mechanism model can be run at any time, ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", up to ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 4 with valid results. After ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 4, the left bottom corner of the slider passes the inclined ramp, but \
it does not travel up the ramp because the constraints have not been written \
to accommodate this."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This runs the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 1, X2 \[Rule] 1.`, Y2 \[Rule] 0.`, Th2 \[Rule] 0.`}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The slider-ramp mechanism is still on the horizontal segment of the ramp."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
 
 
  
%%Creator: Mathematica
 
 
 
  
%%AspectRatio: .4 
 
 
 
  
MathPictureStart
 
 
 
  
%% Graphics
 
 
 
  
/Courier findfont 10  scalefont  setfont
 
 
 
  
% Scaling calculations
 
 
 
  
0.0666667 0.133333 0.0666667 0.133333 [
 
 
 
  
[(0)] .06667 0 0 2 Msboxa
 
 
 
  
[(1)] .2 0 0 2 Msboxa
 
 
 
  
[(2)] .33333 0 0 2 Msboxa
 
 
 
  
[(3)] .46667 0 0 2 Msboxa
 
 
 
  
[(4)] .6 0 0 2 Msboxa
 
 
 
  
[(5)] .73333 0 0 2 Msboxa
 
 
 
  
[(6)] .86667 0 0 2 Msboxa
 
 
 
  
[(7)] 1 0 0 2 Msboxa
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Msboxa
 
 
 
  
[(0)] -0.0125 .06667 1 0 Msboxa
 
 
 
  
[(0.5)] -0.0125 .13333 1 0 Msboxa
 
 
 
  
[(1)] -0.0125 .2 1 0 Msboxa
 
 
 
  
[(1.5)] -0.0125 .26667 1 0 Msboxa
 
 
 
  
[(2)] -0.0125 .33333 1 0 Msboxa
 
 
 
  
[(2.5)] -0.0125 .4 1 0 Msboxa
 
 
 
  
[ -0.001 -0.001 0 0 ]
 
 
 
  
[ 1.001 .401 0 0 ]
 
 
 
  
] MathScale
 
 
 
  
% Start of Graphics
 
 
 
  
1 setlinecap
 
 
 
  
1 setlinejoin
 
 
 
  
newpath
 
 
 
  
[ ] 0 setdash
 
 
 
  
0 g
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.06667 0 m
 
 
 
  
.06667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0)] .06667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.2 0 m
 
 
 
  
.2 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1)] .2 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.33333 0 m
 
 
 
  
.33333 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2)] .33333 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.46667 0 m
 
 
 
  
.46667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(3)] .46667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.6 0 m
 
 
 
  
.6 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(4)] .6 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.73333 0 m
 
 
 
  
.73333 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(5)] .73333 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.86667 0 m
 
 
 
  
.86667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(6)] .86667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 0 m
 
 
 
  
1 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(7)] 1 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.09333 0 m
 
 
 
  
.09333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.12 0 m
 
 
 
  
.12 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.14667 0 m
 
 
 
  
.14667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.17333 0 m
 
 
 
  
.17333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.22667 0 m
 
 
 
  
.22667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.25333 0 m
 
 
 
  
.25333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.28 0 m
 
 
 
  
.28 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.30667 0 m
 
 
 
  
.30667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.36 0 m
 
 
 
  
.36 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.38667 0 m
 
 
 
  
.38667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.41333 0 m
 
 
 
  
.41333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.44 0 m
 
 
 
  
.44 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.49333 0 m
 
 
 
  
.49333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.52 0 m
 
 
 
  
.52 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.54667 0 m
 
 
 
  
.54667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.57333 0 m
 
 
 
  
.57333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.62667 0 m
 
 
 
  
.62667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.65333 0 m
 
 
 
  
.65333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.68 0 m
 
 
 
  
.68 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.70667 0 m
 
 
 
  
.70667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.76 0 m
 
 
 
  
.76 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.78667 0 m
 
 
 
  
.78667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.81333 0 m
 
 
 
  
.81333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.84 0 m
 
 
 
  
.84 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.89333 0 m
 
 
 
  
.89333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.92 0 m
 
 
 
  
.92 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.94667 0 m
 
 
 
  
.94667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.97333 0 m
 
 
 
  
.97333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.04 0 m
 
 
 
  
.04 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.01333 0 m
 
 
 
  
.01333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
1 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
.00625 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .06667 m
 
 
 
  
.00625 .06667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0)] -0.0125 .06667 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .13333 m
 
 
 
  
.00625 .13333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0.5)] -0.0125 .13333 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .2 m
 
 
 
  
.00625 .2 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1)] -0.0125 .2 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .26667 m
 
 
 
  
.00625 .26667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1.5)] -0.0125 .26667 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .33333 m
 
 
 
  
.00625 .33333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2)] -0.0125 .33333 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .4 m
 
 
 
  
.00625 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2.5)] -0.0125 .4 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .01333 m
 
 
 
  
.00375 .01333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .02667 m
 
 
 
  
.00375 .02667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .04 m
 
 
 
  
.00375 .04 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .05333 m
 
 
 
  
.00375 .05333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .08 m
 
 
 
  
.00375 .08 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .09333 m
 
 
 
  
.00375 .09333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .10667 m
 
 
 
  
.00375 .10667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .12 m
 
 
 
  
.00375 .12 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .14667 m
 
 
 
  
.00375 .14667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .16 m
 
 
 
  
.00375 .16 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .17333 m
 
 
 
  
.00375 .17333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .18667 m
 
 
 
  
.00375 .18667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .21333 m
 
 
 
  
.00375 .21333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .22667 m
 
 
 
  
.00375 .22667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .24 m
 
 
 
  
.00375 .24 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .25333 m
 
 
 
  
.00375 .25333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .28 m
 
 
 
  
.00375 .28 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .29333 m
 
 
 
  
.00375 .29333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .30667 m
 
 
 
  
.00375 .30667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .32 m
 
 
 
  
.00375 .32 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .34667 m
 
 
 
  
.00375 .34667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .36 m
 
 
 
  
.00375 .36 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .37333 m
 
 
 
  
.00375 .37333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .38667 m
 
 
 
  
.00375 .38667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
0 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.06667 .39375 m
 
 
 
  
.06667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.2 .39375 m
 
 
 
  
.2 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.33333 .39375 m
 
 
 
  
.33333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.46667 .39375 m
 
 
 
  
.46667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.6 .39375 m
 
 
 
  
.6 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.73333 .39375 m
 
 
 
  
.73333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.86667 .39375 m
 
 
 
  
.86667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 .39375 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.09333 .39625 m
 
 
 
  
.09333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.12 .39625 m
 
 
 
  
.12 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.14667 .39625 m
 
 
 
  
.14667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.17333 .39625 m
 
 
 
  
.17333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.22667 .39625 m
 
 
 
  
.22667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.25333 .39625 m
 
 
 
  
.25333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.28 .39625 m
 
 
 
  
.28 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.30667 .39625 m
 
 
 
  
.30667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.36 .39625 m
 
 
 
  
.36 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.38667 .39625 m
 
 
 
  
.38667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.41333 .39625 m
 
 
 
  
.41333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.44 .39625 m
 
 
 
  
.44 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.49333 .39625 m
 
 
 
  
.49333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.52 .39625 m
 
 
 
  
.52 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.54667 .39625 m
 
 
 
  
.54667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.57333 .39625 m
 
 
 
  
.57333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.62667 .39625 m
 
 
 
  
.62667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.65333 .39625 m
 
 
 
  
.65333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.68 .39625 m
 
 
 
  
.68 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.70667 .39625 m
 
 
 
  
.70667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.76 .39625 m
 
 
 
  
.76 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.78667 .39625 m
 
 
 
  
.78667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.81333 .39625 m
 
 
 
  
.81333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.84 .39625 m
 
 
 
  
.84 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.89333 .39625 m
 
 
 
  
.89333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.92 .39625 m
 
 
 
  
.92 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.94667 .39625 m
 
 
 
  
.94667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.97333 .39625 m
 
 
 
  
.97333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.04 .39625 m
 
 
 
  
.04 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.01333 .39625 m
 
 
 
  
.01333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .4 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 0 m
 
 
 
  
1 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .06667 m
 
 
 
  
1 .06667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .13333 m
 
 
 
  
1 .13333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .2 m
 
 
 
  
1 .2 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .26667 m
 
 
 
  
1 .26667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .33333 m
 
 
 
  
1 .33333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .4 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .01333 m
 
 
 
  
1 .01333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .02667 m
 
 
 
  
1 .02667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .04 m
 
 
 
  
1 .04 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .05333 m
 
 
 
  
1 .05333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .08 m
 
 
 
  
1 .08 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .09333 m
 
 
 
  
1 .09333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .10667 m
 
 
 
  
1 .10667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .12 m
 
 
 
  
1 .12 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .14667 m
 
 
 
  
1 .14667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .16 m
 
 
 
  
1 .16 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .17333 m
 
 
 
  
1 .17333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .18667 m
 
 
 
  
1 .18667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .21333 m
 
 
 
  
1 .21333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .22667 m
 
 
 
  
1 .22667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .24 m
 
 
 
  
1 .24 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .25333 m
 
 
 
  
1 .25333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .28 m
 
 
 
  
1 .28 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .29333 m
 
 
 
  
1 .29333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .30667 m
 
 
 
  
1 .30667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .32 m
 
 
 
  
1 .32 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .34667 m
 
 
 
  
1 .34667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .36 m
 
 
 
  
1 .36 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .37333 m
 
 
 
  
1 .37333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .38667 m
 
 
 
  
1 .38667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 0 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
P
 
 
 
  
p
 
 
 
  
P
 
 
 
  
0 0 m
 
 
 
  
1 0 L
 
 
 
  
1 .4 L
 
 
 
  
0 .4 L
 
 
 
  
closepath
 
 
 
  
clip
 
 
 
  
newpath
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.004 w
 
 
 
  
.06667 .06667 m
 
 
 
  
.6 .06667 L
 
 
 
  
.86667 .33333 L
 
 
 
  
s
 
 
 
  
.02 w
 
 
 
  
.06667 .06667 Mdot
 
 
 
  
.6 .06667 Mdot
 
 
 
  
.86667 .33333 Mdot
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.5 0 0 r
 
 
 
  
.2 .13333 m
 
 
 
  
.2 .06667 L
 
 
 
  
.46667 .06667 L
 
 
 
  
.46667 .13333 L
 
 
 
  
F
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.02 w
 
 
 
  
.2 .06667 Mdot
 
 
 
  
.46667 .06667 Mdot
 
 
 
  
P
 
 
 
  
P
 
 
 
  
P
 
 
 
  
P
 
 
 
  
% End of Graphics
 
 
 
  
MathPictureEnd
 
 
 
  

 
 
 
  
 
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 112},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000L1000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo000gOol00`00Oomoo`0HOol5000IOol3000JOol2000LOol3000JOol0
0`00Oomoo`0IOol2000LOol00`00Oomoo`0EOol003Ioo`03001oo`0001]oo`03001oogoo01Uoo`03
001oogoo01aoo`03001oogoo01Yoo`03001oogoo01Qoo`03001oo`0001Yoo`03001oo`0001]oo`03
001oogoo01Eoo`00=Woo00<007oo00006goo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol0
6Goo10006goo00<007ooOol067oo00<007oo00006goo00<007ooOol05Goo000fOol00`00Ool0000K
Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Ool0000JOol2000KOol2000M
Ool00`00Oomoo`0DOol003Ioo`03001oo`0001]oo`03001oogoo01Uoo`03001oo`0001Yoo`03001o
o`0001]oo`8001Yoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oo`0001Ioo`00=goo00<007oo
Ool06Goo0P0077oo00<007ooOol06Woo00<007ooOol06goo00<007ooOol067oo0`006goo0P006Woo
0`005Woo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000JOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3cOol001Uoo`03001oo`0000Moo`03001oo`00
0?Aoo`0057oo0`000Woo00<007oo00002Goo00@007ooOomoom/001Ioo`006Goo00<007oo00001goo
0P0017oo00@007ooOol000Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01Aoo`006Goo00<007oo00001goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo
00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol057oo
000JOol00`00Oomoo`06Ool30003Ool2003GOol2000FOol002Uoo`03001oogoo0=Moo`03001oogoo
01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2000FOol002Uoo`03001o
ogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2
000FOol002Uoo`03001oogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol0
57oo000YOol2003GOol2000FOol002Aoo`03001oogoo009oo`03001oogoo0=Moo`03001oogoo01Ao
o`008goo00<007oo00000goo00<007ooOol0egoo00<007ooOol057oo000SOol00`00Ool00003Ool3
000;Oomf001EOol2000FOol002=oo`03001oo`0000=oo`03001oogoo00Yoo`<001Yoo`<003Ll00<0
01Yoo`@005Eoo`03001oogoo01Aoo`008goo00<007oo00000goo00<007ooOol02goo00<007ooOol0
6Woo00<003`0?000=c`000<007ooOol06Woo00@007ooOol005Aoo`03001oogoo01Aoo`0097oo00<0
07ooOol00Woo0P00:Woo>S`087oo00<007ooOol0D7oo0P005Woo000YOol00`00Oomoo`0YOolj?00Q
Ool00`00Oomoo`1@Ool00`00Oomoo`0DOol002Uoo`03001oogoo02UoocXl029oo`03001oogoo04mo
o`03001oogoo01Aoo`00:Goo0P00:Woo>S`08goo00<007ooOol0CGoo0P005Woo000YOol00`00Oomo
o`0YOolj?00TOol00`00Oomoo`1=Ool00`00Oomoo`0DOol002Uoo`03001oogoo02UoocXl02Eoo`03
001oogoo04aoo`03001oogoo01Aoo`00:Goo0P00:Woo>S`09Woo00<007ooOol0BWoo0P005Woo000Y
Ool00`00Oomoo`0YOolj?00WOol00`00Oomoo`1:Ool00`00Oomoo`0DOol002Uoo`03001oogoo02Uo
ocXl02Qoo`03001oogoo04Uoo`03001oogoo01Aoo`006Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo0P00:Woo>S`0:Goo00<007ooOol0Agoo0P005Woo000IOol00`00Ool00007Ool0
0`00Ool00003Ool00`00Oomoo`0YOolj?00ZOol00`00Oomoo`17Ool00`00Oomoo`0DOol001Uoo`03
001oo`0000Uoo`04001oogooOol3000YOolj?00[Ool00`00Oomoo`15Ool2000FOol001Uoo`03001o
o`0000Moo`8000Aoo`03001oogoo08moo`03001oogoo04Eoo`03001oogoo01Aoo`006Goo00<007oo
00001goo00<007ooOol00goo00<007ooOol0T7oo00<007ooOol0A7oo00<007ooOol057oo000JOol0
0`00Oomoo`06Ool30003Ool2002BOol00`00Oomoo`12Ool2000FOol002Uoo`03001oogoo099oo`03
001oogoo049oo`03001oogoo01Aoo`00:Goo00<007ooOol0Tgoo00<007ooOol0@Goo00<007ooOol0
57oo000YOol2002EOol00`00Oomoo`0oOol2000FOol002Uoo`03001oogoo09Eoo`03001oogoo03mo
o`03001oogoo01Aoo`00:Goo00<007ooOol0UWoo00<007ooOol0?Woo00<007ooOol057oo000YOol2
002HOol00`00Oomoo`0lOol2000FOol002Uoo`03001oogoo09Qoo`03001oogoo03aoo`03001oogoo
01Aoo`00:Goo00<007ooOol0VGoo00<007ooOol0>goo00<007ooOol057oo000YOol2002KOol00`00
Oomoo`0iOol2000FOol0029oo`D0009oo`03001oogoo09]oo`03001oogoo03Uoo`03001oogoo01Ao
o`0097oo00<007ooOol00Woo00<007ooOol0W7oo00<007ooOol0>7oo00<007ooOol057oo000TOol0
0`00Oomoo`02Ool3002MOol00`00Oomoo`0fOol2000FOol002Aoo`03001oogoo009oo`03001oogoo
09ioo`03001oogoo03Ioo`03001oogoo01Aoo`0097oo00<007ooOol00Woo00<007ooOol0Wgoo00<0
07ooOol0=Goo00<007ooOol057oo000SOol20004Ool2002QOol00`00Oomoo`0cOol2000FOol002Uo
o`03001oogoo0:5oo`03001oogoo03=oo`03001oogoo01Aoo`00:Goo00<007ooOol0XWoo00<007oo
Ool0<Woo00<007ooOol057oo000YOol2002TOol00`00Oomoo`0`Ool2000FOol002Uoo`03001oogoo
0:Aoo`03001oogoo031oo`03001oogoo01Aoo`00:Goo00<007ooOol0YGoo00<007ooOol0;goo00<0
07ooOol057oo000YOol2002WOol00`00Oomoo`0]Ool2000FOol002Uoo`03001oogoo0:Moo`03001o
ogoo02eoo`03001oogoo01Aoo`00:Goo00<007ooOol0Z7oo00<007ooOol0;7oo00<007ooOol057oo
000HOol50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool2002ZOol00`00Oomoo`0ZOol2000FOol0
01Yoo`03001oogoo00Ioo`03001oo`0000=oo`03001oogoo0:Yoo`03001oogoo02Yoo`03001oogoo
01Aoo`006Woo00<007ooOol027oo00@007ooOomoo`<00:]oo`03001oogoo02Qoo`8001Ioo`006Woo
00<007ooOol01Woo0P0017oo00<007ooOol0[7oo00<007ooOol0:7oo00<007ooOol057oo000JOol0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`2]Ool00`00Oomoo`0WOol00`00Oomoo`0DOol0
01Uoo`8000Qoo`<000=oo`800:moo`03001oogoo02Eoo`8001Ioo`00:Goo00<007ooOol0[goo00<0
07ooOol09Goo00<007ooOol057oo000YOol00`00Oomoo`2`Ool00`00Oomoo`0TOol00`00Oomoo`0D
Ool002Uoo`800;9oo`03001oogoo029oo`8001Ioo`00:Goo00<007ooOol0/Woo00<007ooOol08Woo
00<007ooOol057oo000YOol00`00Oomoo`2cOol00`00Oomoo`0QOol00`00Oomoo`0DOol002Uoo`80
0;Eoo`03001oogoo01moo`8001Ioo`00:Goo00<007ooOol0]Goo00<007ooOol07goo00<007ooOol0
57oo000YOol00`00Oomoo`2fOol00`00Oomoo`0NOol00`00Oomoo`0DOol002Uoo`800;Qoo`03001o
ogoo01aoo`8001Ioo`008goo0`000goo00<007ooOol0^7oo00<007ooOol077oo00<007ooOol057oo
000SOol00`00Oomoo`03Ool00`00Oomoo`2iOol00`00Oomoo`0KOol00`00Oomoo`0DOol002Aoo`03
001oogoo009oo`<00;Uoo`8001]oo`8001Ioo`0097oo00<007ooOol00Woo00<007ooOol0^7oo0`00
77oo00<007ooOol057oo000SOol00`00Ool00003Ool00`00Oomoo`2iOol00`00Oomoo`0KOol00`00
Oomoo`0DOol002Aoo`03001oogoo009oo`800=Moo`8001Ioo`00:Goo00<007ooOol0egoo00<007oo
Ool057oo000YOol00`00Oomoo`3GOol00`00Oomoo`0DOol002Uoo`800=Moo`8001Ioo`00:Goo00<0
07ooOol0egoo00<007ooOol057oo000YOol00`00Oomoo`3GOol00`00Oomoo`0DOol002Uoo`800=Mo
o`8001Ioo`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol00`00Oomoo`3GOol00`00Oomo
o`0DOol001Uoo`<000=oo`03001oogoo009oo`03001oogoo009oo`800=Moo`8001Ioo`006Goo00<0
07ooOol01goo00<007oo00000goo00<007ooOol037oo00<007ooOol06Woo00<007ooOol06Woo00<0
07ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<0
07ooOol057oo000JOol00`00Oomoo`08Ool01000Oomoogoof`005Woo000JOol00`00Oomoo`06Ool2
003eOol001Uoo`03001oo`0000Moo`03001oogoo0?Aoo`006Woo00<007ooOol01Woo0`00m7oo003o
OolKOol00?mooa]oo`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {111, 0}} -> {-1.94348, -1.12071, 0.0344832, 
  0.0344832}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5, which puts the slider part way up the ramp."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[2.5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["2.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 2.5`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.226408297372462774`\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the result."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
 
 
  
%%Creator: Mathematica
 
 
 
  
%%AspectRatio: .4 
 
 
 
  
MathPictureStart
 
 
 
  
%% Graphics
 
 
 
  
/Courier findfont 10  scalefont  setfont
 
 
 
  
% Scaling calculations
 
 
 
  
0.0666667 0.133333 0.0666667 0.133333 [
 
 
 
  
[(0)] .06667 0 0 2 Msboxa
 
 
 
  
[(1)] .2 0 0 2 Msboxa
 
 
 
  
[(2)] .33333 0 0 2 Msboxa
 
 
 
  
[(3)] .46667 0 0 2 Msboxa
 
 
 
  
[(4)] .6 0 0 2 Msboxa
 
 
 
  
[(5)] .73333 0 0 2 Msboxa
 
 
 
  
[(6)] .86667 0 0 2 Msboxa
 
 
 
  
[(7)] 1 0 0 2 Msboxa
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Msboxa
 
 
 
  
[(0)] -0.0125 .06667 1 0 Msboxa
 
 
 
  
[(0.5)] -0.0125 .13333 1 0 Msboxa
 
 
 
  
[(1)] -0.0125 .2 1 0 Msboxa
 
 
 
  
[(1.5)] -0.0125 .26667 1 0 Msboxa
 
 
 
  
[(2)] -0.0125 .33333 1 0 Msboxa
 
 
 
  
[(2.5)] -0.0125 .4 1 0 Msboxa
 
 
 
  
[ -0.001 -0.001 0 0 ]
 
 
 
  
[ 1.001 .401 0 0 ]
 
 
 
  
] MathScale
 
 
 
  
% Start of Graphics
 
 
 
  
1 setlinecap
 
 
 
  
1 setlinejoin
 
 
 
  
newpath
 
 
 
  
[ ] 0 setdash
 
 
 
  
0 g
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.06667 0 m
 
 
 
  
.06667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0)] .06667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.2 0 m
 
 
 
  
.2 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1)] .2 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.33333 0 m
 
 
 
  
.33333 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2)] .33333 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.46667 0 m
 
 
 
  
.46667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(3)] .46667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.6 0 m
 
 
 
  
.6 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(4)] .6 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.73333 0 m
 
 
 
  
.73333 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(5)] .73333 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.86667 0 m
 
 
 
  
.86667 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(6)] .86667 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 0 m
 
 
 
  
1 .00625 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(7)] 1 0 0 2 Mshowa
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.09333 0 m
 
 
 
  
.09333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.12 0 m
 
 
 
  
.12 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.14667 0 m
 
 
 
  
.14667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.17333 0 m
 
 
 
  
.17333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.22667 0 m
 
 
 
  
.22667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.25333 0 m
 
 
 
  
.25333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.28 0 m
 
 
 
  
.28 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.30667 0 m
 
 
 
  
.30667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.36 0 m
 
 
 
  
.36 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.38667 0 m
 
 
 
  
.38667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.41333 0 m
 
 
 
  
.41333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.44 0 m
 
 
 
  
.44 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.49333 0 m
 
 
 
  
.49333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.52 0 m
 
 
 
  
.52 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.54667 0 m
 
 
 
  
.54667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.57333 0 m
 
 
 
  
.57333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.62667 0 m
 
 
 
  
.62667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.65333 0 m
 
 
 
  
.65333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.68 0 m
 
 
 
  
.68 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.70667 0 m
 
 
 
  
.70667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.76 0 m
 
 
 
  
.76 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.78667 0 m
 
 
 
  
.78667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.81333 0 m
 
 
 
  
.81333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.84 0 m
 
 
 
  
.84 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.89333 0 m
 
 
 
  
.89333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.92 0 m
 
 
 
  
.92 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.94667 0 m
 
 
 
  
.94667 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.97333 0 m
 
 
 
  
.97333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.04 0 m
 
 
 
  
.04 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.01333 0 m
 
 
 
  
.01333 .00375 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
1 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
.00625 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .06667 m
 
 
 
  
.00625 .06667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0)] -0.0125 .06667 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .13333 m
 
 
 
  
.00625 .13333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(0.5)] -0.0125 .13333 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .2 m
 
 
 
  
.00625 .2 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1)] -0.0125 .2 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .26667 m
 
 
 
  
.00625 .26667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(1.5)] -0.0125 .26667 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .33333 m
 
 
 
  
.00625 .33333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2)] -0.0125 .33333 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .4 m
 
 
 
  
.00625 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
[(2.5)] -0.0125 .4 1 0 Mshowa
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .01333 m
 
 
 
  
.00375 .01333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .02667 m
 
 
 
  
.00375 .02667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .04 m
 
 
 
  
.00375 .04 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .05333 m
 
 
 
  
.00375 .05333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .08 m
 
 
 
  
.00375 .08 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .09333 m
 
 
 
  
.00375 .09333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .10667 m
 
 
 
  
.00375 .10667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .12 m
 
 
 
  
.00375 .12 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .14667 m
 
 
 
  
.00375 .14667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .16 m
 
 
 
  
.00375 .16 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .17333 m
 
 
 
  
.00375 .17333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .18667 m
 
 
 
  
.00375 .18667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .21333 m
 
 
 
  
.00375 .21333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .22667 m
 
 
 
  
.00375 .22667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .24 m
 
 
 
  
.00375 .24 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .25333 m
 
 
 
  
.00375 .25333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .28 m
 
 
 
  
.00375 .28 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .29333 m
 
 
 
  
.00375 .29333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .30667 m
 
 
 
  
.00375 .30667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .32 m
 
 
 
  
.00375 .32 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .34667 m
 
 
 
  
.00375 .34667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .36 m
 
 
 
  
.00375 .36 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .37333 m
 
 
 
  
.00375 .37333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
0 .38667 m
 
 
 
  
.00375 .38667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 0 m
 
 
 
  
0 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.06667 .39375 m
 
 
 
  
.06667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.2 .39375 m
 
 
 
  
.2 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.33333 .39375 m
 
 
 
  
.33333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.46667 .39375 m
 
 
 
  
.46667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.6 .39375 m
 
 
 
  
.6 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.73333 .39375 m
 
 
 
  
.73333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.86667 .39375 m
 
 
 
  
.86667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 .39375 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.09333 .39625 m
 
 
 
  
.09333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.12 .39625 m
 
 
 
  
.12 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.14667 .39625 m
 
 
 
  
.14667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.17333 .39625 m
 
 
 
  
.17333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.22667 .39625 m
 
 
 
  
.22667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.25333 .39625 m
 
 
 
  
.25333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.28 .39625 m
 
 
 
  
.28 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.30667 .39625 m
 
 
 
  
.30667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.36 .39625 m
 
 
 
  
.36 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.38667 .39625 m
 
 
 
  
.38667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.41333 .39625 m
 
 
 
  
.41333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.44 .39625 m
 
 
 
  
.44 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.49333 .39625 m
 
 
 
  
.49333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.52 .39625 m
 
 
 
  
.52 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.54667 .39625 m
 
 
 
  
.54667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.57333 .39625 m
 
 
 
  
.57333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.62667 .39625 m
 
 
 
  
.62667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.65333 .39625 m
 
 
 
  
.65333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.68 .39625 m
 
 
 
  
.68 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.70667 .39625 m
 
 
 
  
.70667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.76 .39625 m
 
 
 
  
.76 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.78667 .39625 m
 
 
 
  
.78667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.81333 .39625 m
 
 
 
  
.81333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.84 .39625 m
 
 
 
  
.84 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.89333 .39625 m
 
 
 
  
.89333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.92 .39625 m
 
 
 
  
.92 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.94667 .39625 m
 
 
 
  
.94667 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.97333 .39625 m
 
 
 
  
.97333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.04 .39625 m
 
 
 
  
.04 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.01333 .39625 m
 
 
 
  
.01333 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
0 .4 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 0 m
 
 
 
  
1 0 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .06667 m
 
 
 
  
1 .06667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .13333 m
 
 
 
  
1 .13333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .2 m
 
 
 
  
1 .2 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .26667 m
 
 
 
  
1 .26667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .33333 m
 
 
 
  
1 .33333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
.99375 .4 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .01333 m
 
 
 
  
1 .01333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .02667 m
 
 
 
  
1 .02667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .04 m
 
 
 
  
1 .04 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .05333 m
 
 
 
  
1 .05333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .08 m
 
 
 
  
1 .08 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .09333 m
 
 
 
  
1 .09333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .10667 m
 
 
 
  
1 .10667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .12 m
 
 
 
  
1 .12 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .14667 m
 
 
 
  
1 .14667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .16 m
 
 
 
  
1 .16 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .17333 m
 
 
 
  
1 .17333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .18667 m
 
 
 
  
1 .18667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .21333 m
 
 
 
  
1 .21333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .22667 m
 
 
 
  
1 .22667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .24 m
 
 
 
  
1 .24 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .25333 m
 
 
 
  
1 .25333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .28 m
 
 
 
  
1 .28 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .29333 m
 
 
 
  
1 .29333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .30667 m
 
 
 
  
1 .30667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .32 m
 
 
 
  
1 .32 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .34667 m
 
 
 
  
1 .34667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .36 m
 
 
 
  
1 .36 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .37333 m
 
 
 
  
1 .37333 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.001 w
 
 
 
  
.99625 .38667 m
 
 
 
  
1 .38667 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
p
 
 
 
  
.002 w
 
 
 
  
1 0 m
 
 
 
  
1 .4 L
 
 
 
  
s
 
 
 
  
P
 
 
 
  
P
 
 
 
  
p
 
 
 
  
P
 
 
 
  
0 0 m
 
 
 
  
1 0 L
 
 
 
  
1 .4 L
 
 
 
  
0 .4 L
 
 
 
  
closepath
 
 
 
  
clip
 
 
 
  
newpath
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.004 w
 
 
 
  
.06667 .06667 m
 
 
 
  
.6 .06667 L
 
 
 
  
.86667 .33333 L
 
 
 
  
s
 
 
 
  
.02 w
 
 
 
  
.06667 .06667 Mdot
 
 
 
  
.6 .06667 Mdot
 
 
 
  
.86667 .33333 Mdot
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.5 0 0 r
 
 
 
  
.38503 .13163 m
 
 
 
  
.4 .06667 L
 
 
 
  
.65986 .12653 L
 
 
 
  
.6449 .19149 L
 
 
 
  
F
 
 
 
  
P
 
 
 
  
p
 
 
 
  
p
 
 
 
  
.02 w
 
 
 
  
.4 .06667 Mdot
 
 
 
  
.65986 .12653 Mdot
 
 
 
  
P
 
 
 
  
P
 
 
 
  
P
 
 
 
  
P
 
 
 
  
% End of Graphics
 
 
 
  
MathPictureEnd
 
 
 
  

 
 
 
  
 
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 112},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000L1000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo000gOol00`00Oomoo`0HOol5000IOol3000JOol2000LOol3000JOol0
0`00Oomoo`0IOol2000LOol00`00Oomoo`0EOol003Ioo`03001oo`0001]oo`03001oogoo01Uoo`03
001oogoo01aoo`03001oogoo01Yoo`03001oogoo01Qoo`03001oo`0001Yoo`03001oo`0001]oo`03
001oogoo01Eoo`00=Woo00<007oo00006goo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol0
6Goo10006goo00<007ooOol067oo00<007oo00006goo00<007ooOol05Goo000fOol00`00Ool0000K
Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Oomoo`0HOol00`00Ool0000JOol2000KOol2000M
Ool00`00Oomoo`0DOol003Ioo`03001oo`0001]oo`03001oogoo01Uoo`03001oo`0001Yoo`03001o
o`0001]oo`8001Yoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oo`0001Ioo`00=goo00<007oo
Ool06Goo0P0077oo00<007ooOol06Woo00<007ooOol06goo00<007ooOol067oo0`006goo0P006Woo
0`005Woo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000JOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3cOol001Uoo`03001oo`0000Moo`03001oo`00
0?Aoo`0057oo0`000Woo00<007oo00002Goo00@007ooOomoom/001Ioo`006Goo00<007oo00001goo
0P0017oo00@007ooOol000Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo01Aoo`006Goo00<007oo00001goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo
00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol06Woo00<007ooOol057oo
000JOol00`00Oomoo`06Ool30003Ool2003GOol2000FOol002Uoo`03001oogoo0=Moo`03001oogoo
01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2000FOol002Uoo`03001o
ogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2
000FOol002Uoo`03001oogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol0
57oo000YOol2003GOol2000FOol002Aoo`03001oogoo009oo`03001oogoo0=Moo`03001oogoo01Ao
o`008goo00<007oo00000goo00<007ooOol0egoo00<007ooOol057oo000SOol00`00Ool00003Ool3
000;Oomf001EOol2000FOol002=oo`03001oo`0000=oo`03001oogoo00Yoo`<004Ioo`<000<l02Eo
o`@005Eoo`03001oogoo01Aoo`008goo00<007oo00000goo00<007ooOol02goo00<007ooOol0AWoo
00<003`0?0001S`08Woo00@007ooOol005Aoo`03001oogoo01Aoo`0097oo00<007ooOol00Woo0P00
EGoo3S`08Goo00<007ooOol0D7oo0P005Woo000YOol00`00Oomoo`1DOolB?00NOol00`00Oomoo`1@
Ool00`00Oomoo`0DOol002Uoo`03001oogoo05=ooaLl01]oo`03001oogoo04moo`03001oogoo01Ao
o`00:Goo0P00E7oo73`05goo00<007ooOol0CGoo0P005Woo000YOol00`00Oomoo`1COolP?00DOol0
0`00Oomoo`1=Ool00`00Oomoo`0DOol002Uoo`03001oogoo05=oobDl011oo`03001oogoo04aoo`03
001oogoo01Aoo`00:Goo0P00E7oo:C`03Goo00<007ooOol0BWoo0P005Woo000YOol00`00Oomoo`1B
Ool^?00:Ool00`00Oomoo`1:Ool00`00Oomoo`0DOol002Uoo`03001oogoo059ooc<l00Ioo`03001o
ogoo04Uoo`03001oogoo01Aoo`006Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo
0P00Dgoo=c`00goo00<007ooOol0Agoo0P005Woo000IOol00`00Ool00007Ool00`00Ool00003Ool0
0`00Oomoo`1BOolj?0020019Ool00`00Oomoo`0DOol001Uoo`03001oo`0000Uoo`04001oogooOol3
001AOolj?0040017Ool2000FOol001Uoo`03001oo`0000Moo`8000Aoo`03001oogoo05IoocHl0004
001oogoo0017Ool00`00Oomoo`0DOol001Uoo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo
05Yooc<l00=oo`03001oogoo04Aoo`03001oogoo01Aoo`006Woo00<007ooOol01Woo0`000goo0P00
H7oo;S`017oo00<007ooOol0@Woo0P005Woo000YOol00`00Oomoo`1SOolY?006Ool00`00Oomoo`12
Ool00`00Oomoo`0DOol002Uoo`03001oogoo06MoobDl00Moo`03001oogoo045oo`03001oogoo01Ao
o`00:Goo0P00KGoo83`027oo00<007ooOol0?goo0P005Woo000YOol00`00Oomoo`1`OolL?009Ool0
0`00Oomoo`0oOol00`00Oomoo`0DOol002Uoo`03001oogoo07EooaLl00Yoo`03001oogoo03ioo`03
001oogoo01Aoo`00:Goo0P00NWoo4S`037oo00<007ooOol0?7oo0P005Woo000YOol00`00Oomoo`1m
Ool>?00=Ool00`00Oomoo`0lOol00`00Oomoo`0DOol002Uoo`03001oogoo089oo`Tl00ioo`03001o
ogoo03]oo`03001oogoo01Aoo`00:Goo0P00Qgoo1C`03goo00<007ooOol0>Goo0P005Woo000ROol5
0002Ool00`00Oomoo`2KOol00`00Oomoo`0iOol00`00Oomoo`0DOol002Aoo`03001oogoo009oo`03
001oogoo09aoo`03001oogoo03Qoo`03001oogoo01Aoo`0097oo00<007ooOol00Woo0`00WGoo00<0
07ooOol0=Woo0P005Woo000TOol00`00Oomoo`02Ool00`00Oomoo`2NOol00`00Oomoo`0fOol00`00
Oomoo`0DOol002Aoo`03001oogoo009oo`03001oogoo09moo`03001oogoo03Eoo`03001oogoo01Ao
o`008goo0P0017oo0P00XGoo00<007ooOol0<goo0P005Woo000YOol00`00Oomoo`2QOol00`00Oomo
o`0cOol00`00Oomoo`0DOol002Uoo`03001oogoo0:9oo`03001oogoo039oo`03001oogoo01Aoo`00
:Goo0P00Y7oo00<007ooOol0<7oo0P005Woo000YOol00`00Oomoo`2TOol00`00Oomoo`0`Ool00`00
Oomoo`0DOol002Uoo`03001oogoo0:Eoo`03001oogoo02moo`03001oogoo01Aoo`00:Goo0P00Ygoo
00<007ooOol0;Goo0P005Woo000YOol00`00Oomoo`2WOol00`00Oomoo`0]Ool00`00Oomoo`0DOol0
02Uoo`03001oogoo0:Qoo`03001oogoo02aoo`03001oogoo01Aoo`0067oo1@000Woo00<007ooOol0
0Woo00<007ooOol00Woo0P00ZWoo00<007ooOol0:Woo0P005Woo000JOol00`00Oomoo`06Ool00`00
Ool00003Ool00`00Oomoo`2ZOol00`00Oomoo`0ZOol00`00Oomoo`0DOol001Yoo`03001oogoo00Qo
o`04001oogooOol3002[Ool00`00Oomoo`0XOol2000FOol001Yoo`03001oogoo00Ioo`8000Aoo`03
001oogoo0:aoo`03001oogoo02Qoo`03001oogoo01Aoo`006Woo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol0[Goo00<007ooOol09goo00<007ooOol057oo000IOol20008Ool30003Ool2002_
Ool00`00Oomoo`0UOol2000FOol002Uoo`03001oogoo0:moo`03001oogoo02Eoo`03001oogoo01Ao
o`00:Goo00<007ooOol0/7oo00<007ooOol097oo00<007ooOol057oo000YOol2002bOol00`00Oomo
o`0ROol2000FOol002Uoo`03001oogoo0;9oo`03001oogoo029oo`03001oogoo01Aoo`00:Goo00<0
07ooOol0/goo00<007ooOol08Goo00<007ooOol057oo000YOol2002eOol00`00Oomoo`0OOol2000F
Ool002Uoo`03001oogoo0;Eoo`03001oogoo01moo`03001oogoo01Aoo`00:Goo00<007ooOol0]Woo
00<007ooOol07Woo00<007ooOol057oo000YOol2002hOol00`00Oomoo`0LOol2000FOol002=oo`<0
00=oo`03001oogoo0;Qoo`03001oogoo01aoo`03001oogoo01Aoo`008goo00<007ooOol00goo00<0
07ooOol0^Goo00<007ooOol06goo00<007ooOol057oo000TOol00`00Oomoo`02Ool3002iOol2000K
Ool2000FOol002Aoo`03001oogoo009oo`03001oogoo0;Qoo`<001aoo`03001oogoo01Aoo`008goo
00<007oo00000goo00<007ooOol0^Goo00<007ooOol06goo00<007ooOol057oo000TOol00`00Oomo
o`02Ool2003GOol2000FOol002Uoo`03001oogoo0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0
egoo00<007ooOol057oo000YOol2003GOol2000FOol002Uoo`03001oogoo0=Moo`03001oogoo01Ao
o`00:Goo00<007ooOol0egoo00<007ooOol057oo000YOol2003GOol2000FOol002Uoo`03001oogoo
0=Moo`03001oogoo01Aoo`00:Goo00<007ooOol0egoo00<007ooOol057oo000IOol30003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool2003GOol2000FOol001Uoo`03001oogoo00Moo`03001oo`0000=o
o`03001oogoo00aoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Yo
o`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo01Aoo`006Woo00<007oo
Ool027oo00@007ooOomoom/001Ioo`006Woo00<007ooOol01Woo0P00mGoo000IOol00`00Ool00007
Ool00`00Oomoo`3dOol001Yoo`03001oogoo00Ioo`<00?Aoo`00ogoo6goo003oOolKOol00?mooa]o
o`00\
\>"],
  ImageRangeCache->{{{0, 281}, {111, 0}} -> {-1.94348, -1.12071, 0.0344832, 
  0.0344832}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following statements generate the graphics in this section. These ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands are defined in Chapter 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Rocker"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
p1=Graphics[{PointSize[.02],
  Line[{{-2.5,-1.5},{-2.5,2},{2.5,2},{2.5,-2},{-2.5,-2},
        {-2.5,-1.5},{-2,-1},{-2.5,-0.5}}],
  Line[{{0,2},{0,-2}}],
  Point[{0,0}], Point[{-2,-1}]},
    AspectRatio->Automatic,PlotRange->{{-3,3},{-2.5,2.5}}]; \
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t1=Graphics[\n  {Text[\"{0,0}\",  { 0, 0},{-1.1, 1.7}],\n   Text[\"P1\",     \
{ 0, 0},{-1.7,-1.7}],\n   Text[\"{-2,-1}\",{-2,-1},{-1.1, 1.7}],\n   \
Text[\"P2\",     {-2,-1},{-1.7,-1.7}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g1=Show[{p1,t1}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p2=Graphics[{\n  {RGBColor[1,0,0],\n   Disk[Location[eccentric,0],1.5]},\n  \
{RGBColor[1,.7,.7],\n   Disk[Location[eccentric,{0.5,0}],1.0]},\n  \
{PointSize[.02],\n   Vertex[eccentric,{{0,0},{0.5,0}}]}},\n    \
AspectRatio->Automatic,PlotRange->{{-3,3},{-2.5,2.5}}]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t2=Graphics[{Text[\"{0,0}\",   {0, 0},  { 0.4, 1.7}],\n             \
Text[\"P1\",      {0, 0},  {0   ,-1.7}],\n             Text[\"{.5,0}\",{0.5, \
0},  {-0.6, 1.7}],\n             Text[\"P2\",    {0.5, 0},  { 0,  -1.7}]}];"],
   "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g2=Show[{p2,t2}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p3=Graphics[{\n  {RGBColor[.2,.2,1],\n   Bar[Line[rocker,0,{4,0}],0,.25],\n  \
 Disk[{-2,-1},.25],\n   Facet[rocker,{{4,-.25},{3.75,-.5},{3.5,-.25}}]},\n  \
{PointSize[.02],Vertex[rocker,{{0,0},{3.75,-0.5},{4,0}}]}},\n    \
AspectRatio->Automatic,PlotRange->{{-3,3},{-2.5,2.5}}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t3=Graphics[{Text[\"P1 {0,0}\", {-2, -1},{-.3,-4}],\n             \
Text[\"{4,0}\", Location[rocker,{4,0}],{-1.2, 1.7}],\n             \
Text[\"P2\",    Location[rocker,{4,0}],{-1.7,-1.7}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g3=Show[{p3,t3}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{p1,p2,p3,Graphics[{LocalAxes[eccentric,.7]}]}/.LastSolve[]];"], "Input",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[{{g1},{g2},{g3}},Frame->True,\n  GraphicsSpacing->0]];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Slider-Ramp"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p1=Graphics[{PointSize[.02],\n  Line[{{0,0},{4,0},{6,2}}],\n  Point[{0,0}], \
Point[{4,0}], Point[{6,2}]},\n    \
AspectRatio->Automatic,PlotRange->{{-.5,7},{-.5,2.5}}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t1=Graphics[\n  {Text[\"{0,0}\",  {0,0},{0, 1.8}],\n   Text[\"P1\",     \
{0,0},{0,-2.2}],\n   Text[\"{4,0}\",  {4,0},{ 0  , 1.8}],\n   Text[\"P2\",    \
 {4,0},{ 1.7,-2.2}],\n   Text[\"{6,2}\",  {6,2},{-1.4, 1.6}],\n   \
Text[\"P3\",     {6,2},{-2.4,-1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g1=Show[{p1,t1}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p2=Graphics[{\n  {RGBColor[.5,0,0],\n   Bar[Line[slider,0,{2,0}],.5,0]},\n  \
{PointSize[.02],\n   Vertex[slider, {0,{2,0}}]}},\n    \
AspectRatio->Automatic,PlotRange->{{-.5,7},{-.5,2.5}}];  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t2=Graphics[{Text[\"{0,0}\",Location[slider,{0, 0}],  { 0  , 1.8}],\n        \
     Text[\"P1\",   Location[slider,{0, 0}],  { 1.7,-1.8}],\n             \
Text[\"{2,0}\",Location[slider,{2, 0}],  { 0  , 1.8}],\n             \
Text[\"P2\",   Location[slider,{2, 0}],  {-1.7,-1.8}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g2=Show[{p2,t2}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{p1,p2}/.LastSolve[],Frame->True];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[{{g1},{g2}},Frame->True,\n  GraphicsSpacing->0]];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["5.2  Time Switching Constraints"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is a compound constraint that contains several normal ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraints and determines which one is active by the value of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This function can be used to model any mechanism that switches from one \
mode of operation to another with the progression of time. \n\nA ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is basically a special case of a ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint that has switching capability explicitly dependent on time. \
All of the functionality of ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be duplicated with ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", except that the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint can be used with another special function, ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", that is used to seek the point in time at which two adjacent constraints \
should switch from one to the next."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["TimeSwitch"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TimeSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["constraint0",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["time1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["constraint1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["timen",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["constraintn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint object that is used in place of a single constraint in a \
model. ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies ",
  StyleBox["constrainti",
    FontSlant->"Italic"],
  " when the value of time is greater than ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " and less than ",
  StyleBox["time(i+1)",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " must evaluate to numbers in ascending order. The values of ",
  StyleBox["time0",
    FontSlant->"Italic"],
  " and ",
  StyleBox["time(n+1)",
    FontSlant->"Italic"],
  " are taken to be ",
  StyleBox["-$MaxMachineNumber",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["+$MaxMachineNumber",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", respectively. ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions analogously to ",
  StyleBox["Which",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The time-dependent, stage-switching function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Each of the constraints supplied to the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint object, or a list of constraint objects. Each constraint or \
list of constraints must constrain the same number of degrees of freedom. \
Note that the constraint numbers of the constraints that are inside of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are irrelevant. The constraint number of the entire ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the only one used to reference the entire constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Examples "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The following example shows how a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (constraint 1) might be used to model a pin on a slider that slides along \
a horizontal track on the ground until the value of time reaches 2.0, at \
which time the pin begins to slide up an inclined track.\n\nThis constraint \
could replace the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint used in the slider-ramp model in the previous section."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a valid ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(slider = 2; \)\), 
    \(TimeSwitch[1, \n\t
      PointOnLine1[1, Point[slider, {2, 0}], Line[ground, {0, 0}, {4, 0}]], \n
      \t2.0, \n\t
      PointOnLine1[1, Point[slider, {2, 0}], Line[ground, {4, 0}, {6, 2}]]]
      \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["TimeSwitch", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The following example shows how a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that constrains two degrees of freedom might be implemented. The first \
constraint in the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " forces the origin of the slider to be coincident with the origin of the \
ground. If the value of time rises above 4.0 the second constraint pair \
becomes active which forces the origin of the slider to lie upon an inclined \
line, while the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of the origin of the slider is a function of time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a valid ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeSwitch[1, \n\t
      Revolute2[1, Point[slider, {0, 0}], Point[ground, {0, 0}]], \n\t4.0, \n
      \t{PointOnLine1[1, Point[slider, {0, 0}], 
          Axis[ground, {0, 0}, {1, 1}]], \n\t\t
        RelativeY1[1, Point[slider, {0, 0}], T - 4.0]}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["TimeSwitch", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Detent Mechanism Example"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function a 2D model of a detent mechanism is developed. The model \
consists of two moving bodies, a slider and a detent plunger. \n\nThe detent \
mechanism goes through seven distinct stages of operation as the detenter \
passes across the slider, down into the detent notch, and back out. These \
stages are progressively activated via the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"    In stage 1 the detenter travels across the right top surface of the \
slider.\n    In stage 2 the detenter travels around the corner that leads \
into the detent notch.\n    In stage 3 the detenter travels down the inclined \
right side of the detent notch.\n    In stage 4 the detenter travels around \
the round bottom of the detent notch.\n    In stage 5 the detenter travels up \
the inclined left side of the detent notch.\n    In stage 6 the detenter \
travels around the corner that leads out of the detent notch.\n    In stage 7 \
the detenter travels across the left top surface of the slider."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the 2D detent model graphic. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
 
 
 
 
  
%%Creator: Mathematica
 
 
 
 
 
  
%%AspectRatio: .5  
 
 
 
 
 
  
MathPictureStart
 
 
 
 
 
  
%% Graphics
 
 
 
 
 
  
/Courier findfont 10  scalefont  setfont
 
 
 
 
 
  
% Scaling calculations
 
 
 
 
 
  
0.25 0.125 0.0625 0.125 [
 
 
 
 
 
  
[(-1)] .125  0 0 2 Msboxa
 
 
 
 
 
  
[(0)] .25  0 0 2 Msboxa
 
 
 
 
 
  
[(1)] .375  0 0 2 Msboxa
 
 
 
 
 
  
[(2)] .5  0 0 2 Msboxa
 
 
 
 
 
  
[(3)] .625  0 0 2 Msboxa
 
 
 
 
 
  
[(4)] .75  0 0 2 Msboxa
 
 
 
 
 
  
[(5)] .875  0 0 2 Msboxa
 
 
 
 
 
  
[(6)] 1 0 0 2 Msboxa
 
 
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Msboxa
 
 
 
 
 
  
[(0)] -0.0125 .0625  1 0 Msboxa
 
 
 
 
 
  
[(0.5)] -0.0125 .125  1 0 Msboxa
 
 
 
 
 
  
[(1)] -0.0125 .1875  1 0 Msboxa
 
 
 
 
 
  
[(1.5)] -0.0125 .25  1 0 Msboxa
 
 
 
 
 
  
[(2)] -0.0125 .3125  1 0 Msboxa
 
 
 
 
 
  
[(2.5)] -0.0125 .375  1 0 Msboxa
 
 
 
 
 
  
[(3)] -0.0125 .4375  1 0 Msboxa
 
 
 
 
 
  
[(3.5)] -0.0125 .5  1 0 Msboxa
 
 
 
 
 
  
[ -0.001 -0.001 0 0 ]
 
 
 
 
 
  
[ 1.001 .501  0 0 ]
 
 
 
 
 
  
] MathScale
 
 
 
 
 
  
% Start of Graphics
 
 
 
 
 
  
1 setlinecap
 
 
 
 
 
  
1 setlinejoin
 
 
 
 
 
  
newpath
 
 
 
 
 
  
[ ] 0 setdash
 
 
 
 
 
  
0 g
 
 
 
 
 
  
p
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.125  0 m
 
 
 
 
 
  
.125  .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(-1)] .125  0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.25  0 m
 
 
 
 
 
  
.25  .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(0)] .25  0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.375  0 m
 
 
 
 
 
  
.375  .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(1)] .375  0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.5  0 m
 
 
 
 
 
  
.5  .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(2)] .5  0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.625  0 m
 
 
 
 
 
  
.625  .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(3)] .625  0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.75  0 m
 
 
 
 
 
  
.75  .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(4)] .75  0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.875  0 m
 
 
 
 
 
  
.875  .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(5)] .875  0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
1 0 m
 
 
 
 
 
  
1 .00625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(6)] 1 0 0 2 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.025  0 m
 
 
 
 
 
  
.025  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.05  0 m
 
 
 
 
 
  
.05  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.075  0 m
 
 
 
 
 
  
.075  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.1  0 m
 
 
 
 
 
  
.1  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.15  0 m
 
 
 
 
 
  
.15  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.175  0 m
 
 
 
 
 
  
.175  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.2  0 m
 
 
 
 
 
  
.2  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.225  0 m
 
 
 
 
 
  
.225  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.275  0 m
 
 
 
 
 
  
.275  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.3  0 m
 
 
 
 
 
  
.3  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.325  0 m
 
 
 
 
 
  
.325  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.35  0 m
 
 
 
 
 
  
.35  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.4  0 m
 
 
 
 
 
  
.4  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.425  0 m
 
 
 
 
 
  
.425  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.45  0 m
 
 
 
 
 
  
.45  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.475  0 m
 
 
 
 
 
  
.475  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.525  0 m
 
 
 
 
 
  
.525  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.55  0 m
 
 
 
 
 
  
.55  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.575  0 m
 
 
 
 
 
  
.575  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.6  0 m
 
 
 
 
 
  
.6  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.65  0 m
 
 
 
 
 
  
.65  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.675  0 m
 
 
 
 
 
  
.675  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.7  0 m
 
 
 
 
 
  
.7  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.725  0 m
 
 
 
 
 
  
.725  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.775  0 m
 
 
 
 
 
  
.775  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.8  0 m
 
 
 
 
 
  
.8  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.825  0 m
 
 
 
 
 
  
.825  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.85  0 m
 
 
 
 
 
  
.85  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.9  0 m
 
 
 
 
 
  
.9  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.925  0 m
 
 
 
 
 
  
.925  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.95  0 m
 
 
 
 
 
  
.95  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.975  0 m
 
 
 
 
 
  
.975  .00375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 0 m
 
 
 
 
 
  
1 0 L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 0 m
 
 
 
 
 
  
.00625  0 L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(-0.5)] -0.0125 0 1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .0625  m
 
 
 
 
 
  
.00625  .0625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(0)] -0.0125 .0625  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .125  m
 
 
 
 
 
  
.00625  .125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(0.5)] -0.0125 .125  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .1875  m
 
 
 
 
 
  
.00625  .1875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(1)] -0.0125 .1875  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .25  m
 
 
 
 
 
  
.00625  .25  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(1.5)] -0.0125 .25  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .3125  m
 
 
 
 
 
  
.00625  .3125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(2)] -0.0125 .3125  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .375  m
 
 
 
 
 
  
.00625  .375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(2.5)] -0.0125 .375  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .4375  m
 
 
 
 
 
  
.00625  .4375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(3)] -0.0125 .4375  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .5  m
 
 
 
 
 
  
.00625  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
[(3.5)] -0.0125 .5  1 0 Mshowa
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .0125  m
 
 
 
 
 
  
.00375  .0125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .025  m
 
 
 
 
 
  
.00375  .025  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .0375  m
 
 
 
 
 
  
.00375  .0375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .05  m
 
 
 
 
 
  
.00375  .05  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .075  m
 
 
 
 
 
  
.00375  .075  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .0875  m
 
 
 
 
 
  
.00375  .0875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .1  m
 
 
 
 
 
  
.00375  .1  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .1125  m
 
 
 
 
 
  
.00375  .1125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .1375  m
 
 
 
 
 
  
.00375  .1375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .15  m
 
 
 
 
 
  
.00375  .15  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .1625  m
 
 
 
 
 
  
.00375  .1625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .175  m
 
 
 
 
 
  
.00375  .175  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .2  m
 
 
 
 
 
  
.00375  .2  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .2125  m
 
 
 
 
 
  
.00375  .2125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .225  m
 
 
 
 
 
  
.00375  .225  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .2375  m
 
 
 
 
 
  
.00375  .2375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .2625  m
 
 
 
 
 
  
.00375  .2625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .275  m
 
 
 
 
 
  
.00375  .275  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .2875  m
 
 
 
 
 
  
.00375  .2875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .3  m
 
 
 
 
 
  
.00375  .3  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .325  m
 
 
 
 
 
  
.00375  .325  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .3375  m
 
 
 
 
 
  
.00375  .3375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .35  m
 
 
 
 
 
  
.00375  .35  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .3625  m
 
 
 
 
 
  
.00375  .3625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .3875  m
 
 
 
 
 
  
.00375  .3875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .4  m
 
 
 
 
 
  
.00375  .4  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .4125  m
 
 
 
 
 
  
.00375  .4125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .425  m
 
 
 
 
 
  
.00375  .425  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .45  m
 
 
 
 
 
  
.00375  .45  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .4625  m
 
 
 
 
 
  
.00375  .4625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .475  m
 
 
 
 
 
  
.00375  .475  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
0 .4875  m
 
 
 
 
 
  
.00375  .4875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 0 m
 
 
 
 
 
  
0 .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .49375  m
 
 
 
 
 
  
0 .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.125  .49375  m
 
 
 
 
 
  
.125  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.25  .49375  m
 
 
 
 
 
  
.25  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.375  .49375  m
 
 
 
 
 
  
.375  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.5  .49375  m
 
 
 
 
 
  
.5  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.625  .49375  m
 
 
 
 
 
  
.625  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.75  .49375  m
 
 
 
 
 
  
.75  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.875  .49375  m
 
 
 
 
 
  
.875  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.025  .49625  m
 
 
 
 
 
  
.025  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.05  .49625  m
 
 
 
 
 
  
.05  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.075  .49625  m
 
 
 
 
 
  
.075  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.1  .49625  m
 
 
 
 
 
  
.1  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.15  .49625  m
 
 
 
 
 
  
.15  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.175  .49625  m
 
 
 
 
 
  
.175  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.2  .49625  m
 
 
 
 
 
  
.2  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.225  .49625  m
 
 
 
 
 
  
.225  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.275  .49625  m
 
 
 
 
 
  
.275  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.3  .49625  m
 
 
 
 
 
  
.3  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.325  .49625  m
 
 
 
 
 
  
.325  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.35  .49625  m
 
 
 
 
 
  
.35  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.4  .49625  m
 
 
 
 
 
  
.4  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.425  .49625  m
 
 
 
 
 
  
.425  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.45  .49625  m
 
 
 
 
 
  
.45  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.475  .49625  m
 
 
 
 
 
  
.475  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.525  .49625  m
 
 
 
 
 
  
.525  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.55  .49625  m
 
 
 
 
 
  
.55  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.575  .49625  m
 
 
 
 
 
  
.575  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.6  .49625  m
 
 
 
 
 
  
.6  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.65  .49625  m
 
 
 
 
 
  
.65  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.675  .49625  m
 
 
 
 
 
  
.675  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.7  .49625  m
 
 
 
 
 
  
.7  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.725  .49625  m
 
 
 
 
 
  
.725  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.775  .49625  m
 
 
 
 
 
  
.775  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.8  .49625  m
 
 
 
 
 
  
.8  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.825  .49625  m
 
 
 
 
 
  
.825  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.85  .49625  m
 
 
 
 
 
  
.85  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.9  .49625  m
 
 
 
 
 
  
.9  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.925  .49625  m
 
 
 
 
 
  
.925  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.95  .49625  m
 
 
 
 
 
  
.95  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.975  .49625  m
 
 
 
 
 
  
.975  .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
0 .5  m
 
 
 
 
 
  
1 .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  0 m
 
 
 
 
 
  
1 0 L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  .0625  m
 
 
 
 
 
  
1 .0625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  .125  m
 
 
 
 
 
  
1 .125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  .1875  m
 
 
 
 
 
  
1 .1875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  .25  m
 
 
 
 
 
  
1 .25  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  .3125  m
 
 
 
 
 
  
1 .3125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  .375  m
 
 
 
 
 
  
1 .375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
.99375  .4375  m
 
 
 
 
 
  
1 .4375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .0125  m
 
 
 
 
 
  
1 .0125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .025  m
 
 
 
 
 
  
1 .025  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .0375  m
 
 
 
 
 
  
1 .0375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .05  m
 
 
 
 
 
  
1 .05  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .075  m
 
 
 
 
 
  
1 .075  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .0875  m
 
 
 
 
 
  
1 .0875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .1  m
 
 
 
 
 
  
1 .1  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .1125  m
 
 
 
 
 
  
1 .1125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .1375  m
 
 
 
 
 
  
1 .1375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .15  m
 
 
 
 
 
  
1 .15  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .1625  m
 
 
 
 
 
  
1 .1625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .175  m
 
 
 
 
 
  
1 .175  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .2  m
 
 
 
 
 
  
1 .2  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .2125  m
 
 
 
 
 
  
1 .2125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .225  m
 
 
 
 
 
  
1 .225  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .2375  m
 
 
 
 
 
  
1 .2375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .2625  m
 
 
 
 
 
  
1 .2625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .275  m
 
 
 
 
 
  
1 .275  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .2875  m
 
 
 
 
 
  
1 .2875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .3  m
 
 
 
 
 
  
1 .3  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .325  m
 
 
 
 
 
  
1 .325  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .3375  m
 
 
 
 
 
  
1 .3375  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .35  m
 
 
 
 
 
  
1 .35  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .3625  m
 
 
 
 
 
  
1 .3625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .3875  m
 
 
 
 
 
  
1 .3875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .4  m
 
 
 
 
 
  
1 .4  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .4125  m
 
 
 
 
 
  
1 .4125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .425  m
 
 
 
 
 
  
1 .425  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .45  m
 
 
 
 
 
  
1 .45  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .4625  m
 
 
 
 
 
  
1 .4625  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .475  m
 
 
 
 
 
  
1 .475  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.001  w
 
 
 
 
 
  
.99625  .4875  m
 
 
 
 
 
  
1 .4875  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
.002  w
 
 
 
 
 
  
1 0 m
 
 
 
 
 
  
1 .5  L
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
P
 
 
 
 
 
  
0 0 m
 
 
 
 
 
  
1 0 L
 
 
 
 
 
  
1 .5  L
 
 
 
 
 
  
0 .5  L
 
 
 
 
 
  
closepath
 
 
 
 
 
  
clip
 
 
 
 
 
  
newpath
 
 
 
 
 
  
p
 
 
 
 
 
  
p
 
 
 
 
 
  
.25  .05  m
 
 
 
 
 
  
.75  .05  L
 
 
 
 
 
  
.75  0 L
 
 
 
 
 
  
.25  0 L
 
 
 
 
 
  
F
 
 
 
 
 
  
.25  .2  m
 
 
 
 
 
  
.4625  .2  L
 
 
 
 
 
  
.4625  .25  L
 
 
 
 
 
  
.25  .25  L
 
 
 
 
 
  
F
 
 
 
 
 
  
.5375  .2  m
 
 
 
 
 
  
.75  .2  L
 
 
 
 
 
  
.75  .25  L
 
 
 
 
 
  
.5375  .25  L
 
 
 
 
 
  
F
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
1 0 0 r
 
 
 
 
 
  
.004  w
 
 
 
 
 
  
.3625  .125  m
 
 
 
 
 
  
.3  .1875  L
 
 
 
 
 
  
.175  .1875  L
 
 
 
 
 
  
.175  .0625  L
 
 
 
 
 
  
.675  .0625  L
 
 
 
 
 
  
.675  .1875  L
 
 
 
 
 
  
.55  .1875  L
 
 
 
 
 
  
.4875  .125  L
 
 
 
 
 
  
s
 
 
 
 
 
  
newpath
 
 
 
 
 
  
.425  .1875  .08839  -135 -45 arc
 
 
 
 
 
  
s
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
0 0 1 r
 
 
 
 
 
  
.4625  .44053  m
 
 
 
 
 
  
.5375  .44053  L
 
 
 
 
 
  
.5375  .19053  L
 
 
 
 
 
  
.4625  .19053  L
 
 
 
 
 
  
F
 
 
 
 
 
  
.004  w
 
 
 
 
 
  
.5  .19053  m
 
 
 
 
 
  
.5  .19053  .0375  0 365.73 arc
 
 
 
 
 
  
F
 
 
 
 
 
  
P
 
 
 
 
 
  
p
 
 
 
 
 
  
p
 
 
 
 
 
  
.008  w
 
 
 
 
 
  
.425  .1875  Mdot
 
 
 
 
 
  
P
 
 
 
 
 
  
P
 
 
 
 
 
  
P
 
 
 
 
 
  
% End of Graphics
 
 
 
 
 
  
MathPictureEnd
 
 
 
 
 
  
 
 
 
 
  
 
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{447, 224},
  ImageMargins->{{18, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006o0000h1000`40O003h00Oogoo`7oo003oOoo0
Ool00?mool1oo`00ogoo`7oo001DOol5000]Ool00`00Oomoo`0/Ool5000^Ool3000_Ool2000aOol3
000^Ool00`00Oomoo`0^Ool2000>Ool005Ioo`03001oogoo02aoo`03001oo`0002moo`03001oogoo
02ioo`03001oogoo035oo`03001oogoo02moo`03001oogoo02aoo`03001oo`0002moo`03001oo`00
00eoo`00D7oo0`000goo00<007ooOol0;7oo00<007oo0000;goo00<007ooOol0;goo00<007ooOol0
;goo00<007ooOol0;Woo1000;goo00<007ooOol0;Goo00<007oo00003Goo001FOol00`00Oomoo`0/
Ool00`00Ool0000_Ool00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Ool0000^
Ool2000`Ool2000>Ool005Ioo`03001oogoo02aoo`03001oo`0002moo`03001oogoo02ioo`03001o
o`0002moo`03001oo`00031oo`8002ioo`03001oogoo02moo`03001oogoo00eoo`00EGoo0P00;goo
00<007ooOol0;Goo0P00<Goo00<007ooOol0;goo00<007ooOol0<7oo00<007ooOol0;7oo0`00<7oo
0P003Goo003oOoo0Ool00?mool1oo`00ogoo`7oo003oOoo0Ool00?mool1oo`00ogoo`7oo000AOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3oOonROol0011oo`03001oo`0000Moo`03001o
o`000?mooj=oo`002goo0`000Woo00<007oo00002Goo00<007ooOol017ooo`00T0003Goo000@Ool0
0`00Ool00007Ool20007Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Oomoo`07Ooo80009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`0;Ool0011oo`03001oo`0000Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00MoolP000Uoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00]oo`00
4Goo00<007ooOol01Woo0`001Woo00<007ooOol0;Woo00<007ooOol0;goob000<Goo00<007ooOol0
;goo00<007ooOol02goo000SOol00`00Oomoo`1POoo7001TOol00`00Oomoo`0;Ool002=oo`80065o
olL0069oo`<000eoo`008goo00<007ooOol0H7ooa`00I7oo00<007ooOol02goo000SOol00`00Oomo
o`1POoo7001TOol00`00Oomoo`0;Ool002=oo`03001oogoo061oolL006Aoo`03001oogoo00]oo`00
8goo00<007ooOol0H7ooa`00I7oo00<007ooOol02goo000SOol2001QOoo7001ROol3000=Ool002=o
o`03001oogoo061oolL006Aoo`03001oogoo00]oo`008goo00<007ooOol0H7ooa`00I7oo00<007oo
Ool02goo000SOol00`00Oomoo`1POoo7001TOol00`00Oomoo`0;Ool002=oo`03001oogoo061oolL0
06Aoo`03001oogoo00]oo`008goo0P00HGooa`00HWoo0`003Goo000SOol00`00Oomoo`1POoo7001T
Ool00`00Oomoo`0;Ool002=oo`03001oogoo061oolL006Aoo`03001oogoo00]oo`008goo00<007oo
Ool0H7ooa`00I7oo00<007ooOol02goo000SOol00`00Oomoo`1POoo7001TOol00`00Oomoo`0;Ool0
02=oo`80065oolL0069oo`<000eoo`008goo00<007ooOol0ogooS7oo00<007ooOol02goo000SOol0
0`00Oomoo`3oOon<Ool00`00Oomoo`0;Ool001]oo`03001oogoo00Eoo`03001oogoo0?moohaoo`03
001oogoo00]oo`006Woo00<007oo00001Woo00<007ooOol0ogooS7oo00<007ooOol02goo000JOol0
0`00Ool00006Ool30012Ooo8O01nOol4000=Ool001Yoo`03001oo`0000Ioo`03001oogoo049oo`03
O01oogoo0<Aoo`03O01oogoo07moo`03001oogoo00]oo`006Woo00<007oo00001Woo00<007ooOol0
@Woo00=l07ooOol0a7oo00=l07ooOol0Ogoo00<007ooOol02goo000KOol00`00Oomoo`05Ool00`00
Oomoo`12Ool00g`0Oomoo`34Ool00g`0Oomoo`1oOol00`00Oomoo`0;Ool002=oo`03001oogoo049o
o`03O01oogoo0<Aoo`03O01oogoo07moo`03001oogoo00]oo`008goo0P00@goo00=l07ooOol0a7oo
00=l07ooOol0OGoo0`003Goo000SOol00`00Oomoo`12Ool00g`0Oomoo`34Ool00g`0Oomoo`1oOol0
0`00Oomoo`0;Ool002=oo`03001oogoo049oo`03O01oogoo0<Aoo`03O01oogoo07moo`03001oogoo
00]oo`008goo00<007ooOol0@Woo00=l07ooOol0a7oo00=l07ooOol0Ogoo00<007ooOol02goo000S
Ool00`00Oomoo`12Ool00g`0Oomoo`34Ool00g`0Oomoo`1oOol00`00Oomoo`0;Ool002=oo`8004=o
o`03O01oogoo0<Aoo`03O01oogoo07eoo`<000eoo`008goo00<007ooOol0@Woo00=l07ooOol0a7oo
00=l07ooOol0Ogoo00<007ooOol02goo000SOol00`00Oomoo`12Ool00g`0Oomoo`34Ool00g`0Oomo
o`1oOol00`00Oomoo`0;Ool002=oo`03001oogoo049oo`03O01oogoo0<Aoo`03O01oogoo07moo`03
001oogoo00]oo`008goo00<007ooOol0@Woo00=l07ooOol0a7oo00=l07ooOol0Ogoo00<007ooOol0
2goo000SOol20013Ool00g`0Oomoo`1LOol;O01MOol00g`0Oomoo`1mOol3000=Ool002=oo`03001o
ogoo049oo`03O01oogoo05Moo`El00]oo`El05Qoo`03O01oogoo07moo`03001oogoo00]oo`008goo
00<007ooOol0@Woo00=l07ooOol0EGoo0W`05Goo0W`0EWoo00=l07ooOol0Ogoo00<007ooOol02goo
000SOol00`00Oomoo`12Ool00g`0Oomoo`1BOol3O00IOol3O01COol00g`0Oomoo`1oOol00`00Oomo
o`0;Ool002=oo`03001oogoo049oo`03O01oogoo051oo`9l01moo`03O01oogoo051oo`03O01oogoo
07moo`03001oogoo00]oo`008goo0P00@goo00=l07ooOol0CWoo0W`08Woo0W`0D7oo00=l07ooOol0
OGoo0`003Goo000SOol00`00Oomoo`12Ool00g`0Oomoo`1=Ool00g`0Oomoo`0TOol00g`0Oomoo`1=
Ool00g`0Oomoo`1oOol00`00Oomoo`0;Ool002=oo`03001oogoo049oo`03O01oogoo04aoo`03O01o
ogoo02Ioo`9l04eoo`03O01oogoo07moo`03001oogoo00]oo`004Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol01Goo00<007ooOol0@Woo00=l07ooOol0Bgoo00=l07ooOol0:Goo00=l07oo
Ool0BWoo00=l07ooOol0Ogoo00<007ooOol02goo000@Ool00`00Ool00007Ool00`00Ool00006Ool0
0`00Oomoo`12Ool00g`0Oomoo`19Ool2O00]Ool2O01:Ool00g`0Oomoo`1oOol00`00Oomoo`0;Ool0
011oo`03001oo`0000Uoo`03001oogoo00Aoo`<0049oo`03O01oogoo04Qoo`03O01oogoo02moo`03
O01oogoo04Moo`03O01oogoo07aoo`@000eoo`0047oo00<007oo00001goo0P001goo00<007ooOol0
@Woo00=l07ooOol0Agoo00=l07ooOol0<Goo00=l07ooOol0AWoo00=l07ooOol0Ogoo00<007ooOol0
2goo000@Ool00`00Ool00007Ool00`00Oomoo`06Ool00`00Oomoo`12Ool00g`0Oomoo`16Ool00g`0
Oomoo`0cOol00g`0Oomoo`15Ool00g`0Oomoo`1oOol00`00Oomoo`0;Ool0015oo`03001oogoo00Io
o`<000Ioo`03001oogoo049oo`03O01oogoo04Eoo`03O01oogoo03Eoo`03O01oogoo04Aoo`03O01o
ogoo07moo`03001oogoo00]oo`008goo00<007ooOol0@Woo00=l07ooOol0A7oo00=l07ooOol0=goo
00=l07ooOol0@goo00=l07ooOol0Ogoo00<007ooOol02goo000SOol20013Ool00g`0Oomoo`13Ool0
0g`0Oomoo`0iOol00g`0Oomoo`12Ool00g`0Oomoo`1mOol3000=Ool002=oo`03001oogoo049oo`03
O01oogoo049oo`03O01oogoo03]oo`03O01oogoo045oo`03O01oogoo07moo`03001oogoo00]oo`00
8goo00<007ooOol0@Woo00=l07ooOol0@Goo00=l07ooOol0?Goo00=l07ooOol0@7oo00=l07ooOol0
Ogoo00<007ooOol02goo000SOol00`00Oomoo`12Ool00g`0Oomoo`10Ool00g`0Oomoo`0oOol00g`0
Oomoo`0oOol00g`0Oomoo`1oOol00`00Oomoo`0;Ool002=oo`03001oogoo049oo`03O01oogoo03mo
o`03O01oogoo045oo`03O01oogoo03ioo`03O01oogoo07moo`03001oogoo00]oo`008goo0P00@goo
00=l07ooOol0?Woo00=l07ooOol0@goo00=l07ooOol0?Goo00=l07ooOol0OGoo0`003Goo000SOol0
0`00Oomoo`12Ool00g`0Oomoo`0mOol00g`0Oomoo`15Ool00g`0Oomoo`0lOol00g`0Oomoo`1oOol0
0`00Oomoo`0;Ool002=oo`03001oogoo049oo`03O01oogoo03aoo`03O01oogoo03ioo`H07`=oo`03
O01oogoo03]oo`03O01oogoo07moo`03001oogoo00]oo`008goo00<007ooOol0@Woo00=l07ooOol0
>goo00=l07ooOol0>Goo3`0O00=oog`0Ool0>goo00=l07ooOol0Ogoo00<007ooOol02goo000SOol0
0`00Oomoo`12Ool00g`0Oomoo`0jOol00g`0Oomoo`0iOolA01l00gooO01oo`0jOol00g`0Oomoo`1o
Ool00`00Oomoo`0;Ool002=oo`8004=oo`03O01oogoo03Uoo`03O01oogoo03Uooa<07`03Ooml07oo
03Uoo`03O01oogoo07eoo`<000eoo`008goo00<007ooOol0@Woo00=l07ooOol0>7oo00=l07ooOol0
>Goo5@0O00=oog`0Ool0>7oo00=l07ooOol0Ogoo00<007ooOol02goo000SOol00`00Oomoo`12Ool0
0g`0Oomoo`0gOol00g`0Oomoo`0iOolG01l00gooO01oo`0gOol00g`0Oomoo`1oOol00`00Oomoo`0;
Ool002=oo`03001oogoo049oo`03O01oogoo03Ioo`03O01oogoo03YooaP07`03Ooml07oo03Ioo`03
O01oogoo07moo`03001oogoo00]oo`008goo00<007ooOol0@Woo00=l07ooOol0=Goo00=l07ooOol0
>Woo6P0O00=oog`0Ool0=Goo00=l07ooOol0Ogoo00<007ooOol02goo000SOol20013Ool00g`0Oomo
o`0dOol00g`0Oomoo`0jOolL01l00gooO01oo`0dOol00g`0Oomoo`1mOol3000=Ool002=oo`03001o
ogoo049oo`03O01oogoo03=oo`03O01oogoo03]ooa`07`9oo`03O01oogoo039oo`03O01oogoo07mo
o`03001oogoo00]oo`008goo00<007ooOol0@Woo00=l07ooOol0<Woo00=l07ooOol0?7oo700O0goo
00=l07ooOol0<Goo00=l07ooOol0Ogoo00<007ooOol02goo000IOol50005Ool00`00Oomoo`12Ool0
0g`0Oomoo`0aOol00g`0Oomoo`0lOolN01l3Ool00g`0Oomoo`0`Ool00g`0Oomoo`1oOol00`00Oomo
o`0;Ool001]oo`03001oogoo00Eoo`03001oogoo049oo`03O01oogoo031oo`03O01oogoo03eooah0
7`Aoo`03O01oogoo02moo`03O01oogoo07moo`03001oogoo00]oo`006goo00<007ooOol01Goo0`00
@Woo<g`0@7oo7P0O1Goo<W`0OWoo10003Goo000KOol00`00Oomoo`05Ool00`00Oomoo`2eOolN01nh
Ool00`00Oomoo`0;Ool001]oo`03001oogoo00Eoo`03001oogoo0;Eooah07kQoo`03001oogoo00]o
o`006Woo0P001goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol00`00Oomoo`2eOolN
01nhOol00`00Oomoo`0;Ool002=oo`800;Iooah07kIoo`<000eoo`008goo00<007ooOol0H7ooE@00
7P0OE000I7oo00<007ooOol02goo000SOol00`00Oomoo`1POomE000N01mD001TOol00`00Oomoo`0;
Ool002=oo`03001oogoo061ooeD001h07e@006Aoo`03001oogoo00]oo`008goo00<007ooOol0H7oo
E@007P0OE000I7oo00<007ooOol02goo000SOol2001QOomE000N01mD001ROol3000=Ool002=oo`03
001oogoo061ooeD001h07e@006Aoo`03001oogoo00]oo`008goo00<007ooOol0H7ooE@007P0OE000
I7oo00<007ooOol02goo000SOol00`00Oomoo`1POomE000N01mD001TOol00`00Oomoo`0;Ool002=o
o`03001oogoo061ooeD001h07e@006Aoo`03001oogoo00]oo`008goo0P00HGooE@007P0OE000HWoo
0`003Goo000SOol00`00Oomoo`1POomE000N01mD001TOol00`00Oomoo`0;Ool002=oo`03001oogoo
061ooeD001h07e@006Aoo`03001oogoo00]oo`008goo00<007ooOol0H7ooE@007P0OE000I7oo00<0
07ooOol02goo000SOol00`00Oomoo`1POomE000N01mD001TOol00`00Oomoo`0;Ool002=oo`80065o
oeD001h07e@0069oo`<000eoo`008goo00<007ooOol0H7ooE@007P0OE000I7oo00<007ooOol02goo
000SOol00`00Oomoo`1POomE000N01mD001TOol00`00Oomoo`0;Ool000moo`D0009oo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo061ooeD001h07e@006Aoo`03001oogoo00]oo`004Goo00<0
07ooOol01Woo00<007oo00001Woo00<007ooOol0H7ooE@007P0OE000I7oo00<007ooOol02goo000A
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool3001POomE000N01mD001QOol4000=Ool0015oo`03001o
ogoo00Ioo`8000Moo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`004Goo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000@Ool20008Ool30006Ool0
0`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo
00]oo`008goo0P00]Woo7P0O]Woo0`003Goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;
Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo00<007ooOol0]Goo7P0O^7oo
00<007ooOol02goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`800;Iooah0
7kIoo`<000eoo`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol00`00Oomoo`2e
OolN01nhOol00`00Oomoo`0;Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo
00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol2002fOolN01nfOol3000=Ool002=oo`03
001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol0
2goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`03001oogoo0;Eooah07kQo
o`03001oogoo00]oo`008goo0P00]Woo7P0O]Woo0`003Goo000SOol00`00Oomoo`2eOolN01nhOol0
0`00Oomoo`0;Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`006Woo0`001Woo00<0
07ooOol0]Goo7P0O^7oo00<007ooOol02goo000JOol00`00Oomoo`06Ool00`00Oomoo`2eOolN01nh
Ool00`00Oomoo`0;Ool001]oo`03001oogoo00Eoo`<00;Eooah07kEoo`@000eoo`006goo00<007oo
Ool01Goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000JOol00`00Ool00006Ool00`00Oomo
o`2eOolN01nhOol00`00Oomoo`0;Ool001]oo`03001oogoo00Eoo`03001oogoo0;Eooah07kQoo`03
001oogoo00]oo`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol2002fOolN01nf
Ool3000=Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo00<007ooOol0]Goo
7P0O^7oo00<007ooOol02goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`03
001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo0P00]Woo7P0O]Woo0`003Goo000SOol00`00
Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]o
o`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol00`00Oomoo`2eOolN01nhOol0
0`00Oomoo`0;Ool002=oo`800;Iooah07kIoo`<000eoo`008goo00<007ooOol0]Goo7P0O^7oo00<0
07ooOol02goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`03001oogoo0;Eo
oah07kQoo`03001oogoo00]oo`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol2
002fOolN01nfOol3000=Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo00<0
07ooOol0]Goo7P0O^7oo00<007ooOol02goo000@Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool0011oo`03001oogoo00Moo`03001oo`0000Io
o`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`004Goo00<007ooOol027oo00<007ooOol017oo
0`00]Goo7P0O]Goo10003Goo000AOol00`00Oomoo`06Ool20007Ool00`00Oomoo`2eOolN01nhOol0
0`00Oomoo`0;Ool0011oo`03001oo`0000Moo`03001oogoo00Ioo`03001oogoo0;Eooah07kQoo`03
001oogoo00]oo`004Goo00<007ooOol01Woo0`001Woo00<007ooOol0]Goo7P0O^7oo00<007ooOol0
2goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`800;Iooah07kIoo`<000eo
o`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol00`00Oomoo`2eOolN01nhOol0
0`00Oomoo`0;Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo00<007ooOol0
]Goo7P0O^7oo00<007ooOol02goo000SOol2002fOolN01nfOol3000=Ool002=oo`03001oogoo0;Eo
oah07kQoo`03001oogoo00]oo`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol0
0`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo
00]oo`008goo0P00]Woo7P0O]Woo0`003Goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;
Ool002=oo`03001oogoo0;Eooah07kQoo`03001oogoo00]oo`008goo00<007ooOol0]Goo7P0O^7oo
00<007ooOol02goo000SOol00`00Oomoo`2eOolN01nhOol00`00Oomoo`0;Ool002=oo`800;Iooah0
7kIoo`<000eoo`008goo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000SOol00`00Oomoo`2e
OolN01nhOol00`00Oomoo`0;Ool001Yoo`8000Moo`03001oogoo0;Eooah07kQoo`03001oogoo00]o
o`0077oo00<007ooOol017oo00<007ooOol0]Goo7P0O^7oo00<007ooOol02goo000KOol00`00Oomo
o`05Ool3002eOolN01neOol4000=Ool001aoo`03001oogoo00Aoo`03001oogoo0;Eooah07kQoo`03
001oogoo00]oo`006Woo00<007oo00001Woo00<007ooOol0ogooS7oo00<007ooOol02goo000KOol0
0`00Oomoo`05Ool00`00Oomoo`3oOon<Ool00`00Oomoo`0;Ool002=oo`03001oogoo0?moohaoo`03
001oogoo00]oo`008goo0P00ogooRgoo0`003Goo000SOol00`00Oomoo`3oOon<Ool00`00Oomoo`0;
Ool002=oo`03001oogoo0?moohaoo`03001oogoo00]oo`008goo00<007ooOol0ogooS7oo00<007oo
Ool02goo000SOol00`00Oomoo`3oOon<Ool00`00Oomoo`0;Ool002=oo`800?mooh]oo`<000eoo`00
8goo00<007ooOol0ogooS7oo00<007ooOol02goo000SOol00`00Oomoo`3oOon<Ool00`00Oomoo`0;
Ool002=oo`03001oogoo0?moohaoo`03001oogoo00]oo`008goo00<007ooOol0ogooS7oo00<007oo
Ool02goo000SOol2003oOon;Ool3000=Ool002=oo`03001oogoo0?moohaoo`03001oogoo00]oo`00
8goo00<007ooOol0ogooS7oo00<007ooOol02goo000SOol00`00Oomoo`3oOon<Ool00`00Oomoo`0;
Ool002=oo`03001oogoo0?moohaoo`03001oogoo00]oo`008goo0P00ogooRgoo0`003Goo000SOol0
0`00Oomoo`3oOon<Ool00`00Oomoo`0;Ool0011oo`8000Aoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo02ioo`03001oogoo02moo`03001oogoo02moo`03001oogoo02moo`03001oogoo02io
o`03001oogoo02moo`03001oogoo02moo`03001oogoo02moo`03001oogoo00]oo`004Woo00<007oo
Ool01Goo00<007oo00001Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol02goo000AOol00`00Oomoo`08Ool00`00Oomoo`04Oooo
002@000=Ool0019oo`03001oogoo00Eoo`800?moojAoo`0047oo00<007oo00001goo00<007ooOol0
ogooXgoo000AOol00`00Oomoo`06Ool3003oOonSOol00?mool1oo`00ogoo`7oo003oOoo0Ool00001
\
\>"],
  ImageRangeCache->{{{0, 446}, {223, 0}} -> {-2.70834, -0.861833, 0.0201007, 
  0.0201007}}]
}, Open  ]],

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three body objects are defined for the detent mechanism model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four points are defined on the ground body (body 1).\nP1 and P2 are two \
points that define the horizontal line on which the slider translates.\nP3 \
and P4 are two points that define the vertical line on which the detenter \
translates."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Nine points are defined on the slider (body 2).\nP1 and P2 are two points \
that define the horizontal translation line of the slider.\nP3 to P8 are a \
series of points defining the detent notch in the top surface of the slider.\n\
P9 is the center point of the circular bottom of the detent notch."], 
  "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two points are defined on the detenter (body 3).\nP1 and P2 are two points \
defining the vertical translation axis of the detenter."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names for each body number in the model are defined."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(slider = 2; \)\), 
    \(\(detenter = 3; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[ground] = Body[ground, PointList\[Rule]{\n  (*P1*) {0 ,0 },\n  (*P2*) {4 \
,0 },\n  (*P3*) {2 ,2 },\n  (*P4*) {2 ,3 }} ];"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[slider] = Body[slider, PointList\[Rule]{\n  (*P1*) {0  ,0  },\n  (*P2*) \
{4  ,0  },\n  (*P3*) {0  ,1  },\n  (*P4*) {1  ,1  },\n  (*P5*) {1.5,0.5},\n  \
(*P6*) {2.5,0.5},\n  (*P7*) {3  ,1  },\n  (*P8*) {4  ,1  },\n  (*P9*) {2  ,1  \
}} ];"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[detenter] = Body[detenter, PointList\[Rule]{\n  (*P1*) {0  ,0  },\n  \
(*P2*) {0  ,2  }},\n  InitialGuess\[Rule]{{2.0,1.3},0} ];"], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are all three bodies in the detent mechanism model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.98649 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0472973 0.952381 [
[ -0.001 -0.001 0 0 ]
[ 1.001 1.98749 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 1.98649 L
s
P
P
p
p
.002 w
0 1.98649 m
1 1.98649 L
s
P
p
.002 w
1 0 m
1 1.98649 L
s
P
P
p
P
0 0 m
1 0 L
1 1.98649 L
0 1.98649 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0472973 0.97619 0.677928 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.22973 0.135135 0.162162 0.135135 [
[ 0 0 0 0 ]
[ 1 .66216 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .66216 L
0 .66216 L
closepath
clip
newpath
p
p
p
.4 .4 1 r
.54054 .60811 m
.45946 .60811 L
.45946 .33784 L
.54054 .33784 L
F
.004 w
.5 .33784 m
.5 .33784 .04054 0 365.73 arc
F
P
p
.004 w
.5 .33784 m
.5 .54054 L
s
.47133 .3665 m
.5 .33784 L
.52867 .3665 L
s
P
p
p
.02 w
.5 .33784 Mdot
.5 .60811 Mdot
P
P
P
p
[({0,0})] .5 .33784 -1.9 0 Mshowa
[(P1)] .5 .33784 3.2 0 Mshowa
[({0,2})] .5 .60811 -1.3 -1.6 Mshowa
[(P2)] .5 .60811 1.8 -1.6 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.677928 0.97619 1.30856 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.22973 0.135135 0.162162 0.135135 [
[ 0 0 0 0 ]
[ 1 .66216 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .66216 L
0 .66216 L
closepath
clip
newpath
p
p
p
1 0 0 r
p
.004 w
.25676 .22973 m
.18919 .2973 L
.05405 .2973 L
.05405 .16216 L
.59459 .16216 L
.59459 .2973 L
.45946 .2973 L
.39189 .22973 L
s
P
.004 w
newpath
.32432 .2973 .09555 -135 -45 arc
s
P
p
p
.02 w
.05405 .16216 Mdot
.59459 .16216 Mdot
.05405 .2973 Mdot
.18919 .2973 Mdot
.25676 .22973 Mdot
.39189 .22973 Mdot
.45946 .2973 Mdot
.59459 .2973 Mdot
.32432 .2973 Mdot
P
P
P
p
[(P1)] .05405 .16216 -1.6 -1.6 Mshowa
[(P2)] .59459 .16216 -1.6 -1.6 Mshowa
[(P3)] .05405 .2973 -1.6 -1.6 Mshowa
[(P4)] .18919 .2973 -1.6 -1.6 Mshowa
[(P5)] .25676 .22973 -1.6 -1.6 Mshowa
[(P6)] .39189 .22973 -1.6 1.6 Mshowa
[(P7)] .45946 .2973 -1.6 -1.6 Mshowa
[(P8)] .59459 .2973 -1.6 -1.6 Mshowa
[(P9)] .32432 .2973 -1.6 -1.6 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 1.30856 0.97619 1.93919 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.22973 0.135135 0.162162 0.135135 [
[ 0 0 0 0 ]
[ 1 .66216 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .66216 L
0 .66216 L
closepath
clip
newpath
p
p
.22973 .14865 m
.77027 .14865 L
.77027 .09459 L
.22973 .09459 L
F
.22973 .31081 m
.44595 .31081 L
.44595 .36486 L
.22973 .36486 L
F
.55405 .31081 m
.77027 .31081 L
.77027 .36486 L
.55405 .36486 L
F
.004 w
.02703 .06757 m
.02703 .63514 L
.97297 .63514 L
.97297 .06757 L
.02703 .06757 L
s
p
.015 w
.22973 .16216 Mdot
.77027 .16216 Mdot
.5 .43243 Mdot
.5 .56757 Mdot
P
P
p
[({0,0})] .22973 .16216 1.2 1.4 Mshowa
[(P1)] .22973 .16216 1.8 -1.4 Mshowa
[({4,0})] .77027 .16216 -1.2 1.4 Mshowa
[(P2)] .77027 .16216 -1.8 -1.4 Mshowa
[({2,2})] .5 .43243 -1.3 0 Mshowa
[(P3)] .5 .43243 2 0 Mshowa
[({2,3})] .5 .56757 -1.3 0 Mshowa
[(P4)] .5 .56757 2 0 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{196, 390},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000340001QQ000`40O003h00Oa7oo0034Ool00<<0
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40
005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`1KOol6<ImNOol10001Ool00003001oogoo
05Uoo`XaWeaoo`40005oo`0000<007ooOol0F7oo336OFgoo0@000Goo00000`00Oomoo`1GOol><ImJ
Ool10001Ool00003001oogoo05Moo`haW`Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo
03ioo`40005oo`0000<007ooOol0BGoo0`000Woo1@0017oo3S6O1Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0?Goo0@000Goo00000`00Oomoo`1:
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool?<Il6Ool01`00Oomoogoo001oo`0000Aoo`06001oogoo
001oo`000goo00<007ooOol0?Goo0@000Goo00000`00Oomoo`1:Ool30003Ool00`00Oomoo`04Ool7
<Il00`00<IlaW`04<Il5Ool20003Ool00`00Ool00007Ool00`00Ool00003Ool2000nOol10001Ool0
0003001oogoo04Yoo`04001oogoo0002Ool00`00Oomoo`03Ool7<Il30005<Il6Ool01`00Oomoogoo
001oo`0000Moo`03001oo`0000=oo`03001oogoo03eoo`40005oo`0000<007ooOol0BWoo00@007oo
Ool0009oo`03001oogoo00=oo`HaW`05000aW`00<Il00004<Il6Ool01`00Oomoogoo001oo`0000Mo
o`03001oo`0000=oo`03001oogoo03eoo`40005oo`0000<007ooOol0BGoo10000Woo0P001Goo1C6O
00@0036O<Il0008aW`04000aWc6O<Il7Ool01@00Oomoogoo00002Goo00D007ooOomoo`00041oo`40
005oo`0000<007ooOol0EWoo136O00D0036O<IlaW`0000<aW`03000aWc6O05Yoo`40005oo`0000<0
07ooOol0EWoo0c6O00<0036O<Il00S6O00<0036O<Il00S6O00<0036OOol0FGoo0@000Goo00000`00
Oomoo`1FOol8<Il00`00<IlaW`04<ImJOol10001Ool00003001oogoo05Ioo`PaW`03000aWc6O00@a
WeYoo`40005oo`0000<007ooOol0EWoo236O00<0036O<Il0136OFWoo0@000Goo00000`00Oomoo`1F
Ool8<Il00`00<IlaW`04<ImJOol10001Ool00003001oogoo05Ioo`PaW`03000aWc6O00@aWeYoo`40
005oo`0000<007ooOol0EWoo236O00<0036O<Il0136OFWoo0@000Goo00000`00Oomoo`1FOol8<Il0
0`00<IlaW`04<ImJOol10001Ool00003001oogoo05Ioo`PaW`03000aWc6O00@aWeYoo`40005oo`00
00<007ooOol0EWoo236O00<0036O<Il0136OFWoo0@000Goo00000`00Oomoo`1FOol8<Il00`00<Ila
W`04<ImJOol10001Ool00003001oogoo05Ioo`PaW`03000aWc6O00@aWeYoo`40005oo`0000<007oo
Ool0EWoo236O00<0036O<Il0136OFWoo0@000Goo00000`00Oomoo`1FOol8<Il00`00<IlaW`04<ImJ
Ool10001Ool00003001oogoo05Ioo`PaW`03000aWc6O00@aWeYoo`40005oo`0000<007ooOol0EWoo
236O00<0036O<Il0136OFWoo0@000Goo00000`00Oomoo`1FOol8<Il00`00<IlaW`04<ImJOol10001
Ool00003001oogoo05Ioo`PaW`03000aWc6O00@aWeYoo`40005oo`0000<007ooOol0EWoo236O00<0
036O<Il0136OFWoo0@000Goo00000`00Oomoo`1FOol8<Il00`00<IlaW`04<ImJOol10001Ool00003
001oogoo05Ioo`PaW`03000aWc6O00@aWeYoo`40005oo`0000<007ooOol0EWoo236O00<0036O<Il0
136OFWoo0@000Goo00000`00Oomoo`1FOol8<Il00`00<IlaW`04<ImJOol10001Ool00003001oogoo
05Ioo`PaW`03000aWc6O00@aWeYoo`40005oo`0000<007ooOol0EWoo236O00<0036O<Il0136OFWoo
0@000Goo00000`00Oomoo`1FOol8<Il00`00<IlaW`04<ImJOol10001Ool00003001oogoo05Ioo`Pa
W`03000aWc6O00@aWeYoo`40005oo`0000<007ooOol0EWoo236O00<0036O<Il0136OFWoo0@000Goo
00000`00Oomoo`1FOol8<Il00`00<IlaW`04<ImJOol10001Ool00003001oogoo05Ioo`PaW`03000a
Wc6O00@aWeYoo`40005oo`0000<007ooOol0EWoo236O00<0036O<Il0136OFWoo0@000Goo00000`00
Oomoo`1FOol8<Il00`00<IlaW`04<ImJOol10001Ool00003001oogoo05Ioo`PaW`03000aWc6O00@a
WeYoo`40005oo`0000<007ooOol0EWoo3c6OFWoo0@000Goo00000`00Oomoo`1FOol?<ImJOol10001
Ool00003001oogoo05Ioo`laWeYoo`40005oo`0000<007ooOol0EWoo3c6OFWoo0@000Goo00000`00
Oomoo`1FOol?<ImJOol10001Ool00003001oogoo05Ioo`laWeYoo`40005oo`0000<007ooOol0EWoo
3c6OFWoo0@000Goo00000`00Oomoo`1FOol?<ImJOol10001Ool00003001oogoo05Ioo`laWeYoo`40
005oo`0000<007ooOol0EWoo3c6OFWoo0@000Goo00000`00Oomoo`1FOol?<ImJOol10001Ool00003
001oogoo05Ioo`laWeYoo`40005oo`0000<007ooOol0EWoo3c6OFWoo0@000Goo00000`00Oomoo`2o
Ool10001Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2o
Ool10001Ool00003001oogoo0;moo`40005oo`0000<007ooOol0IGoo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol0AGoo0@000Goo00000`00Oomoo`1@Ool30003Ool3000;Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoogoo0`000goo00<007ooOol0A7oo0@000Goo00000`00Oomoo`1A
Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01`00Oomoogoo001oo`0000Aoo`04001oogoo0005Ool0
0`00Oomoo`14Ool10001Ool00003001oogoo055oo`<000=oo`03001oogoo00Uoo`8000=oo`03001o
o`0000Qoo`03001oogoo009oo`8004Eoo`40005oo`0000<007ooOol0DGoo00@007ooOol0009oo`03
001oogoo00Yoo`07001oogooOol007oo000027oo00<007ooOol00Woo00<007ooOol0A7oo0@000Goo
00000`00Oomoo`1AOol02000Oomoo`00Ool007oo000;Ool01`00Oomoogoo001oo`0000Moo`03001o
o`0000=oo`03001oogoo04Aoo`40005oo`0000<007ooOol0D7oo10000goo00<007ooOol02goo00D0
07ooOomoo`0000Uoo`05001oogooOol00017Ool10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<0
07ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001oogoo00]oofEl04moo`40005o
o`0000<007ooOol02goo00=l07ooOol0?goo0`000goo0P006Woo00=l07ooOol0CGoo0@000Goo0000
0`00Oomoo`0;Ool00g`0Oomoo`10Ool00`00Oomoo`02Ool00`00Ool0000IOol00g`0Oomoo`1=Ool1
0001Ool00003001oogoo00]oo`03O01oogoo041oo`<0009oo`03001oo`0001Uoo`03O01oogoo04eo
o`40005oo`0000<007ooOol02goo00=l07ooOol0@7oo00D007ooOol007oo008001Yoo`03O01oogoo
04eoo`40005oo`0000<007ooOol02goo00=l07ooOol0@7oo00H007ooOol007oo000KOol00g`0Oomo
o`1=Ool10001Ool00003001oogoo00]oo`03O01oogoo03moo`@000=oo`8001Uoo`03O01oogoo04eo
o`40005oo`0000<007ooOol02goo00=l07ooOol00`000Woo1@008Woo27`0;Goo00=l07ooOol00`00
0goo0`00A7oo0@000Goo00000`00Oomoo`0;Ool01G`0Oomoogoo00001Goo00<007ooOol07goo0g`0
27oo0g`0:Woo00El07ooOomoo`0000Aoo`03001oogoo04Aoo`40005oo`0000<007ooOol02goo00Al
07ooOomoo`<000=oo`03001oogoo01eoo`9l00ioo`9l02Qoo`04O01oogooOol30003Ool00`00Oomo
o`13Ool10001Ool00003001oogoo00]oo`05O01oogooOol00002Ool01000Oomoo`007Woo00=l07oo
Ool047oo00=l07ooOol09Goo00El07ooOomoo`00009oo`04001oogoo0015Ool10001Ool00003001o
ogoo00]oo`05O01oogooOol00002Ool01000Oomoo`0077oo0W`057oo0W`09Goo00El07ooOomoo`00
009oo`05001oo`00Ool00014Ool10001Ool00003001oogoo00]oo`03O01oogoo00@0009oo`8001]o
o`03O01oogoo01Ioo`03O01oogoo029oo`03O01oogoo00@000=oo`03001oogoo04=oo`40005oo`00
00<007ooOol02goo00=l07ooOol08Woo00=l07ooOol067oo00=l07ooOol08Goo00=l07ooOol0CGoo
0@000Goo00000`00Oomoo`0;Ool00g`0Oomoo`0QOol00g`0Oomoo`0JOol00g`0Oomoo`0POol00g`0
Oomoo`1=Ool10001Ool00003001oogoo00]oo`03O01oogoo021oo`03O01oogoo01aoo`03O01oogoo
01moo`03O01oogoo04eoo`40005oo`0000<007ooOol02goo00=l07ooOol07goo00=l07ooOol07Woo
00=l07ooOol07Woo00=l07ooOol0CGoo0@000Goo00000`00Oomoo`0;Ool00g`0Oomoo`0NOol00g`0
Oomoo`0POol00g`0Oomoo`0MOol00g`0Oomoo`1=Ool10001Ool00003001oogoo00]oo`03O01oogoo
01eoo`03O01oogoo029oo`03O01oogoo01aoo`03O01oogoo04eoo`40005oo`0000<007ooOol02goo
00=l07ooOol077oo00=l07ooOol08goo00=l07ooOol077oo00=l07ooOol0CGoo0@000Goo00000`00
Oomoo`0;Ool00g`0Oomoo`0KOol00g`0Oomoo`08Ool30004Ool00`00Oomoo`0COol00g`0Oomoo`0K
Ool00g`0Oomoo`1=Ool10001Ool00003001oogoo00]oo`03O01oogoo01Yoo`03O01oogoo00Yoo`03
001oogoo009oo`03001oo`0001Eoo`03O01oogoo01Yoo`03O01oogoo04eoo`40005oo`0000<007oo
Ool02goo00=l07ooOol06Goo00=l07ooOol02goo0`0017oo00<007ooOol057oo00=l07ooOol06Goo
00=l07ooOol0CGoo0@000Goo00000`00Oomoo`0;Ool00g`0Oomoo`0HOol00g`0Oomoo`0<Ool01@00
Oomoo`00Ool00P0067oo00=l07ooOol067oo00=l07ooOol0CGoo0@000Goo00000`00Oomoo`0;Ool0
0g`0Oomoo`0GOol00g`0Oomoo`0=Ool01P00Oomoo`00Ool001Yoo`03O01oogoo01Moo`03O01oogoo
04eoo`40005oo`0000<007ooOol02goo6W`03goo10000Woo0`006Goo6W`0Cgoo0@000Goo00000`00
Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00
Oomoo`2oOol10001Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00
Oomoo`0>Ool30003Ool2000AOol30004Ool3000?Ool30003Ool2000AOol30004Ool00`00Oomoo`0?
Ool30004Ool00`00Oomoo`13Ool10001Ool00003001oogoo00moo`03001oogoo00Aoo`03001oogoo
00moo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo
00=oo`03001oogoo011oo`03001oogoo009oo`03001oo`0004Aoo`40005oo`0000<007ooOol03goo
0`000goo00<007ooOol047oo0`000Woo100047oo0`000goo0P004Goo0`000goo00<007ooOol047oo
0`000Woo00<007oo0000A7oo0@000Goo00000`00Oomoo`0?Ool01000Oomoo`000goo00<007ooOol0
3goo00P007ooOol007oo001oo`004Goo00P007ooOol007oo001oo`004Goo00@007ooOol000=oo`03
001oogoo00moo`04001oogoo0002Ool00`00Oomoo`13Ool10001Ool00003001oogoo00moo`08001o
ogoo001oo`00Ool0015oo`04001oogoo0002Ool2000AOol02000Oomoo`00Ool007oo000AOol02000
Oomoo`00Ool007oo000AOol02000Oomoo`00Ool007oo0014Ool10001Ool00003001oogoo00ioo`@0
00=oo`03001oogoo00moo`@000Aoo`03001oogoo00ioo`@000=oo`80011oo`@0009oo`<0011oo`@0
00=oo`03001oogoo04=oo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001
Ool00003001oogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`06Oona0008
Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007oo
Ool01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]
Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40
005oo`0000<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06
Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`04OomT0006Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool10001Ool00003001oogoo
00Ioo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00=oof@000Eoo`03001oogoo009oo`<0009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Yoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol02Goo
00L007ooOomoo`00Ool00004Ool01P00Oomoo`00Ool000=oo`03001oogoo00=oof@000Eoo`03001o
ogoo00=oo`03001oogoo009oo`06001oogoo001oo`000goo00<007ooOol02Woo00<007ooOol01Woo
0@000Goo00000`00Oomoo`06Ool00`00Oomoo`08Ool20003Ool00`00Ool00007Ool00`00Ool00003
Ool20004OomT0004Ool20003Ool40006Ool00`00Ool00003Ool2000;Ool00`00Oomoo`06Ool10001
Ool00003001oogoo00Ioo`03001oogoo00Uoo`07001oogooOol007oo00001goo00<007oo00000goo
00<007ooOol00gooI0001Goo00L007ooOomoo`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0:
Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo00Uoo`07001oogooOol007oo
00001goo00<007oo00000goo00<007ooOol00gooI0001Goo00<007ooOol00Woo0P001goo00<007oo
00000goo00<007ooOol02Woo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`0:
Ool01@00Oomoogoo00002Goo00D007ooOomoo`0000Ioof@000Ioo`03001oogoo009oo`03001oogoo
00Ioo`05001oogooOol0000=Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo
02=oof@002Ioo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol08gooI0009Woo
00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`0SOomT000VOol00`00Oomoo`06
Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007oo
Ool01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`0R
Ool00`00Oomoo`1QOol00`00Oomoo`0TOol00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03
001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0[Goo00<007oo
Ool01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003
001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007oo
Ool0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`0EOol30002Ool5001/
Ool30003Ool3000IOol00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo01Ioo`03
001oogoo00=oo`03001oogoo06eoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo00Ioo`40
005oo`0000<007ooOol01Woo00<007ooOol05Woo0`000goo00<007ooOol0KGoo0`000goo00<007oo
Ool067oo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`0FOol01000Oomoo`00
0Woo00<007ooOol0KGoo00@007ooOol0009oo`03001oogoo01Qoo`03001oogoo00Ioo`40005oo`00
00<007ooOol01Woo00<007ooOol05Woo00@007ooOol0009oo`03001oogoo06eoo`08001oogoo001o
o`00Ool001Uoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol05Goo10000Woo
0P00KWoo10000goo00<007ooOol067oo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00
Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo
00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00
Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo
0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo
0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo
00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0[Goo
00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001
Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo
00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00
Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`00
00<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00
Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo02=oobP001AoobP0
02Ioo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol08goo:00057oo:0009Woo
00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`0SOolX000DOolX000VOol00`00
Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo02=oobP001AoobP002Ioo`03001oogoo
00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol08goo:00057oo:0009Woo00<007ooOol01Woo
0@000Goo00000`00Oomoo`06Ool00`00Oomoo`0SOolX000DOolX000VOol00`00Oomoo`06Ool10001
Ool00003001oogoo00Ioo`03001oogoo02=oobP001AoobP002Ioo`03001oogoo00Ioo`40005oo`00
00<007ooOol01Woo00<007ooOol08goo:00057oo:0009Woo00<007ooOol01Woo0@000Goo00000`00
Oomoo`06Ool00`00Oomoo`0SOolX000DOolX000VOol00`00Oomoo`06Ool10001Ool00003001oogoo
00Ioo`03001oogoo02=oobP001AoobP002Ioo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo
00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00
Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`00
00<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00
Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo
00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00
Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo
0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0G7oo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol0?7oo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00
Oomoo`16Ool30003Ool2000=Ool01000Oomoogoo0`000goo00@007ooOomoo`<000=oo`03001oogoo
03]oo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0Agoo00<007ooOol017oo
00<007ooOol02Woo00D007ooOomoo`0000Ioo`04001oogoo0005Ool00`00Oomoo`0kOol00`00Oomo
o`06Ool10001Ool00003001oogoo00Ioo`03001oogoo04Moo`<000=oo`03001oogoo00Aoo`03001o
ogoo00=oo`8000Aoo`03001oogoo00Moo`03001oogoo009oo`8003aoo`03001oogoo00Ioo`40005o
o`0000<007ooOol01Woo00<007ooOol0Agoo00@007ooOol000=oo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo03]oo`03001oogoo00Ioo`40005oo`00
00<007ooOol01Woo00<007ooOol0Agoo00P007ooOol007oo001oo`0037oo00L007ooOomoo`00Ool0
0007Ool00`00Ool00003Ool00`00Oomoo`0kOol00`00Oomoo`06Ool10001Ool00003001oogoo00Io
o`03001oogoo04Ioo`@000=oo`03001oogoo00aoo`05001oogooOol00009Ool01@00Oomoogoo0000
?Woo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool1
0001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol0
1Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool0
0`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005o
o`0000<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool0
0`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001o
ogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo0000
0`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001o
ogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0[Goo00<007ooOol0
1Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool00003001o
ogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0
[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool1
0001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol0
1Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`1LOol0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`00Oomoo`06Ool10001Ool00003001o
ogoo00Ioo`03001oogoo04Ioo`<000Aoo`<000]oo`04001oogooOol30003Ool01000Oomoogoo0P00
17oo00<007ooOol0>goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`17Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00D007ooOomo
o`0003eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<007ooOol0Agoo0`000Woo1000
17oo00<007ooOol00goo0P0017oo00<007ooOol01goo00<007ooOol00Woo0P00?7oo00<007ooOol0
1Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`17Ool02000Oomoo`00Ool007oo000<Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool01@00Oomoogoo0000?Goo00<007ooOol01Woo0@000Goo00000`00
Oomoo`06Ool00`00Oomoo`17Ool01000Oomoo`000Woo0P0037oo00L007ooOomoo`00Ool00007Ool0
0`00Ool00003Ool00`00Oomoo`0kOol00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001o
ogoo04Ioo`@000Aoo`03001oogoo00]oo`05001oogooOol00009Ool01@00Oomoogoo0000?Woo00<0
07ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool10001Ool0
0003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<007ooOol01Woo00<0
07ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomoo`2]Ool00`00Oomo
o`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Ioo`40005oo`0000<0
07ooOol01Woo00<007ooOol0[Goo00<007ooOol01Woo0@000Goo00000`00Oomoo`06Ool00`00Oomo
o`2]Ool00`00Oomoo`06Ool10001Ool00003001oogoo00Ioo`03001oogoo0:eoo`03001oogoo00Io
o`40005oo`0000<007ooOol01Woo/@0027oo0@000Goo00000`00Oomoo`2oOol10001Ool00003001o
ogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001o
ogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001o
ogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00003001o
ogoo0;moo`40005oo`0000<007ooOol0_goo0@000Goo00000`00Oomoo`2oOol10001Ool00<<0005o
o`00a7oo0000\
\>"],
  ImageRangeCache->{{{0, 195}, {389, 0}} -> {-0.0260552, -0.0561677, 
  0.00539544, 0.00539544}, {{4.8125, 190.125}, {378.563, 255.813}} ->
   {-1.89222, -1.61769, 0.039933, 0.039933}, {{4.8125, 190.125}, {255.813, 
  133.125}} -> {-1.89282, -6.51942, 0.0399392, 0.0399392}, {{4.8125, 190.125},
   {133.125, 10.375}} -> {-1.89222, -11.4187, 0.039933, 0.039933}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The body objects are incorporated into the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[slider], bd[detenter]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Constraints "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three regular constraints and one ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are used to model the detent mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces a horizontal line on the slider to be coincident with a \
horizontal line on the ground, allowing the slider to translate in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction only."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces a vertical line on the detenter to be coincident with a \
vertical line on the ground, allowing the detenter to translate in the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " direction only."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the slider. This driving constraint is used to specify the \
position of the slider as a function of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the one remaining degree of freedom."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Four of the seven stages of operation (1, 3, 5, and 7) are modeled by ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints that place the center of the detenter tip a specified \
distance (detenter tip radius) away from various lines on the slider."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The second and sixth stages, in which the detenter tip moves around sharp \
corners on the slider, are modeled with ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints that place the center of the detenter tip a specified \
distance (detenter tip radius) away from the sharp corners on the slider."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The fourth stage, in which the detenter tip is traveling around the arc at \
the bottom of the detent notch, is also modeled with a ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint that places the center of the detenter tip a specified \
distance (detent notch radius minus detenter tip radius) away from the center \
point of the arc."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The exact values of the switch times given as arguments to the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are not known. The symbols given in place of switch times (",
  StyleBox["tm2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["tm3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc.) are set to approximate values before running the model. The exact \
switch times will be determined later with ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the three regular constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(tm2 =. ; tm3 =. ; tm4 =. ; tm5 =. \), 
    \(cs[1] = Translate2[1, \n\t\tLine[ground, 1, 2], Line[slider, 1, 2]]; \n
    cs[2] = Translate2[2, \n\t\tLine[ground, 3, 4], Line[detenter, 1, 2]]; \n
    \(cs[3] = RelativeX1[3, Point[slider, 1], T]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the seven-stage ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cs[4] = 
      TimeSwitch[4, \n\t\t
        PointOnLine1[1, \n\t\t\tPoint[detenter, 1], Line[slider, 7, 8], .3], 
        \n\t\t\(-1\), 
        RelativeDistance1[2, \n\t\t\tPoint[detenter, 1], 
          Point[slider, 7], .3], \n\t\ttm2, 
        PointOnLine1[3, \n\t\t\tPoint[detenter, 1], Line[slider, 6, 7], .3], 
        \n\t\ttm3, 
        RelativeDistance1[4, \n\t\t\tPoint[detenter, 1], Point[slider, 9], 
          2\^\(\(-1\)/2\) - .3], \n\t\ttm4, 
        PointOnLine1[5, \n\t\t\tPoint[detenter, 1], Line[slider, 4, 5], .3], 
        \n\t\ttm5, 
        RelativeDistance1[6, \n\t\t\tPoint[detenter, 1], 
          Point[slider, 4], .3], \n\t\t1, 
        PointOnLine1[7, \n\t\t\tPoint[detenter, 1], Line[slider, 3, 4], .3]]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The constraints are incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs[1], cs[2], cs[3], cs[4]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Before the detent model can be run, the switch times used in the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint (",
  StyleBox["tm2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["tm3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc.) must be given numeric values."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are guesses for switch times."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(tm2 = \(-.8\); \)\), 
    \(\(tm3 = \(-.4\); \)\), 
    \(\(tm4 = .4; \)\), 
    \(\(tm5 = .8; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = -1.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[\(-1.3\)]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          RowBox[{"-", 
            StyleBox["1.30000000000000004`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}]}], ",", 
        \(X2 \[Rule] \(-1.30000000000000004`\)\), ",", \(Y2 \[Rule] 0.`\), 
        ",", \(Th2 \[Rule] 0.`\), ",", 
        RowBox[{"X3", "\[Rule]", 
          StyleBox["2.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(Y3 \[Rule] 1.30000000000000004`\), 
        ",", \(Th3 \[Rule] 0.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the detent mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = -1.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
  
%%Creator: Mathematica
 
  
%%AspectRatio: .66216 
 
  
MathPictureStart
 
  
%% Graphics
 
  
/Courier findfont 10  scalefont  setfont
 
  
% Scaling calculations
 
  
0.22973 0.135135 0.162162 0.135135 [
 
  
[ 0 0 0 0 ]
 
  
[ 1 .66216 0 0 ]
 
  
] MathScale
 
  
% Start of Graphics
 
  
1 setlinecap
 
  
1 setlinejoin
 
  
newpath
 
  
[ ] 0 setdash
 
  
0 g
 
  
p
 
  
P
 
  
0 0 m
 
  
1 0 L
 
  
1 .66216 L
 
  
0 .66216 L
 
  
closepath
 
  
clip
 
  
newpath
 
  
p
 
  
p
 
  
.22973 .14865 m
 
  
.77027 .14865 L
 
  
.77027 .09459 L
 
  
.22973 .09459 L
 
  
F
 
  
.22973 .31081 m
 
  
.45946 .31081 L
 
  
.45946 .36486 L
 
  
.22973 .36486 L
 
  
F
 
  
.54054 .31081 m
 
  
.77027 .31081 L
 
  
.77027 .36486 L
 
  
.54054 .36486 L
 
  
F
 
  
.004 w
 
  
.02703 .06757 m
 
  
.02703 .63514 L
 
  
.97297 .63514 L
 
  
.97297 .06757 L
 
  
.02703 .06757 L
 
  
s
 
  
p
 
  
.015 w
 
  
.22973 .16216 Mdot
 
  
.77027 .16216 Mdot
 
  
.5 .43243 Mdot
 
  
.5 .56757 Mdot
 
  
P
 
  
P
 
  
p
 
  
p
 
  
1 0 0 r
 
  
p
 
  
.004 w
 
  
.25676 .22973 m
 
  
.18919 .2973 L
 
  
.05405 .2973 L
 
  
.05405 .16216 L
 
  
.59459 .16216 L
 
  
.59459 .2973 L
 
  
.45946 .2973 L
 
  
.39189 .22973 L
 
  
s
 
  
P
 
  
.004 w
 
  
newpath
 
  
.32432 .2973 .09555 -135 -45 arc
 
  
s
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.05405 .16216 Mdot
 
  
.59459 .16216 Mdot
 
  
.05405 .2973 Mdot
 
  
.18919 .2973 Mdot
 
  
.25676 .22973 Mdot
 
  
.39189 .22973 Mdot
 
  
.45946 .2973 Mdot
 
  
.59459 .2973 Mdot
 
  
.32432 .2973 Mdot
 
  
P
 
  
P
 
  
P
 
  
p
 
  
p
 
  
0 0 1 r
 
  
.54054 .60811 m
 
  
.45946 .60811 L
 
  
.45946 .33784 L
 
  
.54054 .33784 L
 
  
F
 
  
.004 w
 
  
.5 .33784 m
 
  
.5 .33784 .04054 0 365.73 arc
 
  
F
 
  
0 0 0 r
 
  
p
 
  
.5 .33784 m
 
  
.5 .54054 L
 
  
s
 
  
.47133 .3665 m
 
  
.5 .33784 L
 
  
.52867 .3665 L
 
  
s
 
  
P
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.5 .33784 Mdot
 
  
.5 .60811 Mdot
 
  
P
 
  
P
 
  
P
 
  
P
 
  
% End of Graphics
 
  
MathPictureEnd
 
  

 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 186},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000^Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0008Oooo000:0009Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo
00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00
Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo
00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?mo
o`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomo
o`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`00
27oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOonH000hOol00`00
Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo
V000>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03
001oogoo03EooiP003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=GooV000>7oo00<007ooOol0
1goo0008Ool00`00Oomoo`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qo
o`03001oogoo00Moo`0027oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomo
o`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`00
27oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomo
o`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol00goo0P00<7oo
00<007ooOol0HWoo0P00<7oo00<007ooOol0=Woo00<007ooOol01goo0008Ool00`00Oomoo`02Ool4
002CO004000^Ool3000gOol00`00Oomoo`07Ool000Qoo`03001oogoo009oo`@002moo`03001oogoo
065oo`@002moo`03001oogoo03Ioo`03001oogoo00Moo`0027oo00<007ooOol00goo0P00UGoo0P00
JGoo00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`2DOol00g`0Oomoo`1WOol00`00
Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01oogoo09Aoo`03O01oogoo06Moo`03001oogoo00Mo
o`0027oo00<007ooOol017oo00=l07ooOol0U7oo00=l07ooOol0Igoo00<007ooOol01goo0008Ool0
0`00Oomoo`04Ool00g`0Oomoo`2DOol00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo
00Aoo`03O01oogoo09Aoo`03O01oogoo06Moo`03001oogoo00Moo`0027oo00<007ooOol017oo00=l
07ooOol0U7oo00=l07ooOol0Igoo00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`2D
Ool00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01oogoo09Aoo`03O01o
ogoo06Moo`03001oogoo00Moo`0027oo00<007ooOol017oo00=l07ooOol0@goo3G`0A7oo00=l07oo
Ool0Igoo00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`11Ool2O00=Ool2O012Ool0
0g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01oogoo03ioo`=l015oo`=l
03moo`03O01oogoo06Moo`03001oogoo00Moo`0027oo00<007ooOol017oo00=l07ooOol0?7oo0W`0
5goo0W`0?Goo00=l07ooOol0Igoo00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`0j
Ool2O00KOol2O00kOol00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01o
ogoo03Uoo`03O01oogoo01eoo`03O01oogoo03Qoo`03O01oogoo06Moo`03001oogoo00Moo`0027oo
00<007ooOol017oo00=l07ooOol0>7oo00=l07ooOol07goo00=l07ooOol0=goo00=l07ooOol0Igoo
00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`0eOol200000g`0Oomoo`0QOol2000g
Ool00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01oogoo03Aoo`@0029o
o`@003Ioo`03O01oogoo06Moo`03001oogoo00Moo`0027oo00<007ooOol017oo00=l07ooOol0=7oo
10008Woo1000=Woo00=l07ooOol0Igoo00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomo
o`0dOol00g`00000000TOol200000gooO01oo`0dOol00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qo
o`03001oogoo00Aoo`03O01oogoo03=oo`03O01oogoo02Uoo`03O01oogoo039oo`03O01oogoo06Mo
o`03001oogoo00Moo`0027oo00<007ooOol017oo00=l07ooOol0<Woo00=l07ooOol0:goo00=l07oo
Ool0<Goo00=l07ooOol0Igoo00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`0aOol0
0g`0Oomoo`0]Ool00g`0Oomoo`0`Ool00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo
00Aoo`03O01oogoo031oo`03O01oogoo02moo`03O01oogoo02moo`03O01oogoo06Moo`03001oogoo
00Moo`0027oo00<007ooOol017oo00=l07ooOol0;goo00=l07ooOol0<Goo00=l07ooOol0;Woo00=l
07ooOol0Igoo00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`0^Ool00g`0Oomoo`0c
Ool00g`0Oomoo`0]Ool00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01o
ogoo02eoo`03O01oogoo03Eoo`03O01oogoo02aoo`03O01oogoo06Moo`03001oogoo00Moo`0027oo
00<007ooOol017oo00=l07ooOol0;7oo00=l07ooOol0=goo00=l07ooOol0:goo00=l07ooOol0Igoo
00<007ooOol01goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`0[Ool00g`0Oomoo`0iOol00g`0Oomo
o`0ZOol00g`0Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01oogoo02Yoo`03
O01oogoo03]oo`03O01oogoo02Uoo`03O01oogoo06Moo`03001oogoo00Moo`0027oo00<007ooOol0
17oo00=l07ooOol0:Goo00=l07ooOol0?Goo00=l07ooOol0:7oo00=l07ooOol0Igoo00<007ooOol0
1goo0008Ool00`00Oomoo`04Ool00g`0Oomoo`0XOol00g`0Oomoo`0oOol00g`0Oomoo`0WOol00g`0
Oomoo`1WOol00`00Oomoo`07Ool000Qoo`03001oogoo00Aoo`03O01oogoo02Moo`03O01oogoo045o
o`03O01oogoo02Ioo`03O01oogoo06Moo`03001oogoo00Moo`0027oo00<007ooOol017oo00=l07oo
Ool09Woo00=l07ooOol0@goo00=l07ooOol09Goo00=l07ooOol0Igoo00<007ooOol01goo0008Ool0
0`00Oomoo`04Ool00g`0Oomoo`0UOol00g`0Oomoo`15Ool00g`0Oomoo`0TOol00g`0Oomoo`1WOol0
0`00Oomoo`07Ool000Qoo`03001oogoo00=oo`8002Aoo`800003O01oogoo025oo`8002=oo`8002Ao
o`8006Uoo`03001oogoo00Moo`0027oo00<007ooOol00Woo10008W`010008Woo10008Goo10008W`0
1000J7oo00<007ooOol01goo0008Ool00`00Oomoo`02Ool4000ROol4000ROol4000QOol40004Ool;
01lCOol4001XOol00`00Oomoo`07Ool000Qoo`03001oogoo00=oo`8002Aoo`8002Aoo`8002=oo`80
00Aoo`h07a9oo`8006Uoo`03001oogoo00Moo`0027oo00<007ooOol0NGoo400OO7oo00<007ooOol0
1goo0008Ool00`00Oomoo`0eOom10002OolB01l2Oom1000hOol00`00Oomoo`07Ool000Qoo`03001o
ogoo03Eood40009ooa<07`03Ool0000003l003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo
@@0000=oo`0O01l04`0O@@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOom100000goo01l0
7`0C01m1000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eood4001H07d4003Qoo`03001oogoo
00Moo`0027oo00<007ooOol0=Goo@@005P0O@@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0e
Oom1000:01l2000:01m1000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eood4000T07`@000T0
7d4003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo@@002@0O10002@0O@@00>7oo00<007oo
Ool01goo0008Ool00`00Oomoo`0eOom1000901l300000`0O00007`0701m1000hOol00`00Oomoo`07
Ool000Qoo`03001oogoo03Eood4000P07`0400007`0O000201l00`0001l07`0501m1000hOol00`00
Oomoo`07Ool000Qoo`03001oogoo03Eood4000L07`0500007`0O01l0000301l00`0001l07`0401m1
000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eood4000H07`0300007`0O00807`0300007`0O
00807`0300007`0O00<07d4003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo@@001@0O00<0
000O01l00`0O00<0000O01l00`0O00<0000O01l00P0O@@00>7oo00<007ooOol01goo0008Ool00`00
Oomoo`0eOom1000401l00`0001l07`0401l00`0001l07`0401l0100001l07`0O@@00>7oo00<007oo
Ool01goo0008Ool00`00Oomoo`1fOol301l00`0001l07`0501l00`0001l07`0501l00`0001l07`1i
Ool00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Mo
o`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomo
o`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`030000
7`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<0
07ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qo
o`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo
2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`08
01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo
00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00
Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`03
00007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo
00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool0
00Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0
MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l0
7`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001o
ogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool0
0`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/0
7`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200O
NGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07
Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007oo
Ool0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`00
01l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03
001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008
Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Io
o`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0
200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomo
o`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<0
07ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l0
0`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUo
o`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo
0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo
07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O
01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00
Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo
00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;
01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P0
7gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol0
1goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001o
ogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo
00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo
07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008
Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001o
ogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF
01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<0
07ooOol0MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07
Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo
00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo
07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008
Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`X07`8000X07gUo
o`03001oogoo00Moo`0027oo00<007ooOol0Ogoo1000PWoo00<007ooOol01goo0008Ool00`00Oomo
o`1oOol40022Ool00`00Oomoo`07Ool000Qoo`03001oogoo081oo`8008=oo`03001oogoo00Moo`00
27oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07
Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007oo
Ool01goo0008Oooo000:0009Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo
003oOolKOol00?mooa]oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {185, 0}} -> {-1.72138, -1.20002, 0.0264867, 
  0.0264867}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run twice more at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = -0.5 and ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = -0.1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(postab = SolveMech[{\(-0.5\), \(-0.1\)}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              RowBox[{"-", 
                StyleBox["0.5`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}]}], ",", \(X2 \[Rule] \(-0.5`\)\), ",", 
            \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.`\), ",", 
            RowBox[{"X3", "\[Rule]", 
              StyleBox["2.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2]}], ",", 
            \(Y3 \[Rule] 0.924264068711928388`\), ",", \(Th3 \[Rule] 0.`\)}], 
          "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              RowBox[{"-", 
                StyleBox["0.1`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}]}], ",", \(X2 \[Rule] \(-0.1`\)\), ",", 
            \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.`\), ",", 
            RowBox[{"X3", "\[Rule]", 
              StyleBox["2.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->2]}], ",", 
            \(Y3 \[Rule] 0.605366079372594079`\), ",", \(Th3 \[Rule] 0.`\)}], 
          "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the detent mechanism at the two new solution points."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
  
%%Creator: Mathematica
 
  
%%AspectRatio: .33108 
 
  
MathPictureStart
 
  
%% Graphics
 
  
/Courier findfont 10  scalefont  setfont
 
  
% Scaling calculations
 
  
0.0238095 0.47619 0.00788288 0.47619 [
 
  
[ 0 0 0 0 ]
 
  
[ 1 .33108 0 0 ]
 
  
] MathScale
 
  
% Start of Graphics
 
  
1 setlinecap
 
  
1 setlinejoin
 
  
newpath
 
  
[ ] 0 setdash
 
  
0 g
 
  
p
 
  
P
 
  
0 0 m
 
  
1 0 L
 
  
1 .33108 L
 
  
0 .33108 L
 
  
closepath
 
  
clip
 
  
newpath
 
  
p
 
  
p
 
  
% Start of sub-graphic
 
  
p
 
  
0.0238095 0.00788288 0.5 0.323198 MathSubStart
 
  
%% Graphics
 
  
/Courier findfont 10  scalefont  setfont
 
  
% Scaling calculations
 
  
0.22973 0.135135 0.162162 0.135135 [
 
  
[ 0 0 0 0 ]
 
  
[ 1 .66216 0 0 ]
 
  
] MathScale
 
  
% Start of Graphics
 
  
1 setlinecap
 
  
1 setlinejoin
 
  
newpath
 
  
[ ] 0 setdash
 
  
p
 
  
P
 
  
0 0 m
 
  
1 0 L
 
  
1 .66216 L
 
  
0 .66216 L
 
  
closepath
 
  
clip
 
  
newpath
 
  
p
 
  
p
 
  
.22973 .14865 m
 
  
.77027 .14865 L
 
  
.77027 .09459 L
 
  
.22973 .09459 L
 
  
F
 
  
.22973 .31081 m
 
  
.45946 .31081 L
 
  
.45946 .36486 L
 
  
.22973 .36486 L
 
  
F
 
  
.54054 .31081 m
 
  
.77027 .31081 L
 
  
.77027 .36486 L
 
  
.54054 .36486 L
 
  
F
 
  
.004 w
 
  
.02703 .06757 m
 
  
.02703 .63514 L
 
  
.97297 .63514 L
 
  
.97297 .06757 L
 
  
.02703 .06757 L
 
  
s
 
  
p
 
  
.015 w
 
  
.22973 .16216 Mdot
 
  
.77027 .16216 Mdot
 
  
.5 .43243 Mdot
 
  
.5 .56757 Mdot
 
  
P
 
  
P
 
  
p
 
  
p
 
  
1 0 0 r
 
  
p
 
  
.004 w
 
  
.36486 .22973 m
 
  
.2973 .2973 L
 
  
.16216 .2973 L
 
  
.16216 .16216 L
 
  
.7027 .16216 L
 
  
.7027 .2973 L
 
  
.56757 .2973 L
 
  
.5 .22973 L
 
  
s
 
  
P
 
  
.004 w
 
  
newpath
 
  
.43243 .2973 .09555 -135 -45 arc
 
  
s
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.16216 .16216 Mdot
 
  
.7027 .16216 Mdot
 
  
.16216 .2973 Mdot
 
  
.2973 .2973 Mdot
 
  
.36486 .22973 Mdot
 
  
.5 .22973 Mdot
 
  
.56757 .2973 Mdot
 
  
.7027 .2973 Mdot
 
  
.43243 .2973 Mdot
 
  
P
 
  
P
 
  
P
 
  
p
 
  
p
 
  
0 0 1 r
 
  
.54054 .55733 m
 
  
.45946 .55733 L
 
  
.45946 .28706 L
 
  
.54054 .28706 L
 
  
F
 
  
.004 w
 
  
.5 .28706 m
 
  
.5 .28706 .04054 0 365.73 arc
 
  
F
 
  
0 0 0 r
 
  
p
 
  
.5 .28706 m
 
  
.5 .48977 L
 
  
s
 
  
.47133 .31573 m
 
  
.5 .28706 L
 
  
.52867 .31573 L
 
  
s
 
  
P
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.5 .28706 Mdot
 
  
.5 .55733 Mdot
 
  
P
 
  
P
 
  
P
 
  
P
 
  
MathSubEnd
 
  
P
 
  
% End of sub-graphic
 
  
% Start of sub-graphic
 
  
p
 
  
0.5 0.00788288 0.97619 0.323198 MathSubStart
 
  
%% Graphics
 
  
/Courier findfont 10  scalefont  setfont
 
  
% Scaling calculations
 
  
0.22973 0.135135 0.162162 0.135135 [
 
  
[ 0 0 0 0 ]
 
  
[ 1 .66216 0 0 ]
 
  
] MathScale
 
  
% Start of Graphics
 
  
1 setlinecap
 
  
1 setlinejoin
 
  
newpath
 
  
[ ] 0 setdash
 
  
p
 
  
P
 
  
0 0 m
 
  
1 0 L
 
  
1 .66216 L
 
  
0 .66216 L
 
  
closepath
 
  
clip
 
  
newpath
 
  
p
 
  
p
 
  
.22973 .14865 m
 
  
.77027 .14865 L
 
  
.77027 .09459 L
 
  
.22973 .09459 L
 
  
F
 
  
.22973 .31081 m
 
  
.45946 .31081 L
 
  
.45946 .36486 L
 
  
.22973 .36486 L
 
  
F
 
  
.54054 .31081 m
 
  
.77027 .31081 L
 
  
.77027 .36486 L
 
  
.54054 .36486 L
 
  
F
 
  
.004 w
 
  
.02703 .06757 m
 
  
.02703 .63514 L
 
  
.97297 .63514 L
 
  
.97297 .06757 L
 
  
.02703 .06757 L
 
  
s
 
  
p
 
  
.015 w
 
  
.22973 .16216 Mdot
 
  
.77027 .16216 Mdot
 
  
.5 .43243 Mdot
 
  
.5 .56757 Mdot
 
  
P
 
  
P
 
  
p
 
  
p
 
  
1 0 0 r
 
  
p
 
  
.004 w
 
  
.41892 .22973 m
 
  
.35135 .2973 L
 
  
.21622 .2973 L
 
  
.21622 .16216 L
 
  
.75676 .16216 L
 
  
.75676 .2973 L
 
  
.62162 .2973 L
 
  
.55405 .22973 L
 
  
s
 
  
P
 
  
.004 w
 
  
newpath
 
  
.48649 .2973 .09555 -135 -45 arc
 
  
s
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.21622 .16216 Mdot
 
  
.75676 .16216 Mdot
 
  
.21622 .2973 Mdot
 
  
.35135 .2973 Mdot
 
  
.41892 .22973 Mdot
 
  
.55405 .22973 Mdot
 
  
.62162 .2973 Mdot
 
  
.75676 .2973 Mdot
 
  
.48649 .2973 Mdot
 
  
P
 
  
P
 
  
P
 
  
p
 
  
p
 
  
0 0 1 r
 
  
.54054 .51424 m
 
  
.45946 .51424 L
 
  
.45946 .24397 L
 
  
.54054 .24397 L
 
  
F
 
  
.004 w
 
  
.5 .24397 m
 
  
.5 .24397 .04054 0 365.73 arc
 
  
F
 
  
0 0 0 r
 
  
p
 
  
.5 .24397 m
 
  
.5 .44667 L
 
  
s
 
  
.47133 .27263 m
 
  
.5 .24397 L
 
  
.52867 .27263 L
 
  
s
 
  
P
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.5 .24397 Mdot
 
  
.5 .51424 Mdot
 
  
P
 
  
P
 
  
P
 
  
P
 
  
MathSubEnd
 
  
P
 
  
% End of sub-graphic
 
  
P
 
  
P
 
  
% End of Graphics
 
  
MathPictureEnd
 
  

 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{400, 132},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000Q1000`40O003h00OogooTGoo003oOonA
Ool00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00
ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo000@Oonc
0009Oonc000AOol0011oo`03001oogoo0:moo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo
00moo`0047oo00<007ooOol0[goo00<007ooOol01goo00<007ooOol0[goo00<007ooOol03goo000@
Ool00`00Oomoo`2_Ool00`00Oomoo`07Ool00`00Oomoo`2_Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo0:moo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo00moo`0047oo00<007ooOol0[goo
00<007ooOol01goo00<007ooOol0[goo00<007ooOol03goo000@Ool00`00Oomoo`0SOomV000VOol0
0`00Oomoo`07Ool00`00Oomoo`0SOomV000VOol00`00Oomoo`0?Ool0011oo`03001oogoo02=oofH0
02Ioo`03001oogoo00Moo`03001oogoo02=oofH002Ioo`03001oogoo00moo`0047oo00<007ooOol0
8gooIP009Woo00<007ooOol01goo00<007ooOol08gooIP009Woo00<007ooOol03goo000@Ool00`00
Oomoo`0SOomV000VOol00`00Oomoo`07Ool00`00Oomoo`0SOomV000VOol00`00Oomoo`0?Ool0011o
o`03001oogoo02=oofH002Ioo`03001oogoo00Moo`03001oogoo02=oofH002Ioo`03001oogoo00mo
o`0047oo00<007ooOol08gooIP009Woo00<007ooOol01goo00<007ooOol08gooIP009Woo00<007oo
Ool03goo000@Ool00`00Oomoo`0SOomV000VOol00`00Oomoo`07Ool00`00Oomoo`0SOomV000VOol0
0`00Oomoo`0?Ool0011oo`03001oogoo02=oofH002Ioo`03001oogoo00Moo`03001oogoo02=oofH0
02Ioo`03001oogoo00moo`0047oo00<007ooOol08gooIP009Woo00<007ooOol01goo00<007ooOol0
8gooIP009Woo00<007ooOol03goo000@Ool00`00Oomoo`0SOomV000VOol00`00Oomoo`07Ool00`00
Oomoo`0SOomV000VOol00`00Oomoo`0?Ool0011oo`03001oogoo02=oofH002Ioo`03001oogoo00Mo
o`03001oogoo02=oofH002Ioo`03001oogoo00moo`0047oo00<007ooOol0[goo00<007ooOol01goo
00<007ooOol0[goo00<007ooOol03goo000@Ool00`00Oomoo`0FOomWO00bOol00`00Oomoo`07Ool0
0`00Oomoo`0QOomWO00WOol00`00Oomoo`0?Ool0011oo`03001oogoo01Ioo`03O01oogoo00Uoo`03
001oogoo05Moo`03O01oogoo00Uoo`03001oogoo02Aoo`03001oogoo00Moo`03001oogoo025oo`03
O00007oo06=oo`03O00007oo02Eoo`03001oogoo00moo`0047oo00<007ooOol05Woo00=l07ooOol0
Hgoo00=l07ooOol0<7oo00<007ooOol01goo00<007ooOol08Goo00=l07ooOol0Hgoo00=l07ooOol0
9Goo00<007ooOol03goo000@Ool00`00Oomoo`0FOol00g`0Oomoo`1SOol00g`0Oomoo`0`Ool00`00
Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`1SOol00g`0Oomoo`0UOol00`00Oomoo`0?Ool0011o
o`03001oogoo01Ioo`03O01oogoo06=oo`03O01oogoo031oo`03001oogoo00Moo`03001oogoo025o
o`03O01oogoo06=oo`03O01oogoo02Eoo`03001oogoo00moo`0047oo00<007ooOol05Woo00=l07oo
Ool0Hgoo00=l07ooOol0<7oo00<007ooOol01goo00<007ooOol08Goo00=l07ooOol0Hgoo00=l07oo
Ool09Goo00<007ooOol03goo000@Ool00`00Oomoo`0FOol00g`0Oomoo`1SOol00g`0Oomoo`0`Ool0
0`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`1SOol00g`0Oomoo`0UOol00`00Oomoo`0?Ool0
011oo`03001oogoo01Ioo`03O01oogoo06=oo`03O01oogoo031oo`03001oogoo00Moo`03001oogoo
025oo`03O01oogoo06=oo`03O01oogoo02Eoo`03001oogoo00moo`0047oo00<007ooOol05Woo00=l
07ooOol0:goo2g`0;Goo00=l07ooOol0<7oo00<007ooOol01goo00<007ooOol08Goo00=l07ooOol0
:Woo37`0;Goo00=l07ooOol09Goo00<007ooOol03goo000@Ool00`00Oomoo`0FOol00g`0Oomoo`0Y
Ool2O00;Ool2O00[Ool00g`0Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0Y
Ool00g`0Oomoo`03Ool701l2O00[Ool00g`0Oomoo`0UOol00`00Oomoo`0?Ool0011oo`03001oogoo
01Ioo`03O01oogoo02Qoo`03O01oogoo00eoo`9l02Uoo`03O01oogoo031oo`03001oogoo00Moo`03
001oogoo025oo`03O01oogoo02Moo`9l00Aoo`X07`03Ooml07oo02Uoo`03O01oogoo02Eoo`03001o
ogoo00moo`0047oo00<007ooOol05Woo00=l07ooOol09Woo0W`04Woo00=l07ooOol09Woo00=l07oo
Ool0<7oo00<007ooOol01goo00<007ooOol08Goo00=l07ooOol09Woo00=l07ooOol00goo300O00=o
og`0O000:7oo00=l07ooOol09Goo00<007ooOol03goo000@Ool00`00Oomoo`0FOol00g`0Oomoo`0T
Ool2O00EOol2O00VOol00g`0Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0T
Ool2O005Ool>01l2Ool00g`0Oomoo`0UOol00g`0Oomoo`0UOol00`00Oomoo`0?Ool0011oo`03001o
ogoo01Ioo`03O01oogoo02=oo`03O01oogoo01Moo`03O01oogoo02=oo`03O01oogoo031oo`03001o
ogoo00Moo`03001oogoo025oo`03O01oogoo02=oo`03O01oogoo00Eoo`h07`=oo`03O01oogoo02Ao
o`03O01oogoo02Eoo`03001oogoo00moo`0047oo00<007ooOol05Woo00=l07ooOol08Woo00=l07oo
Ool06Goo00=l07ooOol08Woo00=l07ooOol0<7oo00<007ooOol01goo00<007ooOol08Goo00=l07oo
Ool08Woo00=l07ooOol01Woo3`0O0goo00=l07ooOol08goo00=l07ooOol09Goo00<007ooOol03goo
000@Ool00`00Oomoo`0FOol00g`0Oomoo`0QOol00g`0Oomoo`0KOol00g`0Oomoo`0QOol00g`0Oomo
o`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0QOol00g`0Oomoo`07Ool?01l4Ool0
0g`0Oomoo`0ROol00g`0Oomoo`0UOol00`00Oomoo`0?Ool0011oo`03001oogoo01Ioo`03O01oogoo
021oo`03O01oogoo01eoo`03O01oogoo021oo`03O01oogoo031oo`03001oogoo00Moo`03001oogoo
025oo`03O01oogoo021oo`03O01oogoo00Qoo`L07`0300007`0O00D07`Eoo`03O01oogoo025oo`03
O01oogoo02Eoo`03001oogoo00moo`0047oo00<007ooOol05Woo00=l07ooOol07goo00=l07ooOol0
5goo1`0O00=oog`0Ool087oo00=l07ooOol0<7oo00<007ooOol01goo00<007ooOol08Goo00=l07oo
Ool07goo00=l07ooOol02Goo1P0O0`001P0O1Woo00=l07ooOol087oo00=l07ooOol09Goo00<007oo
Ool03goo000@Ool00`00Oomoo`0FOol00g`0Oomoo`0NOol00g`0Oomoo`0GOol:01l00g`0Oomoo`0N
Ool00g`0Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0NOol00g`0Oomoo`0:
Ool501l01@0001l0000O00001@0O1goo00=l07ooOol07goo00=l07ooOol09Goo00<007ooOol03goo
000@Ool00`00Oomoo`0FOol00g`0Oomoo`0MOol00g`0Oomoo`0GOol<01l00g`0Oomoo`0MOol00g`0
Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0MOol00g`0Oomoo`0;Ool401l0
100001l07`000P0O0P000`0O27oo00=l07ooOol07Woo00=l07ooOol09Goo00<007ooOol03goo000@
Ool00`00Oomoo`0FOol00g`0Oomoo`0MOol00g`0Oomoo`0FOol>01l00g`0Oomoo`0LOol00g`0Oomo
o`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0LOol00g`0Oomoo`0<Ool301l01@00
01l07`0O0000100O00<0000O01l02Goo00=l07ooOol07Goo00=l07ooOol09Goo00<007ooOol03goo
000@Ool00`00Oomoo`0FOol00g`0Oomoo`0LOol00g`0Oomoo`0GOol>01l00gooO01oo`0LOol00g`0
Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0KOol00g`0Oomoo`0=Ool201l0
0`0001l07`0201l00`0001l07`0301l00`0001moo`09Ool00g`0Oomoo`0LOol00g`0Oomoo`0UOol0
0`00Oomoo`0?Ool0011oo`03001oogoo01Ioo`03O01oogoo01]oo`03O01oogoo01Qoo`h07`9oo`03
O01oogoo01Yoo`03O01oogoo031oo`03001oogoo00Moo`03001oogoo025oo`03O01oogoo01Yoo`03
O01oogoo00ioo`L07`0300007`0O00D07`]oo`03O01oogoo01]oo`03O01oogoo02Eoo`03001oogoo
00moo`0047oo00<007ooOol05Woo00=l07ooOol06Woo00=l07ooOol067oo3`0O0goo00=l07ooOol0
6Goo00=l07ooOol0<7oo00<007ooOol01goo00<007ooOol08Goo00=l07ooOol06Goo00=l07ooOol0
3goo1`0O00<0000O01l01@0O37oo00=l07ooOol06Woo00=l07ooOol09Goo00<007ooOol03goo000@
Ool00`00Oomoo`0FOol00g`0Oomoo`0IOol00g`0Oomoo`0JOol701l00`0001l07`0401l4Ool00g`0
Oomoo`0HOol00g`0Oomoo`0`Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00g`0Oomoo`0HOol00g`0
Oomoo`0@Ool701l00`0001l07`0501l=Ool00g`0Oomoo`0IOol00g`0Oomoo`0UOol00`00Oomoo`0?
Ool0011oo`03001oogoo01Ioo`03O01oogoo01Qoo`03O01oogoo01Yoo`L07`<000D07`Eoo`03O01o
ogoo01Moo`03O01oogoo031oo`03001oogoo00Moo`03001oogoo025oo`03O01oogoo01Moo`03O01o
ogoo015oo`L07`0300007`0O00D07`ioo`03O01oogoo01Qoo`03O01oogoo02Eoo`03001oogoo00mo
o`0047oo00<007ooOol05Woo6g`07Goo1P0O00D0000O00007`0000@07`IooaYl039oo`03001oogoo
00Moo`03001oogoo025ooaYl01Aoo`L07`0300007`0O00D07`mooa]l02Moo`03001oogoo00moo`00
47oo00<007ooOol0CWoo100O0P000P0O00@0000O01l000<07e9oo`03001oogoo00Moo`03001oogoo
04moo`L07`0300007`0O00D07e5oo`03001oogoo00moo`0047oo00<007ooOol0CWoo0`0O00<0000O
01l00P0O00D0000O01l07`0000807e9oo`03001oogoo00Moo`03001oogoo04moo`L07`0300007`0O
00D07e5oo`03001oogoo00moo`0047oo00<007ooOol08goo:`000P0O00<0000O01l00`0O00<0000O
01l00P0O00<0000O0000:`009Woo00<007ooOol01goo00<007ooOol08goo;0001`0O00<0000O01l0
1@0O:`009Woo00<007ooOol03goo000@Ool00`00Oomoo`0SOol[000801l00`0001l07`0401l/000V
Ool00`00Oomoo`07Ool00`00Oomoo`0SOol/000701l00`0001l07`0501l[000VOol00`00Oomoo`0?
Ool0011oo`03001oogoo02=oob/000P07`0300007`0O00@07b`002Ioo`03001oogoo00Moo`03001o
ogoo02=oob`000L07`0300007`0O00D07b/002Ioo`03001oogoo00moo`0047oo00<007ooOol08goo
:`00200O00<0000O01l0100O;0009Woo00<007ooOol01goo00<007ooOol08goo;0001`0O00<0000O
01l01@0O:`009Woo00<007ooOol03goo000@Ool00`00Oomoo`0SOol[000801l00`0001l07`0401l/
000VOol00`00Oomoo`07Ool00`00Oomoo`0SOol/000701l00`0001l07`0501l[000VOol00`00Oomo
o`0?Ool0011oo`03001oogoo02=oob/000P07`0300007`0O00@07b`002Ioo`03001oogoo00Moo`03
001oogoo02=oob`000L07`0300007`0O00D07b/002Ioo`03001oogoo00moo`0047oo00<007ooOol0
8goo:`00200O00<0000O01l0100O;0009Woo00<007ooOol01goo00<007ooOol08goo;0001`0O00<0
000O01l01@0O:`009Woo00<007ooOol03goo000@Ool00`00Oomoo`0SOol[000801l00`0001l07`04
01l/000VOol00`00Oomoo`07Ool00`00Oomoo`0SOol/000701l00`0001l07`0501l[000VOol00`00
Oomoo`0?Ool0011oo`03001oogoo02=oob/000P07`0300007`0O00@07b`002Ioo`03001oogoo00Mo
o`03001oogoo02=oob`000L07`0300007`0O00D07b/002Ioo`03001oogoo00moo`0047oo00<007oo
Ool08goo:`00200O00<0000O01l0100O;0009Woo00<007ooOol01goo00<007ooOol08goo;0001`0O
00<0000O01l01@0O:`009Woo00<007ooOol03goo000@Ool00`00Oomoo`1>Ool801l00`0001l07`04
01mBOol00`00Oomoo`07Ool00`00Oomoo`1?Ool701l00`0001l07`0501mAOol00`00Oomoo`0?Ool0
011oo`03001oogoo04ioo`P07`0300007`0O00@07e9oo`03001oogoo00Moo`03001oogoo04moo`L0
7`0300007`0O00D07e5oo`03001oogoo00moo`0047oo00<007ooOol0CWoo200O00<0000O01l0100O
DWoo00<007ooOol01goo00<007ooOol0Cgoo1`0O00<0000O01l01@0ODGoo00<007ooOol03goo000@
Ool00`00Oomoo`1>Ool801l00`0001l07`0401mBOol00`00Oomoo`07Ool00`00Oomoo`1?Ool701l0
0`0001l07`0501mAOol00`00Oomoo`0?Ool0011oo`03001oogoo04ioo`P07`0300007`0O00@07e9o
o`03001oogoo00Moo`03001oogoo04moo`L07`0300007`0O00D07e5oo`03001oogoo00moo`0047oo
00<007ooOol0CWoo200O00<0000O01l0100ODWoo00<007ooOol01goo00<007ooOol0Cgoo1`0O00<0
000O01l01@0ODGoo00<007ooOol03goo000@Ool00`00Oomoo`1>Ool801l00`0001l07`0401mBOol0
0`00Oomoo`07Ool00`00Oomoo`1?Ool701l00`0001l07`0501mAOol00`00Oomoo`0?Ool0011oo`03
001oogoo04ioo`P07`0300007`0O00@07e9oo`03001oogoo00Moo`03001oogoo04moo`L07`030000
7`0O00D07e5oo`03001oogoo00moo`0047oo00<007ooOol0CWoo200O00<0000O01l0100ODWoo00<0
07ooOol01goo00<007ooOol0Cgoo1`0O00<0000O01l01@0ODGoo00<007ooOol03goo000@Ool00`00
Oomoo`1>Ool801l00`0001l07`0401mBOol00`00Oomoo`07Ool00`00Oomoo`1?Ool701l00`0001l0
7`0501mAOol00`00Oomoo`0?Ool0011oo`03001oogoo04ioo`P07`0300007`0O00@07e9oo`03001o
ogoo00Moo`03001oogoo04moo`L07`0300007`0O00D07e5oo`03001oogoo00moo`0047oo00<007oo
Ool0CWoo200O00<0000O01l0100ODWoo00<007ooOol01goo00<007ooOol0Cgoo1`0O00<0000O01l0
1@0ODGoo00<007ooOol03goo000@Ool00`00Oomoo`1>Ool801l00`0001l07`0401mBOol00`00Oomo
o`07Ool00`00Oomoo`1?Ool701l00`0001l07`0501mAOol00`00Oomoo`0?Ool0011oo`03001oogoo
04ioo`P07`0300007`0O00@07e9oo`03001oogoo00Moo`03001oogoo04moo`L07`0300007`0O00D0
7e5oo`03001oogoo00moo`0047oo00<007ooOol0CWoo200O00<0000O01l0100ODWoo00<007ooOol0
1goo00<007ooOol0Cgoo1`0O00<0000O01l01@0ODGoo00<007ooOol03goo000@Ool00`00Oomoo`1>
Ool801l00`0001l07`0401mBOol00`00Oomoo`07Ool00`00Oomoo`1?Ool701l00`0001l07`0501mA
Ool00`00Oomoo`0?Ool0011oo`03001oogoo04ioo`P07`0300007`0O00@07e9oo`03001oogoo00Mo
o`03001oogoo04moo`l07e5oo`03001oogoo00moo`0047oo00<007ooOol0CWoo200O00<0000O01l0
100ODWoo00<007ooOol01goo00<007ooOol0Cgoo3`0ODGoo00<007ooOol03goo000@Ool00`00Oomo
o`1>Ool801l00`0001l07`0401mBOol00`00Oomoo`07Ool00`00Oomoo`1?Ool?01mAOol00`00Oomo
o`0?Ool0011oo`03001oogoo04ioo`P07`0300007`0O00@07e9oo`03001oogoo00Moo`03001oogoo
04moo`l07e5oo`03001oogoo00moo`0047oo00<007ooOol0CWoo200O00<0000O01l0100ODWoo00<0
07ooOol01goo00<007ooOol0Cgoo3`0ODGoo00<007ooOol03goo000@Ool00`00Oomoo`1>Ool801l0
0`0001l07`0401mBOol00`00Oomoo`07Ool00`00Oomoo`1?Ool?01mAOol00`00Oomoo`0?Ool0011o
o`03001oogoo04ioo`P07`0300007`0O00@07e9oo`03001oogoo00Moo`03001oogoo04moo`l07e5o
o`03001oogoo00moo`0047oo00<007ooOol0CWoo200O00<0000O01l0100ODWoo00<007ooOol01goo
00<007ooOol0Cgoo3`0ODGoo00<007ooOol03goo000@Ool00`00Oomoo`1>Ool?01mBOol00`00Oomo
o`07Ool00`00Oomoo`1?Ool?01mAOol00`00Oomoo`0?Ool0011oo`03001oogoo04ioo`l07e9oo`03
001oogoo00Moo`03001oogoo04moo`l07e5oo`03001oogoo00moo`0047oo00<007ooOol0CWoo3`0O
DWoo00<007ooOol01goo00<007ooOol0Cgoo3`0ODGoo00<007ooOol03goo000@Ool00`00Oomoo`1>
Ool?01mBOol00`00Oomoo`07Ool00`00Oomoo`1?Ool?01mAOol00`00Oomoo`0?Ool0011oo`03001o
ogoo04ioo`l07e9oo`03001oogoo00Moo`03001oogoo04moo`l07e5oo`03001oogoo00moo`0047oo
00<007ooOol0CWoo3`0ODWoo00<007ooOol01goo00<007ooOol0[goo00<007ooOol03goo000@Ool0
0`00Oomoo`1>Ool?01mBOol00`00Oomoo`07Ool00`00Oomoo`2_Ool00`00Oomoo`0?Ool0011oo`03
001oogoo04ioo`l07e9oo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo00moo`0047oo00<0
07ooOol0CWoo3`0ODWoo00<007ooOol01goo00<007ooOol0[goo00<007ooOol03goo000@Ool00`00
Oomoo`1>Ool?01mBOol00`00Oomoo`07Ool00`00Oomoo`2_Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo04ioo`l07e9oo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo00moo`0047oo00<007oo
Ool0CWoo3`0ODWoo00<007ooOol01goo00<007ooOol0[goo00<007ooOol03goo000@Ool00`00Oomo
o`1>Ool?01mBOol00`00Oomoo`07Ool00`00Oomoo`2_Ool00`00Oomoo`0?Ool0011oo`03001oogoo
0:moo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo00moo`0047oo00<007ooOol0EGoo00<0
07ooOol0Egoo00<007ooOol01goo00<007ooOol0EGoo00<007ooOol0Egoo00<007ooOol03goo000@
Ool00`00Oomoo`2_Ool00`00Oomoo`07Ool00`00Oomoo`2_Ool00`00Oomoo`0?Ool0011oo`03001o
ogoo0:moo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo00moo`0047oo00<007ooOol0[goo
00<007ooOol01goo00<007ooOol0[goo00<007ooOol03goo000@Ool00`00Oomoo`2_Ool00`00Oomo
o`07Ool00`00Oomoo`2_Ool00`00Oomoo`0?Ool0011oo`03001oogoo0:moo`03001oogoo00Moo`03
001oogoo0:moo`03001oogoo00moo`0047oo00<007ooOol0[goo00<007ooOol01goo00<007ooOol0
[goo00<007ooOol03goo000@Ool00`00Oomoo`2_Ool00`00Oomoo`07Ool00`00Oomoo`2_Ool00`00
Oomoo`0?Ool0011oo`03001oogoo0:moo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo00mo
o`0047oo00<007ooOol0[goo00<007ooOol01goo00<007ooOol0[goo00<007ooOol03goo000@Ool0
0`00Oomoo`2_Ool00`00Oomoo`07Ool00`00Oomoo`2_Ool00`00Oomoo`0?Ool0011oo`03001oogoo
0:moo`03001oogoo00Moo`03001oogoo0:moo`03001oogoo00moo`0047oo/`002Goo/`004Goo003o
OonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5o
o`00\
\>"],
  ImageRangeCache->{{{0, 399}, {131, 0}} -> {-0.0588348, -0.0165575, 
  0.00530745, 0.00530745}, {{11.0625, 199.5}, {127.875, 3.0625}} -> {-2.13447,
   -1.32347, 0.0392707, 0.0392707}, {{199.5, 387.875}, {127.875, 3.0625}} ->
   {-9.53715, -1.32432, 0.0392838, 0.0392838}}]
}, Open  ]],

Cell[TextData[{
  "Note again that the current values of the switch times (",
  StyleBox["tm2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["tm3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc.) are merely guesses. If the model is run at values very close to \
those times, incorrect results will be generated whenever the model uses the \
wrong constraint. The exact values of the switch times are found in the next \
subsection with the ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Finding Switch Times"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to seek the time at which two adjacent constraints in a \
",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are simultaneously valid, that is, to numerically find the correct switch \
time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FindSwitchTime[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, snum, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a solution to the current mechanism model that simultaneously \
satisfies two adjacent constraints in a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, while allowing time to vary. The constraint number of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is specified by ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", and which pair of adjacent constraints in the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is considered is specified by ",
  StyleBox["snum",
    FontSlant->"Italic"],
  ". With ",
  StyleBox["snum",
    FontSlant->"Italic"],
  " = 1, the conjunction of the first and second stages of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is sought."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A function for seeking stage transition times."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " works by adding one degree of freedom to the model (",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " becomes a dependent variable) and adding one extra constraint by using \
the pair of adjacent constraints simultaneously. ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the same solution block as ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so it uses the most recent solution returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") for its initial guess.\n\n",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts two options to deal with special situations that may arise in a \
pair of adjacent constraints, ",
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies that the pair of constraints being considered are a pair \
that come into conjunction tangentially. This implies that as the mechanism \
passes through the correct switch time, there is no discontinuity in the \
location or velocity of the mechanism components. When this is true, ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must use the velocity solution to seek the switch time. If ",
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used when the constraints are in fact a tangent pair, ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may have trouble converging. The default setting is ",
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies which equations of a multiple degree of freedom constraint \
set are used to seek the switch time. ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be a two element list: the first element applies to the first set \
of equations of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " pair, the second element applies to the second set. Allowable values for \
each element are a list of integers (1 through the number of degrees of \
freedom in the constraint), ",
  StyleBox["All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Sum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, all of the constraints in that side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are used. ",
  StyleBox["Sum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the sum of all the equations in the specified side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to be used as a single constraint, which may lead to a singularity. A \
list of integers uses the equations explicitly specified by their position in \
the constraint. The default setting is ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{All, Sum}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Options for ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To understand the need for the ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, imagine a two degree of freedom ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If both sides of the adjacent two degree of freedom constraint pair are \
used simultaneously, two extra constraints are added to the model, but only \
one degree of freedom (time) is added. This results in an overconstrained \
model to which no solution can be found.\n\nThe default setting ",
  StyleBox["RequiredEquations->{All, Sum}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " deals with this problem in a general but unsophisticated manner. All of \
the constraint equations from the first side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " pair are used, as well as a single equation formed from the sum of all \
the equations from the second side, resulting in the required one extra \
constraint equation. This combination of constraints is valid ",
  StyleBox["if",
    FontSlant->"Italic"],
  " all of the equations in the second side of the constraint pair except one \
are redundant with respect to the equations in the first side. Thus the \
redundant equations in the sum are satisfied because of the first side of the \
constraint pair, and the one nonredundant equation is satisfied by the \
satisfying the sum. However, if there is no redundancy in the pair this will \
not work, and the solution will fail. If the default setting fails, the user \
must explicitly specify which equations to use to seek the switch time.\n\n\
For example, take the following ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " example that was given in the beginning of this section."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " example."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(TimeSwitch[3, \n\t
      Revolute2[1, \n\t\tPoint[slider, {0, 0}], Point[ground, {0, 0}]], \n\t
      3.5, \n\t{
        PointOnLine1[1, \n\t\t\tPoint[slider, {0, 0}], 
          Axis[ground, {0, 0}, {1, 1}]], \n\t\t
        RelativeY1[1, Point[slider, {0, 0}], T - 4.0]}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "To seek the correct value of the switch time, which is currently set to \
3.5, the following ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " could be used with all of the default option settings. Note that the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is constraint 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a command to find the correct value of the switch time."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(FindSwitchTime[3, 1]\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The default setting for ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " works fine in this case because the first constraint equation in the \
second side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") is redundant with the first side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "), because the ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be satisfied for the ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to be satisfied.\n\nThe following example shows a setting for ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that explicitly specifies which equations to use. This setting would \
cause only the ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint to be used from the second side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a setting of the ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(FindSwitchTime[3, 1, RequiredEquations \[Rule] {All, {2}}]\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "When the ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used with a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that contains multiple degree of freedom constraint functions, such as ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (2D) or ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (3D), it is necessary to know exactly what each of the 2, 3, 4, or 5 \
equations in the constraint are doing, so that you can know which ones need \
to be specified with the ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. To find out \"which equation does what\", see the notes on the \
particular constraint function in the appendix."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Detent Mechanism Example"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In the detent mechanism example in the previous subsection, the values \
given for the switch times that were assigned variable names (",
  StyleBox["tm2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = -0.8, ",
  StyleBox["tm3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = -0.4, etc.) were merely guesses. ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to find the correct values of the switch times.\n\nThe first and \
sixth switch times were set to values of -1 and 1, respectively, which are \
exact values evident from the geometry of the detenter and notch. \n\nThe \
value of the second switch time must be found with ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is the time at which the detenter stops traveling around the sharp \
corner on the upper-right side of the detent notch and passes onto the \
inclined right side of the notch. These two adjacent constraints come into \
conjunction tangentially because there is no velocity discontinuity as the \
detenter passes onto the inclined flat side of the detent notch. Thus, ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must actually search for the point of tangency. This requires that the \
option ",
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " be specified. Before ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is invoked, ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to move the mechanism close to the correct position to provide \
better initial guesses."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This finds switch time 2 in constraint 4."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SolveMech[\(-1.1\)]; \)\), 
    \(FindSwitchTime[4, 2, TangentConstraint \[Rule] True]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      \(T \[Rule] \(-0.787867965203175035`\)\), ",", 
        \(X2 \[Rule] \(-0.787867965203175035`\)\), ",", \(Y2 \[Rule] 0.`\), 
        ",", \(Th2 \[Rule] 0.`\), ",", 
        RowBox[{"X3", "\[Rule]", 
          StyleBox["2.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(Y3 \[Rule] 1.21213203479682474`\), 
        ",", \(Th3 \[Rule] 0.`\), ",", \(X2d \[Rule] 1.`\), ",", 
        \(Y2d \[Rule] 0.`\), ",", \(Th2d \[Rule] 0.`\), ",", 
        \(X3d \[Rule] 0.`\), ",", \(Y3d \[Rule] \(-1.`\)\), ",", 
        \(Th3d \[Rule] 0.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This sets the value of ",
  StyleBox["tm2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tm2 = T /. %\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-0.787867965203175035`\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the detent mechanism at the tangency point associated with ",
  StyleBox["tm2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
  
%%Creator: Mathematica
 
  
%%AspectRatio: .66216 
 
  
MathPictureStart
 
  
%% Graphics
 
  
/Courier findfont 10  scalefont  setfont
 
  
% Scaling calculations
 
  
0.22973 0.135135 0.162162 0.135135 [
 
  
[ 0 0 0 0 ]
 
  
[ 1 .66216 0 0 ]
 
  
] MathScale
 
  
% Start of Graphics
 
  
1 setlinecap
 
  
1 setlinejoin
 
  
newpath
 
  
[ ] 0 setdash
 
  
0 g
 
  
p
 
  
P
 
  
0 0 m
 
  
1 0 L
 
  
1 .66216 L
 
  
0 .66216 L
 
  
closepath
 
  
clip
 
  
newpath
 
  
p
 
  
p
 
  
.22973 .14865 m
 
  
.77027 .14865 L
 
  
.77027 .09459 L
 
  
.22973 .09459 L
 
  
F
 
  
.22973 .31081 m
 
  
.44595 .31081 L
 
  
.44595 .36486 L
 
  
.22973 .36486 L
 
  
F
 
  
.55405 .31081 m
 
  
.77027 .31081 L
 
  
.77027 .36486 L
 
  
.55405 .36486 L
 
  
F
 
  
.004 w
 
  
.02703 .06757 m
 
  
.02703 .63514 L
 
  
.97297 .63514 L
 
  
.97297 .06757 L
 
  
.02703 .06757 L
 
  
s
 
  
p
 
  
.015 w
 
  
.22973 .16216 Mdot
 
  
.77027 .16216 Mdot
 
  
.5 .43243 Mdot
 
  
.5 .56757 Mdot
 
  
P
 
  
P
 
  
p
 
  
p
 
  
1 0 0 r
 
  
p
 
  
.004 w
 
  
.32596 .22973 m
 
  
.2584 .2973 L
 
  
.12326 .2973 L
 
  
.12326 .16216 L
 
  
.6638 .16216 L
 
  
.6638 .2973 L
 
  
.52867 .2973 L
 
  
.4611 .22973 L
 
  
s
 
  
P
 
  
.004 w
 
  
newpath
 
  
.39353 .2973 .09555 -135 -45 arc
 
  
s
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.12326 .16216 Mdot
 
  
.6638 .16216 Mdot
 
  
.12326 .2973 Mdot
 
  
.2584 .2973 Mdot
 
  
.32596 .22973 Mdot
 
  
.4611 .22973 Mdot
 
  
.52867 .2973 Mdot
 
  
.6638 .2973 Mdot
 
  
.39353 .2973 Mdot
 
  
P
 
  
P
 
  
P
 
  
p
 
  
p
 
  
0 0 1 r
 
  
.54054 .59623 m
 
  
.45946 .59623 L
 
  
.45946 .32596 L
 
  
.54054 .32596 L
 
  
F
 
  
.004 w
 
  
.5 .32596 m
 
  
.5 .32596 .04054 0 365.73 arc
 
  
F
 
  
0 0 0 r
 
  
p
 
  
.5 .32596 m
 
  
.5 .52867 L
 
  
s
 
  
.47133 .35463 m
 
  
.5 .32596 L
 
  
.52867 .35463 L
 
  
s
 
  
P
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.5 .32596 Mdot
 
  
.5 .59623 Mdot
 
  
P
 
  
P
 
  
P
 
  
P
 
  
% End of Graphics
 
  
MathPictureEnd
 
  

 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 186},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000^Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0008Oooo000:0009Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo
00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00
Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo
00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?mo
o`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomo
o`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`00
27oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOonH000hOol00`00
Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo
V000>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03
001oogoo03EooiP003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=GooV000>7oo00<007ooOol0
1goo0008Ool00`00Oomoo`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qo
o`03001oogoo00Moo`0027oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomo
o`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`00
27oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomo
o`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol05Woo0P007Goo
00<007ooOol0MWoo0P0077oo00<007ooOol0=Woo00<007ooOol01goo0008Ool00`00Oomoo`0EOol4
002DO004000JOol3000gOol00`00Oomoo`07Ool000Qoo`03001oogoo01Eoo`@001aoo`03001oogoo
07Eoo`@001]oo`03001oogoo03Ioo`03001oogoo00Moo`0027oo00<007ooOol05Woo0P0000=l07oo
Ool0Tgoo0P00EGoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`2DOol00g`0Oomo
o`1COol00`00Oomoo`07Ool000Qoo`03001oogoo01Qoo`03O01oogoo09Aoo`03O01oogoo05=oo`03
001oogoo00Moo`0027oo00<007ooOol067oo00=l07ooOol0U7oo00=l07ooOol0Dgoo00<007ooOol0
1goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`2DOol00g`0Oomoo`1COol00`00Oomoo`07Ool000Qo
o`03001oogoo01Qoo`03O01oogoo09Aoo`03O01oogoo05=oo`03001oogoo00Moo`0027oo00<007oo
Ool067oo00=l07ooOol0U7oo00=l07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol0
0g`0Oomoo`2DOol00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo01Qoo`03O01oogoo
09Aoo`03O01oogoo05=oo`03001oogoo00Moo`0027oo00<007ooOol067oo00=l07ooOol0@goo37`0
AGoo00=l07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`10Ool3O00<
Ool2O013Ool00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo01Qoo`03O01oogoo03io
o`9l015oo`=l041oo`03O01oogoo05=oo`03001oogoo00Moo`0027oo00<007ooOol067oo00=l07oo
Ool0>goo0g`05Woo0W`0?Woo00=l07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol0
0g`0Oomoo`0iOol2O00KOol2O00lOol00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo
01Qoo`03O01oogoo03Qoo`03O01oogoo01eoo`03O01oogoo03Uoo`03O01oogoo05=oo`03001oogoo
00Moo`0027oo00<007ooOol067oo00=l07ooOol0=goo00=l07ooOol07goo00=l07ooOol0>7oo00=l
07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`0dOol200000g`0Oomo
o`0QOol2000hOol00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo01Qoo`03O01oogoo
03=oo`@0029oo`@003Moo`03O01oogoo05=oo`03001oogoo00Moo`0027oo00<007ooOol067oo00=l
07ooOol0<goo10008Woo1000=goo00=l07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0H
Ool00g`0Oomoo`0cOol00g`00000000TOol200000gooO01oo`0eOol00g`0Oomoo`1COol00`00Oomo
o`07Ool000Qoo`03001oogoo01Qoo`03O01oogoo039oo`03O01oogoo02Uoo`03O01oogoo03=oo`03
O01oogoo05=oo`03001oogoo00Moo`0027oo00<007ooOol067oo00=l07ooOol0<Goo00=l07ooOol0
:goo00=l07ooOol0<Woo00=l07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00g`0
Oomoo`0`Ool00g`0Oomoo`0]Ool00g`0Oomoo`0aOol00g`0Oomoo`1COol00`00Oomoo`07Ool000Qo
o`03001oogoo01Qoo`03O01oogoo02moo`03O01oogoo02moo`03O01oogoo031oo`03O01oogoo05=o
o`03001oogoo00Moo`0027oo00<007ooOol067oo00=l07ooOol0;Woo00=l07ooOol0<Goo00=l07oo
Ool0;goo00=l07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`0]Ool0
0g`0Oomoo`0cOol00g`0Oomoo`0^Ool00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo
01Qoo`03O01oogoo02aoo`03O01oogoo03Eoo`03O01oogoo02eoo`03O01oogoo05=oo`03001oogoo
00Moo`0027oo00<007ooOol067oo00=l07ooOol0;7oo00=l07ooOol0=Woo00=l07ooOol0;7oo00=l
07ooOol0Dgoo00<007ooOol01goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`0[Ool00g`0Oomoo`0h
Ool00g`0Oomoo`0[Ool00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo01Qoo`03O01o
ogoo02Yoo`03O01oogoo03Yoo`03O01oogoo02Yoo`03O01oogoo05=oo`03001oogoo00Moo`0027oo
00<007ooOol067oo00=l07ooOol0:Goo00=l07ooOol0?7oo00=l07ooOol0:Goo00=l07ooOol0Dgoo
00<007ooOol01goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`0XOol00g`0Oomoo`0nOol00g`0Oomo
o`0XOol00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo01Qoo`03O01oogoo02Moo`03
O01oogoo041oo`03O01oogoo02Moo`03O01oogoo05=oo`03001oogoo00Moo`0027oo00<007ooOol0
67oo00=l07ooOol09Woo00=l07ooOol0>Goo1`0O0Woo00=l07ooOol09Woo00=l07ooOol0Dgoo00<0
07ooOol01goo0008Ool00`00Oomoo`0HOol00g`0Oomoo`0UOol00g`0Oomoo`0hOol<01l00g`0Oomo
o`0UOol00g`0Oomoo`1COol00`00Oomoo`07Ool000Qoo`03001oogoo01Ioo`800003O01oogoo025o
o`800003Ooml07oo025oo`8001Ioo`h07`8002Aoo`8005Eoo`03001oogoo00Moo`0027oo00<007oo
Ool05Goo10008W`010008Woo100057oo4@0O00<007`0O00087`01000E7oo00<007ooOol01goo0008
Ool00`00Oomoo`0EOol4000ROol4000ROol4000COolC01lROol4001DOol00`00Oomoo`07Ool000Qo
o`03001oogoo01Ioo`8002Aoo`8002Aoo`8001Aooa<07b=oo`8005Eoo`03001oogoo00Moo`0027oo
00<007ooOol0Mgoo5@0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`0eOolm0005OolE01l4Oolm
000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000AooaH07`Aoocd003Qoo`03001oogoo
00Moo`0027oo00<007ooOol0=Goo?@0017oo5P0O17oo?@00>7oo00<007ooOol01goo0008Ool00`00
Oomoo`0eOolm0004Ool:01l2000:01l4Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eo
ocd000Aoo`T07`@000T07`Aoocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo
2@0O10002@0O17oo?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOolm0004Ool901l30000
0`0O00007`0701l4Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000Aoo`P07`04
00007`0O000201l00`0001l07`0501l4Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eo
ocd000Aoo`L07`0500007`0O01l0000301l00`0001l07`0401l4Oolm000hOol00`00Oomoo`07Ool0
00Qoo`03001oogoo03Eoocd000Aoo`H07`0300007`0O00807`0300007`0O00807`0300007`0O00<0
7`Aoocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo1@0O00<0000O01l00`0O
00<0000O01l00`0O00<0000O01l00P0O17oo?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0e
Oolm0004Ool401l00`0001l07`0401l00`0001l07`0401l0100001l07`0O17oo?@00>7oo00<007oo
Ool01goo0008Ool00`00Oomoo`0eOolm0004Ool301l00`0001l07`0501l00`0001l07`0501l00`00
01l07`04Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000Aoo`/07`0300007`0O
00P07`Aoocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo2`0O00<0000O01l0
200O17oo?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol0
0`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`00
27oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1f
Ool;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O
00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007oo
Ool01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03
001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O
00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801mi
Ool00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Mo
o`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomo
o`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`030000
7`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<0
07ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qo
o`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo
2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`08
01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo
00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00
Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`03
00007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo
00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool0
00Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0
MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l0
7`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001o
ogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool0
0`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/0
7`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200O
NGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07
Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007oo
Ool0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`00
01l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03
001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008
Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Io
o`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0
200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomo
o`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<0
07ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l0
0`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Mo
o`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol0
0`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0
MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qo
o`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo00<007oo
Ool01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07IooaH0
7gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00
Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Mo
o`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol0
0`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0
MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol:01l2000:01miOol00`00Oomoo`07
Ool000Qoo`03001oogoo07Ioo`T07`@000T07gUoo`03001oogoo00Moo`0027oo00<007ooOol0Ogoo
1000PWoo00<007ooOol01goo0008Ool00`00Oomoo`20Ool20023Ool00`00Oomoo`07Ool000Qoo`03
001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008
Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Mo
o`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomo
o`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<0
07ooOol01goo0008Oooo000:0009Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo
6goo003oOolKOol00?mooa]oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {185, 0}} -> {-1.72138, -1.20002, 0.0264867, 
  0.0264867}}]
}, Open  ]],

Cell[TextData[{
  "The third switch point occurs when the detenter passes from the inclined \
right side of the detent notch onto the round bottom of the notch. This is \
also a tangent constraint pair, so ",
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used again."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"This finds and sets switch time 3 in constraint 4."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(tm3 = T /. FindSwitchTime[4, 3, TangentConstraint \[Rule] True]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-0.287867965644035717`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the detent mechanism at the tangency point associated with ",
  StyleBox["tm3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
 
  
%%Creator: Mathematica
 
  
%%AspectRatio: .66216 
 
  
MathPictureStart
 
  
%% Graphics
 
  
/Courier findfont 10  scalefont  setfont
 
  
% Scaling calculations
 
  
0.22973 0.135135 0.162162 0.135135 [
 
  
[ 0 0 0 0 ]
 
  
[ 1 .66216 0 0 ]
 
  
] MathScale
 
  
% Start of Graphics
 
  
1 setlinecap
 
  
1 setlinejoin
 
  
newpath
 
  
[ ] 0 setdash
 
  
0 g
 
  
p
 
  
P
 
  
0 0 m
 
  
1 0 L
 
  
1 .66216 L
 
  
0 .66216 L
 
  
closepath
 
  
clip
 
  
newpath
 
  
p
 
  
p
 
  
.22973 .14865 m
 
  
.77027 .14865 L
 
  
.77027 .09459 L
 
  
.22973 .09459 L
 
  
F
 
  
.22973 .31081 m
 
  
.44595 .31081 L
 
  
.44595 .36486 L
 
  
.22973 .36486 L
 
  
F
 
  
.55405 .31081 m
 
  
.77027 .31081 L
 
  
.77027 .36486 L
 
  
.55405 .36486 L
 
  
F
 
  
.004 w
 
  
.02703 .06757 m
 
  
.02703 .63514 L
 
  
.97297 .63514 L
 
  
.97297 .06757 L
 
  
.02703 .06757 L
 
  
s
 
  
p
 
  
.015 w
 
  
.22973 .16216 Mdot
 
  
.77027 .16216 Mdot
 
  
.5 .43243 Mdot
 
  
.5 .56757 Mdot
 
  
P
 
  
P
 
  
p
 
  
p
 
  
1 0 0 r
 
  
p
 
  
.004 w
 
  
.39353 .22973 m
 
  
.32596 .2973 L
 
  
.19083 .2973 L
 
  
.19083 .16216 L
 
  
.73137 .16216 L
 
  
.73137 .2973 L
 
  
.59623 .2973 L
 
  
.52867 .22973 L
 
  
s
 
  
P
 
  
.004 w
 
  
newpath
 
  
.4611 .2973 .09555 -135 -45 arc
 
  
s
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.19083 .16216 Mdot
 
  
.73137 .16216 Mdot
 
  
.19083 .2973 Mdot
 
  
.32596 .2973 Mdot
 
  
.39353 .22973 Mdot
 
  
.52867 .22973 Mdot
 
  
.59623 .2973 Mdot
 
  
.73137 .2973 Mdot
 
  
.4611 .2973 Mdot
 
  
P
 
  
P
 
  
P
 
  
p
 
  
p
 
  
0 0 1 r
 
  
.54054 .52867 m
 
  
.45946 .52867 L
 
  
.45946 .2584 L
 
  
.54054 .2584 L
 
  
F
 
  
.004 w
 
  
.5 .2584 m
 
  
.5 .2584 .04054 0 365.73 arc
 
  
F
 
  
0 0 0 r
 
  
p
 
  
.5 .2584 m
 
  
.5 .4611 L
 
  
s
 
  
.47133 .28706 m
 
  
.5 .2584 L
 
  
.52867 .28706 L
 
  
s
 
  
P
 
  
P
 
  
p
 
  
p
 
  
.02 w
 
  
.5 .2584 Mdot
 
  
.5 .52867 Mdot
 
  
P
 
  
P
 
  
P
 
  
P
 
  
% End of Graphics
 
  
MathPictureEnd
 
  

 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 186},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000^Q000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0008Oooo000:0009Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo
00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00
Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo
00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?mo
o`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomo
o`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`00
27oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOonH000hOol00`00
Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo
V000>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03
001oogoo03EooiP003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=GooV000>7oo00<007ooOol0
1goo0008Ool00`00Oomoo`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qo
o`03001oogoo00Moo`0027oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomo
o`0eOonH000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03EooiP003Qoo`03001oogoo00Moo`00
27oo00<007ooOol0=GooV000>7oo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomo
o`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0:Goo0P002Woo
00<007ooOol0R7oo0P002Woo00<007ooOol0=Woo00<007ooOol01goo0008Ool00`00Oomoo`0XOol4
002CO0040008Ool3000gOol00`00Oomoo`07Ool000Qoo`03001oogoo02Qoo`@000Uoo`03001oogoo
08Moo`@000Uoo`03001oogoo03Ioo`03001oogoo00Moo`0027oo00<007ooOol0:Goo0P0000=l07oo
Ool0TWoo0P0000=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0Oomoo`2D
Ool00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qoo`03001oogoo02]oo`03O01oogoo09Aoo`03O01o
ogoo041oo`03001oogoo00Moo`0027oo00<007ooOol0:goo00=l07ooOol0U7oo00=l07ooOol0@7oo
00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0Oomoo`2DOol00g`0Oomoo`10Ool00`00Oomo
o`07Ool000Qoo`03001oogoo02]oo`03O01oogoo09Aoo`03O01oogoo041oo`03001oogoo00Moo`00
27oo00<007ooOol0:goo00=l07ooOol0U7oo00=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00
Oomoo`0[Ool00g`0Oomoo`2DOol00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qoo`03001oogoo02]o
o`03O01oogoo09Aoo`03O01oogoo041oo`03001oogoo00Moo`0027oo00<007ooOol0:goo00=l07oo
Ool0@Woo3G`0AGoo00=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0Oomo
o`10Ool2O00=Ool2O013Ool00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qoo`03001oogoo02]oo`03
O01oogoo03ioo`9l015oo`=l041oo`03O01oogoo041oo`03001oogoo00Moo`0027oo00<007ooOol0
:goo00=l07ooOol0>goo0g`05Woo0W`0?Woo00=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00
Oomoo`0[Ool00g`0Oomoo`0iOol2O00KOol2O00lOol00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qo
o`03001oogoo02]oo`03O01oogoo03Qoo`03O01oogoo01Aoo`L07`9oo`03O01oogoo03Uoo`03O01o
ogoo041oo`03001oogoo00Moo`0027oo00<007ooOol0:goo00=l07ooOol0=goo00=l07ooOol04goo
2`0O00=oog`0Ool0>Goo00=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0
Oomoo`0dOol200000g`0Oomoo`0COol>01l2000hOol00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qo
o`03001oogoo02]oo`03O01oogoo03=oo`@001Aooa407`03001oogoo03Eoo`03O01oogoo041oo`03
001oogoo00Moo`0027oo00<007ooOol0:goo00=l07ooOol0<goo10004goo4`0O=goo00=l07ooOol0
@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0Oomoo`0cOol00g`00000000DOolC01l0
0g`0Oomoo`0dOol00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qoo`03001oogoo02]oo`03O01oogoo
039oo`03O01oogoo01AooaD07`03O01oogoo03=oo`03O01oogoo041oo`03001oogoo00Moo`0027oo
00<007ooOol0:goo00=l07ooOol0<Goo00=l07ooOol05Goo5@0O00=oog`0Ool0<goo00=l07ooOol0
@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0Oomoo`0`Ool00g`0Oomoo`0EOolF01l2
Ool00g`0Oomoo`0aOol00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qoo`03001oogoo02]oo`03O01o
ogoo02moo`03O01oogoo01IooaH07`=oo`03O01oogoo031oo`03O01oogoo041oo`03001oogoo00Mo
o`0027oo00<007ooOol0:goo00=l07ooOol0;Woo00=l07ooOol05goo2P0O0P002P0O17oo00=l07oo
Ool0;goo00=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0Oomoo`0]Ool0
0g`0Oomoo`0HOol901l4000901l5Ool00g`0Oomoo`0^Ool00g`0Oomoo`10Ool00`00Oomoo`07Ool0
00Qoo`03001oogoo02]oo`03O01oogoo02aoo`03O01oogoo01Uoo`T07`@000T07`Ioo`03O01oogoo
02eoo`03O01oogoo041oo`03001oogoo00Moo`0027oo00<007ooOol0:goo00=l07ooOol0:goo00=l
07ooOol06Woo2@0O0`0000<07`0001l01`0O1goo00=l07ooOol0;7oo00=l07ooOol0@7oo00<007oo
Ool01goo0008Ool00`00Oomoo`0[Ool00g`0Oomoo`0ZOol00g`0Oomoo`0KOol801l0100001l07`00
0P0O00<0000O01l01@0O27oo00=l07ooOol0:goo00=l07ooOol0@7oo00<007ooOol01goo0008Ool0
0`00Oomoo`0[Ool00g`0Oomoo`0YOol00g`0Oomoo`0LOol701l01@0001l07`0O00000`0O00<0000O
01l0100O2Goo00=l07ooOol0:Woo00=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[
Ool00g`0Oomoo`0XOol00g`0Oomoo`0MOol601l00`0001l07`0201l00`0001l07`0201l00`0001l0
7`0301l:Ool00g`0Oomoo`0YOol00g`0Oomoo`10Ool00`00Oomoo`07Ool000Qoo`03001oogoo02]o
o`03O01oogoo02Moo`03O01oogoo01ioo`D07`0300007`0O00<07`0300007`0O00<07`0300007`0O
00807`]oo`03O01oogoo02Qoo`03O01oogoo041oo`03001oogoo00Moo`0027oo00<007ooOol0:goo
00=l07ooOol09Woo00=l07ooOol07goo100O00<0000O01l0100O00<0000O01l0100O00@0000O01l0
7`aoo`03O01oogoo02Moo`03O01oogoo041oo`03001oogoo00Moo`0027oo00<007ooOol0:goo00=l
07ooOol09Goo00=l07ooOol087oo0`0O00<0000O01l01@0O00<0000O01l01@0O00<0000O01l03Goo
00=l07ooOol09Woo00=l07ooOol0@7oo00<007ooOol01goo0008Ool00`00Oomoo`0[Ool00g`0Oomo
o`0TOol00g`0Oomoo`0QOol;01l00`0001l07`0801l>Ool00g`0Oomoo`0UOol00g`0Oomoo`10Ool0
0`00Oomoo`07Ool000Qoo`03001oogoo02Uoo`800003O01oogoo025oo`800003O01oogoo025oo`03
00007`0O00T07`0300007`0O00P07`moo`8002=oo`800003O01oogoo041oo`03001oogoo00Moo`00
27oo00<007ooOol0:7oo10008W`010008Woo0P002`0O00<0000O01l0200O3Woo10008G`01000@Woo
00<007ooOol01goo0008Ool00`00Oomoo`0XOol4000ROol4000ROol2000;01l00`0001l07`0801l>
Ool4000QOol40012Ool00`00Oomoo`07Ool000Qoo`03001oogoo02Uoo`8002Aoo`8002Aoo`030000
7`0O00T07`0300007`0O00P07`moo`8002=oo`8004=oo`03001oogoo00Moo`0027oo00<007ooOol0
MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`0eOolm0004Ool;01l0
0`0001l07`0801l4Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000Aoo`/07`03
00007`0O00P07`Aoocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo2`0O00<0
000O01l0200O17oo?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOolm0004Ool;01l00`00
01l07`0801l4Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000Aoo`/07`030000
7`0O00P07`Aoocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo2`0O00<0000O
01l0200O17oo?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOolm0004Ool;01l00`0001l0
7`0801l4Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000Aoo`/07`0300007`0O
00P07`Aoocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo2`0O00<0000O01l0
200O17oo?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOolm0004Ool;01l00`0001l07`08
01l4Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000Aoo`/07`0300007`0O00P0
7`Aoocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo2`0O00<0000O01l0200O
17oo?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`0eOolm0004Ool;01l00`0001l07`0801l4
Oolm000hOol00`00Oomoo`07Ool000Qoo`03001oogoo03Eoocd000Aoo`/07`0300007`0O00P07`Ao
ocd003Qoo`03001oogoo00Moo`0027oo00<007ooOol0=Goo?@0017oo2`0O00<0000O01l0200O17oo
?@00>7oo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomo
o`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<0
07ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l0
0`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUo
o`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo
0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo
07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O
01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00
Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo
00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;
01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P0
7gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol0
1goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001o
ogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0
000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol0
0`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`00
27oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1f
Ool;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03001oogoo07Ioo`/07`0300007`0O
00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O00<0000O01l0200ONGoo00<007oo
Ool01goo0008Ool00`00Oomoo`1fOol;01l00`0001l07`0801miOol00`00Oomoo`07Ool000Qoo`03
001oogoo07Ioo`/07`0300007`0O00P07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2`0O
00<0000O01l0200ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07
Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo
00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo
07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008
Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001o
ogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF
01miOol00`00Oomoo`07Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<0
07ooOol0MWoo5P0ONGoo00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07
Ool000Qoo`03001oogoo07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo5P0ONGoo
00<007ooOol01goo0008Ool00`00Oomoo`1fOolF01miOol00`00Oomoo`07Ool000Qoo`03001oogoo
07IooaH07gUoo`03001oogoo00Moo`0027oo00<007ooOol0MWoo2P0O0P002P0ONGoo00<007ooOol0
1goo0008Ool00`00Oomoo`1fOol901l4000901miOol00`00Oomoo`07Ool000Qoo`03001oogoo07mo
o`@0089oo`03001oogoo00Moo`0027oo00<007ooOol0P7oo0P00Pgoo00<007ooOol01goo0008Ool0
0`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`00
27oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07
Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007oo
Ool01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03
001oogoo00Moo`0027oo00<007ooOol0P7oo00<007ooOol0PWoo00<007ooOol01goo0008Ool00`00
Oomoo`1oOol30023Ool00`00Oomoo`07Ool000Qoo`03001oogoo081oo`03001oogoo089oo`03001o
ogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool0
0`00Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo
1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo
0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00
Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo
00<007ooOol0ogoo1Woo00<007ooOol01goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool0
00Qoo`03001oogoo0?moo`Ioo`03001oogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol0
1goo0008Ool00`00Oomoo`3oOol6Ool00`00Oomoo`07Ool000Qoo`03001oogoo0?moo`Ioo`03001o
ogoo00Moo`0027oo00<007ooOol0ogoo1Woo00<007ooOol01goo0008Oooo000:0009Ool00?mooa]o
o`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {185, 0}} -> {-1.72138, -1.20002, 0.0264867, 
  0.0264867}}]
}, Open  ]],

Cell[TextData[{
  "Because of symmetry, the values of ",
  StyleBox["tm4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["tm5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are known to be the negatives of ",
  StyleBox["tm3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["tm2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", respectively. With all of the switch times set to valid values, the \
detent mechanism model can be run at any value of time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Now set the last two switch times."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(tm4 = \(-tm3\); \)\), 
    \(\(tm5 = \(-tm2\); \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following statements generate the graphics in this section. These ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands are defined in Chapter 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Detenter"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
p1=Graphics[{PointSize[.015],
  Polygon[ {{0,-.1},{4,-.1},{4,-.5},{0,-.5}} ],
  Polygon[ {{0,1.1},{1.6,1.1},{1.6,1.5},{0,1.5}} ],
  Polygon[ {{2.4,1.1},{4,1.1},{4,1.5},{2.4,1.5}} ],
  Line[{{-1.5,-.7},{-1.5,3.5},{5.5,3.5},{5.5,-.7},{-1.5,-.7}}],
  Vertex[ground, {1,2,3,4}] },
    AspectRatio->Automatic,PlotRange->{{-1.7,5.7},{-1.2,3.7}}];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t1=Graphics[\n  {Text[\"{0,0}\",  { 0, 0},{ 1.2, 1.4}],\n   Text[\"P1\",     \
{ 0, 0},{ 1.8,-1.4}],\n   Text[\"{4,0}\",  { 4, 0},{-1.2, 1.4}],\n   \
Text[\"P2\",     { 4, 0},{-1.8,-1.4}],\n   Text[\"{2,2}\",  { 2, 2},{-1.3, \
0.0}],\n   Text[\"P3\",     { 2, 2},{ 2.0, 0.0}],\n   Text[\"{2,3}\",  { 2, \
3},{-1.3, 0.0}],\n   Text[\"P4\",     { 2, 3},{ 2.0, 0.0}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g1=Show[{p1,t1}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p2=Graphics[{\n  {RGBColor[1,0,0],\n   Edge[slider, {5,4,3,1,2,8,7,6} ],\n   \
Circle[Location[slider,9],1/Sqrt[2],\n         \
{Angle[slider,9,5],Angle[slider,9,6]} ] },\n  {PointSize[.02],\n   \
Vertex[slider,Range[9]]}},\n    \
AspectRatio->Automatic,PlotRange->{{-1.7,5.7},{-1.2,3.7}}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t2=Graphics[{Text[\"P1\",Location[slider,1],  {-1.6,-1.6}],\n             \
Text[\"P2\",Location[slider,2],  {-1.6,-1.6}],\n             \
Text[\"P3\",Location[slider,3],  {-1.6,-1.6}],\n             \
Text[\"P4\",Location[slider,4],  {-1.6,-1.6}],\n             \
Text[\"P5\",Location[slider,5],  {-1.6,-1.6}],\n             \
Text[\"P6\",Location[slider,6],  {-1.6, 1.6}],\n             \
Text[\"P7\",Location[slider,7],  {-1.6,-1.6}],\n             \
Text[\"P8\",Location[slider,8],  {-1.6,-1.6}],\n             \
Text[\"P9\",Location[slider,9],  {-1.6,-1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g2=Show[{p2,t2}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p3=Graphics[{\n  {RGBColor[.4,.4,1],\n   Bar[Line[detenter,2,1],.3],\n   \
Disk[Location[detenter,1],.3]},\n   Arrow[Line[detenter,1,2],1.5, \
Reverse->True],\n  {PointSize[.02],Vertex[detenter,{1,2}]}},\n   \
AspectRatio->Automatic,PlotRange->{{-1.7,5.7},{-1.2,3.7}}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t3=Graphics[{Text[\"{0,0}\",Location[detenter,1],{-1.9,0}],\n             \
Text[\"P1\",   Location[detenter,1],{ 3.2,0}],\n             Text[\"{0,2}\", \
Location[detenter,2],{-1.3,-1.6}],\n             Text[\"P2\",    \
Location[detenter,2],{ 1.8,-1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g3=Show[{p3,t3}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{p1,p2,p3}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[{{g1},{g2},{g3}},Frame->True,\n  GraphicsSpacing->0]];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{p1,p2,p3}/.#]&/@postab;"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[GraphicsArray[%],GraphicsSpacing->0];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 700},
WindowMargins->{{50, Automatic}, {Automatic, 15}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 90, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1846, 57, 88, 2, 47, "Subsection"],
Cell[1937, 61, 793, 18, 147, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2767, 84, 133, 3, 33, "Section",
  PageBreakAbove->True],
Cell[2903, 89, 538, 15, 91, "Text"],

Cell[CellGroupData[{
Cell[3466, 108, 91, 2, 47, "Subsection"],

Cell[CellGroupData[{
Cell[3582, 114, 1563, 63, 87, "Special3"],
Cell[5148, 179, 157, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[5320, 186, 2211, 74, 251, "Text"],

Cell[CellGroupData[{
Cell[7556, 264, 92, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[7673, 270, 188, 8, 24, "SmallText"],
Cell[7864, 280, 84, 2, 25, "Input"]
}, Open  ]],
Cell[7963, 285, 507, 14, 92, "Text"],

Cell[CellGroupData[{
Cell[8495, 303, 198, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[8718, 315, 104, 3, 45, "Input"],
Cell[8825, 320, 291, 6, 145, "Input"],
Cell[9119, 328, 61, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[9207, 333, 833, 24, 132, "Text"],

Cell[CellGroupData[{
Cell[10065, 361, 197, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[10287, 373, 402, 8, 185, "Input"],
Cell[10692, 383, 61, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[10826, 392, 104, 2, 31, "Subsection"],
Cell[10933, 396, 1002, 24, 207, "Text"],

Cell[CellGroupData[{
Cell[11960, 424, 116, 2, 24, "SmallText"],
Cell[12079, 428, 13946, 289, 242, 1484, 130, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[26040, 720, 90, 2, 43, "Subsubsection"],
Cell[26133, 724, 126, 2, 33, "Text"],
Cell[26262, 728, 233, 5, 59, "Special1"],
Cell[26498, 735, 269, 5, 59, "Special1"],
Cell[26770, 742, 262, 5, 59, "Special1"],
Cell[27035, 749, 127, 2, 24, "SmallText"],
Cell[27165, 753, 30437, 585, 558, 2788, 239, "GraphicsData", 
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[57627, 1342, 140, 3, 24, "SmallText"],
Cell[57770, 1347, 134, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57941, 1356, 221, 7, 24, "SmallText"],
Cell[58165, 1365, 129, 3, 25, "Input"]
}, Open  ]],
Cell[58309, 1371, 94, 2, 43, "Subsubsection"],
Cell[58406, 1375, 248, 8, 53, "Text"],
Cell[58657, 1385, 434, 15, 43, "Special1"],
Cell[59094, 1402, 295, 11, 26, "Special1"],
Cell[59392, 1415, 403, 14, 44, "Special1"],
Cell[59798, 1431, 313, 9, 43, "Special1"],
Cell[60114, 1442, 393, 13, 44, "Special1"],
Cell[60510, 1457, 495, 20, 43, "Special2"],
Cell[61008, 1479, 452, 17, 43, "Special2"],

Cell[CellGroupData[{
Cell[61485, 1500, 137, 3, 24, "SmallText"],
Cell[61625, 1505, 544, 11, 245, "Input"]
}, Open  ]],
Cell[62184, 1519, 91, 2, 43, "Subsubsection"],
Cell[62278, 1523, 427, 16, 54, "Text"],

Cell[CellGroupData[{
Cell[62730, 1543, 224, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[62979, 1555, 117, 3, 45, "Input"],
Cell[63099, 1560, 420, 9, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63568, 1575, 283, 12, 24, "SmallText"],
Cell[63854, 1589, 14009, 290, 242, 1486, 130, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[77878, 1882, 420, 16, 54, "Text"],

Cell[CellGroupData[{
Cell[78323, 1902, 213, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[78561, 1914, 110, 3, 45, "Input"],
Cell[78674, 1919, 432, 10, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[79155, 1935, 284, 12, 24, "SmallText"],
Cell[79442, 1949, 13802, 287, 242, 1478, 130, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[93293, 2242, 109, 2, 31, "Subsection"],
Cell[93405, 2246, 1084, 25, 227, "Text"],

Cell[CellGroupData[{
Cell[94514, 2275, 125, 2, 24, "SmallText"],
Cell[94642, 2279, 22550, 4824, 120, 15387, 4730, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[117207, 7106, 90, 2, 43, "Subsubsection"],
Cell[117300, 7110, 132, 3, 33, "Text"],
Cell[117435, 7115, 316, 6, 76, "Special1"],
Cell[117754, 7123, 270, 5, 59, "Special1"],
Cell[118027, 7130, 131, 3, 24, "SmallText"],
Cell[118161, 7135, 16046, 343, 279, 1939, 164, "GraphicsData", 
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[134232, 7482, 140, 3, 24, "SmallText"],
Cell[134375, 7487, 104, 3, 45, "Input"]
}, Open  ]],
Cell[134494, 7493, 94, 2, 43, "Subsubsection"],
Cell[134591, 7497, 252, 8, 53, "Text"],
Cell[134846, 7507, 394, 16, 44, "Special1"],
Cell[135243, 7525, 295, 9, 43, "Special1"],
Cell[135541, 7536, 247, 9, 26, "Special1"],
Cell[135791, 7547, 305, 9, 43, "Special2"],
Cell[136099, 7558, 303, 9, 43, "Special2"],
Cell[136405, 7569, 440, 11, 91, "Text"],

Cell[CellGroupData[{
Cell[136870, 7584, 132, 3, 24, "SmallText"],
Cell[137005, 7589, 524, 10, 225, "Input"]
}, Open  ]],
Cell[137544, 7602, 91, 2, 43, "Subsubsection"],
Cell[137638, 7606, 571, 18, 73, "Text"],

Cell[CellGroupData[{
Cell[138234, 7628, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[138446, 7640, 71, 2, 25, "Input"],
Cell[138520, 7644, 99, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[138668, 7652, 156, 4, 24, "SmallText"],
Cell[138827, 7658, 22494, 4823, 120, 15384, 4730, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161358, 12486, 234, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[161617, 12498, 73, 2, 25, "Input"],
Cell[161693, 12502, 309, 8, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[162051, 12516, 98, 2, 24, "SmallText"],
Cell[162152, 12520, 22550, 4824, 120, 15387, 4730, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[184739, 17349, 191, 8, 24, "SmallText"],
Cell[184933, 17359, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[185051, 17367, 91, 2, 31, "Subsection"],
Cell[185145, 17371, 264, 8, 53, "Text"],
Cell[185412, 17381, 89, 2, 43, "Subsubsection"],
Cell[185504, 17385, 319, 9, 133, "Input"],
Cell[185826, 17396, 266, 5, 97, "Input"],
Cell[186095, 17403, 92, 2, 25, "Input"],
Cell[186190, 17407, 344, 6, 169, "Input"],
Cell[186537, 17415, 303, 6, 79, "Input"],
Cell[186843, 17423, 105, 2, 25, "Input"],
Cell[186951, 17427, 355, 6, 169, "Input"],
Cell[187309, 17435, 267, 5, 97, "Input"],
Cell[187579, 17442, 105, 2, 25, "Input"],
Cell[187687, 17446, 144, 4, 43, "Input"],
Cell[187834, 17452, 152, 4, 43, "Input"],
Cell[187989, 17458, 94, 2, 43, "Subsubsection"],
Cell[188086, 17462, 245, 5, 70, "Input"],
Cell[188334, 17469, 336, 6, 70, "Input"],
Cell[188673, 17477, 92, 2, 70, "Input"],
Cell[188768, 17481, 268, 5, 70, "Input"],
Cell[189039, 17488, 358, 6, 70, "Input"],
Cell[189400, 17496, 105, 2, 70, "Input"],
Cell[189508, 17500, 114, 2, 70, "Input"],
Cell[189625, 17504, 147, 4, 70, "Input"],
Cell[189775, 17510, 85, 2, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[189909, 17518, 132, 3, 33, "Section",
  PageBreakAbove->True],
Cell[190044, 17523, 1426, 42, 210, "Text"],

Cell[CellGroupData[{
Cell[191495, 17569, 90, 2, 47, "Subsection"],

Cell[CellGroupData[{
Cell[191610, 17575, 1985, 80, 119, "Special3"],
Cell[193598, 17657, 148, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[193761, 17663, 766, 21, 112, "Text"],

Cell[CellGroupData[{
Cell[194552, 17688, 92, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[194669, 17694, 188, 8, 24, "SmallText"],
Cell[194860, 17704, 84, 2, 25, "Input"]
}, Open  ]],
Cell[194959, 17709, 595, 15, 130, "Text"],

Cell[CellGroupData[{
Cell[195579, 17728, 196, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[195800, 17740, 313, 8, 165, "Input"],
Cell[196116, 17750, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[196203, 17755, 726, 19, 111, "Text"],

Cell[CellGroupData[{
Cell[196954, 17778, 196, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[197175, 17790, 308, 6, 145, "Input"],
Cell[197486, 17798, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[197619, 17807, 104, 2, 31, "Subsection"],
Cell[197726, 17811, 720, 20, 149, "Text"],
Cell[198449, 17833, 681, 10, 147, "Text"],

Cell[CellGroupData[{
Cell[199155, 17847, 116, 2, 24, "SmallText"],
Cell[199274, 17851, 37881, 7964, 232, 22864, 7773, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[237170, 25818, 89, 2, 43, "Subsubsection"],
Cell[237262, 25822, 137, 3, 33, "Text"],
Cell[237402, 25827, 317, 6, 59, "Special1"],
Cell[237722, 25835, 381, 7, 76, "Special1"],
Cell[238106, 25844, 211, 4, 42, "Special1"],

Cell[CellGroupData[{
Cell[238342, 25852, 132, 3, 24, "SmallText"],
Cell[238477, 25857, 133, 4, 65, "Input"],
Cell[238613, 25863, 178, 3, 97, "Input"],
Cell[238794, 25868, 295, 5, 187, "Input"],
Cell[239092, 25875, 185, 3, 79, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[239314, 25883, 137, 3, 24, "SmallText"],
Cell[239454, 25888, 25350, 551, 398, 3571, 277, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264841, 26444, 129, 3, 24, "SmallText"],
Cell[264973, 26449, 106, 2, 25, "Input"]
}, Open  ]],
Cell[265094, 26454, 95, 2, 43, "Subsubsection"],
Cell[265192, 26458, 248, 8, 53, "Text"],
Cell[265443, 26468, 381, 12, 43, "Special1"],
Cell[265827, 26482, 381, 12, 43, "Special1"],
Cell[266211, 26496, 438, 16, 44, "Special1"],
Cell[266652, 26514, 219, 8, 26, "Special1"],
Cell[266874, 26524, 377, 9, 60, "Special2"],
Cell[267254, 26535, 432, 10, 77, "Special2"],
Cell[267689, 26547, 472, 11, 77, "Special2"],
Cell[268164, 26560, 659, 21, 93, "Text"],

Cell[CellGroupData[{
Cell[268848, 26585, 118, 2, 24, "SmallText"],
Cell[268969, 26589, 308, 5, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[269314, 26599, 204, 8, 24, "SmallText"],
Cell[269521, 26609, 804, 17, 309, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[270362, 26631, 136, 3, 24, "SmallText"],
Cell[270501, 26636, 101, 2, 25, "Input"]
}, Open  ]],
Cell[270617, 26641, 91, 2, 43, "Subsubsection"],
Cell[270711, 26645, 432, 16, 54, "Text"],

Cell[CellGroupData[{
Cell[271168, 26665, 113, 2, 24, "SmallText"],
Cell[271284, 26669, 160, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271481, 26679, 191, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[271697, 26691, 78, 2, 25, "Input"],
Cell[271778, 26695, 577, 14, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[272404, 26715, 199, 8, 24, "SmallText"],
Cell[272606, 26725, 13254, 529, 194, 2102, 386, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[285897, 27259, 288, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[286210, 27275, 99, 2, 25, "Input"],
Cell[286312, 27279, 1224, 30, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[287585, 27315, 140, 3, 24, "SmallText"],
Cell[287728, 27320, 18506, 1033, 140, 4681, 857, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[306249, 28356, 639, 19, 92, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[306925, 28380, 100, 2, 31, "Subsection"],
Cell[307028, 28384, 464, 17, 73, "Text"],
Cell[307495, 28403, 1171, 39, 119, "Special3"],
Cell[308669, 28444, 149, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[308821, 28449, 1236, 41, 172, "Text"],
Cell[310060, 28492, 3056, 93, 323, "Special3"],
Cell[313119, 28587, 209, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[313331, 28598, 1901, 40, 399, "Text"],

Cell[CellGroupData[{
Cell[315257, 28642, 187, 8, 24, "SmallText"],
Cell[315447, 28652, 337, 7, 145, "Input"]
}, Open  ]],
Cell[315799, 28662, 430, 13, 74, "Text"],

Cell[CellGroupData[{
Cell[316254, 28679, 146, 4, 24, "SmallText"],
Cell[316403, 28685, 101, 3, 25, "Input"]
}, Open  ]],
Cell[316519, 28691, 1366, 47, 173, "Text"],

Cell[CellGroupData[{
Cell[317910, 28742, 209, 8, 24, "SmallText"],
Cell[318122, 28752, 139, 3, 25, "Input"]
}, Open  ]],
Cell[318276, 28758, 919, 27, 132, "Text"],
Cell[319198, 28787, 107, 2, 43, "Subsubsection"],
Cell[319308, 28791, 1885, 50, 325, "Text"],

Cell[CellGroupData[{
Cell[321218, 28845, 120, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[321363, 28851, 149, 3, 45, "Input"],
Cell[321515, 28856, 636, 13, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[322200, 28875, 185, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[322410, 28887, 71, 2, 25, "Input"],
Cell[322484, 28891, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[322593, 28898, 229, 8, 24, "SmallText"],
Cell[322825, 28908, 13333, 530, 194, 2096, 386, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[336173, 29441, 458, 14, 73, "Text"],
Cell[336634, 29457, 130, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[336789, 29464, 125, 3, 25, "Input"],
Cell[336917, 29469, 60, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[337014, 29475, 229, 8, 24, "SmallText"],
Cell[337246, 29485, 13452, 531, 194, 2094, 386, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[350713, 30019, 590, 21, 73, "Text"],

Cell[CellGroupData[{
Cell[351328, 30044, 113, 2, 24, "SmallText"],
Cell[351444, 30048, 112, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[351593, 30056, 189, 8, 24, "SmallText"],
Cell[351785, 30066, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[351903, 30074, 91, 2, 31, "Subsection"],
Cell[351997, 30078, 264, 8, 53, "Text"],
Cell[352264, 30088, 91, 2, 43, "Subsubsection"],
Cell[352358, 30092, 413, 10, 169, "Input"],
Cell[352774, 30104, 442, 7, 169, "Input"],
Cell[353219, 30113, 92, 2, 25, "Input"],
Cell[353314, 30117, 366, 7, 169, "Input"],
Cell[353683, 30126, 641, 11, 187, "Input"],
Cell[354327, 30139, 105, 2, 25, "Input"],
Cell[354435, 30143, 345, 6, 151, "Input"],
Cell[354783, 30151, 334, 6, 120, "Input"],
Cell[355120, 30159, 105, 2, 30, "Input"],
Cell[355228, 30163, 105, 2, 30, "Input"],
Cell[355336, 30167, 152, 4, 48, "Input"],
Cell[355491, 30173, 104, 2, 30, "Input"],
Cell[355598, 30177, 117, 2, 30, "Input"],
Cell[355718, 30181, 85, 2, 30, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

