(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    971291,      33655]*)
(*NotebookOutlinePosition[    972234,      33687]*)
(*  CellTagsIndexPosition[    972190,      33683]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["6.  Cams and Gears", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers the modeling of contacting cam surfaces and gear \
trains with ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  ". Cam constraints allow the definition of arbitrary curves or surfaces \
that operate in tangent contact with other curves, surfaces, or points in a ",
  
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. Cams are supported in 2D or 3D models, and 3D cams may be spatial \
curves or surfaces.\n\nGear constraints are used to model several types of \
nominal gear relationships, such as a pair of spur gears, a rack and pinion, \
or a lead screw. These constraints are referred to as nominal gear \
constraints because only the nominal rotary motion is modeled, not the \
tooth-to-tooth interactions of an involute gear set."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["6.1  Cam Constraints"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "A cam relationship is considered to be any relationship in which an \
arbitrarily defined space curve or surface is constrained to be in intimate \
contact with another point, curve, or surface. ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " provides several special constraint functions that allow such arbitrary \
geometric elements to be used in the mechanism model. The definitive \
characteristic of cam constraints is that they force two surfaces to be \
simultaneously in contact with each other and, in most cases, tangent with \
each other at the point of contact."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Cam Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The 2D cam constraints provided by ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cover four elementary cases of a cam and follower mechanism. In each \
case, the cam surface is defined by the locus of a single 2D point that is a \
function of one symbolic parameter. For example, the following 2D points are \
defined parametrically as functions of the symbol ",
  StyleBox["s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Each of these ",
  StyleBox["locuspointi",
    FontSlant->"Italic"],
  " would be valid as a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam profile."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a valid ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam profile."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(locuspoint1 = {s, Sin[s\^2]}; \)\), 
    \(\(ParametricPlot[Evaluate[locuspoint1], {s, \(-2\), 2}, 
      AspectRatio \[Rule] Automatic]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4392 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.190648 0.238095 [
[.02381 .17815 -6 -9 ]
[.02381 .17815 6 0 ]
[.2619 .17815 -6 -9 ]
[.2619 .17815 6 0 ]
[.7381 .17815 -3 -9 ]
[.7381 .17815 3 0 ]
[.97619 .17815 -3 -9 ]
[.97619 .17815 3 0 ]
[.4875 .01208 -30 -4.5 ]
[.4875 .01208 0 4.5 ]
[.4875 .0716 -24 -4.5 ]
[.4875 .0716 0 4.5 ]
[.4875 .13112 -30 -4.5 ]
[.4875 .13112 0 4.5 ]
[.4875 .25017 -24 -4.5 ]
[.4875 .25017 0 4.5 ]
[.4875 .3097 -18 -4.5 ]
[.4875 .3097 0 4.5 ]
[.4875 .36922 -24 -4.5 ]
[.4875 .36922 0 4.5 ]
[.4875 .42874 -6 -4.5 ]
[.4875 .42874 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .4392 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .19065 m
.02381 .1969 L
s
[(-2)] .02381 .17815 0 1 Mshowa
.2619 .19065 m
.2619 .1969 L
s
[(-1)] .2619 .17815 0 1 Mshowa
.7381 .19065 m
.7381 .1969 L
s
[(1)] .7381 .17815 0 1 Mshowa
.97619 .19065 m
.97619 .1969 L
s
[(2)] .97619 .17815 0 1 Mshowa
.125 Mabswid
.07143 .19065 m
.07143 .1944 L
s
.11905 .19065 m
.11905 .1944 L
s
.16667 .19065 m
.16667 .1944 L
s
.21429 .19065 m
.21429 .1944 L
s
.30952 .19065 m
.30952 .1944 L
s
.35714 .19065 m
.35714 .1944 L
s
.40476 .19065 m
.40476 .1944 L
s
.45238 .19065 m
.45238 .1944 L
s
.54762 .19065 m
.54762 .1944 L
s
.59524 .19065 m
.59524 .1944 L
s
.64286 .19065 m
.64286 .1944 L
s
.69048 .19065 m
.69048 .1944 L
s
.78571 .19065 m
.78571 .1944 L
s
.83333 .19065 m
.83333 .1944 L
s
.88095 .19065 m
.88095 .1944 L
s
.92857 .19065 m
.92857 .1944 L
s
.25 Mabswid
0 .19065 m
1 .19065 L
s
.5 .01208 m
.50625 .01208 L
s
[(-0.75)] .4875 .01208 1 0 Mshowa
.5 .0716 m
.50625 .0716 L
s
[(-0.5)] .4875 .0716 1 0 Mshowa
.5 .13112 m
.50625 .13112 L
s
[(-0.25)] .4875 .13112 1 0 Mshowa
.5 .25017 m
.50625 .25017 L
s
[(0.25)] .4875 .25017 1 0 Mshowa
.5 .3097 m
.50625 .3097 L
s
[(0.5)] .4875 .3097 1 0 Mshowa
.5 .36922 m
.50625 .36922 L
s
[(0.75)] .4875 .36922 1 0 Mshowa
.5 .42874 m
.50625 .42874 L
s
[(1)] .4875 .42874 1 0 Mshowa
.125 Mabswid
.5 .02398 m
.50375 .02398 L
s
.5 .03589 m
.50375 .03589 L
s
.5 .04779 m
.50375 .04779 L
s
.5 .0597 m
.50375 .0597 L
s
.5 .08351 m
.50375 .08351 L
s
.5 .09541 m
.50375 .09541 L
s
.5 .10731 m
.50375 .10731 L
s
.5 .11922 m
.50375 .11922 L
s
.5 .14303 m
.50375 .14303 L
s
.5 .15493 m
.50375 .15493 L
s
.5 .16684 m
.50375 .16684 L
s
.5 .17874 m
.50375 .17874 L
s
.5 .20255 m
.50375 .20255 L
s
.5 .21446 m
.50375 .21446 L
s
.5 .22636 m
.50375 .22636 L
s
.5 .23827 m
.50375 .23827 L
s
.5 .26208 m
.50375 .26208 L
s
.5 .27398 m
.50375 .27398 L
s
.5 .28589 m
.50375 .28589 L
s
.5 .29779 m
.50375 .29779 L
s
.5 .3216 m
.50375 .3216 L
s
.5 .33351 m
.50375 .33351 L
s
.5 .34541 m
.50375 .34541 L
s
.5 .35731 m
.50375 .35731 L
s
.5 .38112 m
.50375 .38112 L
s
.5 .39303 m
.50375 .39303 L
s
.5 .40493 m
.50375 .40493 L
s
.5 .41684 m
.50375 .41684 L
s
.5 .00017 m
.50375 .00017 L
s
.25 Mabswid
.5 0 m
.5 .4392 L
s
0 0 m
1 0 L
1 .4392 L
0 .4392 L
closepath
clip
newpath
.5 Mabswid
.02381 .01046 m
.06244 .13505 L
.10458 .27973 L
.12507 .33698 L
.13506 .36016 L
.14415 .37831 L
.15297 .39318 L
.16254 .40626 L
.1678 .41212 L
.17265 .4167 L
.17764 .4206 L
.18221 .42348 L
.18687 .42575 L
.18943 .42672 L
.19188 .42746 L
.19412 .42799 L
.19621 .42835 L
.19741 .42851 L
.19849 .42862 L
.19975 .4287 L
.20093 .42874 L
.20213 .42874 L
.20344 .4287 L
.2041 .42866 L
.20481 .42861 L
.20609 .42848 L
.20737 .42831 L
.20858 .42811 L
.21084 .42765 L
.21351 .42695 L
.21597 .42615 L
.22156 .42385 L
.23119 .41838 L
.24022 .41173 L
.26083 .39216 L
.29951 .34567 L
.34065 .29376 L
.38028 .25021 L
.41839 .21856 L
.438 .20678 L
.4489 .20161 L
.45895 .19773 L
.46919 .19464 L
.47458 .19336 L
.48029 .19228 L
.48525 .19156 L
.48989 .19108 L
.49255 .19088 L
.49381 .19081 L
.49498 .19075 L
Mistroke
.49632 .19071 L
.49703 .19069 L
.49778 .19067 L
.4985 .19066 L
.49918 .19065 L
.50044 .19065 L
.50161 .19066 L
.50286 .19068 L
.50404 .19072 L
.50511 .19076 L
.50774 .1909 L
.51023 .19109 L
.51518 .19162 L
.52056 .19242 L
.53017 .19447 L
.53905 .19705 L
.55775 .20465 L
.57837 .21639 L
.59775 .23059 L
.61862 .24914 L
.65981 .29432 L
.69949 .3444 L
.73765 .39052 L
.7573 .40967 L
.76829 .41803 L
.77826 .42376 L
.78313 .42582 L
.78579 .42673 L
.78827 .42743 L
.79057 .42795 L
.79266 .42832 L
.79386 .42847 L
.79499 .42859 L
.79618 .42868 L
.79749 .42873 L
.79877 .42874 L
.79997 .42871 L
.8013 .42863 L
.80204 .42857 L
.80272 .42849 L
.80402 .42832 L
.80543 .42808 L
.80829 .42741 L
.8108 .42664 L
.81347 .4256 L
.8183 .42319 L
.82362 .41969 L
.82852 .41566 L
.83962 .40359 L
.8494 .38945 L
Mistroke
.85976 .37085 L
.87931 .32579 L
.89762 .2729 L
.93641 .13915 L
.97619 .01046 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 123},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000Na000`40O003h00Oogoo6Goo003oOolI
Ool008]oo`8008]oo`00MWoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0RWoo001eOol00`00Ool00008Ool01`00Oomoogoo001oo`0000Aoo`03001o
ogoo08Yoo`002Woo00<007ooOol0Hgoo0`000Woo00<007oo000027oo00<007ooOol00goo00<007oo
Ool00Woo0`00OWoo00<007ooOol02Goo000:Ool00`00Oomoo`1XOol00`00Ool00009Ool00`00Oomo
o`020005Ool00`00Oomoo`1nOol00`00Oomoo`09Ool000]oo`03001oogoo06Moo`03001oo`0000Mo
o`03001oo`00009oo`03001oogoo00Aoo`03001oogoo07eoo`03001oogoo00Yoo`002goo00<007oo
Ool0J7oo00<007ooOol01Woo0`000Woo0`0017oo0P00OWoo00<007ooOol02Woo000;Ool00`00Oomo
o`1mOol00`00Oomoo`1mOol00`00Oomoo`0:Ool000aoo`03001oogoo07aoo`03001oogoo07aoo`03
001oogoo00]oo`0037oo00<007ooOol0O7oo0P00OGoo00<007ooOol02goo000<Ool00`00Oomoo`1l
Ool00`00Oomoo`1lOol00`00Oomoo`0;Ool000aoo`03001oogoo07aoo`03001oogoo07]oo`03001o
ogoo00aoo`003Goo00<007ooOol0Ngoo00<007ooOol0Ngoo00<007ooOol037oo000=Ool00`00Oomo
o`1kOol2001lOol00`00Oomoo`0<Ool000eoo`03001oogoo07]oo`03001oogoo07Yoo`03001oogoo
00eoo`003Woo00<007ooOol0NWoo00<007ooOol0NWoo00<007ooOol03Goo000>Ool00`00Oomoo`1j
Ool2001kOol00`00Oomoo`0=Ool000ioo`03001oogoo06Yoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo07Uoo`03001oogoo00ioo`003goo00<007ooOol0J7oo00<007oo
00001goo00<007oo000017oo00<007ooOol0NGoo00<007ooOol03Woo000?Ool00`00Oomoo`1SOol3
0002Ool00`00Ool00009Ool00`00Oomoo`02Ool3001iOol00`00Oomoo`0>Ool000moo`03001oogoo
06Qoo`03001oo`0000Moo`8000Eoo`03001oogoo07Qoo`03001oogoo00moo`003goo00<007ooOol0
J7oo00<007oo00001goo00<007ooOol017oo00<007ooOol0N7oo00<007ooOol03goo000@Ool00`00
Oomoo`1XOol00`00Oomoo`06Ool30004Ool2001iOol00`00Oomoo`0?Ool0011oo`03001oogoo07Qo
o`03001oogoo07Qoo`03001oogoo00moo`0047oo00<007ooOol0N7oo00<007ooOol0Mgoo00<007oo
Ool047oo000AOol00`00Oomoo`1gOol00`00Oomoo`1gOol00`00Oomoo`0@Ool0015oo`03001oogoo
07Moo`8007Qoo`03001oogoo011oo`004Goo00<007ooOol0Mgoo00<007ooOol0MWoo00<007ooOol0
4Goo000BOol00`00Oomoo`1fOol00`00Oomoo`1fOol00`00Oomoo`0AOol0019oo`03001oogoo07Io
o`8007Moo`03001oogoo015oo`004Woo00<007ooOol0MWoo00<007ooOol0MGoo00<007ooOol04Woo
000BOol00`00Oomoo`1fOol00`00Oomoo`1eOol00`00Oomoo`0BOol001=oo`03001oogoo07Eoo`80
07Ioo`03001oogoo019oo`004goo00<007ooOol0H7oo00<007ooOol00Woo00@007ooOomoo`<000=o
o`03001oogoo00=oo`03001oogoo07Aoo`03001oogoo01=oo`004goo00<007ooOol0Ggoo00<007oo
00001goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0M7oo00<007ooOol04goo000DOol0
0`00Oomoo`1IOol30002Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool3001dOol0
0`00Oomoo`0COol001Aoo`03001oogoo05ioo`03001oo`0000Qoo`04001oogooOol20005Ool00`00
Oomoo`1cOol00`00Oomoo`0DOol001Aoo`03001oogoo05ioo`03001oo`0000Moo`03001oo`00009o
o`03001oogoo00Aoo`03001oogoo07=oo`03001oogoo01Aoo`005Goo00<007ooOol0GWoo00<007oo
Ool01goo00@007ooOomoo`<000Aoo`03001oogoo07=oo`03001oogoo01Aoo`005Goo00<007ooOol0
Lgoo0P00Lgoo00<007ooOol05Goo000;Ool30007Ool00`00Oomoo`0bOol5000lOol00`00Oomoo`0k
Ool5000bOol00`00Oomoo`08Ool3000:Ool000]oo`03001oogoo00Moo`03001oogoo03Aoo`03001o
ogoo03aoo`03001oogoo03eoo`03001oogoo039oo`03001oogoo00Qoo`03001oogoo00Yoo`001Woo
0`000goo00<007ooOol01goo00<007ooOol0;Goo0`000goo00<007ooOol0?7oo0P00?Woo00<007oo
Ool0<Woo00<007ooOol02Goo00<007ooOol02Goo000<Ool00`00Oomoo`07Ool00`00Oomoo`0cOol0
0`00Oomoo`0lOol00`00Oomoo`0mOol00`00Oomoo`0aOol00`00Oomoo`0:Ool00`00Oomoo`09Ool0
00]oo`03001oo`0000Qoo`03001oogoo03=oo`03001oogoo03aoo`03001oogoo03eoo`03001oogoo
035oo`03001oogoo00Uoo`03001oo`0000Yoo`0037oo00<007ooOol027oo00<007ooOol0<Goo0P00
?Woo0P00?Goo0P00<goo00<007ooOol02Woo00<007ooOol02Goo000GOol00`00Oomoo`1aOol00`00
Oomoo`1aOol00`00Oomoo`0FOol001Moo`03001oogoo075oo`03001oogoo071oo`03001oogoo01Mo
o`0067oo00<007ooOol0L7oo0P00LGoo00<007ooOol05goo000HOol00`00Oomoo`1`Ool00`00Oomo
o`1`Ool00`00Oomoo`0GOol001Qoo`03001oogoo071oo`03001oogoo06moo`03001oogoo01Qoo`00
0gooo`004P0017oo000:Ool00`00Oomoo`0:Ool00`00Ool0000:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`0:Ool00`00Oomoo`03Ool50002Ool00`00Oomoo`070003Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`08Ool00`00Ool0000<Ool00`00Oomoo`09Ool000Yoo`03001oogoo00aoo`03001o
ogoo02ioo`03001oogoo039oo`D000Moo`03001oogoo00Moo`<003Aoo`03001oogoo02ioo`03001o
ogoo00aoo`03001oogoo00Uoo`006Goo00<007ooOol0HGoo0P0037oo00<007ooOol02Woo0P00HWoo
00<007ooOol06Goo000JOol00`00Oomoo`1NOol2000>Ool2000=Ool2001POol00`00Oomoo`0IOol0
01Yoo`03001oogoo05eoo`03001oogoo00ioo`03001oogoo00ioo`8005ioo`03001oogoo01Uoo`00
6Woo00<007ooOol0Fgoo0P004Goo00<007ooOol047oo0P00G7oo00<007ooOol06Goo000KOol00`00
Oomoo`1HOol2000COol2000COol00`00Oomoo`1HOol00`00Oomoo`0JOol001]oo`03001oogoo05Mo
o`03001oogoo01=oo`03001oogoo01=oo`8005Qoo`03001oogoo01Yoo`006goo00<007ooOol0EWoo
00<007ooOol057oo00<007ooOol05Goo00<007ooOol0EGoo00<007ooOol06Woo000KOol00`00Oomo
o`1EOol00`00Oomoo`0EOol2000GOol2001EOol00`00Oomoo`0JOol001aoo`03001oogoo05=oo`03
001oogoo01Ioo`03001oogoo01Qoo`03001oogoo055oo`03001oogoo01]oo`0077oo00<007ooOol0
DWoo00<007ooOol05goo00<007ooOol06Goo00<007ooOol0D7oo00<007ooOol06goo000LOol00`00
Oomoo`1@Ool2000JOol2000KOol00`00Oomoo`1?Ool00`00Oomoo`0KOol001eoo`03001oogoo04io
o`03001oogoo01Yoo`03001oogoo01]oo`03001oogoo04eoo`03001oogoo01aoo`007Goo00<007oo
Ool0CGoo00<007ooOol01Woo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001oogoo00=oo`03
001oogoo01aoo`03001oogoo04aoo`03001oogoo01aoo`007Goo00<007ooOol0C7oo00<007ooOol0
1Woo00<007oo00001goo00<007ooOol00Woo00<007oo000017oo00<007ooOol07Goo00<007ooOol0
Bgoo00<007ooOol077oo000NOol00`00Oomoo`1:Ool00`00Oomoo`07Ool00`00Ool00008Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool3000NOol00`00Oomoo`1:Ool00`00Oomoo`0LOol001ioo`03001o
ogoo04Uoo`03001oogoo00Qoo`03001oo`0000Qoo`04001oogooOol20005Ool00`00Oomoo`0OOol0
0`00Oomoo`18Ool00`00Oomoo`0MOol001ioo`03001oogoo04Qoo`03001oogoo00Uoo`03001oo`00
00Moo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo021oo`03001oogoo04Moo`03001oogoo
01eoo`007Woo00<007ooOol0Agoo00<007ooOol02goo00<007ooOol01goo00@007ooOomoo`<000Ao
o`80025oo`03001oogoo04Moo`03001oogoo01eoo`007goo00<007ooOol0AGoo00<007ooOol08Goo
00<007ooOol08Goo00<007ooOol0AWoo00<007ooOol07Goo000OOol00`00Oomoo`14Ool00`00Oomo
o`0ROol00`00Oomoo`0ROol00`00Oomoo`14Ool00`00Oomoo`0NOol001moo`03001oogoo04=oo`03
001oogoo02=oo`8002Aoo`03001oogoo04=oo`03001oogoo01ioo`0087oo00<007ooOol0@Goo00<0
07ooOol097oo00<007ooOol097oo00<007ooOol0@Woo00<007ooOol07Woo000POol00`00Oomoo`10
Ool00`00Oomoo`0UOol00`00Oomoo`0UOol00`00Oomoo`10Ool00`00Oomoo`0OOol0021oo`03001o
ogoo03moo`03001oogoo02Ioo`8002Ioo`03001oogoo041oo`03001oogoo01moo`008Goo00<007oo
Ool0?Goo00<007ooOol09goo00<007ooOol09Woo00<007ooOol0?goo00<007ooOol07goo000QOol0
0`00Oomoo`0lOol00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0mOol00`00Oomoo`0POol0
025oo`03001oogoo03]oo`03001oogoo02Uoo`8002Uoo`03001oogoo03aoo`03001oogoo021oo`00
8Woo00<007ooOol0>Goo00<007ooOol0:Woo00<007ooOol0:Goo00<007ooOol0>Woo00<007ooOol0
8Goo000ROol00`00Oomoo`0iOol00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`0iOol00`00Oomoo`0QOol0029oo`03001oogoo03Qo
o`03001oogoo01Yoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo02]oo`03001oogoo03Qo
o`03001oogoo025oo`008goo00<007ooOol0=Woo00<007ooOol06goo00<007oo00002Goo00<007oo
Ool00Woo0`00:goo00<007ooOol0=goo00<007ooOol08Woo000SOol00`00Oomoo`0eOol00`00Oomo
o`0LOol00`00Ool00007Ool20005Ool00`00Oomoo`0/Ool00`00Oomoo`0fOol00`00Oomoo`0ROol0
02=oo`03001oogoo03Aoo`03001oogoo01eoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo
02eoo`03001oogoo03Eoo`03001oogoo029oo`0097oo00<007ooOol0<goo00<007ooOol07Woo00<0
07ooOol01Woo0`0017oo0P00;goo00<007ooOol0<goo00<007ooOol08goo000TOol00`00Oomoo`0b
Ool00`00Oomoo`0_Ool00`00Oomoo`0_Ool00`00Oomoo`0bOol00`00Oomoo`0SOol002Aoo`03001o
ogoo035oo`03001oogoo031oo`03001oogoo031oo`03001oogoo035oo`03001oogoo02=oo`009Goo
00<007ooOol0;goo00<007ooOol0<Goo0P00<Goo00<007ooOol0<7oo00<007ooOol097oo000UOol0
0`00Oomoo`0_Ool00`00Oomoo`0aOol00`00Oomoo`0aOol00`00Oomoo`0_Ool00`00Oomoo`0TOol0
02Eoo`03001oogoo02ioo`03001oogoo039oo`03001oogoo039oo`03001oogoo02eoo`03001oogoo
02Eoo`009Woo00<007ooOol0;7oo00<007ooOol0<goo0P00=7oo00<007ooOol0;7oo00<007ooOol0
9Goo000VOol00`00Oomoo`0[Ool00`00Oomoo`0dOol00`00Oomoo`0dOol00`00Oomoo`0ZOol00`00
Oomoo`0VOol002Moo`03001oogoo02Uoo`03001oogoo03Eoo`03001oogoo03Eoo`03001oogoo02Uo
o`03001oogoo02Ioo`009goo00<007ooOol0:7oo00<007ooOol0=Woo00<007ooOol0=Goo00<007oo
Ool0:Goo00<007ooOol09Woo000XOol00`00Oomoo`0WOol00`00Oomoo`0fOol2000gOol00`00Oomo
o`0WOol00`00Oomoo`0WOol002Qoo`03001oogoo02Ioo`03001oogoo029oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo03Moo`03001oogoo02Ioo`03
001oogoo02Moo`00:Goo00<007ooOol097oo00<007ooOol08Woo00<007oo000027oo00L007ooOomo
o`00Ool00004Ool00`00Oomoo`0hOol00`00Oomoo`0TOol00`00Oomoo`0XOol002Uoo`03001oogoo
02=oo`03001oogoo02=oo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo009oo`<003Qoo`03
001oogoo02Aoo`03001oogoo02Qoo`00:Woo00<007ooOol08Goo00<007ooOol097oo00<007oo0000
2Goo00<007ooOol00P001Goo00<007ooOol0>Goo00<007ooOol08Woo00<007ooOol0:Goo000ZOol0
0`00Oomoo`0POol00`00Oomoo`0UOol00`00Ool00007Ool00`00Ool00002Ool00`00Oomoo`04Ool0
0`00Oomoo`0jOol00`00Oomoo`0QOol00`00Oomoo`0YOol002]oo`03001oogoo01moo`03001oogoo
02Ioo`03001oogoo00Ioo`<0009oo`<000Aoo`8003aoo`03001oogoo01moo`03001oogoo02Yoo`00
:goo00<007ooOol07Woo00<007ooOol0?7oo00<007ooOol0>goo00<007ooOol07goo00<007ooOol0
:Woo000/Ool00`00Oomoo`0LOol00`00Oomoo`0mOol00`00Oomoo`0lOol00`00Oomoo`0MOol00`00
Oomoo`0[Ool002eoo`03001oogoo01Yoo`03001oogoo03ioo`8003ioo`03001oogoo01]oo`03001o
ogoo02aoo`00;Goo00<007ooOol06Goo00<007ooOol0?goo00<007ooOol0?Woo00<007ooOol06Goo
00<007ooOol0;Goo000^Ool00`00Oomoo`0GOol00`00Oomoo`10Ool00`00Oomoo`0oOol00`00Oomo
o`0HOol00`00Oomoo`0]Ool002ioo`03001oogoo01Ioo`03001oogoo045oo`03001oogoo041oo`80
01Moo`03001oogoo02ioo`00;goo00<007ooOol057oo00<007ooOol0@Woo0P00@goo00<007ooOol0
4goo00<007ooOol0;goo000`Ool2000COol00`00Oomoo`13Ool00`00Oomoo`13Ool00`00Oomoo`0A
Ool00`00Oomoo`0`Ool0035oo`03001oogoo00moo`8004Ioo`03001oogoo04Aoo`80011oo`03001o
ogoo035oo`00<Woo00<007ooOol03Goo00<007ooOol0AWoo0P00Agoo00<007ooOol037oo00<007oo
Ool0<Woo000cOol2000;Ool20011Ool50003Ool00`00Oomoo`17Ool00`00Oomoo`09Ool3000dOol0
03Eoo`<000Ioo`8004Eoo`03001oogoo00=oo`03001oogoo04Qoo`@000Eoo`8003Moo`00=goo1`00
Agoo00<007ooOol00goo0`00Bgoo1`00>7oo0025Ool00`00Oomoo`03Ool00`00Oomoo`2:Ool008Eo
o`03001oogoo00=oo`03001oogoo08Yoo`00Q7oo0P001Goo00<007ooOol0RWoo003oOolIOol00001
\
\>"],
  ImageRangeCache->{{{0, 279}, {122, 0}} -> {-2.16039, -0.819685, 0.0154866, 
  0.0154866}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is another ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam profile."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(locuspoint2
       = {If[\[Pi]/2 < s < 3\ \[Pi]/2, 1, 1 + Cos[s]]\ Cos[s], Sin[s]}; \n
    \(ParametricPlot[Evaluate[locuspoint2], {s, 0, 2\ \[Pi]}, 
      AspectRatio \[Rule] Automatic, Compiled \[Rule] False]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .66667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.341268 0.317461 0.333333 0.317461 [
[.02381 .32083 -6 -9 ]
[.02381 .32083 6 0 ]
[.18254 .32083 -12 -9 ]
[.18254 .32083 12 0 ]
[.5 .32083 -9 -9 ]
[.5 .32083 9 0 ]
[.65873 .32083 -3 -9 ]
[.65873 .32083 3 0 ]
[.81746 .32083 -9 -9 ]
[.81746 .32083 9 0 ]
[.97619 .32083 -3 -9 ]
[.97619 .32083 3 0 ]
[.32877 .01587 -12 -4.5 ]
[.32877 .01587 0 4.5 ]
[.32877 .1746 -24 -4.5 ]
[.32877 .1746 0 4.5 ]
[.32877 .49206 -18 -4.5 ]
[.32877 .49206 0 4.5 ]
[.32877 .65079 -6 -4.5 ]
[.32877 .65079 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .66667 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .33333 m
.02381 .33958 L
s
[(-1)] .02381 .32083 0 1 Mshowa
.18254 .33333 m
.18254 .33958 L
s
[(-0.5)] .18254 .32083 0 1 Mshowa
.5 .33333 m
.5 .33958 L
s
[(0.5)] .5 .32083 0 1 Mshowa
.65873 .33333 m
.65873 .33958 L
s
[(1)] .65873 .32083 0 1 Mshowa
.81746 .33333 m
.81746 .33958 L
s
[(1.5)] .81746 .32083 0 1 Mshowa
.97619 .33333 m
.97619 .33958 L
s
[(2)] .97619 .32083 0 1 Mshowa
.125 Mabswid
.05555 .33333 m
.05555 .33708 L
s
.0873 .33333 m
.0873 .33708 L
s
.11905 .33333 m
.11905 .33708 L
s
.15079 .33333 m
.15079 .33708 L
s
.21428 .33333 m
.21428 .33708 L
s
.24603 .33333 m
.24603 .33708 L
s
.27778 .33333 m
.27778 .33708 L
s
.30952 .33333 m
.30952 .33708 L
s
.37301 .33333 m
.37301 .33708 L
s
.40476 .33333 m
.40476 .33708 L
s
.43651 .33333 m
.43651 .33708 L
s
.46825 .33333 m
.46825 .33708 L
s
.53174 .33333 m
.53174 .33708 L
s
.56349 .33333 m
.56349 .33708 L
s
.59524 .33333 m
.59524 .33708 L
s
.62698 .33333 m
.62698 .33708 L
s
.69048 .33333 m
.69048 .33708 L
s
.72222 .33333 m
.72222 .33708 L
s
.75397 .33333 m
.75397 .33708 L
s
.78571 .33333 m
.78571 .33708 L
s
.84921 .33333 m
.84921 .33708 L
s
.88095 .33333 m
.88095 .33708 L
s
.9127 .33333 m
.9127 .33708 L
s
.94444 .33333 m
.94444 .33708 L
s
.25 Mabswid
0 .33333 m
1 .33333 L
s
.34127 .01587 m
.34752 .01587 L
s
[(-1)] .32877 .01587 1 0 Mshowa
.34127 .1746 m
.34752 .1746 L
s
[(-0.5)] .32877 .1746 1 0 Mshowa
.34127 .49206 m
.34752 .49206 L
s
[(0.5)] .32877 .49206 1 0 Mshowa
.34127 .65079 m
.34752 .65079 L
s
[(1)] .32877 .65079 1 0 Mshowa
.125 Mabswid
.34127 .04762 m
.34502 .04762 L
s
.34127 .07936 m
.34502 .07936 L
s
.34127 .11111 m
.34502 .11111 L
s
.34127 .14286 m
.34502 .14286 L
s
.34127 .20635 m
.34502 .20635 L
s
.34127 .23809 m
.34502 .23809 L
s
.34127 .26984 m
.34502 .26984 L
s
.34127 .30159 m
.34502 .30159 L
s
.34127 .36508 m
.34502 .36508 L
s
.34127 .39683 m
.34502 .39683 L
s
.34127 .42857 m
.34502 .42857 L
s
.34127 .46032 m
.34502 .46032 L
s
.34127 .52381 m
.34502 .52381 L
s
.34127 .55556 m
.34502 .55556 L
s
.34127 .5873 m
.34502 .5873 L
s
.34127 .61905 m
.34502 .61905 L
s
.25 Mabswid
.34127 0 m
.34127 .66667 L
s
0 0 m
1 0 L
1 .66667 L
0 .66667 L
closepath
clip
newpath
.5 Mabswid
.97619 .33333 m
.97616 .3358 L
.97609 .33804 L
.97594 .34062 L
.97574 .34306 L
.97525 .34741 L
.97452 .35212 L
.97347 .35731 L
.97209 .3628 L
.96889 .37262 L
.96464 .38273 L
.9598 .39214 L
.94575 .41338 L
.92726 .43465 L
.90687 .45368 L
.85025 .49461 L
.79113 .5275 L
.71935 .55992 L
.64146 .58885 L
.5707 .61074 L
.49929 .62892 L
.43908 .64095 L
.41165 .64521 L
.38487 .64841 L
.37192 .64954 L
.36596 .64996 L
.36045 .65028 L
.35741 .65042 L
.35415 .65055 L
.35148 .65064 L
.34857 .65071 L
.34698 .65074 L
.34549 .65077 L
.34394 .65078 L
.34228 .65079 L
.34084 .65079 L
.33932 .65079 L
.33661 .65076 L
.33402 .65071 L
.33257 .65067 L
.33122 .65064 L
.32614 .65043 L
.32152 .65018 L
.31664 .64984 L
.30652 .64889 L
.29542 .64747 L
.27586 .64398 L
.25779 .63962 L
.23697 .63317 L
.21766 .62574 L
Mistroke
.18291 .60848 L
.14835 .58545 L
.11924 .56023 L
.09059 .52812 L
.06861 .49594 L
.05018 .46003 L
.04186 .43887 L
.03557 .41895 L
.03069 .3991 L
.02731 .38035 L
.02587 .36949 L
.02489 .35957 L
.02449 .35407 L
.02431 .35117 L
.02415 .34809 L
.02404 .3454 L
.02394 .34244 L
.02387 .33974 L
.02383 .33721 L
.02381 .33474 L
.02381 .3321 L
.02383 .32961 L
.02386 .32735 L
.02393 .32468 L
.02402 .3218 L
.02425 .31657 L
.02459 .31109 L
.02505 .3053 L
.02614 .29495 L
.02743 .28549 L
.0289 .27668 L
.03316 .25684 L
.03915 .23582 L
.04616 .21633 L
.06265 .18118 L
.08494 .14604 L
.10953 .11636 L
.13789 .08957 L
.17278 .06427 L
.20836 .04503 L
.22936 .03625 L
.24914 .02953 L
.26894 .02422 L
.28764 .02043 L
.29848 .01877 L
.30838 .01758 L
.31388 .01706 L
.31986 .0166 L
.3255 .01626 L
.32818 .01614 L
Mistroke
.33072 .01605 L
.33316 .01598 L
.33582 .01592 L
.33824 .01589 L
.34049 .01587 L
.34316 .01588 L
.34563 .0159 L
.34701 .01592 L
.34852 .01595 L
.35128 .01602 L
.35646 .0162 L
.36207 .01648 L
.37252 .01717 L
.38538 .01831 L
.39797 .01969 L
.42857 .02398 L
.49294 .03632 L
.55737 .05224 L
.63289 .07495 L
.70315 .10026 L
.83289 .16163 L
.88521 .19576 L
.91078 .21638 L
.93088 .2358 L
.9466 .25441 L
.96011 .27508 L
.96557 .28596 L
.96964 .29613 L
.97289 .30691 L
.97423 .31295 L
.97514 .31845 L
.9756 .32217 L
.97591 .32559 L
.97602 .32738 L
.97612 .32935 L
.97617 .33141 L
.97619 .33333 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 188},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000_1000`40O003h00Oogoo6goo001POol0
0`00Oomoo`2gOol0061oo`03001oogoo0;Moo`00Egoo1@0017oo00<007ooOol0]goo001IOol00`00
Oomoo`04Ool00`00Oomoo`2gOol005=ooaL00;1oo`00CWoo20000goo00<007ooOol017oo00<007oo
Ool01goo2P00YWoo001:Ool4000;Ool00`00Oomoo`04Ool00`00Oomoo`0AOol7002OOol004Qoo`80
00ioo`8000Ioo`03001oogoo01Qoo`@009]oo`00AGoo0`0067oo00<007ooOol077oo1@00UWoo0012
Ool3000KOol00`00Oomoo`0QOol4002BOol003moo`<001ioo`03001oogoo02Eoo`D008eoo`00?7oo
0`008Goo00<007ooOol0:Woo1000RGoo000jOol2000TOol00`00Oomoo`0^Ool50024Ool003Qoo`80
02Ioo`8003Aoo`@0081oo`00=Woo0P00:7oo00<007ooOol0=goo1000O7oo000eOol00`00Oomoo`0X
Ool00`00Oomoo`0kOol3001iOol003=oo`8002]oo`03001oogoo03ioo`<007Ioo`00<Goo0P00;Goo
00<007ooOol0@Goo0`00Lgoo000`Ool00`00Oomoo`0]Ool00`00Oomoo`14Ool3001`Ool002ioo`80
031oo`03001oogoo04Moo`<006eoo`00;Goo00<007ooOol0<7oo00<007ooOol0BWoo0`00JWoo000/
Ool00`00Oomoo`0aOol00`00Oomoo`1=Ool3001WOol002Yoo`8003Aoo`80055oo`<006Aoo`00:Goo
00<007ooOol0=7oo00<007ooOol0Dgoo0`00HGoo000WOol2000gOol00`00Oomoo`1FOol2001OOol0
02Ioo`03001oogoo03Moo`03001oogoo05Qoo`<005aoo`009Goo00<007ooOol0>7oo00<007ooOol0
Fgoo0`00FGoo000TOol00`00Oomoo`0iOol00`00Oomoo`1NOol3001FOol002=oo`03001oogoo03Yo
o`03001oogoo065oo`<005=oo`008Woo00<007ooOol0>goo00<007ooOol0I7oo0P00DGoo000QOol0
0`00Oomoo`0lOol00`00Oomoo`1VOol2001?Ool0021oo`03001oogoo03eoo`8006Uoo`8004eoo`00
7goo00<007ooOol0?Woo00<007ooOol0JWoo0P00Bgoo000NOol00`00Oomoo`0oOol00`00Oomoo`1/
Ool20019Ool001eoo`03001oogoo041oo`03001oogoo06ioo`8004Moo`0077oo00<007ooOol0@Goo
00<007ooOol0L7oo0P00AGoo000KOol00`00Oomoo`12Ool00`00Oomoo`1bOol20013Ool001]oo`03
001oogoo049oo`03001oogoo07Aoo`<0041oo`006Woo00<007ooOol0@goo00<007ooOol0Mgoo0P00
?Woo000IOol00`00Oomoo`14Ool00`00Oomoo`1iOol2000lOol001Qoo`03001oogoo04Eoo`8007ao
o`8003Yoo`005goo00<007ooOol0AWoo00<007ooOol0OGoo0P00>7oo000GOol00`00Oomoo`16Ool0
0`00Oomoo`1oOol2000fOol001Ioo`03001oogoo04Moo`03001oogoo085oo`8003Aoo`005Goo00<0
07ooOol0B7oo00<007ooOol0Pgoo0P00<Woo000DOol00`00Oomoo`19Ool00`00Oomoo`25Ool2000`
Ool001Aoo`03001oogoo03Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo08Moo`8002ioo`004goo00<007ooOol0>7oo00<007oo00001goo00<007oo00001Goo00<007oo
Ool0RGoo0P00;7oo000BOol00`00Oomoo`0dOol30002Ool00`00Ool00009Ool00`00Oomoo`03Ool2
002<Ool00`00Oomoo`0YOol0019oo`03001oogoo03Uoo`03001oo`0000Moo`8000Ioo`03001oogoo
08aoo`8002Uoo`004Goo00<007ooOol0>Woo00<007oo00001goo00<007ooOol01Goo00<007ooOol0
SWoo0P009goo000AOol00`00Oomoo`0kOol00`00Oomoo`06Ool30005Ool00`00Oomoo`2@Ool00`00
Oomoo`0TOol0011oo`03001oogoo04eoo`03001oogoo095oo`8002Aoo`0047oo00<007ooOol0CGoo
00<007ooOol0Tgoo0P008Woo000?Ool00`00Oomoo`1>Ool00`00Oomoo`2EOol00`00Oomoo`0OOol0
00moo`03001oogoo04ioo`03001oogoo09Ioo`03001oogoo01ioo`003goo00<007ooOol0CWoo00<0
07ooOol0Ugoo00<007ooOol07Goo000>Ool00`00Oomoo`1?Ool2002IOol2000MOol000ioo`03001o
ogoo04moo`03001oogoo09Yoo`03001oogoo01Yoo`003Goo00<007ooOol0D7oo00<007ooOol0Vgoo
00<007ooOol06Goo000=Ool00`00Oomoo`1@Ool00`00Oomoo`2LOol00`00Oomoo`0HOol000eoo`03
001oogoo051oo`03001oogoo09eoo`03001oogoo01Moo`0037oo00<007ooOol0DGoo00<007ooOol0
WWoo00<007ooOol05Woo000<Ool00`00Oomoo`1AOol00`00Oomoo`2OOol00`00Oomoo`0EOol000ao
o`03001oogoo055oo`03001oogoo0:1oo`03001oogoo01Aoo`002goo00<007ooOol0DWoo00<007oo
Ool0XGoo00<007ooOol04goo000;Ool00`00Oomoo`1BOol2002SOol00`00Oomoo`0BOol000]oo`03
001oogoo059oo`03001oogoo0:=oo`03001oogoo015oo`002Woo00<007ooOol0Dgoo00<007ooOol0
Y7oo00<007ooOol047oo000:Ool00`00Oomoo`1COol00`00Oomoo`2TOol00`00Oomoo`0@Ool000Yo
o`03001oogoo05=oo`03001oogoo0:Eoo`03001oogoo00moo`002Goo00<007ooOol0E7oo00<007oo
Ool0YWoo00<007ooOol03Woo0009Ool00`00Oomoo`1DOol00`00Oomoo`2WOol00`00Oomoo`0=Ool0
00Uoo`03001oogoo05Aoo`03001oogoo0:Moo`03001oogoo00eoo`002Goo00<007ooOol0E7oo00<0
07ooOol0Z7oo00<007ooOol037oo0008Ool00`00Oomoo`1EOol2002ZOol00`00Oomoo`0;Ool000Qo
o`03001oogoo05Eoo`03001oogoo0:Uoo`03001oogoo00]oo`0027oo00<007ooOol0EGoo00<007oo
Ool0ZWoo00<007ooOol02Woo0008Ool00`00Oomoo`1EOol00`00Oomoo`2[Ool00`00Oomoo`09Ool0
00Qoo`03001oogoo05Eoo`03001oogoo0:]oo`03001oogoo00Uoo`0027oo00<007ooOol0EGoo00<0
07ooOol0[7oo00<007ooOol027oo0007Ool5000TOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0ROol5000S
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`0ROol40007Ool000Moo`03001oo`0002Eoo`03001o
o`0000Moo`03001oo`0002Aoo`03001oogoo02=oo`03001oo`0000Moo`03001oo`0002Eoo`03001o
ogoo02Eoo`03001oogoo00Ioo`03001oo`0002Aoo`03001oogoo00Moo`000goo0`0000Aoo`00Ool0
021oo`<0009oo`03001oo`0000Uoo`03001oogoo029oo`03001oogoo02=oo`03001oo`0000Uoo`03
001oogoo02=oo`03001oogoo02Eoo`03001oogoo00Qoo`03001oogoo029oo`8000Qoo`001goo00<0
07oo00009Goo00<007oo00001goo0P009Goo0P0097oo00<007oo00001goo0P009Woo00<007ooOol0
9Goo00<007ooOol01Woo0P009Goo0P0027oo0007Ool00`00Ool0000UOol00`00Ool00007Ool00`00
Oomoo`0TOol00`00Oomoo`0SOol00`00Ool00007Ool00`00Oomoo`0UOol00`00Oomoo`0UOol00`00
Oomoo`06Ool00`00Oomoo`0TOol30007Ool000Moo`<002Ioo`03001oogoo00Ioo`<002Aoo`03001o
ogoo02Aoo`03001oogoo00Ioo`<002Aoo`8002Ioo`8000Qoo`<002Eoo`03001oogoo00Ioo`001goo
00<007ooOol0EWoo00<007ooOol0[Woo00<007ooOol01Woo0007Ool00`00Oomoo`1FOol00`00Oomo
o`2^Ool00`00Oomoo`06Ool000Moo`03001oogoo05Ioo`03001oogoo0:ioo`03001oogoo00Ioo`00
1goo00<007ooOol0EWoo00<007ooOol0[Woo00<007ooOol01Woo0007Ool00`00Oomoo`1FOol00`00
Oomoo`2^Ool00`00Oomoo`06Ool000Moo`03001oogoo05Ioo`03001oogoo0:ioo`03001oogoo00Io
o`00o`006P000Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool20007Ool000Moo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo
02Uoo`03001oogoo02Yoo`03001oogoo02Uoo`03001oogoo02Uoo`8000Moo`001goo00<007ooOol0
EWoo00<007ooOol0[Woo00<007ooOol01Woo0007Ool00`00Oomoo`1FOol00`00Oomoo`2^Ool00`00
Oomoo`06Ool000Moo`03001oogoo05Ioo`03001oogoo0:ioo`03001oogoo00Ioo`001goo00<007oo
Ool0EWoo00<007ooOol0[Woo00<007ooOol01Woo0007Ool00`00Oomoo`1FOol00`00Oomoo`2^Ool0
0`00Oomoo`06Ool000Moo`03001oogoo05Ioo`03001oogoo0:eoo`03001oogoo00Moo`001goo00<0
07ooOol0EWoo0P00[Woo00<007ooOol01goo0007Ool00`00Oomoo`1FOol00`00Oomoo`2/Ool00`00
Oomoo`08Ool000Moo`03001oogoo05Ioo`03001oogoo0:aoo`03001oogoo00Qoo`001goo00<007oo
Ool0EWoo00<007ooOol0[7oo00<007ooOol027oo0007Ool00`00Oomoo`1FOol00`00Oomoo`2[Ool0
0`00Oomoo`09Ool000Moo`03001oogoo05Ioo`03001oogoo0:]oo`03001oogoo00Uoo`001goo00<0
07ooOol0EWoo00<007ooOol0ZWoo00<007ooOol02Woo0008Ool00`00Oomoo`1EOol00`00Oomoo`2Z
Ool00`00Oomoo`0:Ool000Qoo`03001oogoo05Eoo`03001oogoo0:Uoo`03001oogoo00]oo`0027oo
00<007ooOol0EGoo0P00ZWoo00<007ooOol02goo0008Ool00`00Oomoo`1EOol00`00Oomoo`2XOol0
0`00Oomoo`0<Ool000Uoo`03001oogoo05Aoo`03001oogoo0:Moo`03001oogoo00eoo`002Goo00<0
07ooOol0E7oo00<007ooOol0Ygoo00<007ooOol03Goo0009Ool00`00Oomoo`1DOol00`00Oomoo`2V
Ool00`00Oomoo`0>Ool000Yoo`03001oogoo05=oo`03001oogoo0:Eoo`03001oogoo00moo`002Woo
00<007ooOol0Dgoo00<007ooOol0Y7oo00<007ooOol047oo000:Ool00`00Oomoo`1COol00`00Oomo
o`2SOol00`00Oomoo`0AOol000]oo`03001oogoo059oo`03001oogoo0:=oo`03001oogoo015oo`00
2goo00<007ooOol0DWoo0P00Xgoo00<007ooOol04Woo000;Ool00`00Oomoo`1BOol00`00Oomoo`2Q
Ool00`00Oomoo`0COol000aoo`03001oogoo055oo`03001oogoo0:1oo`03001oogoo01Aoo`0037oo
00<007ooOol0DGoo00<007ooOol0Wgoo00<007ooOol05Goo000<Ool00`00Oomoo`1AOol00`00Oomo
o`2NOol00`00Oomoo`0FOol000eoo`03001oogoo051oo`03001oogoo09eoo`03001oogoo01Moo`00
3Goo00<007ooOol0D7oo00<007ooOol0W7oo00<007ooOol067oo000=Ool00`00Oomoo`1@Ool00`00
Oomoo`2KOol00`00Oomoo`0IOol000ioo`03001oogoo04moo`03001oogoo09Uoo`8001aoo`003Woo
00<007ooOol0Cgoo0P00VGoo00<007ooOol077oo000>Ool00`00Oomoo`1?Ool00`00Oomoo`2FOol2
000OOol000moo`03001oogoo04ioo`03001oogoo09Eoo`03001oogoo01moo`003goo00<007ooOol0
CWoo00<007ooOol0U7oo00<007ooOol087oo000@Ool00`00Oomoo`1=Ool00`00Oomoo`2BOol2000S
Ool0011oo`03001oogoo04eoo`03001oogoo095oo`03001oogoo02=oo`004Goo00<007ooOol0>goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0Sgoo0P009Woo000AOol0
0`00Oomoo`0jOol00`00Ool00007Ool00`00Ool00005Ool00`00Oomoo`2>Ool00`00Oomoo`0VOol0
019oo`03001oogoo03Uoo`03001oo`0000Uoo`03001oogoo00=oo`8008eoo`8002Uoo`004Woo00<0
07ooOol0>Goo00<007oo00001goo0P001Woo00<007ooOol0Rgoo00<007ooOol0:Goo000COol00`00
Oomoo`0hOol00`00Ool00007Ool00`00Oomoo`05Ool00`00Oomoo`29Ool2000/Ool001Aoo`03001o
ogoo03Qoo`03001oogoo00Ioo`<000Eoo`03001oogoo08Moo`8002ioo`0057oo00<007ooOol0BGoo
00<007ooOol0QGoo0P00<7oo000EOol00`00Oomoo`18Ool00`00Oomoo`24Ool00`00Oomoo`0`Ool0
01Ioo`03001oogoo04Moo`03001oogoo089oo`8003=oo`005Woo00<007ooOol0Agoo00<007ooOol0
P7oo0P00=Goo000GOol00`00Oomoo`16Ool00`00Oomoo`1nOol2000gOol001Qoo`03001oogoo04Eo
o`8007eoo`8003Uoo`0067oo00<007ooOol0AGoo00<007ooOol0NWoo0P00>goo000IOol00`00Oomo
o`14Ool00`00Oomoo`1hOol2000mOol001Yoo`03001oogoo04=oo`03001oogoo07Ioo`8003moo`00
6goo00<007ooOol0@Woo00<007ooOol0M7oo0P00@Goo000LOol00`00Oomoo`11Ool00`00Oomoo`1b
Ool20013Ool001eoo`03001oogoo041oo`03001oogoo071oo`8004Eoo`007Goo00<007ooOol0@7oo
00<007ooOol0KWoo0P00Agoo000NOol00`00Oomoo`0oOol00`00Oomoo`1/Ool20019Ool001moo`03
001oogoo03ioo`8006]oo`8004]oo`0087oo00<007ooOol0?Goo00<007ooOol0J7oo0P00CGoo000Q
Ool00`00Oomoo`0lOol00`00Oomoo`1UOol3001?Ool0029oo`03001oogoo03]oo`03001oogoo06=o
o`80059oo`008goo00<007ooOol0>Woo00<007ooOol0H7oo0`00E7oo000TOol00`00Oomoo`0iOol0
0`00Oomoo`1MOol3001GOol002Eoo`8003Uoo`03001oogoo05]oo`8005Yoo`009goo00<007ooOol0
=Woo00<007ooOol0F7oo0`00G7oo000XOol00`00Oomoo`0eOol00`00Oomoo`1EOol3001OOol002Uo
o`03001oogoo03Aoo`8005Aoo`80069oo`00:Woo0P00=7oo00<007ooOol0D7oo0`00I7oo000/Ool2
000bOol00`00Oomoo`1=Ool3001WOol002ioo`03001oogoo02moo`03001oogoo04Uoo`@006Yoo`00
;goo0P00;goo00<007ooOol0AWoo0`00KWoo000aOol2000]Ool00`00Oomoo`13Ool3001aOol003=o
o`03001oogoo02Yoo`03001oogoo03moo`@007Aoo`00=7oo0P00:Woo00<007ooOol0?7oo0`00N7oo
000fOol2000XOol00`00Oomoo`0hOol4001kOol003Qoo`8002Ioo`8003Eoo`@007moo`00>Woo0P00
97oo00<007ooOol0<7oo1000Pgoo000lOol3000QOol00`00Oomoo`0/Ool40027Ool003moo`8001mo
o`03001oogoo02Moo`D008]oo`00@Goo0`0077oo00<007ooOol08Goo1P00T7oo0014Ool3000IOol0
0`00Oomoo`0KOol6002FOol004Moo`@001Eoo`03001oogoo01Eoo`H009aoo`00Bgoo1@001goo1@00
17oo00<007ooOol03Goo2000XWoo001@Ool800000goo001oo`05Ool00`00Oomoo`08Ool5002ZOol0
05Qooa<00:moo`00FGoo00<007ooOol017oo00<007ooOol0]goo001IOol00`00Oomoo`04Ool00`00
Oomoo`2gOol005Qoo`8000Ioo`03001oogoo0;Moo`00H7oo00<007ooOol0]goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {187, 0}} -> {-1.07866, -1.05058, 0.011236, 
  0.011236}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that although the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam constraints constrain one degree of freedom in the mechanism model, \
they actually add two (or three, as in ",
  StyleBox["CamToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") equations to the model. This is because each cam constraint also adds \
one (or two) symbols to the model's dependent variable list for a net loss of \
one degree of freedom. This anomaly is of no consequence to the user except \
when a cam constraint is used within ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In these cases, the added symbol in the cam constraint must be dealt \
with in the other stages of the switch function, usually by using the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to set the added symbol equal to a constant."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToPoint1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam profile with a point follower ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam profile as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a differentiable parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CamToPoint1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the specified ",
  StyleBox["point",
    FontSlant->"Italic"],
  " lies in contact with the cam profile.\n\n",
  StyleBox["CamToCircle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point, rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam profile with a circular follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam profile as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the cam profile lies tangent to a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". The circular follower lies on the left side of the cam profile (",
  StyleBox["rad",
    FontSlant->"Italic"],
  " positive) when traveling along the locus in the direction of increasing ",
  
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["CamToLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam profile with a flat follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam profile as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the cam profile lies tangent to the specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["CamToCam1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models two cam profiles that lie in contact with each other. The locus of \
",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " defines the first cam profile as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", while ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " defines the second cam profile as a function of the symbol ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the two cam profiles lie tangent to and in contact with \
each other."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2D cam constraints."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The locus point that is passed to a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam constraint must be a valid ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " point object containing the parametrically defined point. Also, the point \
must evaluate to a two-element list of differentiable expressions that are \
functionally dependent on the parameter ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " at the time the constraints are processed with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is because the locus point is differentiated with respect to the \
parameter ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Thus, if the locus point is not a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " when passed to ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " its derivative will be zero.\n\nA special graphics function ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is provided to parametrically plot the cam profiles in global \
coordinates. Note that ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics object with the head ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", not a graphics primitive like most other ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["min",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a graphics object representing the cam profile that is defined by \
the locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", which must be a parametric function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object returned by ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not evaluated until numeric values are available for ",
  StyleBox["Xn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Yn",
    FontSlant->"Italic"],
  ", and so on, where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the body number of the cam body.\n\n",
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["lpnt....",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, min, max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " plots several point loci ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the same options as ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", with some different defaults."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A cam-specific graphics function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " produces the same output as would the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", except that ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " transforms the local cam profile into the global coordinate system. ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not evaluate directly to a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object unless numeric values for the coordinate transformation are \
available. Instead, ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates to a ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that evaluates to a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object when numbers are available for the transformation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CamPlot[Point[2, locuspoint2], {s, 0, 2\ \[Pi]}, Frame \[Rule] True]\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysPlot[{X2, 
        Y2}, {{Cos[Th2], \(-Sin[Th2]\)}, {Sin[Th2], Cos[Th2]}}, {{
          Cos[s]\ If[\[Pi]\/2 < s < \(3\ \[Pi]\)\/2, 1, 1 + Cos[s]], 
          Sin[s]}}, "<>"]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "When numbers are available for ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object evaluates to a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here is the repositioned cam."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[% /. {X2 \[Rule] 1, Y2 \[Rule] \(-2\), Th2 \[Rule] 0.5}, 
      DisplayFunction \[Rule] $DisplayFunction]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79244 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.340295 1.03975 0.340295 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.19396 -0.0125 -9 -9 ]
[.19396 -0.0125 9 0 ]
[.3641 -0.0125 -3 -9 ]
[.3641 -0.0125 3 0 ]
[.53425 -0.0125 -9 -9 ]
[.53425 -0.0125 9 0 ]
[.7044 -0.0125 -3 -9 ]
[.7044 -0.0125 3 0 ]
[.87455 -0.0125 -9 -9 ]
[.87455 -0.0125 9 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01887 -12 -4.5 ]
[-0.0125 .01887 0 4.5 ]
[-0.0125 .18901 -24 -4.5 ]
[-0.0125 .18901 0 4.5 ]
[-0.0125 .35916 -12 -4.5 ]
[-0.0125 .35916 0 4.5 ]
[-0.0125 .52931 -24 -4.5 ]
[-0.0125 .52931 0 4.5 ]
[-0.0125 .69946 -12 -4.5 ]
[-0.0125 .69946 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .79244 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .79244 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.19396 0 m
.19396 .00625 L
s
[(0.5)] .19396 -0.0125 0 1 Mshowa
.3641 0 m
.3641 .00625 L
s
[(1)] .3641 -0.0125 0 1 Mshowa
.53425 0 m
.53425 .00625 L
s
[(1.5)] .53425 -0.0125 0 1 Mshowa
.7044 0 m
.7044 .00625 L
s
[(2)] .7044 -0.0125 0 1 Mshowa
.87455 0 m
.87455 .00625 L
s
[(2.5)] .87455 -0.0125 0 1 Mshowa
.125 Mabswid
.05784 0 m
.05784 .00375 L
s
.09187 0 m
.09187 .00375 L
s
.1259 0 m
.1259 .00375 L
s
.15993 0 m
.15993 .00375 L
s
.22799 0 m
.22799 .00375 L
s
.26202 0 m
.26202 .00375 L
s
.29605 0 m
.29605 .00375 L
s
.33007 0 m
.33007 .00375 L
s
.39813 0 m
.39813 .00375 L
s
.43216 0 m
.43216 .00375 L
s
.46619 0 m
.46619 .00375 L
s
.50022 0 m
.50022 .00375 L
s
.56828 0 m
.56828 .00375 L
s
.60231 0 m
.60231 .00375 L
s
.63634 0 m
.63634 .00375 L
s
.67037 0 m
.67037 .00375 L
s
.73843 0 m
.73843 .00375 L
s
.77246 0 m
.77246 .00375 L
s
.80649 0 m
.80649 .00375 L
s
.84052 0 m
.84052 .00375 L
s
.90858 0 m
.90858 .00375 L
s
.94261 0 m
.94261 .00375 L
s
.97664 0 m
.97664 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01887 m
.00625 .01887 L
s
[(-3)] -0.0125 .01887 1 0 Mshowa
0 .18901 m
.00625 .18901 L
s
[(-2.5)] -0.0125 .18901 1 0 Mshowa
0 .35916 m
.00625 .35916 L
s
[(-2)] -0.0125 .35916 1 0 Mshowa
0 .52931 m
.00625 .52931 L
s
[(-1.5)] -0.0125 .52931 1 0 Mshowa
0 .69946 m
.00625 .69946 L
s
[(-1)] -0.0125 .69946 1 0 Mshowa
.125 Mabswid
0 .0529 m
.00375 .0529 L
s
0 .08693 m
.00375 .08693 L
s
0 .12096 m
.00375 .12096 L
s
0 .15499 m
.00375 .15499 L
s
0 .22304 m
.00375 .22304 L
s
0 .25707 m
.00375 .25707 L
s
0 .2911 m
.00375 .2911 L
s
0 .32513 m
.00375 .32513 L
s
0 .39319 m
.00375 .39319 L
s
0 .42722 m
.00375 .42722 L
s
0 .46125 m
.00375 .46125 L
s
0 .49528 m
.00375 .49528 L
s
0 .56334 m
.00375 .56334 L
s
0 .59737 m
.00375 .59737 L
s
0 .6314 m
.00375 .6314 L
s
0 .66543 m
.00375 .66543 L
s
0 .73349 m
.00375 .73349 L
s
0 .76752 m
.00375 .76752 L
s
.25 Mabswid
0 0 m
0 .79244 L
s
.02381 .78619 m
.02381 .79244 L
s
.19396 .78619 m
.19396 .79244 L
s
.3641 .78619 m
.3641 .79244 L
s
.53425 .78619 m
.53425 .79244 L
s
.7044 .78619 m
.7044 .79244 L
s
.87455 .78619 m
.87455 .79244 L
s
.125 Mabswid
.05784 .78869 m
.05784 .79244 L
s
.09187 .78869 m
.09187 .79244 L
s
.1259 .78869 m
.1259 .79244 L
s
.15993 .78869 m
.15993 .79244 L
s
.22799 .78869 m
.22799 .79244 L
s
.26202 .78869 m
.26202 .79244 L
s
.29605 .78869 m
.29605 .79244 L
s
.33007 .78869 m
.33007 .79244 L
s
.39813 .78869 m
.39813 .79244 L
s
.43216 .78869 m
.43216 .79244 L
s
.46619 .78869 m
.46619 .79244 L
s
.50022 .78869 m
.50022 .79244 L
s
.56828 .78869 m
.56828 .79244 L
s
.60231 .78869 m
.60231 .79244 L
s
.63634 .78869 m
.63634 .79244 L
s
.67037 .78869 m
.67037 .79244 L
s
.73843 .78869 m
.73843 .79244 L
s
.77246 .78869 m
.77246 .79244 L
s
.80649 .78869 m
.80649 .79244 L
s
.84052 .78869 m
.84052 .79244 L
s
.90858 .78869 m
.90858 .79244 L
s
.94261 .78869 m
.94261 .79244 L
s
.97664 .78869 m
.97664 .79244 L
s
.25 Mabswid
0 .79244 m
1 .79244 L
s
.99375 .01887 m
1 .01887 L
s
.99375 .18901 m
1 .18901 L
s
.99375 .35916 m
1 .35916 L
s
.99375 .52931 m
1 .52931 L
s
.99375 .69946 m
1 .69946 L
s
.125 Mabswid
.99625 .0529 m
1 .0529 L
s
.99625 .08693 m
1 .08693 L
s
.99625 .12096 m
1 .12096 L
s
.99625 .15499 m
1 .15499 L
s
.99625 .22304 m
1 .22304 L
s
.99625 .25707 m
1 .25707 L
s
.99625 .2911 m
1 .2911 L
s
.99625 .32513 m
1 .32513 L
s
.99625 .39319 m
1 .39319 L
s
.99625 .42722 m
1 .42722 L
s
.99625 .46125 m
1 .46125 L
s
.99625 .49528 m
1 .49528 L
s
.99625 .56334 m
1 .56334 L
s
.99625 .59737 m
1 .59737 L
s
.99625 .6314 m
1 .6314 L
s
.99625 .66543 m
1 .66543 L
s
.99625 .73349 m
1 .73349 L
s
.99625 .76752 m
1 .76752 L
s
.25 Mabswid
1 0 m
1 .79244 L
s
0 0 m
1 0 L
1 .79244 L
0 .79244 L
closepath
clip
newpath
.5 Mabswid
.96138 .68545 m
.95596 .69438 L
.95015 .70227 L
.93432 .71866 L
.91543 .73255 L
.89161 .74511 L
.87753 .75081 L
.86117 .75625 L
.84586 .76041 L
.82877 .76417 L
.81268 .767 L
.79422 .76951 L
.78591 .77041 L
.77682 .77126 L
.76002 .77244 L
.7507 .77291 L
.74553 .77311 L
.74062 .77327 L
.73601 .77338 L
.73357 .77343 L
.73099 .77348 L
.7264 .77354 L
.72216 .77357 L
.71711 .77357 L
.71427 .77356 L
.71167 .77354 L
.7066 .77349 L
.70177 .7734 L
.69614 .77327 L
.6909 .77312 L
.67896 .77266 L
.66037 .77166 L
.63961 .77015 L
.59706 .76589 L
.55525 .76032 L
.51705 .75413 L
.43317 .73705 L
.35652 .71719 L
.29317 .69713 L
.23832 .67587 L
.19735 .6558 L
.15896 .63067 L
.12729 .60353 L
.09718 .57023 L
.07352 .53625 L
.05388 .49902 L
.04481 .47686 L
.03776 .45561 L
.03192 .43299 L
.02961 .42172 L
Mistroke
.02781 .4112 L
.02637 .40085 L
.02534 .39145 L
.0249 .38641 L
.02451 .38097 L
.02419 .37521 L
.02407 .37237 L
.02398 .36979 L
.0239 .36704 L
.02385 .36444 L
.02382 .3617 L
.02381 .36015 L
.02381 .35872 L
.02382 .35633 L
.02385 .35371 L
.02391 .35097 L
.02398 .34839 L
.02408 .34552 L
.02422 .3425 L
.02452 .33711 L
.02495 .33132 L
.02553 .325 L
.02693 .31321 L
.02887 .3007 L
.03353 .2784 L
.03976 .2562 L
.04818 .23271 L
.06774 .19193 L
.0922 .15454 L
.12315 .11886 L
.15618 .08978 L
.19018 .06667 L
.21072 .0554 L
.23085 .04604 L
.27007 .03212 L
.29104 .0268 L
.30267 .02446 L
.31366 .02263 L
.32381 .02126 L
.33316 .02028 L
.33812 .01986 L
.34356 .01949 L
.34904 .0192 L
.35203 .01908 L
.35481 .01899 L
.35767 .01893 L
.35911 .0189 L
.3607 .01888 L
.3635 .01887 L
.36612 .01887 L
Mistroke
.36771 .01889 L
.36921 .01891 L
.37204 .01896 L
.37362 .019 L
.37508 .01904 L
.37839 .01917 L
.38405 .01945 L
.38916 .01979 L
.40061 .02083 L
.41086 .02209 L
.42189 .02381 L
.44171 .02783 L
.46234 .03335 L
.48453 .04089 L
.52747 .06064 L
.56944 .08682 L
.62127 .12568 L
.73676 .23026 L
.84706 .35383 L
.89087 .41321 L
.93075 .47799 L
.94581 .5078 L
.95889 .53894 L
.96461 .55558 L
.96888 .57046 L
.97207 .58433 L
.97343 .59169 L
.97446 .59853 L
.9752 .60475 L
.97551 .60799 L
.97578 .6114 L
.97595 .61424 L
.97608 .61734 L
.97616 .62014 L
.97619 .62273 L
.97617 .62596 L
.97609 .62899 L
.97597 .63169 L
.97579 .6346 L
.97553 .63774 L
.97518 .64104 L
.97437 .64687 L
.97339 .65226 L
.9721 .65795 L
.96912 .66794 L
.96544 .67726 L
.96138 .68545 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{279, 221},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004G0000gA000`40O003h00Oogoo67oo003oOolH
Ool00?mooaQoo`00ogoo67oo003oOolHOol00?mooaQoo`0087oo00<007ooOol08goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol087oo1@008Goo1@000Woo00<007ooOol00Woo00<007ooOol0
8Woo0`008Woo0`000goo00<007ooOol00Woo00<007ooOol06Woo000OOol00`00Ool0000SOol00`00
Ool00007Ool00`00Ool0000SOol00`00Oomoo`0SOol00`00Oomoo`06Ool00`00Ool0000SOol00`00
Oomoo`0ROol00`00Oomoo`07Ool00`00Ool0000KOol001moo`03001oo`0002=oo`03001oo`0000Uo
o`03001oogoo025oo`03001oogoo02=oo`03001oogoo00Qoo`03001oogoo029oo`03001oogoo029o
o`03001oogoo00Qoo`03001oogoo01Uoo`007goo00<007oo00008goo00<007oo00001goo0P0097oo
00<007ooOol08goo00<007ooOol01Woo0P009Goo00<007ooOol08Woo00<007ooOol01Woo0P0077oo
000OOol00`00Ool0000SOol00`00Ool00007Ool00`00Oomoo`0SOol00`00Oomoo`0SOol00`00Oomo
o`06Ool00`00Oomoo`0SOol00`00Ool0000ROol00`00Ool00007Ool00`00Oomoo`0KOol0021oo`03
001oogoo02=oo`03001oogoo00Ioo`<0029oo`8002Aoo`8000Qoo`<002Aoo`03001oogoo029oo`03
001oogoo00Ioo`<001]oo`00ogoo67oo003oOolHOol00?mooaQoo`00ogoo67oo003oOolHOol001]o
oo/0005oo`006goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol00Woo0@000Goo000KOol00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`0XOol0
0`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0XOol00`00Oomoo`0LOol10001Ool001Aoo`80
00Eoo`03001oogoo0?Moo`40005oo`005Woo00<007ooOol00Woo00<007ooOol0mgoo0@000Goo000?
Ool30003Ool00`00Oomoo`03Ool2001AOolC002COol20001Ool001Ioo`03001oogoo009oo`03001o
ogoo04Qoo`P001=oo`H008ioo`40005oo`0057oo00<007oo000017oo00<007ooOol0A7oo10008Goo
1000RWoo0@000Goo000EOol00`00Oomoo`03Ool00`00Oomoo`0oOol5000YOol30027Ool10001Ool0
01]oo`03001oogoo03eoo`80035oo`@008=oo`40005oo`006goo00<007ooOol0>goo0P00=goo1000
Ogoo0@000Goo000KOol00`00Oomoo`0iOol2000mOol2001mOol10001Ool001]oo`03001oogoo03Io
o`<0045oo`8007]oo`40005oo`006goo0P00=7oo0`00AWoo0P00N7oo0P000Goo000KOol00`00Oomo
o`0aOol2001;Ool2001gOol10001Ool001]oo`03001oogoo02moo`8004moo`8007Eoo`40005oo`00
6goo00<007ooOol0;Goo0P00Dgoo0P00Lgoo0@000Goo000KOol00`00Oomoo`0/Ool00`00Oomoo`1E
Ool00`00Oomoo`1`Ool10001Ool001]oo`03001oogoo02]oo`03001oogoo05Moo`03001oogoo06mo
o`40005oo`006goo00<007ooOol0:Goo0P00Fgoo0P00Kgoo0@000Goo000KOol00`00Oomoo`0XOol0
0`00Oomoo`1MOol00`00Oomoo`1/Ool10001Ool001]oo`03001oogoo02Moo`03001oogoo05moo`80
06aoo`40005oo`006goo0P009Woo0P00I7oo00<007ooOol0J7oo0P000Goo000KOol00`00Oomoo`0T
Ool00`00Oomoo`1UOol00`00Oomoo`1XOol10001Ool001]oo`03001oogoo02=oo`03001oogoo06Mo
o`8006Qoo`40005oo`006goo00<007ooOol08Woo00<007ooOol0JWoo00<007ooOol0IGoo0@000Goo
000KOol00`00Oomoo`0QOol00`00Oomoo`1/Ool00`00Oomoo`1TOol10001Ool001]oo`03001oogoo
01moo`80071oo`8006Aoo`40005oo`006goo00<007ooOol07Woo00<007ooOol0LWoo00<007ooOol0
HGoo0@000Goo000KOol00`00Oomoo`0MOol00`00Oomoo`1dOol00`00Oomoo`1POol10001Ool001]o
o`03001oogoo01aoo`03001oogoo07Ioo`80061oo`40005oo`006goo0P0077oo00<007ooOol0NGoo
00<007ooOol0G7oo0P000Goo000KOol00`00Oomoo`0JOol00`00Oomoo`1kOol00`00Oomoo`1LOol1
0001Ool001]oo`03001oogoo01Uoo`03001oogoo07eoo`03001oogoo05]oo`40005oo`006goo00<0
07ooOol067oo00<007ooOol0Ogoo00<007ooOol0FWoo0@000Goo000KOol00`00Oomoo`0HOol00`00
Oomoo`20Ool00`00Oomoo`1IOol10001Ool001]oo`03001oogoo01Moo`03001oogoo089oo`8005Uo
o`40005oo`006goo00<007ooOol05Woo00<007ooOol0QGoo00<007ooOol0EWoo0@000Goo000KOol0
0`00Oomoo`0EOol00`00Oomoo`27Ool00`00Oomoo`1EOol10001Ool001]oo`8001Eoo`03001oogoo
08Uoo`03001oogoo05=oo`80005oo`006goo00<007ooOol04goo00<007ooOol0Rgoo00<007ooOol0
Dgoo0@000Goo000KOol00`00Oomoo`0COol00`00Oomoo`2<Ool00`00Oomoo`1BOol10001Ool001]o
o`03001oogoo019oo`03001oogoo08ioo`03001oogoo055oo`40005oo`006goo00<007ooOol04Goo
00<007ooOol0T7oo00<007ooOol0D7oo0@000Goo000KOol00`00Oomoo`0AOol00`00Oomoo`2AOol0
0`00Oomoo`1?Ool10001Ool001]oo`03001oogoo011oo`03001oogoo09=oo`8004moo`40005oo`00
2Woo0`000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol0UWoo00<0
07ooOol0C7oo0@000Goo000:Ool00`00Oomoo`07Ool00`00Ool00004Ool00`00Oomoo`0?Ool00`00
Oomoo`2GOol00`00Oomoo`1;Ool10001Ool000Eoo`<000=oo`03001oogoo00Qoo`03001oogoo009o
o`8000moo`03001oogoo09Uoo`03001oogoo04Uoo`80005oo`002goo00<007ooOol01Woo0P001Goo
00<007ooOol03Woo00<007ooOol0VWoo00<007ooOol0BGoo0@000Goo000:Ool00`00Ool00007Ool0
0`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`2LOol00`00Oomoo`18Ool10001Ool000]oo`03
001oogoo00Ioo`<000Aoo`03001oogoo00eoo`03001oogoo09eoo`03001oogoo04Moo`40005oo`00
6goo00<007ooOol037oo00<007ooOol0Wgoo00<007ooOol0AWoo0@000Goo000KOol00`00Oomoo`0<
Ool00`00Oomoo`2POol00`00Oomoo`15Ool10001Ool001]oo`03001oogoo00]oo`03001oogoo0:9o
o`8004Eoo`40005oo`006goo00<007ooOol02goo00<007ooOol0Y7oo00<007ooOol0@Woo0@000Goo
000KOol2000;Ool00`00Oomoo`2VOol00`00Oomoo`10Ool20001Ool001]oo`03001oogoo00Yoo`03
001oogoo0:Moo`03001oogoo041oo`40005oo`006goo00<007ooOol02Goo00<007ooOol0ZGoo00<0
07ooOol0?goo0@000Goo000KOol00`00Oomoo`09Ool00`00Oomoo`2ZOol00`00Oomoo`0nOol10001
Ool001]oo`03001oogoo00Uoo`03001oogoo0:]oo`03001oogoo03eoo`40005oo`006goo00<007oo
Ool027oo00<007ooOol0[Goo00<007ooOol0?7oo0@000Goo000KOol00`00Oomoo`08Ool00`00Oomo
o`2^Ool00`00Oomoo`0kOol10001Ool001]oo`03001oogoo00Moo`03001oogoo0;1oo`03001oogoo
03Yoo`40005oo`006goo00<007ooOol01goo00<007ooOol0/7oo00<007ooOol0>Woo0@000Goo000K
Ool20008Ool00`00Oomoo`2aOol00`00Oomoo`0hOol20001Ool001]oo`03001oogoo00Ioo`03001o
ogoo0;=oo`03001oogoo03Qoo`40005oo`006goo00<007ooOol01Woo00<007ooOol0]7oo00<007oo
Ool0=goo0@000Goo000KOol00`00Oomoo`06Ool00`00Oomoo`2eOol00`00Oomoo`0fOol10001Ool0
01]oo`03001oogoo00Eoo`03001oogoo0;Moo`03001oogoo03Eoo`40005oo`006goo00<007ooOol0
1Goo00<007ooOol0^7oo00<007ooOol0=7oo0@000Goo000KOol00`00Oomoo`05Ool00`00Oomoo`2i
Ool00`00Oomoo`0cOol10001Ool001]oo`03001oogoo00Eoo`03001oogoo0;Yoo`03001oogoo039o
o`40005oo`006goo0P001Goo00<007ooOol0_7oo00<007ooOol0<7oo0P000Goo000KOol00`00Oomo
o`04Ool00`00Oomoo`2lOol00`00Oomoo`0aOol10001Ool001]oo`03001oogoo00Aoo`03001oogoo
0;eoo`03001oogoo031oo`40005oo`006goo00<007ooOol017oo00<007ooOol0_Woo00<007ooOol0
;goo0@000Goo000KOol00`00Oomoo`04Ool00`00Oomoo`2oOol00`00Oomoo`0^Ool10001Ool001]o
o`03001oogoo00=oo`03001oogoo0<5oo`03001oogoo02eoo`40005oo`006goo00<007ooOol00goo
00<007ooOol0`Woo00<007ooOol0;7oo0@000Goo000KOol00`00Oomoo`03Ool00`00Oomoo`33Ool0
0`00Oomoo`0[Ool10001Ool001]oo`03001oogoo00=oo`03001oogoo0<Aoo`03001oogoo02Yoo`40
005oo`006goo0P0017oo00<007ooOol0aGoo00<007ooOol0:7oo0P000Goo000KOol00`00Oomoo`03
Ool00`00Oomoo`36Ool00`00Oomoo`0XOol10001Ool001]oo`03001oogoo00=oo`03001oogoo0<Io
o`03001oogoo02Qoo`40005oo`006goo00<007ooOol00goo00<007ooOol0agoo00<007ooOol09goo
0@000Goo000KOol00`00Oomoo`03Ool00`00Oomoo`38Ool00`00Oomoo`0VOol10001Ool001]oo`03
001oogoo00=oo`03001oogoo0<Uoo`03001oogoo02Eoo`40005oo`0057oo0`0017oo00<007ooOol0
0goo00<007ooOol0bWoo00<007ooOol097oo0@000Goo000DOol00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`3;Ool00`00Oomoo`0SOol10001Ool000moo`<000=oo`03001oogoo00=oo`8000Ao
o`03001oogoo0<aoo`03001oogoo025oo`80005oo`005Goo00<007ooOol00goo00<007ooOol00goo
00<007ooOol0c7oo00<007ooOol08Woo0@000Goo000DOol00`00Ool00004Ool00`00Oomoo`03Ool0
0`00Oomoo`3=Ool00`00Oomoo`0QOol10001Ool001Eoo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo0<ioo`03001oogoo021oo`40005oo`006goo00<007ooOol00goo00<007ooOol0cgoo00<0
07ooOol07goo0@000Goo000KOol00`00Oomoo`03Ool00`00Oomoo`3?Ool00`00Oomoo`0OOol10001
Ool001]oo`03001oogoo00=oo`03001oogoo0=1oo`03001oogoo01ioo`40005oo`006goo00<007oo
Ool00goo00<007ooOol0dGoo00<007ooOol07Goo0@000Goo000KOol00`00Oomoo`03Ool00`00Oomo
o`3BOol00`00Oomoo`0LOol10001Ool001]oo`8000Aoo`03001oogoo0=9oo`03001oogoo01]oo`80
005oo`006goo00<007ooOol00goo00<007ooOol0dgoo00<007ooOol06goo0@000Goo000KOol00`00
Oomoo`03Ool00`00Oomoo`3DOol00`00Oomoo`0JOol10001Ool001]oo`03001oogoo00=oo`03001o
ogoo0=Eoo`03001oogoo01Uoo`40005oo`006goo00<007ooOol017oo00<007ooOol0e7oo00<007oo
Ool06Goo0@000Goo000KOol00`00Oomoo`04Ool00`00Oomoo`3EOol00`00Oomoo`0HOol10001Ool0
01]oo`03001oogoo00Aoo`03001oogoo0=Ioo`03001oogoo01Moo`40005oo`006goo00<007ooOol0
17oo00<007ooOol0eWoo00<007ooOol05goo0@000Goo000KOol20005Ool00`00Oomoo`3GOol00`00
Oomoo`0EOol20001Ool001]oo`03001oogoo00Eoo`03001oogoo0=Ioo`03001oogoo01Ioo`40005o
o`006goo00<007ooOol01Goo00<007ooOol0egoo00<007ooOol05Goo0@000Goo000KOol00`00Oomo
o`05Ool00`00Oomoo`3HOol00`00Oomoo`0DOol10001Ool001]oo`03001oogoo00Eoo`03001oogoo
0=Qoo`03001oogoo01Aoo`40005oo`006goo00<007ooOol01Woo00<007ooOol0f7oo00<007ooOol0
4goo0@000Goo000KOol00`00Oomoo`06Ool00`00Oomoo`3IOol00`00Oomoo`0BOol10001Ool001]o
o`03001oogoo00Ioo`03001oogoo0=Uoo`03001oogoo019oo`40005oo`006goo00<007ooOol01Woo
00<007ooOol0fWoo00<007ooOol04Goo0@000Goo000KOol20008Ool00`00Oomoo`3IOol00`00Oomo
o`0@Ool20001Ool001]oo`03001oogoo00Moo`03001oogoo0=Yoo`03001oogoo011oo`40005oo`00
6goo00<007ooOol01goo00<007ooOol0fgoo00<007ooOol03goo0@000Goo000KOol00`00Oomoo`08
Ool00`00Oomoo`3JOol00`00Oomoo`0?Ool10001Ool001]oo`03001oogoo00Qoo`03001oogoo0=]o
o`03001oogoo00ioo`40005oo`006goo00<007ooOol027oo00<007ooOol0fgoo00<007ooOol03Woo
0@000Goo000KOol00`00Oomoo`09Ool00`00Oomoo`3KOol00`00Oomoo`0=Ool10001Ool001]oo`03
001oogoo00Uoo`03001oogoo0=]oo`03001oogoo00eoo`40005oo`006goo0P002goo00<007ooOol0
fgoo00<007ooOol02goo0P000Goo000KOol00`00Oomoo`0:Ool00`00Oomoo`3KOol00`00Oomoo`0<
Ool10001Ool001]oo`03001oogoo00Yoo`03001oogoo0=aoo`03001oogoo00]oo`40005oo`006goo
00<007ooOol02goo00<007ooOol0fgoo00<007ooOol02goo0@000Goo000KOol00`00Oomoo`0;Ool0
0`00Oomoo`3LOol00`00Oomoo`0:Ool10001Ool001]oo`03001oogoo00aoo`03001oogoo0=]oo`03
001oogoo00Yoo`40005oo`006goo00<007ooOol037oo00<007ooOol0g7oo00<007ooOol02Goo0@00
0Goo0009Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`3K
Ool00`00Oomoo`09Ool10001Ool000]oo`03001oogoo00Ioo`03001oo`0000Aoo`03001oogoo00eo
o`03001oogoo0=aoo`03001oogoo00Qoo`40005oo`001Goo0`000goo00<007ooOol027oo00<007oo
Ool00Woo0P003goo00<007ooOol0fgoo00<007ooOol01goo0P000Goo000;Ool00`00Oomoo`06Ool2
0005Ool00`00Oomoo`0>Ool00`00Oomoo`3LOol00`00Oomoo`07Ool10001Ool000]oo`03001oogoo
00Ioo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo0=]oo`03001oogoo00Moo`40005oo`00
2Woo0P0027oo0`0017oo00<007ooOol047oo00<007ooOol0fWoo00<007ooOol01goo0@000Goo000K
Ool00`00Oomoo`0@Ool00`00Oomoo`3KOol00`00Oomoo`06Ool10001Ool001]oo`03001oogoo015o
o`03001oogoo0=Yoo`03001oogoo00Ioo`40005oo`006goo00<007ooOol04Woo00<007ooOol0fWoo
00<007ooOol01Goo0@000Goo000KOol00`00Oomoo`0COol00`00Oomoo`3IOol00`00Oomoo`05Ool1
0001Ool001]oo`8001Aoo`03001oogoo0=Uoo`03001oogoo00Aoo`80005oo`006goo00<007ooOol0
57oo00<007ooOol0fGoo00<007ooOol017oo0@000Goo000KOol00`00Oomoo`0EOol00`00Oomoo`3H
Ool00`00Oomoo`04Ool10001Ool001]oo`03001oogoo01Ioo`03001oogoo0=Moo`03001oogoo00Ao
o`40005oo`006goo00<007ooOol05goo00<007ooOol0eWoo00<007ooOol017oo0@000Goo000KOol0
0`00Oomoo`0HOol00`00Oomoo`3EOol00`00Oomoo`04Ool10001Ool001]oo`03001oogoo01Uoo`03
001oogoo0=Aoo`03001oogoo00Aoo`40005oo`006goo00<007ooOol06Goo00<007ooOol0e7oo00<0
07ooOol017oo0@000Goo000KOol00`00Oomoo`0JOol00`00Oomoo`3DOol00`00Oomoo`03Ool10001
Ool001]oo`8001aoo`03001oogoo0==oo`03001oogoo009oo`80005oo`006goo00<007ooOol077oo
00<007ooOol0dWoo00<007ooOol00goo0@000Goo000KOol00`00Oomoo`0MOol00`00Oomoo`3AOol0
0`00Oomoo`03Ool10001Ool001]oo`03001oogoo01ioo`03001oogoo0=1oo`03001oogoo00=oo`40
005oo`006goo00<007ooOol07goo00<007ooOol0cgoo00<007ooOol00goo0@000Goo000KOol00`00
Oomoo`0POol2003?Ool00`00Oomoo`03Ool10001Ool001]oo`03001oogoo029oo`03001oogoo0<ao
o`03001oogoo00=oo`40005oo`006goo00<007ooOol08goo00<007ooOol0bgoo00<007ooOol00goo
0@000Goo000KOol00`00Oomoo`0TOol00`00Oomoo`3:Ool00`00Oomoo`03Ool10001Ool001]oo`80
02Ioo`800<Yoo`03001oogoo009oo`80005oo`006goo00<007ooOol09goo00<007ooOol0agoo00<0
07ooOol00goo0@000Goo000KOol00`00Oomoo`0XOol00`00Oomoo`36Ool00`00Oomoo`03Ool10001
Ool001]oo`03001oogoo02Uoo`800<Ioo`03001oogoo00=oo`40005oo`006goo00<007ooOol0:goo
00<007ooOol0`goo00<007ooOol00goo0@000Goo000KOol00`00Oomoo`0/Ool20033Ool00`00Oomo
o`03Ool10001Ool001]oo`03001oogoo02ioo`03001oogoo0;moo`03001oogoo00Aoo`40005oo`00
6goo00<007ooOol0;goo0P00_goo00<007ooOol017oo0@000Goo000KOol2000bOol2002mOol00`00
Oomoo`03Ool20001Ool001]oo`03001oogoo03=oo`800;]oo`03001oogoo00Aoo`40005oo`006goo
00<007ooOol0=Goo0P00^7oo00<007ooOol01Goo0@000Goo000KOol00`00Oomoo`0gOol3002eOol0
0`00Oomoo`05Ool10001Ool001]oo`03001oogoo03Yoo`<00;5oo`03001oogoo00Ioo`40005oo`00
6goo00<007ooOol0?Goo0P00[goo00<007ooOol01Woo0@000Goo000KOol00`00Oomoo`0oOol3002[
Ool00`00Oomoo`07Ool10001Ool001=oo`D000=oo`03001oogoo049oo`<00:Moo`03001oogoo00Qo
o`40005oo`005Goo00<007ooOol00goo00<007ooOol0AGoo0`00Xgoo00<007ooOol02Goo0@000Goo
000?Ool30003Ool00`00Oomoo`03Ool20019Ool3002POol00`00Oomoo`08Ool20001Ool001Eoo`03
001oogoo00=oo`03001oogoo04]oo`<009aoo`03001oogoo00Yoo`40005oo`005Goo00<007ooOol0
0goo00<007ooOol0CWoo1000Ugoo00<007ooOol02goo0@000Goo000DOol20005Ool00`00Oomoo`1B
Ool3002COol00`00Oomoo`0<Ool10001Ool001]oo`03001oogoo05Eoo`<008moo`03001oogoo00eo
o`40005oo`006goo00<007ooOol0F7oo1000RWoo00<007ooOol03Woo0@000Goo000KOol00`00Oomo
o`1LOol40024Ool2000AOol10001Ool001]oo`03001oogoo061oo`@007moo`03001oogoo015oo`40
005oo`006goo0P00IGoo1000NWoo00<007ooOol04Goo0P000Goo000KOol00`00Oomoo`1XOol4001d
Ool2000EOol10001Ool001]oo`03001oogoo06aoo`D006eoo`8001Moo`40005oo`006goo00<007oo
Ool0LGoo1P00I7oo0`006Goo0@000Goo000KOol00`00Oomoo`1gOol5001MOol2000LOol10001Ool0
01]oo`03001oogoo07aoo`D005Ioo`8001ioo`40005oo`006goo00<007ooOol0PGoo1@00CWoo0`00
87oo0@000Goo000KOol00`00Oomoo`26Ool70012Ool5000SOol10001Ool001]oo`03001oogoo08eo
o`/003=oo`@002Qoo`40005oo`006goo0P00VGoo20008Goo2P00:goo0P000Goo000KOol00`00Oomo
o`2POolQ000fOol10001Ool001]oo`03001oogoo0?Moo`40005oo`006goo00<007ooOol0mgoo0@00
0Goo000KOol00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00
Oomoo`0WOol00`00Oomoo`0XOol00`00Oomoo`0LOol10001Ool001]oo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo009oo`40005oo`006goon`000Goo
003oOolHOol00?mooaQoo`00ogoo67oo003oOolHOol00001\
\>"],
  ImageRangeCache->{{{0, 278}, {220, 0}} -> {-0.387993, -3.25139, 0.0117199, 
  0.0117199}}]
}, Open  ]],

Cell[TextData[{
  "Note that the ",
  StyleBox["DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " was set to ",
  StyleBox["Identity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default so as not to produce unwanted output when the ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is evaluated. This must be rectified when the ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is shown with the ",
  StyleBox["DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["$DisplayFunctio",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "n setting."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Example 2D Cam Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam functions a 2D model of a rotating cam with a flat follower is \
developed. The model consists of two moving bodies, the cam and the \
follower."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the 2D cam-follower mechanism. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
  
%%Creator: Mathematica 
  
%%AspectRatio: 1.11111  
  
MathPictureStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
0.5 0.111111 0.5 0.111111 [ 
  
[ 0 0 0 0 ] 
  
[ 1 1.11111 0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
0 g 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 1.11111 L 
  
0 1.11111 L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
.004 w 
  
.11111 .94444 m 
  
.05556 .94444 L 
  
.05556 .05556 L 
  
.94444 .05556 L 
  
.61111 .05556 L 
  
.5 .5 L 
  
.38889 .05556 L 
  
s 
  
.015 w 
  
.5 .5 Mdot 
  
.11111 .94444 Mdot 
  
.004 w 
  
newpath 
  
.5 .5 .14444 0 365.73 arc 
  
s 
  
P 
  
p 
  
p 
  
.015 w 
  
.11111 .94444 Mdot 
  
.17788 .83969 Mdot 
  
.84096 .90876 Mdot 
  
P 
  
0 0 1 r 
  
p 
  
.02 w 
  
.11111 .94444 m 
  
.49791 .98474 L 
  
s 
  
P 
  
p 
  
.38739 .97323 m 
  
.60842 .99625 L 
  
.84096 .90876 L 
  
.17788 .83969 L 
  
F 
  
P 
  
P 
  
p 
  
p 
  
p 
  
.004 w 
  
.83333 .5 m 
  
.83332 .50455 L 
  
.83329 .50909 L 
  
.83323 .51363 L 
  
.83315 .51817 L 
  
.83305 .52271 L 
  
.83293 .52725 L 
  
.83262 .5363 L 
  
.83222 .54534 L 
  
.83173 .55435 L 
  
.83048 .57227 L 
  
.82888 .59001 L 
  
.82693 .60755 L 
  
.82198 .64183 L 
  
.81564 .67479 L 
  
.80796 .70613 L 
  
.79896 .73558 L 
  
.78868 .76289 L 
  
.76445 .81025 L 
  
.75061 .82994 L 
  
.7357 .84681 L 
  
.71978 .86077 L 
  
.71146 .86665 L 
  
.70292 .87178 L 
  
.69416 .87616 L 
  
.68519 .87981 L 
  
.67602 .88272 L 
  
.67137 .8839 L 
  
.66667 .8849 L 
  
.66192 .88572 L 
  
.65713 .88636 L 
  
.65472 .88661 L 
  
.6523 .88682 L 
  
.64987 .88699 L 
  
.64743 .88711 L 
  
.64498 .88719 L 
  
.64252 .88722 L 
  
.64005 .88721 L 
  
.63757 .88716 L 
  
.63508 .88706 L 
  
.63258 .88693 L 
  
.63008 .88675 L 
  
.62756 .88653 L 
  
.62251 .88596 L 
  
.61742 .88523 L 
  
.60715 .88328 L 
  
.59676 .88071 L 
  
.58627 .87753 L 
  
.54351 .85924 L 
  
.5 .83333 L 
  
Mistroke 
  
.41373 .76642 L 
  
.33333 .69245 L 
  
.2643 .62459 L 
  
.21132 .57044 L 
  
.19204 .54899 L 
  
.18436 .53951 L 
  
.17802 .53072 L 
  
.17307 .52251 L 
  
.16952 .51475 L 
  
.16827 .511 L 
  
.16778 .50914 L 
  
.16738 .5073 L 
  
.16707 .50547 L 
  
.16695 .50455 L 
  
.16685 .50364 L 
  
.16677 .50273 L 
  
.16671 .50182 L 
  
.16668 .50091 L 
  
.16667 .5 L 
  
.16668 .49909 L 
  
.16671 .49818 L 
  
.16677 .49727 L 
  
.16685 .49636 L 
  
.16695 .49545 L 
  
.16707 .49453 L 
  
.16738 .4927 L 
  
.16827 .489 L 
  
.16952 .48525 L 
  
.17307 .47749 L 
  
.17802 .46928 L 
  
.21132 .42956 L 
  
.2643 .37541 L 
  
.33333 .30755 L 
  
.41373 .23358 L 
  
.45649 .19828 L 
  
.5 .16667 L 
  
.54351 .14076 L 
  
.56503 .13055 L 
  
.58627 .12247 L 
  
.59676 .11929 L 
  
.60715 .11672 L 
  
.61742 .11477 L 
  
.62251 .11404 L 
  
.62756 .11347 L 
  
.63008 .11325 L 
  
.63258 .11307 L 
  
.63508 .11294 L 
  
.63757 .11284 L 
  
.64005 .11279 L 
  
.64252 .11278 L 
  
Mistroke 
  
.64498 .11281 L 
  
.64743 .11289 L 
  
.64987 .11301 L 
  
.6523 .11318 L 
  
.65713 .11364 L 
  
.66192 .11428 L 
  
.66667 .1151 L 
  
.67602 .11728 L 
  
.68519 .12019 L 
  
.69416 .12384 L 
  
.70292 .12822 L 
  
.71978 .13923 L 
  
.7357 .15319 L 
  
.75061 .17006 L 
  
.76445 .18975 L 
  
.77716 .21216 L 
  
.78868 .23711 L 
  
.79896 .26442 L 
  
.80796 .29387 L 
  
.81564 .32521 L 
  
.82198 .35817 L 
  
.82463 .37516 L 
  
.82693 .39245 L 
  
.82888 .40999 L 
  
.83048 .42773 L 
  
.83173 .44565 L 
  
.83222 .45466 L 
  
.83262 .4637 L 
  
.83293 .47275 L 
  
.83305 .47729 L 
  
.83315 .48183 L 
  
.83323 .48637 L 
  
.83329 .49091 L 
  
.83332 .49545 L 
  
.83333 .5 L 
  
Mfstroke 
  
P 
  
P 
  
P 
  
p 
  
.018 w 
  
.62629 .8864 Mdot 
  
P 
  
P 
  
% End of Graphics 
  
MathPictureEnd 
  
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004200017a000`40O003h00Oogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00
ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`003Wooi@003goo000>
Ool00`00Oomoo`1BOol00`00Oomoo`0gOol00`00Oomoo`1ROol000ioo`03001oogoo05=oo`03001o
ogoo03Eoo`03001oogoo06=oo`003Woo00<007ooOol0Dgoo00<007ooOol0=Goo00<007ooOol0Hgoo
000>Ool00`00Oomoo`1COol00`00Oomoo`0eOol00`00Oomoo`1SOol000ioo`03001oogoo05=oo`03
001oogoo03Eoo`03001oogoo06=oo`003Woo00<007ooOol0E7oo00<007ooOol0<goo00<007ooOol0
I7oo000>Ool00`00Oomoo`1DOol00`00Oomoo`0cOol00`00Oomoo`1TOol000ioo`03001oogoo05Ao
o`03001oogoo03=oo`03001oogoo06Aoo`003Woo00<007ooOol0E7oo00<007ooOol0<goo00<007oo
Ool0I7oo000>Ool00`00Oomoo`1EOol00`00Oomoo`0aOol00`00Oomoo`1UOol000ioo`03001oogoo
05Eoo`03001oogoo035oo`03001oogoo06Eoo`003Woo00<007ooOol0EGoo00<007ooOol0<Goo00<0
07ooOol0IGoo000>Ool00`00Oomoo`1EOol00`00Oomoo`0aOol00`00Oomoo`1UOol000ioo`03001o
ogoo05Ioo`03001oogoo02moo`03001oogoo06Ioo`003Woo00<007ooOol0EWoo00<007ooOol0;goo
00<007ooOol00Woo3P00EWoo000>Ool00`00Oomoo`1FOol00`00Oomoo`0^Ool6000>Ool3001COol0
00ioo`03001oogoo05Ioo`03001oogoo02]oo`<00003Ool007oo01Aoo`80055oo`003Woo00<007oo
Ool0Egoo00<007ooOol0:7oo0P000goo00<007ooOol05Woo0P00Cgoo000>Ool00`00Oomoo`1GOol0
0`00Oomoo`0VOol20005Ool00`00Oomoo`0HOol2001=Ool000ioo`03001oogoo05Moo`03001oogoo
02Aoo`8000Moo`03001oogoo01Yoo`03001oogoo04Yoo`003Woo00<007ooOol0Egoo00<007ooOol0
8Woo0P002Goo00<007ooOol06goo0P00BWoo000>Ool00`00Oomoo`1HOol00`00Oomoo`0OOol2000:
Ool00`00Oomoo`0NOol00`00Oomoo`17Ool000ioo`03001oogoo05Qoo`03001oogoo01eoo`8000ao
o`03001oogoo01moo`8004Moo`003Woo00<007ooOol0F7oo00<007ooOol077oo00<007ooOol037oo
00<007ooOol08Goo0P00AGoo000>Ool00`00Oomoo`1HOol00`00Oomoo`0JOol2000?Ool00`00Oomo
o`0SOol00`00Oomoo`12Ool000ioo`03001oogoo05Uoo`03001oogoo01Moo`80011oo`03001oogoo
02Eoo`03001oogoo045oo`003Woo00<007ooOol0FGoo00<007ooOol05Woo00<007ooOol047oo00<0
07ooOol09Goo00<007ooOol0@Goo000>Ool00`00Oomoo`1IOol00`00Oomoo`0DOol2000COol00`00
Oomoo`0VOol00`00Oomoo`10Ool000ioo`03001oogoo05Uoo`03001oogoo01=oo`03001oogoo01=o
o`03001oogoo02Moo`03001oogoo03moo`003Woo00<007ooOol0FWoo00<007ooOol047oo0P005Goo
00<007ooOol0:Goo00<007ooOol0?Woo000>Ool00`00Oomoo`1JOol00`00Oomoo`0?Ool00`00Oomo
o`0EOol00`00Oomoo`0ZOol00`00Oomoo`0mOol000ioo`03001oogoo05Yoo`03001oogoo00ioo`03
001oogoo01Ioo`03001oogoo02Yoo`03001oogoo03eoo`003Woo00<007ooOol0FWoo00<007ooOol0
37oo0P006Goo00<007ooOol0:goo00<007ooOol0?7oo000>Ool00`00Oomoo`1KOol00`00Oomoo`0:
Ool00`00Oomoo`0HOol00`00Oomoo`0]Ool00`00Oomoo`0kOol000ioo`03001oogoo05]oo`03001o
ogoo00Uoo`03001oogoo01Uoo`03001oogoo02eoo`03001oogoo03]oo`003Woo00<007ooOol0Fgoo
00<007ooOol01goo0P0077oo00<007ooOol0;Woo00<007ooOol0>Woo000>Ool00`00Oomoo`1KOol0
0`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomoo`0^Ool00`00Oomoo`0jOol000ioo`03001oogoo
05aoo`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo031oo`03001oogoo03Uoo`003Woo00<0
07ooOol0G7oo00<007ooOol00Woo0P007goo00<007ooOol0<7oo00<007ooOol0>Goo000>Ool00`00
Oomoo`1LOol01@00Oomoogoo00008Goo00<007ooOol0<Goo00<007ooOol0>7oo000>Ool00`00Oomo
o`1LOol01000Oomoo`008Woo00<007ooOol0<Goo00<007ooOol0>7oo000>Ool00`00Oomoo`1MOol2
000ROol00`00Oomoo`0cOol00`00Oomoo`0gOol000ioo`03001oogoo05eoo`03001oogoo025oo`03
001oogoo03=oo`03001oogoo03Moo`003Woo00<007ooOol0Fgoo0`008goo00<007ooOol0=7oo00<0
07ooOol0=Woo000>Ool00`00Oomoo`1JOol01000Oomoo`008goo00<007ooOol0=7oo00<007ooOol0
=Woo000>Ool00`00Oomoo`1IOol00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`0fOol00`00
Oomoo`0eOol000ioo`03001oogoo05Qoo`03001oogoo00=oo`03001oogoo01moo`03001oogoo03Io
o`03001oogoo03Eoo`003Woo00<007ooOol0Egoo00<007ooOol017oo00<007ooOol07goo00<007oo
Ool0=Woo00<007ooOol0=Goo000>Ool00`00Oomoo`1FOol00`00Oomoo`05Ool00`00Oomoo`0OOol0
0`00Oomoo`0gOol00`00Oomoo`0dOol000ioo`03001oogoo05Eoo`03001oogoo00Moo`03001oogoo
01eoo`03001oogoo03Qoo`03001oogoo03Aoo`003Woo00<007ooOol0Dgoo0P002Woo00<007ooOol0
7Goo00<007ooOol0>Goo00<007ooOol0<goo000>Ool00`00Oomoo`1BOol00`00Oomoo`0:Ool00`00
Oomoo`0MOol00`00Oomoo`0iOol00`00Oomoo`0cOol000ioo`03001oogoo055oo`03001oogoo00]o
o`03001oogoo01eoo`03001oogoo03Yoo`03001oogoo039oo`003Woo00<007ooOol0D7oo00<007oo
Ool03Goo00<007ooOol06goo00<007ooOol0>goo00<007ooOol0<Woo000>Ool00`00Oomoo`1?Ool0
0`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`0kOol00`00Oomoo`0bOol000ioo`03001oogoo
04ioo`03001oogoo00moo`03001oogoo01]oo`03001oogoo03aoo`03001oogoo035oo`003Woo00<0
07ooOol0CGoo00<007ooOol047oo00<007ooOol06Woo00<007ooOol0?Goo00<007ooOol0<Goo000>
Ool00`00Oomoo`1<Ool00`00Oomoo`0BOol00`00Oomoo`0IOol00`00Oomoo`0mOol00`00Oomoo`0a
Ool000ioo`03001oogoo04]oo`03001oogoo01=oo`03001oogoo01Uoo`03001oogoo03eoo`03001o
ogoo035oo`003Woo00<007ooOol0BGoo0P005Woo00<007ooOol06Goo00<007ooOol0?Woo00<007oo
Ool0<7oo000>Ool00`00Oomoo`18Ool00`00Oomoo`0GOol00`00Oomoo`0GOol00`00Oomoo`0oOol0
0`00Oomoo`0`Ool000ioo`03001oogoo04Moo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo
03moo`03001oogoo031oo`003Woo00<007ooOol0AWoo00<007ooOol06Goo00<007ooOol05goo00<0
07ooOol0?goo00<007ooOol0<7oo000>Ool00`00Oomoo`15Ool00`00Oomoo`0JOol00`00Oomoo`0G
Ool00`00Oomoo`10Ool00`00Oomoo`0_Ool000ioo`03001oogoo04Aoo`03001oogoo01aoo`03001o
ogoo01Eoo`03001oogoo045oo`03001oogoo02moo`003Woo00<007ooOol0@goo00<007ooOol07Goo
00<007ooOol05Goo00<007ooOol0@Goo00<007ooOol0;goo000>Ool00`00Oomoo`12Ool00`00Oomo
o`0NOol00`00Oomoo`0EOol00`00Oomoo`11Ool00`00Oomoo`0_Ool000ioo`03001oogoo045oo`03
001oogoo01moo`03001oogoo01Eoo`03001oogoo049oo`03001oogoo02ioo`003Woo00<007ooOol0
@7oo00<007ooOol08Goo00<007ooOol04goo00<007ooOol0@goo00<007ooOol0;Woo000>Ool00`00
Oomoo`0oOol00`00Oomoo`0ROol00`00Oomoo`0COol00`00Oomoo`13Ool00`00Oomoo`0^Ool000io
o`03001oogoo03ioo`03001oogoo02=oo`03001oogoo01=oo`03001oogoo04=oo`03001oogoo02io
o`003Woo00<007ooOol0?Goo00<007ooOol097oo00<007ooOol04goo00<007ooOol0A7oo00<007oo
Ool0;Goo000>Ool00`00Oomoo`0lOol00`00Oomoo`0VOol00`00Oomoo`0AOol00`00Oomoo`15Ool0
0`00Oomoo`0]Ool000ioo`03001oogoo03Yoo`8002Uoo`03001oogoo015oo`03001oogoo04Eoo`03
001oogoo02eoo`003Woo00<007ooOol0>Goo00<007ooOol0:Goo00<007ooOol04Goo00<007ooOol0
AGoo00<007ooOol0;Goo000>Ool00`00Oomoo`0hOol00`00Oomoo`0ZOol00`00Oomoo`0AOol00`00
Oomoo`16Ool00`00Oomoo`0/Ool000ioo`03001oogoo03Moo`03001oogoo02aoo`04001oogooOol;
0003Ool00`00Oomoo`17Ool00`00Oomoo`0/Ool000ioo`03001oogoo03Ioo`03001oogoo02aoo`D0
00]oo`D004Qoo`03001oogoo02aoo`003Woo00<007ooOol0=Goo00<007ooOol0:goo0P0000=oo`00
Ool047oo00@007oo000004Ioo`03001oogoo02aoo`003Woo00<007ooOol0=7oo00<007ooOol0:Goo
0`000goo00<007ooOol03goo00@007ooOomoo`<004=oo`03001oogoo02aoo`003Woo00<007ooOol0
<goo00<007ooOol0:7oo0P001goo00<007ooOol03Goo00<007ooOol01Goo0P00@Goo00<007ooOol0
;7oo000>Ool00`00Oomoo`0bOol00`00Oomoo`0WOol20009Ool00`00Oomoo`0=Ool00`00Oomoo`07
Ool2000oOol00`00Oomoo`0/Ool000ioo`03001oogoo035oo`03001oogoo02Moo`03001oogoo00Uo
o`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo03aoo`03001oogoo02aoo`003Woo00<007oo
Ool0<7oo00<007ooOol09Woo0P0037oo00<007ooOol03Goo00<007ooOol02Woo0P00?7oo00<007oo
Ool0;7oo000>Ool00`00Oomoo`0_Ool00`00Oomoo`0UOol2000?Ool00`00Oomoo`0;Ool00`00Oomo
o`0=Ool00`00Oomoo`0jOol00`00Oomoo`0[Ool000ioo`03001oogoo02ioo`03001oogoo02Eoo`03
001oogoo00moo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo03Uoo`03001oogoo02]oo`00
3Woo00<007ooOol0;Goo00<007ooOol09Goo00<007ooOol047oo00<007ooOol02goo00<007ooOol0
3goo00<007ooOol0>7oo00<007ooOol0:goo000>Ool00`00Oomoo`0/Ool00`00Oomoo`0VOol00`00
Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0gOol00`00Oomoo`0[Ool000io
o`03001oogoo02]oo`03001oogoo02Ioo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo019o
o`03001oogoo03Ioo`03001oogoo02]oo`003Woo00<007ooOol0:goo00<007ooOol09Goo00<007oo
Ool04goo00<007ooOol02Goo00<007ooOol04goo00<007ooOol0=Woo00<007ooOol0:Woo000>Ool0
0`00Oomoo`0ZOol00`00Oomoo`0UOol00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0DOol0
0`00Oomoo`0eOol00`00Oomoo`0ZOol000ioo`03001oogoo02Uoo`03001oogoo02Eoo`03001oogoo
01Eoo`03001oogoo00Uoo`03001oogoo01Eoo`03001oogoo03Aoo`03001oogoo02Yoo`003Woo00<0
07ooOol0:7oo00<007ooOol09Goo00<007ooOol05goo00<007ooOol01goo00<007ooOol05goo00<0
07ooOol0<goo00<007ooOol0:Woo000>Ool00`00Oomoo`0WOol00`00Oomoo`0UOol00`00Oomoo`0H
Ool00`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomoo`0cOol00`00Oomoo`0ZOol000ioo`03001o
ogoo02Ioo`03001oogoo02Ioo`03001oogoo01Qoo`03001oogoo00Moo`03001oogoo01Qoo`03001o
ogoo039oo`03001oogoo02Yoo`003Woo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol06Goo
00<007ooOol01goo00<007ooOol06Goo00<007ooOol0<Goo00<007ooOol0:Woo000>Ool00`00Oomo
o`0TOol00`00Oomoo`0WOol00`00Oomoo`0JOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomo
o`0aOol00`00Oomoo`0ZOol000ioo`03001oogoo02=oo`03001oogoo02Qoo`03001oogoo01Yoo`03
001oogoo00Eoo`03001oogoo01Yoo`03001oogoo035oo`03001oogoo02Yoo`003Woo00<007ooOol0
8Woo00<007ooOol0:7oo00<007ooOol06goo00<007ooOol01Goo00<007ooOol06Woo00<007ooOol0
<Goo00<007ooOol0:Woo000>Ool00`00Oomoo`0QOol00`00Oomoo`0YOol00`00Oomoo`0KOol00`00
Oomoo`05Ool00`00Oomoo`0KOol00`00Oomoo`0`Ool00`00Oomoo`0ZOol000ioo`03001oogoo021o
o`03001oogoo02Uoo`03001oogoo01eoo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo031o
o`03001oogoo02Yoo`003Woo00<007ooOol087oo00<007ooOol0:Goo00<007ooOol07Goo00<007oo
Ool00goo00<007ooOol07Goo00<007ooOol0;goo00<007ooOol0:Woo000>Ool00`00Oomoo`0OOol0
0`00Oomoo`0ZOol00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`0_Ool0
0`00Oomoo`0ZOol000ioo`03001oogoo01ioo`03001oogoo02Yoo`03001oogoo01ioo`03001oogoo
00=oo`03001oogoo01eoo`03001oogoo02moo`03001oogoo02Yoo`003Woo00<007ooOol07Goo00<0
07ooOol0:goo00<007ooOol07goo00D007ooOomoo`00025oo`03001oogoo02ioo`03001oogoo02Yo
o`003Woo00<007ooOol077oo00<007ooOol0;7oo00<007ooOol07goo00D007ooOomoo`00025oo`03
001oogoo02ioo`03001oogoo02Yoo`003Woo00<007ooOol06goo00<007ooOol0;Goo00<007ooOol0
7goo00D007ooOomoo`00025oo`03001oogoo02moo`03001oogoo02Uoo`003Woo00<007ooOol06goo
00<007ooOol0;7oo00<007ooOol087oo00D007ooOomoo`00025oo`03001oogoo02moo`03001oogoo
02Uoo`003Woo00<007ooOol06Woo00<007ooOol0;Goo00<007ooOol08Goo00<007oo00008goo00<0
07ooOol0;Woo00<007ooOol0:Goo000>Ool00`00Oomoo`0JOol00`00Oomoo`0]Ool00`00Oomoo`0Q
Ool00`00Ool0000SOol00`00Oomoo`0^Ool00`00Oomoo`0YOol000ioo`03001oogoo01Yoo`03001o
ogoo02eoo`03001oogoo025oo`03001oo`0002=oo`03001oogoo02ioo`03001oogoo02Uoo`003Woo
00<007ooOol06Woo00<007ooOol0;Goo00<007ooOol08Goo00<007oo00008goo00<007ooOol0;Woo
00<007ooOol0:Goo000>Ool00`00Oomoo`0IOol00`00Oomoo`0^Ool00`00Oomoo`0ROol00`00Oomo
o`0ROol00`00Oomoo`0^Ool00`00Oomoo`0YOol000ioo`03001oogoo01Uoo`03001oogoo02ioo`03
001oogoo029oo`03001oogoo029oo`03001oogoo02ioo`03001oogoo02Uoo`003Woo00<007ooOol0
6Goo00<007ooOol0;Woo00<007ooOol0Agoo00<007ooOol0;Woo00<007ooOol0:Goo000>Ool00`00
Oomoo`0IOol2000_Ool00`00Oomoo`17Ool00`00Oomoo`0^Ool00`00Oomoo`0YOol000ioo`03001o
ogoo01Yoo`03001oogoo02eoo`03001oogoo04Moo`03001oogoo02ioo`03001oogoo02Uoo`003Woo
00<007ooOol06Woo00<007ooOol0;Goo00<007ooOol0Agoo00<007ooOol0;Woo00<007ooOol0:Goo
000>Ool00`00Oomoo`0JOol00`00Oomoo`0]Ool00`00Oomoo`17Ool00`00Oomoo`0^Ool00`00Oomo
o`0YOol000ioo`03001oogoo01]oo`03001oogoo02aoo`03001oogoo04Moo`03001oogoo02ioo`03
001oogoo02Uoo`003Woo00<007ooOol06goo00<007ooOol0;7oo00<007ooOol0AWoo00<007ooOol0
;goo00<007ooOol0:Goo000>Ool00`00Oomoo`0LOol00`00Oomoo`0/Ool00`00Oomoo`15Ool00`00
Oomoo`0_Ool00`00Oomoo`0YOol000ioo`03001oogoo01eoo`03001oogoo02]oo`03001oogoo04Eo
o`03001oogoo02ioo`03001oogoo02Yoo`003Woo00<007ooOol07Woo00<007ooOol0:Woo00<007oo
Ool0A7oo00<007ooOol0;goo00<007ooOol0:Woo000>Ool00`00Oomoo`0OOol00`00Oomoo`0ZOol0
0`00Oomoo`13Ool00`00Oomoo`0_Ool00`00Oomoo`0ZOol000ioo`03001oogoo01moo`03001oogoo
02Yoo`03001oogoo04=oo`03001oogoo02moo`03001oogoo02Yoo`003Woo00<007ooOol087oo00<0
07ooOol0:Goo00<007ooOol0@goo00<007ooOol0;goo00<007ooOol0:Woo000>Ool00`00Oomoo`0Q
Ool00`00Oomoo`0XOol00`00Oomoo`12Ool00`00Oomoo`0`Ool00`00Oomoo`0ZOol000ioo`03001o
ogoo029oo`03001oogoo02Qoo`03001oogoo045oo`03001oogoo031oo`03001oogoo02Yoo`003Woo
00<007ooOol08goo00<007ooOol0:7oo00<007ooOol0?goo00<007ooOol0<Goo00<007ooOol0:Woo
000>Ool00`00Oomoo`0TOol00`00Oomoo`0WOol00`00Oomoo`0oOol00`00Oomoo`0aOol00`00Oomo
o`0ZOol000ioo`03001oogoo02Eoo`03001oogoo02Ioo`03001oogoo03moo`03001oogoo035oo`03
001oogoo02Yoo`003Woo00<007ooOol09Woo00<007ooOol09Goo00<007ooOol0?Woo00<007ooOol0
<Woo00<007ooOol0:Woo000>Ool00`00Oomoo`0WOol00`00Oomoo`0UOol00`00Oomoo`0mOol00`00
Oomoo`0bOol00`00Oomoo`0ZOol000ioo`03001oogoo02Qoo`03001oogoo02Eoo`03001oogoo03]o
o`03001oogoo03=oo`03001oogoo02Yoo`003Woo00<007ooOol0:Goo00<007ooOol097oo00<007oo
Ool0>Woo00<007ooOol0=7oo00<007ooOol0:Woo000>Ool00`00Oomoo`0ZOol00`00Oomoo`0TOol0
0`00Oomoo`0hOol00`00Oomoo`0eOol00`00Oomoo`0ZOol000ioo`03001oogoo02]oo`03001oogoo
02Aoo`8003Moo`03001oogoo03Ioo`03001oogoo02Yoo`003Woo00<007ooOol0:goo00<007ooOol0
9Woo00<007ooOol0<goo00<007ooOol0=goo00<007ooOol0:Woo000>Ool00`00Oomoo`0/Ool00`00
Oomoo`0VOol00`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0[Ool000ioo`03001oogoo02eo
o`03001oogoo02Eoo`03001oogoo035oo`03001oogoo03Moo`03001oogoo02]oo`003Woo00<007oo
Ool0;Woo00<007ooOol09Goo00<007ooOol0;Woo0P00>Woo00<007ooOol0:goo000>Ool00`00Oomo
o`0_Ool00`00Oomoo`0UOol2000]Ool00`00Oomoo`0jOol00`00Oomoo`0[Ool000ioo`03001oogoo
031oo`03001oogoo02Ioo`03001oogoo02Qoo`8003eoo`03001oogoo02]oo`003Woo00<007ooOol0
<Goo00<007ooOol09Woo0P009goo00<007ooOol0?Goo00<007ooOol0:goo000>Ool00`00Oomoo`0b
Ool00`00Oomoo`0WOol00`00Oomoo`0SOol00`00Oomoo`0nOol00`00Oomoo`0[Ool000ioo`03001o
ogoo03=oo`03001oogoo02Moo`80025oo`80041oo`03001oogoo02aoo`003Woo00<007ooOol0=7oo
00<007ooOol0:7oo0P007Goo0P00@Woo00<007ooOol0;7oo000>Ool00`00Oomoo`0eOol00`00Oomo
o`0YOol3000GOol30014Ool00`00Oomoo`0/Ool000ioo`03001oogoo03Ioo`03001oogoo02]oo`@0
00moo`@004Moo`03001oogoo02aoo`003Woo00<007ooOol0=goo00<007ooOol0;Woo3`00Bgoo00<0
07ooOol0;7oo000>Ool00`00Oomoo`0hOol00`00Oomoo`27Ool00`00Oomoo`0/Ool000ioo`03001o
ogoo03Uoo`03001oogoo08Eoo`03001oogoo02eoo`003Woo00<007ooOol0>Woo00<007ooOol0Q7oo
00<007ooOol0;Goo000>Ool00`00Oomoo`0kOol00`00Oomoo`23Ool00`00Oomoo`0]Ool000ioo`03
001oogoo03aoo`03001oogoo089oo`03001oogoo02eoo`003Woo00<007ooOol0?Goo00<007ooOol0
P7oo00<007ooOol0;Woo000>Ool00`00Oomoo`0nOol00`00Oomoo`1oOol00`00Oomoo`0^Ool000io
o`03001oogoo03moo`03001oogoo07ioo`03001oogoo02ioo`003Woo00<007ooOol0@7oo00<007oo
Ool0OGoo00<007ooOol0;Woo000>Ool00`00Oomoo`11Ool00`00Oomoo`1kOol00`00Oomoo`0_Ool0
00ioo`03001oogoo049oo`03001oogoo07Yoo`03001oogoo02moo`003Woo00<007ooOol0@goo00<0
07ooOol0NGoo00<007ooOol0;goo000>Ool00`00Oomoo`14Ool00`00Oomoo`1hOol00`00Oomoo`0_
Ool000ioo`03001oogoo04Eoo`03001oogoo07Ioo`03001oogoo031oo`003Woo00<007ooOol0AWoo
00<007ooOol0MGoo00<007ooOol0<7oo000>Ool00`00Oomoo`17Ool00`00Oomoo`1dOol00`00Oomo
o`0`Ool000ioo`03001oogoo04Qoo`03001oogoo07=oo`03001oogoo031oo`003Woo00<007ooOol0
BGoo0P00LWoo00<007ooOol0<Goo000>Ool00`00Oomoo`1;Ool00`00Oomoo`1_Ool00`00Oomoo`0a
Ool000ioo`03001oogoo04aoo`03001oogoo06ioo`03001oogoo035oo`003Woo00<007ooOol0CGoo
00<007ooOol0KGoo00<007ooOol0<Goo000>Ool00`00Oomoo`1>Ool00`00Oomoo`1[Ool00`00Oomo
o`0bOol000ioo`03001oogoo04moo`03001oogoo06Yoo`03001oogoo039oo`003Woo00<007ooOol0
D7oo00<007ooOol0JGoo00<007ooOol0<Woo000>Ool00`00Oomoo`1AOol00`00Oomoo`1XOol00`00
Oomoo`0bOol000ioo`03001oogoo059oo`03001oogoo06Ioo`03001oogoo03=oo`003Woo00<007oo
Ool0Dgoo0P00IWoo00<007ooOol0<goo000>Ool00`00Oomoo`1EOol00`00Oomoo`1ROol00`00Oomo
o`0dOol000ioo`03001oogoo05Ioo`03001oogoo065oo`03001oogoo03Aoo`003Woo00<007ooOol0
Egoo00<007ooOol0Ggoo00<007ooOol0=Goo000>Ool00`00Oomoo`1HOol00`00Oomoo`1NOol00`00
Oomoo`0eOol000ioo`03001oogoo05Uoo`03001oogoo05aoo`03001oogoo03Ioo`003Woo00<007oo
Ool0FWoo00<007ooOol0Fgoo00<007ooOol0=Woo000>Ool00`00Oomoo`1KOol2001JOol00`00Oomo
o`0gOol000ioo`03001oogoo05eoo`03001oogoo05Moo`03001oogoo03Moo`003Woo00<007ooOol0
GWoo00<007ooOol0EGoo00<007ooOol0>7oo000>Ool00`00Oomoo`1OOol2001EOol00`00Oomoo`0h
Ool000ioo`03001oogoo065oo`03001oogoo055oo`03001oogoo03Uoo`003Woo00<007ooOol0HWoo
00<007ooOol0D7oo00<007ooOol0>Goo000>Ool00`00Oomoo`1SOol00`00Oomoo`1>Ool00`00Oomo
o`0jOol000ioo`03001oogoo06Aoo`8004ioo`03001oogoo03Yoo`003Woo00<007ooOol0IWoo00<0
07ooOol0BWoo00<007ooOol0>goo000>Ool00`00Oomoo`1WOol00`00Oomoo`19Ool00`00Oomoo`0k
Ool000ioo`03001oogoo06Qoo`8004Qoo`03001oogoo03aoo`003Woo00<007ooOol0JWoo00<007oo
Ool0A7oo00<007ooOol0?Goo000>Ool00`00Oomoo`1[Ool00`00Oomoo`13Ool00`00Oomoo`0mOol0
00ioo`03001oogoo06aoo`80049oo`03001oogoo03ioo`003Woo00<007ooOol0KWoo00<007ooOol0
?Woo00<007ooOol0?goo000>Ool00`00Oomoo`1_Ool00`00Oomoo`0lOol00`00Oomoo`10Ool000io
o`03001oogoo071oo`8003]oo`03001oogoo045oo`003Woo00<007ooOol0LWoo00<007ooOol0>7oo
00<007ooOol0@Goo000>Ool00`00Oomoo`0NOol901m<Ool2000gOol00`00Oomoo`12Ool000ioo`03
001oogoo021ooa407dAoo`8003Aoo`03001oogoo04=oo`003Woo00<007ooOol08Goo6P0O?7oo00<0
07ooOol0;goo0P00AWoo000>Ool00`00Oomoo`0SOolR01lcOol2000^Ool00`00Oomoo`16Ool000io
o`03001oogoo02Aoob/07b]oo`8002]oo`03001oogoo04Moo`003Woo00<007ooOol09Woo<`0O8goo
0`009Woo0P00BWoo000>Ool00`00Oomoo`0XOolk01lLOol2000SOol00`00Oomoo`1:Ool000ioo`03
001oogoo02Uood@07aAoo`<001moo`03001oogoo04]oo`003Woo00<007ooOol0:gooC00O3Goo0`00
6Woo0P00CWoo000>Ool00`00Oomoo`0/OomE01l6Ool3000DOol3001@Ool000ioo`03001oogoo02io
oe`07`H000Uoo`D005=oo`003Woo00<007ooOol0<7ooGP0O2`00F7oo000>Ool00`00Oomoo`0aOomN
01l00`0001l07`0=01mBOol000ioo`03001oogoo03=oogH07dQoo`003Woo00<007ooOol0=7ooO`0O
?Woo000>Ool00`00Oomoo`0fOon701ldOol000ioo`03001oogoo03Mooi007bYoo`003Woo00<007oo
Ool0>GooS00O;7oo000>Ool00`00Oomoo`0kOon701l_Ool000ioo`03001oogoo03aooh@07c5oo`00
3Woo00<007ooOol0?WooO`0O=7oo000>Ool00`00Oomoo`0oOomk01lgOol000ioo`03001oogoo045o
ogL07cUoo`003Woo00<007ooOol02Goo1`0O<gooLP0O?7oo000>Ool00`00Oomoo`09Ool@01l[Oom_
01lnOol000ioo``001T07bAoofX07d5oo`006Woo8P0O77ooIP0OA7oo000JOol[01lEOomR01m6Ool0
025oobd07`iooed07dUoo`00:Woo;@0O1WooFP0OBgoo000cOon101m>Ool003aoogD07e5oo`00AGoo
JP0ODgoo001>OomN01mFOol005Mooe<07eQoo`00H7ooA`0OFgoo001YOolk01mNOol0079ooa007`Mo
oaT07f1oo`00Ngoo1`0O4Goo300OHgoo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?mo
o`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo
003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?mo
o`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo
003oOol3Ool00?moo`=oo`00ogoo0goo0000\
\>"],
  ImageRangeCache->{{{0, 257}, {286, 0}} -> {-4.50005, -4.50784, 0.0350198, 
  0.0350198}}]
}, Open  ]],

Cell[TextData["Cam Profile"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The cam profile used for this mechanism is defined in terms of \
trigonometric functions of the symbol ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The cam profile expression may contain user-defined parameters that are \
defined at run time, but all of the functional dependence on the controlling \
parameter ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be present when the cam constraint is processed with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Thus, it is not possible to leave the cam profile defined as simply a \
two-element list of symbols, such as {",
  StyleBox["xcam",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ycam",
    FontSlant->"Italic"],
  "}, and then define ",
  StyleBox["xcam",
    FontSlant->"Italic"],
  " and ",
  StyleBox["ycam",
    FontSlant->"Italic"],
  " as functions of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are two parametric expressions defining the locus of the cam profile."],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \(alpha; beta; \), 
    \(On[General::"\<spell1\>"]\), 
    \(\(camprof = {3\ Cos[alpha], 3\ Sin[alpha] + Sin[2\ alpha]}; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a plot of the cam profile."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[Evaluate[camprof], {alpha, 0, 2\ \[Pi]}, 
      AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.16166 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.58083 0.15873 [
[.02381 .56833 -6 -9 ]
[.02381 .56833 6 0 ]
[.18254 .56833 -6 -9 ]
[.18254 .56833 6 0 ]
[.34127 .56833 -6 -9 ]
[.34127 .56833 6 0 ]
[.65873 .56833 -3 -9 ]
[.65873 .56833 3 0 ]
[.81746 .56833 -3 -9 ]
[.81746 .56833 3 0 ]
[.97619 .56833 -3 -9 ]
[.97619 .56833 3 0 ]
[.4875 .10464 -12 -4.5 ]
[.4875 .10464 0 4.5 ]
[.4875 .26337 -12 -4.5 ]
[.4875 .26337 0 4.5 ]
[.4875 .4221 -12 -4.5 ]
[.4875 .4221 0 4.5 ]
[.4875 .73956 -6 -4.5 ]
[.4875 .73956 0 4.5 ]
[.4875 .89829 -6 -4.5 ]
[.4875 .89829 0 4.5 ]
[.4875 1.05702 -6 -4.5 ]
[.4875 1.05702 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.16166 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .58083 m
.02381 .58708 L
s
[(-3)] .02381 .56833 0 1 Mshowa
.18254 .58083 m
.18254 .58708 L
s
[(-2)] .18254 .56833 0 1 Mshowa
.34127 .58083 m
.34127 .58708 L
s
[(-1)] .34127 .56833 0 1 Mshowa
.65873 .58083 m
.65873 .58708 L
s
[(1)] .65873 .56833 0 1 Mshowa
.81746 .58083 m
.81746 .58708 L
s
[(2)] .81746 .56833 0 1 Mshowa
.97619 .58083 m
.97619 .58708 L
s
[(3)] .97619 .56833 0 1 Mshowa
.125 Mabswid
.05555 .58083 m
.05555 .58458 L
s
.0873 .58083 m
.0873 .58458 L
s
.11905 .58083 m
.11905 .58458 L
s
.15079 .58083 m
.15079 .58458 L
s
.21429 .58083 m
.21429 .58458 L
s
.24603 .58083 m
.24603 .58458 L
s
.27778 .58083 m
.27778 .58458 L
s
.30952 .58083 m
.30952 .58458 L
s
.37302 .58083 m
.37302 .58458 L
s
.40476 .58083 m
.40476 .58458 L
s
.43651 .58083 m
.43651 .58458 L
s
.46825 .58083 m
.46825 .58458 L
s
.53175 .58083 m
.53175 .58458 L
s
.56349 .58083 m
.56349 .58458 L
s
.59524 .58083 m
.59524 .58458 L
s
.62698 .58083 m
.62698 .58458 L
s
.69048 .58083 m
.69048 .58458 L
s
.72222 .58083 m
.72222 .58458 L
s
.75397 .58083 m
.75397 .58458 L
s
.78571 .58083 m
.78571 .58458 L
s
.84921 .58083 m
.84921 .58458 L
s
.88095 .58083 m
.88095 .58458 L
s
.9127 .58083 m
.9127 .58458 L
s
.94444 .58083 m
.94444 .58458 L
s
.25 Mabswid
0 .58083 m
1 .58083 L
s
.5 .10464 m
.50625 .10464 L
s
[(-3)] .4875 .10464 1 0 Mshowa
.5 .26337 m
.50625 .26337 L
s
[(-2)] .4875 .26337 1 0 Mshowa
.5 .4221 m
.50625 .4221 L
s
[(-1)] .4875 .4221 1 0 Mshowa
.5 .73956 m
.50625 .73956 L
s
[(1)] .4875 .73956 1 0 Mshowa
.5 .89829 m
.50625 .89829 L
s
[(2)] .4875 .89829 1 0 Mshowa
.5 1.05702 m
.50625 1.05702 L
s
[(3)] .4875 1.05702 1 0 Mshowa
.125 Mabswid
.5 .13638 m
.50375 .13638 L
s
.5 .16813 m
.50375 .16813 L
s
.5 .19988 m
.50375 .19988 L
s
.5 .23162 m
.50375 .23162 L
s
.5 .29512 m
.50375 .29512 L
s
.5 .32686 m
.50375 .32686 L
s
.5 .35861 m
.50375 .35861 L
s
.5 .39035 m
.50375 .39035 L
s
.5 .45385 m
.50375 .45385 L
s
.5 .48559 m
.50375 .48559 L
s
.5 .51734 m
.50375 .51734 L
s
.5 .54908 m
.50375 .54908 L
s
.5 .61258 m
.50375 .61258 L
s
.5 .64432 m
.50375 .64432 L
s
.5 .67607 m
.50375 .67607 L
s
.5 .70781 m
.50375 .70781 L
s
.5 .77131 m
.50375 .77131 L
s
.5 .80305 m
.50375 .80305 L
s
.5 .8348 m
.50375 .8348 L
s
.5 .86654 m
.50375 .86654 L
s
.5 .93004 m
.50375 .93004 L
s
.5 .96178 m
.50375 .96178 L
s
.5 .99353 m
.50375 .99353 L
s
.5 1.02527 m
.50375 1.02527 L
s
.5 .07289 m
.50375 .07289 L
s
.5 .04115 m
.50375 .04115 L
s
.5 .0094 m
.50375 .0094 L
s
.5 1.08877 m
.50375 1.08877 L
s
.5 1.12051 m
.50375 1.12051 L
s
.5 1.15226 m
.50375 1.15226 L
s
.25 Mabswid
.5 0 m
.5 1.16166 L
s
0 0 m
1 0 L
1 1.16166 L
0 1.16166 L
closepath
clip
newpath
.5 Mabswid
.97619 .58083 m
.97618 .58699 L
.97614 .59258 L
.97606 .59905 L
.97597 .60515 L
.97572 .61601 L
.97536 .62777 L
.97483 .6407 L
.97414 .65436 L
.97253 .67875 L
.97039 .70371 L
.96795 .72684 L
.96081 .77835 L
.95129 .82882 L
.94065 .87271 L
.92595 .92069 L
.91017 .96165 L
.87673 1.0257 L
.85665 1.0539 L
.83352 1.07941 L
.80971 1.09938 L
.7966 1.10806 L
.78235 1.11586 L
.76953 1.12153 L
.75512 1.12653 L
.74868 1.12831 L
.74172 1.12995 L
.73569 1.13113 L
.72898 1.1322 L
.72189 1.13305 L
.71797 1.1334 L
.71428 1.13366 L
.71083 1.13383 L
.70766 1.13394 L
.70416 1.134 L
.70046 1.13399 L
.69848 1.13396 L
.69668 1.13392 L
.69459 1.13385 L
.69262 1.13376 L
.68911 1.13356 L
.68528 1.13328 L
.67654 1.13239 L
.66842 1.13126 L
.65466 1.12872 L
.63937 1.12501 L
.60798 1.11473 L
.57667 1.10125 L
.54775 1.08629 L
.4822 1.04483 L
Mistroke
.35941 .94625 L
.25028 .84454 L
.15167 .74718 L
.08024 .67355 L
.05429 .64386 L
.04374 .63007 L
.03499 .61663 L
.02925 .6053 L
.0269 .59912 L
.02601 .5962 L
.0253 .59346 L
.02478 .59099 L
.02434 .58833 L
.02419 .58715 L
.02405 .58591 L
.02396 .58485 L
.02389 .58368 L
.02383 .58233 L
.02381 .5811 L
.02382 .57974 L
.02384 .57906 L
.02387 .57831 L
.02394 .57705 L
.02406 .5757 L
.02435 .57327 L
.02481 .57052 L
.02544 .56761 L
.02697 .56232 L
.02917 .55653 L
.03226 .55 L
.04824 .5255 L
.10383 .46316 L
.18381 .38238 L
.29138 .27779 L
.40968 .1724 L
.52942 .08597 L
.59093 .0539 L
.62148 .04209 L
.6377 .0371 L
.65461 .03295 L
.66882 .03033 L
.67681 .02923 L
.68061 .02881 L
.68419 .02847 L
.68743 .02821 L
.69095 .02798 L
.69413 .02783 L
.69705 .02773 L
.7002 .02767 L
.70366 .02766 L
Mistroke
.70726 .02771 L
.71062 .02782 L
.71423 .028 L
.71816 .02827 L
.72186 .02861 L
.72527 .02898 L
.73168 .02986 L
.73844 .03104 L
.75368 .03471 L
.76718 .03922 L
.79267 .05128 L
.81498 .06621 L
.83813 .0868 L
.86093 .11324 L
.87965 .14061 L
.89806 .17383 L
.92669 .24314 L
.93992 .28629 L
.95205 .33641 L
.96129 .38634 L
.96789 .43432 L
.97146 .46964 L
.9739 .50326 L
.97491 .52265 L
.97557 .54049 L
.97583 .54987 L
.97594 .55525 L
.97603 .56013 L
.9761 .56532 L
.97615 .57086 L
.97618 .57599 L
.97619 .58083 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{242, 282},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003b00016Q000`40O003h00OlWoo001hOol00`00
Oomoo`1gOol007Qoo`03001oogoo07Moo`00N7oo0P00N7oo001hOol00`00Oomoo`1gOol007Qoo`03
001oogoo07Moo`00N7oo00<007ooOol0Mgoo001hOol00`00Oomoo`1gOol007Qoo`03001oogoo02Eo
oa40045oo`00N7oo00<007ooOol08Goo10004Goo0`00?Woo001hOol00`00Oomoo`0MOol4000HOol3
000kOol007Qoo`8001Yoo`@001moo`<003Qoo`00N7oo00<007ooOol05goo0P009Woo0P00=Woo001h
Ool00`00Oomoo`0EOol2000ZOol2000dOol007Qoo`03001oogoo01=oo`8002ioo`80039oo`00N7oo
00<007ooOol04Goo0P00<Woo0P00<7oo001hOol00`00Oomoo`0?Ool2000fOol2000^Ool007Qoo`03
001oogoo00eoo`8003Yoo`03001oogoo02]oo`00N7oo00<007ooOol02goo0P00?Goo00<007ooOol0
:Woo001hOol2000:Ool20010Ool00`00Oomoo`0YOol007Qoo`03001oogoo00Moo`8004=oo`8002Uo
o`00N7oo00<007ooOol01Goo0P00Agoo00<007ooOol09Woo001hOol00`00Oomoo`04Ool00`00Oomo
o`18Ool00`00Oomoo`0UOol007Qoo`03001oogoo009oo`8004aoo`03001oogoo02Aoo`00LGoo0P00
1Goo00D007ooOomoo`0004moo`03001oogoo02=oo`00Lgoo00<007ooOol00Woo00@007ooOol0051o
o`03001oogoo02=oo`00K7oo0`000goo00<007ooOol00goo0`00DWoo00<007ooOol08Woo001cOol0
0`00Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0QOol0075oo`03001oo`0000=oo`8005Ioo`03
001oogoo021oo`00LWoo00<007ooOol00P0000=oo`00Ool0EWoo00<007ooOol07goo001dOol01@00
Oomoogoo0000Egoo00<007ooOol07goo001bOol20004Ool00`00Oomoo`1FOol00`00Oomoo`0NOol0
075oo`03001oogoo00Aoo`03001oogoo05Moo`03001oogoo01eoo`00L7oo00<007ooOol01Goo00<0
07ooOol0F7oo00<007ooOol077oo001^Ool20008Ool2001IOol00`00Oomoo`0LOol006eoo`03001o
ogoo00Qoo`03001oogoo05Uoo`03001oogoo01]oo`00Jgoo0P002goo00<007ooOol0FGoo00<007oo
Ool06goo001ZOol00`00Oomoo`0;Ool00`00Oomoo`1JOol00`00Oomoo`0JOol006Uoo`03001oogoo
00aoo`03001oogoo05Yoo`03001oogoo01Yoo`00Igoo0P003goo00<007ooOol0Fgoo00<007ooOol0
6Goo001VOol00`00Oomoo`0?Ool00`00Oomoo`1KOol00`00Oomoo`0IOol006Eoo`03001oogoo011o
o`03001oogoo05aoo`03001oogoo01Qoo`00Hgoo0P004goo0P00GGoo00<007ooOol067oo001ROol0
0`00Oomoo`0COol00`00Oomoo`1MOol00`00Oomoo`0GOol0065oo`03001oogoo01Aoo`03001oogoo
05eoo`03001oogoo01Moo`00H7oo00<007ooOol05Goo00<007ooOol0GWoo00<007ooOol05Woo001O
Ool00`00Oomoo`0FOol00`00Oomoo`1NOol00`00Oomoo`0FOol005eoo`8001Uoo`03001oogoo05mo
o`03001oogoo01Eoo`00G7oo00<007ooOol06Goo00<007ooOol0Ggoo00<007ooOol05Goo001KOol0
0`00Oomoo`0JOol2001POol00`00Oomoo`0EOol005Yoo`03001oogoo01]oo`03001oogoo061oo`03
001oogoo01Aoo`00FGoo00<007ooOol077oo00<007ooOol0H7oo00<007ooOol057oo001HOol00`00
Oomoo`0MOol00`00Oomoo`1QOol00`00Oomoo`0COol005Moo`03001oogoo01ioo`03001oogoo065o
o`03001oogoo01=oo`00EWoo00<007ooOol07goo00<007ooOol0HWoo00<007ooOol04Woo001EOol0
0`00Oomoo`0POol00`00Oomoo`1ROol00`00Oomoo`0BOol005=oo`8002=oo`03001oogoo069oo`03
001oogoo019oo`00DWoo00<007ooOol08goo0P00I7oo00<007ooOol04Goo001AOol00`00Oomoo`0T
Ool00`00Oomoo`1SOol00`00Oomoo`0AOol0051oo`03001oogoo02Eoo`03001oogoo06Aoo`03001o
ogoo011oo`00Cgoo00<007ooOol09Woo00<007ooOol0I7oo00<007ooOol047oo001>Ool00`00Oomo
o`0WOol00`00Oomoo`1TOol00`00Oomoo`0@Ool004eoo`03001oogoo02Qoo`03001oogoo06Eoo`03
001oogoo00moo`00C7oo00<007ooOol08Woo0`0017oo00<007ooOol0IGoo00<007ooOol03goo001:
Ool2000UOol00`00Oomoo`04Ool00`00Oomoo`1UOol00`00Oomoo`0?Ool004Uoo`03001oogoo021o
o`<000=oo`03001oogoo00=oo`<006Eoo`03001oogoo00moo`00B7oo00<007ooOol09goo00<007oo
Ool00goo00<007ooOol0IWoo00<007ooOol03Woo0017Ool00`00Oomoo`0WOol00`00Ool00004Ool0
0`00Oomoo`1VOol00`00Oomoo`0>Ool004Ioo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo
06Ioo`03001oogoo00ioo`00AGoo00<007ooOol0<7oo00<007ooOol0Igoo00<007ooOol03Goo0014
Ool00`00Oomoo`0aOol00`00Oomoo`1WOol00`00Oomoo`0=Ool004=oo`03001oogoo039oo`03001o
ogoo06Moo`03001oogoo00eoo`00@Woo00<007ooOol0<goo0P00J7oo00<007ooOol03Goo0011Ool0
0`00Oomoo`0dOol00`00Oomoo`1XOol00`00Oomoo`0<Ool0041oo`03001oogoo03Eoo`03001oogoo
06Qoo`03001oogoo00aoo`00?goo00<007ooOol0=Woo00<007ooOol0J7oo00<007ooOol037oo000n
Ool00`00Oomoo`0gOol00`00Oomoo`1XOol00`00Oomoo`0<Ool003eoo`03001oogoo03Qoo`03001o
ogoo06Uoo`03001oogoo00]oo`00?7oo00<007ooOol0>Goo00<007ooOol0JGoo00<007ooOol02goo
000kOol00`00Oomoo`0jOol00`00Oomoo`1YOol00`00Oomoo`0;Ool003Yoo`03001oogoo03]oo`80
06Yoo`03001oogoo00]oo`00>7oo0P00?Woo00<007ooOol0JWoo00<007ooOol02Woo000gOol00`00
Oomoo`0nOol00`00Oomoo`1ZOol00`00Oomoo`0:Ool003Ioo`03001oogoo03moo`03001oogoo06Yo
o`03001oogoo00Yoo`00=Goo00<007ooOol0@7oo00<007ooOol0JWoo00<007ooOol02Woo000dOol0
0`00Oomoo`11Ool00`00Oomoo`1ZOol00`00Oomoo`0:Ool003=oo`03001oogoo049oo`03001oogoo
06]oo`03001oogoo00Uoo`00<Woo00<007ooOol0@goo00<007ooOol0Jgoo00<007ooOol02Goo000a
Ool00`00Oomoo`14Ool2001/Ool00`00Oomoo`09Ool0031oo`03001oogoo04Eoo`03001oogoo06]o
o`03001oogoo00Uoo`00;goo00<007ooOol0AWoo00<007ooOol0Jgoo00<007ooOol02Goo000^Ool0
0`00Oomoo`17Ool00`00Oomoo`1[Ool00`00Oomoo`09Ool002eoo`03001oogoo04Qoo`03001oogoo
06aoo`03001oogoo00Qoo`00;7oo00<007ooOol0BGoo00<007ooOol0K7oo00<007ooOol027oo000[
Ool00`00Oomoo`1:Ool00`00Oomoo`1/Ool00`00Oomoo`08Ool002Yoo`03001oogoo04]oo`8006eo
o`03001oogoo00Qoo`00:Goo00<007ooOol0C7oo00<007ooOol0K7oo00<007ooOol027oo000XOol0
0`00Oomoo`1=Ool00`00Oomoo`1/Ool00`00Oomoo`08Ool002Moo`03001oogoo04ioo`03001oogoo
06eoo`03001oogoo00Moo`009Woo00<007ooOol0Cgoo00<007ooOol0KGoo00<007ooOol01goo000U
Ool00`00Oomoo`1@Ool00`00Oomoo`1]Ool00`00Oomoo`07Ool002Aoo`03001oogoo04Uoo`D000=o
o`03001oogoo06eoo`03001oogoo00Moo`008goo00<007ooOol0C7oo00<007ooOol00goo00<007oo
Ool0KGoo00<007ooOol01goo000ROol00`00Oomoo`17Ool30003Ool00`00Oomoo`03Ool3001]Ool0
0`00Oomoo`07Ool0029oo`03001oogoo04eoo`03001oogoo00=oo`03001oogoo06ioo`03001oogoo
00Ioo`008Goo00<007ooOol0CWoo00<007ooOol00goo00<007ooOol0KWoo00<007ooOol01Woo000P
Ool00`00Oomoo`1>Ool20005Ool00`00Oomoo`1^Ool00`00Oomoo`06Ool001moo`03001oogoo05Io
o`03001oogoo06ioo`03001oogoo00Ioo`007Woo00<007ooOol0Egoo00<007ooOol0KWoo00<007oo
Ool01Woo000MOol00`00Oomoo`1HOol00`00Oomoo`1^Ool00`00Oomoo`06Ool001aoo`03001oogoo
05Uoo`8006moo`03001oogoo00Ioo`006goo00<007ooOol0FWoo00<007ooOol0Kgoo00<007ooOol0
1Goo000JOol00`00Oomoo`1KOol00`00Oomoo`1_Ool00`00Oomoo`05Ool001Uoo`03001oogoo05ao
o`03001oogoo06moo`03001oogoo00Eoo`0067oo00<007ooOol0GGoo00<007ooOol0Kgoo00<007oo
Ool01Goo000GOol00`00Oomoo`1NOol00`00Oomoo`1_Ool00`00Oomoo`05Ool001Ioo`03001oogoo
05moo`03001oogoo06moo`03001oogoo00Eoo`005Goo00<007ooOol0H7oo00<007ooOol0Kgoo00<0
07ooOol01Goo000DOol00`00Oomoo`1QOol2001`Ool00`00Oomoo`05Ool001=oo`03001oogoo069o
o`03001oogoo06moo`03001oogoo00Eoo`004Woo00<007ooOol0Hgoo00<007ooOol0Kgoo00<007oo
Ool01Goo000BOol00`00Oomoo`1SOol00`00Oomoo`1_Ool00`00Oomoo`05Ool0015oo`03001oogoo
06Aoo`03001oogoo06moo`03001oogoo00Eoo`0047oo00<007ooOol0IGoo00<007ooOol0Kgoo00<0
07ooOol01Goo000?Ool00`00Oomoo`1VOol00`00Oomoo`1_Ool00`00Oomoo`05Ool000ioo`03001o
ogoo06Moo`03001oogoo06moo`03001oogoo00Eoo`003Goo00<007ooOol0J7oo0P00L7oo00<007oo
Ool01Goo000<Ool00`00Oomoo`1YOol00`00Oomoo`1_Ool00`00Oomoo`05Ool000]oo`03001oogoo
06Yoo`03001oogoo06moo`03001oogoo00Eoo`002Woo00<007ooOol0Jgoo00<007ooOol0Kgoo00<0
07ooOol01Goo0007Ool200000goo001oo`0QOol3000ROol5000QOol00`00Oomoo`0QOol5000ROol3
000SOol30006Ool000Uoo`03001oogoo025oo`03001oogoo02Aoo`03001oogoo025oo`03001oogoo
02=oo`03001oogoo029oo`03001oogoo02Eoo`03001oogoo00Aoo`000Woo0`000goo0P007Woo0`00
0goo00<007ooOol07Goo0`000goo00<007ooOol08Goo00<007ooOol08goo00<007ooOol08goo00<0
07ooOol08goo0P001Woo0008Ool2000TOol00`00Oomoo`0SOol00`00Oomoo`0QOol2000TOol00`00
Oomoo`0SOol00`00Oomoo`0TOol00`00Oomoo`04Ool000Moo`<002=oo`03001oo`0002Aoo`03001o
ogoo025oo`03001oogoo02=oo`03001oogoo029oo`03001oo`0002=oo`03001oo`0000Ioo`001goo
0P009Goo00<007ooOol08Woo0P008goo00<007ooOol08Woo0P009Goo00<007ooOol08goo0P001Woo
0006Ool00`00Oomoo`1_Ool00`00Oomoo`1`Ool00`00Oomoo`04Ool000Ioo`03001oogoo06moo`03
001oogoo071oo`03001oogoo00Aoo`001Woo00<007ooOol0Kgoo00<007ooOol0L7oo00<007ooOol0
17oo0006Ool00`00Oomoo`1_Ool00`00Oomoo`1`Ool00`00Oomoo`04Ool000Ioo`03001oogoo06mo
o`03001oogoo071oo`03001oogoo00Aoo`00lP000006Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool000Ioo`03001oogoo
02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02Aoo`03001oogoo
02=oo`03001oogoo00Aoo`001Woo00<007ooOol0Kgoo00<007ooOol0L7oo00<007ooOol017oo0006
Ool00`00Oomoo`1_Ool00`00Oomoo`1`Ool00`00Oomoo`04Ool000Ioo`03001oogoo06moo`03001o
ogoo071oo`03001oogoo00Aoo`001goo00<007ooOol0KWoo00<007ooOol0L7oo00<007ooOol017oo
0007Ool00`00Oomoo`1^Ool00`00Oomoo`1`Ool00`00Oomoo`04Ool000Qoo`03001oogoo06eoo`80
075oo`03001oogoo00Aoo`0027oo00<007ooOol0KGoo00<007ooOol0L7oo00<007ooOol017oo0009
Ool00`00Oomoo`1/Ool00`00Oomoo`1`Ool00`00Oomoo`04Ool000Uoo`03001oogoo06aoo`03001o
ogoo071oo`03001oogoo00Aoo`002Woo00<007ooOol0Jgoo00<007ooOol0L7oo00<007ooOol017oo
000;Ool00`00Oomoo`1ZOol00`00Oomoo`1_Ool00`00Oomoo`05Ool000aoo`03001oogoo06Uoo`03
001oogoo06moo`03001oogoo00Eoo`003Goo00<007ooOol0J7oo0P00L7oo00<007ooOol01Goo000>
Ool00`00Oomoo`1WOol00`00Oomoo`1_Ool00`00Oomoo`05Ool000moo`03001oogoo06Ioo`03001o
ogoo06moo`03001oogoo00Eoo`0047oo00<007ooOol0IGoo00<007ooOol0Kgoo00<007ooOol01Goo
000@Ool00`00Oomoo`1UOol00`00Oomoo`1_Ool00`00Oomoo`05Ool0015oo`03001oogoo06Aoo`03
001oogoo06moo`03001oogoo00Eoo`004Woo00<007ooOol0Hgoo00<007ooOol0Kgoo00<007ooOol0
1Goo000COol00`00Oomoo`1ROol00`00Oomoo`1_Ool00`00Oomoo`05Ool001Aoo`03001oogoo065o
o`80071oo`03001oogoo00Eoo`005Goo00<007ooOol0H7oo00<007ooOol0Kgoo00<007ooOol01Goo
000FOol00`00Oomoo`1OOol00`00Oomoo`1_Ool00`00Oomoo`05Ool001Moo`03001oogoo05ioo`03
001oogoo06moo`03001oogoo00Eoo`0067oo00<007ooOol0GGoo00<007ooOol0KWoo00<007ooOol0
1Woo000IOol00`00Oomoo`1LOol00`00Oomoo`1^Ool00`00Oomoo`06Ool001Yoo`03001oogoo05]o
o`03001oogoo06ioo`03001oogoo00Ioo`006goo00<007ooOol0FWoo00<007ooOol0KWoo00<007oo
Ool01Woo000KOol00`00Oomoo`1JOol2001_Ool00`00Oomoo`06Ool001aoo`03001oogoo05Uoo`03
001oogoo06ioo`03001oogoo00Ioo`007Goo00<007ooOol0F7oo00<007ooOol0KWoo00<007ooOol0
1Woo000NOol00`00Oomoo`1GOol00`00Oomoo`1^Ool00`00Oomoo`06Ool001moo`03001oogoo05Io
o`03001oogoo06ioo`03001oogoo00Ioo`0087oo00<007ooOol0CGoo1@000goo00<007ooOol0KWoo
00<007ooOol01Woo000QOol00`00Oomoo`1>Ool00`00Oomoo`03Ool00`00Oomoo`1^Ool00`00Oomo
o`06Ool0029oo`03001oogoo04eoo`03001oogoo00=oo`<006ioo`03001oogoo00Ioo`008goo00<0
07ooOol0C7oo00<007ooOol00goo00<007ooOol0KGoo00<007ooOol01goo000TOol00`00Oomoo`1;
Ool00`00Oomoo`03Ool00`00Oomoo`1]Ool00`00Oomoo`07Ool002Eoo`03001oogoo04Uoo`8000Eo
o`03001oogoo06eoo`03001oogoo00Moo`009Woo00<007ooOol0Cgoo00<007ooOol0KGoo00<007oo
Ool01goo000WOol00`00Oomoo`1>Ool00`00Oomoo`1]Ool00`00Oomoo`07Ool002Qoo`03001oogoo
04eoo`03001oogoo06eoo`03001oogoo00Moo`00:Goo00<007ooOol0C7oo00<007ooOol0K7oo00<0
07ooOol027oo000ZOol00`00Oomoo`1;Ool2001]Ool00`00Oomoo`08Ool002]oo`03001oogoo04Yo
o`03001oogoo06aoo`03001oogoo00Qoo`00;7oo00<007ooOol0BGoo00<007ooOol0K7oo00<007oo
Ool027oo000]Ool00`00Oomoo`18Ool00`00Oomoo`1/Ool00`00Oomoo`08Ool002ioo`03001oogoo
04Moo`03001oogoo06aoo`03001oogoo00Qoo`00;goo00<007ooOol0AWoo00<007ooOol0Jgoo00<0
07ooOol02Goo000`Ool20016Ool00`00Oomoo`1[Ool00`00Oomoo`09Ool0039oo`03001oogoo04=o
o`8006aoo`03001oogoo00Uoo`00<goo00<007ooOol0@Woo00<007ooOol0Jgoo00<007ooOol02Goo
000dOol00`00Oomoo`11Ool00`00Oomoo`1[Ool00`00Oomoo`09Ool003Eoo`03001oogoo041oo`03
001oogoo06]oo`03001oogoo00Uoo`00=Woo00<007ooOol0?goo00<007ooOol0JWoo00<007ooOol0
2Woo000gOol00`00Oomoo`0nOol00`00Oomoo`1ZOol00`00Oomoo`0:Ool003Qoo`03001oogoo03eo
o`03001oogoo06Yoo`03001oogoo00Yoo`00>Goo00<007ooOol0?7oo00<007ooOol0JWoo00<007oo
Ool02Woo000jOol00`00Oomoo`0kOol2001[Ool00`00Oomoo`0:Ool003]oo`03001oogoo03Yoo`03
001oogoo06Uoo`03001oogoo00]oo`00?7oo00<007ooOol0>Goo00<007ooOol0JGoo00<007ooOol0
2goo000mOol00`00Oomoo`0hOol00`00Oomoo`1YOol00`00Oomoo`0;Ool003ioo`03001oogoo03Mo
o`03001oogoo06Qoo`03001oogoo00aoo`00?goo00<007ooOol0=Woo00<007ooOol0J7oo00<007oo
Ool037oo0010Ool00`00Oomoo`0eOol00`00Oomoo`1XOol00`00Oomoo`0<Ool0045oo`03001oogoo
03Aoo`03001oogoo06Qoo`03001oogoo00aoo`00@Woo00<007ooOol0<goo0P00J7oo00<007ooOol0
3Goo0013Ool00`00Oomoo`0bOol00`00Oomoo`1WOol00`00Oomoo`0=Ool004Aoo`03001oogoo035o
o`03001oogoo06Moo`03001oogoo00eoo`00AGoo00<007ooOol0<7oo00<007ooOol0IWoo00<007oo
Ool03Woo0016Ool00`00Oomoo`0_Ool00`00Oomoo`1VOol00`00Oomoo`0>Ool004Moo`03001oogoo
02Moo`<000Aoo`03001oogoo06Ioo`03001oogoo00ioo`00B7oo00<007ooOol09Woo00<007ooOol0
17oo00<007ooOol0IWoo00<007ooOol03Woo0019Ool2000WOol00`00Oomoo`03Ool3001UOol00`00
Oomoo`0?Ool004]oo`03001oogoo02Aoo`03001oogoo00=oo`03001oogoo06Eoo`03001oogoo00mo
o`00C7oo00<007ooOol08Woo00<007oo000017oo00<007ooOol0IGoo00<007ooOol03goo001=Ool0
0`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`1UOol00`00Oomoo`0?Ool004ioo`03001oogoo
02Moo`03001oogoo06Aoo`03001oogoo011oo`00Cgoo00<007ooOol09Woo00<007ooOol0I7oo00<0
07ooOol047oo001@Ool00`00Oomoo`0UOol00`00Oomoo`1TOol00`00Oomoo`0@Ool0055oo`03001o
ogoo02Aoo`03001oogoo06Aoo`03001oogoo011oo`00DWoo00<007ooOol08goo0P00I7oo00<007oo
Ool04Goo001COol00`00Oomoo`0ROol00`00Oomoo`1SOol00`00Oomoo`0AOol005Aoo`03001oogoo
025oo`03001oogoo069oo`03001oogoo019oo`00EGoo00<007ooOol087oo00<007ooOol0HWoo00<0
07ooOol04Woo001FOol00`00Oomoo`0OOol00`00Oomoo`1ROol00`00Oomoo`0BOol005Moo`03001o
ogoo01ioo`03001oogoo065oo`03001oogoo01=oo`00F7oo0P007Woo00<007ooOol0HGoo00<007oo
Ool04goo001JOol00`00Oomoo`0KOol00`00Oomoo`1POol00`00Oomoo`0DOol005]oo`03001oogoo
01Yoo`80065oo`03001oogoo01Aoo`00G7oo00<007ooOol06Goo00<007ooOol0Ggoo00<007ooOol0
5Goo001MOol2000IOol00`00Oomoo`1OOol00`00Oomoo`0EOol005moo`03001oogoo01Ioo`03001o
ogoo05ioo`03001oogoo01Ioo`00H7oo00<007ooOol05Goo00<007ooOol0GWoo00<007ooOol05Woo
001QOol00`00Oomoo`0DOol00`00Oomoo`1MOol00`00Oomoo`0GOol0069oo`8001Aoo`03001oogoo
05eoo`03001oogoo01Moo`00I7oo00<007ooOol04Goo0P00GGoo00<007ooOol067oo001UOol00`00
Oomoo`0@Ool00`00Oomoo`1LOol00`00Oomoo`0HOol006Ioo`03001oogoo00moo`03001oogoo05]o
o`03001oogoo01Uoo`00Igoo0P003goo00<007ooOol0Fgoo00<007ooOol06Goo001YOol00`00Oomo
o`0<Ool00`00Oomoo`1JOol00`00Oomoo`0JOol006Yoo`03001oogoo00]oo`03001oogoo05Yoo`03
001oogoo01Yoo`00Jgoo00<007ooOol02Woo00<007ooOol0FGoo00<007ooOol06goo001/Ool2000:
Ool00`00Oomoo`1IOol00`00Oomoo`0KOol006ioo`03001oogoo00Moo`8005Uoo`03001oogoo01ao
o`00Kgoo00<007ooOol01Woo00<007ooOol0Egoo00<007ooOol07Goo001`Ool00`00Oomoo`05Ool0
0`00Oomoo`1GOol00`00Oomoo`0MOol0075oo`8000Eoo`03001oogoo05Ioo`03001oogoo01ioo`00
Lgoo00<007ooOol00Woo00<007ooOol0EGoo00<007ooOol07goo001dOol01@00Oomoogoo0000EWoo
00<007ooOol087oo001aOol20002Ool200000goo001oo`1EOol00`00Oomoo`0POol007=oo`04001o
ogooOol2001EOol00`00Oomoo`0QOol0079oo`03001oogoo00=oo`<0059oo`03001oogoo029oo`00
Lgoo00<007ooOol00Woo00@007oo0000051oo`03001oogoo02=oo`00LGoo00<007oo000017oo00D0
07ooOomoo`0004ioo`03001oogoo02Aoo`00LWoo00<007ooOol00goo00<007ooOol00Woo0P00Bgoo
00<007ooOol09Goo001hOol00`00Oomoo`04Ool00`00Oomoo`17Ool00`00Oomoo`0VOol007Qoo`03
001oogoo00Eoo`8004Ioo`03001oogoo02Moo`00N7oo00<007ooOol01goo0P00@goo00<007ooOol0
:7oo001hOol2000:Ool20010Ool00`00Oomoo`0YOol007Qoo`03001oogoo00]oo`8003eoo`03001o
ogoo02Yoo`00N7oo00<007ooOol03Goo0P00>Woo00<007ooOol0:goo001hOol00`00Oomoo`0?Ool2
000gOol00`00Oomoo`0/Ool007Qoo`03001oogoo015oo`8003=oo`8002moo`00N7oo00<007ooOol0
4goo0P00<7oo00<007ooOol0;goo001hOol00`00Oomoo`0EOol2000/Ool2000bOol007Qoo`03001o
ogoo01Moo`8002Moo`<003Aoo`00N7oo0P006Woo100087oo0`00=goo001hOol00`00Oomoo`0MOol4
000JOol2000jOol007Qoo`03001oogoo025oo`<0019oo`D003aoo`00N7oo00<007ooOol097oo4P00
@Goo001hOol00`00Oomoo`1gOol007Qoo`03001oogoo07Moo`00N7oo00<007ooOol0Mgoo001hOol0
0`00Oomoo`1gOol007Qoo`8007Qoo`00N7oo00<007ooOol0Mgoo001hOol00`00Oomoo`1gOol00001
\
\>"],
  ImageRangeCache->{{{0, 241}, {281, 0}} -> {-3.15705, -3.67695, 0.0261705, 
  0.0261705}}]
}, Open  ]]
}, Open  ]],

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Three bodies are used for the cam-follower model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(cam = 2; \)\), 
    \(\(follower = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"Two points are required on the ground (body 1).\nP1 is the rotational axis \
of the cam at {0, 0}.\nP2 is the pivot axis of the follower at {-3.5, 4.0}."],
   "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Two points are required on the cam (body 2).\nP1 is the rotational axis of \
the cam at local coordinate {0, 0}.\nP2 is the locus point of the cam that \
was previously defined and named ",
  StyleBox["camprof",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three points are required on the follower (body 3).\nP1 is the pivot axis of \
the follower at local coordinate {0, 0}.\nP2 is the left end {0.5, -1} of the \
flat surface that contacts the cam.\nP3 is the right end {6.5, -1} of the \
flat surface that contacts the cam."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are all of the bodies in the cam-follower model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.11111 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.026455 0.47619 [
[ -0.001 -0.001 0 0 ]
[ 1.001 1.11211 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 1.11111 L
s
P
P
p
p
.002 w
0 1.11111 m
1 1.11111 L
s
P
p
.002 w
1 0 m
1 1.11111 L
s
P
P
p
P
0 0 m
1 0 L
1 1.11111 L
0 1.11111 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.026455 0.5 0.555556 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.111111 0.5 0.111111 [
[ 0 0 0 0 ]
[ 1 1.11111 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 1.11111 L
0 1.11111 L
closepath
clip
newpath
p
p
p
.015 w
.11111 .94444 Mdot
.16667 .83333 Mdot
.83333 .83333 Mdot
P
0 0 1 r
p
.02 w
.11111 .94444 m
.5 .94444 L
s
P
p
.38889 .94444 m
.61111 .94444 L
.83333 .83333 L
.16667 .83333 L
F
P
P
p
[(P1)] .11111 .94444 0 -1.8 Mshowa
[(P2)] .16667 .83333 0 1.7 Mshowa
[(P3)] .83333 .83333 0 1.7 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.026455 0.97619 0.555556 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.555556 0.5 1.08466 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.111111 0.5 0.111111 [
[ 0 0 0 0 ]
[ 1 1.11111 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 1.11111 L
0 1.11111 L
closepath
clip
newpath
p
p
.004 w
.11111 .94444 m
.05556 .94444 L
.05556 .05556 L
.94444 .05556 L
.61111 .05556 L
.5 .5 L
.38889 .05556 L
s
.015 w
.5 .5 Mdot
.11111 .94444 Mdot
P
p
[(P1 {0,0})] .5 .5 -0.4 -1.5 Mshowa
[({-3.5,4})] .11111 .94444 -1.1 1.6 Mshowa
[(P2)] .11111 .94444 -1.5 -1.6 Mshowa
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.555556 0.97619 1.08466 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.111111 0.5 0.111111 [
[ 0 0 0 0 ]
[ 1 1.11111 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 1.11111 L
0 1.11111 L
closepath
clip
newpath
p
p
.004 w
newpath
.5 .5 .11111 0 365.73 arc
s
.018 w
.52358 .84818 Mdot
.5 .5 Mdot
P
p
[(P1)] .5 .5 -1.8 0 Mshowa
[( P2 at)(alpha=0)] .52358 .84818 -0.9 1.3 Mshowa
P
p
p
p
.004 w
.83333 .5 m
.83332 .50455 L
.83329 .50909 L
.83323 .51363 L
.83315 .51817 L
.83305 .52271 L
.83293 .52725 L
.83262 .5363 L
.83222 .54534 L
.83173 .55435 L
.83048 .57227 L
.82888 .59001 L
.82693 .60755 L
.82198 .64183 L
.81564 .67479 L
.80796 .70613 L
.79896 .73558 L
.78868 .76289 L
.76445 .81025 L
.75061 .82994 L
.7357 .84681 L
.71978 .86077 L
.71146 .86665 L
.70292 .87178 L
.69416 .87616 L
.68519 .87981 L
.67602 .88272 L
.67137 .8839 L
.66667 .8849 L
.66192 .88572 L
.65713 .88636 L
.65472 .88661 L
.6523 .88682 L
.64987 .88699 L
.64743 .88711 L
.64498 .88719 L
.64252 .88722 L
.64005 .88721 L
.63757 .88716 L
.63508 .88706 L
.63258 .88693 L
.63008 .88675 L
.62756 .88653 L
.62251 .88596 L
.61742 .88523 L
.60715 .88328 L
.59676 .88071 L
.58627 .87753 L
.54351 .85924 L
.5 .83333 L
Mistroke
.41373 .76642 L
.33333 .69245 L
.2643 .62459 L
.21132 .57044 L
.19204 .54899 L
.18436 .53951 L
.17802 .53072 L
.17307 .52251 L
.16952 .51475 L
.16827 .511 L
.16778 .50914 L
.16738 .5073 L
.16707 .50547 L
.16695 .50455 L
.16685 .50364 L
.16677 .50273 L
.16671 .50182 L
.16668 .50091 L
.16667 .5 L
.16668 .49909 L
.16671 .49818 L
.16677 .49727 L
.16685 .49636 L
.16695 .49545 L
.16707 .49453 L
.16738 .4927 L
.16827 .489 L
.16952 .48525 L
.17307 .47749 L
.17802 .46928 L
.21132 .42956 L
.2643 .37541 L
.33333 .30755 L
.41373 .23358 L
.45649 .19828 L
.5 .16667 L
.54351 .14076 L
.56503 .13055 L
.58627 .12247 L
.59676 .11929 L
.60715 .11672 L
.61742 .11477 L
.62251 .11404 L
.62756 .11347 L
.63008 .11325 L
.63258 .11307 L
.63508 .11294 L
.63757 .11284 L
.64005 .11279 L
.64252 .11278 L
Mistroke
.64498 .11281 L
.64743 .11289 L
.64987 .11301 L
.6523 .11318 L
.65713 .11364 L
.66192 .11428 L
.66667 .1151 L
.67602 .11728 L
.68519 .12019 L
.69416 .12384 L
.70292 .12822 L
.71978 .13923 L
.7357 .15319 L
.75061 .17006 L
.76445 .18975 L
.77716 .21216 L
.78868 .23711 L
.79896 .26442 L
.80796 .29387 L
.81564 .32521 L
.82198 .35817 L
.82463 .37516 L
.82693 .39245 L
.82888 .40999 L
.83048 .42773 L
.83173 .44565 L
.83222 .45466 L
.83262 .4637 L
.83293 .47275 L
.83305 .47729 L
.83315 .48183 L
.83323 .48637 L
.83329 .49091 L
.83332 .49545 L
.83333 .5 L
Mfstroke
P
P
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{372, 413},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005d0001WA000`40O003h00OogooMGoo003o001d
0001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomo
o`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo
00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogoo
L7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<0
07ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40
005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo
0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool0
0003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`
Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00
Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@00
0Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0
ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`00
00<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1o
o`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001o
ogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001
Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3o
Oom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo0000
0`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo
0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007oo
Ool0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005o
o`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?mo
og1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003
001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool1
0001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomo
o`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo
00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogoo
L7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<0
07ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40
005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo
0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool0
0003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`
Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00
Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@00
0Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0
ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`00
00<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1o
o`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001o
ogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001
Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3o
Oom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo0000
0`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo
0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007oo
Ool0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005o
o`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?mo
og1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003
001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool1
0001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomo
o`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo
00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogoo
L7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<0
07ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40
005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo
0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool0
0003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`
Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00
Oomoo`0NOol30003Ool3001]Ool30003Ool2003COol10001Ool00003001oogoo01moo`03001oogoo
009oo`03001oogoo06ioo`03001oogoo00Aoo`03001oogoo0=1oo`40005oo`0000<007ooOol07goo
0`000goo00<007ooOol0KGoo0`000goo00<007ooOol0dGoo0@000Goo00000`00Oomoo`0OOol01000
Oomoo`000Woo00<007ooOol0KGoo00@007ooOol000=oo`03001oogoo0=1oo`40005oo`0000<007oo
Ool07goo00P007ooOol007oo001oo`00KWoo00P007ooOol007oo001oo`00dWoo0@000Goo00000`00
Oomoo`0NOol40003Ool00`00Oomoo`1/Ool40003Ool00`00Oomoo`3AOol10001Ool00003001oogoo
0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool0
0003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`
Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol08Woo00<007ooOol0Lgoo00<0
07ooOol0e7oo0@000Goo00000`00Oomoo`0VOoma01oHOol10001Ool00003001oogoo02Qoofd07mYo
o`40005oo`0000<007ooOol0:WooJ@0Og7oo0@000Goo00000`00Oomoo`0/OomU01oNOol10001Ool0
0003001oogoo02ioof407n1oo`40005oo`0000<007ooOol0<7ooG@0OhWoo0@000Goo00000`00Oomo
o`0bOomI01oTOol10001Ool00003001oogoo03AooeD07nIoo`40005oo`0000<007ooOol0=WooD@0O
j7oo0@000Goo00000`00Oomoo`0hOom<01o[Ool10001Ool00003001oogoo03YoodP07neoo`40005o
o`0000<007ooOol0?7ooA00Okgoo0@000Goo00000`00Oomoo`0nOom001oaOol10001Ool00003001o
ogoo041ooc`07o=oo`40005oo`0000<007ooOol0@Woo>00OmGoo0@000Goo00000`00Oomoo`14Oold
01ogOol10001Ool00003001oogoo04Iooc007oUoo`40005oo`0000<007ooOol067ooG00Ongoo0@00
0Goo00000`00Oomoo`0HOomI01onOol10001Ool00003001oogoo01QoodP07omooa1oo`40005oo`00
00<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1o
o`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001o
ogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`0DOol30002Ool5
003oOomBOol10001Ool00003001oogoo01Eoo`03001oogoo00=oo`03001oogoo0?mooe9oo`40005o
o`0000<007ooOol05Goo0`000goo00<007ooOol0ogooDWoo0@000Goo00000`00Oomoo`0EOol01000
Oomoo`000Woo00<007ooOol0ogooDWoo0@000Goo00000`00Oomoo`0EOol01000Oomoo`000Woo00<0
07ooOol0ogooDWoo0@000Goo00000`00Oomoo`0DOol40002Ool2003oOomDOol10001Ool00003001o
ogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001
Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3o
Oom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo0000
0`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo
0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007oo
Ool0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005o
o`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?mo
og1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003
001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool1
0001Ool00003001oogoo00mooih00<9oo`40005oo`0000<007ooOol03goo00<007ooOol0>7oo00<0
07ooOol097oo00<007ooOol0ngoo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0iOol00`00Oomo
o`0SOol00`00Oomoo`3kOol10001Ool00003001oogoo00moo`03001oogoo03Uoo`03001oogoo029o
o`03001oogoo0?aoo`40005oo`0000<007ooOol03goo00<007ooOol0>Goo00<007ooOol08Woo00<0
07ooOol0o7oo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0iOol00`00Oomoo`0ROol00`00Oomo
o`3lOol10001Ool00003001oogoo00moo`03001oogoo03Yoo`03001oogoo025oo`03001oogoo0?ao
o`40005oo`0000<007ooOol03goo00<007ooOol0>Woo00<007ooOol087oo00<007ooOol0oGoo0@00
0Goo00000`00Oomoo`0?Ool00`00Oomoo`0jOol00`00Oomoo`0POol00`00Oomoo`3mOol10001Ool0
0003001oogoo00moo`03001oogoo03Yoo`03001oogoo021oo`03001oogoo0?eoo`40005oo`0000<0
07ooOol03goo00<007ooOol0>goo00<007ooOol07goo00<007ooOol0/goo1@00AGoo0@000Goo0000
0`00Oomoo`0?Ool00`00Oomoo`0kOol00`00Oomoo`0NOol00`00Oomoo`2`Ool50004Ool40011Ool1
0001Ool00003001oogoo00moo`03001oogoo03]oo`03001oogoo01ioo`03001oogoo0:aoo`@000eo
o`<003ioo`40005oo`0000<007ooOol03goo00<007ooOol0>goo00<007ooOol07Woo00<007ooOol0
ZWoo0P0057oo0P00?7oo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0lOol00`00Oomoo`0MOol0
0`00Oomoo`2XOol2000HOol2000jOol10001Ool00003001oogoo00moo`03001oogoo03aoo`03001o
ogoo01aoo`03001oogoo0:Ioo`<001aoo`03001oogoo03Moo`40005oo`0000<007ooOol03goo00<0
07ooOol0?7oo00<007ooOol077oo00<007ooOol0Y7oo0P0087oo00<007ooOol0=Woo0@000Goo0000
0`00Oomoo`0?Ool00`00Oomoo`0lOol00`00Oomoo`0LOol00`00Oomoo`2SOol00`00Oomoo`0QOol0
0`00Oomoo`0eOol10001Ool00003001oogoo00moo`03001oogoo03eoo`03001oogoo01]oo`03001o
ogoo0:5oo`8002Eoo`03001oogoo03Aoo`40005oo`0000<007ooOol03goo00<007ooOol0?Goo00<0
07ooOol06Woo00<007ooOol0X7oo0P00:7oo00<007ooOol0<goo0@000Goo00000`00Oomoo`0?Ool0
0`00Oomoo`0mOol00`00Oomoo`0JOol00`00Oomoo`2OOol00`00Oomoo`0YOol00`00Oomoo`0bOol1
0001Ool00003001oogoo00moo`03001oogoo03eoo`03001oogoo01Yoo`03001oogoo09eoo`8002eo
o`03001oogoo035oo`40005oo`0000<007ooOol03goo00<007ooOol0?Woo00<007ooOol06Goo00<0
07ooOol0W7oo00<007ooOol0;Goo00<007ooOol0<Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomo
o`0nOol00`00Oomoo`0HOol00`00Oomoo`2KOol2000aOol00`00Oomoo`0`Ool10001Ool00003001o
ogoo00moo`03001oogoo03ioo`03001oogoo01Qoo`03001oogoo09Uoo`8003Aoo`03001oogoo02mo
o`40005oo`0000<007ooOol03goo00<007ooOol0?Woo00<007ooOol067oo00<007ooOol0V7oo00<0
07ooOol0=7oo00<007ooOol0;goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0oOol00`00Oomo
o`0GOol00`00Oomoo`2GOol00`00Oomoo`0fOol00`00Oomoo`0^Ool10001Ool00003001oogoo00mo
o`03001oogoo03moo`03001oogoo01Moo`03001oogoo09Ioo`03001oogoo03Moo`03001oogoo02io
o`40005oo`0000<007ooOol03goo00<007ooOol0?goo00<007ooOol05Woo00<007ooOol0UWoo00<0
07ooOol0>Goo00<007ooOol0;Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0oOol00`00Oomo
o`0FOol00`00Oomoo`2EOol00`00Oomoo`0jOol00`00Oomoo`0]Ool10001Ool00003001oogoo00mo
o`03001oogoo041oo`03001oogoo01Eoo`03001oogoo09Aoo`03001oogoo03aoo`03001oogoo02ao
o`40005oo`0000<007ooOol03goo00<007ooOol0@7oo00<007ooOol05Goo00<007ooOol0Tgoo00<0
07ooOol0?Goo00<007ooOol0;7oo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`10Ool00`00Oomo
o`0DOol00`00Oomoo`2COol00`00Oomoo`0oOol00`00Oomoo`0[Ool10001Ool00003001oogoo00mo
o`03001oogoo041oo`03001oogoo01Aoo`03001oogoo099oo`03001oogoo041oo`03001oogoo02]o
o`40005oo`0000<007ooOol03goo00<007ooOol0@Goo00<007ooOol04goo00<007ooOol0TGoo00<0
07ooOol0@Woo00<007ooOol0:Woo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`11Ool00`00Oomo
o`0COol00`00Oomoo`2@Ool00`00Oomoo`13Ool00`00Oomoo`0ZOol10001Ool00003001oogoo00mo
o`03001oogoo045oo`03001oogoo019oo`03001oogoo091oo`03001oogoo04Eoo`03001oogoo02Uo
o`40005oo`0000<007ooOol03goo00<007ooOol0@Goo00<007ooOol04Woo00<007ooOol0Sgoo00<0
07ooOol0AWoo00<007ooOol0:Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`12Ool00`00Oomo
o`0AOol00`00Oomoo`2>Ool00`00Oomoo`17Ool00`00Oomoo`0YOol10001Ool00003001oogoo00mo
o`03001oogoo049oo`03001oogoo015oo`03001oogoo08aoo`8004Yoo`03001oogoo02Uoo`40005o
o`0000<007ooOol03goo00<007ooOol0@Woo00<007ooOol047oo00<007ooOol0S7oo00<007ooOol0
Bgoo00<007ooOol0:7oo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`12Ool00`00Oomoo`0@Ool0
0`00Oomoo`2;Ool00`00Oomoo`1<Ool00`00Oomoo`0XOol10001Ool00003001oogoo00moo`03001o
ogoo04=oo`03001oogoo00moo`03001oogoo08Yoo`03001oogoo04eoo`03001oogoo02Qoo`40005o
o`0000<007ooOol03goo00<007ooOol0@goo00<007ooOol03goo00<007ooOol0RGoo00<007ooOol0
CWoo00<007ooOol0:7oo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`13Ool00`00Oomoo`0>Ool0
0`00Oomoo`29Ool00`00Oomoo`1@Ool00`00Oomoo`0WOol10001Ool00003001oogoo00moo`03001o
ogoo04=oo`03001oogoo00ioo`03001oogoo08Qoo`03001oogoo055oo`03001oogoo02Moo`40005o
o`0000<007ooOol03goo00<007ooOol0A7oo00<007ooOol03Goo00<007ooOol0Qgoo00<007ooOol0
DWoo00<007ooOol09goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`14Ool00`00Oomoo`0=Ool0
0`00Oomoo`26Ool00`00Oomoo`1DOol00`00Oomoo`0VOol10001Ool00003001oogoo00moo`03001o
ogoo04Aoo`03001oogoo00aoo`03001oogoo08Ioo`03001oogoo05Eoo`03001oogoo02Ioo`40005o
o`0000<007ooOol03goo00<007ooOol0A7oo00<007ooOol037oo00<007ooOol0QGoo00<007ooOol0
EWoo00<007ooOol09Woo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`15Ool00`00Oomoo`0;Ool0
0`00Oomoo`24Ool00`00Oomoo`1GOol00`00Oomoo`0VOol10001Ool00003001oogoo00moo`03001o
ogoo04Eoo`03001oogoo00]oo`03001oogoo08=oo`03001oogoo05Qoo`03001oogoo02Ioo`40005o
o`0000<007ooOol03goo00<007ooOol0AGoo00<007ooOol02Woo00<007ooOol0Pgoo00<007ooOol0
FWoo00<007ooOol09Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`15Ool00`00Oomoo`0:Ool0
0`00Oomoo`22Ool00`00Oomoo`1KOol00`00Oomoo`0UOol10001Ool00003001oogoo00moo`03001o
ogoo04Ioo`03001oogoo00Uoo`03001oogoo085oo`03001oogoo05aoo`03001oogoo02Eoo`40005o
o`0000<007ooOol03goo00<007ooOol0AWoo00<007ooOol02Goo00<007ooOol0P7oo00<007ooOol0
GGoo00<007ooOol09Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`16Ool00`00Oomoo`09Ool0
0`00Oomoo`1oOol00`00Oomoo`1NOol00`00Oomoo`0UOol10001Ool00003001oogoo00moo`03001o
ogoo04Ioo`03001oogoo00Qoo`03001oogoo07moo`03001oogoo05moo`03001oogoo02Eoo`40005o
o`0000<007ooOol03goo00<007ooOol0Agoo00<007ooOol01goo00<007ooOol0OWoo00<007ooOol0
H7oo00<007ooOol09Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomoo`07Ool0
0`00Oomoo`1mOol00`00Oomoo`0VOol7000eOol00`00Oomoo`0TOol10001Ool00003001oogoo00mo
o`03001oogoo04Moo`03001oogoo00Moo`03001oogoo07aoo`03001oogoo02=oo`@000Moo`<0039o
o`03001oogoo02Aoo`40005oo`0000<007ooOol03goo00<007ooOol0Agoo00<007ooOol01Woo00<0
07ooOol0O7oo00<007ooOol08Woo0P003Woo0P00<7oo00<007ooOol097oo0@000Goo00000`00Oomo
o`0?Ool00`00Oomoo`18Ool00`00Oomoo`05Ool00`00Oomoo`1jOol2000SOol2000BOol2000^Ool0
0`00Oomoo`0TOol10001Ool00003001oogoo00moo`03001oogoo04Qoo`03001oogoo00Eoo`03001o
ogoo07Uoo`03001oogoo029oo`03001oogoo01Aoo`03001oogoo02]oo`03001oogoo02Aoo`40005o
o`0000<007ooOol03goo00<007ooOol0B7oo00<007ooOol01Goo00<007ooOol0N7oo00<007ooOol0
8Goo0P0067oo00<007ooOol0:Woo00<007ooOol097oo0@000Goo00000`00Oomoo`0?Ool00`00Oomo
o`18Ool00`00Oomoo`04Ool00`00Oomoo`1hOol00`00Oomoo`0QOol00`00Oomoo`0IOol00`00Oomo
o`0YOol00`00Oomoo`0TOol10001Ool00003001oogoo00moo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo07Moo`03001oogoo029oo`03001oogoo01Yoo`03001oogoo02Qoo`03001oogoo02Ao
o`40005oo`0000<007ooOol03goo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol0MWoo00<0
07ooOol08Woo00<007ooOol06goo00<007ooOol0:7oo00<007ooOol097oo0@000Goo00000`00Oomo
o`0?Ool00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`1eOol00`00Oomoo`0QOol2000OOol0
0`00Oomoo`0XOol00`00Oomoo`0SOol10001Ool00003001oogoo00moo`03001oogoo04Uoo`03001o
ogoo009oo`03001oogoo07Eoo`03001oogoo025oo`03001oogoo021oo`03001oogoo02Moo`03001o
ogoo02=oo`40005oo`0000<007ooOol03goo00<007ooOol0BWoo00D007ooOomoo`0007Moo`03001o
ogoo025oo`03001oogoo021oo`03001oogoo02Moo`03001oogoo02=oo`40005oo`0000<007ooOol0
3goo00<007ooOol0BWoo00D007ooOomoo`0007Ioo`03001oogoo029oo`03001oogoo025oo`03001o
ogoo02Ioo`03001oogoo02=oo`40005oo`0000<007ooOol03goo00<007ooOol0BWoo00D007ooOomo
o`0007Eoo`03001oogoo02=oo`03001oogoo025oo`03001oogoo02Ioo`03001oogoo02=oo`40005o
o`0000<007ooOol03goo00<007ooOol0BWoo00@007ooOol007Eoo`03001oogoo02=oo`03001oogoo
02=oo`03001oogoo02Eoo`03001oogoo02=oo`40005oo`0000<007ooOol03goo00<007ooOol0Bgoo
00<007oo0000MGoo00<007ooOol08goo00<007ooOol08goo00<007ooOol09Goo00<007ooOol08goo
0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`1;Ool00`00Ool0001eOol00`00Oomoo`0SOol00`00
Oomoo`0SOol00`00Oomoo`0UOol00`00Oomoo`0SOol10001Ool00003001oogoo00moo`03001oogoo
04]oo`03001oo`0007Aoo`03001oogoo02Aoo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo
02=oo`40005oo`0000<007ooOol03goo00<007ooOol0Bgoo0P00MGoo00<007ooOol097oo00<007oo
Ool057oo0`000Woo1@001Woo00<007ooOol097oo00<007ooOol08goo0@000Goo00000`00Oomoo`0?
Ool00`00Oomoo`1<Ool00`00Oomoo`1bOol00`00Oomoo`0UOol00`00Oomoo`0EOol00`00Oomoo`03
Ool00`00Oomoo`06Ool00`00Oomoo`0TOol00`00Oomoo`0SOol10001Ool00003001oogoo00moo`03
001oogoo04]oo`8007Aoo`03001oogoo02Eoo`03001oogoo01Eoo`<000=oo`03001oogoo00Ioo`03
001oogoo02Aoo`03001oogoo02=oo`40005oo`0000<007ooOol03goo00<007ooOol0`Goo0P009Woo
00<007ooOol05Goo00@007ooOol0009oo`03001oogoo00Ioo`03001oogoo02Aoo`03001oogoo02=o
o`40005oo`0000<007ooOol03goo00<007ooOol0`Woo00<007ooOol097oo00<007ooOol05Goo00@0
07ooOol0009oo`03001oogoo00Ioo`03001oogoo02Aoo`03001oogoo02=oo`40005oo`0000<007oo
Ool03goo00<007ooOol0`Woo00<007ooOol097oo00<007ooOol057oo10000Woo0P001goo00<007oo
Ool09Goo00<007ooOol08goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`33Ool00`00Oomoo`0S
Ool00`00Oomoo`0SOol00`00Oomoo`0UOol00`00Oomoo`0SOol10001Ool00003001oogoo00moo`03
001oogoo0<=oo`03001oogoo02=oo`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo02=oo`40
005oo`0000<007ooOol03goo00<007ooOol0DWoo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool0G7oo00<007ooOol097oo00<007ooOol08Goo00<007ooOol09Woo00<007ooOol08goo0@000Goo
00000`00Oomoo`0?Ool00`00Oomoo`10Ool30002Ool50007Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0SOol00`00Oomoo`0Q
Ool00`00Oomoo`0VOol00`00Oomoo`0SOol10001Ool00003001oogoo00moo`03001oogoo045oo`03
001oogoo00=oo`03001oogoo00Moo`07001oogooOol007oo000017oo00H007ooOol007oo0003Ool0
0`00Oomoo`1MOol2000SOol00`00Oomoo`0POol00`00Oomoo`0WOol00`00Oomoo`0SOol10001Ool0
0003001oogoo00moo`03001oogoo045oo`<000=oo`03001oogoo00Ioo`8000=oo`03001oo`0000Mo
o`03001oo`0000=oo`80061oo`03001oogoo021oo`03001oogoo021oo`03001oogoo02Moo`03001o
ogoo02=oo`40005oo`0000<007ooOol03goo00<007ooOol0@Goo00@007ooOol0009oo`03001oogoo
00Moo`07001oogooOol007oo00001goo00<007oo00000goo00<007ooOol0Ggoo00<007ooOol08Goo
00<007ooOol07Woo00<007ooOol0:7oo00<007ooOol08goo0@000Goo00000`00Oomoo`0?Ool00`00
Oomoo`11Ool01000Oomoo`000Woo00<007ooOol01goo00L007ooOomoo`00Ool00007Ool00`00Ool0
0003Ool00`00Oomoo`1POol00`00Oomoo`0QOol2000NOol00`00Oomoo`0WOol00`00Oomoo`0TOol1
0001Ool00003001oogoo00moo`03001oogoo041oo`@0009oo`8000Yoo`05001oogooOol00009Ool0
1@00Oomoogoo0000I7oo00<007ooOol08Goo00<007ooOol06goo00<007ooOol0:7oo00<007ooOol0
97oo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3:Ool00`00Oomoo`0QOol00`00Oomoo`0JOol0
0`00Oomoo`0XOol00`00Oomoo`0TOol10001Ool00003001oogoo00moo`03001oogoo0<]oo`03001o
ogoo025oo`03001oogoo01Qoo`03001oogoo02Uoo`03001oogoo02Aoo`40005oo`0000<007ooOol0
3goo00<007ooOol0c7oo00<007ooOol08Goo00<007ooOol05Goo0P00;7oo00<007ooOol097oo0@00
0Goo00000`00Oomoo`0?Ool00`00Oomoo`3=Ool00`00Oomoo`0QOol00`00Oomoo`0COol00`00Oomo
o`0/Ool00`00Oomoo`0TOol10001Ool00003001oogoo00moo`03001oogoo0<ioo`03001oogoo025o
o`<0011oo`8002moo`03001oogoo02Aoo`40005oo`0000<007ooOol03goo00<007ooOol0cgoo00<0
07ooOol08goo0P002Woo1000<Goo00<007ooOol097oo0@000Goo00000`00Oomoo`0?Ool00`00Oomo
o`3@Ool00`00Oomoo`0TOol:000eOol00`00Oomoo`0TOol10001Ool00003001oogoo00moo`03001o
ogoo0=5oo`03001oogoo069oo`03001oogoo02Aoo`40005oo`0000<007ooOol03goo00<007ooOol0
dWoo00<007ooOol0HGoo00<007ooOol097oo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3COol0
0`00Oomoo`1OOol00`00Oomoo`0UOol10001Ool00003001oogoo00moo`03001oogoo0=Aoo`03001o
ogoo05ioo`03001oogoo02Eoo`40005oo`0000<007ooOol03goo00<007ooOol0eGoo00<007ooOol0
GGoo00<007ooOol09Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3FOol00`00Oomoo`1LOol0
0`00Oomoo`0UOol10001Ool00003001oogoo00moo`03001oogoo0=Moo`03001oogoo05]oo`03001o
ogoo02Eoo`40005oo`0000<007ooOol03goo00<007ooOol0f7oo00<007ooOol0FWoo00<007ooOol0
9Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3IOol00`00Oomoo`1HOol00`00Oomoo`0VOol1
0001Ool00003001oogoo00moo`03001oogoo0=Yoo`03001oogoo05Moo`03001oogoo02Ioo`40005o
o`0000<007ooOol03goo00<007ooOol0fgoo00<007ooOol0EWoo00<007ooOol09Woo0@000Goo0000
0`00Oomoo`0?Ool00`00Oomoo`3LOol00`00Oomoo`1EOol00`00Oomoo`0VOol10001Ool00003001o
ogoo00moo`03001oogoo0=eoo`03001oogoo05=oo`03001oogoo02Moo`40005oo`0000<007ooOol0
3goo00<007ooOol0gWoo00<007ooOol0DWoo00<007ooOol09goo0@000Goo00000`00Oomoo`0?Ool0
0`00Oomoo`3OOol00`00Oomoo`0WOol3000WOol00`00Oomoo`0WOol10001Ool00003001oogoo00mo
o`03001oogoo0>1oo`03001oogoo02Moo`03001oogoo02Eoo`03001oogoo02Qoo`40005oo`0000<0
07ooOol03goo00<007ooOol0hGoo00<007ooOol077oo100000Aoo`000000009oo`<00007Ool00000
001oo`00Ool010001goo00<007ooOol047oo00<007ooOol0:7oo0@000Goo00000`00Oomoo`0?Ool0
0`00Oomoo`3ROol00`00Oomoo`0KOol30003Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<0
07oo00000P001goo00<007oo00004Goo00<007ooOol0:7oo0@000Goo00000`00Oomoo`0?Ool00`00
Oomoo`3SOol00`00Oomoo`0LOol01@00Oomoogoo00000goo00H007ooOol007oo0002Ool01@00Oomo
ogoo00000Woo0`000Woo00<007oo00004Goo00<007ooOol0:7oo0@000Goo00000`00Oomoo`0?Ool0
0`00Oomoo`3TOol00`00Oomoo`0JOol20003Ool00`00Oomoo`040002Ool30003Ool20007Ool00`00
Ool0000@Ool00`00Oomoo`0YOol10001Ool00003001oogoo00moo`03001oogoo0>Eoo`03001oogoo
01ioo`03001oogoo00Ioo`03001oogoo00Moo`<0009oo`03001oo`00011oo`03001oogoo02Uoo`40
005oo`0000<007ooOol03goo00<007ooOol0iWoo0P007Goo0P001goo0P003goo00<007ooOol03goo
00<007ooOol0:Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3XOol00`00Oomoo`16Ool00`00
Oomoo`0YOol10001Ool00003001oogoo00moo`03001oogoo0>Uoo`03001oogoo04Aoo`03001oogoo
02Yoo`40005oo`0000<007ooOol03goo00<007ooOol0jWoo00<007ooOol0@goo00<007ooOol0:Woo
0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3[Ool00`00Oomoo`11Ool00`00Oomoo`0[Ool10001
Ool00003001oogoo00moo`03001oogoo0>aoo`03001oogoo041oo`03001oogoo02]oo`40005oo`00
00<007ooOol03goo00<007ooOol0kGoo00<007ooOol0?Woo00<007ooOol0;7oo0@000Goo00000`00
Oomoo`0?Ool00`00Oomoo`3^Ool2000nOol00`00Oomoo`0/Ool10001Ool00003001oogoo00moo`03
001oogoo0?1oo`03001oogoo015oo`<000=oo`<000Moo`@0009oo`80015oo`03001oogoo02eoo`40
005oo`0000<007ooOol03goo00<007ooOol0lGoo00<007ooOol04Goo00<007ooOol00Woo00<007oo
Ool01goo0`000Woo00@007ooOol0011oo`03001oogoo02eoo`40005oo`0000<007ooOol03goo00<0
07ooOol0lWoo0P004Goo0`000goo00<007ooOol027oo00@007ooOol0019oo`03001oogoo02ioo`40
005oo`0000<007ooOol03goo00<007ooOol0m7oo00<007ooOol03Woo00@007ooOol0009oo`03001o
ogoo00Moo`800003Ool000000080011oo`03001oogoo02ioo`40005oo`0000<007ooOol03goo00<0
07ooOol0mGoo00<007ooOol03Goo00P007ooOol007oo001oo`0037oo00<007ooOol03goo00<007oo
Ool0;goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3fOol2000<Ool40003Ool00`00Oomoo`0M
Ool00`00Oomoo`0_Ool10001Ool00003001oogoo00moo`03001oogoo0?Qoo`03001oogoo02moo`03
001oogoo031oo`40005oo`0000<007ooOol03goo00<007ooOol0nGoo00<007ooOol0;Goo00<007oo
Ool0<Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3jOol2000]Ool00`00Oomoo`0aOol10001
Ool00003001oogoo00moo`03001oogoo0?aoo`03001oogoo02Uoo`03001oogoo039oo`40005oo`00
00<007ooOol03goo00<007ooOol0oGoo0P00:7oo00<007ooOol0<goo0@000Goo00000`00Oomoo`0?
Ool00`00Oomoo`3oOol00`00Oomoo`0UOol00`00Oomoo`0cOol10001Ool00003001oogoo00moo`03
001oogoo0?moo`5oo`8002Aoo`03001oogoo03Aoo`40005oo`0000<007ooOol03goo00<007ooOol0
ogoo0goo0P0087oo0P00=goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3oOol5Ool2000MOol0
0`00Oomoo`0gOol10001Ool00003001oogoo00moo`03001oogoo0?moo`Moo`8001Uoo`8003Yoo`40
005oo`0000<007ooOol03goo00<007ooOol037oo00<007ooOol05Goo00<007ooOol01Woo00<007oo
Ool0f7oo0P005Woo00<007ooOol0>Woo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool30002Ool00`00
Oomoo`3IOol2000BOol2000mOol10001Ool00003001oogoo00moo`03001oogoo00]oo`03001oogoo
00Qoo`03001oogoo00Eoo`03001oo`0000Aoo`03001oogoo009oo`05001oogooOol0003MOol4000:
Ool4000oOol10001Ool00003001oogoo00moo`03001oogoo00Yoo`8000=oo`<000=oo`03001oogoo
00Qoo`03001oogoo00Eoo`@0009oo`800>1oo`X004=oo`40005oo`0000<007ooOol03goo00<007oo
Ool02goo00<007ooOol027oo00<007ooOol01Goo0P0027oo00<007oo00000goo00<007ooOol0ogoo
;Goo0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Ool00007Ool0
0`00Oomoo`08Ool20003Ool00`00Oomoo`3oOol]Ool10001Ool00003001oogoo00moo`03001oogoo
00aoo`03001oogoo00Ioo`03001oogoo00Ioo`<000Uoo`04001oogoo003oOol`Ool10001Ool00003
001oogoo00moo`03001oogoo0?mooeioo`40005oo`0000<007ooOol03goo00<007ooOol0ogooGWoo
0@000Goo00000`00Oomoo`0?Ool00`00Oomoo`3oOomNOol10001Ool00003001oogoo00moo`03001o
ogoo0?mooeioo`40005oo`0000<007ooOol03goo00<007ooOol0ogooGWoo0@000Goo00000`00Oomo
o`0?Ool00`00Oomoo`3oOomNOol10001Ool00003001oogoo00moo`/00?mooeIoo`40005oo`0000<0
07ooOol067oo00<007ooOol0ogooEGoo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001o
ogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001
Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`0L
Ool30003Ool3003oOom;Ool10001Ool00003001oogoo01eoo`03001oogoo009oo`03001oogoo0?mo
od]oo`40005oo`0000<007ooOol07Goo0`000goo00<007ooOol0ogooBWoo0@000Goo00000`00Oomo
o`0MOol01000Oomoo`000Woo00<007ooOol0ogooBWoo0@000Goo00000`00Oomoo`0MOol02000Oomo
o`00Ool007oo003oOom;Ool10001Ool00003001oogoo01aoo`@000=oo`03001oogoo0?moodYoo`40
005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo
0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool0
0003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`
Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00
Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@00
0Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`0000<007ooOol0
ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1oo`40005oo`00
00<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001oogoo0?moog1o
o`40005oo`0000<007ooOol0ogooL7oo0@000Goo00000`00Oomoo`3oOom`Ool10001Ool00003001o
ogoo0?moog1oo`40005oo`0000<007ooOol0ogooL7oo0@000Goo003o001d0001Ool00001\
\>"],
  ImageRangeCache->{{{0, 371}, {412, 0}} -> {-0.0524668, -0.0576672, 
  0.00567368, 0.00567368}, {{9.1875, 185.5}, {401.813, 206}} -> {-4.97132,
   -5.02033, 0.0510698, 0.0510698}, {{185.5, 361.75}, {401.813, 206}} ->
   {-1.13012, -0.541967, 0.00595751, 0.00963944}, {{9.1875, 185.5}, {206, 
  10.125}} -> {-4.96974, -15.0171, 0.0510535, 0.0510535}, {{185.5, 361.75}, {
  206, 10.125}} -> {-13.9725, -15.0204, 0.0510644, 0.0510644}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This is to set a nonzero initial guess for the rocker. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[Body[follower, InitialGuess \[Rule] {{\(-3.5\), 4.0}, 0.0}]]
      \)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Constraints "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three regular constraints and one ",
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are required to model the cam-follower mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the center of the cam to be coincident with its \
rotational axis on the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the pivot point of the follower to be coincident with \
its axis on the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the angular coordinate of the cam. This driving \
constraint is used to specify the rotation of the cam as a function of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the single remaining degree of freedom. The point and \
line arguments are given in the same manner as would be used with any other \
constraint, except for the requirement that the local coordinates of the \
point be a function of the symbol ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that while ",
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one degree of freedom in the model, it actually adds two \
equations (one that forces the locus point to lie on the line and one that \
forces the line to be tangent to the cam at the point of contact) and one \
unknown ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraints for the cam-follower mechanism."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Revolute2[1, Point[cam, 0], Point[ground, 0]], \n\t
      Revolute2[2, \n\t\tPoint[follower, 0], Point[ground, {\(-3.5\), 4}]], \n
      \tRotationLock1[3, cam, 2.0  \[Pi]\ T], \n\t
      CamToLine1[4, Point[cam, camprof], {alpha, 1.5}, 
        Line[follower, {0.5, \(-1\)}, {6.5, \(-1\)}]]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The cam-follower mechanism model can now be run in the usual manner. Note \
the presence of the cam parameter ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the solution rule. At this value of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the cam locus point is placed at the point of contact between the cam and \
the follower."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now we run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.15."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[.15] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.15`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 0.942477796076937934`\), ",", 
        RowBox[{"X3", "\[Rule]", 
          RowBox[{"-", 
            StyleBox["3.5`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}]}], ",", \(Y3 \[Rule] 4.`\), ",", 
        \(Th3 \[Rule] 0.261378974305872269`\), ",", 
        \(alpha \[Rule] 0.836663186288445714`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the cam-follower mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.15."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
  
%%Creator: Mathematica 
  
%%AspectRatio: 1.11111  
  
MathPictureStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
0.5 0.111111 0.5 0.111111 [ 
  
[ 0 0 0 0 ] 
  
[ 1 1.11111 0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
0 g 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 1.11111 L 
  
0 1.11111 L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
.004 w 
  
.11111 .94444 m 
  
.05556 .94444 L 
  
.05556 .05556 L 
  
.94444 .05556 L 
  
.61111 .05556 L 
  
.5 .5 L 
  
.38889 .05556 L 
  
s 
  
.015 w 
  
.5 .5 Mdot 
  
.11111 .94444 Mdot 
  
.004 w 
  
newpath 
  
.5 .5 .14444 0 365.73 arc 
  
s 
  
P 
  
p 
  
p 
  
.015 w 
  
.11111 .94444 Mdot 
  
.19349 .85146 Mdot 
  
.83752 1.02374 Mdot 
  
P 
  
0 0 1 r 
  
p 
  
.02 w 
  
.11111 .94444 m 
  
.48679 1.04494 L 
  
s 
  
P 
  
p 
  
.37945 1.01623 m 
  
.59413 1.07365 L 
  
.83752 1.02374 L 
  
.19349 .85146 L 
  
F 
  
P 
  
P 
  
p 
  
p 
  
p 
  
.004 w 
  
.69593 .76967 m 
  
.63579 .80984 L 
  
.57451 .84385 L 
  
.51425 .8703 L 
  
.48513 .88033 L 
  
.457 .88807 L 
  
.44336 .89104 L 
  
.43004 .89341 L 
  
.42351 .89437 L 
  
.41706 .89517 L 
  
.41071 .89581 L 
  
.40757 .89608 L 
  
.40445 .8963 L 
  
.40135 .89649 L 
  
.39828 .89664 L 
  
.39523 .89674 L 
  
.39221 .89681 L 
  
.38922 .89684 L 
  
.38624 .89683 L 
  
.3833 .89678 L 
  
.38038 .89669 L 
  
.37461 .89639 L 
  
.37177 .89618 L 
  
.36896 .89593 L 
  
.36341 .89531 L 
  
.35796 .89454 L 
  
.34741 .89252 L 
  
.33731 .88986 L 
  
.32767 .88659 L 
  
.3185 .88269 L 
  
.30158 .87307 L 
  
.28657 .86107 L 
  
.27348 .84681 L 
  
.26227 .83039 L 
  
.2529 .81197 L 
  
.24528 .7917 L 
  
.24211 .78093 L 
  
.23933 .76977 L 
  
.23695 .75823 L 
  
.23494 .74635 L 
  
.23329 .73416 L 
  
.23199 .72167 L 
  
.23146 .71533 L 
  
.231 .70892 L 
  
.23063 .70245 L 
  
.23033 .69593 L 
  
.2301 .68935 L 
  
.23001 .68605 L 
  
.22994 .68273 L 
  
.22989 .6794 L 
  
Mistroke 
  
.22985 .67606 L 
  
.22983 .67271 L 
  
.22982 .66935 L 
  
.22983 .66598 L 
  
.22986 .6626 L 
  
.2299 .65921 L 
  
.22996 .65581 L 
  
.23011 .64899 L 
  
.23033 .64215 L 
  
.23091 .62839 L 
  
.23169 .61456 L 
  
.23375 .5868 L 
  
.23944 .53163 L 
  
.24634 .47828 L 
  
.26066 .38255 L 
  
.26722 .34224 L 
  
.27333 .30786 L 
  
.27935 .27965 L 
  
.28251 .26786 L 
  
.2859 .25757 L 
  
.28963 .24874 L 
  
.29381 .24131 L 
  
.29612 .23809 L 
  
.29859 .23519 L 
  
.30123 .23261 L 
  
.30407 .23033 L 
  
.3104 .22662 L 
  
.31391 .22516 L 
  
.31768 .22396 L 
  
.32172 .22301 L 
  
.32385 .22261 L 
  
.32605 .22228 L 
  
.32832 .222 L 
  
.33067 .22177 L 
  
.33187 .22167 L 
  
.33309 .22159 L 
  
.33434 .22152 L 
  
.3356 .22146 L 
  
.33688 .22142 L 
  
.33818 .22138 L 
  
.33951 .22136 L 
  
.34085 .22135 L 
  
.34221 .22135 L 
  
.3436 .22136 L 
  
.345 .22138 L 
  
.34643 .22142 L 
  
.34935 .22152 L 
  
.35235 .22166 L 
  
.35544 .22184 L 
  
.35862 .22206 L 
  
Mistroke 
  
.36525 .22261 L 
  
.37224 .22329 L 
  
.38731 .22505 L 
  
.46225 .23608 L 
  
.55773 .25204 L 
  
.6106 .26197 L 
  
.66483 .27361 L 
  
.71853 .28745 L 
  
.76967 .30407 L 
  
.8162 .32404 L 
  
.83711 .33545 L 
  
.85614 .34789 L 
  
.87306 .36139 L 
  
.88769 .376 L 
  
.89983 .39174 L 
  
.90493 .40003 L 
  
.90935 .4086 L 
  
.91309 .41745 L 
  
.91612 .42658 L 
  
.91845 .43597 L 
  
.91934 .44078 L 
  
.92005 .44564 L 
  
.92057 .45057 L 
  
.92077 .45306 L 
  
.92092 .45557 L 
  
.92102 .45809 L 
  
.92108 .46063 L 
  
.92109 .46318 L 
  
.92106 .46575 L 
  
.92098 .46833 L 
  
.92085 .47093 L 
  
.92068 .47355 L 
  
.92046 .47618 L 
  
.91988 .48148 L 
  
.91912 .48684 L 
  
.91705 .49772 L 
  
.91424 .50882 L 
  
.90643 .53159 L 
  
.89578 .55503 L 
  
.88236 .57902 L 
  
.84778 .62799 L 
  
.80399 .67712 L 
  
.69593 .76967 L 
  
Mfstroke 
  
P 
  
P 
  
P 
  
p 
  
.018 w 
  
.34163 .89109 Mdot 
  
P 
  
P 
  
% End of Graphics 
  
MathPictureEnd 
  
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004200017a000`40O003h00Oogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00
ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`003Wooi@003goo000>
Ool00`00Oomoo`1BOol00`00Oomoo`0gOol00`00Oomoo`1ROol000ioo`03001oogoo05=oo`03001o
ogoo03Eoo`03001oogoo06=oo`003Woo00<007ooOol0Dgoo00<007ooOol0=Goo00<007ooOol0Hgoo
000>Ool00`00Oomoo`1COol00`00Oomoo`0eOol00`00Oomoo`1SOol000ioo`03001oogoo05=oo`03
001oogoo03Eoo`03001oogoo06=oo`003Woo00<007ooOol0E7oo00<007ooOol0<goo00<007ooOol0
I7oo000>Ool00`00Oomoo`1DOol00`00Oomoo`0cOol00`00Oomoo`1TOol000ioo`03001oogoo05Ao
o`03001oogoo03=oo`03001oogoo06Aoo`003Woo00<007ooOol0E7oo00<007ooOol0<goo00<007oo
Ool0I7oo000>Ool00`00Oomoo`1EOol00`00Oomoo`0aOol00`00Oomoo`1UOol000ioo`03001oogoo
05Eoo`03001oogoo035oo`03001oogoo06Eoo`003Woo00<007ooOol0EGoo00<007ooOol0<Goo00<0
07ooOol0IGoo000>Ool00`00Oomoo`1EOol00`00Oomoo`0aOol00`00Oomoo`1UOol000ioo`03001o
ogoo05Ioo`03001oogoo02moo`03001oogoo06Ioo`003Woo00<007ooOol0EWoo00<007ooOol0;goo
00<007ooOol0IWoo000>Ool00`00Oomoo`1FOol00`00Oomoo`0_Ool00`00Oomoo`1VOol000ioo`03
001oogoo05Ioo`03001oogoo02moo`03001oogoo06Ioo`003Woo00<007ooOol0Egoo00<007ooOol0
;Goo00<007ooOol0Igoo000>Ool00`00Oomoo`1GOol00`00Oomoo`0]Ool00`00Oomoo`1WOol000io
o`03001oogoo05Moo`03001oogoo02eoo`03001oogoo06Moo`003Woo00<007ooOol0Egoo00<007oo
Ool0;Goo00<007ooOol0Igoo000>Ool00`00Oomoo`1HOol00`00Oomoo`0[Ool00`00Oomoo`1XOol0
00ioo`03001oogoo05Qoo`03001oogoo02]oo`03001oogoo06Qoo`003Woo00<007ooOol0F7oo00<0
07ooOol0:goo00<007ooOol0J7oo000>Ool00`00Oomoo`1HOol00`00Oomoo`0[Ool00`00Oomoo`1X
Ool000ioo`03001oogoo05Uoo`03001oogoo02Uoo`03001oogoo06Uoo`003Woo00<007ooOol0FGoo
00<007ooOol0:Goo00<007ooOol0JGoo000>Ool00`00Oomoo`1IOol00`00Oomoo`0YOol00`00Oomo
o`1YOol000ioo`03001oogoo05Uoo`03001oogoo02Uoo`03001oogoo06Uoo`003Woo00<007ooOol0
FWoo00<007ooOol09goo00<007ooOol0JWoo000>Ool00`00Oomoo`1JOol00`00Oomoo`0WOol00`00
Oomoo`1ZOol000ioo`03001oogoo05Yoo`03001oogoo02Moo`03001oogoo06Yoo`003Woo00<007oo
Ool0FWoo00<007ooOol09goo00<007ooOol0JWoo000>Ool00`00Oomoo`1KOol00`00Oomoo`0UOol0
0`00Oomoo`1[Ool000ioo`03001oogoo05]oo`03001oogoo02Eoo`03001oogoo06]oo`003Woo00<0
07ooOol0Fgoo00<007ooOol09Goo00<007ooOol0Jgoo000>Ool00`00Oomoo`1KOol00`00Oomoo`0U
Ool00`00Oomoo`1[Ool000ioo`03001oogoo05aoo`03001oogoo02=oo`03001oogoo06aoo`003Woo
00<007ooOol0G7oo00<007ooOol08goo00<007ooOol0K7oo000>Ool00`00Oomoo`1LOol00`00Oomo
o`0SOol00`00Oomoo`1/Ool000ioo`03001oogoo05aoo`03001oogoo02=oo`03001oogoo06aoo`00
3Woo00<007ooOol0GGoo00<007ooOol08Goo00<007ooOol0KGoo000>Ool00`00Oomoo`10Ool@000=
Ool00`00Oomoo`0QOol00`00Oomoo`1]Ool000ioo`03001oogoo03ioo`80011oo`L000Ioo`03001o
ogoo025oo`03001oogoo06eoo`003Woo00<007ooOol0?Goo00<007ooOol05goo2P0087oo00<007oo
Ool0KGoo000>Ool00`00Oomoo`0kOol2000QOol00`00Oomoo`08000GOol00`00Oomoo`1^Ool000io
o`03001oogoo03]oo`03001oogoo021oo`03001oogoo00Qoo`H0015oo`03001oogoo06ioo`003Woo
00<007ooOol0>Woo00<007ooOol08Goo00<007ooOol03Woo1P002goo00<007ooOol0KWoo000>Ool0
0`00Oomoo`0iOol00`00Oomoo`0ROol00`00Oomoo`0DOol60005Ool00`00Oomoo`1^Ool000ioo`03
001oogoo03Uoo`03001oogoo02=oo`03001oogoo01Uoo`H0071oo`003Woo00<007ooOol0>7oo00<0
07ooOol097oo00<007ooOol07Goo00<007oo00000`00K7oo000>Ool00`00Oomoo`0hOol00`00Oomo
o`0TOol00`00Oomoo`0MOol00`00Oomoo`03Ool4001XOol000ioo`03001oogoo03Qoo`03001oogoo
02Aoo`03001oogoo01eoo`03001oogoo00Moo`D006=oo`003Woo00<007ooOol0=goo00<007ooOol0
9Woo00<007ooOol06goo00<007ooOol03Goo1000Ggoo000>Ool00`00Oomoo`0gOol00`00Oomoo`0V
Ool00`00Oomoo`0KOol00`00Oomoo`0AOol5001JOol000ioo`03001oogoo03Moo`03001oogoo02Io
o`03001oogoo01]oo`03001oogoo01Ioo`@005Ioo`003Woo00<007ooOol0=Woo00<007ooOol09goo
00<007ooOol06Woo00<007ooOol06goo1000DWoo000>Ool00`00Oomoo`0fOol00`00Oomoo`0XOol0
0`00Oomoo`0IOol00`00Oomoo`0OOol3001?Ool000ioo`03001oogoo03Ioo`03001oogoo02Qoo`03
001oogoo01Uoo`03001oogoo029oo`@004]oo`003Woo00<007ooOol0=Woo00<007ooOol0:7oo00<0
07ooOol06Goo00<007ooOol09Woo0`00B7oo000>Ool00`00Oomoo`0fOol00`00Oomoo`0YOol00`00
Oomoo`0GOol00`00Oomoo`0ZOol30015Ool000ioo`03001oogoo03Eoo`03001oogoo02Yoo`03001o
ogoo01Moo`03001oogoo02eoo`@0045oo`003Woo00<007ooOol0=Goo00<007ooOol0:Woo00<007oo
Ool05goo00<007ooOol0<Goo0`00?Woo000>Ool00`00Oomoo`0eOol00`00Oomoo`0ZOol00`00Oomo
o`0GOol00`00Oomoo`0dOol3000kOol000ioo`03001oogoo03Eoo`03001oogoo02]oo`03001oogoo
01Eoo`03001oogoo03Qoo`8003Uoo`003Woo00<007ooOol0=Goo00<007ooOol0:goo00<007ooOol0
5Goo00<007ooOol0>Woo0P00=goo000>Ool00`00Oomoo`0eOol00`00Oomoo`0[Ool00`00Oomoo`0E
Ool00`00Oomoo`0lOol3000dOol000ioo`03001oogoo03Aoo`03001oogoo02aoo`03001oogoo01Eo
o`03001oogoo03moo`80039oo`003Woo00<007ooOol0=7oo00<007ooOol0;Goo00<007ooOol04goo
00<007ooOol0@Woo0P00<7oo000>Ool00`00Oomoo`0dOol00`00Oomoo`0]Ool00`00Oomoo`0COol0
0`00Oomoo`14Ool2000^Ool000ioo`03001oogoo03Aoo`03001oogoo02eoo`03001oogoo01=oo`03
001oogoo04Ioo`8002aoo`003Woo00<007ooOol0<goo00<007ooOol0;Woo00<007ooOol04goo00<0
07ooOol0B7oo0P00:Woo000>Ool00`00Oomoo`0cOol00`00Oomoo`0_Ool00`00Oomoo`0AOol00`00
Oomoo`1;Ool2000XOol000ioo`03001oogoo03=oo`03001oogoo02moo`03001oogoo015oo`03001o
ogoo04eoo`8002Ioo`003Woo00<007ooOol0<goo00<007ooOol0;goo00<007ooOol04Goo00<007oo
Ool0Cgoo00<007ooOol08goo000>Ool00`00Oomoo`0cOol00`00Oomoo`0_Ool00`00Oomoo`0AOol0
0`00Oomoo`1@Ool00`00Oomoo`0ROol000ioo`03001oogoo039oo`03001oogoo035oo`04001oogoo
Ool;0003Ool00`00Oomoo`1BOol00`00Oomoo`0QOol000ioo`03001oogoo039oo`03001oogoo031o
o`D000]oo`D005Aoo`03001oogoo021oo`003Woo00<007ooOol0<Woo00<007ooOol0;Woo0P0000=o
o`00Ool047oo00@007oo000005=oo`03001oogoo01moo`003Woo00<007ooOol0<Woo00<007ooOol0
:goo0`000goo00<007ooOol03goo00@007ooOomoo`<0055oo`03001oogoo01ioo`003Woo00<007oo
Ool0<Woo00<007ooOol0:Goo0P001goo00<007ooOol03Goo00<007ooOol01Goo0P00D7oo0P007Woo
000>Ool00`00Oomoo`0aOol00`00Oomoo`0XOol20009Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool2
001@Ool00`00Oomoo`0KOol000ioo`03001oogoo035oo`03001oogoo02Moo`03001oogoo00Uoo`03
001oogoo00eoo`03001oogoo00Uoo`03001oogoo04ioo`03001oogoo01Yoo`003Woo00<007ooOol0
<Goo00<007ooOol09Goo0P0037oo00<007ooOol03Goo00<007ooOol02Woo0P00CWoo00<007ooOol0
6Woo000>Ool00`00Oomoo`0aOol00`00Oomoo`0SOol2000?Ool00`00Oomoo`0;Ool00`00Oomoo`0=
Ool00`00Oomoo`1<Ool00`00Oomoo`0IOol000ioo`03001oogoo035oo`03001oogoo029oo`03001o
ogoo00moo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo04aoo`03001oogoo01Qoo`003Woo
00<007ooOol0<Goo00<007ooOol08Goo00<007ooOol047oo00<007ooOol02goo00<007ooOol03goo
00<007ooOol0Bgoo00<007ooOol067oo000>Ool00`00Oomoo`0aOol00`00Oomoo`0QOol00`00Oomo
o`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`1;Ool00`00Oomoo`0GOol000ioo`03
001oogoo031oo`03001oogoo025oo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo019oo`03
001oogoo04Yoo`03001oogoo01Moo`003Woo00<007ooOol0<7oo00<007ooOol087oo00<007ooOol0
4goo00<007ooOol02Goo00<007ooOol04goo00<007ooOol0BGoo00<007ooOol05goo000>Ool00`00
Oomoo`0`Ool00`00Oomoo`0OOol00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0DOol00`00
Oomoo`19Ool00`00Oomoo`0FOol000ioo`03001oogoo031oo`03001oogoo01ioo`03001oogoo01Eo
o`03001oogoo00Uoo`03001oogoo01Eoo`03001oogoo04Qoo`03001oogoo01Ioo`003Woo00<007oo
Ool0<7oo00<007ooOol07Goo00<007ooOol05goo00<007ooOol01goo00<007ooOol05goo00<007oo
Ool0B7oo00<007ooOol05Goo000>Ool00`00Oomoo`0`Ool00`00Oomoo`0LOol00`00Oomoo`0HOol0
0`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomoo`18Ool00`00Oomoo`0EOol000ioo`03001oogoo
031oo`03001oogoo01aoo`03001oogoo01Qoo`03001oogoo00Moo`03001oogoo01Qoo`03001oogoo
04Qoo`03001oogoo01Aoo`003Woo00<007ooOol0<7oo00<007ooOol06goo00<007ooOol06Goo00<0
07ooOol01goo00<007ooOol06Goo00<007ooOol0Agoo00<007ooOol057oo000>Ool00`00Oomoo`0_
Ool00`00Oomoo`0LOol00`00Oomoo`0JOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`18
Ool00`00Oomoo`0COol000ioo`03001oogoo02moo`03001oogoo01aoo`03001oogoo01Yoo`03001o
ogoo00Eoo`03001oogoo01Yoo`03001oogoo04Qoo`03001oogoo01=oo`003Woo00<007ooOol0;goo
00<007ooOol06goo00<007ooOol06goo00<007ooOol01Goo00<007ooOol06Woo00<007ooOol0B7oo
00<007ooOol04goo000>Ool00`00Oomoo`0_Ool00`00Oomoo`0KOol00`00Oomoo`0KOol00`00Oomo
o`05Ool00`00Oomoo`0KOol00`00Oomoo`17Ool00`00Oomoo`0COol000ioo`03001oogoo02moo`03
001oogoo01Yoo`03001oogoo01eoo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo04Moo`03
001oogoo01=oo`003Woo00<007ooOol0;goo00<007ooOol06Woo00<007ooOol07Goo00<007ooOol0
0goo00<007ooOol07Goo00<007ooOol0AWoo00<007ooOol04goo000>Ool00`00Oomoo`0_Ool00`00
Oomoo`0JOol00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`16Ool00`00
Oomoo`0COol000ioo`03001oogoo02moo`03001oogoo01Uoo`03001oogoo01ioo`03001oogoo00=o
o`03001oogoo01eoo`03001oogoo04Ioo`03001oogoo01=oo`003Woo00<007ooOol0;Woo00<007oo
Ool06Woo00<007ooOol07goo00D007ooOomoo`00025oo`03001oogoo04Eoo`03001oogoo01=oo`00
3Woo00<007ooOol0;Woo00<007ooOol06Woo00<007ooOol07goo00D007ooOomoo`00025oo`03001o
ogoo04Eoo`03001oogoo01=oo`003Woo00<007ooOol0;Woo00<007ooOol06Woo00<007ooOol07goo
00D007ooOomoo`00025oo`03001oogoo04Eoo`03001oogoo01=oo`003Woo00<007ooOol0;Woo00<0
07ooOol06Goo00<007ooOol087oo00D007ooOomoo`00025oo`03001oogoo04Eoo`03001oogoo01=o
o`003Woo00<007ooOol0;Woo00<007ooOol06Goo00<007ooOol08Goo00<007oo00008goo00<007oo
Ool0A7oo00<007ooOol04goo000>Ool00`00Oomoo`0^Ool00`00Oomoo`0IOol00`00Oomoo`0QOol0
0`00Ool0000SOol00`00Oomoo`14Ool00`00Oomoo`0COol000ioo`03001oogoo02ioo`03001oogoo
01Uoo`03001oogoo025oo`03001oo`0002=oo`03001oogoo04Aoo`03001oogoo01=oo`003Woo00<0
07ooOol0;Woo00<007ooOol06Goo00<007ooOol08Goo00<007oo00008goo00<007ooOol0A7oo00<0
07ooOol04goo000>Ool00`00Oomoo`0]Ool00`00Oomoo`0JOol00`00Oomoo`0ROol00`00Oomoo`0R
Ool00`00Oomoo`13Ool00`00Oomoo`0DOol000ioo`03001oogoo02eoo`03001oogoo01Yoo`03001o
ogoo029oo`03001oogoo029oo`03001oogoo04=oo`03001oogoo01Aoo`003Woo00<007ooOol0;Goo
00<007ooOol06Woo00<007ooOol0Agoo00<007ooOol0@Woo00<007ooOol05Goo000>Ool00`00Oomo
o`0]Ool00`00Oomoo`0JOol00`00Oomoo`17Ool00`00Oomoo`12Ool00`00Oomoo`0EOol000ioo`03
001oogoo02eoo`03001oogoo01Yoo`03001oogoo04Moo`03001oogoo049oo`03001oogoo01Eoo`00
3Woo00<007ooOol0;Goo00<007ooOol06Woo00<007ooOol0Agoo00<007ooOol0@Goo00<007ooOol0
5Woo000>Ool00`00Oomoo`0/Ool00`00Oomoo`0KOol00`00Oomoo`17Ool00`00Oomoo`11Ool00`00
Oomoo`0FOol000ioo`03001oogoo02aoo`03001oogoo01]oo`03001oogoo04Moo`03001oogoo045o
o`03001oogoo01Ioo`003Woo00<007ooOol0;7oo00<007ooOol06goo00<007ooOol0AWoo00<007oo
Ool0@Goo00<007ooOol05goo000>Ool00`00Oomoo`0/Ool00`00Oomoo`0LOol00`00Oomoo`15Ool0
0`00Oomoo`11Ool00`00Oomoo`0GOol000ioo`03001oogoo02aoo`03001oogoo01aoo`03001oogoo
04Eoo`03001oogoo045oo`03001oogoo01Moo`003Woo00<007ooOol0;7oo00<007ooOol077oo00<0
07ooOol0A7oo00<007ooOol0@Goo00<007ooOol067oo000>Ool00`00Oomoo`0/Ool00`00Oomoo`0M
Ool00`00Oomoo`13Ool00`00Oomoo`11Ool00`00Oomoo`0HOol000ioo`03001oogoo02aoo`03001o
ogoo01eoo`03001oogoo04=oo`03001oogoo045oo`03001oogoo01Qoo`003Woo00<007ooOol0;7oo
00<007ooOol07Goo00<007ooOol0@goo00<007ooOol0@7oo00<007ooOol06Goo000>Ool00`00Oomo
o`0/Ool00`00Oomoo`0MOol00`00Oomoo`12Ool00`00Oomoo`11Ool00`00Oomoo`0IOol000ioo`03
001oogoo02aoo`03001oogoo01ioo`03001oogoo045oo`03001oogoo041oo`03001oogoo01Yoo`00
3Woo00<007ooOol0:goo00<007ooOol087oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol0
6Woo000>Ool00`00Oomoo`0[Ool00`00Oomoo`0POol00`00Oomoo`0oOol00`00Oomoo`10Ool00`00
Oomoo`0KOol000ioo`03001oogoo02]oo`03001oogoo021oo`03001oogoo03moo`03001oogoo041o
o`03001oogoo01]oo`003Woo00<007ooOol0:goo00<007ooOol087oo00<007ooOol0?Woo00<007oo
Ool0@7oo00<007ooOol077oo000>Ool00`00Oomoo`0[Ool00`00Oomoo`0QOol00`00Oomoo`0mOol0
0`00Oomoo`10Ool00`00Oomoo`0LOol000ioo`03001oogoo02]oo`03001oogoo029oo`03001oogoo
03]oo`03001oogoo041oo`03001oogoo01eoo`003Woo00<007ooOol0:goo00<007ooOol08Woo00<0
07ooOol0>Woo00<007ooOol0@7oo00<007ooOol07Woo000>Ool00`00Oomoo`0[Ool00`00Oomoo`0S
Ool00`00Oomoo`0hOol00`00Oomoo`10Ool00`00Oomoo`0OOol000ioo`03001oogoo02]oo`03001o
ogoo02Aoo`8003Moo`03001oogoo045oo`03001oogoo01moo`003Woo00<007ooOol0:goo00<007oo
Ool09Woo00<007ooOol0<goo00<007ooOol0@Goo00<007ooOol087oo000>Ool00`00Oomoo`0[Ool0
0`00Oomoo`0WOol00`00Oomoo`0bOol00`00Oomoo`10Ool00`00Oomoo`0QOol000ioo`03001oogoo
02Yoo`03001oogoo02Qoo`03001oogoo035oo`03001oogoo041oo`03001oogoo029oo`003Woo00<0
07ooOol0:Woo00<007ooOol0:Goo00<007ooOol0;Woo0P00@goo00<007ooOol08Woo000>Ool00`00
Oomoo`0ZOol00`00Oomoo`0ZOol2000]Ool00`00Oomoo`12Ool00`00Oomoo`0SOol000ioo`03001o
ogoo02Yoo`03001oogoo02aoo`03001oogoo02Qoo`8004Aoo`03001oogoo02Aoo`003Woo00<007oo
Ool0:Woo00<007ooOol0;Goo0P009goo00<007ooOol0@goo00<007ooOol09Goo000>Ool00`00Oomo
o`0ZOol00`00Oomoo`0_Ool00`00Oomoo`0SOol00`00Oomoo`14Ool00`00Oomoo`0UOol000ioo`03
001oogoo02Yoo`03001oogoo031oo`80025oo`8004Ioo`03001oogoo02Ioo`003Woo00<007ooOol0
:Woo00<007ooOol0<Woo0P007Goo0P00Agoo00<007ooOol09goo000>Ool00`00Oomoo`0ZOol00`00
Oomoo`0dOol3000GOol30018Ool00`00Oomoo`0XOol000ioo`03001oogoo02Yoo`03001oogoo03Mo
o`@000moo`@004Yoo`03001oogoo02Uoo`003Woo00<007ooOol0:Woo00<007ooOol0>goo3`00CWoo
00<007ooOol0:Goo000>Ool00`00Oomoo`0ZOol00`00Oomoo`2GOol00`00Oomoo`0ZOol000ioo`03
001oogoo02Yoo`03001oogoo09Ioo`03001oogoo02]oo`003Woo00<007ooOol0:Woo00<007ooOol0
UGoo00<007ooOol0;7oo000>Ool00`00Oomoo`0ZOol00`00Oomoo`2DOol00`00Oomoo`0]Ool000io
o`03001oogoo02Yoo`03001oogoo09=oo`03001oogoo02ioo`003Woo00<007ooOol0:Woo00<007oo
Ool0Tgoo00<007ooOol0;Woo000>Ool00`00Oomoo`0ZOol00`00Oomoo`2BOol00`00Oomoo`0_Ool0
00ioo`03001oogoo02Yoo`03001oogoo095oo`03001oogoo031oo`003Woo00<007ooOol0:Woo00<0
07ooOol0T7oo00<007ooOol0<Goo000>Ool00`00Oomoo`0ZOol00`00Oomoo`2?Ool00`00Oomoo`0b
Ool000ioo`03001oogoo02Yoo`03001oogoo08ioo`03001oogoo03=oo`003Woo00<007ooOol0:Woo
00<007ooOol0S7oo0P00=Woo000>Ool00`00Oomoo`0ZOol00`00Oomoo`2;Ool00`00Oomoo`0fOol0
00ioo`03001oogoo02Yoo`03001oogoo08Yoo`03001oogoo03Moo`003Woo00<007ooOol0:Woo00<0
07ooOol0RGoo00<007ooOol0>7oo000>Ool00`00Oomoo`0ZOol00`00Oomoo`28Ool00`00Oomoo`0i
Ool000ioo`03001oogoo02Yoo`03001oogoo08Moo`03001oogoo03Yoo`003Woo00<007ooOol0:Woo
00<007ooOol0QGoo0P00?Goo000>Ool00`00Oomoo`0ZOol00`00Oomoo`24Ool00`00Oomoo`0mOol0
00ioo`03001oogoo02Yoo`03001oogoo08=oo`03001oogoo03ioo`003Woo00<007ooOol0:Woo00<0
07ooOol0PWoo00<007ooOol0?goo000>Ool00`00Oomoo`0ZOol00`00Oomoo`21Ool00`00Oomoo`10
Ool000ioo`03001oogoo02Yoo`03001oogoo081oo`03001oogoo045oo`003Woo00<007ooOol0:Woo
00<007ooOol0OWoo0P00A7oo000>Ool00`00Oomoo`0ZOol00`00Oomoo`1mOol00`00Oomoo`14Ool0
00ioo`03001oogoo02]oo`03001oogoo07]oo`03001oogoo04Eoo`003Woo00<007ooOol0:goo00<0
07ooOol0NWoo00<007ooOol0AWoo000>Ool00`00Oomoo`0[Ool00`00Oomoo`1iOol00`00Oomoo`17
Ool000ioo`03001oogoo02]oo`03001oogoo07Qoo`03001oogoo04Qoo`003Woo00<007ooOol0:goo
00<007ooOol0MWoo0P00Bgoo000>Ool00`00Oomoo`0[Ool00`00Oomoo`1eOol00`00Oomoo`1;Ool0
00ioo`03001oogoo02aoo`03001oogoo07=oo`03001oogoo04aoo`003Woo00<007ooOol0;7oo00<0
07ooOol0LWoo00<007ooOol0CGoo000>Ool00`00Oomoo`0/Ool00`00Oomoo`1`Ool2001@Ool000io
o`03001oogoo02eoo`03001oogoo06ioo`03001oogoo051oo`003Woo00<007ooOol0;Goo00<007oo
Ool0K7oo0P00Dgoo000>Ool00`00Oomoo`0^Ool00`00Oomoo`1ZOol00`00Oomoo`1COol000ioo`03
001oogoo02ioo`03001oogoo06Qoo`8005Ioo`003Woo00<007ooOol0;Woo00<007ooOol0Igoo00<0
07ooOol0EWoo000>Ool00`00Oomoo`0^Ool00`00Oomoo`1UOol2001IOol000ioo`03001oogoo02mo
o`03001oogoo06=oo`03001oogoo05Uoo`003Woo00<007ooOol0;goo00<007ooOol0HGoo0P00G7oo
000>Ool00`00Oomoo`0_Ool00`00Oomoo`1POol00`00Oomoo`1LOol000ioo`03001oogoo031oo`03
001oogoo05eoo`8005moo`003Woo00<007ooOol0<7oo00<007ooOol0Fgoo0P00HGoo000>Ool00`00
Oomoo`0aOol00`00Oomoo`1HOol2001SOol000ioo`03001oogoo035oo`03001oogoo05Moo`03001o
ogoo06=oo`003Woo00<007ooOol0<Woo00<007ooOol0E7oo0P00IWoo000>Ool00`00Oomoo`0cOol0
0`00Oomoo`1AOol2001XOol000ioo`03001oogoo03=oo`03001oogoo04moo`8006Yoo`003Woo00<0
07ooOol0=7oo00<007ooOol0C7oo0P00K7oo000>Ool00`00Oomoo`0eOol00`00Oomoo`19Ool2001^
Ool000ioo`03001oogoo03Ioo`03001oogoo04Ioo`80071oo`003Woo00<007ooOol0=Woo00<007oo
Ool0@goo0`00LWoo000>Ool00`00Oomoo`0ROol201lCOol00`00Oomoo`10Ool2001eOol000ioo`03
001oogoo02=oo`D07a1oo`03001oogoo03aoo`<007Moo`003Woo00<007ooOol097oo200O3Goo00<0
07ooOol0>Goo0P00NWoo000>Ool00`00Oomoo`0UOol;01l:Ool2000fOol3001lOol000ioo`03001o
ogoo02Ioo`d07`Uoo`03001oogoo035oo`8007moo`003Woo00<007ooOol09goo400O1Woo00<007oo
Ool0;Goo0`00PGoo000>Ool00`00Oomoo`0XOolC01l3Ool2000ZOol30024Ool000ioo`03001oogoo
02YooaD07`03Ool0000002Aoo`@008Moo`003Woo00<007ooOol0:goo5`0O1@0077oo0`00Rgoo000>
Ool00`00Oomoo`0/OolI01l01000Ool0000057oo1P00SWoo000>Ool00`00Oomoo`0]OolG01l30002
01lD002DOol000ioo`03001oogoo02iooaL07`0300007`0O00H07j=oo`003Woo00<007ooOol0;goo
8`0OWgoo000>Ool00`00Oomoo`0`OolU01nLOol000ioo`03001oogoo039oobL07iQoo`003Woo00<0
07ooOol0<goo:P0OU7oo000>Ool00`00Oomoo`0dOol]01n@Ool000ioo`03001oogoo03Eoobl07heo
o`003Woo00<007ooOol0=Woo<P0ORGoo000>Ool00`00Oomoo`0gOole01n5Ool000ioo`03001oogoo
00Uoo`D07bYoocP07h5oo`003Woo00<007ooOol02Goo2@0O:7oo>@0OOWoo000>Ool<000<01lVOoll
01mjOol001Yooa007b=oocl07gIoo`006Woo500O87oo@P0OLWoo000NOolC01lNOom501m^Ool0029o
oa<07a]oodL07f]oo`009Goo500O67ooBP0OIgoo000YOolD01lFOom<01mSOol002eooa<07aAoodl0
7emoo`00<7oo500O4GooD@0OG7oo000dOolD01l>OomD01mHOol003Qooa@07`]ooeL07eAoo`00?7oo
4`0O2GooFP0OD7oo000oOolD01l6OomM01m<Ool004=ooa@07`Aooeh07dUoo`00Agoo500O00=oo`0O
01l0G`0OAGoo001;Oomf01m1Ool004ioogL07ceoo`00DWooMP0O>Woo001FOomf01lfOol005YoogH0
7c9oo`00GGooM`0O;Woo001QOomf01l[Ool006Eoofh07bmoo`00JGooI@0O=7oo001/OomM01liOol0
071ooe@07cioo`00M7ooB`0O@goo001gOom301m8Ool007]oo`D07`9ooc@07daoo`00QWoo:`0ODGoo
002:OolR01mFOol008eooaX07e]oo`00TGoo4@0OH7oo002EOol801mUOol00?moo`=oo`00ogoo0goo
003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?mo
o`=oo`00\
\>"],
  ImageRangeCache->{{{0, 257}, {286, 0}} -> {-4.50005, -4.50784, 0.0350198, 
  0.0350198}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.30."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[.30] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.3`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 1.88495559215387586`\), ",", 
        RowBox[{"X3", "\[Rule]", 
          RowBox[{"-", 
            StyleBox["3.5`",
              StyleBoxAutoDelete->True,
              PrintPrecision->2]}]}], ",", \(Y3 \[Rule] 4.`\), ",", 
        \(Th3 \[Rule] 0.0476970832430333668`\), ",", 
        \(alpha \[Rule] \(-0.391270425730651183`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the cam-follower mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.30."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
  
%%Creator: Mathematica 
  
%%AspectRatio: 1.11111  
  
MathPictureStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
0.5 0.111111 0.5 0.111111 [ 
  
[ 0 0 0 0 ] 
  
[ 1 1.11111 0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
0 g 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 1.11111 L 
  
0 1.11111 L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
.004 w 
  
.11111 .94444 m 
  
.05556 .94444 L 
  
.05556 .05556 L 
  
.94444 .05556 L 
  
.61111 .05556 L 
  
.5 .5 L 
  
.38889 .05556 L 
  
s 
  
.015 w 
  
.5 .5 Mdot 
  
.11111 .94444 Mdot 
  
.004 w 
  
newpath 
  
.5 .5 .14444 0 365.73 arc 
  
s 
  
P 
  
p 
  
p 
  
.015 w 
  
.11111 .94444 Mdot 
  
.1719 .83611 Mdot 
  
.83781 .86789 Mdot 
  
P 
  
0 0 1 r 
  
p 
  
.02 w 
  
.11111 .94444 m 
  
.49956 .96299 L 
  
s 
  
P 
  
p 
  
.38857 .95769 m 
  
.61054 .96828 L 
  
.83781 .86789 L 
  
.1719 .83611 L 
  
F 
  
P 
  
P 
  
p 
  
p 
  
p 
  
.004 w 
  
.39699 .81702 m 
  
.32915 .79198 L 
  
.26562 .76239 L 
  
.2088 .72919 L 
  
.16077 .69331 L 
  
.12322 .65564 L 
  
.10876 .63639 L 
  
.09732 .61699 L 
  
.08897 .59754 L 
  
.08595 .58781 L 
  
.08474 .58296 L 
  
.08371 .5781 L 
  
.08288 .57326 L 
  
.08254 .57083 L 
  
.08225 .56842 L 
  
.082 .566 L 
  
.08181 .56358 L 
  
.08165 .56117 L 
  
.08155 .55876 L 
  
.0815 .55635 L 
  
.08149 .55394 L 
  
.08153 .55154 L 
  
.08162 .54914 L 
  
.08175 .54674 L 
  
.08193 .54435 L 
  
.08244 .53957 L 
  
.08312 .5348 L 
  
.08399 .53005 L 
  
.08628 .52059 L 
  
.08928 .5112 L 
  
.09297 .50187 L 
  
.10237 .48346 L 
  
.11429 .46539 L 
  
.1449 .43037 L 
  
.18298 .39699 L 
  
.27328 .33562 L 
  
.36847 .28202 L 
  
.45434 .23733 L 
  
.52221 .20369 L 
  
.54857 .19197 L 
  
.55997 .1876 L 
  
.57028 .18429 L 
  
.57507 .18306 L 
  
.57962 .18212 L 
  
.58181 .18176 L 
  
.58396 .18147 L 
  
.58501 .18136 L 
  
.58605 .18127 L 
  
.58708 .18119 L 
  
.5881 .18113 L 
  
Mistroke 
  
.5891 .1811 L 
  
.5901 .18108 L 
  
.59108 .18109 L 
  
.59205 .18111 L 
  
.59301 .18115 L 
  
.59397 .18122 L 
  
.59491 .1813 L 
  
.59584 .1814 L 
  
.59768 .18167 L 
  
.59949 .18203 L 
  
.60301 .18298 L 
  
.60641 .18428 L 
  
.60973 .18592 L 
  
.61615 .19025 L 
  
.62243 .19603 L 
  
.62871 .20328 L 
  
.6562 .24722 L 
  
.69133 .31433 L 
  
.73453 .40096 L 
  
.78004 .50028 L 
  
.8004 .55186 L 
  
.80928 .57757 L 
  
.81702 .60301 L 
  
.8234 .628 L 
  
.82601 .64028 L 
  
.82821 .65239 L 
  
.82997 .66431 L 
  
.83127 .67601 L 
  
.83174 .68178 L 
  
.83193 .68464 L 
  
.83209 .68749 L 
  
.83221 .69032 L 
  
.8323 .69313 L 
  
.83236 .69593 L 
  
.83239 .69871 L 
  
.83239 .70148 L 
  
.83235 .70423 L 
  
.83228 .70696 L 
  
.83218 .70967 L 
  
.83186 .71504 L 
  
.83166 .7177 L 
  
.83141 .72034 L 
  
.83009 .73071 L 
  
.82921 .73578 L 
  
.82819 .74076 L 
  
.8257 .75047 L 
  
.8226 .75984 L 
  
.81889 .76883 L 
  
.81456 .77745 L 
  
.80399 .79349 L 
  
Mistroke 
  
.79087 .80787 L 
  
.7752 .82051 L 
  
.757 .83134 L 
  
.73635 .84031 L 
  
.72513 .84408 L 
  
.71334 .84738 L 
  
.70099 .8502 L 
  
.68811 .85254 L 
  
.67471 .8544 L 
  
.66782 .85515 L 
  
.66082 .85578 L 
  
.6537 .8563 L 
  
.65009 .85651 L 
  
.64646 .85669 L 
  
.6428 .85684 L 
  
.63912 .85697 L 
  
.63541 .85706 L 
  
.63167 .85712 L 
  
.6279 .85716 L 
  
.62411 .85716 L 
  
.6203 .85714 L 
  
.61646 .85709 L 
  
.6126 .857 L 
  
.60871 .85689 L 
  
.60088 .85658 L 
  
.59295 .85616 L 
  
.58494 .85562 L 
  
.56869 .85421 L 
  
.55216 .85234 L 
  
.53539 .85004 L 
  
.50126 .84416 L 
  
.4666 .83664 L 
  
.39699 .81702 L 
  
Mfstroke 
  
P 
  
P 
  
P 
  
p 
  
.018 w 
  
.60019 .85655 Mdot 
  
P 
  
P 
  
% End of Graphics 
  
MathPictureEnd 
  
 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004200017a000`40O003h00Oogoo0goo003oOol3
Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00
ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`003Wooi@003goo000>
Ool00`00Oomoo`1BOol00`00Oomoo`0gOol00`00Oomoo`1ROol000ioo`03001oogoo05=oo`03001o
ogoo03Eoo`03001oogoo06=oo`003Woo00<007ooOol0Dgoo00<007ooOol0=Goo00<007ooOol0Hgoo
000>Ool00`00Oomoo`1COol00`00Oomoo`0eOol00`00Oomoo`1SOol000ioo`03001oogoo05=oo`03
001oogoo03Eoo`03001oogoo06=oo`003Woo00<007ooOol0E7oo00<007ooOol0<goo00<007ooOol0
I7oo000>Ool00`00Oomoo`1DOol00`00Oomoo`0cOol00`00Oomoo`1TOol000ioo`03001oogoo05Ao
o`03001oogoo03=oo`03001oogoo06Aoo`003Woo00<007ooOol0E7oo00<007ooOol0<goo00<007oo
Ool0I7oo000>Ool00`00Oomoo`1EOol00`00Oomoo`0aOol00`00Oomoo`1UOol000ioo`03001oogoo
05Eoo`03001oogoo035oo`03001oogoo06Eoo`003Woo00<007ooOol0EGoo00<007ooOol0<Goo00<0
07ooOol0IGoo000>Ool00`00Oomoo`1EOol00`00Oomoo`0aOol00`00Oomoo`1UOol000ioo`03001o
ogoo05Ioo`03001oogoo02moo`03001oogoo06Ioo`003Woo00<007ooOol0EWoo00<007ooOol0;goo
00<007ooOol0IWoo000>Ool00`00Oomoo`1FOol00`00Oomoo`0_Ool00`00Oomoo`1VOol000ioo`03
001oogoo05Ioo`03001oogoo02moo`03001oogoo06Ioo`003Woo00<007ooOol0Egoo00<007ooOol0
;Goo00<007ooOol0Igoo000>Ool00`00Oomoo`1GOol00`00Oomoo`0]Ool00`00Oomoo`1WOol000io
o`03001oogoo05Moo`03001oogoo02eoo`03001oogoo06Moo`003Woo00<007ooOol0Egoo00<007oo
Ool0;Goo00<007ooOol0Igoo000>Ool00`00Oomoo`1HOol00`00Oomoo`0[Ool00`00Oomoo`1XOol0
00ioo`03001oogoo05Qoo`03001oogoo02]oo`03001oogoo06Qoo`003Woo00<007ooOol0F7oo00<0
07ooOol0:goo00<007ooOol0J7oo000>Ool00`00Oomoo`1HOol00`00Oomoo`0[Ool00`00Oomoo`1X
Ool000ioo`03001oogoo05Uoo`03001oogoo02Uoo`03001oogoo06Uoo`003Woo00<007ooOol0FGoo
00<007ooOol0:Goo00<007ooOol0JGoo000>Ool00`00Oomoo`1IOol00`00Oomoo`0YOol00`00Oomo
o`1YOol000ioo`03001oogoo05Uoo`03001oogoo02Uoo`03001oogoo06Uoo`003Woo00<007ooOol0
FWoo00<007ooOol09goo00<007ooOol0JWoo000>Ool00`00Oomoo`1JOol00`00Oomoo`0WOol00`00
Oomoo`1ZOol000ioo`03001oogoo05Yoo`03001oogoo02Moo`D006Qoo`003Woo00<007ooOol0FWoo
00<007ooOol08goo1@0017oo0P00IWoo000>Ool00`00Oomoo`1KOol00`00Oomoo`0OOol30003Ool0
0`00Oomoo`05Ool00`00Oomoo`1SOol000ioo`03001oogoo05]oo`03001oogoo01eoo`8000Ioo`03
001oogoo00Ioo`8006=oo`003Woo00<007ooOol0Fgoo00<007ooOol06goo0P0027oo00<007ooOol0
27oo00<007ooOol0H7oo000>Ool00`00Oomoo`1KOol00`00Oomoo`0IOol2000:Ool00`00Oomoo`09
Ool00`00Oomoo`1OOol000ioo`03001oogoo05aoo`03001oogoo01Ioo`8000]oo`03001oogoo00]o
o`03001oogoo05ioo`003Woo00<007ooOol0G7oo00<007ooOol057oo0P003Goo00<007ooOol037oo
00<007ooOol0GGoo000>Ool00`00Oomoo`1LOol00`00Oomoo`0BOol2000?Ool00`00Oomoo`0<Ool0
0`00Oomoo`1MOol000ioo`03001oogoo05aoo`03001oogoo011oo`80015oo`03001oogoo00eoo`03
001oogoo05aoo`003Woo00<007ooOol0GGoo00<007ooOol03Goo0P004Woo00<007ooOol03goo00<0
07ooOol0Fgoo000>Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool2000DOol00`00Oomoo`0?Ool00`00
Oomoo`1KOol000ioo`03001oogoo05eoo`03001oogoo00Uoo`8001Ioo`03001oogoo011oo`03001o
ogoo05Yoo`003Woo00<007ooOol0GGoo00<007ooOol01goo0P0067oo00<007ooOol047oo00<007oo
Ool0FWoo000>Ool00`00Oomoo`1NOol00`00Oomoo`04Ool2000IOol00`00Oomoo`0BOol00`00Oomo
o`1IOol000ioo`03001oogoo05ioo`03001oogoo009oo`8001]oo`03001oogoo01=oo`03001oogoo
05Qoo`003Woo00<007ooOol0GWoo00<007ooOol00P007Goo00<007ooOol04goo00<007ooOol0F7oo
000>Ool00`00Oomoo`1NOol3000OOol00`00Oomoo`0DOol00`00Oomoo`1GOol000ioo`03001oogoo
05eoo`<001moo`03001oogoo01Eoo`03001oogoo05Moo`003Woo00<007ooOol0Fgoo0P000Woo00<0
07ooOol07Goo00<007ooOol05Woo00<007ooOol0EWoo000>Ool00`00Oomoo`1IOol20004Ool00`00
Oomoo`0MOol00`00Oomoo`0FOol00`00Oomoo`1FOol000ioo`03001oogoo05Moo`8000Ioo`03001o
ogoo01eoo`03001oogoo01Moo`03001oogoo05Eoo`003Woo00<007ooOol0EGoo0P002Goo00<007oo
Ool06goo00<007ooOol067oo00<007ooOol0EGoo000>Ool00`00Oomoo`1COol2000;Ool00`00Oomo
o`0KOol00`00Oomoo`0IOol00`00Oomoo`1DOol000ioo`03001oogoo055oo`8000eoo`03001oogoo
01]oo`03001oogoo01Uoo`03001oogoo05Aoo`003Woo00<007ooOol0Cgoo0P003goo00<007ooOol0
6Woo00<007ooOol06goo00<007ooOol0Dgoo000>Ool00`00Oomoo`1=Ool2000BOol00`00Oomoo`0I
Ool00`00Oomoo`0KOol00`00Oomoo`1COol000ioo`03001oogoo04]oo`8001Aoo`03001oogoo01Uo
o`03001oogoo01aoo`03001oogoo059oo`003Woo00<007ooOol0BGoo0P005Woo00<007ooOol06Goo
00<007ooOol077oo00<007ooOol0DWoo000>Ool00`00Oomoo`18Ool00`00Oomoo`0GOol00`00Oomo
o`0GOol00`00Oomoo`0NOol00`00Oomoo`1AOol000ioo`03001oogoo04Ioo`8001Yoo`03001oogoo
01Moo`03001oogoo01ioo`03001oogoo055oo`003Woo00<007ooOol0A7oo0P0077oo00<007ooOol0
5goo00<007ooOol07goo00<007ooOol0D7oo000>Ool00`00Oomoo`12Ool2000NOol00`00Oomoo`0G
Ool00`00Oomoo`0OOol00`00Oomoo`1@Ool000ioo`03001oogoo045oo`03001oogoo01moo`03001o
ogoo01Eoo`03001oogoo025oo`03001oogoo04moo`003Woo00<007ooOol0?goo0P008Woo00<007oo
Ool05Goo00<007ooOol08Goo00<007ooOol0Cgoo000>Ool00`00Oomoo`0mOol2000TOol00`00Oomo
o`0EOol00`00Oomoo`0ROol00`00Oomoo`1>Ool000ioo`03001oogoo03aoo`03001oogoo02Aoo`03
001oogoo01Eoo`03001oogoo029oo`03001oogoo04ioo`003Woo00<007ooOol0>Woo0P00:7oo00<0
07ooOol04goo00<007ooOol097oo00<007ooOol0CGoo000>Ool00`00Oomoo`0hOol2000ZOol00`00
Oomoo`0COol00`00Oomoo`0TOol00`00Oomoo`1=Ool000ioo`03001oogoo03Ioo`8002aoo`03001o
ogoo01=oo`03001oogoo02Eoo`03001oogoo04aoo`003Woo00<007ooOol0=Goo00<007ooOol0;7oo
00<007ooOol04goo00<007ooOol09Goo00<007ooOol0C7oo000>Ool00`00Oomoo`0cOol2000`Ool0
0`00Oomoo`0AOol00`00Oomoo`0WOol00`00Oomoo`1;Ool000ioo`03001oogoo039oo`03001oogoo
031oo`03001oogoo015oo`03001oogoo02Moo`03001oogoo04]oo`003Woo00<007ooOol0<7oo0P00
<goo00<007ooOol04Goo00<007ooOol0:7oo00<007ooOol0BWoo000>Ool00`00Oomoo`0_Ool00`00
Oomoo`0cOol00`00Oomoo`0AOol00`00Oomoo`0XOol00`00Oomoo`1:Ool000ioo`03001oogoo02io
o`03001oogoo03Eoo`04001oogooOol;0003Ool00`00Oomoo`0ZOol00`00Oomoo`19Ool000ioo`03
001oogoo02aoo`8003Moo`D000]oo`D002]oo`03001oogoo04Uoo`003Woo00<007ooOol0:goo00<0
07ooOol0=Goo0P0000=oo`00Ool047oo00@007oo000002Yoo`03001oogoo04Qoo`003Woo00<007oo
Ool0:Goo0P00=Goo0`000goo00<007ooOol03goo00@007ooOomoo`<002Moo`03001oogoo04Qoo`00
3Woo00<007ooOol0:7oo00<007ooOol0<goo0P001goo00<007ooOol03Goo00<007ooOol01Goo0P00
9Woo00<007ooOol0Agoo000>Ool00`00Oomoo`0VOol2000dOol20009Ool00`00Oomoo`0=Ool00`00
Oomoo`07Ool2000TOol00`00Oomoo`17Ool000ioo`03001oogoo02Eoo`03001oogoo03=oo`03001o
ogoo00Uoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo029oo`03001oogoo04Ioo`003Woo
00<007ooOol097oo00<007ooOol0<Woo0P0037oo00<007ooOol03Goo00<007ooOol02Woo0P008Woo
00<007ooOol0AWoo000>Ool00`00Oomoo`0ROol2000cOol2000?Ool00`00Oomoo`0;Ool00`00Oomo
o`0=Ool00`00Oomoo`0POol00`00Oomoo`15Ool000ioo`03001oogoo025oo`03001oogoo039oo`03
001oogoo00moo`03001oogoo00]oo`03001oogoo00ioo`03001oogoo01moo`03001oogoo04Eoo`00
3Woo00<007ooOol07goo0P00=7oo00<007ooOol047oo00<007ooOol02goo00<007ooOol03goo00<0
07ooOol07goo00<007ooOol0A7oo000>Ool00`00Oomoo`0NOol00`00Oomoo`0dOol00`00Oomoo`0@
Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0NOol00`00Oomoo`14Ool000ioo`03001o
ogoo01eoo`03001oogoo03Aoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo019oo`03001o
ogoo01ioo`03001oogoo04=oo`003Woo00<007ooOol06goo0P00=Woo00<007ooOol04goo00<007oo
Ool02Goo00<007ooOol04goo00<007ooOol07Goo00<007ooOol0@goo000>Ool00`00Oomoo`0JOol0
0`00Oomoo`0eOol00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`0MOol0
0`00Oomoo`12Ool000ioo`03001oogoo01Uoo`03001oogoo03Eoo`03001oogoo01Eoo`03001oogoo
00Uoo`03001oogoo01Eoo`03001oogoo01aoo`03001oogoo049oo`003Woo00<007ooOol067oo00<0
07ooOol0=Goo00<007ooOol05goo00<007ooOol01goo00<007ooOol05goo00<007ooOol077oo00<0
07ooOol0@Goo000>Ool00`00Oomoo`0FOol2000gOol00`00Oomoo`0HOol00`00Oomoo`07Ool00`00
Oomoo`0GOol00`00Oomoo`0LOol00`00Oomoo`11Ool000ioo`03001oogoo01Eoo`03001oogoo03Mo
o`03001oogoo01Qoo`03001oogoo00Moo`03001oogoo01Qoo`03001oogoo01aoo`03001oogoo041o
o`003Woo00<007ooOol057oo00<007ooOol0=goo00<007ooOol06Goo00<007ooOol01goo00<007oo
Ool06Goo00<007ooOol06goo00<007ooOol0@7oo000>Ool00`00Oomoo`0COol00`00Oomoo`0hOol0
0`00Oomoo`0JOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`0LOol00`00Oomoo`0oOol0
00ioo`03001oogoo019oo`03001oogoo03Uoo`03001oogoo01Yoo`03001oogoo00Eoo`03001oogoo
01Yoo`03001oogoo01aoo`03001oogoo03moo`003Woo00<007ooOol04Goo00<007ooOol0>Goo00<0
07ooOol06goo00<007ooOol01Goo00<007ooOol06Woo00<007ooOol07Goo00<007ooOol0?Woo000>
Ool00`00Oomoo`0@Ool00`00Oomoo`0jOol00`00Oomoo`0KOol00`00Oomoo`05Ool00`00Oomoo`0K
Ool00`00Oomoo`0LOol00`00Oomoo`0nOol000ioo`03001oogoo011oo`03001oogoo03Uoo`03001o
ogoo01eoo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo01eoo`03001oogoo03eoo`003Woo
00<007ooOol03goo00<007ooOol0>Woo00<007ooOol07Goo00<007ooOol00goo00<007ooOol07Goo
00<007ooOol077oo00<007ooOol0?Goo000>Ool00`00Oomoo`0>Ool00`00Oomoo`0kOol00`00Oomo
o`0MOol00`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`0MOol00`00Oomoo`0lOol000ioo`03
001oogoo00eoo`03001oogoo03]oo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo01eoo`03
001oogoo01eoo`03001oogoo03aoo`003Woo00<007ooOol037oo00<007ooOol0?7oo00<007ooOol0
7goo00D007ooOomoo`00025oo`03001oogoo01eoo`03001oogoo03]oo`003Woo00<007ooOol02goo
00<007ooOol0?Goo00<007ooOol07goo00D007ooOomoo`00025oo`03001oogoo01eoo`03001oogoo
03]oo`003Woo00<007ooOol02goo00<007ooOol0?Goo00<007ooOol07goo00D007ooOomoo`00025o
o`03001oogoo01ioo`03001oogoo03Yoo`003Woo00<007ooOol02Woo00<007ooOol0?Goo00<007oo
Ool087oo00D007ooOomoo`00025oo`03001oogoo01ioo`03001oogoo03Yoo`003Woo00<007ooOol0
2Woo00<007ooOol0?Goo00<007ooOol08Goo00<007oo00008goo00<007ooOol07Woo00<007ooOol0
>Goo000>Ool00`00Oomoo`09Ool00`00Oomoo`0nOol00`00Oomoo`0QOol00`00Ool0000SOol00`00
Oomoo`0NOol00`00Oomoo`0iOol000ioo`03001oogoo00Qoo`03001oogoo03moo`03001oogoo025o
o`03001oo`0002=oo`03001oogoo01moo`03001oogoo03Qoo`003Woo00<007ooOol027oo00<007oo
Ool0?goo00<007ooOol08Goo00<007oo00008goo00<007ooOol07goo00<007ooOol0>7oo000>Ool0
0`00Oomoo`07Ool00`00Oomoo`10Ool00`00Oomoo`0ROol00`00Oomoo`0ROol00`00Oomoo`0POol0
0`00Oomoo`0gOol000ioo`03001oogoo00Moo`03001oogoo041oo`03001oogoo029oo`03001oogoo
029oo`03001oogoo021oo`03001oogoo03Moo`003Woo00<007ooOol01Woo00<007ooOol0@Goo00<0
07ooOol0Agoo00<007ooOol087oo00<007ooOol0=goo000>Ool00`00Oomoo`05Ool00`00Oomoo`12
Ool00`00Oomoo`17Ool00`00Oomoo`0QOol00`00Oomoo`0fOol000ioo`03001oogoo00Eoo`03001o
ogoo049oo`03001oogoo04Moo`03001oogoo025oo`03001oogoo03Ioo`003Woo00<007ooOol01Goo
00<007ooOol0@Woo00<007ooOol0Agoo00<007ooOol08Goo00<007ooOol0=Woo000>Ool00`00Oomo
o`05Ool00`00Oomoo`12Ool00`00Oomoo`17Ool00`00Oomoo`0ROol00`00Oomoo`0eOol000ioo`03
001oogoo00Eoo`03001oogoo049oo`03001oogoo04Moo`03001oogoo029oo`03001oogoo03Eoo`00
3Woo00<007ooOol017oo00<007ooOol0@goo00<007ooOol0AWoo00<007ooOol08goo00<007ooOol0
=Goo000>Ool00`00Oomoo`04Ool00`00Oomoo`14Ool00`00Oomoo`15Ool00`00Oomoo`0TOol00`00
Oomoo`0dOol000ioo`03001oogoo00Aoo`03001oogoo04Aoo`03001oogoo04Eoo`03001oogoo02Ao
o`03001oogoo03Aoo`003Woo00<007ooOol017oo00<007ooOol0A7oo00<007ooOol0A7oo00<007oo
Ool09Woo00<007ooOol0<goo000>Ool00`00Oomoo`04Ool00`00Oomoo`15Ool00`00Oomoo`13Ool0
0`00Oomoo`0VOol00`00Oomoo`0cOol000ioo`03001oogoo00Aoo`03001oogoo04Eoo`03001oogoo
04=oo`03001oogoo02Ioo`03001oogoo03=oo`003Woo00<007ooOol00goo00<007ooOol0AWoo00<0
07ooOol0@goo00<007ooOol09goo00<007ooOol0<Woo000>Ool00`00Oomoo`03Ool00`00Oomoo`16
Ool00`00Oomoo`12Ool00`00Oomoo`0XOol00`00Oomoo`0bOol000ioo`03001oogoo00=oo`03001o
ogoo04Moo`03001oogoo045oo`03001oogoo02Qoo`03001oogoo039oo`003Woo00<007ooOol00goo
00<007ooOol0B7oo00<007ooOol0?goo00<007ooOol0:Woo00<007ooOol0<Goo000>Ool00`00Oomo
o`04Ool00`00Oomoo`17Ool00`00Oomoo`0oOol00`00Oomoo`0ZOol00`00Oomoo`0aOol000ioo`03
001oogoo00Aoo`03001oogoo04Moo`03001oogoo03moo`03001oogoo02Yoo`03001oogoo035oo`00
3Woo00<007ooOol017oo00<007ooOol0Agoo00<007ooOol0?Woo00<007ooOol0;7oo00<007ooOol0
<7oo000>Ool00`00Oomoo`04Ool00`00Oomoo`18Ool00`00Oomoo`0mOol00`00Oomoo`0/Ool00`00
Oomoo`0`Ool000ioo`03001oogoo00Aoo`03001oogoo04Uoo`03001oogoo03]oo`03001oogoo02eo
o`03001oogoo031oo`003Woo00<007ooOol017oo00<007ooOol0BGoo00<007ooOol0>Woo00<007oo
Ool0;goo00<007ooOol0;goo000>Ool00`00Oomoo`05Ool00`00Oomoo`19Ool00`00Oomoo`0hOol0
0`00Oomoo`0`Ool00`00Oomoo`0_Ool000ioo`03001oogoo00Eoo`03001oogoo04Yoo`8003Moo`03
001oogoo035oo`03001oogoo02moo`003Woo00<007ooOol01Goo00<007ooOol0C7oo00<007ooOol0
<goo00<007ooOol0<Woo00<007ooOol0;goo000>Ool00`00Oomoo`06Ool00`00Oomoo`1<Ool00`00
Oomoo`0bOol00`00Oomoo`0cOol00`00Oomoo`0^Ool000ioo`03001oogoo00Ioo`03001oogoo04ao
o`03001oogoo035oo`03001oogoo03Aoo`03001oogoo02ioo`003Woo00<007ooOol01goo00<007oo
Ool0C7oo00<007ooOol0;Woo0P00=goo00<007ooOol0;Woo000>Ool00`00Oomoo`07Ool00`00Oomo
o`1=Ool2000]Ool00`00Oomoo`0hOol00`00Oomoo`0]Ool000ioo`03001oogoo00Qoo`03001oogoo
04ioo`03001oogoo02Qoo`8003]oo`03001oogoo02eoo`003Woo00<007ooOol027oo00<007ooOol0
Cgoo0P009goo00<007ooOol0>goo00<007ooOol0;Goo000>Ool00`00Oomoo`09Ool00`00Oomoo`1@
Ool00`00Oomoo`0SOol00`00Oomoo`0mOol00`00Oomoo`0/Ool000ioo`03001oogoo00Uoo`03001o
ogoo055oo`80025oo`80041oo`03001oogoo02aoo`003Woo00<007ooOol02Woo00<007ooOol0DWoo
0P007Goo0P00@Woo00<007ooOol0;7oo000>Ool00`00Oomoo`0:Ool00`00Oomoo`1DOol3000GOol3
0015Ool00`00Oomoo`0[Ool000ioo`03001oogoo00]oo`03001oogoo05Ioo`@000moo`@004Qoo`03
001oogoo02]oo`003Woo00<007ooOol037oo00<007ooOol0FGoo3`00C7oo00<007ooOol0:goo000>
Ool00`00Oomoo`0<Ool00`00Oomoo`2dOol00`00Oomoo`0[Ool000ioo`03001oogoo00eoo`03001o
ogoo0;=oo`03001oogoo02]oo`003Woo00<007ooOol03Woo00<007ooOol0/Woo00<007ooOol0:goo
000>Ool00`00Oomoo`0?Ool00`00Oomoo`2bOol00`00Oomoo`0ZOol000ioo`03001oogoo011oo`03
001oogoo0;5oo`03001oogoo02Yoo`003Woo00<007ooOol04Goo00<007ooOol0/7oo00<007ooOol0
:Woo000>Ool00`00Oomoo`0BOol00`00Oomoo`2_Ool00`00Oomoo`0ZOol000ioo`03001oogoo01=o
o`03001oogoo0:ioo`03001oogoo02Yoo`003Woo00<007ooOol057oo00<007ooOol0[Goo00<007oo
Ool0:Woo000>Ool00`00Oomoo`0EOol00`00Oomoo`2/Ool00`00Oomoo`0ZOol000ioo`03001oogoo
01Ioo`03001oogoo0:]oo`03001oogoo02Yoo`003Woo00<007ooOol05goo00<007ooOol0ZWoo00<0
07ooOol0:Woo000>Ool00`00Oomoo`0HOol00`00Oomoo`2YOol00`00Oomoo`0ZOol000ioo`03001o
ogoo01Uoo`03001oogoo0:Qoo`03001oogoo02Yoo`003Woo00<007ooOol06Woo0P00Z7oo00<007oo
Ool0:Woo000>Ool00`00Oomoo`0LOol00`00Oomoo`2UOol00`00Oomoo`0ZOol000ioo`03001oogoo
01eoo`03001oogoo0:Aoo`03001oogoo02Yoo`003Woo00<007ooOol07Woo0P00Y7oo00<007ooOol0
:Woo000>Ool00`00Oomoo`0POol00`00Oomoo`2QOol00`00Oomoo`0ZOol000ioo`03001oogoo025o
o`03001oogoo0:1oo`03001oogoo02Yoo`003Woo00<007ooOol08Woo0P00X7oo00<007ooOol0:Woo
000>Ool00`00Oomoo`0TOol00`00Oomoo`2MOol00`00Oomoo`0ZOol000ioo`03001oogoo02Eoo`80
09eoo`03001oogoo02Yoo`003Woo00<007ooOol09goo0P00Vgoo00<007ooOol0:Woo000>Ool00`00
Oomoo`0YOol00`00Oomoo`2GOol00`00Oomoo`0[Ool000ioo`03001oogoo02Yoo`8009Moo`03001o
ogoo02]oo`003Woo00<007ooOol0;7oo0P00UGoo00<007ooOol0:goo000>Ool00`00Oomoo`0^Ool0
0`00Oomoo`2BOol00`00Oomoo`0[Ool000ioo`03001oogoo02moo`80095oo`03001oogoo02aoo`00
3Woo00<007ooOol0<Goo0P00Sgoo00<007ooOol0;7oo000>Ool00`00Oomoo`0cOol2002<Ool00`00
Oomoo`0]Ool000ioo`03001oogoo03Eoo`8008Yoo`03001oogoo02eoo`003Woo00<007ooOol0=goo
0P00R7oo00<007ooOol0;Goo000>Ool00`00Oomoo`0iOol20025Ool00`00Oomoo`0^Ool000ioo`03
001oogoo03]oo`<0089oo`03001oogoo02ioo`003Woo00<007ooOol0?Woo0P00Ogoo00<007ooOol0
;goo000>Ool00`00Oomoo`10Ool2001lOol00`00Oomoo`0`Ool000ioo`03001oogoo049oo`<007Uo
o`03001oogoo031oo`003Woo00<007ooOol0AGoo0P00MWoo00<007ooOol0<Goo000>Ool00`00Oomo
o`17Ool3001bOol00`00Oomoo`0bOol000ioo`03001oogoo04Yoo`8006moo`03001oogoo03=oo`00
3Woo00<007ooOol0C7oo0`00Jgoo00<007ooOol0=7oo000>Ool00`00Oomoo`1?Ool3001WOol00`00
Oomoo`0eOol000ioo`03001oogoo059oo`8006Aoo`03001oogoo03Ioo`003Woo00<007ooOol0E7oo
0`00H7oo00<007ooOol0=goo000>Ool00`00Oomoo`1GOol4001JOol2000jOol000ioo`03001oogoo
05]oo`<005Eoo`8003aoo`003Woo00<007ooOol0GWoo0`00D7oo0P00?Woo000>Ool00`00Oomoo`1Q
Ool4001:Ool20010Ool000ioo`03001oogoo06Eoo`@004Aoo`80049oo`003Woo00<007ooOol07Goo
500O>7oo1000?Woo0P00A7oo000>Ool00`00Oomoo`0OOolW01lWOol7000aOol60016Ool000ioo`03
001oogoo025ooc/07aQoo`H002Qoo`<004aoo`003Woo00<007ooOol08gooCP0O2Goo2@005goo2000
Cgoo000>Ool00`00Oomoo`0TOomO01lG001GOol000ioo`03001oogoo02Ioof407`<001807eEoo`00
3Woo00<007ooOol0:7ooH00O00<0000O01l09P0O@7oo000>Ool00`00Oomoo`0ZOonL01l[Ool000io
o`03001oogoo02]ooiT07beoo`003Woo00<007ooOol0;GooU@0O;goo000>Ool00`00Oomoo`0_OonA
01laOol000ioo`03001oogoo035ooh`07cAoo`003Woo00<007ooOol0<gooR00O=Woo000>Ool00`00
Oomoo`0dOon501lhOol000ioo`03001oogoo03Iooh407cYoo`003Woo00<007ooOol0>7ooO00O?Goo
000>Ool00`00Oomoo`0jOomh01loOol000ioo`03001oogoo03]oogD07d5oo`003Woo00<007ooOol0
?GooL@0O@goo000>Ool00`00Oomoo`0oOom/01m6Ool000ioo`03001oogoo045oofP07dQoo`003Woo
00<007ooOol0@gooI00OBWoo000>Ool00`00Oomoo`14OomP01m=Ool000ioo`03001oogoo04Iooe`0
7dmoo`003Woo00<007ooOol02Goo300O<gooF00ODGoo000>Ool00`00Oomoo`09OolP01lQOomD01mC
Ool000ioo``003@07`iooe007eIoo`006WooT00OF7oo000JOon>01mJOol002Iooh007eaoo`00>Woo
J@0OGgoo001>OomC01mQOol0069oob407`IooaH07f=oo`00MWoo3@0OOgoo003oOol3Ool00?moo`=o
o`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003o
Ool3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=o
o`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003o
Ool3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo003oOol3Ool00?moo`=o
o`00ogoo0goo003oOol3Ool00?moo`=oo`00ogoo0goo0000\
\>"],
  ImageRangeCache->{{{0, 257}, {286, 0}} -> {-4.50005, -4.50784, 0.0350198, 
  0.0350198}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Cam Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The 3D cam constraints provided by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cover eight elementary cases of a cam and follower relationship. The 3D \
cam profiles used by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " fall into two basic categories: spatial surfaces and spatial curves. \
Spatial surfaces are defined by the locus of a single 3D point, the \
coordinates of which are a function of two independent parameters. Space \
curves are defined by a point that is a function of a single parameter. \n\n\
In practice many 3D cam profiles are 2D in nature, in which case they are \
modeled using the techniques that were developed in the last subsection on 2D \
cams. Any 2D cam profile can be converted to a 3D space curve by inserting or \
appending a third constant coordinate to the 2D locus point. \n\nEven when a \
true 3D surface profile is required, it can often be built up from the sum of \
two 2D curves that are functions of two different parameters. The following \
example uses one of the 2D cam profiles that was developed in the previous \
subsections to generate a 3D cam surface. The only change to the 2D cam is \
the addition of the parameter ",
  StyleBox["t",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that directly specifies the local ",
  StyleBox["y",
    FontSlant->"Italic"],
  " coordinate of the cam. This example would serve as a valid cam profile \
for any ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam constraint function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a valid ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam profile."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(locuspoint
       = {If[\[Pi]/2 < s < 3\ \[Pi]/2, 1, 1 + Cos[s]]\ Cos[s], t, Sin[s]}; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a plot of the cam profile."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot3D[Evaluate[locuspoint], {s, 0, 2\ \[Pi]}, {t, 0, 2}, 
      AspectRatio \[Rule] Automatic, \n\tCompiled \[Rule] False, 
      PlotPoints \[Rule] {35, 2}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .91992 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-016 1.01391 -0.0154133 1.01391 [
[.06185 .25091 -12 -8.91652 ]
[.06185 .25091 0 .08348 ]
[.26516 .17213 -5.68204 -9 ]
[.26516 .17213 .31796 0 ]
[.48366 .08752 -5.30738 -9 ]
[.48366 .08752 .69262 0 ]
[.7191 -0.00358 -4.93271 -9 ]
[.7191 -0.00358 1.06729 0 ]
[.00656 .70966 -3.38969 0 ]
[.00656 .70966 2.61031 9 ]
[.08564 .76984 -9.96917 0 ]
[.08564 .76984 8.03083 9 ]
[.15945 .82601 -3.26269 0 ]
[.15945 .82601 2.73731 9 ]
[.22849 .87856 -9.62325 0 ]
[.22849 .87856 8.37675 9 ]
[.29322 .92782 -3.15753 0 ]
[.29322 .92782 2.84247 9 ]
[.04334 .27823 -12 -2.77023 ]
[.04334 .27823 0 6.22977 ]
[.03093 .37142 -24 -2.84104 ]
[.03093 .37142 0 6.15896 ]
[.01783 .46985 -6 -2.91618 ]
[.01783 .46985 0 6.08382 ]
[.00397 .57396 -18 -2.99604 ]
[.00397 .57396 0 6.00396 ]
[-0.01071 .68426 -6 -3.08108 ]
[-0.01071 .68426 0 5.91892 ]
[ 0 0 0 0 ]
[ 1 .91992 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.05626 .26543 m
.74429 0 L
s
.0709 .25978 m
.07542 .26422 L
s
[(-1)] .06185 .25091 1 .98145 Mshowa
.27361 .18158 m
.27783 .18631 L
s
[(0)] .26516 .17213 .89401 1 Mshowa
.49139 .09757 m
.49525 .10259 L
s
[(1)] .48366 .08752 .76913 1 Mshowa
.72597 .00707 m
.7294 .0124 L
s
[(2)] .7191 -0.00358 .64424 1 Mshowa
.125 Mabswid
.11031 .24458 m
.11299 .24728 L
s
.15028 .22916 m
.15292 .23189 L
s
.19081 .21353 m
.19342 .21629 L
s
.23191 .19767 m
.23449 .20047 L
s
.31591 .16526 m
.3184 .16813 L
s
.35882 .14871 m
.36127 .15161 L
s
.40236 .13191 m
.40477 .13485 L
s
.44654 .11487 m
.44891 .11784 L
s
.5369 .08001 m
.53917 .08306 L
s
.5831 .06219 m
.58532 .06527 L
s
.63 .04409 m
.63216 .04722 L
s
.67761 .02572 m
.67973 .02888 L
s
.25 Mabswid
0 .69084 m
.30011 .91992 L
s
.00819 .69709 m
.00901 .6908 L
s
[(0)] .00656 .70966 .1299 -1 Mshowa
.087 .75724 m
.08768 .75094 L
s
[(0.5)] .08564 .76984 .10769 -1 Mshowa
.16055 .81339 m
.16111 .80708 L
s
[(1)] .15945 .82601 .08756 -1 Mshowa
.22937 .86592 m
.2298 .85959 L
s
[(1.5)] .22849 .87856 .06925 -1 Mshowa
.29388 .91516 m
.29421 .90883 L
s
[(2)] .29322 .92782 .05251 -1 Mshowa
.125 Mabswid
.0244 .70946 m
.02487 .70569 L
s
.04038 .72166 m
.04083 .71788 L
s
.05614 .73369 m
.05657 .72991 L
s
.07167 .74555 m
.0721 .74177 L
s
.10211 .76878 m
.1025 .765 L
s
.11702 .78016 m
.1174 .77638 L
s
.13173 .79139 m
.13209 .7876 L
s
.14624 .80246 m
.14658 .79867 L
s
.17468 .82417 m
.175 .82038 L
s
.18862 .83481 m
.18892 .83102 L
s
.20238 .84532 m
.20267 .84153 L
s
.21596 .85568 m
.21624 .85189 L
s
.2426 .87602 m
.24285 .87222 L
s
.25566 .88599 m
.2559 .8822 L
s
.26856 .89584 m
.26879 .89204 L
s
.2813 .90556 m
.28151 .90176 L
s
.25 Mabswid
.05626 .26543 m
0 .69084 L
s
.05517 .27369 m
.06108 .27141 L
s
[(-1)] .04334 .27823 1 -0.38439 Mshowa
.04282 .36704 m
.04877 .36485 L
s
[(-0.5)] .03093 .37142 1 -0.36866 Mshowa
.02978 .46564 m
.03576 .46354 L
s
[(0)] .01783 .46985 1 -0.35196 Mshowa
.01599 .56994 m
.022 .56793 L
s
[(0.5)] .00397 .57396 1 -0.33421 Mshowa
.00137 .68045 m
.00742 .67854 L
s
[(1)] -0.01071 .68426 1 -0.31532 Mshowa
.125 Mabswid
.05275 .29196 m
.0563 .2906 L
s
.05031 .31042 m
.05386 .30908 L
s
.04784 .32909 m
.0514 .32776 L
s
.04534 .34796 m
.04891 .34664 L
s
.04027 .38633 m
.04384 .38502 L
s
.03769 .40583 m
.04127 .40453 L
s
.03508 .42554 m
.03866 .42426 L
s
.03245 .44548 m
.03603 .44421 L
s
.02708 .48603 m
.03068 .48478 L
s
.02436 .50665 m
.02795 .50541 L
s
.0216 .5275 m
.0252 .52627 L
s
.01881 .5486 m
.02241 .54738 L
s
.01313 .59153 m
.01674 .59033 L
s
.01024 .61337 m
.01386 .61219 L
s
.00732 .63546 m
.01094 .63429 L
s
.00437 .65782 m
.00799 .65667 L
s
.25 Mabswid
.05626 .26543 m
0 .69084 L
s
0 .69084 m
.30011 .91992 L
s
.30011 .91992 m
.32036 .52227 L
s
.32036 .52227 m
.05626 .26543 L
s
.74429 0 m
.94662 .31869 L
s
.94662 .31869 m
1 .73889 L
s
1 .73889 m
.77805 .44689 L
s
.77805 .44689 m
.74429 0 L
s
.05626 .26543 m
0 .69084 L
s
0 .69084 m
.77805 .44689 L
s
.77805 .44689 m
.74429 0 L
s
.74429 0 m
.05626 .26543 L
s
.32036 .52227 m
.94662 .31869 L
s
.94662 .31869 m
1 .73889 L
s
1 .73889 m
.30011 .91992 L
s
.30011 .91992 m
.32036 .52227 L
s
0 0 m
1 0 L
1 .91992 L
0 .91992 L
closepath
clip
newpath
.5 Mabswid
.42979 .50541 m .39985 .53202 L .15194 .28209 L p .799 .761 .818 r
F P
0 g
s
.39985 .53202 m .37358 .56225 L .12175 .3158 L p .831 .76 .785 r
F P
0 g
s
.12175 .3158 m .15194 .28209 L .39985 .53202 L p .831 .76 .785 r
F P
0 g
s
.46255 .4832 m .42979 .50541 L .18573 .25194 L p .763 .757 .847 r
F P
0 g
s
.15194 .28209 m .18573 .25194 L .42979 .50541 L p .799 .761 .818 r
F P
0 g
s
.37358 .56225 m .35175 .59527 L .09601 .35215 L p .859 .756 .747 r
F P
0 g
s
.09601 .35215 m .12175 .3158 L .37358 .56225 L p .859 .756 .747 r
F P
0 g
s
.49723 .46602 m .46255 .4832 L .22219 .22618 L p .721 .749 .875 r
F P
0 g
s
.18573 .25194 m .22219 .22618 L .46255 .4832 L p .763 .757 .847 r
F P
0 g
s
.35175 .59527 m .33503 .63017 L .0755 .39017 L p .885 .746 .703 r
F P
0 g
s
.0755 .39017 m .09601 .35215 L .35175 .59527 L p .885 .746 .703 r
F P
0 g
s
.5345 .45392 m .49723 .46602 L .26033 .20556 L p .668 .735 .9 r
F P
0 g
s
.22219 .22618 m .26033 .20556 L .49723 .46602 L p .721 .749 .875 r
F P
0 g
s
.33503 .63017 m .32399 .66594 L .0609 .42879 L p .909 .731 .648 r
F P
0 g
s
.0609 .42879 m .0755 .39017 L .33503 .63017 L p .909 .731 .648 r
F P
0 g
s
.58313 .44414 m .5345 .45392 L .3009 .19004 L p .619 .719 .917 r
F P
0 g
s
.26033 .20556 m .3009 .19004 L .5345 .45392 L p .668 .735 .9 r
F P
0 g
s
.32399 .66594 m .31909 .70154 L .05279 .46689 L p .93 .704 .575 r
F P
0 g
s
.05279 .46689 m .0609 .42879 L .32399 .66594 L p .93 .704 .575 r
F P
0 g
s
.64261 .43689 m .58313 .44414 L .35351 .17608 L p .582 .704 .927 r
F P
0 g
s
.3009 .19004 m .35351 .17608 L .58313 .44414 L p .619 .719 .917 r
F P
0 g
s
.31909 .70154 m .32063 .73587 L .0516 .5033 L p .943 .659 .471 r
F P
0 g
s
.0516 .5033 m .05279 .46689 L .31909 .70154 L p .943 .659 .471 r
F P
0 g
s
.70925 .43328 m .64261 .43689 L .41772 .16391 L p .547 .689 .933 r
F P
0 g
s
.35351 .17608 m .41772 .16391 L .64261 .43689 L p .582 .704 .927 r
F P
0 g
s
.32063 .73587 m .32876 .76781 L .05759 .53683 L p .935 .577 .315 r
F P
0 g
s
.05759 .53683 m .0516 .5033 L .32063 .73587 L p .935 .577 .315 r
F P
0 g
s
.32876 .76781 m .34341 .79622 L .07083 .56626 L p .868 .423 .068 r
F P
0 g
s
.07083 .56626 m .05759 .53683 L .32876 .76781 L p .868 .423 .068 r
F P
0 g
s
.77793 .43469 m .70925 .43328 L .48961 .15497 L p .504 .669 .937 r
F P
0 g
s
.41772 .16391 m .48961 .15497 L .70925 .43328 L p .547 .689 .933 r
F P
0 g
s
.34341 .79622 m .3643 .82002 L .09116 .59046 L p .667 .148 0 r
F P
0 g
s
.09116 .59046 m .07083 .56626 L .34341 .79622 L p .667 .148 0 r
F P
0 g
s
.84252 .44261 m .77793 .43469 L .5637 .15115 L p .438 .635 .939 r
F P
0 g
s
.48961 .15497 m .5637 .15115 L .77793 .43469 L p .504 .669 .937 r
F P
0 g
s
.3643 .82002 m .39092 .83823 L .11812 .60837 L p 0 .215 .682 r
F P
0 g
s
.11812 .60837 m .09116 .59046 L .3643 .82002 L p 0 .215 .682 r
F P
0 g
s
.39092 .83823 m .4225 .85 L .15099 .61908 L p .096 .502 .903 r
F P
0 g
s
.15099 .61908 m .11812 .60837 L .39092 .83823 L p .096 .502 .903 r
F P
0 g
s
.89651 .45833 m .84252 .44261 L .6333 .15452 L p .313 .563 .926 r
F P
0 g
s
.5637 .15115 m .6333 .15452 L .84252 .44261 L p .438 .635 .939 r
F P
0 g
s
.4225 .85 m .458 .85469 L .18874 .62193 L p .364 .657 .969 r
F P
0 g
s
.18874 .62193 m .15099 .61908 L .4225 .85 L p .364 .657 .969 r
F P
0 g
s
.458 .85469 m .49619 .85192 L .23006 .61657 L p .53 .732 .967 r
F P
0 g
s
.23006 .61657 m .18874 .62193 L .458 .85469 L p .53 .732 .967 r
F P
0 g
s
.93384 .48265 m .89651 .45833 L .69119 .16702 L p 0 .348 .825 r
F P
0 g
s
.6333 .15452 m .69119 .16702 L .89651 .45833 L p .313 .563 .926 r
F P
0 g
s
.49619 .85192 m .53746 .84112 L .27541 .60233 L p .638 .77 .943 r
F P
0 g
s
.27541 .60233 m .23006 .61657 L .49619 .85192 L p .638 .77 .943 r
F P
0 g
s
.53746 .84112 m .5911 .81973 L .33502 .57582 L p .695 .786 .92 r
F P
0 g
s
.33502 .57582 m .27541 .60233 L .53746 .84112 L p .695 .786 .92 r
F P
0 g
s
.69119 .16702 m .7306 .19001 L .93384 .48265 L p 0 .348 .825 r
F P
0 g
s
.94992 .51558 m .93384 .48265 L .7306 .19001 L p .775 .355 0 r
F P
0 g
s
.5911 .81973 m .65592 .78814 L .40763 .53752 L p .725 .793 .905 r
F P
0 g
s
.40763 .53752 m .33502 .57582 L .5911 .81973 L p .725 .793 .905 r
F P
0 g
s
.7306 .19001 m .74634 .22393 L .94992 .51558 L p .775 .355 0 r
F P
0 g
s
.9425 .55622 m .94992 .51558 L .74634 .22393 L p .976 .776 .57 r
F P
0 g
s
.65592 .78814 m .72705 .74802 L .48785 .4895 L p .748 .797 .892 r
F P
0 g
s
.48785 .4895 m .40763 .53752 L .65592 .78814 L p .748 .797 .892 r
F P
0 g
s
.72705 .74802 m .79816 .70174 L .56859 .43474 L p .771 .802 .878 r
F P
0 g
s
.56859 .43474 m .48785 .4895 L .72705 .74802 L p .771 .802 .878 r
F P
0 g
s
.91212 .60265 m .9425 .55622 L .73583 .26798 L p .895 .815 .762 r
F P
0 g
s
.74634 .22393 m .73583 .26798 L .9425 .55622 L p .976 .776 .57 r
F P
0 g
s
.79816 .70174 m .86214 .65221 L .64182 .37691 L p .798 .807 .859 r
F P
0 g
s
.64182 .37691 m .56859 .43474 L .79816 .70174 L p .798 .807 .859 r
F P
0 g
s
.86214 .65221 m .91212 .60265 L .6997 .32004 L p .836 .813 .828 r
F P
0 g
s
.73583 .26798 m .6997 .32004 L .91212 .60265 L p .895 .815 .762 r
F P
0 g
s
.6997 .32004 m .64182 .37691 L .86214 .65221 L p .836 .813 .828 r
F P
0 g
s
.25 Mabswid
.74429 0 m
.94662 .31869 L
s
.94662 .31869 m
1 .73889 L
s
1 .73889 m
.77805 .44689 L
s
.77805 .44689 m
.74429 0 L
s
.05626 .26543 m
0 .69084 L
s
0 .69084 m
.77805 .44689 L
s
.77805 .44689 m
.74429 0 L
s
.74429 0 m
.05626 .26543 L
s
.05626 .26543 m
.74429 0 L
s
.0709 .25978 m
.07542 .26422 L
s
[(-1)] .06185 .25091 1 .98145 Mshowa
.27361 .18158 m
.27783 .18631 L
s
[(0)] .26516 .17213 .89401 1 Mshowa
.49139 .09757 m
.49525 .10259 L
s
[(1)] .48366 .08752 .76913 1 Mshowa
.72597 .00707 m
.7294 .0124 L
s
[(2)] .7191 -0.00358 .64424 1 Mshowa
.125 Mabswid
.11031 .24458 m
.11299 .24728 L
s
.15028 .22916 m
.15292 .23189 L
s
.19081 .21353 m
.19342 .21629 L
s
.23191 .19767 m
.23449 .20047 L
s
.31591 .16526 m
.3184 .16813 L
s
.35882 .14871 m
.36127 .15161 L
s
.40236 .13191 m
.40477 .13485 L
s
.44654 .11487 m
.44891 .11784 L
s
.5369 .08001 m
.53917 .08306 L
s
.5831 .06219 m
.58532 .06527 L
s
.63 .04409 m
.63216 .04722 L
s
.67761 .02572 m
.67973 .02888 L
s
.25 Mabswid
0 .69084 m
.30011 .91992 L
s
.00819 .69709 m
.00901 .6908 L
s
[(0)] .00656 .70966 .1299 -1 Mshowa
.087 .75724 m
.08768 .75094 L
s
[(0.5)] .08564 .76984 .10769 -1 Mshowa
.16055 .81339 m
.16111 .80708 L
s
[(1)] .15945 .82601 .08756 -1 Mshowa
.22937 .86592 m
.2298 .85959 L
s
[(1.5)] .22849 .87856 .06925 -1 Mshowa
.29388 .91516 m
.29421 .90883 L
s
[(2)] .29322 .92782 .05251 -1 Mshowa
.125 Mabswid
.0244 .70946 m
.02487 .70569 L
s
.04038 .72166 m
.04083 .71788 L
s
.05614 .73369 m
.05657 .72991 L
s
.07167 .74555 m
.0721 .74177 L
s
.10211 .76878 m
.1025 .765 L
s
.11702 .78016 m
.1174 .77638 L
s
.13173 .79139 m
.13209 .7876 L
s
.14624 .80246 m
.14658 .79867 L
s
.17468 .82417 m
.175 .82038 L
s
.18862 .83481 m
.18892 .83102 L
s
.20238 .84532 m
.20267 .84153 L
s
.21596 .85568 m
.21624 .85189 L
s
.2426 .87602 m
.24285 .87222 L
s
.25566 .88599 m
.2559 .8822 L
s
.26856 .89584 m
.26879 .89204 L
s
.2813 .90556 m
.28151 .90176 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{236, 218},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003/0000fQ000`40O003h00Ok7oo002YOol30010
Ool00:Uoo`03001oogoo041oo`00ZWoo00<007ooOol0?goo002ZOol00`00Oomoo`0oOol00:Uoo`03
001oo`00041oo`00ZWoo00<007ooOol0?goo003/Ool00>aoo`00k7oo002aOol2000iOol00:moo`80
0003Ool0000003Qoo`00[7oo0`000goo0P00>7oo002YOol30003Ool01P00Oomoo`00Ool003Moo`00
Ygoo0P002Goo00@007ooOol003Ioo`00Y7oo0`002goo00@007ooOol003Ioo`00XWoo0`003Goo00D0
07ooOomoo`0003Eoo`00Wgoo0`004Goo00@007ooOol003Eoo`00WGoo0P0057oo00D007ooOomoo`00
03Aoo`00VWoo0`005Woo00<007ooOol00Woo00<007ooOol0<Goo002GOol4000HOol00`00Oomoo`02
Ool00`00Oomoo`0aOol007Ioo`D001Yoo`8001aoo`03001oogoo00=oo`03001oogoo031oo`00N7oo
00<007ooOol05goo0`007Woo00<007ooOol017oo00<007ooOol0;goo001hOol00`00Oomoo`0EOol2
000QOol00`00Oomoo`04Ool00`00Oomoo`0_Ool007Qoo`03001oogoo019oo`@0029oo`03001oogoo
00Eoo`03001oogoo02ioo`00N7oo00<007ooOol047oo0P009Woo00<007ooOol01Goo00<007ooOol0
;Woo001gOol2000?Ool3000XOol00`00Oomoo`06Ool00`00Oomoo`0]Ool008Eoo`<002]oo`03001o
ogoo00Moo`03001oogoo02aoo`00Pgoo0P0000=oo`00Ool0:goo00<007ooOol01goo00<007ooOol0
;7oo0020Ool3000`Ool00`00Oomoo`08Ool00`00Oomoo`0[Ool007ioo`8003=oo`03001oogoo00Uo
o`03001oogoo02Yoo`00Ngoo0`00=Woo00<007ooOol027oo00<007ooOol0:Woo001hOol30002Ool0
0`00Oomoo`0dOol00`00Oomoo`09Ool00`00Oomoo`0YOol007Ioo`8003aoo`03001oogoo00Yoo`03
001oogoo02Qoo`00Lgoo0`00?Woo00<007ooOol02Woo00<007ooOol0:7oo001aOol30010Ool00`00
Oomoo`0;Ool00`00Oomoo`0WOol006ioo`<004=oo`03001oogoo00]oo`03001oogoo02Moo`00K7oo
0P00AWoo00<007ooOol037oo00<007ooOol09Woo001YOol30018Ool00`00Oomoo`0=Ool00`00Oomo
o`0UOol004Uoo`03001oogoo01Yoo`@004Yoo`03001oogoo00eoo`03001oogoo02Eoo`00B7oo00<0
07oo00006Goo0P00CWoo00<007ooOol03Woo00<007ooOol097oo0018Ool00`00Ool0000FOol3001@
Ool00`00Oomoo`0?Ool00`00Oomoo`0SOol004Qoo`03001oo`0001Aoo`8005=oo`03001oogoo00mo
o`03001oogoo02=oo`00B7oo00<007oo00004Goo0`0000=oo`00Ool05Woo9@005goo00<007ooOol0
47oo00<007ooOol08Woo0019Ool00`00Oomoo`0>Ool2000DOol80004A]d00`00@[e2_@0=@[d?>Yh2
:Ud4000COol00`00Oomoo`0@Ool00`00Oomoo`0ROol005Moo`<0011oo`H000e6g@030012_D:m00e2
_@hjWP03000ZGBYM00<ZG@@0011oo`03001oogoo011oo`03001oogoo025oo`00E7oo10003Woo1000
0d[M00<004KMA]d03DKM00<004:m@[d03D:m00<003ZN>Yh033ZN00<002YM:Ud01RYM0`003Goo00<0
07ooOol04Goo00<007ooOol087oo001BOol2000=Ool50008B]d00`00A]e6g@0=A]d00`00@[e2_@0=
@[d00`00>YhjWP0<>Yh00`00:UdZG@08:Ud2000;Ool00`00Oomoo`0AOol00`00Oomoo`0POol004mo
o`<000]oo`@000e:g@030016gDKM00i6g@030012_D:m00e2_@03000jWSZN00`jWP03000ZGBYM00LZ
G@030001NP0000Yoo`03001oogoo019oo`03001oogoo01moo`00CGoo0P002Woo10000Tkm00<004[M
B]d03D[M00<004KMA]d03TKM00<004:m@[d03D:m00<003ZN>Yh02cZN00<002YM:Ud022YM00@0005j
000000Qoo`03001oogoo01=oo`03001oogoo01ioo`00BWoo0`0000=oo`00Ool01Goo10001dkm00<0
04[MB]d03D[M00<004KMA]d03DKM00<004:m@[d03D:m00<003ZN>Yh033ZN00<002YM:Ud022YM00<0
005j0GX00P001Woo00<007ooOol04goo00<007ooOol07Woo0017Ool30008Ool3000<C_d00`00B]e:
g@0=B]d00`00A]e6g@0=A]d00`00@[e2_@0=@[d00`00>YhjWP0<>Yh00`00:UdZG@07:Ud00`000GX1
NP020GX00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`0MOol004Aoo`<000Qoo`<0009Fo003
001>oDkm00Y>o@03001:gD[M00i:g@030016gDKM00e6g@030012_D:m00e2_@03000jWSZN00`jWP03
000ZGBYM00LZG@040001NP5j0GX20004Ool00`00Oomoo`0EOol00`00Oomoo`0LOol0049oo`@000Io
o`<000IFo003001>oDkm00Y>o@03001:gD[M00i:g@030016gDKM00e6g@030012_D:m00e2_@03000j
WSZN00/jWP03000ZGBYM00PZG@050001NP5j0GX00004Ool00`00Oomoo`0EOol00`00Oomoo`0LOol0
041oo`8000Qoo`8000YFo003001>oDkm00Y>o@03001:gD[M00e:g@030016gDKM00i6g@030012_D:m
00a2_@03000jWSZN00`jWP03000ZGBYM00PZG@050001NP5j001QH003Ool00`00Oomoo`0FOol00`00
Oomoo`0KOol003eoo`<000Qoo`800003G_/005Kl00YFo003001>oDkm00Y>o@03001:gD[M00e:g@03
0016gDKM00e6g@030012_D:m00e2_@03000jWSZN00`jWP03000ZGBYM00LZG@040001NP5j0GX20002
Ool00`00Oomoo`0FOol00`00Oomoo`0KOol001]oo`D001]oo`8000Yoo`03001Nnekk009Nn`03001F
o5Kl00QFo003001>oDkm00]>o@03001:gD[M00e:g@030016gDKM00e6g@030012_D:m00e2_@03000j
WSZN00/jWP03000ZGBYM00PZG@050001NP5j001QH002Ool00`00Oomoo`0GOol00`00Oomoo`0JOol0
01eoo`03001oogoo01Qoo`<000Yoo`8000INn`03001Fo5Kl00QFo003001>oDkm00]>o@03001:gD[M
00e:g@030016gDKM00e6g@030012_D:m00e2_@03000jWSZN00/jWP03000ZGBYM00PZG@070001NP5j
001QH7oo00006Woo00<007ooOol06Goo000GOol30003Ool00`00Oomoo`0EOol3000;Ool20009G_/0
0`00E_aFo008E_`00`00C_e>o@0;C_d00`00B]e:g@0=B]d00`00A]e6g@0=A]d00`00@[e2_@0<@[d0
0`00>YhjWP0<>Yh00`00:UdZG@07:Ud01@000GX1NP00HF000P006Woo00<007ooOol06Goo000MOol0
0`00Oomoo`0COol2000=Ool00`00G_]Nn`0:G_/00`00E_aFo008E_`00`00C_e>o@0:C_d00`00B]e:
g@0=B]d00`00A]e6g@0>A]d00`00@[e2_@0<@[d00`00>YhjWP0<>Yh00`00:UdZG@07:Ud01@000GX0
0000HF000P006Woo00<007ooOol067oo000MOol00`00Oomoo`0@Ool300000goo001oo`0:Ool20000
0f<K001Nn`0:G_/00`00E_aFo009E_`00`00C_e>o@0:C_d00`00B]e:g@0=B]d00`00A]e6g@0=A]d0
0`00@[e2_@0=@[d00`00>YhjWP0;>Yh00`00:UdZG@08:Ud2000017lBHF1QH0006goo00<007ooOol0
5goo000LOol2000@Ool2000?Ool00`00Ha]S6`02Ha/00`00G_]Nn`09G_/00`00E_aFo009E_`00`00
C_e>o@0:C_d00`00B]e:g@0=B]d00`00A]e6g@0=A]d00`00@[e2_@0=@[d00`00>YhjWP0;>Yh00`00
:UdZG@07:Ud01P00Oa9o4P00HF0001]oo`03001oogoo01Moo`00:goo0`0047oo00<006<KHa/016<K
00<005kkG_/02Ekk00<005KlE_`02EKl00<004kmC_d02Tkm00<004[MB]d03D[M00<004KMA]d03DKM
00<004:m@[d03D:m00<003ZN>Yh02cZN00<002YM:Ud01RYM00@007lBOa9o4P<001]oo`03001oogoo
01Ioo`00:Goo0`0047oo0P0026<K00<005kkG_/02Ekk00<005KlE_`02EKl00<004kmC_d02Tkm00<0
04[MB]d03D[M00<004KMA]d03DKM00<004:m@[d034:m00<003ZN>Yh033ZN00<002YM:Ud01BYM00<0
07lBOa800WlB00<0065POol06goo00<007ooOol05Goo000VOol3000BOol00`00Ha]S6`09Ha/00`00
G_]Nn`09G_/00`00E_aFo009E_`00`00C_e>o@0:C_d00`00B]e:g@0<B]d00`00A]e6g@0=A]d00`00
@[e2_@0=@[d00`00>YhjWP0;>Yh00`00:UdZG@05:Ud00`00Oa9o4P02Oa800`00HF00000KOol00`00
Oomoo`0EOol002=oo`<001Aoo`03001W6P0000]S6`03001Nnekk00UNn`03001Fo5Kl00QFo003001>
oDkm00]>o@03001:gD[M00a:g@030016gDKM00e6g@030012_D:m00e2_@03000jWSZN00/jWP03000Z
GBYM00@ZG@03001o4WlB009o4P800003HF0007oo01Yoo`03001oogoo01Aoo`008Goo0P005Woo00D0
06LJIaYW6P0000]S6`03001Nnekk00UNn`03001Fo5Kl00QFo003001>oDkm00Y>o@03001:gD[M00e:
g@030016gDKM00e6g@030012_D:m00e2_@03000jWSZN00/jWP03000ZGBYM008ZG@03001o4WlB00=o
4P04001o4P00HF0KOol00`00Oomoo`0DOol001moo`80009oo`03001oogoo019oo`03001W6VLJ00=W
6P03001S6f<K00US6`03001Nnekk00UNn`03001Fo5Kl00QFo003001>oDkm00Y>o@03001:gD[M00e:
g@030016gDKM00e6g@030012_D:m00a2_@03000jWSZN00/jWP03000ZGBYM008ZG@03001o4WlB00=o
4P05001o4P00HF00000KOol00`00Oomoo`0COol001moo`8001Eoo`8000MW6P03001S6f<K00US6`03
001Nnekk00UNn`03001Fo5Kl00QFo003001>oDkm00Y>o@03001:gD[M00e:g@030016gDKM00e6g@03
0012_D:m00a2_@03000jWSZN00/jWP05000ZGBYM:Ud00005Oa801P00Oa9o4P00HF0001]oo`03001o
ogoo019oo`007goo00<007oo00004goo00<006LJIaX026LJ00<006<KHa/026<K00<005kkG_/02Ukk
00<005KlE_`025Kl00<004kmC_d02Tkm00<004[MB]d03D[M00<004KMA]d034KM00<004:m@[d03D:m
00<003ZN>Yh02cZN00D002YM001cF00000Ao4P06001o4WlBOa80065P6goo00<007ooOol04Woo000G
Ool50003Ool01000Oomoo`004Goo00<006LJIaX02VLJ00<006<KHa/026<K00<005kkG_/02Ukk00<0
05KlE_`025Kl00<004kmC_d02Tkm00<004[MB]d034[M00<004KMA]d03DKM00<004:m@[d03D:m00<0
03ZN>Yh02cZN0P000W=H17lB00<007lBOa800WlB0P006goo00<007ooOol04Goo000IOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00IaYW6P0<IaX00`00Ha]S6`08Ha/00`00G_]N
n`09G_/00`00E_aFo009E_`00`00C_e>o@0:C_d00`00B]e:g@0<B]d00`00A]e6g@0=A]d00`00@[e2
_@0<@[d00`00>YhjWP0;>Yh01@00LeQcF7=H00000glB00<007lBOa800WlB00<0065P00006goo00<0
07ooOol047oo000COol30003Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0;Ool00`00JaT0000>
IaX00`00Ha]S6`08Ha/00`00G_]Nn`09G_/00`00E_aFo009E_`00`00C_e>o@0:C_d00`00B]e:g@0<
B]d00`00A]e6g@0=A]d00`00@[e2_@0<@[d00`00>YhjWP09>Yh00`00LeQcF003LeP01@00Oa9o4WlB
000017lB00<0065P00006Woo00<007ooOol047oo000IOol00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`09Ool01@00JaU[6F/I00003VLJ00<006<KHa/026<K00<005kkG_/02Ekk00<005KlE_`0
2EKl00<004kmC_d02Dkm00<004[MB]d03D[M00<004KMA]d034KM00<004:m@[d03D:m00<003ZN>Yh0
1cZN00<007=HLeP01G=H00@007lBOa8000Eo4P8001]oo`03001oogoo00moo`006Goo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol01goo00<006/IJaT00f/I00<006LJIaX036LJ00<006<KHa/0
26<K00<005kkG_/02Ekk00<005KlE_`02EKl00<004kmC_d02Dkm00<004[MB]d03D[M00<004KMA]d0
34KM00<004:m@[d03D:m00<003ZN>Yh01SZN00<007=HLeP01G=H00@007lBOa8000Eo4P03001QH000
01Yoo`03001oogoo00moo`0067oo0P0017oo00<007ooOol01Woo00<007ooOol01Woo00<006/IJaT0
16/I00<006LJIaX036LJ00<006<KHa/026<K00<005kkG_/02Ekk00<005KlE_`025Kl00<004kmC_d0
2Tkm00<004[MB]d034[M00<004KMA]d03DKM00<004:m@[d03D:m00<003ZN>Yh013ZN00<007=HLeP0
1g=H00<007lB00001WlB00<0065P00006Woo00<007ooOol03Woo000NOol00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00JaU[6@06JaT00`00IaYW6P0<IaX00`00Ha]S6`08Ha/00`00G_]Nn`09G_/00`00
E_aFo008E_`00`00C_e>o@0:C_d00`00B]e:g@0<B]d00`00A]e6g@0=A]d00`00@[e2_@0<@[d00`00
>YhjWP03>Yh00`00LeQcF009LeP20007Oa800`00HF1oo`0JOol00`00Oomoo`0=Ool001ioo`03001o
ogoo00Qoo`03001oogoo009oo`03001[6F/I00Q[6@03001W6VLJ00aW6P03001S6f<K00QS6`03001N
nekk00UNn`03001Fo5Kl00QFo003001>oDkm00Y>o@03001:gD[M00a:g@030016gDKM00e6g@030012
_D:m00a2_@05000jWSZN>Yh0000<LeP20007Oa800`00HF00000JOol00`00Oomoo`0=Ool001ioo`03
001oogoo00Uoo`04001oogoo000<JaT00`00IaYW6P0;IaX00`00Ha]S6`09Ha/00`00G_]Nn`09G_/0
0`00E_aFo008E_`00`00C_e>o@0:C_d00`00B]e:g@0<B]d00`00A]e6g@0<A]d00`00@[e2_@0=@[d0
1000>YhjWP003G=H00<007lBOa801WlB00<0065P00006Goo0P003Woo000MOol00`00Oomoo`0;Ool2
00000flG001[6@0;JaT00`00IaYW6P0;IaX00`00Ha]S6`09Ha/00`00G_]Nn`09G_/00`00E_aFo008
E_`00`00C_e>o@0:C_d00`00B]e:g@0<B]d00`00A]e6g@0<A]d00`00@[e2_@0=@[d2000>LeP20008
Oa800`00HF1oo`0EOol300000goo001oo`0=Ool001eoo`8000aoo`05001_5flGKaL0000<JaT00`00
IaYW6P0;IaX00`00Ha]S6`09Ha/00`00G_]Nn`09G_/00`00E_aFo008E_`00`00C_e>o@0:C_d00`00
B]e:g@0;B]d00`00A]e6g@0=A]d00`00@[e2_@0<@[d00`00JeX0000=LeP00`00LeP00008Oa82000B
Ool30004Ool00`00Oomoo`0<Ool001eoo`03001oogoo00]oo`03001_5flG009_5`03001[6F/I00Y[
6@03001W6VLJ00]W6P03001S6f<K00US6`03001Nnekk00UNn`03001Fo5Kl00QFo003001>oDkm00U>
o@03001:gD[M00a:g@030016gDKM00e6g@030012_D:m00Y2_@05001[FV]JJeX0000<LeP00`00LeP0
0008Oa800`00HF00000>Ool30007Ool00`00Oomoo`0<Ool001eoo`03001oogoo00Yoo`03001_5flG
00A_5`03001[6F/I00Y[6@03001W6VLJ00]W6P03001S6f<K00US6`03001Nnekk00QNn`03001Fo5Kl
00UFo003001>oDkm00U>o@03001:gD[M00a:g@030016gDKM00e6g@030012_D:m00Q2_@03001[FV]J
009[FP03001cF7=H00YcF004001cF7=H0008Oa800`00HF1oo`0:Ool3000;Ool00`00Oomoo`0;Ool0
01eoo`03001oogoo00Uoo`03001_5flG00I_5`03001[6F/I00Y[6@03001W6VLJ00]W6P03001S6f<K
00US6`03001Nnekk00QNn`03001Fo5Kl00UFo003001>oDkm00U>o@03001:gD[M00a:g@030016gDKM
00a6g@030012_D:m00M2_@03001[FV]J00A[FP03001cF7=H00UcF005001cF7=HLeP00008Oa820007
Ool3000>Ool00`00Oomoo`0;Ool001eoo`03001oogoo00Qoo`03001_5flG00Q_5`03001[6F/I00Y[
6@03001W6VLJ00]W6P03001S6f<K00US6`03001Nnekk00QNn`03001Fo5Kl00QFo003001>oDkm00Y>
o@03001:gD[M00a:g@030016gDKM00a6g@030012_D:m00E2_@03001[FV]J00I[FP03001cF7=H00Qc
F003001cF7=H009cF003001o4WlB00Eo4P03001QH00000=oo`<0015oo`03001oogoo00]oo`007Goo
00<007ooOol027oo00<006lGKaL02FlG00<006/IJaT02V/I00<006LJIaX02fLJ00<006<KHa/02F<K
00<005kkG_/025kk00<005KlE_`025Kl00<004kmC_d02Tkm00<004[MB]d034[M00<004KMA]d034KM
00<004:m@[d00d:m00<006]JJeX026]J00<007=HLeP01g=H00<007=HLeP00W=H00<007lBOa801WlB
00<0065P00000P0057oo00<007ooOol02goo000LOol00`00Oomoo`08Ool00`00KaM_5`0;KaL00`00
JaU[6@0:JaT00`00IaYW6P0;IaX00`00Ha]S6`09Ha/00`00G_]Nn`08G_/00`00E_aFo008E_`00`00
C_e>o@0:C_d00`00B]e:g@0;B]d00`00A]e6g@0=A]d01@00@[e2_D:m00002f]J00<007=HLeP027=H
00<007=HLeP00W=H00<007lBOa801WlB0P005Woo00<007ooOol02goo000LOol00`00Oomoo`07Ool0
0`00L_H0000=KaL00`00JaU[6@0:JaT00`00IaYW6P0;IaX00`00Ha]S6`08Ha/00`00G_]Nn`09G_/0
0`00E_aFo008E_`00`00C_e>o@0:C_d00`00B]e:g@0;B]d00`00A]e6g@0<A]d01000@[e2_@003F]J
00<007=HLeP01g=H00<007=HLeP00g=H00<007lBOa801WlB0P005Goo00<007ooOol02goo000LOol2
0008Ool01000L_IbmP003FlG00<006/IJaT02V/I00<006LJIaX02fLJ00<006<KHa/026<K00<005kk
G_/02Ekk00<005KlE_`025Kl00<004kmC_d02Dkm00<004[MB]d034[M00<004KMA]d034KM0P003f]J
00<007=HLeP01W=H00<007=HLeP00g=H00<007lBOa801WlB00<0065P000057oo00<007ooOol02goo
000LOol00`00Oomoo`06Ool00`00L_IbmP02L_H00`00KaM_5`0;KaL00`00JaU[6@0:JaT00`00IaYW
6P0;IaX00`00Ha]S6`08Ha/00`00G_]Nn`09G_/00`00E_aFo008E_`00`00C_e>o@09C_d00`00B]e:
g@0<B]d00`00A]e6g@0;A]d00`00JeY[FP0?JeX00`00LeQcF005LeP00`00LeQcF004LeP00`00Oa9o
4P06Oa82000DOol00`00Oomoo`0;Ool000aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00Ioo`03001bmW;f00=bmP03001_5flG00]_5`03001[6F/I00Y[6@03001W6VLJ
00]W6P03001S6f<K00QS6`03001Nnekk00UNn`03001Fo5Kl00QFo003001>oDkm00U>o@03001:gD[M
00a:g@030016gDKM00U6g@03001[FV]J011[FP03001cF7=H00EcF003001cF7=H00EcF003001o4WlB
00Io4P8001Aoo`03001oogoo00Yoo`002goo00<007oo00001goo00<007oo000017oo00<007ooOol0
1Goo00<007;fL_H01G;f00<006lGKaL02flG0P002f/I00<006LJIaX02fLJ00<006<KHa/026<K00<0
05kkG_/02Ekk00<005KlE_`025Kl00<004kmC_d02Dkm00<004[MB]d02d[M00<004KMA]d024KM00<0
06]JJeX04V]J00<007=HLeP017=H00<007=HLeP01W=H00<007lBOa801GlB00<0065P00004goo00<0
07ooOol02Woo0006Ool30002Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00
L_IbmP06L_H2000=KaL00`00JaU[6@09JaT00`00IaYW6P0;IaX00`00Ha]S6`08Ha/00`00G_]Nn`09
G_/00`00E_aFo008E_`00`00C_e>o@09C_d00`00B]e:g@0;B]d00`00A]e6g@06A]d00`00Ic/0000D
JeX00`00LeQcF003LeP00`00LeQcF006LeP00`00Oa9o4P06Oa82000COol00`00Oomoo`0:Ool000]o
o`03001oo`0000Moo`8000Aoo`8000Ioo`03001bmW;f00UbmP03001_5flG00]_5`03001[6F/I00U[
6@03001W6VLJ00]W6P03001S6f<K00QS6`03001Nnekk00UNn`03001Fo5Kl00MFo003001>oDkm00Y>
o@03001:gD[M00]:g@030016gDKM00=6g@8000=W>`03001[FV]J019[FP03001cF7=H009cF003001c
F7=H00McF003001o4WlB00Io4P80019oo`03001oogoo00Yoo`002goo00<007oo00001goo00<007oo
Ool00goo00<007ooOol01Goo00<007;fL_H02W;f00<006lGKaL02flG00<006/IJaT02F/I00<006LJ
IaX02fLJ00<006<KHa/026<K00<005kkG_/025kk00<005KlE_`025Kl00<004kmC_d02Tkm00<004[M
B]d02d[M00D004KMA]e6g@0000EW>`03001[FV]J019[FP03001cF7=H009cF003001cF7=H00QcF003
001o4WlB00Io4P80015oo`03001oogoo00Yoo`0037oo00<007ooOol01Woo0`000goo00<007ooOol0
1Goo0P0037;f00<006lGKaL02flG00<006/IJaT02F/I00<006LJIaX02fLJ00<006<KHa/026<K00<0
05kkG_/025kk00<005KlE_`025Kl00<004kmC_d02Dkm00<004[MB]d034[M00<004KM00001fLk00<0
06]JJeX04V]J00D007=HLeQcF00000YcF003001o4WlB00Io4P03001QH000011oo`03001oogoo00Yo
o`006goo00<007ooOol017oo00@007KdM_@000abmP03001_5flG00]_5`03001[6F/I00U[6@03001W
6VLJ00]W6P03001S6f<K00QS6`03001Nnekk00QNn`03001Fo5Kl00QFo003001>oDkm00U>o@03001:
gD[M00]:g@8000UW>`03001[FV]J019[FP04001cF7=H000;LeP00`00Oa9o4P06Oa82000@Ool00`00
Oomoo`0:Ool001]oo`8000Eoo`05001fm7KdM_@0000<L_H00`00KaM_5`0;KaL00`00JaU[6@09JaT0
0`00IaYW6P0;IaX00`00Ha]S6`08Ha/00`00G_]Nn`08G_/00`00E_aFo008E_`00`00C_e>o@09C_d0
0`00B]e:g@09B]d00`00Ic]W>`0:Ic/00`00JeY[FP0BJeX00`00LeP0000<LeP00`00Oa9o4P06Oa82
000@Ool00`00Oomoo`09Ool001]oo`03001oogoo00=oo`03001fm7Kd00=fm003001bmW;f00YbmP03
001_5flG00]_5`03001[6F/I00U[6@03001W6VLJ00]W6P03001S6f<K00QS6`03001Nnekk00QNn`03
001Fo5Kl00QFo003001>oDkm00U>o@03001:gD[M00M:g@03001W>fLk00aW>`03001[FV]J019[FP80
00ecF003001o4WlB00Eo4P03001QH00000moo`03001oogoo00Uoo`006goo00<007ooOol00goo00<0
07KdM_@017Kd00<007;fL_H02W;f00<006lGKaL02flG00<006/IJaT02F/I00<006LJIaX02fLJ00<0
06<KHa/026<K00<005kkG_/025kk00<005KlE_`025Kl00<004kmC_d02Dkm00<004[MB]d014[M0P00
3fLk00<006]JJeX04V]J0P003G=H00<007lBOa801WlB0P003goo00<007ooOol02Goo000KOol00`00
Oomoo`03Ool00`00M_Afm005M_@2000;L_H00`00KaM_5`0;KaL00`00JaU[6@09JaT00`00IaYW6P0;
IaX00`00Ha]S6`08Ha/00`00G_]Nn`08G_/00`00E_aFo008E_`00`00C_e>o@09C_d00`00B]e:g@02
B]d00`00Ic]W>`0@Ic/00`00JeY[FP0BJeX2000=LeP00`00Oa9o4P06Oa82000>Ool00`00Oomoo`09
Ool001Yoo`8000Aoo`03001fm7Kd00Qfm003001bmW;f00UbmP03001_5flG00]_5`03001[6F/I00U[
6@03001W6VLJ00]W6P03001S6f<K00QS6`03001Nnekk00QNn`03001Fo5Kl00QFo003001>oDkm00U>
o@04001:gD[M000DIc/00`00JeY[FP0BJeX00`00LeQcF00<LeP00`00Oa9o4P06Oa82000=Ool00`00
Oomoo`09Ool001Yoo`03001oogoo00=oo`03001fm7Kd00Ufm003001bmW;f00UbmP03001_5flG00]_
5`03001[6F/I00U[6@03001W6VLJ00]W6P03001S6f<K00QS6`03001Nnekk00QNn`03001Fo5Kl00QF
o003001>oDkm00Q>o@<001IW>`03001[FV]J015[FP8000icF003001o4WlB00Eo4P8000eoo`03001o
ogoo00Uoo`006Woo00<007ooOol00goo0P002gKd00<007;fL_H02G;f00<006lGKaL02flG00<006/I
JaT02F/I00<006LJIaX02fLJ00<006<KHa/026<K00<005kkG_/025kk00<005KlE_`01eKl00<004km
C_d024km00<006LkIc/05fLk00<006]JJeX046]J0P003W=H00<007lBOa801WlB0P0037oo00<007oo
Ool02Goo000JOol00`00Oomoo`02Ool01000M]9fdP002gKd00<007;fL_H02G;f00<006lGKaL02flG
00<006/IJaT02F/I00<006LJIaX02fLJ00<006<KHa/026<K00<005kkG_/025kk00<005KlE_`01eKl
00<004kmC_d01Dkm0P0000=S?000Ic/05fLk00<006]JJeX046]J00<006]J00003W=H00<007lBOa80
1WlB0P002goo00<007ooOol02Goo000JOol20003Ool01@00M]9fdWKB00002gKd00<007;fL_H02G;f
0P0036lG00<006/IJaT02F/I00<006LJIaX02VLJ00<006<KHa/026<K00<005kkG_/025kk00<005Kl
E_`025Kl00<004kmC_d00dkm00<006<lHc`00V<l00<006LkIc/05VLk00<006]JJeX03f]J00@006]J
JeX000icF003001o4WlB00Eo4P8000aoo`03001oogoo00Qoo`006Woo00<007ooOol00Woo00<007KB
M]800WKB00<007KdM_@02GKd00<007;fL_H02W;f00<006lGKaL02VlG00<006/IJaT02F/I00<006LJ
IaX02VLJ00<006<KHa/026<K00<005kkG_/025kk00<005KlE_`025Kl00D004kmC_e>o@0000IS?003
001W>fLk01IW>`03001[FV]J00e[FP8000=[FP03001cF7=H00]cF003001o4WlB00Io4P8000]oo`03
001oogoo00Qoo`006Woo00<007ooOol00Woo00<007KBM]800gKB0P002WKd00<007;fL_H02W;f00<0
06lGKaL02VlG00<006/IJaT02F/I00<006LJIaX02VLJ00<006<KHa/026<K00<005kkG_/025kk00<0
05KlE_`01eKl10001f<l00<006LkIc/05fLk00<006]JJeX02F]J0`000V]J00@006]JJeX000icF003
001o4WlB00Io4P8000Yoo`03001oogoo00Qoo`006Woo00D007ooOomoo`0000QfdP03001fm7Kd00Qf
m003001bmW;f00YbmP03001_5flG00Y_5`03001[6F/I00U[6@03001W6VLJ00YW6P03001S6f<K00QS
6`03001Nnekk00QNn`03001Fo5Kl00AFo0800003Ool006<l00US?003001W>fLk01MW>`03001[FV]J
00E[FP<000I[FP04001[FV]J000>LeP00`00Oa9o4P05Oa800`00HF000009Ool00`00Oomoo`08Ool0
01Uoo`03001oo`00009oo`03001fdWKB00MfdP03001fm7Kd00Qfm003001bmW;f00YbmP03001_5flG
00Y_5`03001[6F/I00U[6@03001W6VLJ00YW6P03001S6f<K00QS6`03001Nnekk00QNn`03001Fo5Kl
00<00003Ool0000000aS?003001W>fLk01IW>`04001[FV]JJeX40009JeX01@00JeY[FV]J00003W=H
00<007lBOa801GlB0P002Goo00<007ooOol027oo000IOol20003Ool00`00M]9fdP08M]800`00M_Af
m008M_@00`00L_IbmP0:L_H00`00KaM_5`0:KaL00`00JaU[6@09JaT00`00IaYW6P0:IaX00`00Ha]S
6`08Ha/00`00G_]Nn`08G_/20003Ool00`00HcaS?00=Hc`00`00Ic]W>`0FIc/3000>JeX01@00JeY[
FV]J00003G=H00<007lBOa801WlB0P0027oo00<007ooOol027oo000DOol00`00Oomoo`02Ool00`00
Oomoo`02Ool2000:M]800`00M_Afm008M_@00`00L_IbmP0:L_H00`00KaM_5`0:KaL00`00JaU[6@09
JaT00`00IaYW6P0:IaX00`00Ha]S6`08Ha/00`00G_]Nn`05G_/20003Ool2000AHc`00`00Ic]W>`0B
Ic/300000fLk001[FP0?JeX01@00JeY[FV]J00003G=H00<007lBOa801WlB0P001goo00<007ooOol0
27oo000COol00`00Ool00003Ool00`00Oomoo`02Ool00`00NZl0000:M]800`00M_Afm008M_@00`00
L_IbmP0:L_H00`00KaM_5`0:KaL00`00JaU[6@09JaT00`00IaYW6P0:IaX00`00Ha]S6`08Ha/00`00
G_]Nn`02G_/20004Ool00`00HcaS?00BHc`00`00Ic]W>`0>Ic/30005Ic/00`00JeY[FP0>JeX01000
JeY[FP003W=H00<007lBOa801GlB0P0027oo00<007ooOol01goo000COol00`00Ool00003Ool00`00
Oomoo`02Ool01000NZmj[`002WKB00<007KdM_@027Kd0P002g;f00<006lGKaL02VlG00<006/IJaT0
2F/I00<006LJIaX02VLJ00<006<KHa/026<K00@005kk000000Eoo`03001S?6<l01AS?003001W>fLk
00YW>`<000UW>`03001[FV]J00e[FP05001[FV]JJeX0000=LeP00`00Oa9o4P06Oa820007Ool00`00
Oomoo`07Ool001=oo`03001oo`0000=oo`03001oogoo009oo`04001j[gZ_NZl20009M]800`00M_Af
m009M_@00`00L_IbmP09L_H00`00KaM_5`0:KaL00`00JaU[6@09JaT00`00IaYW6P0:IaX00`00Ha]S
6`08Ha/00`00Oomoo`03Ool2000GHc`00`00Ic]W>`06Ic/4000<Ic/00`00JeY[FP0>JeX01@00JeY[
FV]J00003G=H00<007lBOa801WlB0P001Woo00<007ooOol01goo000COol00`00Ool00003Ool00`00
Oomoo`02Ool00`00NZmj[`03NZl00`00M]9fdP07M]800`00M_Afm009M_@00`00L_IbmP09L_H00`00
KaM_5`0:KaL00`00JaU[6@09JaT00`00IaYW6P0:IaX00`00Ha]S6`05Ha/20005Ool00`00HcaS?00H
Hc`00`00Ic]W>`02Ic/3000AIc/00`00JeY[FP0>JeX01@00JeY[FV]J00003G=H00<007lBOa801GlB
0P001Woo00<007ooOol01goo000DOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00NZmj[`04NZl0
0`00M]9fdP07M]800`00M_Afm009M_@00`00L_IbmP09L_H00`00KaM_5`0:KaL00`00JaU[6@09JaT0
0`00IaYW6P0:IaX00`00Ha]S6`02Ha/20005Ool200000ell001S?00IHc`4000EIc/00`00JeY[FP0>
JeX01000JeY[FP003W=H00<007lBOa801GlB0P001Goo00<007ooOol01goo000HOol00`00Oomoo`03
Ool00`00NZmj[`05NZl00`00M]9fdP07M]82000:M_@00`00L_IbmP09L_H00`00KaM_5`0:KaL2000:
JaT00`00IaYW6P0:IaX01000Ha/000001Goo0P0015ll00<006<lHc`05F<l100066Lk00<006]JJeX0
3V]J00@006]JJeX000ecF003001o4WlB00Io4P03001oogoo00=oo`03001oogoo00Moo`0067oo0P00
17oo00<007Z_NZl01WZ_00<007KBM]8027KB00<007KdM_@027Kd00<007;fL_H02G;f0P0036lG00<0
06/IJaT026/I00<006LJIaX02VLJ00<007ooOol017oo00<005llGc`01Ell00<006<lHc`04F<l0`00
16<l00<006LkIc/05VLk00<006]JJeX03F]J00D006]JJeY[FP0000ecF003001o4WlB00Io4P03001o
ogoo009oo`03001oogoo00Moo`0067oo00<007ooOol00goo0P0027Z_00<007KBM]8027KB00<007Kd
M_@027Kd00<007;fL_H02W;f00<006lGKaL02VlG00<006/IJaT026/I00<006LJIaX026LJ00<007oo
Ool00goo0P002Ell00<006<lHc`036<l100026<l00<006LkIc/05FLk00<006]JJeX03V]J00D006]J
JeY[FP0000ecF003001o4WlB00Eo4P03001oogoo009oo`03001oogoo00Moo`0067oo00<007ooOol0
0goo00<007I:000027Z_00<007KBM]8027KB00<007KdM_@027Kd00<007;fL_H02W;f00<006lGKaL0
2VlG00<006/IJaT026/I00<006LJIaX01VLJ00<007ooOol00Woo0P0035ll00<006<lHc`026<l0`00
3F<l00<006LkIc/05FLk00<006]JJeX03V]J00@006]JJeX000icF003001o4WlB00Eo4P03001oogoo
009oo`03001oogoo00Ioo`0067oo00<007ooOol00goo00<007I:MTX00P001gZ_0P002GKB00<007Kd
M_@027Kd00<007;fL_H02W;f00<006lGKaL02VlG00<006/IJaT026/I00<006LJIaX00fLJ0P000goo
0P003ell00<006<lHc`016<l0`0046<l00<006LkIc/05VLk00<006]JJeX03V]J00@006]JJeX000ec
F003001o4WlB00Eo4P03001oogoo009oo`03001oogoo00Ioo`0067oo00<007ooOol017oo00D007I:
MTYfBP0000Qj[`03001fdWKB00MfdP03001fm7Kd00Qfm003001bmW;f00YbmP03001_5flG00Y_5`03
001[6F/I00Q[6@05001W6VLJIaX00004Ool00`00GcaO?00?Gc`01000HcaS?6<l0`0056<l00<006Lk
Ic/05VLk00<006]JJeX03F]J00D006]JJeY[FP0000ecF003001o4WlB00Ao4P03001oogoo009oo`03
001oogoo00Ioo`005goo0P001Woo00<007I:MTX00WI:00<007Z_NZl01WZ_00<007KBM]801gKB00<0
07KdM_@027Kd00<007;fL_H02W;f00<006lGKaL02VlG00<006/IJaT026/I00<006LJ00000goo0P00
4ell0`0066<l00<006LkIc/05FLk00<006]JJeX03V]J00D006]JJeY[FP0000ecF003001o4WlB009o
4P03001oogoo00=oo`03001oogoo00Ioo`005goo00<007ooOol01Goo00<007I:MTX00gI:00<007Z_
NZl01WZ_00<007KBM]801gKB00<007KdM_@027Kd00<007;fL_H02W;f00<006lGKaL02VlG00<006/I
JaT026/I00<007ooOol00P004Ell100000=O?000Hc`06F<l00<006LkIc/05FLk00<006]JJeX03V]J
00@006]JJeX000ecF003001o4WlB009o4P03001oogoo00=oo`03001oogoo00Ioo`005goo00<007oo
Ool01Goo00<007I:MTX017I:00<007Z_NZl01WZ_00<007KBM]801gKB00<007KdM_@027Kd00<007;f
L_H02W;f00<006lGKaL02VlG00<006/IJaT01V/I00@007ooOol0011O?0<000IO?003001S?6<l01QS
?003001W>fLk01EW>`03001[FV]J00i[FP04001[FV]J000=LeP01@00Oa9o4WlB00001Goo00<007oo
Ool01Woo000GOol00`00Oomoo`05Ool20006MTX00`00NZmj[`06NZl00`00M]9fdP07M]800`00M_Af
m008M_@2000;L_H00`00KaM_5`0:KaL00`00JaU[6@04JaT01P00Ool00000Gc`000aO?0<000YO?003
001S?6<l01QS?003001W>fLk01EW>`03001[FV]J00e[FP05001[FV]JJeX0000=LeP01000Oa9o4P00
1Goo00<007ooOol01Woo000GOol20007Ool20006MTX20007NZl00`00M]9fdP07M]800`00M_Afm009
M_@00`00L_IbmP09L_H00`00KaM_5`0:KaL00`00JaU[6@02JaT30004Gc`00`00GcaO?006Gc`3000>
Gc`00`00HcaS?00HHc`00`00Ic]W>`0EIc/00`00JeY[FP0=JeX01@00JeY[FV]J00003G=H0P001goo
00<007ooOol01Goo000GOol00`00Oomoo`06Ool01000KJ8000001WI:00<007Z_NZl01GZ_0P0027KB
0P002WKd00<007;fL_H02G;f00<006lGKaL02VlG00<006/IJaT00P001ell00<005llGc`00Ull0`00
4Ull00<006<lHc`05f<l00<006LkIc/05FLk00<006]JJeX03V]J00D006]JJeY[FP0000acF08000Mo
o`03001oogoo00Eoo`005goo00<007ooOol01goo00@006fRKJ8000IfBP03001j[gZ_00Ij[`03001f
dWKB00MfdP03001fm7Kd00Qfm003001bmW;f00UbmP03001_5flG00Y_5`8000YO?0@001IO?003001S
?6<l01MS?003001W>fLk01EW>`03001[FV]J00i[FP04001[FV]J000=LeP00`00Oomoo`05Ool00`00
Oomoo`05Ool001Moo`03001oogoo00Moo`05001]XVfRKJ800006MTX00`00NZmj[`06NZl00`00M]9f
dP07M]800`00M_Afm008M_@00`00L_IbmP09L_H00`00KaM_5`07KaL20009Gc`300000ell001O?00H
Gc`00`00HcaS?00GHc`00`00Ic]W>`0EIc/00`00JeY[FP0>JeX01000JeY[FP002g=H00<007ooOol0
1Woo00<007ooOol01Goo000GOol00`00Oomoo`08Ool01@00KJ9]XVfR00001WI:00<007Z_NZl01WZ_
00<007KBM]801gKB00<007KdM_@027Kd00<007;fL_H02G;f0P001FlG0P0025ll0`001Ell00<005ll
Gc`05ell00<006<lHc`05f<l00<006LkIc/05FLk00<006]JJeX03F]J00D006]JJeY[FP0000YcF003
001oogoo00Ioo`03001oogoo00Eoo`005Woo0`002Woo00D006fRKJ9]XP0000IfBP03001j[gZ_00Ij
[`03001fdWKB00MfdP03001fm7Kd00Qfm003001bmW;f00YbmP03001_5flG008000MO?0<000UO?003
001O?5ll01MO?003001S?6<l01MS?003001W>fLk01EW>`03001[FV]J00e[FP05001[FV]JJeX00008
LeP00`00Oomoo`07Ool00`00Oomoo`05Ool000Moo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00]oo`04001]XVfRKJ820005MTX20007NZl00`00M]9fdP07M]800`00M_Af
m008M_@00`00L_IbmP0:L_H20006Gc`3000=Gc`00`00GcaO?00GGc`00`00HcaS?00GHc`00`00Ic]W
>`0DIc/00`00JeY[FP0>JeX01000JeY[FP0027=H00<007ooOol01goo00<007ooOol01Goo0006Ool0
0`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0;Ool30003KJ800`00MTYfBP04MTX00`00NZmj
[`05NZl00`00M]9fdP07M]800`00M_Afm008M_@00`00L_IbmP07L_H200000e/m001O?002Gc`3000A
Gc`00`00GcaO?00GGc`00`00HcaS?00GHc`00`00Ic]W>`0DIc/00`00JeY[FP0>JeX01000JeY[FP00
1W=H00<007ooOol027oo00<007ooOol01Goo0006Ool00`00Ool00009Ool01@00Oomoogoo00003Woo
00<005B000000ffR00<007I:MTX017I:00<007Z_NZl01GZ_0P0027KB00<007KdM_@027Kd00<007;f
L_H017;f0P000e/m10005Ell00<005llGc`05ell00<006<lHc`05f<l00<006LkIc/056Lk00<006]J
JeX03F]J00D006]JJeY[FP0000AcF003001oogoo00Yoo`03001oogoo00Aoo`001Woo00<007oo0000
1goo0P0017oo00<007ooOol03Goo00<005B000000ffR00<007I:MTX017I:00<007Z_NZl01WZ_00<0
07KBM]801WKB00<007KdM_@027Kd00@007;fL_IbmP80009K?@<0009K?@03001O?5ll01EO?003001O
?5ll01IO?003001S?6<l01MS?003001W>fLk01EW>`03001[FV]J00e[FP05001[FV]JJeX00003LeP0
0`00Oomoo`0:Ool00`00Oomoo`04Ool000Ioo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo
00ioo`<000=]XP03001fBWI:00AfBP03001j[gZ_00Ij[`03001fdWKB00IfdP03001fm7Kd00Qfm0<0
0004Fcd000000006Fcd00`00GcaO?00EGc`00`00GcaO?00FGc`00`00HcaS?00GHc`00`00Ic]W>`0E
Ic/00`00JeY[FP0=JeX01000JeY[FP000W=H00<007ooOol02goo00<007ooOol017oo0007Ool00`00
Oomoo`06Ool30003Ool00`00Oomoo`0?Ool30003KJ800`00MTYfBP04MTX00`00NZmj[`06NZl00`00
M]9fdP06M]820007M_@5000:Fcd00`00GcaO?00EGc`00`00GcaO?00FGc`00`00HcaS?00GHc`00`00
Ic]W>`0DIc/00`00JeY[FP0>JeX01P00JeY[FP00LeP000eoo`03001oogoo00Aoo`005Woo00<007oo
Ool04Goo0`000VfR0P001GI:0P001gZ_00<007KBM]801gKB00@007KdM_Afm0D000iK?@03001O?5ll
01EO?003001O?5ll01IO?003001S?6<l01MS?003001W>fLk01AW>`03001[FV]J00i[FP04001[FV]J
000>Ool00`00Oomoo`04Ool001Eoo`03001oogoo01=oo`<000=]XP03001fBWI:00AfBP03001j[gZ_
00Ej[`03001fdWKB00MfdPH0015K?@03001O?5ll01EO?003001O?5ll01IO?003001S?6<l01MS?003
001W>fLk01AW>`03001[FV]J00e[FP03001[FP0000moo`03001oogoo00Aoo`005Goo0P005Goo1000
0VfR00<007I:MTX017I:00<007Z_NZl01GZ_00<007KBM]800WKB1@001E<N00<005/mFcd03e/m00<0
05llGc`05Ell00<005llGc`05Ull00<006<lHc`05f<l00<006LkIc/056Lk00<006]JJeX03F]J00<0
07ooOol03Woo00<007ooOol017oo000EOol00`00Oomoo`0EOol200001@hL000006fR00001WI:00<0
07Z_NZl00gZ_20002E<N00<005/mFcd03e/m0P005Ull00<005llGc`05Ull00<006<lHc`05f<l00<0
06LkIc/056Lk00<006]JJeX02f]J00<007oo000047oo00<007ooOol00goo000EOol00`00Oomoo`0F
Ool300000`hL0000000<0002@_h4000<Dah00`00FceK?@0@Fcd00`00GcaO?00DGc`00`00GcaO?00F
Gc`00`00HcaS?00FHc`00`00Ic]W>`0DIc/00`00JeY[FP0:JeX01@00Oomoogoo00003goo00<007oo
Ool00goo000EOol00`00Oomoo`0HOol200023Q`00`00;[l^_`05;[l00`00@_i2oP030004@_h00`00
DaiC7P0:Dah2000AFcd00`00GcaO?00DGc`00`00GcaO?00FGc`00`00HcaS?00FHc`00`00Ic]W>`0D
Ic/00`00JeY[FP08JeX00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool001Eoo`03001o
ogoo01Uoo`80008>7003000^_bjo00<^_`@000Q2oP03001C7U<N00]C7P03001K?E/m00mK?@03001O
?5ll01AO?003001O?5ll01IO?003001S?6<l01IS?003001W>fLk01AW>`03001[FV]J00I[FP03001o
ogoo00Aoo`03001oogoo00aoo`03001oogoo00=oo`0057oo0P0077oo0P000PhL1@000bjo0P0024;n
0P0035<N00<005/mFcd03e/m00<005llGc`055ll00<005llGc`05Ull00<006<lHc`05V<l00<006Lk
Ic/056Lk00<006]JJeX016]J00<007ooOol01Woo00<007ooOol02goo00<007ooOol00goo000DOol0
0`00Oomoo`0LOol60007;[l00`00@_i2oP07@_h00`00DaiC7P0:Dah00`00FceK?@0?Fcd00`00GcaO
?00DGc`00`00GcaO?00FGc`00`00HcaS?00FHc`00`00Ic]W>`0DIc/00`00JeY[FP02JeX00`00Oomo
o`08Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool001Aoo`03001oogoo01]oo`D0008>7003000^_bjo
00D^_`030012oT;n00M2oP03001C7U<N00YC7P03001K?E/m00mK?@03001O?5ll01AO?003001O?5ll
01IO?003001S?6<l01IS?003001W>fLk01=W>`05001[FV]JJeX0000<Ool00`00Oomoo`09Ool00`00
Oomoo`03Ool001Aoo`03001oogoo01Qoo`<000Aoo`80008>7003000^_bjo00D^_`030012oT;n00M2
oP03001C7U<N00YC7P03001K?E/m00mK?@03001O?5ll01AO?003001O?5ll01IO?003001S?6<l01IS
?003001W>fLk01=W>`03001[FP0000eoo`03001oogoo00Uoo`03001oogoo00=oo`0057oo00<007oo
Ool057oo100027oo0P000PhL00<002jo;[l01Bjo00<004;n@_h01d;n00<005<NDah02U<N00<005/m
Fcd03e/m00<005llGc`055ll00<005llGc`05Ell00<006<lHc`05V<l00<006LkIc/056Lk00<007oo
Ool03Goo00<007ooOol02Goo00<007ooOol00Woo000DOol2000BOol3000=Ool200023Q`20006;[l0
0`00@_i2oP07@_h00`00DaiC7P0:Dah00`00FceK?@0?Fcd00`00GcaO?00DGc`00`00GcaO?00EGc`0
0`00HcaS?00FHc`00`00Ic]W>`0AIc/2000AOol00`00Oomoo`08Ool00`00Oomoo`02Ool001Aoo`03
001oogoo00ioo`<0015oo`8000<>7003000^_bjo00@^_`8000Q2oP03001C7U<N00YC7P03001K?E/m
00mK?@03001O?5ll01=O?003001O?5ll01IO?003001S?6<l01IS?003001W>fLk00mW>`03001oogoo
019oo`03001oogoo00Moo`03001oogoo009oo`0057oo00<007ooOol02goo0`005Goo0P000`hL00<0
02jo;[l01Bjo00<004;n@_h01T;n0P002e<N00<005/mFcd03e/m00<005llGc`04ell00<005llGc`0
5Ull00<006<lHc`05V<l00<006LkIc/03FLk00<007ooOol04goo00<007ooOol01goo00<007ooOol0
0Woo000DOol00`00Oomoo`08Ool3000JOol200023Q`00`00;[l^_`05;[l00`00@_i2oP07@_h00`00
DaiC7P09Dah2000@Fcd00`00GcaO?00CGc`00`00GcaO?00FGc`00`00HcaS?00FHc`00`00Ic]W>`0:
Ic/2000GOol00`00Oomoo`06Ool00`00Oomoo`02Ool001=oo`8000Ioo`@001ioo`80008>7003000^
_bjo00D^_`030012oT;n00M2oP03001C7U<N00YC7P03001K?E/m00iK?@03001O?5ll01=O?003001O
?5ll01IO?003001S?6<l01IS?003001W>fLk00QW>`03001oogoo01Qoo`03001oogoo00Eoo`03001o
ogoo009oo`0037oo1@000Woo00<007ooOol00Woo0`008goo0P000PhL00<002jo;[l01Bjo00<004;n
@_h01d;n00<005<NDah02U<N00<005/mFcd03U/m00<005llGc`04ell00<005llGc`05Ull00<006<l
Hc`05V<l00<006LkIc/01FLk0P0077oo00<007ooOol017oo00<007ooOol00Woo000>Ool00`00Oomo
o`02Ool00`00Ool00002000WOol200023Q`20006;[l00`00@_i2oP07@_h00`00DaiC7P0:Dah00`00
FceK?@0>Fcd00`00GcaO?00CGc`00`00GcaO?00FGc`00`00HcaS?00EHc`00`00Ic]W>`04Ic/00`00
Oomoo`0LOol00`00Oomoo`05Ool00`00Oomoo`01Ool000ioo`03001oogoo009oo`<002Yoo`8000<>
7003000^_bjo00@^_`030012oT;n00M2oP03001C7U<N00YC7P03001K?E/m00iK?@03001O?5ll01=O
?003001O?5ll01IO?003001S?6<l01ES?003001W>fLk009W>`03001oogoo01ioo`03001oogoo00Ao
o`03001oogoo005oo`003Woo00<007ooOol00goo0P00;7oo0P000PhL00<002jo;[l012jo0P0024;n
00<005<NDah02U<N00<005/mFcd03U/m0P0055ll00<005llGc`05Ull00<006<lHc`05F<l00@006Lk
0000029oo`03001oogoo00=oo`03001oogoo005oo`003Woo00<007ooOol017oo0P00;7oo0P000PhL
00<002jo;[l01Bjo00<004;n@_h01T;n0P002e<N00<005/mFcd03e/m00<005llGc`04Ull00<005ll
Gc`05Ull00<006<lHc`05F<l00<007ooOol08goo00<007ooOol00Woo00<007ooOol00Goo000=Ool2
0008Ool2000[Ool200023Q`00`00;[l^_`05;[l00`00@_i2oP07@_h00`00DaiC7P09Dah00`00FceK
?@0?Fcd00`00GcaO?00BGc`00`00GcaO?00FGc`00`00HcaS?00BHc`2000WOol01@00Oomoogoo0000
0goo000HOol00`00Oomoo`0ZOol200023Q`20006;[l00`00@_i2oP07@_h00`00DaiC7P09Dah00`00
FceK?@0?Fcd00`00GcaO?00BGc`00`00GcaO?00FGc`00`00HcaS?00@Hc`00`00Oomoo`0WOol01@00
Oomoogoo00000goo000IOol2000[Ool200033Q`00`00;[l^_`04;[l00`00@_i2oP07@_h00`00DaiC
7P09Dah00`00FceK?@0?Fcd00`00GcaO?00BGc`00`00GcaO?00FGc`00`00HcaS?00=Hc`2000[Ool0
1000Oomoo`000goo000KOol2000[Ool01@003Q`>70hL00001Rjo00<004;n@_h01d;n00<005<NDah0
2E<N00<005/mFcd03e/m00<005llGc`04Ull00<005llGc`05Ell00<006<lHc`036<l00<007ooOol0
;7oo00<007oo00000goo000LOol00`00Oomoo`0ZOol200023Q`00`00;[l^_`04;[l20008@_h00`00
DaiC7P09Dah2000@Fcd00`00GcaO?00BGc`00`00GcaO?00EGc`00`00HcaS?009Hc`2000`Ool00`00
Ool00002Ool001=oo`03001oogoo00Moo`<002Yoo`80008>7003000^_bjo00D^_`030012oT;n00I2
oP03001C7U<N00YC7P03001K?E/m00iK?@03001O?5ll019O?003001O?5ll01EO?003001S?6<l00MS
?003001oogoo031oo`03001oo`00009oo`004Woo00<007oo00002Woo00<007ooOol0:Goo0P000PhL
00<002jo;[l01Bjo00<004;n@_h01T;n0P002e<N00<005/mFcd03U/m00<005llGc`04Ull00<005ll
Gc`05Ell00<006<lHc`016<l0P00=7oo0P000Woo000BOol00`00Ool0000;Ool00`00Oomoo`0YOol2
00023Q`20006;[l00`00@_i2oP07@_h00`00DaiC7P09Dah00`00FceK?@0>Fcd00`00GcaO?00BGc`0
0`00GcaO?00EGc`00`00HcaS?002Hc`00`00Oomoo`0dOol20002Ool0019oo`03001oo`0000aoo`80
02]oo`05000>70hL3Q`00006;[l00`00@_i2oP07@_h00`00DaiC7P09Dah00`00FceK?@0>Fcd00`00
GcaO?00BGc`00`00GcaO?00EGc`01000Hc`00000<goo100017oo000BOol00`00Ool0000=Ool2000[
Ool200023Q`00`00;[l^_`04;[l00`00@_i2oP07@_h00`00DaiC7P09Dah00`00FceK?@0>Fcd00`00
GcaO?00BGc`00`00GcaO?00EGc`00`00Oomoo`0_Ool40008Ool001=oo`03001oogoo00ioo`03001o
o`0002Uoo`80008>7003000^_bjo00@^_`8000Q2oP03001C7U<N00UC7P03001K?E/m00iK?@03001O
?5ll019O?003001O?5ll019O?08002ioo`@000aoo`009Goo00<007ooOol0:Goo0P000PhL00<002jo
;[l01Bjo00<004;n@_h01T;n00<005<NDah02E<N00<005/mFcd03U/m00<005llGc`04Ull00<005ll
Gc`03ell0P00;7oo100047oo000VOol2000ZOol200023Q`20006;[l00`00@_i2oP06@_h00`00DaiC
7P09Dah00`00FceK?@0>Fcd00`00GcaO?00BGc`00`00GcaO?00=Gc`00`00Oomoo`0XOol4000DOol0
02Qoo`8002Yoo`05000>70hL3Q`00006;[l00`00@_i2oP06@_h2000:Dah00`00FceK?@0>Fcd00`00
GcaO?00BGc`00`00GcaO?00:Gc`2000XOol3000HOol002Uoo`03001oogoo02Uoo`80008>7003000^
_bjo00@^_`030012oT;n00M2oP03001C7U<N00QC7P8000mK?@03001O?5ll019O?003001O?5ll00MO
?08002Ioo`@001]oo`00:Woo0`009goo00@007oo0000008>7003000^_bjo00@^_`030012oT;n00M2
oP03001C7U<N00UC7P03001K?E/m00eK?@8001=O?003001O?5ll00EO?003001oogoo029oo`@001mo
o`00;7oo00<007ooOol09Goo00<007ooOol00P000PhL00<002jo;[l012jo0P0024;n00<005<NDah0
2E<N00<005/mFcd03U/m00<005llGc`04Ell00<005llGc`00Ull0P008Goo10008goo000]Ool00`00
Oomoo`0TOol01000Oomoogoo0P000PhL0P001Rjo00<004;n@_h01T;n00<005<NDah02E<N00<005/m
Fcd03U/m00<005llGc`04Ell00@005ll000001moo`@002Moo`007goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo0P0097oo00<007ooOol00goo00D000hL3Q`>700000H^_`030012oT;n
00I2oP03001C7U<N00UC7P03001K?E/m00iK?@03001O?5ll011O?08001eoo`@002]oo`007Woo00<0
07oo00001goo00<007oo00001Goo00<007ooOol08Goo00<007ooOol017oo00D000hL3Q`>700000H^
_`030012oT;n00I2oP03001C7U<N00UC7P03001K?E/m00iK?@03001O?5ll00eO?08001]oo`@002mo
o`007Woo00<007oo00002Goo00<007ooOol017oo0P008Goo00<007ooOol01Goo0P000PhL00<002jo
;[l012jo00<004;n@_h01T;n0P002U<N00<005/mFcd03U/m00<005llGc`02Ull0P006Woo0`00<goo
000NOol00`00Ool00007Ool20008Ool00`00Oomoo`0OOol00`00Oomoo`06Ool200023Q`00`00;[l^
_`04;[l00`00@_i2oP07@_h00`00DaiC7P08Dah00`00FceK?@0>Fcd00`00GcaO?006Gc`3000HOol4
000fOol001ioo`03001oo`0000Moo`03001oogoo00Qoo`<001ioo`03001oogoo00Moo`80008>7003
000^_bjo00@^_`030012oT;n00M2oP03001C7U<N00QC7P03001K?E/m00iK?@03001O?5ll00=O?080
01Moo`@003Yoo`007goo00<007ooOol01Woo0`002Woo00<007ooOol077oo00<007ooOol02Goo00<0
00hL3Q`00P001Bjo0P0024;n00<005<NDah025<N00<005/mFcd03U/m00<005llGc`00P005Goo1000
?Woo000fOol00`00Oomoo`0KOol00`00Oomoo`0:Ool01@003Q`>70hL00001Rjo00<004;n@_h01T;n
00<005<NDah025<N0P003U/m0`004goo1000@Woo000gOol2000KOol00`00Oomoo`0;Ool200023Q`0
0`00;[l^_`04;[l00`00@_i2oP06@_h00`00DaiC7P09Dah00`00FceK?@09Fcd2000BOol40016Ool0
03Uoo`03001oogoo01Qoo`03001oogoo00aoo`80008>7003000^_bjo00@^_`030012oT;n00I2oP03
001C7U<N00UC7P03001K?E/m00IK?@80015oo`<004Yoo`00>Woo0P0067oo00<007ooOol03Woo00@0
00hL3Q`000H^_`030012oT;n00I2oP8000YC7P03001K?E/m00=K?@8000moo`@004eoo`00>goo0P00
5goo00<007ooOol03goo0P0000<>700000001Bjo00<004;n@_h01d;n00<005<NDah025<N00<005/m
Fcd00P003Goo1000DGoo000mOol2000EOol00`00Oomoo`0AOol200000`hL000^_`04;[l20008@_h0
0`00DaiC7P06Dah4000;Ool4001EOol0039oo`D000Moo`03001oogoo01=oo`03001oogoo01=oo`<0
00H^_`030012oT;n00I2oP04001C7U<NDah4000;Ool4001IOol003Aoo`03001oogoo00Qoo`<0019o
o`03001oogoo01Eoo`D000<^_`030012oT;n00=2oPH000]oo`@005eoo`00=7oo00<007ooOol02Woo
00<007ooOol047oo00<007ooOol06Woo2@003Goo1000HGoo000dOol00`00Oomoo`0;Ool00`00Ool0
000?Ool00`00Oomoo`0]Ool3001UOol003Aoo`03001oogoo00aoo`8000moo`03001oogoo02Uoo`@0
06Qoo`00<goo0P003goo0P003Woo00<007ooOol09Goo1000K7oo0016Ool2000;Ool00`00Oomoo`0R
Ool4001`Ool004Moo`03001oogoo00Uoo`03001oogoo01ioo`@007Aoo`00B7oo0`0027oo00<007oo
Ool06Woo1000N7oo0019Ool20008Ool00`00Oomoo`0GOol3001lOol004]oo`8000Ioo`03001oogoo
01=oo`@007moo`00?7oo1@000Woo00<007ooOol00Woo00@007ooOomoo`8000Eoo`03001oogoo00mo
o`@008=oo`00?Woo00<007ooOol01Woo00<007oo000017oo0P000goo00<007ooOol02goo1000Qgoo
000nOol00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`020009Ool4002;Ool003ioo`03001o
ogoo00Ioo`8000Moo`@000Eoo`@008moo`00?Woo00<007ooOol01Woo00<007ooOol027oo0P0000=o
o`0000000P00Tgoo000mOol20008Ool30009Ool2002GOol00>aoo`00k7oo003/Ool00>aoo`00D7oo
0`00VGoo001@Ool00`00Oomoo`2IOol0055oo`03001oogoo09Qoo`00DGoo00<007ooOol0V7oo001@
Ool00`00Ool0002IOol0055oo`03001oogoo09Qoo`00\
\>"],
  ImageRangeCache->{{{0, 235}, {217, 0}} -> {-0.0894094, -0.0298798, 
  0.00461624, 0.00461624}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that although the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam constraints constrain one degree of freedom in the model (or two in \
the case of ",
  StyleBox["CurveToPoint2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "), they actually add between two and five equations to the model. This is \
because each cam constraint also adds one to four symbols to the model's \
dependent variable list (two parameters for each surface and one for each \
curve) for a net loss of one or two degrees of freedom. This anomaly is of no \
consequence to the user except when a cam constraint is used within ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In these cases the added symbols in the cam constraint must be dealt \
with in the other stages of the switch function, usually by using the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to set the added symbols equal to a constant."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToPoint2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a space curve with a point follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the space curve as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be a differentiable parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CurveToPoint2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that ",
  StyleBox["point",
    FontSlant->"Italic"],
  " lies on the locus of the space curve, constraining two degrees of \
freedom. \n\n",
  StyleBox["CurveToPlane1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains a space curve to lie in contact with a plane that is normal to \
",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the space curve as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["CurveToCylinder1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " contains a space curve to be in tangent contact with a cylinder with \
specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ". The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the space curve as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["CurveToCam1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["gamma",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["delta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains a space curve to be in tangent contact with a spatial surface. \
The locus of ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " defines the space curve as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", and the locus of ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " defines the spatial surface as a function of ",
  StyleBox["gamma",
    FontSlant->"Italic"],
  " and ",
  StyleBox["delta",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Space curve constraints."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToPoint1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a spatial surface with a point follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToPoint1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that ",
  StyleBox["point",
    FontSlant->"Italic"],
  " lie directly on the cam surface. \n \n",
  StyleBox["CamToSphere1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" rad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a spatial surface with a spherical follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToSphere1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the surface is in contact with a sphere of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["CamToPlane1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a spatial cam surface with a planar follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the cam surface lie in tangent contact with a plane \
specified by axis. \n \n",
  StyleBox["CamToCam1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["locuspoint2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["gamma",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["delta",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models two spatial cam surfaces in tangent contact with each other. The \
loci of the ",
  StyleBox["locuspointi",
    FontSlant->"Italic"],
  " define the cam surfaces as functions of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ", ",
  StyleBox["gamma",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["delta",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Spatial surface constraints."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that each symbol in a cam constraint must be accompanied by a \
numerical initial guess, ",
  StyleBox["guess",
    FontSlant->"Italic"],
  ".\n\nThe locus point that is passed to a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam constraint must be a valid ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " point object containing the parametrically defined point. Also, the point \
must evaluate to a three-element list of differentiable expressions that are \
functionally dependent on the parameter ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", at the time that the constraints are processed with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is because the locus point is differentiated with respect to its \
controlling parameters by the ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. Thus, if the locus point is not an explicit function of its \
parameters when passed to ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " its derivative will be zero.\n\nNote that all cam relationships are \
restricted to being in point contact. If two cam surfaces are defined such \
that they instantaneously have line contact instead of point contact, a \
singularity will result. \n\nSome cam constraints are sensitive to which side \
of the cam surface the follower is on. The outside of a surface is defined as \
the side of the positive normal, which is the cross product of the direction \
of the surface gradient with respect to the first parameter and the direction \
of the surface gradient with respect to the second parameter.\n\n",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a special graphics function provided to parametrically plot the cam \
profiles in global coordinates. Note that ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics object, with the head ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", not a graphics primitive like most of the other ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["locuspoint",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, min, max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a graphics object representing the space curve that is defined by \
the locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", which must be a parametric function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object returned by ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not evaluated until numeric values are available for ",
  StyleBox["Xn",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Yn",
    FontSlant->"Italic"],
  ", and so on, where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the body number of the cam body.\n\n",
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["locuspoint, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, min, max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, min, max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " plots a spatial surface that is a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["lpnt...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, min, max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " plots several point loci ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the same options as ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with some different defaults."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A cam-specific graphics function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " produces the same output as would ",
  StyleBox["ParametricPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", except that ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " transforms the cam profile into the global coordinate system. ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not evaluate directly to a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object because numeric values for the coordinate transformation are not \
available. Instead, ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that evaluates to a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object when numbers are available for the transformation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CamPlot[Point[2, locuspoint], {s, 0, 2\ \[Pi]}, {t, 0, 2}, 
      PlotPoints \[Rule] {35, 2}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysPlot[{X2, Y2, 
        Z2}, {{2\ \((\(-\(1\/2\)\) + Ei2\^2 + Eo2\^2)\), 
          2\ \((Ei2\ Ej2 - Ek2\ Eo2)\), 2\ \((Ei2\ Ek2 + Ej2\ Eo2)\)}, {
          2\ \((Ei2\ Ej2 + Ek2\ Eo2)\), 
          2\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\), 
          2\ \((Ej2\ Ek2 - Ei2\ Eo2)\)}, {2\ \((Ei2\ Ek2 - Ej2\ Eo2)\), 
          2\ \((Ej2\ Ek2 + Ei2\ Eo2)\), 
          2\ \((\(-\(1\/2\)\) + Ek2\^2 + Eo2\^2)\)}}, {{
          Cos[s]\ If[\[Pi]\/2 < s < \(3\ \[Pi]\)\/2, 1, 1 + Cos[s]], t, 
          Sin[s]}}, "<>"]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "When numbers are available for ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on, the ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object evaluates to a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here we show the repositioned cam surface."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[%
         /. {X2 \[Rule] 1, Y2 \[Rule] \(-2\), Z2 \[Rule] 0.5, Eo2 \[Rule] .7, 
          Ei2 \[Rule] .7, Ej2 \[Rule] 0, Ek2 \[Rule] 0}, 
      DisplayFunction \[Rule] $DisplayFunction, Boxed \[Rule] True]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93205 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-016 1.01565 -0.00990805 1.01565 [
[ 0 0 0 0 ]
[ 1 .93205 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.05813 .26435 m
0 .70012 L
s
0 .70012 m
.30529 .93205 L
s
.30529 .93205 m
.32568 .52536 L
s
.32568 .52536 m
.05813 .26435 L
s
.74012 0 m
.94521 .32376 L
s
.94521 .32376 m
1 .75354 L
s
1 .75354 m
.77434 .45776 L
s
.77434 .45776 m
.74012 0 L
s
.05813 .26435 m
0 .70012 L
s
0 .70012 m
.77434 .45776 L
s
.77434 .45776 m
.74012 0 L
s
.74012 0 m
.05813 .26435 L
s
.32568 .52536 m
.94521 .32376 L
s
.94521 .32376 m
1 .75354 L
s
1 .75354 m
.30529 .93205 L
s
.30529 .93205 m
.32568 .52536 L
s
0 0 m
1 0 L
1 .93205 L
0 .93205 L
closepath
clip
newpath
.5 Mabswid
.4595 .86492 m .41618 .86713 L .42952 .48467 L p .666 .432 .556 r
F P
0 g
s
.42952 .48467 m .46854 .4821 L .4595 .86492 L p .666 .432 .556 r
F P
0 g
s
.39005 .48274 m .42952 .48467 L .41618 .86713 L p .709 .468 .558 r
F P
0 g
s
.41618 .86713 m .37232 .8653 L .39005 .48274 L p .709 .468 .558 r
F P
0 g
s
.3512 .47637 m .39005 .48274 L .37232 .8653 L p .749 .503 .559 r
F P
0 g
s
.50111 .8587 m .4595 .86492 L .46854 .4821 L p .618 .392 .552 r
F P
0 g
s
.46854 .4821 m .50603 .47509 L .50111 .8587 L p .618 .392 .552 r
F P
0 g
s
.37232 .8653 m .32911 .85945 L .3512 .47637 L p .749 .503 .559 r
F P
0 g
s
.31407 .46568 m .3512 .47637 L .32911 .85945 L p .789 .538 .558 r
F P
0 g
s
.54167 .84813 m .50111 .8587 L .50603 .47509 L p .562 .347 .546 r
F P
0 g
s
.50603 .47509 m .54253 .46327 L .54167 .84813 L p .562 .347 .546 r
F P
0 g
s
.32911 .85945 m .2877 .84972 L .31407 .46568 L p .789 .538 .558 r
F P
0 g
s
.27972 .45092 m .31407 .46568 L .2877 .84972 L p .829 .575 .555 r
F P
0 g
s
.59073 .8306 m .54167 .84813 L .54253 .46327 L p .512 .307 .539 r
F P
0 g
s
.54253 .46327 m .58662 .44374 L .59073 .8306 L p .512 .307 .539 r
F P
0 g
s
.2877 .84972 m .24929 .83631 L .27972 .45092 L p .829 .575 .555 r
F P
0 g
s
.24922 .43243 m .27972 .45092 L .24929 .83631 L p .871 .615 .548 r
F P
0 g
s
.64787 .80618 m .59073 .8306 L .58662 .44374 L p .475 .279 .534 r
F P
0 g
s
.58662 .44374 m .63781 .41665 L .64787 .80618 L p .475 .279 .534 r
F P
0 g
s
.24929 .83631 m .21502 .8195 L .24922 .43243 L p .871 .615 .548 r
F P
0 g
s
.22357 .41066 m .24922 .43243 L .21502 .8195 L p .916 .66 .536 r
F P
0 g
s
.70924 .7759 m .64787 .80618 L .63781 .41665 L p .441 .253 .529 r
F P
0 g
s
.63781 .41665 m .69258 .38319 L .70924 .7759 L p .441 .253 .529 r
F P
0 g
s
.21502 .8195 m .18603 .7997 L .22357 .41066 L p .916 .66 .536 r
F P
0 g
s
.20371 .38617 m .22357 .41066 L .18603 .7997 L p .961 .711 .512 r
F P
0 g
s
.18603 .7997 m .16337 .77739 L .20371 .38617 L p .961 .711 .512 r
F P
0 g
s
.19047 .35966 m .20371 .38617 L .16337 .77739 L p .995 .762 .46 r
F P
0 g
s
.76953 .7413 m .70924 .7759 L .69258 .38319 L p .401 .223 .522 r
F P
0 g
s
.69258 .38319 m .74615 .34512 L .76953 .7413 L p .401 .223 .522 r
F P
0 g
s
.16337 .77739 m .14801 .7532 L .19047 .35966 L p .995 .762 .46 r
F P
0 g
s
.18455 .33193 m .19047 .35966 L .14801 .7532 L p .967 .78 .345 r
F P
0 g
s
.82237 .70437 m .76953 .7413 L .74615 .34512 L p .341 .179 .511 r
F P
0 g
s
.74615 .34512 m .79281 .3047 L .82237 .70437 L p .341 .179 .511 r
F P
0 g
s
.14801 .7532 m .14077 .72783 L .18455 .33193 L p .967 .78 .345 r
F P
0 g
s
.18643 .30389 m .18455 .33193 L .14077 .72783 L p .757 .671 .12 r
F P
0 g
s
.14077 .72783 m .14224 .70212 L .18643 .30389 L p .757 .671 .12 r
F P
0 g
s
.19635 .27652 m .18643 .30389 L .14224 .70212 L p 0 0 .149 r
F P
0 g
s
.86102 .66748 m .82237 .70437 L .79281 .3047 L p .228 .098 .487 r
F P
0 g
s
.79281 .3047 m .82664 .26454 L .86102 .66748 L p .228 .098 .487 r
F P
0 g
s
.14224 .70212 m .15276 .67697 L .19635 .27652 L p 0 0 .149 r
F P
0 g
s
.21424 .25088 m .19635 .27652 L .15276 .67697 L p .016 0 .328 r
F P
0 g
s
.87933 .63313 m .86102 .66748 L .82664 .26454 L p 0 0 .404 r
F P
0 g
s
.82664 .26454 m .84232 .22735 L .87933 .63313 L p 0 0 .404 r
F P
0 g
s
.15276 .67697 m .17231 .65336 L .21424 .25088 L p .016 0 .328 r
F P
0 g
s
.23969 .228 m .21424 .25088 L .17231 .65336 L p .255 .066 .42 r
F P
0 g
s
.17231 .65336 m .20049 .63226 L .23969 .228 L p .255 .066 .42 r
F P
0 g
s
.27193 .20886 m .23969 .228 L .20049 .63226 L p .407 .189 .467 r
F P
0 g
s
.87286 .60365 m .87933 .63313 L .84232 .22735 L p .816 .59 .033 r
F P
0 g
s
.84232 .22735 m .83607 .19561 L .87286 .60365 L p .816 .59 .033 r
F P
0 g
s
.20049 .63226 m .23646 .6146 L .27193 .20886 L p .407 .189 .467 r
F P
0 g
s
.3116 .19368 m .27193 .20886 L .23646 .6146 L p .511 .274 .492 r
F P
0 g
s
.23646 .6146 m .28095 .60058 L .3116 .19368 L p .511 .274 .492 r
F P
0 g
s
.36767 .17914 m .3116 .19368 L .28095 .60058 L p .57 .323 .503 r
F P
0 g
s
.83985 .58089 m .87286 .60365 L .83607 .19561 L p .921 .607 .431 r
F P
0 g
s
.83607 .19561 m .80648 .17124 L .83985 .58089 L p .921 .607 .431 r
F P
0 g
s
.28095 .60058 m .34405 .58719 L .36767 .17914 L p .57 .323 .503 r
F P
0 g
s
.43886 .16565 m .36767 .17914 L .34405 .58719 L p .602 .35 .508 r
F P
0 g
s
.78184 .56589 m .83985 .58089 L .80648 .17124 L p .796 .504 .495 r
F P
0 g
s
.80648 .17124 m .75497 .1553 L .78184 .56589 L p .796 .504 .495 r
F P
0 g
s
.34405 .58719 m .42435 .57479 L .43886 .16565 L p .602 .35 .508 r
F P
0 g
s
.52016 .15472 m .43886 .16565 L .42435 .57479 L p .626 .37 .51 r
F P
0 g
s
.42435 .57479 m .51622 .56479 L .52016 .15472 L p .626 .37 .51 r
F P
0 g
s
.60494 .14819 m .52016 .15472 L .51622 .56479 L p .651 .39 .511 r
F P
0 g
s
.70353 .5588 m .78184 .56589 L .75497 .1553 L p .724 .448 .508 r
F P
0 g
s
.75497 .1553 m .6857 .14789 L .70353 .5588 L p .724 .448 .508 r
F P
0 g
s
.51622 .56479 m .61214 .55889 L .60494 .14819 L p .651 .39 .511 r
F P
0 g
s
.6857 .14789 m .60494 .14819 L .61214 .55889 L p .681 .414 .511 r
F P
0 g
s
.61214 .55889 m .70353 .5588 L .6857 .14789 L p .681 .414 .511 r
F P
0 g
s
.25 Mabswid
.74012 0 m
.94521 .32376 L
s
.94521 .32376 m
1 .75354 L
s
1 .75354 m
.77434 .45776 L
s
.77434 .45776 m
.74012 0 L
s
.05813 .26435 m
0 .70012 L
s
0 .70012 m
.77434 .45776 L
s
.77434 .45776 m
.74012 0 L
s
.74012 0 m
.05813 .26435 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{279, 261},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004G00011A000`40O003h00Oogoo67oo003<Ool2
0019Ool00<Yoo`800003Ool0000004Qoo`00agoo0`000goo0P00B7oo0034Ool30006Ool00`00Ool0
0017Ool00<9oo`8000Uoo`04001oogoo0016Ool00;moo`<000]oo`04001oogoo0016Ool00;eoo`80
00ioo`05001oogooOol00015Ool00;Yoo`<0015oo`04001oogoo0015Ool00;Moo`<001Aoo`05001o
ogooOol00014Ool00;Eoo`8001Moo`03001oogoo009oo`03001oogoo045oo`00/Woo0`006Goo00<0
07ooOol00Woo00<007ooOol0@Goo002`Ool2000LOol00`00Oomoo`03Ool00`00Oomoo`10Ool00:eo
o`<001ioo`03001oogoo00Aoo`03001oogoo03moo`00Zgoo0P008Goo00<007ooOol017oo00<007oo
Ool0?goo002XOol3000SOol00`00Oomoo`05Ool00`00Oomoo`0nOol00:Eoo`<002Ioo`03001oogoo
00Eoo`03001oogoo03ioo`00Xgoo0P00:Goo00<007ooOol01Woo00<007ooOol0?Goo002POol3000[
Ool00`00Oomoo`07Ool00`00Oomoo`0lOol009ioo`8002ioo`03001oogoo00Moo`03001oogoo03ao
o`00Vgoo0`00<7oo00<007ooOol027oo00<007ooOol0>goo002HOol3000dOol00`00Oomoo`08Ool0
0`00Oomoo`0jOol009Ioo`8003Moo`03001oogoo00Qoo`03001oogoo03Yoo`00Tgoo0`00>Goo00<0
07ooOol02Goo00<007ooOol0>Goo002AOol2000lOol00`00Oomoo`0:Ool00`00Oomoo`0hOol008io
o`<003ioo`03001oogoo00Yoo`03001oogoo03Qoo`00Rgoo0`00@Goo00<007ooOol02goo00<007oo
Ool0=goo0029Ool20014Ool00`00Oomoo`0;Ool00`00Oomoo`0gOol008Ioo`<004Ioo`03001oogoo
00aoo`03001oogoo03Ioo`00Q7oo0P00BGoo00<007ooOol03Goo00<007ooOol0=Goo0021Ool3001;
Ool00`00Oomoo`0=Ool00`00Oomoo`0eOol007moo`8004ioo`03001oogoo00ioo`03001oogoo03Ao
o`00O7oo0`00D7oo00<007ooOol03goo00<007ooOol0<goo001iOol3001DOol00`00Oomoo`0>Ool0
0`00Oomoo`0cOol007Moo`8005Moo`03001oogoo00moo`03001oogoo039oo`00M7oo0`00FGoo00<0
07ooOol047oo00<007ooOol0<Goo001bOol2001LOol00`00Oomoo`0@Ool00`00Oomoo`0aOol006mo
o`<005ioo`03001oogoo015oo`03001oogoo031oo`00K7oo0`00HGoo00<007ooOol04Goo00<007oo
Ool0<7oo001ZOol2001TOol00`00Oomoo`0BOol00`00Oomoo`0_Ool006Moo`<006Ioo`03001oogoo
01=oo`03001oogoo02ioo`00IGoo0P00JGoo00<007ooOol04goo00<007ooOol0;Woo001ROol3000n
OolP000=Ool00`00Oomoo`0DOol00`00Oomoo`0]Ool005moo`<003Eoo``000EAT003001E/5F`01=E
/003001Md5g@009Md0X000=oo`03001oogoo01Eoo`03001oogoo02aoo`00GGoo0P00;Woo2P004E6@
00<005F`EK004eF`00<005g@GM0035g@1P005Goo00<007ooOol0;7oo001JOol3000YOol70003DG00
0`00DI1AT00EDI000`00EK1E/00CEK000`00GM1Md00?GM02000016H?000000004goo00<007ooOol0
:goo001HOol2000TOol8000:DG000`00DI1AT00EDI000`00EK1E/00CEK000`00GM1Md00@GM000`00
IPmV3`02IPl3000@Ool00`00Oomoo`0[Ool005Eoo`<0021oo`H0019AL003001AT56@01EAT003001E
/5F`01=E/003001Md5g@011Md003001V3fH?00EV3`<000ioo`03001oogoo02Yoo`00Dgoo0P007Woo
1@000Te`00<0055`DG004e5`00<0056@DI005E6@00<005F`EK004eF`00<005g@GM0045g@00<006H?
IPl026H?0`0037oo00<007ooOol0:Goo001@Ool3000KOol50007CG000`00DG1AL00CDG000`00DI1A
T00EDI000`00EK1E/00CEK000`00GM1Md00@GM000`00IPmV3`0;IPl2000:Ool00`00Oomoo`0YOol0
04eoo`<001Uoo`D000a=L003001AL55`01=AL003001AT56@01EAT003001E/5F`01=E/003001Md5g@
011Md003001V3fH?00aV3`8000Yoo`03001oogoo02Qoo`00Bgoo0P0067oo10004De`00<0055`DG00
4e5`00<0056@DI005E6@00<005F`EK004eF`00<005g@GM0045g@00<006H?IPl036H?00@007I]0000
00Uoo`03001oogoo02Moo`00B7oo0`005Woo100000=9D000CG004Te`00<0055`DG004e5`00<0056@
DI005E6@00<005F`EK004eF`00<005g@GM0045g@0P003FH?00D007I]MVefK@0000Qoo`03001oogoo
02Moo`00AWoo0P005Goo10001DU@00<004e`CG004De`00<0055`DG004e5`00<0056@DI005E6@00<0
05F`EK004eF`00<005g@GM0045g@0P003FH?00<007I]MVd00WI]00<007ooOol01Woo00<007ooOol0
9Woo0013Ool3000COol40009BE000`00CG1=L00ACG000`00DG1AL00CDG000`00DI1AT00EDI000`00
EK1E/00DEK000`00GM1Md00?GM02000=IPl00`00MVefK@03MVd20007Ool00`00Oomoo`0UOol0041o
o`<0019oo`@000e9D003001=L4e`015=L003001AL55`01=AL003001AT56@01EAT003001E/5F`01AE
/003001Md5g@00mMd08000eV3`03001fKGI]00EfK@03001oogoo00Aoo`03001oogoo02Eoo`00?Woo
0P004Woo0`0000=13`00BE003TU@00<004e`CG004De`00<0055`DG004e5`00<0056@DI005E6@00<0
05F`EK0055F`00<005g@GM003eg@0P003VH?00<007I]MVd01GI]1goo00<007ooOol097oo000kOol3
000BOol20004@@l00`00BE19D00=BE000`00CG1=L00ACG000`00DG1AL00CDG000`00DI1AT00EDI00
0`00EK1E/00DEK000`00GM1Md00?GM02000>IPl00`00MVefK@05MVd7Ool00`00Oomoo`0TOol003Uo
o`80019oo`<000I13`030019D4U@00e9D003001=L4e`015=L003001AL55`01=AL003001AT56@01EA
T003001E/5F`01AE/003001Md5g@00mMd08000iV3`03001fKGI]00EfK@03001oogoo00Eoo`03001o
ogoo02=oo`00=Woo0`004Woo0P002D4?00<004U@BE003DU@00<004e`CG0044e`00<0055`DG00555`
00<0056@DI005E6@00<005F`EK0055F`00<005g@GM0045g@00<006H?IPl036H?00<007I]MVd01GI]
00<007ooOol01Woo00<007ooOol08Woo000cOol3000COol3000:@@l00`00BE19D00<BE000`00CG1=
L00ACG000`00DG1AL00DDG000`00DI1AT00EDI000`00EK1E/00DEK000`00GM1Md00@GM000`00IPmV
3`0<IPl00`00MVefK@05MVd00`00Oomoo`06Ool00`00Oomoo`0ROol0035oo`8001Aoo`80008dcP03
00113d4?00Q13`030019D4U@00a9D003001=L4e`015=L003001AL55`01AAL003001AT56@01EAT003
001E/5F`01AE/003001Md5g@011Md003001V3fH?00aV3`03001fKGI]00EfK@03001oogoo00Moo`03
001oogoo025oo`00;Woo0`0057oo0P0013C>00<0044?@@l0244?00<004U@BE0034U@00<004e`CG00
4De`00<0055`DG00555`00<0056@DI005E6@00<005F`EK0055F`00<005g@GM0045g@00<006H?IPl0
36H?00<007I]MVd01GI]0P002Goo00<007ooOol087oo000/Ool2000EOol20006=<h00`00@@m13`07
@@l00`00BE19D00=BE000`00CG1=L00ACG000`00DG1AL00DDG000`00DI1AT00EDI000`00EK1E/00D
EK000`00GM1Md00@GM000`00IPmV3`0<IPl00`00MVefK@05MVd20009Ool00`00Oomoo`0POol002Uo
o`<001Ioo`03000dcSC>00HdcP0300113d4?00M13`030019D4U@00e9D003001=L4e`015=L003001A
L55`01AAL003001AT56@01EAT003001E/5F`01AE/003001Md5g@011Md003001V3fH?00aV3`03001f
KGI]00EfK@8000Yoo`03001oogoo01moo`009goo0P0067oo0P001cC>00<0044?@@l0244?00<004U@
BE003DU@00<004e`CG004De`00<0055`DG00555`00<0056@DI005E6@00<005F`EK0055F`00<005g@
GM0045g@00<006H?IPl036H?00<007I]MVd01GI]00<006Y1Ool02Woo00<007ooOol07Woo000TOol3
000IOol00`0084d00007=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00ACG000`00DG1A
L00DDG000`00DI1AT00EDI000`00EK1E/00DEK000`00GM1Md00@GM02000=IPl00`00MVefK@05MVd0
0`00JT5oo`0:Ool00`00Oomoo`0NOol0025oo`<001]oo`04000PCB1=0007=<h00`00@@m13`08@@l0
0`00BE19D00=BE000`00CG1=L00ACG000`00DG1AL00DDG000`00DI1AT00EDI000`00EK1E/00DEK00
0`00GM1Md00@GM02000=IPl00`00MVefK@05MVd00`00JT5oo`0;Ool00`00Oomoo`0MOol001moo`80
01eoo`05000PCB1=84d00007=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00ACG000`00
DG1AL00DDG000`00DI1AT00EDI000`00EK1E/00DEK000`00GM1Md00@GM02000>IPl00`00MVefK@04
MVd00`00JT5oo`0;Ool00`00Oomoo`0MOol001aoo`<001ioo`03000PCB1=008PC@03000dcSC>00Dd
cP0300113d4?00Q13`030019D4U@00e9D003001=L4e`015=L003001AL55`01AAL003001AT56@01EA
T003001E/5F`01AE/003001Md5g@011Md08000iV3`03001fKGI]00AfK@03001Z@Goo00aoo`03001o
ogoo01aoo`006Woo0P0087oo00<0021=84d00R1=00<003C>=<h01SC>00<0044?@@l0244?00<004U@
BE003DU@00<004e`CG004De`00<0055`DG00555`00<0056@DI005E6@00<005F`EK0055F`00<005g@
GM0045g@0P003VH?00<007I]MVd017I]00<006Y100003Goo00<007ooOol06goo000GOol3000QOol0
0`0084dPC@0384d00`00=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00ACG00
0`00DG1AL00DDG000`00DI1AT00FDI000`00EK1E/00CEK000`00GM1Md00AGM000`00IPmV3`0<IPl0
0`00MVefK@04MVd00`00JT40000=Ool00`00Oomoo`0KOol001Aoo`<002=oo`8000DPC@03000dcSC>
00HdcP0300113d4?00Q13`030019D4U@00e9D003001=L4e`015=L003001AL55`01AAL003001AT56@
01IAT003001E/5F`01=E/003001Md5g@015Md003001V3fH?00aV3`03001fKGI]00AfK@03001Z@@00
00ioo`03001oogoo01Yoo`004Woo0P009Woo0P001B1=00<003C>=<h01SC>00<0044?@@l0244?00<0
04U@BE003DU@00<004e`CG004De`00<0055`DG00555`00<0056@DI005U6@00<005F`EK004eF`00<0
05g@GM004Eg@00<006H?IPl036H?00<007I]MVd01GI]0P003goo00<007ooOol06Goo000@Ool2000W
Ool00`0000X0000584d00`00=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00A
CG000`00DG1AL00DDG000`00DI1AT00FDI000`00EK1E/00CEK000`00GM1Md00AGM000`00IPmV3`0<
IPl00`00MVefK@05MVd2000?Ool00`00Oomoo`0IOol0011oo`8002Ioo`0400002P0:000584d00`00
=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00ACG000`00DG1AL00DDG000`00
DI1AT00FDI000`00EK1E/00CEK000`00GM1Md00AGM000`00IPmV3`0<IPl00`00MVefK@05MVd2000@
Ool00`00Oomoo`0HOol0011oo`03001oo`0002Aoo`0400002P0:000684d00`00=<hdcP05=<h00`00
@@m13`09@@l00`00BE19D00<BE000`00CG1=L00BCG000`00DG1AL00DDG000`00DI1AT00FDI000`00
EK1E/00CEK000`00GM1Md00AGM000`00IPmV3`0<IPl00`00MVefK@05MVd2000@Ool00`00Oomoo`0H
Ool0011oo`04001oogoo000SOol0100000X02P001R1=00<003C>=<h01CC>00<0044?@@l0244?00<0
04U@BE003DU@00<004e`CG004Te`00<0055`DG00555`00<0056@DI005U6@00<005F`EK0055F`00<0
05g@GM0045g@00<006H?IPl036H?00<007I]MVd01GI]0P004Goo00<007ooOol05goo000?Ool00`00
Oomoo`02Ool00`00Oomoo`0OOol01@0000X02P0:00001R1=00<003C>=<h01CC>00<0044?@@l0244?
00<004U@BE003DU@00<004e`CG004Te`00<0055`DG00555`00<0056@DI005U6@00<005F`EK0055F`
00<005g@GM0045g@00<006H?IPl036H?00<007I]MVd01GI]00<006Y1Ool04Goo00<007ooOol05Woo
000?Ool00`00Oomoo`03Ool00`00Oomoo`0NOol01@0000X02P0:00001R1=00<003C>=<h01CC>00<0
044?@@l0244?00<004U@BE003DU@00<004e`CG004Te`00<0055`DG00555`00<0056@DI005U6@00<0
05F`EK0055F`00<005g@GM0045g@00<006H?IPl036H?00<007I]MVd01GI]00<006Y1Ool04Goo00<0
07ooOol05Woo000?Ool00`00Oomoo`04Ool00`00Oomoo`0LOol2000300X00`0084dPC@0384d00`00
=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00BCG000`00DG1AL00DDG000`00
DI1AT00FDI000`00EK1E/00DEK000`00GM1Md00@GM02000=IPl00`00MVefK@05MVd00`00JT5oo`0B
Ool00`00Oomoo`0EOol000moo`03001oogoo00Eoo`03001oogoo01]oo`8000<02P03000PCB1=00<P
C@03000dcSC>00HdcP0300113d4?00Q13`030019D4U@00e9D003001=L4e`019=L003001AL55`01AA
L003001AT56@01IAT003001E/5F`01AE/003001Md5g@011Md08000iV3`03001fKGI]00AfK@03001Z
@@0001=oo`03001oogoo01Aoo`003goo00<007ooOol01Woo00<007ooOol06Goo00<0000400000`0:
00<0021=84d00b1=00<003C>=<h01SC>00<0044?@@l0244?00<004U@BE003DU@00<004e`CG004De`
00<0055`DG005E5`00<0056@DI005U6@00<005F`EK0055F`00<005g@GM0045g@0P003VH?00<007I]
MVd017I]00<006Y100004goo00<007ooOol057oo000?Ool00`00Oomoo`07Ool00`00Oomoo`0HOol2
000400X00`0084dPC@0384d00`00=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=
L00ACG000`00DG1AL00EDG000`00DI1AT00FDI000`00EK1E/00DEK000`00GM1Md00@GM02000>IPl0
0`00MVefK@04MVd00`00JT40000DOol00`00Oomoo`0COol000moo`03001oogoo00Qoo`03001oogoo
01Ioo`030000100000@02P03000PCB1=00<PC@03000dcSC>00HdcP0300113d4?00Q13`030019D4U@
00e9D003001=L4e`015=L003001AL55`01EAL003001AT56@01IAT003001E/5F`01AE/003001Md5g@
015Md003001V3fH?00aV3`03001fKGI]00EfK@8001Eoo`03001oogoo019oo`003goo00<007ooOol0
2Goo00<007ooOol05Goo00<0000400000`0:00<0021=84d0121=00<003C>=<h01SC>00<0044?@@l0
244?00<004U@BE003DU@00<004e`CG004De`00<0055`DG005E5`00<0056@DI005U6@00<005F`EK00
55F`00<005g@GM004Eg@00<006H?IPl036H?00<007I]MVd01GI]0P005Goo00<007ooOol04Woo000>
Ool00`00Oomoo`0;Ool00`00Oomoo`0DOol00`0000@0000300X00`0084dPC@0484d00`00=<hdcP06
=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00ACG000`00DG1AL00EDG000`00DI1AT00F
DI000`00EK1E/00DEK000`00GM1Md00AGM000`00IPmV3`0<IPl00`00MVefK@05MVd2000FOol00`00
Oomoo`0AOol000ioo`03001oogoo00aoo`03001oogoo01=oo`030000100000<02P03000PCB1=00@P
C@03000dcSC>00HdcP0300113d4?00Q13`030019D4U@00e9D003001=L4e`015=L003001AL55`01EA
L003001AT56@01IAT003001E/5F`01AE/003001Md5g@015Md003001V3fH?00aV3`03001fKGI]00Ef
K@8001Ioo`03001oogoo015oo`003Woo00<007ooOol03Goo00<007ooOol04Woo00<0000400000`0:
00<0021=84d0121=00<003C>=<h01CC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG004De`
00<0055`DG005E5`00<0056@DI005U6@00<005F`EK0055F`00<005g@GM004Eg@00<006H?IPl036H?
00<007I]MVd01GI]0P005goo00<007ooOol047oo000>Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol0
0`0000@0000300X00`0084dPC@0484d00`00=<hdcP05=<h00`00@@m13`09@@l00`00BE19D00=BE00
0`00CG1=L00ACG000`00DG1AL00EDG000`00DI1AT00FDI000`00EK1E/00DEK000`00GM1Md00AGM00
0`00IPmV3`0<IPl00`00MVefK@05MVd2000HOol00`00Oomoo`0?Ool000ioo`03001oogoo00moo`03
001oogoo00moo`0400001004000300X00`0084dPC@0384d00`00=<hdcP06=<h00`00@@m13`09@@l0
0`00BE19D00=BE000`00CG1=L00ACG000`00DG1AL00EDG000`00DI1AT00FDI000`00EK1E/00DEK00
0`00GM1Md00AGM000`00IPmV3`0<IPl00`00MVefK@05MVd2000HOol00`00Oomoo`0?Ool000ioo`03
001oogoo011oo`03001oogoo00ioo`0400001004000300X00`0084dPC@0384d00`00=<hdcP06=<h0
0`00@@m13`08@@l00`00BE19D00>BE000`00CG1=L00ACG000`00DG1AL00EDG000`00DI1AT00FDI00
0`00EK1E/00DEK000`00GM1Md00AGM000`00IPmV3`0<IPl00`00MVefK@05MVd00`00JT5oo`0GOol2
000@Ool000ioo`03001oogoo015oo`03001oogoo00eoo`030000100000@02P03000PCB1=00<PC@03
000dcSC>00HdcP0300113d4?00Q13`030019D4U@00e9D003001=L4e`019=L003001AL55`01EAL003
001AT56@01IAT003001E/5F`01AE/003001Md5g@015Md003001V3fH?00aV3`03001fKGI]00EfK@03
001Z@Goo01Aoo`<00003Ool007oo00moo`003Woo00<007ooOol04Woo00<007ooOol037oo00<00004
0000100:00<0021=84d00b1=00<003C>=<h01SC>00<0044?@@l0244?00<004U@BE003DU@00<004e`
CG004Te`00<0055`DG005E5`00<0056@DI005U6@00<005F`EK0055F`00<005g@GM004Eg@00<006H?
IPl03FH?00<007I]MVd017I]00<006Y100004Goo0`0017oo00<007ooOol03Woo000=Ool00`00Oomo
o`0DOol00`00Oomoo`0;Ool00`0000@0000400X00`0084dPC@0384d00`00=<hdcP06=<h00`00@@m1
3`08@@l00`00BE19D00=BE000`00CG1=L00BCG000`00DG1AL00EDG000`00DI1AT00FDI000`00EK1E
/00DEK000`00GM1Md00AGM02000>IPl00`00MVefK@04MVd00`00JT40000>Ool30007Ool00`00Oomo
o`0>Ool000eoo`03001oogoo01Eoo`03001oogoo00Yoo`030000100000<02P03000PCB1=00@PC@03
000dcSC>00HdcP0300113d4?00Q13`030019D4U@00e9D003001=L4e`019=L003001AL55`01EAL003
001AT56@01IAT003001E/5F`01AE/003001Md5g@015Md08000iV3`03001fKGI]00EfK@8000]oo`<0
00]oo`03001oogoo00eoo`003Goo00<007ooOol05Woo00<007ooOol02Goo00<0000400000`0:00<0
021=84d0121=00<003C>=<h01SC>00<0044?@@l0244?00<004U@BE003DU@00<004e`CG004Te`00<0
055`DG005E5`00<0056@DI005U6@00<005F`EK0055F`00<005g@GM004Eg@0P003VH?00<007I]MVd0
1GI]0P0027oo0`003Woo00<007ooOol03Goo000=Ool00`00Oomoo`0GOol00`00Oomoo`08Ool00`00
00@0000300X00`0084dPC@0484d00`00=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00
CG1=L00BCG000`00DG1AL00EDG000`00DI1AT00FDI000`00EK1E/00DEK000`00GM1Md00BGM000`00
IPmV3`0<IPl00`00MVefK@05MVd20005Ool3000AOol00`00Oomoo`0=Ool000eoo`03001oogoo01Qo
o`03001oogoo00Moo`030000100000<02P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00Q1
3`030019D4U@00e9D003001=L4e`019=L003001AL55`01EAL003001AT56@01IAT003001E/5F`01AE
/003001Md5g@019Md003001V3fH?00aV3`03001fKGI]00EfK@800003Ool00000008001Aoo`03001o
ogoo00eoo`003Goo00<007ooOol06Goo00<007ooOol01Goo00@0000400@000<02P03000PCB1=00@P
C@03000dcSC>00DdcP0300113d4?00U13`030019D4U@00e9D003001=L4e`019=L003001AL55`01EA
L003001AT56@01IAT003001E/5F`01AE/003001Md5g@019Md003001V3fH?00aV3`03001fKGI]00Ef
K@<001Qoo`03001oogoo00eoo`003Goo00<007ooOol06Woo00<007ooOol017oo00@0000400@000<0
2P03000PCB1=00<PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9D003001=L4e`019=
L003001AL55`01EAL003001AT56@01IAT003001E/5F`01EE/003001Md5g@015Md003001V3fH?00aV
3`03001fKGI]00EfK@8001Uoo`03001oogoo00eoo`0037oo00<007ooOol077oo00<007ooOol00goo
00@0000400@000<02P03000PCB1=00<PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9
D003001=L4e`019=L003001AL55`01AAL003001AT56@01MAT003001E/5F`01EE/003001Md5g@015M
d003001V3fH?00aV3`03001fKGI]00EfK@8001Uoo`03001oogoo00eoo`0037oo00<007ooOol07Goo
00<007ooOol00Woo00<000040000100:00<0021=84d00b1=00<003C>=<h01SC>00<0044?@@l02D4?
00<004U@BE003DU@00<004e`CG004Te`00<0055`DG00555`00<0056@DI005e6@00<005F`EK005EF`
00<005g@GM004Eg@00<006H?IPl036H?00<007I]MVd01GI]0P006Goo00<007ooOol03Goo000<Ool0
0`00Oomoo`0NOol01`00Oomoogoo0000100000@02P03000PCB1=00<PC@03000dcSC>00HdcP030011
3d4?00U13`030019D4U@00e9D003001=L4e`019=L003001AL55`01AAL003001AT56@01MAT003001E
/5F`01EE/003001Md5g@015Md003001V3fH?00aV3`03001fKGI]00EfK@8001Yoo`03001oogoo00ao
o`0037oo00<007ooOol07goo00H007ooOol00004000300X00`0084dPC@0484d00`00=<hdcP06=<h0
0`00@@m13`09@@l00`00BE19D00=BE000`00CG1=L00ACG000`00DG1AL00EDG000`00DI1AT00GDI00
0`00EK1E/00EEK000`00GM1Md00AGM000`00IPmV3`0<IPl00`00MVefK@05MVd00`00JT40000IOol0
0`00Oomoo`0<Ool000aoo`03001oogoo021oo`05001oo`0000@0000300X00`0084dPC@0484d00`00
=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00>BE000`00CG1=L00ACG000`00DG1AL00EDG000`00
DI1AT00GDI000`00EK1E/00EEK000`00GM1Md00AGM000`00IPmV3`0<IPl00`00MVefK@05MVd00`00
JT40000IOol00`00Oomoo`0<Ool000aoo`03001oogoo025oo`80000300@0000:00802P03000PCB1=
00@PC@03000dcSC>00HdcP0300113d4?00Q13`030019D4U@00i9D003001=L4e`015=L003001AL55`
01EAL003001AT56@01MAT003001E/5F`01EE/003001Md5g@015Md003001V3fH?00eV3`03001fKGI]
00AfK@03001Z@@0001Uoo`03001oogoo00aoo`0037oo00<007ooOol08Woo00<0000400000`0:00<0
021=84d0121=00<003C>=<h01SC>00<0044?@@l0244?00<004U@BE003TU@00<004e`CG004De`00<0
055`DG005E5`00<0056@DI005e6@00<005F`EK005EF`00<005g@GM004Eg@00<006H?IPl03FH?00<0
07I]MVd01GI]0P006Goo00<007ooOol037oo000<Ool00`00Oomoo`0ROol00`0000@0000300X00`00
84dPC@0484d00`00=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00BCG000`00
DG1AL00EDG000`00DI1AT00GDI000`00EK1E/00EEK000`00GM1Md00AGM000`00IPmV3`0=IPl00`00
MVefK@05MVd2000IOol00`00Oomoo`0<Ool000]oo`03001oogoo029oo`0400001004000300X00`00
84dPC@0484d00`00=<hdcP06=<h00`00@@m13`08@@l00`00BE19D00=BE000`00CG1=L00BCG000`00
DG1AL00EDG000`00DI1AT00GDI000`00EK1E/00EEK000`00GM1Md00BGM000`00IPmV3`0<IPl00`00
MVefK@05MVd2000IOol00`00Oomoo`0<Ool000]oo`03001oogoo029oo`0400001004000300X00`00
84dPC@0484d00`00=<hdcP05=<h00`00@@m13`09@@l00`00BE19D00=BE000`00CG1=L00BCG000`00
DG1AL00EDG000`00DI1AT00GDI000`00EK1E/00EEK000`00GM1Md00BGM000`00IPmV3`0<IPl00`00
MVefK@05MVd2000JOol00`00Oomoo`0;Ool000]oo`03001oogoo029oo`030000100000@02P03000P
CB1=00<PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9D003001=L4e`019=L003001A
L55`01EAL003001AT56@01MAT003001E/5F`01EE/003001Md5g@019Md003001V3fH?00aV3`03001f
KGI]00EfK@8001Yoo`03001oogoo00]oo`002goo00<007ooOol08Woo00<000040000100:00<0021=
84d00b1=00<003C>=<h01SC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG004Te`00<0055`
DG005E5`00<0056@DI005e6@00<005F`EK005EF`00<005g@GM004Ug@00<006H?IPl036H?00<007I]
MVd01GI]0P006Woo00<007ooOol02goo000;Ool00`00Oomoo`0ROol00`0000@0000300X00`0084dP
C@0484d00`00=<hdcP06=<h00`00@@m13`09@@l00`00BE19D00=BE000`00CG1=L00BCG000`00DG1A
L00EDG000`00DI1AT00GDI000`00EK1E/00EEK000`00GM1Md00BGM000`00IPmV3`0<IPl00`00MVef
K@05MVd2000JOol00`00Oomoo`0;Ool000]oo`03001oogoo029oo`030000100000<02P03000PCB1=
00@PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9D003001=L4e`019=L003001AL55`
01EAL003001AT56@01MAT003001E/5F`01EE/003001Md5g@019Md003001V3fH?00aV3`03001fKGI]
00EfK@8001Yoo`03001oogoo00]oo`002goo00<007ooOol08Woo00<0000400000`0:00<0021=84d0
121=00<003C>=<h01SC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG004Te`00<0055`DG00
5E5`00<0056@DI005e6@00<005F`EK005EF`00<005g@GM004Ug@00<006H?IPl036H?00<007I]MVd0
1GI]00<006Y100006Goo00<007ooOol02goo000:Ool00`00Oomoo`0SOol00`0000@0000300X00`00
84dPC@0484d00`00=<hdcP06=<h00`00@@m13`09@@l00`00BE19D00=BE000`00CG1=L00BCG000`00
DG1AL00EDG000`00DI1AT00GDI000`00EK1E/00EEK000`00GM1Md00BGM000`00IPmV3`0<IPl00`00
MVefK@05MVd00`00JT40000IOol00`00Oomoo`0;Ool000Yoo`03001oogoo02=oo`030000100000<0
2P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9D003001=L4e`019=
L003001AL55`01EAL003001AT56@01MAT003001E/5F`01EE/003001Md5g@019Md003001V3fH?00aV
3`03001fKGI]00EfK@03001Z@@0001Uoo`03001oogoo00]oo`002Woo00<007ooOol08Woo00@00004
00@000<02P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9D003001=
L4e`019=L003001AL55`01EAL003001AT56@01MAT003001E/5F`01EE/003001Md5g@019Md003001V
3fH?00aV3`03001fKGI]00IfK@8001Yoo`03001oogoo00Yoo`002Woo00<007ooOol08Woo00@00004
00@000<02P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00Q13`030019D4U@00i9D003001=
L4e`019=L003001AL55`01EAL003001AT56@01MAT003001E/5F`01EE/003001Md5g@019Md003001V
3fH?00eV3`03001fKGI]00EfK@8001Yoo`03001oogoo00Yoo`002Woo00<007ooOol08Woo00<00004
0000100:00<0021=84d0121=00<003C>=<h01SC>00<0044?@@l0244?00<004U@BE003TU@00<004e`
CG004Te`00<0055`DG005E5`00<0056@DI005e6@00<005F`EK005EF`00<005g@GM004Ug@00<006H?
IPl03FH?00<007I]MVd01GI]0P006Woo00<007ooOol02Woo000:Ool00`00Oomoo`0ROol00`0000@0
000400X00`0084dPC@0384d00`00=<hdcP07=<h00`00@@m13`08@@l00`00BE19D00>BE000`00CG1=
L00BCG000`00DG1AL00EDG000`00DI1AT00GDI000`00EK1E/00EEK000`00GM1Md00BGM000`00IPmV
3`0=IPl00`00MVefK@05MVd2000JOol00`00Oomoo`0:Ool000Yoo`03001oogoo029oo`0300001000
00@02P03000PCB1=00<PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00i9D003001=L4e`
019=L003001AL55`01EAL003001AT56@01MAT003001E/5F`01IE/003001Md5g@015Md08000iV3`03
001fKGI]00EfK@8001Yoo`03001oogoo00Yoo`002Woo00<007ooOol08Woo00<0000400000`0:00<0
021=84d0121=00<003C>=<h01SC>00<0044?@@l02D4?00<004U@BE003TU@00<004e`CG004Te`00<0
055`DG005E5`00<0056@DI005e6@00<005F`EK005UF`00<005g@GM004Ug@00<006H?IPl036H?00<0
07I]MVd01GI]0P006Woo00<007ooOol02Woo0009Ool00`00Oomoo`0SOol00`0000@0000300X00`00
84dPC@0484d00`00=<hdcP06=<h00`00@@m13`09@@l00`00BE19D00=BE000`00CG1=L00CCG000`00
DG1AL00EDG000`00DI1AT00GDI000`00EK1E/00FEK000`00GM1Md00BGM000`00IPmV3`0<IPl00`00
MVefK@05MVd2000JOol00`00Oomoo`0:Ool000Uoo`03001oogoo02=oo`030000100000<02P03000P
CB1=00@PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9D003001=L4e`01==L003001A
L55`01EAL003001AT56@01MAT003001E/5F`01IE/003001Md5g@019Md003001V3fH?00aV3`03001f
KGI]00EfK@8001]oo`03001oogoo00Uoo`002Goo00<007ooOol08goo00<0000400000`0:00<0021=
84d0121=00<003C>=<h01SC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG004de`00<0055`
DG005E5`00<0056@DI005e6@00<005F`EK005UF`00<005g@GM004Ug@00<006H?IPl036H?00<007I]
MVd01GI]0P006goo00<007ooOol02Goo0009Ool00`00Oomoo`0ROol0100000@010000`0:00<0021=
84d0121=00<003C>=<h01SC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG004Te`00<0055`
DG005U5`00<0056@DI005e6@00<005F`EK005UF`00<005g@GM004Ug@00<006H?IPl036H?00<007I]
MVd01GI]00<006Y100006Woo00<007ooOol02Goo0009Ool00`00Oomoo`0ROol0100000@010000`0:
00<0021=84d0121=00<003C>=<h01SC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG004Te`
00<0055`DG005U5`00<0056@DI00656@00<005F`EK005EF`00<005g@GM004Eg@0P003VH?00<007I]
MVd01GI]00<006Y100006Woo00<007ooOol02Goo0009Ool00`00Oomoo`0ROol00`0000@0000400X0
0`0084dPC@0484d00`00=<hdcP06=<h00`00@@m13`09@@l00`00BE19D00=BE000`00CG1=L00BCG00
0`00DG1AL00FDG000`00DI1AT00HDI000`00EK1E/00EEK000`00GM1Md00>GM0300000eg@0000000=
IPl00`00MVefK@05MVd00`00JT40000JOol00`00Oomoo`09Ool000Uoo`03001oogoo029oo`030000
100000@02P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@00e9D003001=
L4e`019=L003001AL55`01IAL003001AT56@01QAT003001E/5F`01EE/003001Md5g@00]Md0<000AM
d003001V3`0000aV3`03001fKGI]00IfK@8001Yoo`03001oogoo00Uoo`002Goo00<007ooOol08Woo
00<000040000100:00<0021=84d00b1=00<003C>=<h01cC>00<0044?@@l02D4?00<004U@BE003DU@
00<004e`CG004Te`00<0055`DG005U5`00<0056@DI00656@00<005F`EK005EF`00<005g@GM001eg@
10001eg@00<006H?00003FH?00<007I]MVd01GI]0P006Woo00<007ooOol02Goo0008Ool00`00Oomo
o`0SOol00`0000@0000300X00`0084dPC@0484d00`00=<hdcP07=<h00`00@@m13`09@@l00`00BE19
D00=BE000`00CG1=L00BCG000`00DG1AL00FDG000`00DI1AT00HDI000`00EK1E/00EEK000`00GM1M
d004GM03000;GM001000IPmV3`0036H?00<007I]MVd01GI]0P006goo00<007ooOol027oo0008Ool0
0`00Oomoo`0SOol00`0000@0000300X00`0084dPC@0484d00`00=<hdcP06=<h00`00@@m13`09@@l0
0`00BE19D00>BE000`00CG1=L00BCG000`00DG1AL00FDG000`00DI1AT00HDI000`00EK1E/00EEK00
1000GM1Md5g@0`003Ug@00D006H?IPmV3`0000]V3`03001fKGI]00EfK@8001]oo`03001oogoo00Qo
o`0027oo00<007ooOol08goo00<0000400000`0:00<0021=84d0121=00<003C>=<h01SC>00<0044?
@@l02D4?00<004U@BE003TU@00<004e`CG004Te`00<0055`DG005U5`00<0056@DI00656@00<005F`
EK005EF`10004Eg@00<006H?IPl00VH?00<006H?IPl026H?00<007I]MVd01GI]0P006goo00<007oo
Ool027oo0008Ool00`00Oomoo`0SOol00`0000@0000300X00`0084dPC@0484d00`00=<hdcP06=<h0
0`00@@m13`09@@l00`00BE19D00>BE000`00CG1=L00BCG000`00DG1AL00FDG000`00DI1AT00HDI00
0`00EK1E/00CEK03000DGM000`00IPmV3`02IPl00`00IPmV3`08IPl00`00MVefK@05MVd2000KOol0
0`00Oomoo`08Ool000Qoo`03001oogoo029oo`0400001004000300X00`0084dPC@0484d00`00=<hd
cP06=<h00`00@@m13`09@@l00`00BE19D00>BE000`00CG1=L00BCG000`00DG1AL00FDG000`00DI1A
T00HDI000`00EK1E/00@EK030002EK000`00GM1Md00BGM000`00IPmV3`03IPl00`00IPmV3`07IPl0
0`00MVefK@05MVd2000KOol00`00Oomoo`08Ool000Qoo`03001oogoo029oo`0400001004000300X0
0`0084dPC@0484d00`00=<hdcP06=<h00`00@@m13`09@@l00`00BE19D00>BE000`00CG1=L00BCG00
0`00DG1AL00FDG000`00DI1AT00HDI000`00EK1E/00<EK040005EK000`00GM1Md00CGM000`00IPmV
3`03IPl00`00IPmV3`06IPl00`00MVefK@05MVd2000KOol00`00Oomoo`08Ool000Qoo`03001oogoo
029oo`0400001004000300X00`0084dPC@0484d00`00=<hdcP06=<h00`00@@m13`09@@l00`00BE19
D00>BE000`00CG1=L00BCG000`00DG1AL00FDG000`00DI1AT00HDI000`00EK1E/009EK030009EK00
0`00GM1Md00CGM000`00IPmV3`04IPl00`00IPmV3`05IPl00`00MVefK@05MVd00`00JT40000JOol0
0`00Oomoo`08Ool000Moo`03001oogoo02=oo`030000100000@02P03000PCB1=00@PC@03000dcSC>
00HdcP0300113d4?00U13`030019D4U@00i9D003001=L4e`019=L003001AL55`01IAL003001AT56@
01QAT003001E/5F`00IE/0<000aE/003001Md5g@01=Md003001V3fH?00AV3`03001V3fH?00EV3`03
001fKGI]00EfK@03001Z@@0001Yoo`03001oogoo00Qoo`001goo00<007ooOol08goo00<000040000
100:00<0021=84d0121=00<003C>=<h01SC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG00
4de`00<0055`DG005U5`00<0056@DI00656@00<005F`EK000eF`0`003eF`00<005g@GM004eg@00<0
06H?IPl01FH?00<006H?IPl016H?00<007I]MVd01GI]00<006Y100006goo00<007ooOol01goo0007
Ool00`00Oomoo`0SOol00`0000@0000300X00`0084dPC@0584d00`00=<hdcP06=<h00`00@@m13`09
@@l00`00BE19D00=BE000`00CG1=L00CCG000`00DG1AL00FDG000`00DI1AT00HDI000`00EK1E/003
000BEK000`00GM1Md00CGM000`00IPmV3`06IPl00`00IPmV3`03IPl00`00MVefK@06MVd2000KOol0
0`00Oomoo`07Ool000Moo`03001oogoo02=oo`030000100000<02P03000PCB1=00@PC@03000dcSC>
00LdcP0300113d4?00U13`030019D4U@00e9D003001=L4e`01==L003001AL55`01IAL003001AT56@
01QAT0<001EE/003001Md5g@01=Md003001V3fH?00MV3`03001V3fH?009V3`03001fKGI]00IfK@80
01]oo`03001oogoo00Moo`001goo00<007ooOol08goo00<0000400000`0:00<0021=84d0121=00<0
03C>=<h01cC>00<0044?@@l02D4?00<004U@BE003DU@00<004e`CG004de`00<0055`DG005U5`00<0
056@DI00556@1@005eF`00<005g@GM004eg@00<006H?IPl026H?00D006H?IPmV3`0000QfK@8001]o
o`03001oogoo00Moo`001goo00<007ooOol08goo00<0000400000`0:00<0021=84d0121=00<003C>
=<h01SC>00<0044?@@l02T4?00<004U@BE003DU@00<004e`CG004de`00<0055`DG005U5`00<0056@
DI004E6@0`00156@00<005F`EK005EF`00<005g@GM004eg@00<006H?IPl026H?00<006H?IPl00VH?
00<007I]MVd01GI]0P006goo00<007ooOol01goo0007Ool00`00Oomoo`0SOol00`0000@0000300X0
0`0084dPC@0484d00`00=<hdcP06=<h00`00@@m13`0:@@l00`00BE19D00=BE000`00CG1=L00CCG00
0`00DG1AL00FDG000`00DI1AT00>DI030007DI000`00EK1E/00FEK000`00GM1Md00BGM000`00IPmV
3`09IPl01@00IPmV3fH?00001gI]0P006goo00<007ooOol01goo0007Ool00`00Oomoo`0ROol01000
00@010000`0:00<0021=84d0121=00<003C>=<h01SC>00<0044?@@l02T4?00<004U@BE003DU@00<0
04e`CG004de`00<0055`DG005U5`00<0056@DI002e6@0`002U6@00<005F`EK005UF`00<005g@GM00
4Ug@00<006H?IPl02VH?00@006H?IPl000MfK@8001]oo`03001oogoo00Moo`001Woo00<007ooOol0
8goo00@0000400@000<02P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00U13`030019D4U@
00i9D003001=L4e`01==L003001AL55`01IAL003001AT56@00QAT0<000eAT003001E/5F`01IE/003
001Md5g@019Md003001V3fH?00]V3`03001V3`0000MfK@8001aoo`03001oogoo00Ioo`001Woo00<0
07ooOol08goo00<000040000100:00<0021=84d0121=00<003C>=<h01SC>00<0044?@@l02D4?00<0
04U@BE003TU@00<004e`CG004de`00<0055`DG005U5`00<0056@DI001E6@0`00456@00<005F`EK00
5UF`00<005g@GM004Ug@00<006H?IPl02fH?00<006H?00001gI]0P0077oo00<007ooOol01Woo0006
Ool00`00Oomoo`0SOol00`0000@0000400X00`0084dPC@0484d00`00=<hdcP06=<h00`00@@m13`09
@@l00`00BE19D00>BE000`00CG1=L00CCG000`00DG1AL00FDG000`00DI1AT002DI03000CDI000`00
EK1E/00FEK000`00GM1Md00BGM000`00IPmV3`0<IPl20007MVd00`00JT40000KOol00`00Oomoo`06
Ool000Ioo`03001oogoo02=oo`030000100000@02P03000PCB1=00@PC@03000dcSC>00HdcP030011
3d4?00U13`030019D4U@00i9D003001=L4e`019=L003001AL55`01MAL0D001IAT003001E/5F`01IE
/003001Md5g@019Md003001V3fH?00eV3`03001fKGI]00EfK@03001Z@@0001]oo`03001oogoo00Io
o`001Woo00<007ooOol08goo00<0000400000`0:00<0021=84d01B1=00<003C>=<h01SC>00<0044?
@@l02D4?00<004U@BE003TU@00<004e`CG004Te`00<0055`DG005E5`0`006U6@00<005F`EK005UF`
00<005g@GM004eg@00<006H?IPl036H?0P001WI]00<006Y100006goo00<007ooOol01Woo0006Ool0
0`00Oomoo`0SOol00`0000@0000300X00`0084dPC@0484d00`00=<hdcP07=<h00`00@@m13`09@@l0
0`00BE19D00>BE000`00CG1=L00BCG000`00DG1AL00BDG030002DG000`00DI1AT00HDI000`00EK1E
/00FEK000`00GM1Md00CGM000`00IPmV3`0<IPl20007MVd2000KOol00`00Oomoo`06Ool000Ioo`03
001oogoo02=oo`030000100000<02P03000PCB1=00@PC@03000dcSC>00LdcP0300113d4?00U13`03
0019D4U@00i9D003001=L4e`019=L003001AL55`00mAL0<000EAL003001AT56@01QAT003001E/5F`
01IE/003001Md5g@01=Md003001V3fH?00aV3`03001fK@0000IfK@8001]oo`03001oogoo00Ioo`00
1Woo00<007ooOol08goo00<0000400000`0:00<0021=84d0121=00<003C>=<h01cC>00<0044?@@l0
2D4?00<004U@BE003TU@00<004e`CG004Te`00<0055`DG00355`0`00255`00<0056@DI00656@00<0
05F`EK005UF`00<005g@GM004eg@00<006H?IPl036H?00@007I]MVd000EfK@8001]oo`03001oogoo
00Ioo`001Goo00<007ooOol08goo00@0000400@000<02P03000PCB1=00@PC@03000dcSC>00LdcP03
00113d4?00U13`030019D4U@00i9D003001=L4e`019=L003001AL55`00UAL0<000]AL003001AT56@
01QAT003001E/5F`01IE/003001Md5g@01=Md003001V3fH?00aV3`05001fKGI]MVd00004MVd2000L
Ool00`00Oomoo`05Ool000Eoo`03001oogoo02=oo`0400001004000300X00`0084dPC@0484d00`00
=<hdcP06=<h00`00@@m13`0:@@l00`00BE19D00=BE000`00CG1=L00CCG000`00DG1AL005DG04000>
DG000`00DI1AT00BDI0U000@GM000`00IPmV3`0=IPl01@00MVefKGI]00000gI]0P0077oo00<007oo
Ool01Goo0005Ool00`00Oomoo`0SOol00`0000@0000400X00`0084dPC@0484d00`00=<hdcP06=<h0
0`00@@m13`0:@@l00`00BE19D00=BE000`00CG1=L00CCG000`00DG1AL002DG03000BDG000`00DI1A
T004DI0>000>?A400`00>A0i400=>A000`00<?0`l004<?0;0005GM000`00IPmV3`0=IPl01@00MVef
KGI]00000gI]0P0077oo00<007ooOol01Goo0005Ool00`00Oomoo`0SOol00`0000@0000400X00`00
84dPC@0484d00`00=<hdcP06=<h00`00@@m13`0:@@l00`00BE19D00=BE000`00CG1=L00CCG000`00
DG000002000ADG0<000<@C400`00?A4m4@0<?A400`00>A0i400=>A000`00<?0`l00=<?000`00:;00
0006000>IPl00`00MVefK@02MVd00`00MVefK@02000LOol00`00Oomoo`05Ool000Eoo`03001oogoo
02=oo`030000100000@02P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00Y13`030019D4U@
00e9D003001=L4e`019=L0<000aAL0P00003CI4004Ea00Q5L@030011<D4a00Y1<@03000m4CdA00`m
4@03000i43T@00di4003000`l33`00d`l003000X/2R`00HX/0@000YV3`03001fKGI]00=fK@04001f
K@00000LOol00`00Oomoo`05Ool000Eoo`03001oogoo02=oo`030000100000<02P03000PCB1=00DP
C@03000dcSC>00HdcP0300113d4?00Y13`030019D4U@00e9D003001=L4e`00m=L0<00003CG00055`
00=AL0T000U=T@030015LDEa00M5L@030011<D4a00Y1<@03000m4CdA00`m4@03000i43T@00di4003
000`l33`00d`l003000X/2R`00XX/0@000IV3`03001fKGI]00AfK@<001aoo`03001oogoo00Eoo`00
1Goo00<007ooOol08goo00<0000400000`0:00<0021=84d01B1=00<003C>=<h01SC>00<0044?@@l0
2D4?00<004U@BE003TU@00<004e`CG0034e`0`0000==L00000001P001eFa00<004fACI4024fA00<0
04EaAG401dEa00<0044a@C402T4a00<003dA?A4033dA00<003T@>A003CT@00<0033`<?003C3`00<0
02R`:;0032R`00<001a_00000`000VH?00<007I]MVd017I]0P0000=Z@@00Ool06Woo00<007ooOol0
1Goo0004Ool00`00Oomoo`0TOol00`0000@0000300X00`0084dPC@0484d00`00=<hdcP07=<h00`00
@@m13`09@@l00`00BE19D00>BE000`00CG1=L008CG080004FM400`00EK5E/@08EK400`00CI5=T@08
CI400`00AG55L@07AG400`00@C51<@0:@C400`00?A4m4@0<?A400`00>A0i400=>A000`00<?0`l00>
<?000`00:;0X/00;:;000`0076lLK`0376l30007MVd00`00JT40000LOol00`00Oomoo`04Ool000Ao
o`03001oogoo02Aoo`030000100000<02P03000PCB1=00@PC@03000dcSC>00LdcP0300113d4?00U1
3`030019D4U@00i9D004001=L4e`CG09000:FM400`00EK5E/@08EK400`00CI5=T@08CI400`00AG55
L@07AG400`00@C51<@0:@C400`00?A4m4@0<?A400`00>A0i400>>A000`00<?0`l00=<?000`00:;0X
/00<:;000`0076lLK`0576l00`00MVefK@04MVd3000LOol00`00Oomoo`04Ool000Aoo`03001oogoo
02=oo`0400001004000300X00`0084dPC@0484d00`00=<hdcP07=<h00`00@@m13`09@@l00`00BE19
D00<BE06000015hA0000000015hA00<005WAFM4025WA00<005FaEK4025Fa00<004fACI4024fA00<0
04EaAG401dEa00<0044a@C402T4a00<003dA?A4033dA00<003T@>A003ST@00<0033`<?003C3`00<0
02R`:;0032R`00<001a_76l01Qa_0P001GI]0P0077oo00<007ooOol017oo0004Ool00`00Oomoo`0S
Ool0100000@010000`0:00<0021=84d0121=00<003C>=<h01cC>00<0044?@@l02D4?00<004U@BE00
24U@10000VHa00<005hA00000P001ehA00<005WAFM4025WA00<005FaEK4025Fa00<004fACI4024fA
00<004EaAG401dEa00<0044a@C402T4a00<003dA?A4033dA00<003T@>A003ST@00<0033`<?003C3`
00<002R`:;0032R`00<001a_76l021a_00<007I]MVd00WI]0P0077oo00<007ooOol017oo0004Ool0
0`00Oomoo`0SOol00`0000@0000400X00`0084dPC@0484d00`00=<hdcP07=<h00`00@@m13`09@@l0
0`00BE19D004BE040005IS43000:GQ400`00FM5Id@08FM400`00EK5E/@08EK400`00CI5=T@08CI40
0`00AG55L@07AG400`00@C51<@0:@C400`00?A4m4@0<?A400`00>A0i400>>A000`00<?0`l00=<?00
0`00:;0X/00<:;000`0076lLK`0876l20003MVd3000KOol00`00Oomoo`04Ool000Aoo`03001oogoo
02=oo`030000100000@02P03000PCB1=00@PC@03000dcSC>00HdcP0300113d4?00Y13`030019D4U@
00@000IV<@<00003IS4005hA00UN4@03001IdEWA00UId@03001E/EFa00QE/@03001=TDfA00Q=T@03
0015LDEa00M5L@030011<D4a00Y1<@03000m4CdA00`m4@03000i43T@00hi4003000`l33`00d`l003
000X/2R`00`X/003000LKaa_00PLK`0500003000001fK@0200000goo001oo`0IOol00`00Oomoo`04
Ool000Aoo`03001oogoo02=oo`030000100000@02P03000PCB1=00@PC@03000dcSC>00HdcP030011
3d4?00U13`@000=ZD@03001V<FHa00@000AV<@03001N4EhA00QN4@03001IdEWA00UId@03001E/EFa
00QE/@03001=TDfA00Q=T@030015LDEa00M5L@030011<D4a00Y1<@03000m4CdA00`m4@03000i43T@
00hi4003000`l33`00d`l003000X/2R`00`X/003000LKaa_00PLK`040000300<00`30002Ool00`00
Oomoo`0GOol00`00Oomoo`04Ool000Aoo`03001oogoo02=oo`030000100000<02P03000PCB1=00DP
C@03000dcSC>00HdcP0300113d4?00I13`<000MZD@<000QV<@03001N4EhA00QN4@03001IdEWA00UI
d@03001E/EFa00QE/@03001=TDfA00Q=T@030015LDEa00M5L@030011<D4a00Y1<@03000m4CdA00`m
4@03000i43T@00hi4003000`l33`00d`l003000X/2R`00`X/003000LKaa_00PLK`030000300<0080
3080009oo`03001oogoo01Moo`03001oogoo00Aoo`000goo00<007ooOol097oo00<0000400000`0:
00<0021=84d01B1=00<003C>=<h01SC>00<0044?@@l00T4?1@001VYA10002VHa00<005hAGQ4025hA
00<005WAFM402EWA00<005FaEK4025Fa00<004fACI4024fA00<004EaAG401dEa00<0044a@C402T4a
00<003dA?A4033dA00<003T@>A003ST@00<0033`<?003C3`00<002R`:;0032R`00<001a_76l021a_
00<0000<00`00P0<0P000goo00<007ooOol05goo00<007ooOol00goo0003Ool00`00Oomoo`0TOol0
0`0000@0000300X00`0084dPC@0584d00`00=<hdcP06=<h00`00@@l000020004KW401000JU5ZDFYA
0`000fYA00<006HaIS4026Ha00<005hAGQ4025hA00<005WAFM402EWA00<005FaEK4025Fa00<004fA
CI4024fA00<004EaAG401dEa00<0044a@C402T4a00<003dA?A4033dA00<003T@>A003ST@00<0033`
<?003C3`00<002R`:;0032R`00<001a_76l02Aa_00@0000<00`0308000Aoo`03001oogoo01Ioo`03
001oogoo00=oo`000goo00<007ooOol097oo00<0000400000`0:00<0021=84d0121=00<003C>=<h0
1cC>0P001fia10001VYA00<006HaIS4026Ha00<005hAGQ4025hA00<005WAFM402EWA00<005FaEK40
25Fa00<004fACI4024fA00<004EaAG401dEa00<0044a@C402T4a00<003dA?A403CdA00<003T@>A00
3CT@00<0033`<?003C3`00<002R`:;0032R`00<001a_76l02Aa_00<0000<00`00P0<0P0017oo00<0
07ooOol05Goo00<007ooOol00goo0003Ool00`00Oomoo`0SOol0100000@010000`0:00<0021=84d0
121=00<003C>=<h01CC>0P001fia0`002FYA00<006HaIS4026Ha00<005hAGQ4025hA00<005WAFM40
2EWA00<005FaEK4025Fa00<004fACI4024fA00<004EaAG401dEa00<0044a@C402T4a00<003dA?A40
3CdA00<003T@>A003CT@00<0033`<?003C3`00<002R`:;0032R`00<001a_76l02Aa_00<0000<00`0
0P0<0P001Goo00<007ooOol057oo00<007ooOol00goo0003Ool00`00Oomoo`0SOol0100000@01000
0`0:00<0021=84d0121=00<003C>=<h00cC>0P0000=f/@00KW400Via100000=^L@00JU402FYA00<0
06HaIS4026Ha00<005hAGQ4025hA00<005WAFM402EWA00<005FaEK4025Fa00<004fACI4024fA00<0
04EaAG401dEa00<0044a@C402T4a00<003dA?A403CdA00<003T@>A003CT@00<0033`<?003C3`00<0
02R`:;0032R`00<001a_76l02Aa_00<0000<00`00P0<0P001Goo00<007ooOol057oo00<007ooOol0
0goo0003Ool00`00Oomoo`0SOol0100000@010000`0:00<0021=84d0121=00@003C>=<hdcP8000=f
/@@000E^L@03001ZDFYA00QZD@03001V<FHa00QV<@03001N4EhA00QN4@03001IdEWA00UId@03001E
/EFa00QE/@03001=TDfA00Q=T@030015LDEa00M5L@030011<D4a00Y1<@03000m4CdA00dm4@03000i
43T@00di4003000`l33`00d`l003000X/2R`00`X/003000LKaa_00TLK`030000300<0080308000Io
o`03001oogoo01=oo`03001oogoo00=oo`000goo00<007ooOol08goo00<000040000100:00<0021=
84d0121=00@003C>000000=f/@<000Q^L@03001ZDFYA00QZD@03001V<FHa00QV<@03001N4EhA00QN
4@03001IdEWA00QId@03001E/EFa00UE/@03001=TDfA00Q=T@030015LDEa00M5L@030011<D4a00Y1
<@03000m4CdA00dm4@03000i43T@00di4003000`l33`00d`l003000X/2R`00`X/003000LKaa_00TL
K`030000300<00<03003001oogoo00Eoo`03001oogoo019oo`03001oogoo00=oo`000Woo00<007oo
Ool097oo00<000040000100:1b1=0P000WJa0`000WJa00<006iaKW401Via00<006YAJU401fYA00<0
06HaIS402FHa00<005hAGQ4025hA00<005WAFM4025WA00<005FaEK402EFa00<004fACI4024fA00<0
04EaAG401dEa00<0044a@C402T4a00<003dA?A403CdA00<003T@>A003CT@00<0033`<?003C3`00<0
02R`:;003BR`00<001a_76l021a_00<0000<00`00`0<00<007ooOol01Woo00<007ooOol04Woo00<0
07ooOol00Woo0002Ool00`00Oomoo`0TOol00`0000@0000400X684d00`00N]0000020005M[400`00
KW5^L@06KW400`00JU5ZD@07JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5Id@08FM400`00
EK5E/@09EK400`00CI5=T@08CI400`00AG55L@07AG400`00@C51<@0:@C400`00?A4m4@0=?A400`00
>A0i400=>A000`00<?0`l00=<?000`00:;0X/00=:;000`0076lLK`0876l00`0000`0300200`00`00
Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`02Ool0009oo`03001oogoo02Aoo`030000100000<0
2P03000PCB1=008PC@@000Qf/@03001^LFia00I^L@03001ZDFYA00MZD@03001V<FHa00QV<@03001N
4EhA00UN4@03001IdEWA00QId@03001E/EFa00UE/@03001=TDfA00Q=T@030015LDEa00M5L@030011
<D4a00]1<@03000m4CdA00`m4@03000i43T@00di4003000`l33`00d`l003000X/2R`00dX/003000L
Kaa_00PLK`030000300<00803003001oogoo00Qoo`03001oogoo015oo`03001oogoo009oo`000Woo
00<007ooOol097oo00<0000400000`0:00<0021=84d00`000W[@00<007JaM[401WJa00<006iaKW40
1Via00<006YAJU401fYA00<006HaIS4026Ha00<005hAGQ402EhA00<005WAFM4025WA00<005FaEK40
2EFa00<004fACI4024fA00<004EaAG401dEa00<0044a@C402d4a00<003dA?A4033dA00<003T@>A00
3CT@00<0033`<?003S3`00<002R`:;0032R`00<001a_76l021a_00D0000<00`0300000aoo`03001o
ogoo011oo`03001oogoo009oo`000Woo00<007ooOol097oo0P0400<0000:00X01@0017[@00<007Ja
M[401GJa00<006iaKW401fia00<006YAJU401fYA00<006HaIS4026Ha00<005hAGQ402EhA00<005WA
FM4025WA00<005FaEK402EFa00<004fACI4024fA00<004EaAG401dEa00<0044a@C402d4a00<003dA
?A4033dA00<003T@>A003CT@00<0033`<?003S3`00<002R`:;0032R`00<001a_76l021a_00D0000<
00`0300000eoo`03001oogoo00moo`03001oogoo009oo`000Woo00<007ooOol097oo0P040`0000@0
2P00000000Ejd003001f/GJa00Ef/@03001^LFia00M^L@03001ZDFYA00MZD@03001V<FHa00QV<@03
001N4EhA00UN4@03001IdEWA00QId@03001E/EFa00UE/@03001=TDfA00Q=T@030015LDEa00M5L@03
0011<D4a00]1<@03000m4CdA00`m4@03000i43T@00di4003000`l33`00h`l003000X/2R`00`X/003
000LKaa_00TLK`030000300000ioo`03001oogoo00moo`03001oogoo009oo`000Woo00<007ooOol0
8goo0`00100:0P001W[@00<007JaM[401GJa00<006iaKW401fia00<006YAJU401fYA00<006HaIS40
26Ha00<005hAGQ402EhA00<005WAFM4025WA00<005FaEK402EFa00<004fACI4024fA00<004EaAG40
1dEa00<0044a@C402d4a00<003dA?A4033dA00<003T@>A003CT@00<0033`<?003S3`00<002R`:;00
32R`00<001a_76l02Aa_00<0000<00003goo00<007ooOol03Woo00<007ooOol00Woo0002Ool00`00
Oomoo`0POol4000200@300X00`00O`h00006N]000`00M[5f/@05M[400`00KW5^L@07KW400`00JU5Z
D@07JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5Id@08FM400`00EK5E/@09EK400`00CI5=
T@08CI400`00AG55L@07AG400`00@C51<@0;@C400`00?A4m4@0<?A400`00>A0i400=>A000`00<?0`
l00><?000`00:;0X/00<:;000`0076lLK`0976l2000AOol00`00Oomoo`0>Ool00`00Oomoo`01Ool0
0003Ool007oo01moo`<000=oo`030000100000802P04001o3Wl>0006N]000`00M[5f/@05M[400`00
KW5^L@07KW400`00JU5ZD@07JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5Id@08FM400`00
EK5E/@09EK400`00CI5=T@08CI400`00AG55L@07AG400`00@C51<@0;@C400`00?A4m4@0<?A400`00
>A0i400>>A000`00<?0`l00=<?000`00:;0X/00<:;000`0076lLK`0976l2000BOol00`00Oomoo`0=
Ool00`00Oomoo`01Ool00003Ool007oo01aoo`<000Ioo`050000100000X00003O`h00`00N]1jd004
N]000`00M[5f/@05M[400`00KW5^L@07KW400`00JU5ZD@07JU400`00IS5V<@08IS400`00GQ5N4@09
GQ400`00FM5Id@08FM400`00EK5E/@09EK400`00CI5=T@08CI400`00AG55L@07AG400`00@C51<@0;
@C400`00?A4m4@0<?A400`00>A0i400>>A000`00<?0`l00=<?000`00:;0X/00<:;000`0076lLK`09
76l00`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`01Ool00003Ool007oo01Qoo`@000Uoo`05
0000100000X00003O`h00`00N]1jd004N]000`00M[5f/@05M[400`00KW5^L@06KW400`00JU5ZD@08
JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5Id@08FM400`00EK5E/@09EK400`00CI5=T@07
CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0<?A400`00>A0i400>>A000`00<?0`l00=
<?000`00:;0X/00<:;000`0076lLK`0976l00`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`01
Ool00003Ool007oo01Eoo`<000eoo`04000010000004O`h00`00N]1jd004N]000`00M[5f/@05M[40
0`00KW5^L@06KW400`00JU5ZD@08JU400`00IS5V<@08IS400`00GQ5N4@08GQ400`00FM5Id@09FM40
0`00EK5E/@08EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0<?A40
0`00>A0i400>>A000`00<?0`l00=<?000`00:;0X/00<:;000`0076lLK`0876l00`00Oomoo`0DOol0
0`00Oomoo`0;Ool00`00Oomoo`01Ool00003Ool007oo019oo`<0011oo`80108000Ao3P03001jd7[@
00=jd003001f/GJa00If/@03001^LFia00I^L@03001ZDFYA00QZD@03001V<FHa00QV<@03001N4EhA
00QN4@03001IdEWA00UId@03001E/EFa00QE/@03001=TDfA00Q=T@030015LDEa00Q5L@030011<D4a
00]1<@03000m4CdA00`m4@03000i43T@00hi4003000`l33`00d`l003000X/2R`00`X/003000LKaa_
00LLK`03001oogoo01Ioo`03001oogoo00Yoo`03001oogoo005oo`0000=oo`00Ool03goo0`004goo
0P040P0017l>00<007[@N]000g[@00<007JaM[401WJa00<006iaKW401Via00<006YAJU4026YA00<0
06HaIS4026Ha00<005hAGQ4025hA00<005WAFM402EWA00<005FaEK4025Fa00<004fACI4024fA00<0
04EaAG4024Ea00<0044a@C402d4a00<003dA?A4033dA00<003T@>A003ST@00<0033`<?003C3`00<0
02R`:;0032R`00<001a_76l01Qa_00<007ooOol067oo00<007ooOol02Goo00<007ooOol00Goo0000
0goo001oo`0<Ool3000FOol01004001k2`0017l>00<007[@N]000g[@00<007JaM[401WJa00<006ia
KW401Via00<006YAJU401fYA00<006HaIS402FHa00<005hAGQ4025hA00<005WAFM402EWA00<005Fa
EK4025Fa00<004fACI4024fA00<004EaAG4024Ea00<0044a@C402d4a00<003dA?A4033dA00<003T@
>A003ST@00<0033`<?003C3`00<002R`:;003BR`00<001a_76l011a_00<007ooOol06Goo00<007oo
Ool02Goo00<007ooOol00Goo00000goo001oo`09Ool3000HOol01@0000@007/;000017l>00<007[@
N]000g[@00<007JaM[401GJa00<006iaKW401fia00<006YAJU401fYA00<006HaIS402FHa00<005hA
GQ4025hA00<005WAFM402EWA00<005FaEK4025Fa00<004fACI4024fA00<004EaAG4024Ea00<0044a
@C402d4a00<003dA?A4033dA00<003T@>A003ST@00<0033`<?003C3`00<002R`:;003BR`00<001a_
76l00Qa_0P007Goo00<007ooOol02Goo0@000Goo0Goo00000`00Oomoo`05Ool4000KOol20002N`/0
1@00O`io3Wl>00001W[@00<007JaM[401GJa00<006iaKW401fia00<006YAJU401fYA00<006HaIS40
2FHa00<005hAGQ4025hA00<005WAFM402EWA00<005FaEK4025Fa00<004fACI4024fA00<004EaAG40
24Ea00<0044a@C402d4a00<003dA?A4033dA00<003T@>A003ST@00<0033`<?003C3`00<002R`:;00
3BR`00D001a_76lLK`00021oo`03001oogoo00Qoo`40005oo`5oo`0000<007ooOol00Woo0`007goo
0P000W/;00D007l>O`io3P0000Ijd003001f/GJa00Ef/@03001^LFia00M^L@03001ZDFYA00MZD@03
001V<FHa00UV<@03001N4EhA00QN4@03001IdEWA00UId@03001E/EFa00QE/@03001=TDfA00Q=T@03
0015LDEa00Q5L@030011<D4a00]1<@03000m4CdA00`m4@03000i43T@00hi4003000`l33`00d`l003
000X/2R`00dX/004000LKaa_000ROol00`00Oomoo`07Ool10001Ool1Ool00003001oo`000080029o
o`80009k2`05001o3Wl>O`h00006N]000`00M[5f/@05M[400`00KW5^L@07KW400`00JU5ZD@07JU40
0`00IS5V<@09IS400`00GQ5N4@08GQ400`00FM5Id@09FM400`00EK5E/@08EK400`00CI5=T@08CI40
0`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0<?A400`00>A0i400>>A000`00<?0`l00=<?00
0`00:;0X/00=:;000`0076l0000SOol00`00Oomoo`07Ool10001Ool1Ool0008002Eoo`80009k2`Ao
3P03001jd7[@00Ajd003001f/GJa00Ef/@03001^LFia00M^L@03001ZDFYA00MZD@03001V<FHa00QV
<@03001N4EhA00UN4@03001IdEWA00UId@03001E/EFa00QE/@03001=TDfA00Q=T@030015LDEa00Q5
L@030011<D4a00]1<@03000m4CdA00`m4@03000i43T@00hi4003000`l33`00d`l003000X/2R`00dX
/08002Eoo`03001oogoo00Ioo`40005oo`5oo`0000=oo`00Ool097oo0P000W/;17l>00<007[@N]00
17[@00<007JaM[401GJa00<006iaKW401fia00<006YAJU401fYA00<006HaIS4026Ha00<005hAGQ40
2EhA00<005WAFM402EWA00<005FaEK4025Fa00<004fACI4024fA00<004EaAG4024Ea00<0044a@C40
2d4a00<003dA?A4033dA00<003T@>A003ST@00<0033`<?003C3`00<002R`:;003BR`00<007ooOol0
9Goo00<007ooOol01Goo0@000Goo0Goo0002Ool2000SOol20002N`/4O`h00`00N]1jd004N]000`00
M[5f/@05M[400`00KW5^L@07KW400`00JU5ZD@07JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00
FM5Id@09FM400`00EK5E/@08EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00
?A4m4@0<?A400`00>A0i400>>A000`00<?0`l00><?000`00:;0X/00::;02000YOol00`00Oomoo`04
Ool10001Ool1Ool000Aoo`03001oogoo021oo`04001k2g/;0004O`h00`00N]1jd003N]000`00M[5f
/@06M[400`00KW5^L@07KW400`00JU5ZD@07JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5I
d@09FM400`00EK5E/@08EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m
4@0<?A400`00>A0i400>>A000`00<?0`l00><?000`00:;0X/009:;000`00Oomoo`0ZOol00`00Oomo
o`04Ool10001Ool000Eoo`03001oogoo01moo`04001k2g/;0004O`h00`00N]1jd003N]000`00M[5f
/@06M[400`00KW5^L@06KW400`00JU5ZD@08JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5I
d@09FM400`00EK5E/@08EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m
4@0<?A400`00>A0i400>>A000`00<?0`l00><?000`00:;0X/007:;02000]Ool00`00Oomoo`04Ool1
0001Ool000Ioo`8001moo`04001k2g/;0004O`h00`00N]1jd003N]000`00M[5f/@06M[400`00KW5^
L@06KW400`00JU5ZD@08JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5Id@09FM400`00EK5E
/@08EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0<?A400`00>A0i
400>>A000`00<?0`l00><?000`00:;0X/006:;000`00Oomoo`0^Ool00`00Oomoo`03Ool10001Ool0
00Qoo`03001oogoo01aoo`04001k2g/;0004O`h00`00N]1jd003N]000`00M[5f/@05M[400`00KW5^
L@07KW400`00JU5ZD@08JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5Id@09FM400`00EK5E
/@08EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0<?A400`00>A0i
400>>A000`00<?0`l00><?000`00:;0X/004:;02000bOol00`00Oomoo`02Ool10001Ool000Uoo`03
001oogoo01]oo`04001k2g/;0003O`h00`00N]1jd004N]000`00M[5f/@05M[400`00KW5^L@07KW40
0`00JU5ZD@08JU400`00IS5V<@08IS400`00GQ5N4@09GQ400`00FM5Id@08FM400`00EK5E/@09EK40
0`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0<?A400`00>A0i400>>A00
0`00<?0`l00><?000`00:;0X/003:;000`00Oomoo`0cOol01@00Oomoogoo00000Goo000:Ool2000K
Ool01000N`]k2`000gl>00<007[@N]0017[@00<007JaM[401GJa00<006iaKW401fia00<006YAJU40
1fYA00<006HaIS402FHa00<005hAGQ402EhA00<005WAFM4025WA00<005FaEK402EFa00<004fACI40
24fA00<004EaAG4024Ea00<0044a@C402d4a00<003dA?A4033dA00<003T@>A003ST@00<0033`<?00
3S3`00@002R`:;0X/08003Ioo`05001oogooOol00001Ool000aoo`03001oogoo01Uoo`03001k2`00
00=o3P03001jd7[@00Ajd003001f/GJa00Ef/@03001^LFia00M^L@03001ZDFYA00MZD@03001V<FHa
00UV<@03001N4EhA00UN4@03001IdEWA00QId@03001E/EFa00UE/@03001=TDfA00Q=T@030015LDEa
00Q5L@030011<D4a00]1<@03000m4CdA00`m4@03000i43T@00hi4003000`l33`00h`l004000X/2R`
000iOol01000Oomoo`000Goo000=Ool00`00Oomoo`0HOol00`00N`]o3P03O`h00`00N]1jd004N]00
0`00M[5f/@05M[400`00KW5^L@07KW400`00JU5ZD@07JU400`00IS5V<@09IS400`00GQ5N4@09GQ40
0`00FM5Id@08FM400`00EK5E/@09EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C40
0`00?A4m4@0<?A400`00>A0i400>>A000`00<?0`l00><?03000kOol00`00Ool00001Ool000ioo`80
01Qoo`03001k2gl>00=o3P03001jd7[@00Ajd003001f/GJa00Ef/@03001^LFia00M^L@03001ZDFYA
00MZD@03001V<FHa00UV<@03001N4EhA00UN4@03001IdEWA00QId@03001E/EFa00UE/@03001=TDfA
00Q=T@030015LDEa00Q5L@030011<D4a00]1<@03000m4CdA00`m4@03000i43T@00li4003000`l33`
00d`l003001oogoo03aoo`40005oo`40000047oo00<007ooOol05Goo00<007/;O`h00gl>00<007[@
N]0017[@00<007JaM[401GJa00<006iaKW401fia00<006YAJU401fYA00<006HaIS402FHa00<005hA
GQ402EhA00<005WAFM4025WA00<005FaEK402EFa00<004fACI4024fA00<004EaAG4024Ea00<0044a
@C402d4a00<003dA?A403CdA00<003T@>A003ST@00<0033`<?002c3`0P00?goo0@000Goo0@00000A
Ool00`00Oomoo`0EOol00`00O`io3P02O`h00`00N]1jd003N]000`00M[5f/@06M[400`00KW5^L@07
KW400`00JU5ZD@07JU400`00IS5V<@09IS400`00GQ5N4@09GQ400`00FM5Id@08FM400`00EK5E/@09
EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0=?A400`00>A0i400>
>A000`00<?0`l00:<?000`00Oomoo`10Ool20000019oo`8001Eoo`03001o3Wl>009o3P03001jd7[@
00=jd003001f/GJa00If/@03001^LFia00M^L@03001ZDFYA00MZD@03001V<FHa00UV<@03001N4EhA
00QN4@03001IdEWA00UId@03001E/EFa00UE/@03001=TDfA00Q=T@030015LDEa00Q5L@030011<D4a
00]1<@03000m4CdA00dm4@03000i43T@00hi4003000`l33`00P`l08004=oo`80000057oo00<007oo
Ool04goo00D007l>O`io3P0000Ejd003001f/GJa00If/@03001^LFia00M^L@03001ZDFYA00MZD@03
001V<FHa00UV<@03001N4EhA00QN4@03001IdEWA00UId@03001E/EFa00UE/@03001=TDfA00Q=T@03
0015LDEa00Q5L@030011<D4a00]1<@03000m4CdA00dm4@03000i43T@00hi4003000`l33`00H`l080
045oo`@0009oo`005Goo00<007ooOol04Woo00D007l>O`io3P0000Ejd003001f/GJa00If/@03001^
LFia00M^L@03001ZDFYA00MZD@03001V<FHa00UV<@03001N4EhA00QN4@03001IdEWA00UId@03001E
/EFa00UE/@03001=TDfA00Q=T@030015LDEa00Q5L@030011<D4a00]1<@03000m4CdA00dm4@03000i
43T@00hi4003000`l33`00D`l003001oogoo03eoo`@000Ioo`005Woo00<007ooOol04Woo00<007l>
O`h01W[@00<007JaM[401GJa00<006iaKW401fia00<006YAJU4026YA00<006HaIS402FHa00<005hA
GQ4025hA00<005WAFM402EWA00<005FaEK402EFa00<004fACI4024fA00<004EaAG4024Ea00<0044a
@C402d4a00<003dA?A403CdA00<003T@>A003ST@00<0033`<?000c3`0P00?7oo10002Woo000GOol2
000BOol00`00O`io3P06N]000`00M[5f/@05M[400`00KW5^L@07KW400`00JU5ZD@08JU400`00IS5V
<@08IS400`00GQ5N4@09GQ400`00FM5Id@09FM400`00EK5E/@09EK400`00CI5=T@08CI400`00AG55
L@08AG400`00@C51<@0;@C400`00?A4m4@0=?A400`00>A0i400>>A000`00<?0`l002<?000`00Oomo
o`0hOol4000>Ool001Uoo`03001oogoo011oo`03001o3W[@00Ejd003001f/GJa00Ef/@03001^LFia
00M^L@03001ZDFYA00QZD@03001V<FHa00QV<@03001N4EhA00UN4@03001IdEWA00UId@03001E/EFa
00UE/@03001=TDfA00Q=T@030015LDEa00Q5L@030011<D4a00]1<@03000m4CdA00dm4@03000i43T@
00hi4003000`l33`008003Moo`@0019oo`006Woo00<007ooOol03goo00<007l>N]001G[@00<007Ja
M[401GJa00<006iaKW401fia00<006YAJU4026YA00<006HaIS4026Ha00<005hAGQ402EhA00<005WA
FM402EWA00<005FaEK402EFa00<004fACI4024fA00<004EaAG4024Ea00<0044a@C402d4a00<003dA
?A403CdA00<003T@>A003ST@0`00=Goo10005Woo000KOol2000@Ool00`00N]1jd004N]000`00M[5f
/@05M[400`00KW5^L@07KW400`00JU5ZD@07JU400`00IS5V<@09IS400`00GQ5N4@09GQ400`00FM5I
d@09FM400`00EK5E/@09EK400`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m
4@0=?A400`00>A0i400=>A02000cOol4000JOol001eoo`03001oogoo00ioo`03001jd7[@00=jd003
001f/GJa00Ef/@03001^LFia00M^L@03001ZDFYA00MZD@03001V<FHa00UV<@03001N4EhA00UN4@03
001IdEWA00UId@03001E/EFa00UE/@03001=TDfA00Q=T@030015LDEa00Q5L@030011<D4a00]1<@03
000m4CdA00dm4@03000i43T@00/i4080039oo`<001ioo`007Woo00<007ooOol03Woo00<007[@N]00
0W[@27Ja00<006iaKW401fia00<006YAJU401fYA00<006HaIS402FHa00<005hAGQ402EhA00<005WA
FM402EWA00<005FaEK402EFa00<004fACI4024fA00<004EaAG4024Ea00<0044a@C402d4a00<003dA
?A403CdA00<003T@>A002CT@0P00<7oo10008Goo000OOol2000?Ool01000N]1jd7[@27Ja00<006ia
KW401fia00<006YAJU401fYA00<006HaIS402FHa00<005hAGQ402EhA00<005WAFM402EWA00<005Fa
EK402EFa00<004fACI4024fA00<004EaAG4024Ea00<0044a@C402d4a00<003dA?A403CdA00<003T@
>A001cT@0P00;Woo10009Goo000QOol00`00Oomoo`0=Ool00`00N]1jd008M[400`00KW5^L@07KW40
0`00JU5ZD@07JU400`00IS5V<@09IS400`00GQ5N4@09GQ400`00FM5Id@09FM400`00EK5E/@09EK40
0`00CI5=T@08CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@0=?A400`00>A0i4005>A02
000/Ool4000YOol0029oo`03001oogoo00eoo`03001jd7Ja00Mf/@03001^LFia00M^L@03001ZDFYA
00MZD@03001V<FHa00UV<@03001N4EhA00UN4@03001IdEWA00UId@03001E/EFa00UE/@03001=TDfA
00Q=T@030015LDEa00Q5L@030011<D4a00]1<@03000m4CdA00dm4@03000i43T@00<i408002Yoo`@0
02eoo`008goo0P003Woo00<007JaM[401WJa00<006iaKW401fia00<006YAJU401fYA00<006HaIS40
2FHa00<005hAGQ402EhA00<005WAFM402EWA00<005FaEK402EFa00<004fACI4024fA00<004EaAG40
24Ea00<0044a@C402d4a00<003dA?A403CdA00@003T@>A0i408002Qoo`@0035oo`009Goo00<007oo
Ool037oo00<007JaM[401GJa2Via00<006YAJU401fYA00<006HaIS402FHa00<005hAGQ402EhA00<0
05WAFM402EWA00<005FaEK4025Fa00<004fACI402DfA00<004EaAG4024Ea00<0044a@C402d4a00<0
03dA?A403CdA00@003T@000002Ioo`@003Eoo`009Woo00<007ooOol037oo0P001GJa2Via00<006YA
JU401fYA00<006HaIS402FHa00<005hAGQ402EhA00<005WAFM402EWA00<005FaEK4025Fa00<004fA
CI402DfA00<004EaAG4024Ea00<0044a@C402d4a00<003dA?A4033dA0`0097oo1000>Goo000WOol2
000>Ool00`00M[5f/@02M[4:KW400`00JU5ZD@07JU400`00IS5V<@09IS400`00GQ5N4@09GQ400`00
FM5Id@09FM400`00EK5E/@08EK400`00CI5=T@09CI400`00AG55L@08AG400`00@C51<@0;@C400`00
?A4m4@0:?A42000SOol4000mOol002Uoo`03001oogoo00aoo`04001f/GJaM[49KW400`00JU5ZD@08
JU400`00IS5V<@09IS400`00GQ5N4@09GQ400`00FM5Id@09FM400`00EK5E/@08EK400`00CI5=T@09
CI400`00AG55L@08AG400`00@C51<@0;@C400`00?A4m4@08?A42000ROol30011Ool002Yoo`03001o
ogoo00aoo`800003M[5^LFia00M^L@03001ZDFYA00QZD@03001V<FHa00UV<@03001N4EhA00UN4@03
001IdEWA00UId@03001E/EFa00QE/@03001=TDfA00U=T@030015LDEa00Q5L@030011<D4a00]1<@03
000m4CdA00Hm4@80021oo`@004Aoo`00:goo00<007ooOol03Goo0P0026ia00<006YAJU4026YA00<0
06HaIS402FHa00<005hAGQ402EhA00<005WAFM4025WA00<005FaEK402EFa00<004fACI402DfA00<0
04EaAG4024Ea00<0044a@C402d4a00<003dA?A400cdA0`007Woo1000B7oo000/Ool2000?Ool20006
KW400`00JU5ZD@08JU400`00IS5V<@09IS400`00GQ5N4@09GQ400`00FM5Id@08FM400`00EK5E/@09
EK400`00CI5=T@09CI400`00AG55L@08AG400`00@C51<@0;@C401000?A4m4CdA0P007Goo1000C7oo
000^Ool00`00Oomoo`0>Ool30003KW400`00JU5ZD@07JU400`00IS5V<@0:IS400`00GQ5N4@08GQ40
0`00FM5Id@09FM400`00EK5E/@09EK400`00CI5=T@09CI400`00AG55L@08AG400`00@C51<@0;@C40
1000?A4000006goo1000D7oo000_Ool00`00Oomoo`0@Ool200000fia001ZD@08JU400`00IS5V<@09
IS400`00GQ5N4@09GQ400`00FM5Id@09FM400`00EK5E/@09EK400`00CI5=T@09CI400`00AG55L@08
AG400`00@C51<@0:@C43000IOol4001DOol0031oo`80019oo`<000QZD@03001V<FHa00UV<@03001N
4EhA00UN4@03001IdEWA00UId@03001E/EFa00UE/@03001=TDfA00U=T@030015LDEa00Q5L@030011
<D4a00M1<@<001Qoo`@005Qoo`00<Woo00<007ooOol04Woo0P001VYA00<006HaIS402FHa00<005hA
GQ402EhA00<005WAFM402EWA00<005FaEK402EFa00<004fACI402DfA00<004EaAG4024Ea00<0044a
@C401D4a0P005goo1000G7oo000cOol00`00Oomoo`0COol30003JU400`00IS5V<@09IS400`00GQ5N
4@09GQ400`00FM5Id@09FM400`00EK5E/@09EK400`00CI5=T@09CI400`00AG55L@08AG400`00@C51
<@02@C43000FOol3001POol003Aoo`8001Ioo`800003JU4006Ha00YV<@03001N4EhA00UN4@03001I
dEWA00UId@03001E/EFa00UE/@03001=TDfA00U=T@030015LDEa00Q5L@030011<@00008001Eoo`@0
06=oo`00=Woo00<007ooOol05Goo0`002VHa00<005hAGQ402EhA00<005WAFM402EWA00<005FaEK40
2EFa00<004fACI402DfA00<004EaAG401dEa0`0057oo1000Igoo000gOol00`00Oomoo`0GOol40006
IS400`00GQ5N4@09GQ400`00FM5Id@09FM400`00EK5E/@09EK400`00CI5=T@09CI400`00AG55L@03
AG44000COol4001[Ool003Qoo`8001]oo`@0009V<@03001N4EhA00UN4@03001IdEWA00UId@03001E
/EFa00UE/@03001=TDfA00U=T@030015L@0000<001=oo`@006moo`00>Woo00<007ooOol067oo00@0
07ooOomoo`P000IN4@03001IdEWA00UId@03001E/EFa00UE/@03001=TDfA00A=T@L001=oo`@007=o
o`00>goo00<007ooOol05goo00<007ooOol02Goo30001UWA00<005FaEK4015Fa30005Woo1000Mgoo
000lOol2000GOol00`00Oomoo`0EOol=000NOol4001kOol003ioo`03001oogoo01Aoo`03001oogoo
03eoo`<007moo`00?goo00<007ooOol04goo00<007ooOol0>Goo1000PWoo0010Ool00`00Oomoo`0B
Ool00`00Oomoo`0eOol40026Ool0045oo`80019oo`03001oogoo035oo`@008Yoo`00@goo00<007oo
Ool03goo00<007ooOol0;Goo1000SWoo0014Ool00`00Oomoo`0>Ool00`00Oomoo`0YOol4002BOol0
04Eoo`8000ioo`03001oogoo02Eoo`@009Ioo`00Agoo00<007ooOol02goo00<007ooOol08Goo1000
VWoo0018Ool00`00Oomoo`09Ool00`00Oomoo`0NOol4002NOol004Uoo`8000Uoo`03001oogoo01]o
o`<00:9oo`00Bgoo00<007ooOol01Woo00<007ooOol05goo1000YGoo001<Ool00`00Oomoo`05Ool0
0`00Oomoo`0COol4002YOol004eoo`8000Eoo`03001oogoo00moo`@00:eoo`00Cgoo00<007ooOol0
0Woo00<007ooOol02goo1000/Goo001@Ool01@00Oomoogoo00002Goo1000]Goo001AOol200000goo
001oo`04Ool4002iOol005=oo`800003Ool0000000800;eoo`00E7oo0P00`Goo0000\
\>"],
  ImageRangeCache->{{{0, 278}, {260, 0}} -> {-4.923*^-06, 0.00817454, 
  0.00354173, 0.00354173}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that the ",
  StyleBox["DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " was set to ",
  StyleBox["Identity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default so as not to produce unwanted output when the ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is evaluated. This must be rectified when the ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is shown with the ",
  StyleBox["DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["$DisplayFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Example 3D Cam Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam functions, a 3D model of a rotating cam with a spherical follower is \
developed. The model consists of two moving bodies, the cam and the follower. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the 3D cam-follower model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.09373  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.033745 1.07005 0.0267512 1.07005 [ 
[ 0 0 0 0 ] 
[ 1 1.09373 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 1.09373 L 
0 1.09373 L 
closepath 
clip 
newpath 
p 
P 
p 
.004 w 
.16285 .32403 m 
.32221 .48769 L 
s 
P 
p 
.004 w 
.715 .11243 m 
.16285 .32403 L 
s 
P 
p 
.002 w 
.49239 .52643 m .47145 .54504 L .36197 .42658 L p 
.804 .771 .823 r 
F P 
s 
P 
p 
.004 w 
.51374 .55041 m 
.57576 .64305 L 
s 
P 
p 
.004 w 
.44379 .44594 m 
.51374 .55041 L 
s 
P 
p 
.004 w 
.74964 .3409 m 
.84211 .30914 L 
s 
P 
p 
.004 w 
.32221 .48769 m 
.39527 .4626 L 
s 
P 
p 
.004 w 
.40476 .45934 m 
.74964 .3409 L 
s 
P 
p 
.002 w 
.47145 .54504 m .45319 .56609 L .34241 .4488 L p 
.838 .772 .789 r 
F P 
s 
P 
p 
.002 w 
.34241 .4488 m .36197 .42658 L .47145 .54504 L p 
.838 .772 .789 r 
F P 
s 
P 
p 
.002 w 
.51539 .51083 m .49239 .52643 L .38422 .40678 L p 
.765 .766 .854 r 
F P 
s 
P 
p 
.002 w 
.36197 .42658 m .38422 .40678 L .49239 .52643 L p 
.804 .771 .823 r 
F P 
s 
P 
p 
.002 w 
.45319 .56609 m .43816 .58898 L .32612 .4728 L p 
.869 .769 .748 r 
F P 
s 
P 
p 
.002 w 
.32612 .4728 m .34241 .4488 L .45319 .56609 L p 
.869 .769 .748 r 
F P 
s 
P 
p 
.002 w 
.53976 .49872 m .51539 .51083 L .40848 .38999 L p 
.72 .756 .881 r 
F P 
s 
P 
p 
.002 w 
.38422 .40678 m .40848 .38999 L .51539 .51083 L p 
.765 .766 .854 r 
F P 
s 
P 
p 
.004 w 
.2912 .27484 m 
.39946 .39623 L 
s 
P 
p 
.002 w 
.43816 .58898 m .42684 .61302 L .31361 .49788 L p 
.899 .76 .699 r 
F P 
s 
P 
p 
.004 w 
.32138 .50356 m 
.32221 .48769 L 
s 
P 
p 
.002 w 
.31361 .49788 m .32612 .4728 L .43816 .58898 L p 
.899 .76 .699 r 
F P 
s 
P 
p 
.004 w 
.84211 .30914 m 
.715 .11243 L 
s 
P 
p 
.002 w 
.56594 .49011 m .53976 .49872 L .43405 .37673 L p 
.664 .74 .906 r 
F P 
s 
P 
p 
.002 w 
.40848 .38999 m .43405 .37673 L .53976 .49872 L p 
.72 .756 .881 r 
F P 
s 
P 
p 
.002 w 
.42684 .61302 m .41962 .63749 L .30531 .52328 L p 
.925 .742 .636 r 
F P 
s 
P 
p 
.004 w 
.31977 .53396 m 
.32126 .50566 L 
s 
P 
p 
.002 w 
.30531 .52328 m .31361 .49788 L .42684 .61302 L p 
.925 .742 .636 r 
F P 
s 
P 
p 
.002 w 
.6 .48307 m .56594 .49011 L .46139 .36699 L p 
.614 .722 .922 r 
F P 
s 
P 
p 
.004 w 
.57576 .64305 m 
.63757 .50439 L 
s 
P 
p 
.004 w 
.63757 .50439 m 
.70336 .35679 L 
s 
P 
p 
.002 w 
.43405 .37673 m .46139 .36699 L .56594 .49011 L p 
.664 .74 .906 r 
F P 
s 
P 
p 
.002 w 
.41962 .63749 m .4168 .66164 L .30155 .54822 L p 
.947 .711 .549 r 
F P 
s 
P 
p 
.004 w 
.31835 .56092 m 
.31959 .53754 L 
s 
P 
p 
.002 w 
.30155 .54822 m .30531 .52328 L .41962 .63749 L p 
.947 .711 .549 r 
F P 
s 
P 
p 
.002 w 
.64144 .47773 m .6 .48307 L .49686 .35858 L p 
.576 .706 .931 r 
F P 
s 
P 
p 
.002 w 
.46139 .36699 m .49686 .35858 L .6 .48307 L p 
.614 .722 .922 r 
F P 
s 
P 
p 
.002 w 
.4168 .66164 m .41854 .68469 L .30254 .57192 L p 
.956 .655 .422 r 
F P 
s 
P 
p 
.004 w 
.31717 .58341 m 
.31816 .56457 L 
s 
P 
p 
.002 w 
.30254 .57192 m .30155 .54822 L .4168 .66164 L p 
.956 .655 .422 r 
F P 
s 
P 
p 
.004 w 
.35904 .37933 m 
.41969 .47274 L 
s 
P 
p 
.004 w 
.2912 .27484 m 
.35904 .37933 L 
s 
P 
p 
.002 w 
.6875 .47489 m .64144 .47773 L .53995 .35166 L p 
.54 .69 .937 r 
F P 
s 
P 
p 
.002 w 
.49686 .35858 m .53995 .35166 L .64144 .47773 L p 
.576 .706 .931 r 
F P 
s 
P 
p 
.002 w 
.41854 .68469 m .42488 .70589 L .30834 .59358 L p 
.93 .548 .225 r 
F P 
s 
P 
p 
.004 w 
.31629 .60015 m 
.31703 .58601 L 
s 
P 
p 
.002 w 
.30834 .59358 m .30254 .57192 L .41854 .68469 L p 
.93 .548 .225 r 
F P 
s 
P 
p 
.004 w 
.46456 .78245 m 
.57576 .64305 L 
s 
P 
p 
.004 w 
.42312 .83441 m 
.46456 .78245 L 
s 
P 
p 
.002 w 
.42488 .70589 m .43571 .72447 L .31889 .61242 L p 
.813 .345 0 r 
F P 
s 
P 
p 
.002 w 
.31889 .61242 m .30834 .59358 L .42488 .70589 L p 
.813 .345 0 r 
F P 
s 
P 
p 
.004 w 
.29717 .963 m 
.31592 .60711 L 
s 
P 
p 
.002 w 
.73455 .47547 m .6875 .47489 L .58782 .34713 L p 
.496 .669 .94 r 
F P 
s 
P 
p 
.002 w 
.53995 .35166 m .58782 .34713 L .6875 .47489 L p 
.54 .69 .937 r 
F P 
s 
P 
p 
.002 w 
.43571 .72447 m .45078 .73976 L .33395 .62775 L p 
.531 .023 0 r 
F P 
s 
P 
p 
.002 w 
.33395 .62775 m .31889 .61242 L .43571 .72447 L p 
.531 .023 0 r 
F P 
s 
P 
p 
.002 w 
.77834 .48048 m .73455 .47547 L .63668 .34608 L p 
.429 .634 .941 r 
F P 
s 
P 
p 
.002 w 
.58782 .34713 m .63668 .34608 L .73455 .47547 L p 
.496 .669 .94 r 
F P 
s 
P 
p 
.002 w 
.45078 .73976 m .46967 .75113 L .35311 .63893 L p 
0 .316 .784 r 
F P 
s 
P 
p 
.002 w 
.35311 .63893 m .33395 .62775 L .45078 .73976 L p 
0 .316 .784 r 
F P 
s 
P 
p 
.002 w 
.46967 .75113 m .49179 .75809 L .43411 .70209 L p 
.191 .543 .928 r 
F P 
s 
P 
p 
.002 w 
.43411 .70209 m .37579 .64547 L p 
.41908 .69419 L .191 .543 .928 r 
F P 
s 
P 
p 
.41908 .69419 m .46967 .75113 L .43411 .70209 L .191 .543 .928 r 
F 
P 
p 
.002 w 
.49179 .75809 m .495 .75838 L p 
.4321 .67735 L .409 .665 .965 r 
F P 
s 
P 
p 
.002 w 
.48844 .73277 m .4321 .67735 L p 
.495 .75838 L .409 .665 .965 r 
F P 
s 
P 
p 
.42018 .67022 m .49179 .75809 L .4321 .67735 L .409 .665 .965 r 
F 
P 
p 
.002 w 
.37579 .64547 m .49179 .75809 L p 
.42018 .67022 L .409 .665 .965 r 
F P 
s 
P 
p 
.002 w 
.40125 .647 m .37911 .64567 L p 
.42018 .67022 L .409 .665 .965 r 
F P 
s 
P 
p 
.002 w 
.37911 .64567 m .37579 .64547 L p 
.42018 .67022 L .409 .665 .965 r 
F P 
s 
P 
p 
.002 w 
.49123 .70606 m .4838 .69862 L p 
.49066 .71158 L .549 .729 .958 r 
F P 
s 
P 
p 
.002 w 
.4838 .69862 m .4286 .64337 L p 
.46397 .69046 L .549 .729 .958 r 
F P 
s 
P 
p 
.46397 .69046 m .51642 .76029 L .4838 .69862 L .549 .729 .958 r 
F 
P 
p 
.002 w 
.45814 .63421 m .4286 .64337 L .54268 .75755 L p 
.644 .764 .936 r 
F P 
s 
P 
p 
.002 w 
.47837 .69342 m .49181 .70051 L p 
.48187 .7071 L .736 .89 .95 r 
F P 
s 
P 
p 
.002 w 
.49181 .70051 m .49301 .70114 L .49167 .70186 L p 
.736 .89 .95 r 
F P 
s 
P 
p 
.002 w 
.49167 .70186 m .48187 .7071 L p 
.49181 .70051 L .736 .89 .95 r 
F P 
s 
P 
p 
.002 w 
.51642 .76029 m .54268 .75755 L .49123 .70606 L p 
.549 .729 .958 r 
F P 
s 
P 
p 
.49066 .71158 m .51642 .76029 L .49123 .70606 L .549 .729 .958 r 
F 
P 
p 
.002 w 
.48187 .7071 m .49167 .70186 L p 
.49017 .71206 L .714 .705 .841 r 
F P 
s 
P 
p 
.002 w 
.49167 .70186 m .49301 .70114 L p 
.49271 .70228 L .714 .705 .841 r 
F P 
s 
P 
p 
.49017 .71206 m .49167 .70186 L .49271 .70228 L .714 .705 .841 r 
F 
P 
p 
.002 w 
.4286 .64337 m .40125 .647 L .51642 .76029 L p 
.549 .729 .958 r 
F P 
s 
P 
p 
.002 w 
.48085 .74789 m .45572 .7211 L .48187 .7071 L p 
.714 .705 .841 r 
F P 
s 
P 
p 
.48085 .74789 m .48187 .7071 L .49017 .71206 L .714 .705 .841 r 
F 
P 
p 
.002 w 
.47221 .69017 m .47837 .69342 L p 
.45572 .7211 L .736 .89 .95 r 
F P 
s 
P 
p 
.002 w 
.48187 .7071 m .45572 .7211 L p 
.47837 .69342 L .736 .89 .95 r 
F P 
s 
P 
p 
.002 w 
.495 .75838 m .51642 .76029 L .48844 .73277 L p 
.409 .665 .965 r 
F P 
s 
P 
p 
.002 w 
.4321 .67735 m .40125 .647 L p 
.42018 .67022 L .409 .665 .965 r 
F P 
s 
P 
p 
.002 w 
.51294 .73086 m .48085 .74789 L p 
.49017 .71206 L .714 .705 .841 r 
F P 
s 
P 
p 
.002 w 
.49301 .70114 m .50713 .7222 L p 
.49017 .71206 L .714 .705 .841 r 
F P 
s 
P 
p 
.002 w 
.50713 .7222 m .51294 .73086 L p 
.49017 .71206 L .714 .705 .841 r 
F P 
s 
P 
p 
.002 w 
.50855 .78126 m .48085 .74789 L .50096 .73722 L p 
.666 .571 .739 r 
F P 
s 
P 
p 
.002 w 
.50096 .73722 m .51294 .73086 L p 
.51188 .74297 L .666 .571 .739 r 
F P 
s 
P 
p 
.50855 .78126 m .50096 .73722 L .51188 .74297 L .666 .571 .739 r 
F 
P 
p 
.002 w 
.48085 .74789 m .50855 .78126 L .49484 .79808 L p 
.73 .581 .688 r 
F P 
s 
P 
p 
.002 w 
.49484 .79808 m .45702 .77699 L .48085 .74789 L p 
.73 .581 .688 r 
F P 
s 
P 
p 
.002 w 
.45702 .77699 m .49484 .79808 L .48954 .81761 L p 
.762 .548 .606 r 
F P 
s 
P 
p 
.002 w 
.42789 .75493 m .45702 .77699 L .44755 .8108 L p 
.876 .674 .626 r 
F P 
s 
P 
p 
.002 w 
.48954 .81761 m .44755 .8108 L .45702 .77699 L p 
.762 .548 .606 r 
F P 
s 
P 
p 
.002 w 
.44755 .8108 m .48954 .81761 L .49191 .82642 L p 
.754 .455 .478 r 
F P 
s 
P 
p 
.002 w 
.49191 .82642 m .49415 .83474 L p 
.47774 .82631 L .754 .455 .478 r 
F P 
s 
P 
p 
.47774 .82631 m .44755 .8108 L .49191 .82642 L .754 .455 .478 r 
F 
P 
p 
.002 w 
.29552 .99438 m .10745 .8537 L .24808 .82457 L p 
.735 .797 .901 r 
F P 
s 
P 
p 
.002 w 
.41661 .79419 m .44755 .8108 L .45146 .82611 L p 
.886 .536 .378 r 
F P 
s 
P 
p 
.002 w 
.24808 .82457 m .38639 .79591 L p 
.42208 .81417 L .735 .797 .901 r 
F P 
s 
P 
p 
.42789 .82593 m .42208 .81417 L .44533 .82606 L .735 .797 .901 r 
F 
P 
p 
.24808 .82457 m .42208 .81417 L .42789 .82593 L .735 .797 .901 r 
F 
P 
p 
.002 w 
.40502 .77181 m .41661 .79419 L .42099 .81197 L p 
.862 .527 .012 r 
F P 
s 
P 
p 
.41469 .79921 m .40502 .77181 L .42099 .81197 L .862 .527 .012 r 
F 
P 
p 
.43788 .81981 m .41661 .79419 L .45146 .82611 L .886 .536 .378 r 
F 
P 
p 
.002 w 
.44755 .8108 m .41661 .79419 L .42789 .75493 L p 
.876 .674 .626 r 
F P 
s 
P 
p 
.002 w 
.49415 .83474 m .45517 .84063 L .44755 .8108 L p 
.754 .455 .478 r 
F P 
s 
P 
p 
.002 w 
.41501 .73746 m .42789 .75493 L .41661 .79419 L p 
.993 .842 .59 r 
F P 
s 
P 
p 
.002 w 
.44709 .82408 m .44533 .82606 L p 
.42208 .81417 L .735 .797 .901 r 
F P 
s 
P 
p 
.38639 .79591 m .42099 .81197 L .42208 .81417 L .735 .797 .901 r 
F 
P 
p 
.42099 .81197 m .44709 .82408 L .42208 .81417 L .735 .797 .901 r 
F 
P 
p 
.002 w 
.44533 .82606 m .29552 .99438 L p 
.24808 .82457 L .735 .797 .901 r 
F P 
s 
P 
p 
.002 w 
.45517 .84063 m .42516 .82886 L .42099 .81197 L p 
.886 .536 .378 r 
F P 
s 
P 
p 
.002 w 
.42099 .81197 m .41661 .79419 L p 
.43788 .81981 L .886 .536 .378 r 
F P 
s 
P 
p 
.45517 .84063 m .42099 .81197 L .43788 .81981 L .886 .536 .378 r 
F 
P 
p 
.002 w 
.49156 .77412 m .44709 .82408 L p 
.42099 .81197 L .735 .797 .901 r 
F P 
s 
P 
p 
.002 w 
.4088 .78729 m .40502 .77181 L p 
.41469 .79921 L .862 .527 .012 r 
F P 
s 
P 
p 
.002 w 
.41661 .79419 m .40502 .77181 L .41501 .73746 L p 
.993 .842 .59 r 
F P 
s 
P 
p 
.002 w 
.41662 .74942 m .40502 .77181 L .4088 .78729 L p 
0 0 .486 r 
F P 
s 
P 
p 
.40309 .80366 m .41058 .7909 L .42099 .81197 L .735 .797 .901 r 
F 
P 
p 
.002 w 
.4073 .79158 m .41058 .7909 L p 
.40309 .80366 L .735 .797 .901 r 
F P 
s 
P 
p 
.002 w 
.41058 .7909 m .49156 .77412 L p 
.42099 .81197 L .735 .797 .901 r 
F P 
s 
P 
p 
.002 w 
.42516 .82886 m .41239 .80197 L .4088 .78729 L p 
.862 .527 .012 r 
F P 
s 
P 
p 
.42516 .82886 m .4088 .78729 L .41469 .79921 L .862 .527 .012 r 
F 
P 
p 
.002 w 
.4088 .78729 m .41239 .80197 L p 
.41501 .76948 L 0 0 .486 r 
F P 
s 
P 
p 
.41501 .76948 m .41662 .74942 L .4088 .78729 L 0 0 .486 r 
F 
P 
p 
.002 w 
.38639 .79591 m .4073 .79158 L p 
.40309 .80366 L .735 .797 .901 r 
F P 
s 
P 
p 
.002 w 
.42099 .81197 m .42516 .82886 L p 
.41469 .79921 L .862 .527 .012 r 
F P 
s 
P 
p 
.002 w 
.45146 .82611 m .45517 .84063 L p 
.43788 .81981 L .886 .536 .378 r 
F P 
s 
P 
p 
.004 w 
.10745 .8537 m 
.16285 .32403 L 
s 
P 
p 
.025 w 
.10745 .8537 m 
.29552 .99438 L 
s 
P 
p 
.002 w 
.37579 .64547 m .35311 .63893 L .46967 .75113 L p 
.191 .543 .928 r 
F P 
s 
P 
p 
.002 w 
.81451 .49075 m .77834 .48048 L .68211 .34969 L p 
.3 .559 .927 r 
F P 
s 
P 
p 
.002 w 
.63668 .34608 m .68211 .34969 L .77834 .48048 L p 
.429 .634 .941 r 
F P 
s 
P 
p 
.004 w 
.5668 .16922 m 
.70336 .35679 L 
s 
P 
p 
.004 w 
.41969 .47274 m 
.49111 .32539 L 
s 
P 
p 
.004 w 
.49111 .32539 m 
.5668 .16922 L 
s 
P 
p 
.002 w 
.83915 .5068 m .81451 .49075 L .71951 .359 L p 
0 .335 .816 r 
F P 
s 
P 
p 
.002 w 
.68211 .34969 m .71951 .359 L .81451 .49075 L p 
.3 .559 .927 r 
F P 
s 
P 
p 
.002 w 
.54268 .75755 m .57087 .74953 L .45814 .63421 L p 
.644 .764 .936 r 
F P 
s 
P 
p 
.002 w 
.57087 .74953 m .60731 .73436 L .49651 .61739 L p 
.698 .78 .915 r 
F P 
s 
P 
p 
.002 w 
.50202 .67909 m .5305 .70823 L p 
.50697 .63598 L .698 .78 .915 r 
F P 
s 
P 
p 
.002 w 
.5305 .70823 m .57087 .74953 L p 
.55022 .71284 L .698 .78 .915 r 
F P 
s 
P 
p 
.50697 .63598 m .5305 .70823 L .55022 .71284 L .698 .78 .915 r 
F 
P 
p 
.002 w 
.50487 .68932 m .53041 .70027 L .4995 .70099 L p 
.351 .748 .985 r 
F P 
s 
P 
p 
.002 w 
.4995 .70099 m .49301 .70114 L p 
.49436 .69979 L .351 .748 .985 r 
F P 
s 
P 
p 
.49436 .69979 m .50487 .68932 L .4995 .70099 L .351 .748 .985 r 
F 
P 
p 
.002 w 
.51294 .73086 m .49853 .70938 L p 
.53041 .70027 L .534 .63 .893 r 
F P 
s 
P 
p 
.002 w 
.49853 .70938 m .49301 .70114 L .4995 .70099 L p 
.534 .63 .893 r 
F P 
s 
P 
p 
.002 w 
.4995 .70099 m .53041 .70027 L p 
.49853 .70938 L .534 .63 .893 r 
F P 
s 
P 
p 
.002 w 
.49651 .61739 m .45814 .63421 L .50202 .67909 L p 
.698 .78 .915 r 
F P 
s 
P 
p 
.49651 .61739 m .50202 .67909 L .50697 .63598 L .698 .78 .915 r 
F 
P 
p 
.002 w 
.71951 .359 m .74479 .37467 L .83915 .5068 L p 
0 .335 .816 r 
F P 
s 
P 
p 
.002 w 
.84942 .52862 m .83915 .5068 L .74479 .37467 L p 
.794 .374 0 r 
F P 
s 
P 
p 
.002 w 
.60731 .73436 m .65114 .71237 L .54281 .59327 L p 
.726 .788 .901 r 
F P 
s 
P 
p 
.002 w 
.54281 .59327 m .49651 .61739 L .60731 .73436 L p 
.726 .788 .901 r 
F P 
s 
P 
p 
.025 w 
.41969 .47274 m 
.53424 .59774 L 
s 
P 
p 
.002 w 
.74479 .37467 m .75492 .39683 L .84942 .52862 L p 
.794 .374 0 r 
F P 
s 
P 
p 
.002 w 
.84398 .55563 m .84942 .52862 L .75492 .39683 L p 
.973 .774 .576 r 
F P 
s 
P 
p 
.002 w 
.65114 .71237 m .69905 .68479 L .59356 .56321 L p 
.748 .793 .889 r 
F P 
s 
P 
p 
.002 w 
.59356 .56321 m .54281 .59327 L .65114 .71237 L p 
.748 .793 .889 r 
F P 
s 
P 
p 
.002 w 
.69905 .68479 m .7468 .65329 L .64429 .52908 L p 
.77 .798 .875 r 
F P 
s 
P 
p 
.002 w 
.64429 .52908 m .59356 .56321 L .69905 .68479 L p 
.77 .798 .875 r 
F P 
s 
P 
p 
.002 w 
.82334 .58661 m .84398 .55563 L .74851 .4249 L p 
.892 .812 .762 r 
F P 
s 
P 
p 
.002 w 
.75492 .39683 m .74851 .4249 L .84398 .55563 L p 
.973 .774 .576 r 
F P 
s 
P 
p 
.002 w 
.51294 .73086 m .5271 .7715 L .50855 .78126 L p 
.666 .571 .739 r 
F P 
s 
P 
p 
.002 w 
.50855 .78126 m .49484 .79808 L .53204 .81304 L closepath p 
.628 .437 .604 r 
F P 
s 
P 
p 
.002 w 
.5271 .7715 m .50855 .78126 L .53204 .81304 L closepath p 
.601 .431 .623 r 
F P 
s 
P 
p 
.002 w 
.45572 .7211 m .48085 .74789 L .45702 .77699 L p 
.813 .714 .755 r 
F P 
s 
P 
p 
.002 w 
.7468 .65329 m .78972 .61985 L .69006 .49309 L p 
.797 .803 .857 r 
F P 
s 
P 
p 
.002 w 
.69006 .49309 m .64429 .52908 L .7468 .65329 L p 
.797 .803 .857 r 
F P 
s 
P 
p 
.002 w 
.49484 .79808 m .48954 .81761 L .53204 .81304 L closepath p 
.638 .42 .57 r 
F P 
s 
P 
p 
.002 w 
.54515 .73035 m .54567 .7714 L .5271 .7715 L p 
.561 .511 .757 r 
F P 
s 
P 
p 
.002 w 
.5271 .7715 m .51294 .73086 L .54515 .73035 L p 
.561 .511 .757 r 
F P 
s 
P 
p 
.002 w 
.54567 .7714 m .5271 .7715 L .53204 .81304 L closepath p 
.56 .401 .623 r 
F P 
s 
P 
p 
.002 w 
.78972 .61985 m .82334 .58661 L .72609 .45761 L p 
.834 .809 .826 r 
F P 
s 
P 
p 
.002 w 
.74851 .4249 m .72609 .45761 L .82334 .58661 L p 
.892 .812 .762 r 
F P 
s 
P 
p 
.002 w 
.45702 .77699 m .42789 .75493 L .45572 .7211 L p 
.813 .714 .755 r 
F P 
s 
P 
p 
.002 w 
.72609 .45761 m .69006 .49309 L .78972 .61985 L p 
.834 .809 .826 r 
F P 
s 
P 
p 
.002 w 
.53041 .70027 m .54515 .73035 L .51294 .73086 L p 
.534 .63 .893 r 
F P 
s 
P 
p 
.002 w 
.48954 .81761 m .49415 .83474 L .53204 .81304 L closepath p 
.626 .379 .524 r 
F P 
s 
P 
p 
.002 w 
.56907 .74686 m .55936 .78108 L .54567 .7714 L p 
.386 .367 .716 r 
F P 
s 
P 
p 
.002 w 
.54567 .7714 m .54515 .73035 L .56907 .74686 L p 
.386 .367 .716 r 
F P 
s 
P 
p 
.002 w 
.55936 .78108 m .54567 .7714 L .53204 .81304 L closepath p 
.508 .348 .599 r 
F P 
s 
P 
p 
.002 w 
.5644 .79813 m .55936 .78108 L .53204 .81304 L closepath p 
.456 .279 .551 r 
F P 
s 
P 
p 
.002 w 
.5593 .81799 m .5644 .79813 L .53204 .81304 L closepath p 
.422 .213 .488 r 
F P 
s 
P 
p 
.002 w 
.54533 .83524 m .5593 .81799 L .53204 .81304 L closepath p 
.425 .177 .432 r 
F P 
s 
P 
p 
.002 w 
.52634 .84508 m .54533 .83524 L .53204 .81304 L closepath p 
.469 .191 .409 r 
F P 
s 
P 
p 
.002 w 
.50758 .84485 m .52634 .84508 L .53204 .81304 L closepath p 
.533 .247 .427 r 
F P 
s 
P 
p 
.002 w 
.49415 .83474 m .50758 .84485 L .53204 .81304 L closepath p 
.59 .318 .472 r 
F P 
s 
P 
p 
.002 w 
.4395 .70775 m .45572 .7211 L .42789 .75493 L p 
.899 .897 .816 r 
F P 
s 
P 
p 
.002 w 
.45572 .7211 m .4395 .70775 L .47221 .69017 L p 
.736 .89 .95 r 
F P 
s 
P 
p 
.002 w 
.45517 .84063 m .49415 .83474 L .50758 .84485 L p 
.662 .257 .268 r 
F P 
s 
P 
p 
.002 w 
.42789 .75493 m .41501 .73746 L .4395 .70775 L p 
.899 .897 .816 r 
F P 
s 
P 
p 
.002 w 
.55819 .7192 m .56907 .74686 L .54515 .73035 L p 
.098 .347 .816 r 
F P 
s 
P 
p 
.002 w 
.54515 .73035 m .53041 .70027 L .55819 .7192 L p 
.098 .347 .816 r 
F P 
s 
P 
p 
.002 w 
.57803 .77644 m .5644 .79813 L .55936 .78108 L p 
.096 .069 .534 r 
F P 
s 
P 
p 
.002 w 
.55936 .78108 m .56907 .74686 L .57803 .77644 L p 
.096 .069 .534 r 
F P 
s 
P 
p 
.002 w 
.49301 .70114 m .47221 .69017 L .50487 .68932 L p 
.351 .748 .985 r 
F P 
s 
P 
p 
.002 w 
.47833 .85843 m .50758 .84485 L .52634 .84508 L p 
.384 0 0 r 
F P 
s 
P 
p 
.002 w 
.50758 .84485 m .47833 .85843 L .45517 .84063 L p 
.662 .257 .268 r 
F P 
s 
P 
p 
.002 w 
.56913 .81127 m .5593 .81799 L .5644 .79813 L p 
0 0 .129 r 
F P 
s 
P 
p 
.002 w 
.5644 .79813 m .57803 .77644 L .56913 .81127 L p 
0 0 .129 r 
F P 
s 
P 
p 
.002 w 
.42516 .82886 m .45517 .84063 L .47833 .85843 L p 
.625 .059 0 r 
F P 
s 
P 
p 
.002 w 
.51111 .85894 m .52634 .84508 L .54533 .83524 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.52634 .84508 m .51111 .85894 L .47833 .85843 L p 
.384 0 0 r 
F P 
s 
P 
p 
.002 w 
.56855 .75351 m .57803 .77644 L .56907 .74686 L p 
.759 .435 0 r 
F P 
s 
P 
p 
.002 w 
.56907 .74686 m .55819 .7192 L .56855 .75351 L p 
.759 .435 0 r 
F P 
s 
P 
p 
.002 w 
.52894 .70579 m .55819 .7192 L .53041 .70027 L p 
.531 0 0 r 
F P 
s 
P 
p 
.002 w 
.53041 .70027 m .50487 .68932 L .52894 .70579 L p 
.531 0 0 r 
F P 
s 
P 
p 
.004 w 
.10745 .8537 m 
.31165 .60456 L 
s 
P 
p 
.004 w 
.31165 .60456 m 
.41969 .47274 L 
s 
P 
p 
.002 w 
.54453 .84165 m .54533 .83524 L .5593 .81799 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.5593 .81799 m .56913 .81127 L .54453 .84165 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.54533 .83524 m .54453 .84165 L .51111 .85894 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.43682 .71191 m .4395 .70775 L .41501 .73746 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.45601 .7016 m .47221 .69017 L .4395 .70775 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.4395 .70775 m .43682 .71191 L .45601 .7016 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.42244 .72935 m .41501 .73746 L .40502 .77181 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.41501 .73746 m .42244 .72935 L .43682 .71191 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.47503 .70115 m .50487 .68932 L .47221 .69017 L p 
.302 0 0 r 
F P 
s 
P 
p 
.002 w 
.47221 .69017 m .45601 .7016 L .47503 .70115 L p 
.302 0 0 r 
F P 
s 
P 
p 
.002 w 
.47833 .85843 m .45189 .84954 L .42516 .82886 L p 
.625 .059 0 r 
F P 
s 
P 
p 
.002 w 
.45189 .84954 m .47833 .85843 L .51111 .85894 L p 
.254 .715 .95 r 
F P 
s 
P 
p 
.002 w 
.41239 .80197 m .42516 .82886 L .45189 .84954 L p 
0 .286 .786 r 
F P 
s 
P 
p 
.002 w 
.55803 .79415 m .56913 .81127 L .57803 .77644 L p 
.998 .85 .55 r 
F P 
s 
P 
p 
.002 w 
.57803 .77644 m .56855 .75351 L .55803 .79415 L p 
.998 .85 .55 r 
F P 
s 
P 
p 
.002 w 
.40502 .77181 m .41662 .74942 L .42244 .72935 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.53771 .73567 m .56855 .75351 L .55819 .7192 L p 
.891 .52 .329 r 
F P 
s 
P 
p 
.002 w 
.55819 .7192 m .52894 .70579 L .53771 .73567 L p 
.891 .52 .329 r 
F P 
s 
P 
p 
.002 w 
.48886 .71082 m .52894 .70579 L .50487 .68932 L p 
.644 .213 .209 r 
F P 
s 
P 
p 
.002 w 
.50487 .68932 m .47503 .70115 L .48886 .71082 L p 
.644 .213 .209 r 
F P 
s 
P 
p 
.002 w 
.49006 .85006 m .51111 .85894 L .54453 .84165 L p 
.722 .912 .96 r 
F P 
s 
P 
p 
.002 w 
.51111 .85894 m .49006 .85006 L .45189 .84954 L p 
.254 .715 .95 r 
F P 
s 
P 
p 
.002 w 
.52916 .82974 m .54453 .84165 L .56913 .81127 L p 
.907 .922 .815 r 
F P 
s 
P 
p 
.002 w 
.56913 .81127 m .55803 .79415 L .52916 .82974 L p 
.907 .922 .815 r 
F P 
s 
P 
p 
.002 w 
.54453 .84165 m .52916 .82974 L .49006 .85006 L p 
.722 .912 .96 r 
F P 
s 
P 
p 
.002 w 
.42244 .72935 m .44908 .73328 L .43682 .71191 L closepath p 
.388 .129 .395 r 
F P 
s 
P 
p 
.002 w 
.43682 .71191 m .44908 .73328 L .45601 .7016 L closepath p 
.437 .146 .372 r 
F P 
s 
P 
p 
.002 w 
.41662 .74942 m .44908 .73328 L .42244 .72935 L closepath p 
.387 .171 .459 r 
F P 
s 
P 
p 
.002 w 
.43566 .81979 m .45189 .84954 L .49006 .85006 L p 
.51 .63 .905 r 
F P 
s 
P 
p 
.002 w 
.45189 .84954 m .43566 .81979 L .41239 .80197 L p 
0 .286 .786 r 
F P 
s 
P 
p 
.002 w 
.42099 .76687 m .41239 .80197 L .43566 .81979 L p 
.348 .341 .71 r 
F P 
s 
P 
p 
.002 w 
.41239 .80197 m .42099 .76687 L .41662 .74942 L p 
0 0 .486 r 
F P 
s 
P 
p 
.002 w 
.45601 .7016 m .44908 .73328 L .47503 .70115 L closepath p 
.511 .212 .395 r 
F P 
s 
P 
p 
.002 w 
.52829 .77108 m .55803 .79415 L .56855 .75351 L p 
.887 .68 .616 r 
F P 
s 
P 
p 
.002 w 
.56855 .75351 m .53771 .73567 L .52829 .77108 L p 
.887 .68 .616 r 
F P 
s 
P 
p 
.002 w 
.4937 .72817 m .53771 .73567 L .52894 .70579 L p 
.755 .442 .455 r 
F P 
s 
P 
p 
.002 w 
.52894 .70579 m .48886 .71082 L .4937 .72817 L p 
.755 .442 .455 r 
F P 
s 
P 
p 
.002 w 
.42099 .76687 m .44908 .73328 L .41662 .74942 L closepath p 
.429 .248 .532 r 
F P 
s 
P 
p 
.002 w 
.47503 .70115 m .44908 .73328 L .48886 .71082 L closepath p 
.577 .292 .448 r 
F P 
s 
P 
p 
.002 w 
.46889 .81999 m .49006 .85006 L .52916 .82974 L p 
.713 .715 .85 r 
F P 
s 
P 
p 
.002 w 
.49006 .85006 m .46889 .81999 L .43566 .81979 L p 
.51 .63 .905 r 
F P 
s 
P 
p 
.002 w 
.43454 .77699 m .44908 .73328 L .42099 .76687 L closepath p 
.489 .327 .588 r 
F P 
s 
P 
p 
.002 w 
.43566 .81979 m .43454 .77699 L .42099 .76687 L p 
.348 .341 .71 r 
F P 
s 
P 
p 
.002 w 
.43454 .77699 m .43566 .81979 L .46889 .81999 L p 
.548 .505 .76 r 
F P 
s 
P 
p 
.002 w 
.50299 .80213 m .52916 .82974 L .55803 .79415 L p 
.821 .724 .758 r 
F P 
s 
P 
p 
.002 w 
.55803 .79415 m .52829 .77108 L .50299 .80213 L p 
.821 .724 .758 r 
F P 
s 
P 
p 
.002 w 
.48886 .71082 m .44908 .73328 L .4937 .72817 L closepath p 
.618 .361 .507 r 
F P 
s 
P 
p 
.002 w 
.48807 .7486 m .52829 .77108 L .53771 .73567 L p 
.766 .545 .598 r 
F P 
s 
P 
p 
.002 w 
.53771 .73567 m .4937 .72817 L .48807 .7486 L p 
.766 .545 .598 r 
F P 
s 
P 
p 
.002 w 
.52916 .82974 m .50299 .80213 L .46889 .81999 L p 
.713 .715 .85 r 
F P 
s 
P 
p 
.002 w 
.4937 .72817 m .44908 .73328 L .48807 .7486 L closepath p 
.631 .407 .559 r 
F P 
s 
P 
p 
.002 w 
.48807 .7486 m .44908 .73328 L .47342 .7665 L closepath p 
.622 .426 .596 r 
F P 
s 
P 
p 
.002 w 
.47342 .7665 m .44908 .73328 L .45376 .77691 L closepath p 
.593 .419 .616 r 
F P 
s 
P 
p 
.002 w 
.45376 .77691 m .44908 .73328 L .43454 .77699 L closepath p 
.547 .386 .615 r 
F P 
s 
P 
p 
.002 w 
.46889 .81999 m .45376 .77691 L .43454 .77699 L p 
.548 .505 .76 r 
F P 
s 
P 
p 
.002 w 
.45376 .77691 m .46889 .81999 L .50299 .80213 L p 
.663 .571 .741 r 
F P 
s 
P 
p 
.002 w 
.47342 .7665 m .50299 .80213 L .52829 .77108 L p 
.731 .581 .687 r 
F P 
s 
P 
p 
.002 w 
.52829 .77108 m .48807 .7486 L .47342 .7665 L p 
.731 .581 .687 r 
F P 
s 
P 
p 
.002 w 
.50299 .80213 m .47342 .7665 L .45376 .77691 L p 
.663 .571 .741 r 
F P 
s 
P 
p 
P 
p 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{262, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004600017a000`40O003h00Oogoo1goo003oOol7
Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00
ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7
Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00
ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00^Goo0P00Bgoo002g
Ool20002Ool00`00Oomoo`18Ool00;Aoo`<000Aoo`03001oogoo04Qoo`00/Goo0`0027oo00<007oo
Ool0Agoo002_Ool2000<Ool00`00Oomoo`16Ool00:aoo`<000ioo`03001oogoo04Ioo`00ZGoo0`00
4Woo00<007ooOol0AGoo002WOol2000FOol00`00Oomoo`14Ool00:Aoo`<001Qoo`03001oogoo04Ao
o`00XWoo0P0077oo00<007ooOol0@goo002OOol3000NOol00`00Oomoo`13Ool009aoo`<0029oo`03
001oogoo049oo`00VWoo0P009Woo00<007ooOol0@Goo002GOol3000XOol00`00Oomoo`11Ool009Eo
o`8002aoo`03001oogoo041oo`00TWoo0`00;goo00<007ooOol0?goo002?Ool300000goo0000000_
Ool00`00Oomoo`0oOol008eoo`8000=oo`03001oo`00031oo`03001oogoo03ioo`00RWoo0`001Goo
00@007ooOol0031oo`03001oogoo03eoo`00Qgoo0`001goo00<007ooOol00Woo00<007ooOol0;Goo
00<007ooOol0?Goo0025Ool2000:Ool00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`0lOol0
089oo`<000]oo`03001oogoo00Aoo`03001oogoo02ioo`03001oogoo03]oo`00P7oo0P003Woo00<0
07ooOol01Goo00<007ooOol0;Goo00<007ooOol0>goo001mOol3000?Ool00`00Oomoo`07Ool00`00
Oomoo`0]Ool00`00Oomoo`0jOol007Yoo`<0019oo`03001oogoo00Qoo`03001oogoo02eoo`03001o
ogoo03Uoo`00N7oo0P0057oo00<007ooOol02Goo00<007ooOol0;Goo00<007ooOol0>Goo001eOol3
000FOol00`00Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`0hOol007=oo`8001Qoo`03001oogoo
00aoo`03001oogoo02aoo`03001oogoo03Qoo`00L7oo0`006Woo00<007ooOol03Goo00<007ooOol0
;7oo00<007ooOol0=goo001]Ool3000MOol00`00Oomoo`0=Ool00`00Oomoo`0]Ool00`00Oomoo`0f
Ool006]oo`8001moo`03001oogoo00moo`03001oogoo02aoo`03001oogoo03Ioo`00J7oo0`008Goo
00<007ooOol047oo00<007ooOol0;7oo00<007ooOol0=Goo001UOol3000SOol00`00Oomoo`0AOol0
0`00Oomoo`0]Ool00`00Oomoo`0dOol006=oo`8002Ioo`03001oogoo019oo`03001oogoo02aoo`03
001oogoo03Aoo`00H7oo0`009goo00<007ooOol057oo00<007ooOol0;7oo00<007ooOol0<goo001N
Ool2000ZOol00`00Oomoo`0EOol00`00Oomoo`0/Ool00`00Oomoo`0bOol005]oo`<002]oo`03001o
ogoo01Ioo`03001oogoo02aoo`03001oogoo039oo`00F7oo0`00;Woo00<007ooOol05goo00<007oo
Ool0;7oo00<007ooOol0<Goo001FOol2000`Ool00`00Oomoo`0IOol00`00Oomoo`0/Ool00`00Oomo
o`0`Ool005=oo`<0039oo`03001oogoo01Yoo`03001oogoo02]oo`03001oogoo031oo`00D7oo0`00
=7oo00<007ooOol06goo00<007ooOol0;7oo00<007ooOol0;goo001>Ool2000gOol00`00Oomoo`0L
Ool00`00Oomoo`0/Ool00`00Oomoo`0^Ool004]oo`<003Qoo`03001oogoo01ioo`03001oogoo02]o
o`03001oogoo02ioo`00BGoo0P0000=oo`00Ool0>7oo00<007ooOol07goo00<007ooOol0:goo00<0
07ooOol0;Goo0016Ool30004Ool00`00Oomoo`0fOol00`00Oomoo`0OOol00`00Oomoo`0[Ool00`00
Oomoo`0]Ool004=oo`<000Moo`8003Ioo`03001oogoo025oo`03001oogoo02]oo`03001oogoo02ao
o`00@Goo0P002goo0P00=Goo00<007ooOol08Woo00<007ooOol0:goo00<007ooOol0:goo000nOol3
000>Ool2000cOol00`00Oomoo`0TOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool003aoo`80015oo`03
001oo`00039oo`03001oogoo02Aoo`03001oogoo02]oo`03001oogoo02Yoo`00>Goo0`0057oo0P00
<Goo00<007ooOol09Woo00<007ooOol0:goo00<007ooOol0:Goo000fOol3000GOol00`00Ool0000`
Ool00`00Oomoo`0WOol00`00Oomoo`0ZOol00`00Oomoo`0YOol003Aoo`8001]oo`03001oo`0002io
o`03001oogoo02Qoo`03001oogoo02Yoo`8002Yoo`00<Goo0`007Woo00<007oo0000;Goo00<007oo
Ool0:Goo00<007ooOol09goo0P00;7oo000^Ool3000QOol01000Oomoo`00:goo00<007ooOol0:goo
00<007ooOol08goo0`00;Woo000/Ool2000UOol01000Oomoo`00:Woo00<007ooOol0;7oo00<007oo
Ool07goo0`00<Goo000ZOol2000XOol01000Oomoo`00:7oo00<007ooOol0;Goo00<007ooOol07Goo
0P00=7oo000ZOol2000XOol01@00Oomoogoo00009goo00<007ooOol0;Woo00<007ooOol06Goo0`00
=Woo000ZOol00`00Ool0000XOol01@00Oomoogoo00009Goo00<007ooOol0<7oo00<007ooOol05Goo
0`00>Goo000ZOol01000Oomoo`009goo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol0<Goo
00<007ooOol04Woo0P00?7oo000ZOol01@00Oomoogoo00009goo00D007ooOomoo`0002=oo`03001o
ogoo039oo`03001oogoo00moo`<003ioo`00:Goo00<007ooOol00goo00<007ooOol09Goo00D007oo
Oomoo`00029oo`03001oogoo03=oo`03001oogoo00]oo`<0045oo`00:Goo00<007ooOol017oo00<0
07ooOol097oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol05Woo5P002Goo00<007ooOol0
1goo0`00A7oo000YOol00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0M
Ool00`00Oomoo`0@Ool60004A]d00`00?[hn_P0:?[h00`00=YhfWP02=Yh900000goo001oo`04Ool3
0017Ool002Uoo`03001oogoo00Ioo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo01]oo`03
001oogoo00Qoo`T000]6g@03000n_Sjn00Tn_P03000fWSJN00TfWP8V?@L004Yoo`00:Goo00<007oo
Ool01goo00<007ooOol08goo00<007ooOol00goo00<007ooOol06Woo00@007ooOomoo`L000I:g@03
0016gDKM00]6g@03000n_Sjn00Xn_P03000fWSJN00PfWP03000V?BHm00<V?@<004Yoo`00:Goo00<0
07ooOol027oo00<007ooOol08goo00<007ooOol00goo00<007ooOol067oo00<007oo00000P000Tkm
00<004[MB]d02D[M00<004KMA]d02dKM00<003jn?[h02Sjn00<003JN=Yh023JN00<002Hm9Sd01BHm
0P00B7oo000YOol00`00Oomoo`09Ool00`00Oomoo`0ROol00`00Oomoo`04Ool00`00Oomoo`0FOol3
0006C_d00`00B]e:g@09B]d00`00A]e6g@0;A]d00`00?[hn_P0:?[h00`00=YhfWP08=Yh00`009SdV
?@049Sd00`000EX00017Ool002Uoo`03001oogoo00Yoo`03001oogoo029oo`03001oogoo00Aoo`03
001oogoo019oo`@000Q>o@03001:gD[M00U:g@030016gDKM00a6g@03000n_Sjn00Tn_P03000fWSJN
00TfWP03000V?BHm00@V?@030001FP0004Ioo`00:Goo00<007ooOol02goo00<007ooOol08Woo00<0
07ooOol017oo00<007ooOol03Goo10000UKl0P002Dkm00<004[MB]d02D[M00<004KMA]d02dKM00<0
03jn?[h02Sjn00<003JN=Yh023JN00<002Hm9Sd01BHm00@0005J000004Aoo`00:Goo00<007ooOol0
37oo00<007ooOol08Goo00<007ooOol017oo00<007ooOol02goo0P001UKl0P002Tkm00<004[MB]d0
2D[M00<004KMA]d02dKM00<003jn?[h02Sjn00<003JN=Yh023JN00<002Hm9Sd01BHm00@0005J0EX0
04=oo`00:7oo00<007ooOol03Woo00<007ooOol08Goo00<007ooOol017oo00<007ooOol027oo0P00
00=O7000E_`01EKl00<005Kl00002Tkm00<004[MB]d02D[M00<004KMA]d02dKM00<003jn?[h02Sjn
00<003JN=Yh023JN00<002Hm9Sd012Hm00D0005J0EX1FP00049oo`00:7oo00<007ooOol03goo00<0
07ooOol08Goo00<007ooOol017oo00<007ooOol01Goo0P0015lL00<005KlE_`00UKl00@005KlE_`0
00]>o@03001:gD[M00U:g@030016gDKM00]6g@03000n_Sjn00Tn_P03000fWSJN00TfWP03000V?BHm
00@V?@040001FP5J0012Ool002Qoo`03001oogoo011oo`03001oogoo021oo`03001oogoo00Eoo`03
001oogoo009oo`8000MO7005001Fo5KlE_`00003E_`00`00C_e>o@09C_d00`00B]e:g@09B]d00`00
A]e6g@0:A]d00`00?[hn_P0:?[h00`00=YhfWP08=Yh00`009SdV?@059Sd010000EX1FP00@Goo000X
Ool00`00Oomoo`0AOol00`00Oomoo`0POol00`00Oomoo`05Ool01000Oomoo`002ElL00@005KlE_`0
00EFo003001>oDkm00Q>o@03001:gD[M00U:g@030016gDKM00]6g@03000n_Sjn00Xn_P03000fWSJN
00PfWP03000V?BHm00@V?@030001FP5J0080041oo`00:7oo00<007ooOol04Woo00<007ooOol087oo
00<007ooOol01Goo0P0000=S6`00Ga`025lL00<005Kl00001UKl00<004kmC_d024km00<004[MB]d0
2D[M00<004KMA]d02dKM00<003jn?[h02Sjn00<003JN=Yh023JN00<002Hm9Sd012Hm00<0005J0EX0
0P00?goo000XOol00`00Oomoo`0COol00`00Oomoo`0OOol00`00Oomoo`04Ool00`00Ha]S6`02Ha/0
0`00GaaO7007Ga`00`00E_aFo006E_`00`00C_e>o@08C_d00`00B]e:g@09B]d00`00A]e6g@0;A]d0
0`00?[hn_P09?[h00`00=YhfWP09=Yh00`009SdV?@049Sd010000EX00000?goo000XOol00`00Oomo
o`0DOol00`00Oomoo`0OOol01000Oomoogoo0P001V<K00<005lLGa`01UlL0P0025Kl00<004kmC_d0
24km00<004[MB]d02D[M00<004KMA]d02TKM00<003jn?[h02Sjn00<003JN=Yh023JN00<002Hm9Sd0
1BHm00@007lBOa8003ioo`00:7oo00<007ooOol057oo00<007ooOol087oo00<007oo00002F<K00<0
05lLGa`015lL00@005lLGa`000MFo003001>oDkm00U>o@03001:gD[M00U:g@030016gDKM00Y6g@03
000n_Sjn00Xn_P03000fWSJN00PfWP03000V?BHm00@V?@03001o4WlB008003eoo`00:7oo00<007oo
Ool05Goo00<007ooOol07goo0P0000=W6P00Ha/026<K00<005lLGa`00elL00D005lLGaaO700000MF
o003001>oDkm00Q>o@03001:gD[M00Y:g@030016gDKM00Y6g@03000n_Sjn00Tn_P03000fWSJN00Tf
WP03000V?BHm00<V?@04001o4WlBOa82000lOol002Qoo`03001oogoo01Ioo`03001oogoo01ioo`80
009W6P03001S6f<K00IS6`03001O75lL009O7003001O75lL009O7003001Fo5Kl00IFo003001>oDkm
00Q>o@03001:gD[M00U:g@030016gDKM00]6g@03000n_Sjn00Tn_P03000fWSJN00PfWP03000V?BHm
00<V?@04001o4WlBOa82000lOol002Moo`03001oogoo01Qoo`03001oogoo01]oo`80009W6P04001W
6VLJ0008Ha/01@00GaaO75lL00001ElL00<005KlE_`01UKl00<004kmC_d024km00<004[MB]d02D[M
00<004KMA]d02dKM00<003jn?[h02Cjn00<003JN=Yh023JN00D002Hm9SdV?@0000Eo4P8003]oo`00
9goo00<007ooOol06Goo00<007ooOol06Goo00<006LJIaX00VLJ00D006LJIaYW6P0000QS6`03001O
700000MO7003001Fo5Kl00IFo003001>oDkm00Q>o@03001:gD[M00U:g@030016gDKM00Y6g@03000n
_Sjn00Xn_P03000fWSJN00PfWP04000V?BHm0006Oa82000jOol002Moo`03001oogoo01Yoo`03001o
ogoo01Moo`03001W6VLJ00AW6P05001W6VLJIaX00008Ha/20008Ga`00`00E_aFo006E_`00`00C_e>
o@08C_d00`00B]e:g@09B]d00`00A]e6g@0:A]d00`00?[hn_P09?[h00`00=YhfWP09=Yh00`009Sd0
0006Oa800`00IF00000iOol002Moo`03001oogoo01]oo`03001oogoo01Eoo`03001[6@0000IW6P04
001W6VLJ0008Ha/20009Ga`00`00E_aFo005E_`00`00C_e>o@09C_d00`00B]e:g@09B]d00`00A]e6
g@0:A]d00`00?[hn_P09?[h00`00=YhfWP08=Yh200000g<h001o4P05Oa82000iOol002Moo`03001o
ogoo01aoo`03001oogoo01=oo`05001[6F/IJaT00005IaX01@00IaYW6VLJ00001f<K00<006<K0000
2ElL00<005KlE_`01EKl00<004kmC_d024km00<004[MB]d02T[M00<004KMA]d02TKM00<003jn?[h0
2Cjn00<003JN=Yh01cJN00@007<hLcP000Mo4P8003Qoo`009goo00<007ooOol07Goo00<007ooOol0
4Goo00<006/IJaT00f/I00<006LJIaX00fLJ00D006LJIaYW6P0000ES6`05001S6f<KHa/00008Ga`0
0`00E_aFo006E_`00`00C_e>o@08C_d00`00B]e:g@0:B]d00`00A]e6g@09A]d00`00?[hn_P0:?[h0
0`00=YhfWP06=Yh01@00LcQc>7<h00001glB0P00=goo000WOol00`00Oomoo`0NOol00`00Oomoo`0@
Ool00`00JaU[6@04JaT00`00IaYW6P03IaX01@00IaYW6VLJ000016<K00<006<KHa/00V<K00<005lL
Ga`01UlL00<005KlE_`01UKl00<004kmC_d024km00<004[MB]d02D[M00<004KMA]d02TKM00<003jn
?[h02Cjn00<003JN=Yh01CJN00<007<hLcP00g<h00<007lBOa8017lB0P00=goo000WOol00`00Oomo
o`0OOol00`00Oomoo`0>Ool00`00JaU[6@06JaT00`00IaYW6P02IaX00`00IaYW6P02IaX01000Ha]S
6`001V<K00<005lLGa`01UlL00<005KlE_`01UKl00<004kmC_d024km00<004[MB]d02D[M00<004KM
A]d02TKM00<003jn?[h02Cjn00<003JN=Yh00cJN00<007<hLcP01G<h00<007lBOa8017lB0P00=Woo
000WOol00`00Oomoo`0POol00`00Oomoo`0<Ool00`00JaU[6@08JaT00`00IaYW6P02IaX00`00IaYW
6P02IaX00`00Ha/00007Ha/00`00GaaO7006Ga`00`00E_aFo006E_`00`00C_e>o@08C_d00`00B]e:
g@09B]d00`00A]e6g@0:A]d00`00?[hn_P09?[h01@00=YhfWSJN000027<h00<007lBOa801GlB0P00
=Goo000WOol00`00Oomoo`0QOol00`00Oomoo`0:Ool00`00KaL0000:JaT00`00IaYW6P02IaX00`00
IaYW6P02IaX00`00Ha]S6`06Ha/00`00GaaO7007Ga`00`00E_aFo006E_`00`00C_e>o@07C_d00`00
B]e:g@0:B]d00`00A]e6g@09A]d00`00?[hn_P0:?[h01000=YhfWP002G<h00<007lBOa8017lB00<0
06EP0000=7oo000VOol00`00Oomoo`0SOol00`00Oomoo`09Ool01000KaM_5`002F/I00<006LJIaX0
0VLJ00D006LJIaX006LJ008000QS6`03001O75lL00MO7003001Fo5Kl00EFo003001>oDkm00Q>o@03
001:gD[M00Y:g@030016gDKM00U6g@03000n_Sjn00Tn_P03000fWP0000]c>003001o4WlB00Ao4P80
03Aoo`009Woo00<007ooOol097oo00<007ooOol01goo00<006lGKaL00VlG00<006/IJaT01f/I00D0
06LJIaX006LJ00@0009W6P03001S6f<K00IS6`03001O75lL00MO7003001Fo5Kl00EFo003001>oDkm
00Q>o@03001:gD[M00Y:g@030016gDKM00U6g@03000n_Sjn00Tn_P03001[>P0000]c>003001o4WlB
00Ao4P8003=oo`009Woo00<007ooOol09Goo00<007ooOol01Goo00<006lGKaL016lG00<006/IJaT0
1f/I00@006LJIaYW6PD0009W6P03001S6f<K00IS6`03001O75lL00IO7003001Fo5Kl00IFo003001>
oDkm00Q>o@03001:gD[M00U:g@030016gDKM00Y6g@03000n_Sjn00Ln_P04001[>V/j000;LcP00`00
Oa9o4P04Oa800`00IF00000bOol002Ioo`03001oogoo02Ioo`03001oogoo00Aoo`03001_5flG00E_
5`03001[6F/I00M[6@03001W6P0000D0009W6P03001S6f<K00MS6`03001O75lL00IO7003001Fo5Kl
00IFo003001>oDkm00Q>o@03001:gD[M00U:g@030016gDKM00U6g@03000n_Sjn00Hn_P03001[>V/j
009[>P03001c>7<h00Uc>003001o4WlB00Ao4P03001UH000035oo`009Woo00<007ooOol09goo00<0
07ooOol00Woo00<006lGKaL01flG00<006/IJaT01f/I20000VLJ00<006<KHa/01f<K00<005lLGa`0
1UlL00<005KlE_`01UKl00<004kmC_d024km00<004[MB]d02D[M00<004KMA]d02DKM00<003jn?[h0
13jn00<006/jJcX016/j00<007<hLcP02G<h00<007lBOa8017lB0P00<Goo000VOol00`00Oomoo`0X
Ool01P00Oomoo`00LaH000U_5`03001[6F/I00M[6@P0009W6P03001S6f<K00MS6`03001O75lL00IO
7003001Fo5Kl00IFo003001>oDkm00M>o@03001:gD[M00Q:gA@000Q[>P03001c>7<h00Uc>003001o
4WlB00=o4P03001UH000031oo`009Woo00<007ooOol0:Goo00<007oo00000W<F00<006lGKaL01VlG
00<006/IJaT026/I20000VLJ00<006<KHa/01f<K00<005lLGa`01UlL00<005KlE_`01EKl00<004km
C_d024km00@004[MB]e:g@H000Aoo`03001oogoo00]oo`03001[>V/j00M[>P03001c>7<h00Uc>003
001o4WlB00Ao4P03001UH00002moo`009Woo00<007ooOol0:Woo00<007<FLaH00W<F00<006lGKaL0
1VlG00<006/IJaT01f/I2@000VLJ00<006<KHa/01f<K00<005lLGa`01UlL00<005KlE_`01EKl00<0
04kmC_d01Tkm1@002Goo00<007ooOol02goo00<006/jJcX02F/j00<007<hLcP02G<h00<007lBOa80
17lB00<006EP0000;Woo000VOol00`00Oomoo`0ZOol00`00LaIc5P03LaH00`00KaM_5`06KaL00`00
JaU[6@05JaT00`00JaU[6@080002IaX00`00Ha]S6`07Ha/00`00GaaO7005Ga`00`00E_aFo006E_`0
1000C_e>oDkm10003Woo00<007ooOol02Woo00<006/jJcX02f/j00<007<hLcP02G<h00<007lBOa80
0glB00<006EP0000;Woo000VOol00`00Oomoo`0YOol00`00LaIc5P05LaH00`00KaM_5`06KaL00`00
JaU[6@03JaT00`00JaU[6@02JaT80002IaX00`00Ha]S6`06Ha/00`00GaaO7006Ga`00`00E_aFo005
E_`4000AOol00`00Oomoo`0:Ool00`00JcY[>P0=JcX00`00LcQc>008LcP00`00Oa9o4P04Oa800`00
IF00000]Ool002Eoo`03001oogoo02Yoo`03001c5W<F00Ic5P03001_5flG00I_5`05001[6F/IJaT0
0006JaT80002IaX00`00Ha]S6`06Ha/00`00GaaO7006Ga`00`00E_aFo004000EOol00`00Oomoo`09
Ool00`00Ic/0000>JcX00`00LcQc>009LcP00`00Oa9o4P04Oa800`00IF00000/Ool002Eoo`03001o
ogoo02Uoo`03001c5W<F00Qc5P03001_5flG00I_5`03001[6@0000Q[6@P0009W6P03001S6f<K00IS
6`03001O75lL00IO708001Qoo`03001oogoo00Uoo`05001W>fLkIc/0000>JcX00`00LcQc>009LcP0
0`00Oa9o4P04Oa800`00IF00000[Ool002Eoo`03001oogoo02Uoo`8000Yc5P03001_5flG00I_5`80
00U[6@P0009W6P03001S6f<K00IS6`03001O75lL00=O708001Yoo`03001oogoo00Moo`8000AW>`03
001[>V/j00e[>P03001c>7<h00Uc>003001o4WlB00=o4P03001UH00002]oo`009Goo00<007ooOol0
:7oo00@007KdM_@000Yc5P03001_5flG00E_5`8000Y[6@P00003IaX006<K00QS6`03001O75lL0080
01aoo`03001oogoo00Ioo`03001W>fLk00EW>`03001[>V/j00e[>P03001c>7<h00Qc>003001o4WlB
00Ao4P03001UH00002Yoo`009Goo00<007ooOol0:7oo00D007KdM_Afm00000Yc5P03001_5flG00=_
5`04001_5flG000:JaT70002IaX00`00Ha]S6`07Ha/2000MOol00`00Oomoo`06Ool00`00Ic]W>`07
Ic/00`00JcY[>P0<JcX00`00LcQc>009LcP00`00Oa9o4P04Oa82000ZOol002Eoo`03001oogoo02Qo
o`03001fm7Kd009fm003001c5W<F00Qc5P05001_5flGKaL00004KaL00`00JaU[6@08JaT70002IaX0
0`00Ha]S6`04Ha/2000OOol00`00Oomoo`05Ool00`00Ic]W>`09Ic/00`00JcY[>P0<JcX00`00LcQc
>009LcP00`00Oa9o4P03Oa800`00IF00000YOol002Eoo`03001oogoo02Moo`03001fm7Kd00Afm003
001c5W<F00Qc5P03001_5`0000I_5`03001[6F/I00M[6@P0009W6P03001S6f<K009S6`03001oogoo
01ioo`03001oogoo00Eoo`03001W>fLk00YW>`03001[>V/j00e[>P03001c>7<h00Uc>003001o4WlB
00=o4P8002Uoo`009Goo00<007ooOol09goo00<007KdM_@01GKd00<007<FLaH027<F0P001flG00<0
06/IJaT01f/I20000VLJ00@006<K0000025oo`03001oogoo00=oo`8000iW>`03001[>V/j00a[>P03
001c>7<h00Uc>003001o4WlB00Ao4P03001oogoo02Moo`009Goo00<007ooOol09goo0P001gKd00<0
07<FLaH01g<F0P0026lG00<006/IJaT01f/I20000VLJ00<007oo000087oo00<007ooOol00goo00<0
06LkIc/03fLk00<006/jJcX036/j00<007<hLcP02G<h00<007lBOa800glB0P00:7oo000UOol00`00
Oomoo`0WOol00`00N]400007M_@00`00LaIc5P05LaH00`00LaH00009KaL00`00JaU[6@07JaT90002
Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Ic]W>`0AIc/00`00JcY[>P0<JcX00`00LcQc>009
LcP00`00Oa9o4P03Oa800`00Oomoo`0VOol002Aoo`03001oogoo02Qoo`04001jdG[A0007M_@00`00
LaIc5P03LaH01@00LaIc5W<F00002FlG00<006/IJaT01f/I20000goo00<007ooOol07Goo00<007oo
Ool00P0000=S>`00Ic/04FLk00<006/jJcX03F/j00<007<hLcP02G<h00<007lBOa800WlB00<007oo
Ool09Woo000TOol00`00Oomoo`0WOol00`00N]5jd@02N]400`00M_Afm005M_@01@00LaIc5W<F0000
1G<F00<006lGKaL01flG00<006/IJaT01f/I20000goo00<007ooOol06goo00@007ooOol000AS>`03
001W>fLk011W>`03001[>V/j00a[>P03001c>7<h00Uc>003001o4WlB009o4P03001oogoo02Ioo`00
97oo00<007ooOol09goo00<007[AN]400g[A00<007KdM_@01GKd00@007<FLaH000Ic5P03001_5flG
00I_5`03001[6F/I00Q[6@P000=oo`03001oogoo01Yoo`<000ES>`03001W>fLk015W>`03001[>V/j
00a[>P03001c>7<h00Uc>005001o4WlBOa80000XOol002Aoo`03001oogoo02Moo`03001jdG[A00Aj
d@03001fm7Kd00Efm08000Qc5P03001_5flG00I_5`03001[6F/I00Q[6@P0009oo`03001oogoo01Uo
o`8000QS>`03001W>fLk015W>`03001[>V/j00a[>P03001c>7<h00Uc>003001o4P0002Uoo`0097oo
00<007ooOol09goo00<007[AN]401G[A00<007KdM_@017Kd0P002G<F00<006lGKaL01VlG00<006/I
JaT01V/I00<007oo00001P000goo00<007ooOol05goo0P002V<k00<006LkIc/046Lk00<006/jJcX0
3F/j00<007<hLcP02G<h0P00:Goo000TOol00`00Oomoo`0WOol20007N]400`00M_Afm002M_@01000
M_Afm0002G<F00<006lGKaL01VlG00<006/IJaT016/I00@007ooOomoo`L000=oo`03001oogoo01Ao
o`8000eS>`03001W>fLk011W>`03001[>V/j00a[>P03001c>7<h00Uc>08002Uoo`0097oo00<007oo
Ool09goo00<007Z=00001g[A00@007KdM_@000Afm003001c5W<F00Mc5P03001_5flG00I_5`03001[
6F/I009[6@03001oogoo00=oo`L0009oo`03001oogoo01=oo`03001S>f<k00iS>`03001W>fLk011W
>`03001[>V/j00a[>P03001c>7<h00Uc>003001oogoo02Moo`0097oo00<007ooOol09goo00@007Z=
NXd000Mjd@03001fm00000Efm003001c5W<F00Mc5P03001_5flG00I_5`05001[6F/IJaT00006Ool7
0002Ool00`00Oomoo`0@Ool2000AHc/00`00Ic]W>`0AIc/00`00JcY[>P0<JcX00`00LcQc>007LcP0
0`00Oomoo`0XOol002Aoo`03001oogoo02Moo`04001jSGZ=NXd20006N]400`00M_Afm005M_@00`00
LaIc5P07LaH00`00KaM_5`06KaL00`00JaT00007Ool80002Ool00`00Oomoo`0>Ool00`00Hc]S>`0B
Hc/00`00Ic]W>`0AIc/00`00JcY[>P0<JcX00`00LcQc>005LcP00`00Oomoo`0YOol002Aoo`03001o
ogoo02Moo`03001jSGZ=009jS@03001jdG[A00=jd@03001jd@0000Mfm003001c5W<F00Mc5P03001_
5flG00I_5`03001oogoo00Moo`P00003Ool007oo00eoo`800003Gc`006<k01=S>`03001W>fLk011W
>`03001[>V/j00a[>P03001c>7<h00Ec>003001oogoo02Uoo`008goo00<007ooOol0:7oo00<007Z=
NXd00gZ=00D007[AN]5jd@0000=jd@03001fm7Kd00Efm003001c5W<F00Mc5P03001_5flG00A_5`03
001oogoo00Uoo`P00003Ool007oo00Yoo`8000AO?003001S>f<k019S>`03001W>fLk011W>`03001[
>V/j00a[>P03001c>7<h00=c>003001oogoo02Yoo`008goo00<007ooOol0:7oo0P001GZ=00<007[A
00001G[A00<007KdM_@01GKd00<007<FLaH01g<F00<006lGKaL00VlG00<007ooOol02goo2@002Woo
00<005llGc`01Ell00<006<kHc/04V<k00<006LkIc/046Lk00<006/jJcX036/j00D007<hLcQc>000
02eoo`008goo00<007ooOol0:Goo0P001GZ=0P001W[A00<007KdM_@01GKd00<007<FLaH01g<F00D0
06lGKaM_5`0000ioo`T000Moo`8000UO?003001S>f<k019S>`03001W>fLk011W>`03001[>V/j00a[
>P03001c>00002ioo`008goo00<007ooOol0:Goo00<007HW000017Z=0P001g[A00<007KdM_@01GKd
00<007<FLaH01g<F00<006lG000047oo2@001Goo00<005llGc`02Ull00<006<kHc/04F<k00<006Lk
Ic/046Lk00<006/jJcX036/j00<007<h0000;Woo000SOol00`00Oomoo`0YOol01000MRMf9`000WZ=
00@007Z=NXd000Mjd@03001fm7Kd00Efm003001c5W<F00Mc5P03001oogoo011oo`P000=oo`8000eO
?003001S>f<k019S>`03001W>fLk011W>`03001[>V/j00a[>P03001oogoo02eoo`008goo00<007oo
Ool0:Woo00<007HWMRL00P0017Z=00<007[AN]401G[A00<007KdM_@01GKd00<007<FLaH01W<F00<0
07ooOol04Goo2P0045ll00<006<kHc/04V<k00<006LkIc/046Lk00<006/jJcX02V/j00<007ooOol0
;Woo000SOol00`00Oomoo`0ZOol00`00MRMf9`020005NXd00`00N]5jd@05N]400`00M_Afm005M_@0
0`00LaIc5P04LaH00`00Oomoo`0COol7000CGc`00`00Hc]S>`0BHc/00`00Ic]W>`0@Ic/00`00JcY[
>P08JcX00`00Oomoo`0_Ool002=oo`03001oogoo02]oo`04001f9`00MRL20004NXd00`00N]5jd@05
N]400`00M_Afm005M_@00`00LaIc5P03LaH00`00Oomoo`0DOol7000CGc`00`00Hc]S>`0BHc/00`00
Ic]W>`0?Ic/00`00JcY[>P07JcX00`00Oomoo`0`Ool002=oo`03001oogoo02]oo`8000Af9`03001j
SGZ=009jS@03001jdG[A00Ejd@03001fm7Kd00Efm005001c5W<FLaH0000HOol7000CGc`00`00Hc]S
>`0AHc/00`00Ic]W>`0@Ic/00`00JcY[>P05JcX00`00Oomoo`0aOol002=oo`03001oogoo02]oo`<0
00Af9`03001jSGZ=009jS@8000Ijd@03001fm7Kd00Efm004001c5W<F000FOol70002Gc`00`00GcaO
?00AGc`00`00Hc]S>`0AHc/00`00Ic]W>`0@Ic/00`00JcY[>P04JcX00`00Oomoo`0aOol0029oo`03
001oogoo02]oo`05001oo`00JF000004MRL00`00NXejS@03NXd00`00N]5jd@04N]400`00M_Afm005
M_@2000EOol20003Gc`30004Gc`00`00GcaO?00AGc`00`00Hc]S>`0AHc/00`00Ic]W>`0@Ic/00`00
JcY[>P02JcX00`00Oomoo`0bOol0029oo`03001oogoo02Yoo`03001oogoo00800003JF0007HW00=f
9`03001jSGZ=00=jS@03001jdG[A00Ajd@03001fm7Kd00Efm003001oogoo015oo`8000IO?003001O
?5ll00AO?003001O?5ll015O?003001S>f<k015S>`03001W>fLk00mW>`05001[>V/jJcX0000eOol0
029oo`03001oogoo02Yoo`08001oogoo001oo`00JF0000Af9`03001jSGZ=00=jS@03001jdG[A00Aj
d@03001fm7Kd00Afm003001oogoo00ioo`<000mO?003001O?5ll019O?003001S>f<k015S>`03001W
>fLk00mW>`03001[>P0003Ioo`008Woo00<007ooOol0:Goo00D007ooOomoo`00009oo`03001YH000
00Af9`03001jSGZ=00=jS@03001jdG[A00Ajd@03001fm7Kd009fm003001oogoo00eoo`80009K7@03
001O?5ll00iO?003001O?5ll019O?003001S>f<k011S>`03001W>fLk011W>`03001oogoo03Eoo`00
8Woo00<007ooOol0:7oo00<007ooOol00Woo00L007ooOomoo`00JF000004MRL00`00NXejS@03NXd0
0`00N]5jd@04N]401@00M_Afm7Kd000037oo0`001E/M00<005llGc`03Ull00<005llGc`04Ell00<0
06<kHc/04F<k00<006LkIc/03FLk0P00>7oo000ROol00`00Oomoo`0WOol00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00JF000004MRL00`00NXejS@03NXd00`00N]5jd@04N]401000M_Afm0002Woo0P00
2E/M00<005llGc`03Ull00<005llGc`04Ell00<006<kHc/04F<k00<006LkIc/02fLk00<007ooOol0
>7oo000ROol00`00Oomoo`0VOol00`00Oomoo`04Ool00`00Oomoo`03Ool30004MRL00`00NXejS@03
NXd00`00N]5jd@04N]420008Ool3000<Fad00`00GcaO?00>Gc`00`00GcaO?00AGc`00`00Hc]S>`0A
Hc/00`00Ic]W>`08Ic/2000kOol0029oo`03001oogoo02Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`<000Af9`03001jSGZ=00=jS@03001jdG[A00Ajd@03001oogoo00Aoo`80009C7@03001K7E/M00]K
7@03001O?5ll00iO?003001O?5ll015O?003001S>f<k015S>`03001W>fLk00IW>`03001oogoo03]o
o`008Woo00<007ooOol09Goo00<007ooOol01Goo00<007ooOol01Goo00<0005I00000P000WHW00<0
07Z=NXd00gZ=00<007[AN]400g[A00@007ooOomoo`<000EC7@03001K7E/M00]K7@03001O?5ll00iO
?003001O?5ll015O?003001S>f<k015S>`03001W>fLk00=W>`8003ioo`008Woo00<007ooOol097oo
00<007ooOol01Goo00<007ooOol01goo00@0005I000J?@H000=jS@04001jdG[AN]450009Dad00`00
FaeK7@0;Fad00`00GcaO?00>Gc`00`00GcaO?00AGc`00`00Hc]S>`0@Hc/00`00Ic]W>`02Ic/00`00
Oomoo`0nOol0025oo`03001oogoo02Aoo`03001oogoo00Ioo`03001oogoo00Qoo`030001F@0000@J
?@03000f_P0000H000A6oP03001C7E<M00QC7@03001K7E/M00]K7@03001O?5ll00iO?003001O?5ll
015O?003001S>f<k011S>`04001W>`000011Ool0025oo`03001oogoo02=oo`03001oogoo00Moo`03
001oogoo00Uoo`030001F@0000@J?@03000f_SJn008f_P030016oTKn00E6oP03001C7E<M00QC7@03
001K7E/M00]K7@03001O?5ll00iO?003001O?5ll015O?003001S>f<k011S>`03001oogoo045oo`00
8Goo00<007ooOol08Woo00<007ooOol027oo00<007ooOol02Woo00<0005I000011Xm00<003Jn=[h0
0SJn00<004KnA_h01DKn00<005<MDad025<M00<005/MFad02e/M00<005llGc`03Ell00<005llGc`0
4Ull00<006<kHc/03F<k0P00A7oo000QOol00`00Oomoo`0ROol00`00Oomoo`08Ool00`00Oomoo`0;
Ool00`000ET000046Sd00`00=[hf_P02=[h00`00A_i6oP05A_h00`00DaeC7@08Dad00`00FaeK7@0;
Fad00`00GcaO?00=Gc`00`00GcaO?00BGc`00`00Hc]S>`0;Hc/00`00Oomoo`14Ool0025oo`03001o
ogoo025oo`03001oogoo00Uoo`03001oogoo00aoo`030001F@0000@J?@03000f_SJn008f_P030016
oTKn00A6oP03Ool005<M00UC7@03001K7E/M00]K7@03001O?5ll00eO?003001O?5ll015O?003001S
>f<k00US>`8004Moo`008Goo00<007ooOol087oo00<007ooOol02Woo00<007ooOol03Goo00<0005I
000011Xm00<003Jn=[h00SJn00<004KnA_h01DKn00<005<MDad025<M00<005/MFad02e/M00<005ll
Gc`03Ell00<005llGc`04Ell00<006<kHc/01f<k00<007ooOol0Agoo000QOol00`00Oomoo`0OOol0
0`00Oomoo`0;Ool00`00Oomoo`0>Ool00`000ET000046Sd00`00=[hf_P02=[h00`00A_i6oP05A_h0
0`00DaeC7@08Dad00`00FaeK7@0;Fad00`00GcaO?00=Gc`00`00GcaO?00AGc`00`00Hc]S>`04Hc/2
001:Ool0025oo`03001oogoo01ioo`03001oogoo00aoo`03001oogoo00moo`030001F@0000@J?@03
000f_SJn008f_P030016oTKn00E6oP03001C7E<M00QC7@03001K7E/M00YK7@03001O?5ll00iO?003
001O?5ll015O?003001S>f<k009S>`03001oogoo04Yoo`008Goo00<007ooOol07Woo00<007ooOol0
37oo00<007ooOol047oo00<0005I000011Xm00<003Jn=[h00SJn00<004KnA_h00dKn00=oodKn0000
2U<M00<005/MFad02U/M00<005llGc`03Ull00<005llGc`04Ell00@006<k000004eoo`008Goo00<0
07ooOol07Goo00<007ooOol03Goo00<007ooOol04Goo00<0005I000011Xm00<003Jn=[h00SJn00<0
04KnA_h00dKn00=oodKn00002U<M00<005/MFad02U/M00<005llGc`03Ull00<005llGc`04Ell00<0
07ooOol0CGoo000POol00`00Oomoo`0MOol00`00Oomoo`0>Ool00`00Oomoo`0BOol300046Sd00`00
=[hf_P02=[h00`00A_i6oP03A_h00gooA_h0000:Dad00`00FaeK7@0:Fad00`00GcaO?00>Gc`00`00
GcaO?00>Gc`2001@Ool0021oo`03001oogoo01aoo`03001oogoo00moo`03001oogoo01Aoo`8000@J
?@03000f_SJn008f_P030016oTKn00A6oPd000aK7@03001O?5ll00iO?003001O?5ll00]O?080059o
o`0087oo00<007ooOol06goo00<007ooOol047oo00<007ooOol05Goo0P0011Xm00<003Jn=[h00SJn
00@004KnA_i6oP<000DT0080009@aP<000eK7@03001O?5ll00eO?003001O?5ll00YO?003001oogoo
059oo`0087oo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol05Woo0`000aXm00<003Jn=[h0
0SJn1@000b@00`001U360`0035/M00<005llGc`03Ell00<005llGc`01ell0P00EGoo000POol00`00
Oomoo`0JOol00`00Oomoo`0AOol00`00Oomoo`0GOol00`000ET000036Sd00`00=[hf_P09000;D<H3
000;Fad00`00GcaO?00=Gc`00`00GcaO?005Gc`00`00Oomoo`1EOol0021oo`03001oogoo01Uoo`03
001oogoo019oo`03001oogoo01Qoo`030001F@0000<J?@H00090c0040019;P000007D<H8000:Fad0
0`00GcaO?00=Gc`00`00GcaO?002Gc`2001HOol0021oo`03001oogoo01Qoo`03001oogoo01=oo`03
001oogoo01Uoo`040001F@006Sd400001CB;0010c43<000014T^1`001F7>00<0078:00000P002E/M
00<005llGc`03Ell00@005ll000005Yoo`0087oo00<007ooOol05goo00<007ooOol04goo00<007oo
Ool06goo00<0005I00000P000cB;00@0043<@<`000=9;P<000YQcP04001b2W8:LPX30008Fad00`00
GcaO?00<Gc`2001LOol0021oo`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo01aoo`<00007
<8`003B;=8/0043<00000TT^0P000Te`00<0067>HLh02F7>00<0078:LPX00W8:0P0025/M00<005ll
Gc`02Ell0P00GWoo000POol00`00Oomoo`0FOol00`00Oomoo`0DOol00`00Oomoo`0LOol20002<8`0
0`00=8/dR`020002BBh00`00CG1=L003CG000`00HLiQcP08HLh00`00LPYb2P03LPX00`00FaeK7@07
Fad00`00GcaO?006Gc`2001POol001moo`03001oogoo01Ioo`03001oogoo01Eoo`03001oogoo01]o
o`8000@`S0<00003BBh0000000I=L003001QcV7>00QQcP03001b2W8:00Ab2P03001K7E/M00MK7@03
001O?5ll00=O?080069oo`007goo00<007ooOol05Goo00<007ooOol05Woo00<007ooOol06Woo1@00
0S2<10000de`2000267>00<0078:LPX0178:00<005/MFad025/M00<005llGc`00P00I7oo000OOol0
0`00Oomoo`0DOol00`00Oomoo`0GOol00`00Oomoo`0JOol20003<:h90005DK400`00HS=R<`060003
HLh00`00LPYb2P03LPX00`00FaeK7@08Fad3001VOol001moo`03001oogoo01=oo`03001oogoo01Qo
o`03001oogoo01Uoo`8000@`[PL000MA/@03001R<f8c00IR<`@000Ib2P03001K7E/M00EK7@8006Uo
o`007goo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol06Goo0P000S2^0P0000<dl@000000
0P000Tfc0`000e6a00<0068cHS<02V8c0`00178:00<005/MFad00U/M0`00Jgoo000OOol00`00Oomo
o`0BOol00`00Oomoo`0IOol00`00Oomoo`0HOol200000c2^00000002=?401P00?E800000BK<000A=
/`800003DK40068c00YR<`04001b/g:cL[<20002LPX200000e/M0000001^Ool001moo`03001oogoo
015oo`03001oogoo01Yoo`03001oogoo01Qoo`<000<dl@03000mDSeB00800099/`03001=/dfc00==
/`8000]R<`03001b/g:c00=b/`800003LPX00000071oo`007goo00<007ooOol047oo00<007ooOol0
6goo00<007ooOol067oo0P0013Ca00D003eB0015T`000099/`03001=/dfc00==/`04001NE@000009
HS<00`00L[=b/`05L[<2001aOol001moo`03001oogoo00moo`03001oogoo01aoo`03001oogoo01Mo
o`<000<dl@06000mDSeB0015T`000dVc00D004fcCK==/`0000ANE@8000IR<`03001b/g:c00Mb/`80
071oo`007goo00<007ooOol03Woo00<007ooOol07Goo00<007ooOol05goo00H0000?00l003Ca0003
?E801000AI=5T`000dVc00@004fcCK<000INE@03001R<f8c00=R<`03001b/g:c00Ib/`03001oL@00
071oo`007Woo00<007ooOol03goo00<007ooOol07Goo00<007ooOol05goo00<0000?00l00P000ceB
00D004FCAI=5T`0000=9/`03001=/`0000QNE@8000=R<`03001b/g:c00Ib/`03001oL@00071oo`00
7Woo00<007ooOol03Woo00<007ooOol07Woo00<007ooOol05Woo00D0000?00l03`0000@mDP050015
TdFCAI<00004BK<00`00GUENE@09GUD30009L[<00`00Og40001`Ool001ioo`03001oogoo00eoo`03
001oogoo01moo`03001oogoo01Ioo`0400003`0?00l20003?E801@00AI=5TdFC00000TVc0P0000=F
E`00GUD02eiE00<007:cL[<01g:c00@007maOg4006moo`007Woo00<007ooOol037oo00<007ooOol0
87oo00<007ooOol05Woo00H0000?00l03`00;EH30004AI<30004EUL00`00GUENE@08GUD00`00J_P0
0007L[<01@00Og5oLGma0000Kgoo000NOol00`00Oomoo`0;Ool00`00Oomoo`0QOol00`00Oomoo`0F
Ool0100000l03`0012eF1P001eIG00<005iEGUD01UiE00@006[hJ_QZn08000Eb/`05001oLGmaOg40
001_Ool001ioo`03001oogoo00Yoo`03001oogoo029oo`03001oogoo01Moo`0300003`0000@]EP03
001664HH00966003001FEeIG00IFE`03001NEEiE00ENE@03001Zn6[h00=Zn003001b/g:c009b/`05
001oLGmaOg40001_Ool001ioo`03001oogoo00Yoo`03001oogoo025oo`03001oogoo01Qoo`030000
3`0000@]EP03001664HH00=66003001FEeIG00EFE`03001NEEiE00ANE@03001Zn6[h00EZn005001b
/g:cL[<00002Og400`00Oomoo`1^Ool001ioo`03001oogoo00Uoo`03001oogoo029oo`03001oogoo
01Ioo`<0000300l002eF00<]EP03001664HH00=66003001FEeIG00IFE`03001NEEiE009NE@03001Z
n6[h00MZn0<000=oL@03001oogoo06ioo`007Woo00<007ooOol027oo00<007ooOol08goo00<007oo
Ool047oo1P000Ull0P001BeF00<004HHAQP00dHH00<005IGEUL01eIG00@005iEGUD000aZn005001o
LGmaOg40001`Ool001ioo`03001oogoo00Moo`03001oogoo02Aoo`03001oogoo00aoo`@000UO?003
000]EReF00<]EP03001664HH00A66003001FEeIG00MFE`03001NE@0000]Zn003001g^P00009oL@03
001oogoo06ioo`007Goo00<007ooOol01goo00<007ooOol09Goo00<007ooOol01goo1@003Ell00<0
02eF;EH00beF00<004HHAQP014HH00<005IGEUL025IG00<006[hJ_P02F[h00@007NjMkX0009oL@03
001oogoo06ioo`007Goo00<007ooOol01goo00<007ooOol09Goo00<007ooOol00goo10004Ull0P00
12eF00<004HHAQP01DHH00<005IGEUL01EIG0P0000=Jf`00J_P02F[h00@007NjMkYg^P80075oo`00
7Goo00<007ooOol01Woo00<007ooOol09Woo1P005ell0P000beF00<004HHAQP01DHH00<005IGEUL0
0eIG0P0015[K00<006[hJ_P01V[h00<007NjMkX00WNj0P00LGoo000MOol00`00Oomoo`05Ool00`00
Oomoo`0TOol4000LGc`01P000CT00000;EH000M66004001FEeIGEUL20007F]/00`00J_QZn004J_P0
0`00MkYg^P04MkX00`00Oomoo`1_Ool001eoo`03001oogoo00Aoo`03001oogoo021oo`D0025O?003
0001>@4i008000Q660<000YJf`03001Zn6[h009Zn003001g^WNj00Ag^P03001oogoo071oo`007Goo
00<007ooOol00goo00<007ooOol07Goo10009Ull00@0004i0CT1>@X000eJf`05001Zn6[hJ_P00005
MkX00`00Oomoo`1aOol001eoo`03001oogoo00=oo`03001oogoo01Qoo`8002iO?0050001>@4i0CT0
0008@Y`00`00F]]Jf`0;F]/00`00J_P00005MkX00`00Oomoo`1bOol001eoo`03001oogoo009oo`03
001oogoo01Eoo`@0031O?0050001>@4i0CT00008@Y`00`00F]]Jf`0<F]/00`00MkYg^P04MkX00`00
Oomoo`1bOol001eoo`05001oogooOol0000COol5000eGc`200020CT00`00@Ya2W006@Y`00`00F]]J
f`09F]/200000enn001g^P03MkX00`00Oomoo`1cOol001eoo`04001oogoo000@Ool4000lGc`00`00
0CT00008@Y`00`00F]]Jf`07F]/20004Gkh200000gNj001oo`1eOol001]oo`80009oo`03001oogoo
00Yoo`D003mO?005001oo`000CT00008@Y`00`00F]]Jf`04F]/20008Gkh00`00Oomoo`1eOol001]o
o`800003Ool007oo00Qoo`@004AO?003001oogoo008000U2W004001Jfe[KF]/20008Gkh2001hOol0
01Yoo`D000Aoo`D004MO?003001oogoo00=oo`D000A2W004001Jf`000008Gkh2001jOol001Yoo`T0
04]O?003001oogoo00Ioo`8000038]h0000000D000MO_P8007aoo`006Goo2000C5ll00<007ooOol0
2Goo0P001R;N0`000Unn0P00OWoo000IOol:0019Gc`00`00Oomoo`0<Ool;0020Ool001Yoo`X004MO
?003001oogoo09Qoo`0077oo2@00AEll00<007ooOol0VGoo000MOol:0012Gc`00`00Oomoo`2JOol0
01ioo`X0041O?003001oogoo09]oo`0087oo2P00?Ull00<007ooOol0Vgoo000QOol:000lGc`00`00
Oomoo`2LOol0029oo`X003YO?003001oogoo09eoo`0097oo2P00=ell00<007ooOol0WWoo000UOol:
000eGc`00`00Oomoo`2OOol002Moo`T003=O?003001oogoo0:1oo`00:7oo2P00<5ll00<007ooOol0
XGoo000YOol:000^Gc`00`00Oomoo`2ROol002]oo`T002aO?003001oogoo0:=oo`00;7oo2P00:Ull
00<007ooOol0Xgoo000]Ool:000XGc`00`00Oomoo`2TOol002moo`X002EO?003001oogoo0:Eoo`00
<7oo2P008ell00<007ooOol0YWoo000aOol:000QGc`00`00Oomoo`2WOol003=oo`X001iO?003001o
ogoo0:Qoo`00=7oo2P0075ll00<007ooOol0ZGoo000fOol9000JGc`00`00Oomoo`2ZOol003Moo`X0
01QO?003001oogoo0:Yoo`00>7oo2P005Ull00<007ooOol0Zgoo000jOol9000DGc`00`00Oomoo`2/
Ool003]oo`X0015O?003001oogoo0:eoo`00?7oo2P003ell00<007ooOol0[Woo000nOol:000<Gc`0
0`00Oomoo`2_Ool003moo`X000YO?003001oogoo0;1oo`00@7oo2P0025ll00<007ooOol0/Goo0012
Ool:0005Gc`00`00Oomoo`2bOol004=oo`X000AO?003001oogoo0;9oo`00AGoo2@000Ull00<007oo
Ool0/goo0016Ool:002fOol004Moo`X00;Eoo`00BGoo2000]Goo001:Ool6002fOol004]oo`D00;Io
o`00CGoo0P00]goo001>Ool00`00Oomoo`2eOol00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Mo
o`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003o
Ool7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Mo
o`00ogoo1goo003oOol7Ool00?moo`Moo`00\
\>"],
  ImageRangeCache->{{{0, 261}, {286, 0}} -> {0.0315312, -0.0259655, 
  0.00358063, 0.00358063}}]
}, Open  ]],

Cell[TextData["Cam Profile"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The cam profile used for this mechanism is defined in terms of \
trigonometric functions of the symbols ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The cam profile expression may contain user-defined parameters that are \
defined at run time, but all of the functional dependence on the controlling \
parameters, ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", must be present when the cam profile is processed with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Thus, it is not possible to leave the cam profile defined as simply a \
three element list of symbols, such as {",
  StyleBox["xcam, ycam, zcam",
    FontSlant->"Italic"],
  "}, and then define ",
  StyleBox["xcam",
    FontSlant->"Italic"],
  ", ",
  StyleBox["ycam",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["zcam",
    FontSlant->"Italic"],
  " as functions of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time. \n\nThe cam surface is the same as the one developed and \
plotted in the last subsection. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here are the parametric expressions defining the locus of the cam surface."],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(camsurf
       = {If[\[Pi]/2 < alpha < 3\ \[Pi]/2, 1, 1 + Cos[alpha]]\ Cos[alpha], 
        beta, Sin[alpha]}; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData["Bodies "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Three bodies are used for the cam-follower model. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(cam = 2; \)\), 
    \(\(follower = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"Four points are required on the ground (body 1).\nP1 and P2 are the two ends \
of the rotational axis of the cam at local coordinates {0, 0, 0} and {0, 2, \
0}.\nP3 and P4 are the two ends of the rotational axis of the follower at \
local coordinates {-2, 0, 2} and {-2, 2, 2}."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three points are required on the cam (body 2).\nP1 and P2 are the two ends \
of the rotational axis of the cam at local coordinates {0, 0, 0} and {0, 2, \
0}.\nP3 is the locus point of the cam that was previously defined and named ",
  
  StyleBox["camsurf",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three points are required on the follower (body 3).\nP1 and P2 are the two \
ends of the rotational axis of the follower at local coordinates {0, 0, 0} \
and {0, 2, 0}.\nP3 is the center of the spherical cam follower at {2 , 1, \
0}."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here are all of the bodies in the cam model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0238095 0.47619 [
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0238095 0.5 0.5 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.033745 1.07005 0.0267512 1.07005 [
[ 0 0 0 0 ]
[ 1 1.09373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.09373 L
0 1.09373 L
closepath
clip
newpath
p
P
p
.002 w
.47414 .77516 m .50656 .80432 L .49577 .82293 L p
.747 .573 .66 r
F P
s
P
p
.002 w
.50656 .80432 m .47414 .77516 L .50405 .75256 L p
.695 .58 .723 r
F P
s
P
p
.002 w
.44711 .75007 m .47414 .77516 L .45529 .80734 L p
.843 .706 .712 r
F P
s
P
p
.002 w
.49577 .82293 m .45529 .80734 L .47414 .77516 L p
.747 .573 .66 r
F P
s
P
p
.002 w
.45529 .80734 m .49577 .82293 L .49434 .84232 L p
.765 .52 .563 r
F P
s
P
p
.002 w
.42501 .78746 m .45529 .80734 L .45244 .84098 L p
.89 .638 .55 r
F P
s
P
p
.002 w
.45529 .80734 m .42501 .78746 L .44711 .75007 L p
.843 .706 .712 r
F P
s
P
p
.002 w
.49434 .84232 m .45244 .84098 L .45529 .80734 L p
.765 .52 .563 r
F P
s
P
p
.002 w
.45244 .84098 m .42139 .82652 L .42501 .78746 L p
.89 .638 .55 r
F P
s
P
p
.002 w
.4129 .76823 m .42501 .78746 L .42139 .82652 L p
.997 .777 .429 r
F P
s
P
p
.002 w
.42139 .82652 m .40962 .80235 L .4129 .76823 L p
.997 .777 .429 r
F P
s
P
p
.002 w
.10745 .8537 m .49585 .7917 L .29552 .99438 L closepath p
.713 .794 .915 r
F P
s
P
p
.025 w
.10745 .8537 m
.29552 .99438 L
s
P
p
.002 w
.50405 .75256 m .52385 .7913 L .50656 .80432 L p
.695 .58 .723 r
F P
s
P
p
.002 w
.50656 .80432 m .49577 .82293 L .53645 .83042 L closepath p
.634 .433 .592 r
F P
s
P
p
.002 w
.52385 .7913 m .50656 .80432 L .53645 .83042 L closepath p
.614 .436 .618 r
F P
s
P
p
.002 w
.48192 .72371 m .50405 .75256 L .47414 .77516 L p
.759 .716 .812 r
F P
s
P
p
.002 w
.47414 .77516 m .44711 .75007 L .48192 .72371 L p
.759 .716 .812 r
F P
s
P
p
.002 w
.53746 .74533 m .54314 .78729 L .52385 .7913 L p
.607 .542 .755 r
F P
s
P
p
.002 w
.52385 .7913 m .50405 .75256 L .53746 .74533 L p
.607 .542 .755 r
F P
s
P
p
.002 w
.54314 .78729 m .52385 .7913 L .53645 .83042 L closepath p
.577 .415 .625 r
F P
s
P
p
.002 w
.52071 .71506 m .53746 .74533 L .50405 .75256 L p
.619 .673 .879 r
F P
s
P
p
.002 w
.50405 .75256 m .48192 .72371 L .52071 .71506 L p
.619 .673 .879 r
F P
s
P
p
.002 w
.49577 .82293 m .49434 .84232 L .53645 .83042 L closepath p
.636 .406 .553 r
F P
s
P
p
.002 w
.56578 .75561 m .5594 .79341 L .54314 .78729 L p
.465 .437 .743 r
F P
s
P
p
.002 w
.54314 .78729 m .53746 .74533 L .56578 .75561 L p
.465 .437 .743 r
F P
s
P
p
.002 w
.5594 .79341 m .54314 .78729 L .53645 .83042 L closepath p
.529 .371 .611 r
F P
s
P
p
.002 w
.45244 .84098 m .49434 .84232 L .50276 .85737 L p
.732 .394 .409 r
F P
s
P
p
.002 w
.49434 .84232 m .50276 .85737 L .53645 .83042 L closepath p
.615 .357 .504 r
F P
s
P
p
.002 w
.55361 .72672 m .56578 .75561 L .53746 .74533 L p
.317 .502 .881 r
F P
s
P
p
.002 w
.53746 .74533 m .52071 .71506 L .55361 .72672 L p
.317 .502 .881 r
F P
s
P
p
.002 w
.50276 .85737 m .51893 .86394 L .53645 .83042 L closepath p
.57 .291 .453 r
F P
s
P
p
.002 w
.56824 .8082 m .5594 .79341 L .53645 .83042 L closepath p
.476 .307 .573 r
F P
s
P
p
.002 w
.56714 .82779 m .56824 .8082 L .53645 .83042 L closepath p
.432 .237 .514 r
F P
s
P
p
.002 w
.55626 .84685 m .56714 .82779 L .53645 .83042 L closepath p
.42 .186 .452 r
F P
s
P
p
.002 w
.53856 .86012 m .55626 .84685 L .53645 .83042 L closepath p
.449 .181 .414 r
F P
s
P
p
.002 w
.51893 .86394 m .53856 .86012 L .53645 .83042 L closepath p
.508 .223 .417 r
F P
s
P
p
.002 w
.43238 .73544 m .44711 .75007 L .42501 .78746 L p
.945 .888 .745 r
F P
s
P
p
.002 w
.46296 .71224 m .48192 .72371 L .44711 .75007 L p
.812 .903 .905 r
F P
s
P
p
.002 w
.44711 .75007 m .43238 .73544 L .46296 .71224 L p
.812 .903 .905 r
F P
s
P
p
.002 w
.58135 .78113 m .56824 .8082 L .5594 .79341 L p
.224 .208 .63 r
F P
s
P
p
.002 w
.5594 .79341 m .56578 .75561 L .58135 .78113 L p
.224 .208 .63 r
F P
s
P
p
.002 w
.4969 .70457 m .52071 .71506 L .48192 .72371 L p
.547 .839 .998 r
F P
s
P
p
.002 w
.48192 .72371 m .46296 .71224 L .4969 .70457 L p
.547 .839 .998 r
F P
s
P
p
.002 w
.42139 .82652 m .45244 .84098 L .46673 .86728 L p
.846 .416 .204 r
F P
s
P
p
.002 w
.50276 .85737 m .46673 .86728 L .45244 .84098 L p
.732 .394 .409 r
F P
s
P
p
.002 w
.46673 .86728 m .50276 .85737 L .51893 .86394 L p
.583 .138 .158 r
F P
s
P
p
.002 w
.42501 .78746 m .4129 .76823 L .43238 .73544 L p
.945 .888 .745 r
F P
s
P
p
.002 w
.57952 .81537 m .56714 .82779 L .56824 .8082 L p
0 0 .312 r
F P
s
P
p
.002 w
.56824 .8082 m .58135 .78113 L .57952 .81537 L p
0 0 .312 r
F P
s
P
p
.002 w
.57167 .75623 m .58135 .78113 L .56578 .75561 L p
0 0 .49 r
F P
s
P
p
.002 w
.56578 .75561 m .55361 .72672 L .57167 .75623 L p
0 0 .49 r
F P
s
P
p
.002 w
.52551 .71469 m .55361 .72672 L .52071 .71506 L p
0 .391 .732 r
F P
s
P
p
.002 w
.52071 .71506 m .4969 .70457 L .52551 .71469 L p
0 .391 .732 r
F P
s
P
p
.002 w
.51893 .86394 m .49478 .87893 L .46673 .86728 L p
.583 .138 .158 r
F P
s
P
p
.002 w
.49478 .87893 m .51893 .86394 L .53856 .86012 L p
.221 0 0 r
F P
s
P
p
.002 w
.5604 .84893 m .55626 .84685 L .56714 .82779 L p
0 0 0 r
F P
s
P
p
.002 w
.56714 .82779 m .57952 .81537 L .5604 .84893 L p
0 0 0 r
F P
s
P
p
.002 w
.52921 .8723 m .53856 .86012 L .55626 .84685 L p
0 0 0 r
F P
s
P
p
.002 w
.53856 .86012 m .52921 .8723 L .49478 .87893 L p
.221 0 0 r
F P
s
P
p
.002 w
.43771 .8571 m .46673 .86728 L .49478 .87893 L p
.321 0 0 r
F P
s
P
p
.002 w
.46673 .86728 m .43771 .8571 L .42139 .82652 L p
.846 .416 .204 r
F P
s
P
p
.002 w
.40962 .80235 m .42139 .82652 L .43771 .8571 L p
0 0 .361 r
F P
s
P
p
.002 w
.55626 .84685 m .5604 .84893 L .52921 .8723 L p
0 0 0 r
F P
s
P
p
.002 w
.43432 .73553 m .43238 .73544 L .4129 .76823 L p
0 0 0 r
F P
s
P
p
.002 w
.45228 .72191 m .46296 .71224 L .43238 .73544 L p
0 0 0 r
F P
s
P
p
.002 w
.43238 .73544 m .43432 .73553 L .45228 .72191 L p
0 0 0 r
F P
s
P
p
.002 w
.47212 .71745 m .4969 .70457 L .46296 .71224 L p
.108 0 0 r
F P
s
P
p
.002 w
.46296 .71224 m .45228 .72191 L .47212 .71745 L p
.108 0 0 r
F P
s
P
p
.002 w
.4229 .75476 m .4129 .76823 L .40962 .80235 L p
0 0 .213 r
F P
s
P
p
.002 w
.4129 .76823 m .4229 .75476 L .43432 .73553 L p
0 0 0 r
F P
s
P
p
.002 w
.56943 .79609 m .57952 .81537 L .58135 .78113 L p
.982 .761 .353 r
F P
s
P
p
.002 w
.58135 .78113 m .57167 .75623 L .56943 .79609 L p
.982 .761 .353 r
F P
s
P
p
.002 w
.54102 .7404 m .57167 .75623 L .55361 .72672 L p
.834 .375 .12 r
F P
s
P
p
.002 w
.55361 .72672 m .52551 .71469 L .54102 .7404 L p
.834 .375 .12 r
F P
s
P
p
.002 w
.48866 .72343 m .52551 .71469 L .4969 .70457 L p
.548 .072 .076 r
F P
s
P
p
.002 w
.4969 .70457 m .47212 .71745 L .48866 .72343 L p
.548 .072 .076 r
F P
s
P
p
.002 w
.49478 .87893 m .47023 .87063 L .43771 .8571 L p
.321 0 0 r
F P
s
P
p
.002 w
.47023 .87063 m .49478 .87893 L .52921 .8723 L p
.492 .84 .996 r
F P
s
P
p
.002 w
.42379 .82888 m .43771 .8571 L .47023 .87063 L p
.253 .477 .881 r
F P
s
P
p
.002 w
.43771 .8571 m .42379 .82888 L .40962 .80235 L p
0 0 .361 r
F P
s
P
p
.002 w
.42103 .77464 m .40962 .80235 L .42379 .82888 L p
.154 .154 .605 r
F P
s
P
p
.002 w
.40962 .80235 m .42103 .77464 L .4229 .75476 L p
0 0 .213 r
F P
s
P
p
.002 w
.54696 .83536 m .5604 .84893 L .57952 .81537 L p
.955 .91 .733 r
F P
s
P
p
.002 w
.57952 .81537 m .56943 .79609 L .54696 .83536 L p
.955 .91 .733 r
F P
s
P
p
.002 w
.51041 .86279 m .52921 .8723 L .5604 .84893 L p
.81 .928 .912 r
F P
s
P
p
.002 w
.52921 .8723 m .51041 .86279 L .47023 .87063 L p
.492 .84 .996 r
F P
s
P
p
.002 w
.5604 .84893 m .54696 .83536 L .51041 .86279 L p
.81 .928 .912 r
F P
s
P
p
.002 w
.4229 .75476 m .45322 .75105 L .43432 .73553 L closepath p
.383 .141 .418 r
F P
s
P
p
.002 w
.43432 .73553 m .45322 .75105 L .45228 .72191 L closepath p
.415 .134 .377 r
F P
s
P
p
.002 w
.53879 .77513 m .56943 .79609 L .57167 .75623 L p
.902 .639 .53 r
F P
s
P
p
.002 w
.57167 .75623 m .54102 .7404 L .53879 .77513 L p
.902 .639 .53 r
F P
s
P
p
.002 w
.49743 .73841 m .54102 .7404 L .52551 .71469 L p
.729 .373 .376 r
F P
s
P
p
.002 w
.52551 .71469 m .48866 .72343 L .49743 .73841 L p
.729 .373 .376 r
F P
s
P
p
.002 w
.45228 .72191 m .45322 .75105 L .47212 .71745 L closepath p
.482 .184 .382 r
F P
s
P
p
.002 w
.42103 .77464 m .45322 .75105 L .4229 .75476 L closepath p
.4 .199 .489 r
F P
s
P
p
.002 w
.47212 .71745 m .45322 .75105 L .48866 .72343 L closepath p
.554 .262 .426 r
F P
s
P
p
.002 w
.47023 .87063 m .4521 .84043 L .42379 .82888 L p
.253 .477 .881 r
F P
s
P
p
.002 w
.4521 .84043 m .47023 .87063 L .51041 .86279 L p
.607 .678 .892 r
F P
s
P
p
.002 w
.42935 .7899 m .42379 .82888 L .4521 .84043 L p
.439 .421 .742 r
F P
s
P
p
.002 w
.42379 .82888 m .42935 .7899 L .42103 .77464 L p
.154 .154 .605 r
F P
s
P
p
.002 w
.42935 .7899 m .45322 .75105 L .42103 .77464 L closepath p
.451 .28 .557 r
F P
s
P
p
.002 w
.51902 .80935 m .54696 .83536 L .56943 .79609 L p
.852 .715 .711 r
F P
s
P
p
.002 w
.56943 .79609 m .53879 .77513 L .51902 .80935 L p
.852 .715 .711 r
F P
s
P
p
.002 w
.48866 .72343 m .45322 .75105 L .49743 .73841 L closepath p
.605 .337 .484 r
F P
s
P
p
.002 w
.49592 .75849 m .53879 .77513 L .54102 .7404 L p
.769 .514 .55 r
F P
s
P
p
.002 w
.54102 .7404 m .49743 .73841 L .49592 .75849 L p
.769 .514 .55 r
F P
s
P
p
.002 w
.4871 .83337 m .51041 .86279 L .54696 .83536 L p
.762 .726 .819 r
F P
s
P
p
.002 w
.51041 .86279 m .4871 .83337 L .4521 .84043 L p
.607 .678 .892 r
F P
s
P
p
.002 w
.44579 .79636 m .45322 .75105 L .42935 .7899 L closepath p
.512 .353 .601 r
F P
s
P
p
.002 w
.4521 .84043 m .44579 .79636 L .42935 .7899 L p
.439 .421 .742 r
F P
s
P
p
.002 w
.54696 .83536 m .51902 .80935 L .4871 .83337 L p
.762 .726 .819 r
F P
s
P
p
.002 w
.49743 .73841 m .45322 .75105 L .49592 .75849 L closepath p
.629 .392 .54 r
F P
s
P
p
.002 w
.49592 .75849 m .45322 .75105 L .4844 .77821 L closepath p
.628 .421 .583 r
F P
s
P
p
.002 w
.4844 .77821 m .45322 .75105 L .46598 .79211 L closepath p
.606 .425 .61 r
F P
s
P
p
.002 w
.46598 .79211 m .45322 .75105 L .44579 .79636 L closepath p
.566 .402 .618 r
F P
s
P
p
.002 w
.44579 .79636 m .4521 .84043 L .4871 .83337 L p
.599 .539 .758 r
F P
s
P
p
.002 w
.4871 .83337 m .46598 .79211 L .44579 .79636 L p
.599 .539 .758 r
F P
s
P
p
.002 w
.4844 .77821 m .51902 .80935 L .53879 .77513 L p
.749 .573 .657 r
F P
s
P
p
.002 w
.53879 .77513 m .49592 .75849 L .4844 .77821 L p
.749 .573 .657 r
F P
s
P
p
.002 w
.46598 .79211 m .4871 .83337 L .51902 .80935 L p
.694 .58 .724 r
F P
s
P
p
.002 w
.51902 .80935 m .4844 .77821 L .46598 .79211 L p
.694 .58 .724 r
F P
s
P
p
P
p
[(P1)] .10745 .8537 0 2 Mshowa
[(P2)] .29552 .99438 0 -2 Mshowa
[(P3)] .49585 .7917 -5 0 Mshowa
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.0238095 0.97619 0.5 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.5 0.5 0.97619 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.033745 1.07005 0.0267512 1.07005 [
[ 0 0 0 0 ]
[ 1 1.09373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.09373 L
0 1.09373 L
closepath
clip
newpath
p
P
p
.004 w
.16285 .32403 m
.32221 .48769 L
s
P
p
.004 w
.32221 .48769 m
.84211 .30914 L
s
P
p
.004 w
.29552 .99438 m
.32221 .48769 L
s
P
p
.004 w
.44379 .44594 m
.57576 .64305 L
s
P
p
.004 w
.2912 .27484 m
.44379 .44594 L
s
P
p
.004 w
.70336 .35679 m
.57576 .64305 L
s
P
p
.004 w
.5668 .16922 m
.70336 .35679 L
s
P
p
.004 w
.16285 .32403 m
.10745 .8537 L
s
P
p
.004 w
.715 .11243 m
.16285 .32403 L
s
P
p
.004 w
.84211 .30914 m
.715 .11243 L
s
P
p
.004 w
.41969 .47274 m
.2912 .27484 L
s
P
p
.004 w
.57576 .64305 m
.29552 .99438 L
s
P
p
.004 w
.41969 .47274 m
.5668 .16922 L
s
P
p
.004 w
.10745 .8537 m
.41969 .47274 L
s
P
p
P
p
[(P1)] .41969 .47274 -1 -2 Mshowa
[(P2)] .57576 .64305 -1 -2 Mshowa
[(P3)] .10745 .8537 0 -1.6 Mshowa
[(P4)] .29552 .99438 0 -1.6 Mshowa
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.5 0.5 0.97619 0.97619 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.033745 1.07005 0.0267512 1.07005 [
[ 0 0 0 0 ]
[ 1 1.09373 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.09373 L
0 1.09373 L
closepath
clip
newpath
p
P
p
.002 w
.50138 .5198 m .47954 .53727 L .37058 .41833 L p
.789 .77 .836 r
F P
s
P
p
.002 w
.47954 .53727 m .46013 .55742 L .34988 .43966 L p
.825 .772 .803 r
F P
s
P
p
.002 w
.34988 .43966 m .37058 .41833 L .47954 .53727 L p
.825 .772 .803 r
F P
s
P
p
.002 w
.46013 .55742 m .44375 .57965 L .33221 .46303 L p
.857 .771 .765 r
F P
s
P
p
.002 w
.33221 .46303 m .34988 .43966 L .46013 .55742 L p
.857 .771 .765 r
F P
s
P
p
.002 w
.52501 .50554 m .50138 .5198 L .39372 .39967 L p
.748 .763 .865 r
F P
s
P
p
.002 w
.37058 .41833 m .39372 .39967 L .50138 .5198 L p
.789 .77 .836 r
F P
s
P
p
.002 w
.44375 .57965 m .43089 .60331 L .31813 .48777 L p
.887 .764 .72 r
F P
s
P
p
.002 w
.31813 .48777 m .33221 .46303 L .44375 .57965 L p
.887 .764 .72 r
F P
s
P
p
.002 w
.54973 .49494 m .52501 .50554 L .41859 .38423 L p
.699 .751 .892 r
F P
s
P
p
.002 w
.39372 .39967 m .41859 .38423 L .52501 .50554 L p
.748 .763 .865 r
F P
s
P
p
.002 w
.43089 .60331 m .422 .6277 L .3081 .51313 L p
.915 .751 .663 r
F P
s
P
p
.002 w
.3081 .51313 m .31813 .48777 L .43089 .60331 L p
.915 .751 .663 r
F P
s
P
p
.002 w
.5748 .48836 m .54973 .49494 L .44448 .37251 L p
.638 .731 .915 r
F P
s
P
p
.002 w
.41859 .38423 m .44448 .37251 L .54973 .49494 L p
.699 .751 .892 r
F P
s
P
p
.002 w
.422 .6277 m .41739 .65207 L .3025 .53835 L p
.939 .726 .587 r
F P
s
P
p
.002 w
.3025 .53835 m .3081 .51313 L .422 .6277 L p
.939 .726 .587 r
F P
s
P
p
.002 w
.59945 .48606 m .5748 .48836 L .47061 .36489 L p
.558 .699 .935 r
F P
s
P
p
.002 w
.44448 .37251 m .47061 .36489 L .5748 .48836 L p
.638 .731 .915 r
F P
s
P
p
.002 w
.41739 .65207 m .41729 .67565 L .30157 .56264 L p
.955 .682 .479 r
F P
s
P
p
.002 w
.30157 .56264 m .3025 .53835 L .41739 .65207 L p
.955 .682 .479 r
F P
s
P
p
.002 w
.62289 .48818 m .59945 .48606 L .49619 .36167 L p
.443 .645 .943 r
F P
s
P
p
.002 w
.47061 .36489 m .49619 .36167 L .59945 .48606 L p
.558 .699 .935 r
F P
s
P
p
.002 w
.41729 .67565 m .42179 .69768 L .30544 .58521 L p
.947 .599 .315 r
F P
s
P
p
.002 w
.30544 .58521 m .30157 .56264 L .41729 .67565 L p
.947 .599 .315 r
F P
s
P
p
.002 w
.64535 .49505 m .62289 .48818 L .52041 .36303 L p
.271 .549 .925 r
F P
s
P
p
.002 w
.49619 .36167 m .52041 .36303 L .62289 .48818 L p
.443 .645 .943 r
F P
s
P
p
.002 w
.42179 .69768 m .43085 .7174 L .31412 .60527 L p
.876 .441 .058 r
F P
s
P
p
.002 w
.31412 .60527 m .30544 .58521 L .42179 .69768 L p
.876 .441 .058 r
F P
s
P
p
.002 w
.67202 .5084 m .64535 .49505 L .54348 .36931 L p
.087 .431 .873 r
F P
s
P
p
.002 w
.52041 .36303 m .54348 .36931 L .64535 .49505 L p
.271 .549 .925 r
F P
s
P
p
.002 w
.43085 .7174 m .44427 .73408 L .32741 .62209 L p
.665 .163 0 r
F P
s
P
p
.002 w
.32741 .62209 m .31412 .60527 L .43085 .7174 L p
.665 .163 0 r
F P
s
P
p
.002 w
.70254 .52813 m .67202 .5084 L .57075 .38211 L p
0 .327 .809 r
F P
s
P
p
.002 w
.54348 .36931 m .57075 .38211 L .67202 .5084 L p
.087 .431 .873 r
F P
s
P
p
.002 w
.44427 .73408 m .46169 .74709 L .34499 .63499 L p
0 .19 .678 r
F P
s
P
p
.002 w
.34499 .63499 m .32741 .62209 L .44427 .73408 L p
0 .19 .678 r
F P
s
P
p
.002 w
.46169 .74709 m .48357 .75627 L .36734 .64383 L p
.074 .468 .888 r
F P
s
P
p
.002 w
.36734 .64383 m .34499 .63499 L .46169 .74709 L p
.074 .468 .888 r
F P
s
P
p
.002 w
.73464 .55346 m .70254 .52813 L .60186 .40136 L p
0 .221 .731 r
F P
s
P
p
.002 w
.57075 .38211 m .60186 .40136 L .70254 .52813 L p
0 .327 .809 r
F P
s
P
p
.025 w
.41969 .47274 m
.57576 .64305 L
s
P
p
.002 w
.48357 .75627 m .51503 .76364 L .39971 .65051 L p
.275 .593 .948 r
F P
s
P
p
.002 w
.39971 .65051 m .36734 .64383 L .48357 .75627 L p
.275 .593 .948 r
F P
s
P
p
.002 w
.76525 .58317 m .73464 .55346 L .63451 .42636 L p
0 .089 .62 r
F P
s
P
p
.002 w
.60186 .40136 m .63451 .42636 L .73464 .55346 L p
0 .221 .731 r
F P
s
P
p
.002 w
.51503 .76364 m .55564 .769 L .44168 .65484 L p
.371 .646 .962 r
F P
s
P
p
.002 w
.44168 .65484 m .39971 .65051 L .51503 .76364 L p
.371 .646 .962 r
F P
s
P
p
.002 w
.55564 .769 m .60292 .7715 L .49076 .65601 L p
.437 .68 .966 r
F P
s
P
p
.002 w
.49076 .65601 m .44168 .65484 L .55564 .769 L p
.437 .68 .966 r
F P
s
P
p
.002 w
.79081 .61562 m .76525 .58317 L .66555 .45598 L p
0 0 .44 r
F P
s
P
p
.002 w
.63451 .42636 m .66555 .45598 L .76525 .58317 L p
0 .089 .62 r
F P
s
P
p
.002 w
.60292 .7715 m .65342 .7701 L .54341 .65304 L p
.497 .708 .965 r
F P
s
P
p
.002 w
.54341 .65304 m .49076 .65601 L .60292 .7715 L p
.497 .708 .965 r
F P
s
P
p
.002 w
.66555 .45598 m .69131 .48868 L .79081 .61562 L p
0 0 .44 r
F P
s
P
p
.002 w
.8077 .64888 m .79081 .61562 L .69131 .48868 L p
.789 .354 0 r
F P
s
P
p
.002 w
.65342 .7701 m .70298 .76376 L .59531 .64498 L p
.561 .737 .958 r
F P
s
P
p
.002 w
.59531 .64498 m .54341 .65304 L .65342 .7701 L p
.561 .737 .958 r
F P
s
P
p
.002 w
.81286 .68087 m .8077 .64888 L .70803 .52256 L p
.963 .632 .275 r
F P
s
P
p
.002 w
.69131 .48868 m .70803 .52256 L .8077 .64888 L p
.789 .354 0 r
F P
s
P
p
.002 w
.70298 .76376 m .7472 .7517 L .64185 .6311 L p
.638 .768 .942 r
F P
s
P
p
.002 w
.64185 .6311 m .59531 .64498 L .70298 .76376 L p
.638 .768 .942 r
F P
s
P
p
.002 w
.80439 .70962 m .81286 .68087 L .71254 .55555 L p
.96 .79 .628 r
F P
s
P
p
.002 w
.70803 .52256 m .71254 .55555 L .81286 .68087 L p
.963 .632 .275 r
F P
s
P
p
.002 w
.7472 .7517 m .78201 .73355 L .67878 .61119 L p
.734 .8 .905 r
F P
s
P
p
.002 w
.67878 .61119 m .64185 .6311 L .7472 .7517 L p
.734 .8 .905 r
F P
s
P
p
.002 w
.71254 .55555 m .70287 .58564 L .80439 .70962 L p
.96 .79 .628 r
F P
s
P
p
.002 w
.78201 .73355 m .80439 .70962 L .70287 .58564 L p
.851 .821 .819 r
F P
s
P
p
.002 w
.70287 .58564 m .67878 .61119 L .78201 .73355 L p
.851 .821 .819 r
F P
s
P
p
P
p
[(P1)] .41969 .47274 1.6 1.6 Mshowa
[(P2)] .57576 .64305 -1.6 -1.6 Mshowa
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{460, 460},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007<0001c1000`40O003h00OogoocGoo003o003<
0001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomo
o`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo
00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoo
b7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<0
07ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40
005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo
0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool0
0003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8
Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00
Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@00
0Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0
ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`00
00<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQo
o`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001o
ogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001
Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3o
Ooo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo0000
0`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo
0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007oo
Ool0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005o
o`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?mo
olQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003
001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool1
0001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomo
o`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo
00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoo
b7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<0
07ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40
005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo
0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool0
0003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8
Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00
Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@00
0Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0
ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`00
00<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQo
o`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001o
ogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001
Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3o
Ooo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo0000
0`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo
0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007oo
Ool0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005o
o`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?mo
olQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003
001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool1
0001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomo
o`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo
00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoo
b7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<0
07ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40
005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo
0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool0
0003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8
Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00
Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@00
0Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0
ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo07=oo`<00?mooe9oo`40
005oo`0000<007ooOol0L7oo10000TA20`00ogooCgoo0@000Goo00000`00Oomoo`1^Ool40007A482
003oOom=Ool10001Ool00003001oogoo06aoo`D000A4@P@00004GF`00000003oOom;Ool10001Ool0
0003001oogoo06]oo`<00003?:`004D=00@000IMK004001YH`00003oOom9Ool10001Ool00003001o
ogoo06Yoo`80008l[00400153DD=A@d20007GF`01000JF=YHfUS0P00ogooAgoo0@000Goo00000`00
Oomoo`1XOol200001CB<000l[3b/00000TD=00@004e?CDl000MMK005001YHfUSJF<0003oOom7Ool1
0001Ool00003001oogoo06Moo`80008dS004000l[000A@d20002CDl60003GF`00`00JF=YH`02JF<0
0`00Oomoo`3oOom4Ool10001Ool00003001oogoo06Ioo`800004<8d003B<=8`30002CDl200000e6A
001R4@03HQ450003JF<00`00Oomoo`3oOom4Ool10001Ool00003001oogoo06Ioo`80008`S@L000=A
T@03001R4F8A00IR4@<0009YH`03001oogoo0?mood=oo`40005oo`0000<007ooOol0IGoo2`00156A
00<0068AHQ401V8A00<007:@LY000`00ogooAGoo0@000Goo00000`00Oomoo`1UOol20003<<l40002
DK860007HQ400`00LY1bT002LY02003oOom4Ool10001Ool00003001oogoo06Aoo`80008`c`800005
>A400000CK<00004DK800`00GUENE@030004HQ400`00LY1bT003LY000`00Oomoo`3oOom2Ool10001
Ool00003001oogoo06Aoo`@0008i4@800003BI<004fc0080009A/P03001NEEiE00=NE@<00003HQ40
07:@00AbT0800?mood=oo`40005oo`0000<007ooOol0I7oo0P000cTA00D0045c0019T`0000==/`80
00UNE@8000EbT0800?mood=oo`40005oo`0000<007ooOol0I7oo0`0000Li4@00@G=1L`00BI<00004
CK<00`00GUENE@07GUD00`00K]H00004LY000`00O`/0003oOom2Ool10001Ool00003001oogoo029o
o`<0009oo`D003Qoo`05000@T`00>A400002@G<00`00BI<00003CK<00`00FUL00008GUD01000K]I^
eP000g:@00<007l;00000Woo0`000goo0P00ogoo>7oo0@000Goo00000`00Oomoo`0SOol00`00Oomo
o`03Ool00`00Oomoo`0gOol2000249<01000@G=1L`000dVC0`000eYG00<005iEGUD015iE00<006kF
K]H00VkF0P0000AbT000O`/000=oo`03001oogoo00Aoo`03001oogoo0?moocEoo`40005oo`0000<0
07ooOol08goo0`000goo00<007ooOol0=goo0P000Q2C10000TVC0P001UYG0P0015iE00<006kFK]H0
16kF0P0000=o2`00Ool00Woo0`000goo00<007ooOol0ogoo=Woo0@000Goo00000`00Oomoo`0SOol0
1000Oomoo`000Woo00<007ooOol0=goo00D0012C49<@T`00008i]`<00003CSP005YG00MJE`04001N
EEiE0008K]H00`00O`/00003Ool01000Oomoo`000goo00<007ooOol0ogoo=Goo0@000Goo00000`00
Oomoo`0SOol01000Oomoo`000Woo00<007ooOol0=goo00D0012C49<@T`00008i]`03001>>4hh009>
>003001JEeYG00IJE`03001NE@0000M^eP04001k]`000003Ool02000Oomoo`00Ool007oo003oOolg
Ool10001Ool00003001oogoo029oo`@0009oo`8003Aoo`L0000349<003Vg008i]`03001>>4hh009>
>003001JEeYG00MJE`03001^eVkF00I^eP04001k]`000002Ool40003Ool00`00Oomoo`3oOolfOol1
0001Ool00003001oogoo05Qoo`H000IK?@03000@T`0000<i]`03001>>4hh00=>>003001JEeYG00AJ
E`800003H_X006kF00E^eP05001k]g^gNkL0003oOom2Ool10001Ool00003001oogoo055oo`L000aK
?@<000<i]`03001>>4hh00=>>003001JEeYG00=JE`03001RnV;j009RnP03001^eVkF009^eP05001k
]g^gNkL0003oOom3Ool10001Ool00003001oogoo04]oo`H001AK?@8000@i]`03001>>4hh00=>>005
001JEeYGFUL00006H_X01000K]I^eP0017^g00<007ooOol0ogoo@Goo0@000Goo00000`00Oomoo`14
Ool7000JFcd30003>KL00`00CSQ>>003CSP01000FUL0000026;j00<006kF00000g^g00<007ooOol0
ogoo@Woo0@000Goo00000`00Oomoo`0nOol6000QFcd200001B7l000003Vg00000dhh10002f;j00<0
07^gNkL00W^g00<007ooOol0ogoo@Woo0@000Goo00000`00Oomoo`0hOol6000XFcd200028O`50004
C[`00`00H_YRnP07H_X00`00Ikd00002NkL00`00Oomoo`3oOom3Ool10001Ool00003001oogoo02Mo
o`03001oogoo00Moo`L002iK?@8000@Qo003001>_4jl00E>_003001RnV;j00ERnP07001W_FNmIkd0
07^g0000ogooAGoo0@000Goo00000`00Oomoo`0VOol400000goo00000004000fFcd00`008O`Qo002
8O`00`00C[a>_005C[`00`00H_YRnP03H_X20005Ikd00`00Oomoo`3oOom4Ool10001Ool00003001o
ogoo02Eoo`H003aK?@8000@Qo003001>_4jl00E>_005001RnV;jH_X00006Ikd00`00Oomoo`3oOom5
Ool10001Ool00003001oogoo02Eoo`L003]K?@<000<Qo003001>_4jl00I>_003001RnP0000IW_@03
001oogoo0?moodIoo`40005oo`0000<007ooOol09goo1`00>5/m00@007ooOomoo`80008Qo003001>
_4jl00E>_08000EW_@800?moodUoo`40005oo`0000<007ooOol0:7oo1`00=U/m00<007ooOol017oo
0`000djl10000SmO0P000VNm00<007ooOol0ogooBGoo0@000Goo00000`00Oomoo`0YOol7000dFcd0
0`00Oomoo`07Ool40008?el2003oOom<Ool10001Ool00003001oogoo02]oo`L0035K?@03001oogoo
00aoo`H00?mooe1oo`40005oo`0000<007ooOol0;7oo1`00;e/m00<007ooOol0ogooHgoo0@000Goo
00000`00Oomoo`0]Ool7000]Fcd00`00Oomoo`3oOomTOol10001Ool00003001oogoo02moo`L002YK
?@03001oogoo0?moofEoo`40005oo`0000<007ooOol0<7oo1`00:5/m00<007ooOol0ogooIWoo0@00
0Goo00000`00Oomoo`0aOol7000VFcd00`00Oomoo`3oOomWOol10001Ool00003001oogoo03=oo`L0
02=K?@03001oogoo0?moofQoo`40005oo`0000<007ooOol0=7oo1`008E/m00<007ooOol0ogooJGoo
0@000Goo00000`00Oomoo`0eOol7000OFcd00`00Oomoo`3oOomZOol10001Ool00003001oogoo03Mo
o`H001eK?@03001oogoo0?moof]oo`40005oo`0000<007ooOol0>7oo1`006U/m00<007ooOol0ogoo
K7oo0@000Goo00000`00Oomoo`0iOol7000HFcd00`00Oomoo`3oOom]Ool10001Ool00003001oogoo
03Yoo`L001IK?@03001oogoo0?moofioo`40005oo`0000<007ooOol0?7oo1`004e/m00<007ooOol0
ogooKgoo0@000Goo00000`00Oomoo`0mOol7000AFcd00`00Oomoo`3oOom`Ool10001Ool00003001o
ogoo03ioo`L000mK?@03001oogoo0?moog5oo`40005oo`0000<007ooOol0@7oo1`0035/m00<007oo
Ool0ogooLWoo0@000Goo00000`00Oomoo`11Ool7000:Fcd00`00Oomoo`3oOomcOol10001Ool00003
001oogoo049oo`L000QK?@03001oogoo0?moogAoo`40005oo`0000<007ooOol0A7oo1`001E/m00<0
07ooOol0ogooMGoo0@000Goo00000`00Oomoo`15Ool70003Fcd00`00Oomoo`3oOomfOol10001Ool0
0003001oogoo04Ioo`L00003Fcd007oo0?moogQoo`40005oo`0000<007ooOol0B7oo1`00ogooNGoo
0@000Goo00000`00Oomoo`19Ool6003oOomiOol10001Ool00003001oogoo04Yoo`@00?moogYoo`40
005oo`0000<007ooOol0C7oo00<007ooOol0ogooNGoo0@000Goo00000`00Oomoo`3oOoo8Ool10001
Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3o
Ooo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo0000
0`00Oomoo`3oOoo8Ool10001Ool00003001oogoo04Moo`<000=oo`<00?moogQoo`40005oo`0000<0
07ooOol0B7oo00<007ooOol00Woo00<007ooOol0ogooN7oo0@000Goo00000`00Oomoo`18Ool30003
Ool00`00Oomoo`3oOomgOol10001Ool00003001oogoo04Qoo`04001oogoo0002Ool00`00Oomoo`3o
OomgOol10001Ool00003001oogoo04Qoo`08001oogoo001oo`00Ool00?moogQoo`40005oo`0000<0
07ooOol0Agoo10000goo00<007ooOol0ogooMgoo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool0
0003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8
Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00
Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@00
0Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0
ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`00
00<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQo
o`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001o
ogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001
Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3o
Ooo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0Wgoo0P00ogoo9goo0@00
0Goo00000`00Oomoo`2MOol20002Ool00`00Oomoo`3oOolTOol10001Ool00003001oogoo09Yoo`<0
00Aoo`03001oogoo0?moobAoo`40005oo`0000<007ooOol0V7oo0P0027oo00<007ooOol0ogoo8goo
0@000Goo00000`00Oomoo`2EOol3000:Ool00`00Oomoo`3oOolSOol10001Ool00003001oogoo099o
o`<000ioo`03001oogoo0?moob9oo`40005oo`0000<007ooOol0T7oo0P004Woo00<007ooOol0ogoo
8Goo0@000Goo00000`00Oomoo`2=Ool3000DOol00`00Oomoo`3oOolQOol10001Ool00003001oogoo
08]oo`8001Qoo`03001oogoo0?moob1oo`40005oo`0000<007ooOol0R7oo0`006goo00<007ooOol0
ogoo7goo0@000Goo00000`00Oomoo`26Ool2000NOol00`00Oomoo`3oOolOOol10001Ool00003001o
ogoo08=oo`<0025oo`03001oogoo0?mooaioo`40005oo`0000<007ooOol0PGoo0P0097oo00<007oo
Ool0ogoo7Woo0@000Goo00000`00Oomoo`1nOol300000goo0000000TOol00`00Oomoo`3oOolMOol1
0001Ool00003001oogoo07]oo`<000=oo`03001oo`0002Eoo`03001oogoo0?mooaaoo`40005oo`00
00<007ooOol0NGoo0P001Woo00@007ooOol002Aoo`03001oogoo0?mooaaoo`40005oo`0000<007oo
Ool0MWoo0`001goo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol0ogoo6goo0@000Goo0000
0`00Oomoo`1dOol2000:Ool00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`3oOolJOol10001
Ool00003001oogoo075oo`<000]oo`03001oogoo00Aoo`03001oogoo029oo`03001oogoo0?mooaYo
o`40005oo`0000<007ooOol0Kgoo0P003Woo00<007ooOol01Goo00<007ooOol08Woo00<007ooOol0
ogoo6Goo0@000Goo00000`00Oomoo`1/Ool3000?Ool00`00Oomoo`07Ool00`00Oomoo`0QOol00`00
Oomoo`3oOolIOol10001Ool00003001oogoo06Yoo`80019oo`03001oogoo00Qoo`03001oogoo025o
o`03001oogoo0?mooaQoo`40005oo`0000<007ooOol0Igoo0`004goo00<007ooOol02Goo00<007oo
Ool08Woo00<007ooOol0ogoo5goo0@000Goo00000`00Oomoo`1TOol3000FOol00`00Oomoo`0:Ool0
0`00Oomoo`0QOol00`00Oomoo`3oOolGOol10001Ool00003001oogoo069oo`8001Qoo`03001oogoo
00aoo`03001oogoo025oo`03001oogoo0?mooaIoo`40005oo`0000<007ooOol0Ggoo0`006Woo00<0
07ooOol037oo00<007ooOol08Woo00<007ooOol0ogoo5Goo0@000Goo00000`00Oomoo`1MOol2000L
Ool00`00Oomoo`0>Ool00`00Oomoo`0QOol00`00Oomoo`3oOolEOol10001Ool00003001oogoo05Yo
o`<001ioo`03001oogoo00moo`03001oogoo025oo`03001oogoo0?mooaAoo`40005oo`0000<007oo
Ool0F7oo0P0087oo00<007ooOol04Goo00<007ooOol087oo00<007ooOol0ogoo57oo0@000Goo0000
0`00Oomoo`1EOol3000ROol00`00Oomoo`0AOol00`00Oomoo`0QOol00`00Oomoo`3oOolCOol10001
Ool00003001oogoo059oo`<002Aoo`03001oogoo01=oo`03001oogoo025oo`03001oogoo0?mooa9o
o`40005oo`0000<007ooOol0D7oo0P009goo00<007ooOol057oo00<007ooOol087oo00<007ooOol0
ogoo4Woo0@000Goo00000`00Oomoo`1=Ool3000XOol00`00Oomoo`0FOol00`00Oomoo`0POol00`00
Oomoo`3oOolAOol10001Ool00003001oogoo04]oo`8002]oo`03001oogoo01Ioo`03001oogoo025o
o`03001oogoo0?mooa1oo`40005oo`0000<007ooOol0B7oo0`0000=oo`00Ool0:Goo00<007ooOol0
67oo00<007ooOol087oo00<007ooOol0ogoo47oo0@000Goo00000`00Oomoo`16Ool20004Ool2000Y
Ool00`00Oomoo`0IOol00`00Oomoo`0POol00`00Oomoo`3oOol?Ool10001Ool00003001oogoo04=o
o`<000Moo`8002Moo`03001oogoo01]oo`03001oogoo01moo`03001oogoo0?moo`moo`40005oo`00
00<007ooOol0@Goo0P002goo0P009Woo00<007ooOol06goo00<007ooOol087oo00<007ooOol0ogoo
3Woo0@000Goo00000`00Oomoo`0nOol3000=Ool00`00Ool0000TOol00`00Oomoo`0MOol00`00Oomo
o`0POol00`00Oomoo`3oOol=Ool10001Ool00003001oogoo03]oo`<0015oo`8002Aoo`03001oogoo
01ioo`03001oogoo01moo`03001oogoo0?moo`eoo`40005oo`0000<007ooOol0>Goo0P005Goo0P00
8Woo00<007ooOol07goo00<007ooOol07goo0P00ogoo3Woo0@000Goo00000`00Oomoo`0fOol3000G
Ool00`00Ool0000QOol00`00Oomoo`0POol00`00Oomoo`0KOol3003oOol@Ool10001Ool00003001o
ogoo03Aoo`8001]oo`03001oo`0001moo`03001oogoo029oo`03001oogoo01Moo`<00?mooa=oo`40
005oo`0000<007ooOol0<Woo0P007Woo00<007oo00007Woo00<007ooOol08goo00<007ooOol04goo
0`00ogoo5Woo0@000Goo00000`00Oomoo`0bOol2000NOol01000Oomoo`007Goo00<007ooOol08goo
00<007ooOol047oo0`00ogoo6Goo0@000Goo00000`00Oomoo`0bOol00`00Ool0000NOol01000Oomo
o`006goo00<007ooOol09Goo00<007ooOol037oo0`00ogoo77oo0@000Goo00000`00Oomoo`0bOol0
1000Oomoo`007Woo00@007ooOol001Yoo`03001oogoo02Ioo`03001oogoo00Qoo`<00?mooamoo`40
005oo`0000<007ooOol0<Woo00D007ooOomoo`0001eoo`05001oogooOol0000HOol00`00Oomoo`0X
Ool00`00Oomoo`04Ool3003oOolROol10001Ool00003001oogoo035oo`03001oogoo00=oo`03001o
ogoo01]oo`05001oogooOol0000GOol00`00Oomoo`0XOol01000Oomoogoo0`00ogoo9Goo0@000Goo
00000`00Oomoo`0aOol00`00Oomoo`04Ool00`00Oomoo`0KOol01@00Oomoogoo00005Goo00<007oo
Ool0:Woo0`00ogoo:7oo0@000Goo00000`00Oomoo`0aOol00`00Oomoo`05Ool00`00Oomoo`0JOol0
1@00Oomoogoo00005Goo00<007ooOol09goo1000[Woo2@00LWoo0@000Goo00000`00Oomoo`0aOol0
0`00Oomoo`06Ool00`00Oomoo`0JOol01@00Oomoogoo00004goo00<007ooOol09Goo0`000Woo00<0
07ooOol0Z7oo1@000dKM00<003ZN>Yh00SZN00<R?@000000L7oo0@000Goo00000`00Oomoo`0aOol0
0`00Oomoo`07Ool00`00Oomoo`0JOol01@00Oomoogoo00004Woo00<007ooOol08Woo0`001Goo00<0
07ooOol0YGoo0`000e;m00<004KMA]d00dKM00<003ZN>Yh00SZN0R8m0`00KGoo0@000Goo00000`00
Oomoo`0aOol00`00Oomoo`08Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00
Oomoo`0POol30007Ool00`00Oomoo`2TOol200000e/L001Bo@04D_d00`00A]e6g@03A]d00`00>Yhj
WP02>Yh38Sd00`Vk0000001[Ool10001Ool00003001oogoo035oo`03001oogoo00Uoo`03001oogoo
01Uoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo01eoo`<000Yoo`03001oogoo0:9oo`80
00AK7003001BoE;m00=Bo@030016gDKM0096g@03000jWSZN008jWP04000R?B8m8Sd22K/2001YOol1
0001Ool00003001oogoo035oo`03001oogoo00Yoo`03001oogoo01Uoo`03001oogoo009oo`03001o
ogoo00]oo`03001oogoo01]oo`<000aoo`03001oogoo0:9oo`03001K75/L00EK7003001BoE;m009B
o@030016gDKM00=6g@03000jWSZN008jWP04000R?B8m00032K/2001WOol10001Ool00003001oogoo
035oo`03001oogoo00]oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo
01Qoo`<000moo`03001oogoo0:1oo`800003Ga/005/L00EK7003001BoE;m00=Bo@030016gDKM00=6
g@03000jWSZN008jWP04000R?B8m00032K/00`5I001oo`1UOol10001Ool00003001oogoo035oo`03
001oogoo00aoo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo01Moo`80
015oo`03001oogoo09moo`8000AO6`03001K75/L00AK7003001BoE;m00=Bo@030016gDKM00=6g@03
000jWSZN008jWP04000R?B8m00022K/010000ET00000I7oo0@000Goo00000`00Oomoo`0`Ool00`00
Oomoo`0>Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0DOol3000C
Ool00`00Oomoo`2NOol00`00Ga]O6`05Ga/00`00FaaK7004Fa`00`00D_eBo@03D_d00`00A]e6g@03
A]d00`00>YhjWP02>Yh010008SdR?@000PVk00@0005I0ET006=oo`40005oo`0000<007ooOol0<7oo
00<007ooOol03Woo00<007ooOol067oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol04Woo
0`005Woo00<007ooOol0W7oo0P0000=W6P00Ga/01ElK00<005/LFa`01E/L00<005;mD_d00e;m00<0
04KMA]d00dKM00<003ZN>Yh00SZN00@0028m8Sd00089^`030001F@5I0080065oo`40005oo`0000<0
07ooOol0<7oo00<007ooOol03goo00<007ooOol067oo00<007ooOol017oo00<007ooOol017oo00<0
07ooOol03goo0`0067oo00<007ooOol0Vgoo0P0016LJ00<005lKGa/015lK00<005/LFa`01E/L00<0
05;mD_d00e;m00<004KMA]d00TKM00<003ZN>Yh00SZN00@0028m8Sd000<9^`050001F@5I0?L0001P
Ool10001Ool00003001oogoo031oo`03001oogoo011oo`03001oogoo01Qoo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo00eoo`<001]oo`03001oogoo09Moo`@00003IaX0000000<00003IaX0
05lK00EO6`03001K75/L00EK7003001BoE;m00=Bo@030016gDKM0096g@03000jWSZN008jWP04000R
?B8m00032K/01@000ET0003g0000Ggoo0@000Goo00000`00Oomoo`0`Ool00`00Oomoo`0AOol00`00
Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool3000MOol00`00Oomoo`2I
Ool200001F/I001W6VLJ00000fLJ00<005lKGa/01ElK00<005/LFa`015/L00<005;mD_d015;m00<0
04KMA]d00TKM00<003ZN>Yh00SZN00@0028m8Sd00089^`050001F@5I0000m`02001MOol10001Ool0
0003001oogoo031oo`03001oogoo019oo`03001oogoo01Moo`03001oogoo00Aoo`04001oogoo000:
Ool3000POol00`00Oomoo`2IOol3000016/I001W6P0016LJ00<005lKGa/01ElK00<005/LFa`015/L
00<005;mD_d00e;m00<004KMA]d00dKM00<003ZN>Yh00SZN00@0028m8Sd00089^`040001F@5I0002
0?L00`00Oomoo`1JOol10001Ool00003001oogoo031oo`03001oogoo01=oo`03001oogoo01Moo`03
001oogoo00Aoo`03001oo`0000Moo`<0029oo`03001oogoo09Yoo`05001[6F/I001[6@020005IaX0
0`00Ga]O6`05Ga/00`00FaaK7004Fa`00`00D_eBo@03D_d00`00A]e6g@03A]d00`00>YhjWP02>Yh0
10008SdR?@000PVk00@0005I0ET00080m`03001oogoo05Uoo`40005oo`0000<007ooOol0<7oo00<0
07ooOol057oo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol00goo0`009Goo00<007ooOol0
VGoo0P000V/I00@006/IJaT000IW6P03001O6elK00EO6`03001K75/L00AK7003001BoE;m00=Bo@03
0016gDKM00=6g@03000jWSZN008jWP03000R?@0000<9^`040001F@5I00020?L00`00Oomoo`1HOol1
0001Ool00003001oogoo031oo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo00Aoo`800004
Ool00000000XOol00`00Oomoo`2HOol50002JaT30006IaX00`00Ga]O6`05Ga/00`00FaaK7004Fa`0
0`00D_eBo@03D_d00`00A]e6g@02A]d00`00>YhjWP02>Yh010008SdR?@000`Vk00<0005I00000P3g
0P00FGoo0@000Goo00000`00Oomoo`0_Ool00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`02
Ool4000ZOol00`00Oomoo`2HOol00`00KaP00007JaT00`00IaYW6P05IaX00`00Ga]O6`04Ga/00`00
FaaK7005Fa`00`00D_eBo@03D_d00`00A]e6g@02A]d00`00>YhjWP02>Yh010008SdR?@000PVk00@0
005I0ET00080m`8005Qoo`40005oo`0000<007ooOol0;goo00<007ooOol067oo00<007ooOol05Goo
00<007ooOol00`000goo00<007ooOol09goo00<007ooOol0Ugoo00D006lHKaQ_600000M[6@03001W
6VLJ00EW6P03001O6elK00AO6`03001K75/L00AK7003001BoE;m00ABo@030016gDKM0096g@03000j
WSZN008jWP04000R?B8m00022K/010000ET1F@000P3g0P00Egoo0@000Goo00000`00Oomoo`0_Ool0
0`00Oomoo`0IOol00`00Oomoo`0DOol300000goo001oo`03Ool00`00Oomoo`0VOol00`00Oomoo`2H
Ool00`00KaQ_6002KaP00`00JaU[6@05JaT00`00IaYW6P05IaX00`00Ga]O6`04Ga/00`00FaaK7004
Fa`00`00D_eBo@04D_d00`00A]e6g@02A]d00`00>YhjWP02>Yh010008SdR?@000PVk00@0005I0ET0
0080m`8005Ioo`40005oo`0000<007ooOol0;goo00<007ooOol06Woo00<007ooOol047oo0`000Woo
00<007oo00001Goo00<007ooOol09Goo00<007ooOol0Ugoo00<006lHKaP016lH00<006/IJaT01F/I
00@006LJ000000=W6P03001O6elK00EO6`03001K75/L00AK7003001BoE;m00ABo@030016gDKM0096
g@03000jWSZN008jWP03000R?@0000<9^`040001F@5I00020?L00`1C001oo`1DOol10001Ool00003
001oogoo02moo`03001oogoo01]oo`03001oogoo00aoo`<000Eoo`8000Moo`03001oogoo02=oo`03
001oogoo09Moo`03001c5`0000I_6003001[6F/I00E[6@<000AW6P03001O6elK00EO6`03001K75/L
00AK7003001BoE;m00=Bo@030016gDKM00=6g@03000jWSZN008jWP03000R?@0000<9^`030001F@00
0080m`030000D`0005Aoo`40005oo`0000<007ooOol0;goo00<007ooOol077oo00<007ooOol027oo
0`002Goo00<007ooOol01Goo00<007ooOol08goo00<007ooOol0Ugoo00@007<GLaL000I_6003001[
6F/I00=[6@D000AW6P03001O6elK00EO6`03001K75/L00AK7003001BoE;m00=Bo@030016gDKM0096
g@03000jWSZN008jWP04000R?B8m00022K/010000ET1F@000P3g0P00E7oo0@000Goo00000`00Oomo
o`0_Ool00`00Oomoo`0MOol00`00Oomoo`04Ool3000;Ool00`00Oomoo`07Ool00`00Oomoo`0QOol0
0`00Oomoo`2GOol00`00LaMc5`02LaL00`00KaQ_6004KaP00`00JaU[6@03JaT50004IaX00`00Ga]O
6`05Ga/00`00FaaK7004Fa`00`00D_eBo@03D_d00`00A]e6g@02A]d00`00>YhjWP02>Yh010008SdR
?@000PVk00@0005I0ET00080m`8005=oo`40005oo`0000<007ooOol0;goo00<007ooOol07Woo00<0
07ooOol00`003Goo00<007ooOol02Goo00<007ooOol087oo00<007ooOol0Ugoo00<007<GLaL00g<G
00<006lHKaP016lH00<006/IJaT00V/I1P0016LJ00<005lKGa/01ElK00<005/LFa`00e/L00<005;m
D_d015;m00<004KMA]d00TKM00<003ZN>Yh00SZN00@0028m8Sd00089^`040001F@5I00020?L2001B
Ool10001Ool00003001oogoo02moo`03001oogoo01moo`80011oo`03001oogoo00Uoo`03001oogoo
021oo`03001oogoo09Ioo`03001c5g<G00Ec5`03001_66lH00A_6003001[6F/I009[6@H000AW6P03
001O6elK00AO6`03001K75/L00AK7003001BoE;m00=Bo@`000038Sd000Vk0089^`040001F@5I0002
0?L2001AOol10001Ool00003001oogoo02moo`03001oogoo01moo`03001oogoo00ioo`03001oogoo
00]oo`03001oogoo01ioo`03001oogoo09Moo`8000Ic5`03001_66lH00E_6003001[6F/I009[6@H0
00AW6P03001O6elK00AO6`03001K75/L00AK7003001BoE;m008000aoo`<000<9^`030001F@000080
m`030000D`00051oo`40005oo`0000<007ooOol0;Woo00<007ooOol087oo00<007ooOol03Goo00<0
07ooOol03Goo00<007ooOol07Goo00<007ooOol0UWoo00@007LEMaD000Ic5`03001_66lH00E_6003
001[6F/I009[6@H000AW6P03001O6elK00AO6`03001K75/L00=K70<0011oo`<000052K/0005I0ET0
00020?L3001?Ool10001Ool00003001oogoo02ioo`03001oogoo021oo`03001oogoo00aoo`03001o
ogoo00ioo`03001oogoo01aoo`03001oogoo09Moo`05001g5GLEMaD00006LaL00`00KaQ_6004KaP0
0`00JaU[6@03JaT60003IaX00`00Ga]O6`05Ga/00`00FaaK7002000FOol300020ET00`000?L0m`02
001?Ool10001Ool00003001oogoo02ioo`03001oogoo021oo`03001oogoo00]oo`03001oogoo011o
o`03001oogoo01]oo`03001oogoo09Ioo`03001g5GLE00=g5@03001c5g<G00Ac5`03001_66lH00A_
6003001[6F/I00=[6@H000=W6P03001O6elK00EO6`8001Yoo`800081F@030000m`3g008004ioo`40
005oo`0000<007ooOol0;Woo00<007ooOol087oo00<007ooOol02Woo00<007ooOol04Woo00<007oo
Ool06Goo00<007ooOol0Ugoo00<007LEMaD017LE00<007<GLaL017<G00<006lHKaP016lH00<006/I
JaT00f/I1P000fLJ00<005lKGa/00UlK0P007Woo0P0000@1F@000?L0m`8004eoo`40005oo`0000<0
07ooOol0;Woo00<007ooOol087oo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol06Goo00<0
07ooOol0Ugoo0P001WLE00<007<GLaL017<G00<006lHKaP016lH00<006/IJaT00f/I1P000fLJ00@0
05lK0000029oo`800080m`03001UH00004aoo`40005oo`0000<007ooOol0;Woo00<007ooOol087oo
00<007ooOol02Goo00<007ooOol01Goo0`000Woo1@001Goo00<007ooOol067oo00<007ooOol0Ugoo
00<007[b00001WLE00<007<GLaL017<G00<006lHKaP016lH00<006/IJaT00f/I1@0016LJ00<007oo
Ool08goo0P000P3g00<006EPOol0Bgoo0@000Goo00000`00Oomoo`0^Ool00`00Oomoo`0POol00`00
Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0FOol00`00
Oomoo`2GOol01@00N_9jlW[b00001WLE00<007<GLaL017<G00<006lHKaP016lH00<006/IJaT00f/I
1@000VLJ00<007ooOol09Woo00<0003g00000P00Bgoo0@000Goo00000`00Oomoo`0^Ool00`00Oomo
o`0POol00`00Oomoo`07Ool00`00Oomoo`08Ool30003Ool00`00Oomoo`06Ool00`00Oomoo`0FOol0
0`00Oomoo`2GOol00`00N_9jlP02N_800`00MaEg5@04MaD00`00LaMc5`04LaL00`00KaQ_6004KaP0
0`00JaU[6@03JaT6000ZOol200000gZ80000001:Ool10001Ool00003001oogoo02ioo`03001oogoo
021oo`03001oogoo00Ioo`03001oogoo00Uoo`04001oogoo0002Ool00`00Oomoo`07Ool00`00Oomo
o`0DOol00`00Oomoo`2HOol00`00N_9jlP03N_800`00MaEg5@04MaD00`00LaMc5`04LaL00`00KaQ_
6004KaP00`00JaU[6@02JaT6000[Ool01@00NXP006EP0000BGoo0@000Goo00000`00Oomoo`0]Ool0
0`00Oomoo`0POol00`00Oomoo`07Ool00`00Oomoo`09Ool01000Oomoo`000Woo00<007ooOol027oo
00<007ooOol04goo00<007ooOol0V7oo0P001G[b00<007LEMaD017LE00<007<GLaL017<G00<006lH
KaP016lH00<006/IJaT00V/I1P00:Woo00<007Z8NXP00`00B7oo0@000Goo00000`00Oomoo`0]Ool0
0`00Oomoo`0POol00`00Oomoo`06Ool00`00Oomoo`09Ool40002Ool2000:Ool00`00Oomoo`0BOol0
0`00Oomoo`2IOol00`00NZl00005N_800`00MaEg5@03MaD00`00LaMc5`05LaL00`00KaQ_6004KaP0
1000JaU[6F/I1`00:Goo00@007Z8NXQjR08004Qoo`40005oo`0000<007ooOol0;Goo00<007ooOol0
87oo00<007ooOol01Goo00<007ooOol07Goo00<007ooOol04Goo00<007ooOol0V7oo00D007Z_NZmj
[`0000EjlP03001g5GLE00=g5@03001c5g<G00Ac5`03001_66lH00E_6003001[6@00009oo`H002Qo
o`03001jR7Z8009jR08004Moo`40005oo`0000<007ooOol0;Goo00<007ooOol087oo00<007ooOol0
17oo00<007ooOol07goo00<007ooOol03goo00<007ooOol0VGoo00<007Z_NZl00WZ_00<007[bN_80
0g[b00<007LEMaD00gLE00<007<GLaL017<G00<006lHKaP01FlH00<007ooOol00Woo1P009goo00<0
07Z8NXP00WZ800<006EP0000AWoo0@000Goo00000`00Oomoo`0]Ool00`00Oomoo`0POol00`00Oomo
o`03Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`2IOol00`00NZmj[`03NZl00`00N_9j
lP03N_800`00MaEg5@03MaD00`00LaMc5`04LaL00`00KaQ_6003KaP00`00Oomoo`04Ool6000VOol2
0004NXP00`00IF000015Ool10001Ool00003001oogoo02eoo`03001oogoo021oo`03001oogoo009o
o`03001oogoo029oo`03001oogoo00ioo`03001oogoo09Uoo`8000Ej[`03001jlW[b00=jlP03001g
5GLE00=g5@03001c5g<G00Ac5`03001_66lH009_6003001oogoo00Eoo`H002Eoo`03001k=00000Aj
R0<004Aoo`40005oo`0000<007ooOol0;Goo00<007ooOol087oo00<007ooOol00Woo00<007ooOol0
8goo00<007ooOol037oo00<007ooOol0VWoo00<007YZ00001GZ_00<007[bN_800g[b00<007LEMaD0
0gLE00<007<GLaL017<G00@006lHKaP000Uoo`H002=oo`04001k=7/d0005NXP20014Ool10001Ool0
0003001oogoo02eoo`03001oogoo021oo`05001oogooOol0000VOol00`00Oomoo`0<Ool00`00Oomo
o`2KOol00`00NVX00005NZl00`00N_9jlP03N_800`00MaEg5@03MaD00`00LaMc5`04LaL00`00KaP0
000:Ool6000ROol01@00NcAk=7/d000017Z800<006EP0000@goo0@000Goo00000`00Oomoo`0]Ool0
0`00Oomoo`0POol01000Oomoo`00:7oo00<007ooOol02Woo00<007ooOol0W7oo00@007YZNVX000Ej
[`03001jlW[b00=jlP03001g5GLE00=g5@03001c5g<G00Ac5`03001oogoo00Yoo`D0029oo`03001k
=7/d009k=003001jR7Z8009jR003001UH000049oo`40005oo`0000<007ooOol0;Goo00<007ooOol0
87oo00<007oo0000:Woo00<007ooOol02Goo00<007ooOol0W7oo00D007YZNVYjJP0000Ej[`03001j
lW[b00=jlP03001g5GLE00=g5@03001c5g<G009c5`03001oogoo00aoo`D0025oo`03001k=7/d00=k
=003001jR7Z8009jR0<0045oo`40005oo`0000<007ooOol0;7oo00<007ooOol08Goo0P00:goo00<0
07ooOol027oo00<007ooOol0WGoo0P000gYZ00<007Z_NZl00gZ_00<007[bN_800g[b00<007LEMaD0
0gLE00@007<GLaL0011oo`D001moo`03001_FP0000Ek=003001jR7Z8009jR080045oo`40005oo`00
00<007ooOol0;7oo00<007ooOol08Goo0P00;7oo00<007ooOol01goo00<007ooOol0WWoo0P000gYZ
00<007Z_NZl00gZ_00<007[bN_800g[b00<007LEMaD00gLE00<007<G000047oo1P007Goo00D006mJ
KeY_FP0000Ak=003001jR7Z8009jR003001UH000041oo`40005oo`0000<007ooOol0;7oo00<007oo
Ool08Goo00<007ooOol0;7oo00<007ooOol01Woo00<007ooOol0WWoo00<0077100000gYZ00<007Z_
NZl00gZ_00<007[bN_800g[b00<007LEMaD00gLE00<007ooOol047oo1P006goo00<006mJKeX00VmJ
00<007/dNc@00g/d00<007Z8NXP00WZ800<006EP0000?goo0@000Goo00000`00Oomoo`0/Ool00`00
Oomoo`0POol2000^Ool00`00Oomoo`05Ool00`00Oomoo`2POol00`00LL400003NVX00`00NZmj[`03
NZl00`00N_9jlP03N_800`00MaEg5@02MaD00`00Oomoo`0AOol6000IOol00`00KeY_FP04KeX00`00
NcAk=003Nc@00`00NXQjR002NXP3000nOol10001Ool00003001oogoo02aoo`03001oogoo01moo`03
001oo`0002moo`03001oogoo00Aoo`03001oogoo0:5oo`03001a`@0000=jJP03001j[gZ_00=j[`03
001jlW[b00=jlP05001g5GLEMaD0000DOol6000GOol00`00KeY_FP06KeX00`00NcAk=003Nc@00`00
NXQjR002NXP2000nOol10001Ool00003001oogoo02aoo`03001oogoo01ioo`04001oogoo000`Ool0
0`00Oomoo`02Ool00`00Oomoo`2SOol00`00LL400003NVX00`00NZmj[`03NZl00`00N_9jlP03N_80
0`00MaD0000FOol6000DOol200000ell001_FP07KeX00`00NcAk=003Nc@01`00NXQjR7Z8001UH000
03eoo`40005oo`0000<007ooOol0;7oo00<007ooOol07Woo00@007ooOol0031oo`03001oogoo009o
o`03001oogoo0:Aoo`03001a`@0000=jJP8000Aj[`03001jlW[b00=jlP8001Moo`H0015oo`8000AO
?003001_FVmJ00I_FP03001k=7/d009k=003001jR7Z8009jR08003eoo`40005oo`0000<007ooOol0
;7oo00<007ooOol07Goo00D007ooOomoo`00035oo`04001oogoo002XOol00`00LL400004NVX00`00
NZmj[`02NZl00`00N_9jlP03N_800`00Oomoo`0FOol6000>Ool20006Gc`00`00KeY_FP06KeX00`00
NcAk=003Nc@00`00NXQjR002NXP2000lOol10001Ool00003001oogoo02aoo`03001oogoo01aoo`03
001oogoo009oo`03001oogoo031oo`03001oo`000:Uoo`03001a`@0000AjJP03001j[gZ_009j[`03
001jlW[b009jlP03001oogoo01Moo`H000Yoo`<000UO?003001_FVmJ00I_FP03001k=7/d00=k=003
001jR7Z8009jR003001oogoo03Yoo`40005oo`0000<007ooOol0;7oo00<007ooOol06goo00<007oo
Ool00goo00<007ooOol0<7oo0P00Zgoo0`0017YZ00<007Z_NZl00WZ_00D007[bN_9jlP0001Yoo`D0
00Moo`<0009C7P03001O?5ll00QO?003001_FVmJ00I_FP03001k=7/d00=k=004001jR7Z8NXP2000k
Ool10001Ool00003001oogoo02]oo`03001oogoo01]oo`03001oogoo00=oo`03001oogoo039oo`03
001oogoo0:Yoo`030009g00000<00003NVX007Z_00=j[`03001jlP0001aoo`D000=oo`<000IC7P03
001O?5ll00QO?003001_FVmJ00I_FP03001k=7/d00=k=005001jR7Z8NXP0000kOol10001Ool00003
001oogoo02]oo`03001oogoo01Yoo`03001oogoo00Aoo`03001oogoo035oo`03001oogoo0:aoo`04
0009g0WL2M`40004NZl2000MOol7000:Dah00`00GcaO?008Gc`00`00KeY_FP06KeX00`00NcAk=002
Nc@00`00NXQjR002NXP00`00Oomoo`0hOol10001Ool00003001oogoo02]oo`03001oogoo01Yoo`03
001oogoo00Aoo`03001oogoo031oo`03001oogoo0:ioo`050009g0WL2M`000028Uh6000COol;0005
A_h00`00DaiC7P08Dah00`00GcaO?009Gc`00`00KeY_FP05KeX00`00NcAk=003Nc@01@00NXQjR7Z8
0000>Woo0@000Goo00000`00Oomoo`0[Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0`
Ool00`00Oomoo`2_Ool01@002M`9g0WL00000b9N00<002jN;Yh050001SkN00<004KnA_h024Kn00<0
05<NDah025<N00<005llGc`025ll00<006mJKeX01VmJ00<007/dNc@00g/d00@007Z8NXP003Yoo`40
005oo`0000<007ooOol0:goo00<007ooOol067oo00<007ooOol01Woo00<007ooOol0;goo00<007oo
Ool0/Goo00D000WL2M`9g00000<RGP03000^WRjN00@^WP03000f_SJn00Lf_P03000ngSkN00TngP03
0016oTKn00Q6oP03001C7U<N00QC7P03001O?5ll00QO?003001_FVmJ00I_FP03001k=7/d00=k=003
001jR00003Yoo`40005oo`0000<007ooOol0:goo00<007ooOol05goo00<007ooOol01goo00<007oo
Ool0;Woo00<007ooOol0/goo00D000WL2M`9g00000<RGP03000^WRjN00@^WP03000f_SJn00Lf_P03
000ngSkN00TngP030016oTKn00Q6oP03001C7U<N00QC7P03001O?5ll00QO?003001_FVmJ00I_FP03
001k=7/d00=k=003001jR00003Uoo`40005oo`0000<007ooOol0:goo00<007ooOol05Woo00<007oo
Ool027oo00<007ooOol0;Goo00<007ooOol0]Goo00D000WL2M`9g00000<RGP03000^WRjN00@^WP03
000f_SJn00Lf_P03000ngSkN00TngP030016oTKn00Q6oP03001C7U<N00QC7P03001O?5ll00QO?003
001_FVmJ00I_FP03001k=7/d009k=003001jR00003Uoo`40005oo`0000<007ooOol0:goo00<007oo
Ool05Woo00<007ooOol027oo00<007ooOol0;7oo00<007ooOol0]goo00D000WL2M`9g00000<RGP03
000^WRjN00@^WP03000f_SJn00Lf_P03000ngSkN00TngP030016oTKn00Q6oP03001C7U<N00QC7P03
001O?5ll00QO?003001_FVmJ00E_FP03001k=7/d00=k=08003Uoo`40005oo`0000<007ooOol0:goo
00<007ooOol05Goo00<007ooOol02Goo00<007ooOol0;7oo00<007ooOol0^7oo00D000WL2M`9g000
00<RGP03000^WRjN00@^WP03000f_SJn00Lf_P03000ngSkN00PngP040016oTKnA_h30003A_h3000:
Dah00`00GcaO?008Gc`00`00KeY_FP05KeX00`00NcAk=003Nc@00`00Oomoo`0gOol10001Ool00003
001oogoo02Yoo`03001oogoo01Eoo`03001oogoo00Yoo`03001oogoo02]oo`03001oogoo0;Yoo`05
0009g0WL2M`000038Uh00`00;Yh^WP04;Yh00`00=[hf_P07=[h00`00?]hngP08?]h01@00A_i6oTKn
000014Kn00@004KnA_h000YC7P03001O?5ll00MO?003001_FVmJ00I_FP03001k=7/d009k=003001o
ogoo03Moo`40005oo`0000<007ooOol0:Woo00<007ooOol057oo00<007ooOol02goo00<007ooOol0
:Woo00<007ooOol01Goo0`000goo0`00[Woo0P000PWL00D0029N8UhRGP0000H^WP03000f_SJn00Lf
_P03000ngSkN00PngP030016oTKn00<000=6oP040016oTKn0009Dah00`00GcaO?008Gc`00`00KeY_
FP06KeX01@00NcAk=7/d0000>Goo0@000Goo00000`00Oomoo`0ZOol00`00Oomoo`0COol00`00Oomo
o`0<Ool00`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`2`Ool010002M`9
g0000b9N00<002jN;Yh012jN00<003Jn=[h01cJn00<003kN?]h023kN00<004Kn00000TKn00@004Kn
A_h000=6oP03001C7U<N00MC7P03001O?5ll00QO?003001_FVmJ00I_FP03001k=00003Yoo`40005o
o`0000<007ooOol0:Woo00<007ooOol04Woo00<007ooOol03Goo00<007ooOol0:7oo00<007ooOol0
27oo0`000goo00<007ooOol0/7oo00@000WL2M`000<RGP03000^WRjN00@^WP03000f_SJn00Lf_P03
000ngSkN00PngP800096oP050016oP00A_h00003A_h00`00DaiC7P07Dah00`00GcaO?008Gc`00`00
KeY_FP05KeX00`00Nc@0000jOol10001Ool00003001oogoo02Yoo`03001oogoo019oo`03001oogoo
00eoo`03001oogoo02Qoo`03001oogoo00Qoo`04001oogoo0002Ool00`00Oomoo`2aOol010002M`9
g0000b9N0P001BjN00<003Jn=[h01cJn00<003kN?]h01ckN10000dKn00<004KnA_h00TKn00<005<N
Dah025<N00<005llGc`025ll00<006mJKeX01FmJ0P00>Woo0@000Goo00000`00Oomoo`0ZOol00`00
Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0WOol00`00Oomoo`09Ool02000Oomoo`00Ool007oo
002cOol010002M`9g000129N00<002jN;Yh00bjN0P0023Jn00<003kN?]h023kN00<004KnA_h024Kn
00<005<NDah025<N00<005llGc`025ll00<006mJKeX01FmJ00<007ooOol0>7oo0@000Goo00000`00
Oomoo`0ZOol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`0VOol00`00Oomoo`09Ool40003
Ool00`00Oomoo`2cOol010002M`9g000129N00<002jN;Yh012jN00<003Jn=[h01SJn00<003kN?]h0
23kN00<004KnA_h024Kn00<005<NDah025<N00<005llGc`01ell00<006mJKeX016mJ00<007ooOol0
>Goo0@000Goo00000`00Oomoo`0ZOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0UOol0
0`00Oomoo`38Ool010002M`9g000129N00<002jN;Yh012jN00<003Jn=[h01SJn00<003kN?]h023kN
00<004KnA_h024Kn00<005<NDah025<N00<005llGc`01ell00@006mJKeY_FP8003aoo`40005oo`00
00<007ooOol0:Woo00<007ooOol03Woo00<007ooOol04Goo00<007ooOol097oo00<007ooOol0bWoo
00@000WL2M`000@RGP03000^WRjN00@^WP03000f_SJn00Hf_P03000ngSkN00PngP030016oTKn00Q6
oP03001C7U<N00QC7P03001O?5ll00MO?003001_FP0003ioo`40005oo`0000<007ooOol0:Woo00<0
07ooOol03Woo00<007ooOol04Goo00<007ooOol097oo00<007ooOol0bgoo00@000WL2M`000@RGP03
000^WRjN00@^WP03000f_SJn00Hf_P03000ngSkN00PngP030016oTKn00Q6oP03001C7U<N00MC7P03
001O?5ll00QO?003001oogoo03eoo`40005oo`0000<007ooOol0:Goo00<007ooOol03Woo00<007oo
Ool04Woo00<007ooOol08goo00<007ooOol0cGoo00@000WL2M`000@RGP03000^WRjN00@^WP03000f
_SJn00Hf_P03000ngSkN00PngP030016oTKn00Q6oP03001C7U<N00MC7P03001O?5ll00EO?080041o
o`40005oo`0000<007ooOol0:Goo00<007ooOol03Goo00<007ooOol04Woo00<007ooOol08goo00<0
07ooOol0cgoo00@000WL2M`000@RGP03000^WRjN00@^WP03000f_SJn00Hf_P03000ngSkN00LngP03
0016oTKn00U6oP03001C7U<N00MC7P03001O?5ll009O?080049oo`40005oo`0000<007ooOol0:Goo
00<007ooOol037oo00<007ooOol04goo00<007ooOol08Woo00<007ooOol0dGoo0P0000<9g0008Uh0
0b9N00<002jN;Yh012jN00<003Jn=[h01SJn00<003kN?]h01ckN00<004KnA_h02DKn00<005<NDah0
1e<N00@005ll000004Aoo`40005oo`0000<007ooOol0:Goo00<007ooOol02goo00<007ooOol057oo
00<007ooOol08Goo00<007ooOol0e7oo0`00129N00<002jN;Yh012jN00<003Jn=[h01SJn00<003kN
?]h01ckN00<004KnA_h02DKn00<005<NDah01U<N0P00AWoo0@000Goo00000`00Oomoo`0YOol00`00
Oomoo`0:Ool00`00Oomoo`0EOol00`00Oomoo`0QOol00`00Oomoo`3FOol400028Uh00`00;Yh^WP04
;Yh00`00=[hf_P06=[h00`00?]hngP07?]h00`00A_i6oP09A_h01000DaiC7U<N1000B7oo0@000Goo
00000`00Oomoo`0YOol00`00Oomoo`0:Ool00`00Oomoo`0EOol00`00Oomoo`0POol00`00Oomoo`3K
Ool70003;Yh00`00=[hf_P06=[h00`00?]hngP07?]h00`00A_i6oP07A_h5001<Ool10001Ool00003
001oogoo02Uoo`03001oogoo00Uoo`03001oogoo01Ioo`03001oogoo01moo`03001oogoo0>=oo`T0
00@f_P03000ngSkN00LngP040016oTKnA_h5001AOol10001Ool00003001oogoo02Uoo`03001oogoo
00Qoo`03001oogoo01Moo`03001oogoo01ioo`03001oogoo0>eooa8005Ioo`40005oo`0000<007oo
Ool0:Goo00<007ooOol01goo00<007ooOol067oo00<007ooOol07Goo00<007ooOol0ogooEgoo0@00
0Goo00000`00Oomoo`0XOol00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`0MOol00`00Oomo
o`3oOomGOol10001Ool00003001oogoo02Qoo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo
01aoo`03001oogoo0?mooeQoo`40005oo`0000<007ooOol0:7oo00<007ooOol01Woo00<007ooOol0
6Woo00<007ooOol06goo00<007ooOol0ogooFGoo0@000Goo00000`00Oomoo`0XOol00`00Oomoo`05
Ool00`00Oomoo`0KOol00`00Oomoo`0JOol00`00Oomoo`3oOomJOol10001Ool00003001oogoo02Qo
o`03001oogoo00Aoo`03001oogoo01aoo`03001oogoo01Uoo`03001oogoo0?mooe]oo`40005oo`00
00<007ooOol0:7oo00<007ooOol00goo00<007ooOol07Goo00<007ooOol06Goo00<007ooOol0ogoo
Fgoo0@000Goo00000`00Oomoo`0XOol00`00Oomoo`03Ool00`00Oomoo`0MOol00`00Oomoo`0HOol0
0`00Oomoo`3oOomLOol10001Ool00003001oogoo02Qoo`03001oogoo009oo`03001oogoo01ioo`03
001oogoo01Moo`03001oogoo0?mooeeoo`40005oo`0000<007ooOol0:7oo00D007ooOomoo`00025o
o`03001oogoo01Ioo`03001oogoo0?mooeioo`40005oo`0000<007ooOol0:7oo00@007ooOol0029o
o`03001oogoo01Eoo`03001oogoo0?mooemoo`40005oo`0000<007ooOol09goo00@007ooOol002=o
o`03001oogoo01Eoo`03001oogoo0?mooemoo`40005oo`0000<007ooOol09goo00<007oo000097oo
00<007ooOol057oo00<007ooOol0ogooH7oo0@000Goo00000`00Oomoo`0WOol00`00Ool0000SOol0
0`00Oomoo`0DOol00`00Oomoo`3oOomQOol10001Ool00003001oogoo02Moo`8002Aoo`03001oogoo
01=oo`03001oogoo0?moof9oo`40005oo`0000<007ooOol09goo00<007ooOol08goo00<007ooOol0
4Woo00<007ooOol0ogooHgoo0@000Goo00000`00Oomoo`1=Ool00`00Oomoo`0BOol00`00Oomoo`3o
OomSOol10001Ool00003001oogoo04eoo`03001oogoo015oo`03001oogoo0?moofAoo`40005oo`00
00<007ooOol0CGoo00<007ooOol047oo00<007ooOol0ogooIGoo0@000Goo00000`00Oomoo`1=Ool0
0`00Oomoo`0?Ool00`00Oomoo`3oOomVOol10001Ool00003001oogoo04eoo`03001oogoo00ioo`03
001oogoo0?moofMoo`40005oo`0000<007ooOol0CGoo00<007ooOol03Woo00<007ooOol0ogooIgoo
0@000Goo00000`00Oomoo`1=Ool00`00Oomoo`0=Ool00`00Oomoo`3oOomXOol10001Ool00003001o
ogoo029oo`<000=oo`8002=oo`03001oogoo00aoo`03001oogoo0?moofUoo`40005oo`0000<007oo
Ool08goo00<007ooOol017oo00<007ooOol087oo00<007ooOol02goo00<007ooOol0ogooJWoo0@00
0Goo00000`00Oomoo`0SOol30003Ool00`00Oomoo`0QOol00`00Oomoo`0:Ool00`00Oomoo`3oOom[
Ool10001Ool00003001oogoo02=oo`04001oogoo0003Ool00`00Oomoo`0POol00`00Oomoo`0:Ool0
0`00Oomoo`3oOom[Ool10001Ool00003001oogoo02=oo`08001oogoo001oo`00Ool0029oo`03001o
ogoo00Uoo`03001oogoo0?moofaoo`40005oo`0000<007ooOol08Woo10000goo00<007ooOol08Goo
00<007ooOol027oo00<007ooOol0ogooKGoo0@000Goo00000`00Oomoo`1=Ool00`00Oomoo`07Ool0
0`00Oomoo`3oOom^Ool10001Ool00003001oogoo04eoo`03001oogoo00Ioo`03001oogoo0?moofmo
o`40005oo`0000<007ooOol0CGoo00<007ooOol01Woo00<007ooOol0ogooKgoo0@000Goo00000`00
Oomoo`1=Ool00`00Oomoo`05Ool00`00Oomoo`3oOom`Ool10001Ool00003001oogoo04aoo`03001o
ogoo00Eoo`03001oogoo0?moog5oo`40005oo`0000<007ooOol0C7oo00<007ooOol017oo00<007oo
Ool0ogooLWoo0@000Goo00000`00Oomoo`1<Ool00`00Oomoo`03Ool00`00Oomoo`3oOomcOol10001
Ool00003001oogoo04aoo`03001oogoo00=oo`03001oogoo0?moog=oo`40005oo`0000<007ooOol0
C7oo00<007ooOol00Woo00<007ooOol0ogooM7oo0@000Goo00000`00Oomoo`1<Ool01@00Oomoogoo
0000ogooMgoo0@000Goo00000`00Oomoo`1<Ool01000Oomoo`00ogooN7oo0@000Goo00000`00Oomo
o`1<Ool00`00Ool0003oOomiOol10001Ool00003001oogoo04aoo`03001oo`000?moogUoo`40005o
o`0000<007ooOol0C7oo0P00ogooNWoo0@000Goo00000`00Oomoo`1<Ool00`00Oomoo`3oOomiOol1
0001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomo
o`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo
00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0Agoo
0`0017oo0`00ogooMgoo0@000Goo00000`00Oomoo`18Ool00`00Oomoo`04Ool00`00Oomoo`3oOomf
Ool10001Ool00003001oogoo04Qoo`<0009oo`@00?moogMoo`40005oo`0000<007ooOol0B7oo00P0
07ooOol007oo001oo`00ogooN7oo0@000Goo00000`00Oomoo`18Ool01000Oomoo`000Woo0P00ogoo
N7oo0@000Goo00000`00Oomoo`17Ool40004Ool00`00Oomoo`3oOomfOol10001Ool00003001oogoo
0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool0
0003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00Oomoo`3oOoo8
Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@000Goo00000`00
Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0ogoob7oo0@00
0Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`0000<007ooOol0
ogoob7oo0@000Goo00000`00Oomoo`3oOoo8Ool10001Ool00003001oogoo0?moolQoo`40005oo`00
00<007ooOol0ogoob7oo0@000Goo003o003<0001Ool00001\
\>"],
  ImageRangeCache->{{{0, 459}, {459, 0}} -> {-0.0521105, -0.0521105, 
  0.00458436, 0.00458436}, {{11.3125, 229.5}, {447.625, 229.5}} ->
   {-0.0654234, -0.0783086, 0.00468603, 0.00468603}, {{229.5, 447.625}, {
  447.625, 229.5}} -> {-1.12977, -0.438078, 0.0048138, 0.00778889}, {{11.3125,
   229.5}, {229.5, 11.3125}} -> {-0.0652617, -1.10014, 0.00468469, 
  0.00468469}, {{229.5, 447.625}, {229.5, 11.3125}} -> {-1.08726, -1.10014, 
  0.00468469, 0.00468469}}],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used here only to set a nonzero initial guess for the follower. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[
      Body[follower, InitialGuess \[Rule] {{\(-2\), 0, 2}, {1, 0, 0, 0}}]]\)],
   "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Constraints "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three regular constraints and one cam constraint are required to model the \
cam-follower mechanism."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of the cam to be coincident with its \
rotational axis on the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the pivot axis of the follower to be coincident with \
its axis on the ground."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the angular coordinate of the cam. This driving \
constraint specifies the rotation of the cam as a function of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["CamToSphere1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the one remaining degree of freedom. The point \
arguments to ",
  StyleBox["CamToSphere1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are given in the same syntax as would be used with any other ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, except for the requirement that the local coordinates of the \
locuspoint be a function of the symbols, ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that while ",
  StyleBox["CamToSphere1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one degree of freedom in the model, it actually adds three \
equations (one that forces the spherical follower to lie a specified distance \
away from the cam surface, and two more that force the cam surface to be \
tangent at the point of contact) and two unknowns, ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" and ",
    FontFamily->"Times"],
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  "to the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraints for the cam-follower mechanism."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      Revolute5[1, \n\t\tLine[cam, 0, {0, 2, 0}], 
        Line[ground, 0, {0, 2, 0}]], \n\t
      Revolute5[2, Line[follower, 0, {0, 2, 0}], 
        Line[ground, {\(-2\), 0, 2}, {\(-2\), 2, 2}]], \n\t
      ProjectedAngle1[3, \n\t\tVector[cam, {0, 0, 1}], 
        Vector[ground, {0, 0, 1}], Vector[ground, {0, \(-1\), 0}], 
        2.0  \[Pi]\ T], \n\t
      CamToSphere1[4, Point[cam, camsurf], {alpha, 1.5}, {beta, 1}, 
        Point[follower, {2, 1, 0}], 0.5]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The cam-follower mechanism model can now be run in the usual manner. Note \
the presence of the cam parameters, ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", in the solution rule. At these values of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the cam locus point is placed at the point of contact between the cam and \
the follower."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.1] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 0\), ",", 
        \(Eo2 \[Rule] 0.951056516295153464`\), ",", \(Ei2 \[Rule] 0\), ",", 
        \(Ej2 \[Rule] \(-0.309016994374947406`\)\), ",", \(Ek2 \[Rule] 0\), 
        ",", \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 0\), ",", 
        \(Z3 \[Rule] 2.`\), ",", \(Eo3 \[Rule] 0.995552269625996011`\), ",", 
        \(Ei3 \[Rule] 0\), ",", \(Ej3 \[Rule] 0.0942108191373422876`\), ",", 
        \(Ek3 \[Rule] 0\), ",", \(alpha \[Rule] 1.02760315584735795`\), ",", 
        \(beta \[Rule] 1.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the cam-follower mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.09373  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.033745 1.07005 0.0267512 1.07005 [ 
[ 0 0 0 0 ] 
[ 1 1.09373 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 1.09373 L 
0 1.09373 L 
closepath 
clip 
newpath 
p 
P 
p 
.004 w 
.16285 .32403 m 
.32221 .48769 L 
s 
P 
p 
.004 w 
.5668 .16922 m 
.70336 .35679 L 
s 
P 
p 
.004 w 
.715 .11243 m 
.16285 .32403 L 
s 
P 
p 
.002 w 
.50138 .5198 m .47954 .53727 L .37058 .41833 L p 
.789 .77 .836 r 
F P 
s 
P 
p 
.004 w 
.51398 .55077 m 
.57576 .64305 L 
s 
P 
p 
.004 w 
.44379 .44594 m 
.48445 .50667 L 
s 
P 
p 
.004 w 
.49608 .52404 m 
.51398 .55077 L 
s 
P 
p 
.004 w 
.79742 .32449 m 
.84211 .30914 L 
s 
P 
p 
.004 w 
.32221 .48769 m 
.40734 .45845 L 
s 
P 
p 
.004 w 
.41771 .45489 m 
.79742 .32449 L 
s 
P 
p 
.002 w 
.47954 .53727 m .46013 .55742 L .34988 .43966 L p 
.825 .772 .803 r 
F P 
s 
P 
p 
.002 w 
.34988 .43966 m .37058 .41833 L .47954 .53727 L p 
.825 .772 .803 r 
F P 
s 
P 
p 
.002 w 
.46013 .55742 m .44375 .57965 L .33221 .46303 L p 
.857 .771 .765 r 
F P 
s 
P 
p 
.002 w 
.33221 .46303 m .34988 .43966 L .46013 .55742 L p 
.857 .771 .765 r 
F P 
s 
P 
p 
.002 w 
.52501 .50554 m .50138 .5198 L .39372 .39967 L p 
.748 .763 .865 r 
F P 
s 
P 
p 
.002 w 
.37058 .41833 m .39372 .39967 L .50138 .5198 L p 
.789 .77 .836 r 
F P 
s 
P 
p 
.002 w 
.44375 .57965 m .43089 .60331 L .31813 .48777 L p 
.887 .764 .72 r 
F P 
s 
P 
p 
.004 w 
.32206 .49064 m 
.32221 .48769 L 
s 
P 
p 
.002 w 
.31813 .48777 m .33221 .46303 L .44375 .57965 L p 
.887 .764 .72 r 
F P 
s 
P 
p 
.002 w 
.54973 .49494 m .52501 .50554 L .41859 .38423 L p 
.699 .751 .892 r 
F P 
s 
P 
p 
.002 w 
.39372 .39967 m .41859 .38423 L .52501 .50554 L p 
.748 .763 .865 r 
F P 
s 
P 
p 
.004 w 
.2912 .27484 m 
.39939 .39615 L 
s 
P 
p 
.004 w 
.84211 .30914 m 
.715 .11243 L 
s 
P 
p 
.002 w 
.43089 .60331 m .422 .6277 L .3081 .51313 L p 
.915 .751 .663 r 
F P 
s 
P 
p 
.004 w 
.3204 .52216 m 
.322 .49173 L 
s 
P 
p 
.002 w 
.3081 .51313 m .31813 .48777 L .43089 .60331 L p 
.915 .751 .663 r 
F P 
s 
P 
p 
.002 w 
.5748 .48836 m .54973 .49494 L .44448 .37251 L p 
.638 .731 .915 r 
F P 
s 
P 
p 
.002 w 
.41859 .38423 m .44448 .37251 L .54973 .49494 L p 
.699 .751 .892 r 
F P 
s 
P 
p 
.002 w 
.422 .6277 m .41739 .65207 L .3025 .53835 L p 
.939 .726 .587 r 
F P 
s 
P 
p 
.004 w 
.3189 .55061 m 
.32023 .52532 L 
s 
P 
p 
.002 w 
.3025 .53835 m .3081 .51313 L .422 .6277 L p 
.939 .726 .587 r 
F P 
s 
P 
p 
.002 w 
.59945 .48606 m .5748 .48836 L .47061 .36489 L p 
.558 .699 .935 r 
F P 
s 
P 
p 
.004 w 
.57576 .64305 m 
.63531 .50945 L 
s 
P 
p 
.004 w 
.63531 .50945 m 
.70336 .35679 L 
s 
P 
p 
.002 w 
.44448 .37251 m .47061 .36489 L .5748 .48836 L p 
.638 .731 .915 r 
F P 
s 
P 
p 
.002 w 
.41739 .65207 m .41729 .67565 L .30157 .56264 L p 
.955 .682 .479 r 
F P 
s 
P 
p 
.004 w 
.31761 .57503 m 
.3187 .55439 L 
s 
P 
p 
.002 w 
.30157 .56264 m .3025 .53835 L .41739 .65207 L p 
.955 .682 .479 r 
F P 
s 
P 
p 
.002 w 
.62289 .48818 m .59945 .48606 L .49619 .36167 L p 
.443 .645 .943 r 
F P 
s 
P 
p 
.002 w 
.47061 .36489 m .49619 .36167 L .59945 .48606 L p 
.558 .699 .935 r 
F P 
s 
P 
p 
.004 w 
.35927 .37968 m 
.41969 .47274 L 
s 
P 
p 
.004 w 
.2912 .27484 m 
.35927 .37968 L 
s 
P 
p 
.002 w 
.41729 .67565 m .42179 .69768 L .30544 .58521 L p 
.947 .599 .315 r 
F P 
s 
P 
p 
.004 w 
.3166 .59423 m 
.31745 .57815 L 
s 
P 
p 
.002 w 
.30544 .58521 m .30157 .56264 L .41729 .67565 L p 
.947 .599 .315 r 
F P 
s 
P 
p 
.002 w 
.64535 .49505 m .62289 .48818 L .52041 .36303 L p 
.271 .549 .925 r 
F P 
s 
P 
p 
.002 w 
.49619 .36167 m .52041 .36303 L .62289 .48818 L p 
.443 .645 .943 r 
F P 
s 
P 
p 
.004 w 
.40747 .85403 m 
.44055 .81256 L 
s 
P 
p 
.002 w 
.42179 .69768 m .43085 .7174 L .31412 .60527 L p 
.876 .441 .058 r 
F P 
s 
P 
p 
.004 w 
.31594 .60683 m 
.31651 .59591 L 
s 
P 
p 
.002 w 
.31412 .60527 m .30544 .58521 L .42179 .69768 L p 
.876 .441 .058 r 
F P 
s 
P 
p 
.004 w 
.29989 .91141 m 
.31593 .60701 L 
s 
P 
p 
.002 w 
.67202 .5084 m .64535 .49505 L .54348 .36931 L p 
.087 .431 .873 r 
F P 
s 
P 
p 
.002 w 
.52041 .36303 m .54348 .36931 L .64535 .49505 L p 
.271 .549 .925 r 
F P 
s 
P 
p 
.002 w 
.43085 .7174 m .44427 .73408 L .32741 .62209 L p 
.665 .163 0 r 
F P 
s 
P 
p 
.004 w 
.47649 .7675 m 
.57576 .64305 L 
s 
P 
p 
.004 w 
.44055 .81256 m 
.47649 .7675 L 
s 
P 
p 
.002 w 
.32741 .62209 m .31412 .60527 L .43085 .7174 L p 
.665 .163 0 r 
F P 
s 
P 
p 
.002 w 
.70254 .52813 m .67202 .5084 L .57075 .38211 L p 
0 .327 .809 r 
F P 
s 
P 
p 
.002 w 
.54348 .36931 m .57075 .38211 L .67202 .5084 L p 
.087 .431 .873 r 
F P 
s 
P 
p 
.002 w 
.44427 .73408 m .46169 .74709 L .34499 .63499 L p 
0 .19 .678 r 
F P 
s 
P 
p 
.002 w 
.34499 .63499 m .32741 .62209 L .44427 .73408 L p 
0 .19 .678 r 
F P 
s 
P 
p 
.002 w 
.46169 .74709 m .48357 .75627 L .36734 .64383 L p 
.074 .468 .888 r 
F P 
s 
P 
p 
.002 w 
.36734 .64383 m .34499 .63499 L .46169 .74709 L p 
.074 .468 .888 r 
F P 
s 
P 
p 
.002 w 
.73464 .55346 m .70254 .52813 L .60186 .40136 L p 
0 .221 .731 r 
F P 
s 
P 
p 
.002 w 
.57075 .38211 m .60186 .40136 L .70254 .52813 L p 
0 .327 .809 r 
F P 
s 
P 
p 
.025 w 
.41969 .47274 m 
.57576 .64305 L 
s 
P 
p 
.002 w 
.50173 .81061 m .46574 .78604 L .49244 .75917 L p 
.717 .583 .704 r 
F P 
s 
P 
p 
.002 w 
.46574 .78604 m .50173 .81061 L .4941 .83011 L p 
.758 .56 .63 r 
F P 
s 
P 
p 
.002 w 
.4373 .76272 m .46574 .78604 L .45227 .81976 L p 
.864 .69 .664 r 
F P 
s 
P 
p 
.002 w 
.4941 .83011 m .45227 .81976 L .46574 .78604 L p 
.758 .56 .63 r 
F P 
s 
P 
p 
.002 w 
.45227 .81976 m .4941 .83011 L .49549 .84179 L p 
.762 .485 .515 r 
F P 
s 
P 
p 
.002 w 
.49549 .84179 m .49629 .8485 L p 
.48536 .84136 L .762 .485 .515 r 
F P 
s 
P 
p 
.48536 .84136 m .45227 .81976 L .49549 .84179 L .762 .485 .515 r 
F 
P 
p 
.002 w 
.29552 .99438 m .10745 .8537 L .24785 .83129 L p 
.713 .794 .915 r 
F P 
s 
P 
p 
.002 w 
.42139 .80188 m .45227 .81976 L .45444 .84005 L p 
.893 .586 .459 r 
F P 
s 
P 
p 
.002 w 
.24785 .83129 m .38872 .8088 L p 
.42477 .82755 L .713 .794 .915 r 
F P 
s 
P 
p 
.43053 .83904 m .42477 .82755 L .44831 .83979 L .713 .794 .915 r 
F 
P 
p 
.24785 .83129 m .42477 .82755 L .43053 .83904 L .713 .794 .915 r 
F 
P 
p 
.002 w 
.40969 .78084 m .42139 .80188 L .42371 .82544 L p 
.949 .659 .212 r 
F P 
s 
P 
p 
.41896 .81596 m .40969 .78084 L .42371 .82544 L .949 .659 .212 r 
F 
P 
p 
.44435 .83525 m .42139 .80188 L .45444 .84005 L .893 .586 .459 r 
F 
P 
p 
.002 w 
.45227 .81976 m .42139 .80188 L .4373 .76272 L p 
.864 .69 .664 r 
F P 
s 
P 
p 
.002 w 
.49629 .8485 m .45569 .85174 L .45227 .81976 L p 
.762 .485 .515 r 
F P 
s 
P 
p 
.002 w 
.4501 .83798 m .44831 .83979 L p 
.42477 .82755 L .713 .794 .915 r 
F P 
s 
P 
p 
.38872 .8088 m .42371 .82544 L .42477 .82755 L .713 .794 .915 r 
F 
P 
p 
.42371 .82544 m .4501 .83798 L .42477 .82755 L .713 .794 .915 r 
F 
P 
p 
.002 w 
.44831 .83979 m .29552 .99438 L p 
.24785 .83129 L .713 .794 .915 r 
F P 
s 
P 
p 
.002 w 
.45569 .85174 m .42505 .83903 L .42371 .82544 L p 
.893 .586 .459 r 
F P 
s 
P 
p 
.002 w 
.42371 .82544 m .42139 .80188 L p 
.44435 .83525 L .893 .586 .459 r 
F P 
s 
P 
p 
.45569 .85174 m .42371 .82544 L .44435 .83525 L .893 .586 .459 r 
F 
P 
p 
.002 w 
.49585 .7917 m .4501 .83798 L p 
.42371 .82544 L .713 .794 .915 r 
F P 
s 
P 
p 
.002 w 
.41165 .80139 m .40969 .78084 L p 
.41896 .81596 L .949 .659 .212 r 
F P 
s 
P 
p 
.002 w 
.42139 .80188 m .40969 .78084 L .42374 .74655 L p 
.977 .867 .661 r 
F P 
s 
P 
p 
.002 w 
.42103 .76214 m .40969 .78084 L .41165 .80139 L p 
0 0 .387 r 
F P 
s 
P 
p 
.40567 .81685 m .41339 .80486 L .42371 .82544 L .713 .794 .915 r 
F 
P 
p 
.002 w 
.41011 .80538 m .41339 .80486 L p 
.40567 .81685 L .713 .794 .915 r 
F P 
s 
P 
p 
.002 w 
.41339 .80486 m .49585 .7917 L p 
.42371 .82544 L .713 .794 .915 r 
F P 
s 
P 
p 
.002 w 
.42505 .83903 m .41279 .81322 L .41165 .80139 L p 
.949 .659 .212 r 
F P 
s 
P 
p 
.42505 .83903 m .41165 .80139 L .41896 .81596 L .949 .659 .212 r 
F 
P 
p 
.002 w 
.41165 .80139 m .41279 .81322 L p 
.41687 .78789 L 0 0 .387 r 
F P 
s 
P 
p 
.41687 .78789 m .42103 .76214 L .41165 .80139 L 0 0 .387 r 
F 
P 
p 
.002 w 
.38872 .8088 m .41011 .80538 L p 
.40567 .81685 L .713 .794 .915 r 
F P 
s 
P 
p 
.002 w 
.42371 .82544 m .42505 .83903 L p 
.41896 .81596 L .949 .659 .212 r 
F P 
s 
P 
p 
.002 w 
.45444 .84005 m .45569 .85174 L p 
.44435 .83525 L .893 .586 .459 r 
F P 
s 
P 
p 
.004 w 
.10745 .8537 m 
.16285 .32403 L 
s 
P 
p 
.025 w 
.10745 .8537 m 
.29552 .99438 L 
s 
P 
p 
.002 w 
.48357 .75627 m .51503 .76364 L .39971 .65051 L p 
.275 .593 .948 r 
F P 
s 
P 
p 
.002 w 
.39971 .65051 m .36734 .64383 L .48357 .75627 L p 
.275 .593 .948 r 
F P 
s 
P 
p 
.004 w 
.41969 .47274 m 
.48851 .33075 L 
s 
P 
p 
.004 w 
.48851 .33075 m 
.5668 .16922 L 
s 
P 
p 
.002 w 
.76525 .58317 m .73464 .55346 L .63451 .42636 L p 
0 .089 .62 r 
F P 
s 
P 
p 
.002 w 
.60186 .40136 m .63451 .42636 L .73464 .55346 L p 
0 .221 .731 r 
F P 
s 
P 
p 
.002 w 
.51503 .76364 m .55564 .769 L .44168 .65484 L p 
.371 .646 .962 r 
F P 
s 
P 
p 
.002 w 
.44168 .65484 m .39971 .65051 L .51503 .76364 L p 
.371 .646 .962 r 
F P 
s 
P 
p 
.002 w 
.55564 .769 m .60292 .7715 L .49076 .65601 L p 
.437 .68 .966 r 
F P 
s 
P 
p 
.002 w 
.49076 .65601 m .44168 .65484 L .55564 .769 L p 
.437 .68 .966 r 
F P 
s 
P 
p 
.002 w 
.79081 .61562 m .76525 .58317 L .66555 .45598 L p 
0 0 .44 r 
F P 
s 
P 
p 
.002 w 
.63451 .42636 m .66555 .45598 L .76525 .58317 L p 
0 .089 .62 r 
F P 
s 
P 
p 
.002 w 
.60292 .7715 m .65342 .7701 L .54341 .65304 L p 
.497 .708 .965 r 
F P 
s 
P 
p 
.002 w 
.54341 .65304 m .49076 .65601 L .60292 .7715 L p 
.497 .708 .965 r 
F P 
s 
P 
p 
.002 w 
.66555 .45598 m .69131 .48868 L .79081 .61562 L p 
0 0 .44 r 
F P 
s 
P 
p 
.002 w 
.8077 .64888 m .79081 .61562 L .69131 .48868 L p 
.789 .354 0 r 
F P 
s 
P 
p 
.002 w 
.49244 .75917 m .51713 .79509 L .50173 .81061 L p 
.717 .583 .704 r 
F P 
s 
P 
p 
.002 w 
.52556 .74595 m .53627 .78757 L .51713 .79509 L p 
.644 .562 .747 r 
F P 
s 
P 
p 
.002 w 
.51713 .79509 m .49244 .75917 L .52556 .74595 L p 
.644 .562 .747 r 
F P 
s 
P 
p 
.002 w 
.51713 .79509 m .50173 .81061 L .53645 .83042 L closepath p 
.623 .437 .61 r 
F P 
s 
P 
p 
.002 w 
.53627 .78757 m .51713 .79509 L .53645 .83042 L closepath p 
.592 .425 .625 r 
F P 
s 
P 
p 
.002 w 
.46842 .73144 m .49244 .75917 L .46574 .78604 L p 
.794 .717 .78 r 
F P 
s 
P 
p 
.002 w 
.50689 .71587 m .52556 .74595 L .49244 .75917 L p 
.68 .696 .859 r 
F P 
s 
P 
p 
.002 w 
.49244 .75917 m .46842 .73144 L .50689 .71587 L p 
.68 .696 .859 r 
F P 
s 
P 
p 
.002 w 
.50173 .81061 m .4941 .83011 L .53645 .83042 L closepath p 
.637 .426 .58 r 
F P 
s 
P 
p 
.002 w 
.46574 .78604 m .4373 .76272 L .46842 .73144 L p 
.794 .717 .78 r 
F P 
s 
P 
p 
.002 w 
.55669 .74993 m .55419 .79007 L .53627 .78757 L p 
.525 .485 .755 r 
F P 
s 
P 
p 
.002 w 
.53627 .78757 m .52556 .74595 L .55669 .74993 L p 
.525 .485 .755 r 
F P 
s 
P 
p 
.002 w 
.55419 .79007 m .53627 .78757 L .53645 .83042 L closepath p 
.547 .39 .619 r 
F P 
s 
P 
p 
.002 w 
.65342 .7701 m .70298 .76376 L .59531 .64498 L p 
.561 .737 .958 r 
F P 
s 
P 
p 
.002 w 
.59531 .64498 m .54341 .65304 L .65342 .7701 L p 
.561 .737 .958 r 
F P 
s 
P 
p 
.002 w 
.4941 .83011 m .49629 .8485 L .53645 .83042 L closepath p 
.631 .391 .536 r 
F P 
s 
P 
p 
.002 w 
.54304 .72022 m .55669 .74993 L .52556 .74595 L p 
.459 .59 .897 r 
F P 
s 
P 
p 
.002 w 
.52556 .74595 m .50689 .71587 L .54304 .72022 L p 
.459 .59 .897 r 
F P 
s 
P 
p 
.002 w 
.57759 .77051 m .56612 .80207 L .55419 .79007 L p 
.325 .31 .688 r 
F P 
s 
P 
p 
.002 w 
.55419 .79007 m .55669 .74993 L .57759 .77051 L p 
.325 .31 .688 r 
F P 
s 
P 
p 
.002 w 
.56612 .80207 m .55419 .79007 L .53645 .83042 L closepath p 
.495 .332 .589 r 
F P 
s 
P 
p 
.002 w 
.56873 .82049 m .56612 .80207 L .53645 .83042 L closepath p 
.446 .262 .536 r 
F P 
s 
P 
p 
.002 w 
.56118 .8404 m .56873 .82049 L .53645 .83042 L closepath p 
.42 .201 .473 r 
F P 
s 
P 
p 
.002 w 
.54545 .85629 m .56118 .8404 L .53645 .83042 L closepath p 
.434 .177 .423 r 
F P 
s 
P 
p 
.002 w 
.52588 .86378 m .54545 .85629 L .53645 .83042 L closepath p 
.485 .203 .411 r 
F P 
s 
P 
p 
.002 w 
.50788 .86087 m .52588 .86378 L .53645 .83042 L closepath p 
.549 .265 .437 r 
F P 
s 
P 
p 
.002 w 
.49629 .8485 m .50788 .86087 L .53645 .83042 L closepath p 
.601 .335 .485 r 
F P 
s 
P 
p 
.002 w 
.81286 .68087 m .8077 .64888 L .70803 .52256 L p 
.963 .632 .275 r 
F P 
s 
P 
p 
.002 w 
.69131 .48868 m .70803 .52256 L .8077 .64888 L p 
.789 .354 0 r 
F P 
s 
P 
p 
.002 w 
.45111 .71905 m .46842 .73144 L .4373 .76272 L p 
.868 .903 .855 r 
F P 
s 
P 
p 
.002 w 
.48483 .70532 m .50689 .71587 L .46842 .73144 L p 
.671 .879 .976 r 
F P 
s 
P 
p 
.002 w 
.46842 .73144 m .45111 .71905 L .48483 .70532 L p 
.671 .879 .976 r 
F P 
s 
P 
p 
.002 w 
.45569 .85174 m .49629 .8485 L .50788 .86087 L p 
.697 .321 .332 r 
F P 
s 
P 
p 
.002 w 
.42374 .74655 m .4373 .76272 L .42139 .80188 L p 
.977 .867 .661 r 
F P 
s 
P 
p 
.002 w 
.4373 .76272 m .42374 .74655 L .45111 .71905 L p 
.868 .903 .855 r 
F P 
s 
P 
p 
.002 w 
.70298 .76376 m .7472 .7517 L .64185 .6311 L p 
.638 .768 .942 r 
F P 
s 
P 
p 
.002 w 
.64185 .6311 m .59531 .64498 L .70298 .76376 L p 
.638 .768 .942 r 
F P 
s 
P 
p 
.002 w 
.56731 .74391 m .57759 .77051 L .55669 .74993 L p 
0 .193 .723 r 
F P 
s 
P 
p 
.002 w 
.55669 .74993 m .54304 .72022 L .56731 .74391 L p 
0 .193 .723 r 
F P 
s 
P 
p 
.002 w 
.58229 .80258 m .56873 .82049 L .56612 .80207 L p 
.007 0 .454 r 
F P 
s 
P 
p 
.002 w 
.56612 .80207 m .57759 .77051 L .58229 .80258 L p 
.007 0 .454 r 
F P 
s 
P 
p 
.002 w 
.51635 .70903 m .54304 .72022 L .50689 .71587 L p 
.159 .639 .925 r 
F P 
s 
P 
p 
.002 w 
.50689 .71587 m .48483 .70532 L .51635 .70903 L p 
.159 .639 .925 r 
F P 
s 
P 
p 
.002 w 
.47556 .87346 m .50788 .86087 L .52588 .86378 L p 
.48 .001 .041 r 
F P 
s 
P 
p 
.002 w 
.50788 .86087 m .47556 .87346 L .45569 .85174 L p 
.697 .321 .332 r 
F P 
s 
P 
p 
.002 w 
.42505 .83903 m .45569 .85174 L .47556 .87346 L p 
.751 .238 0 r 
F P 
s 
P 
p 
.004 w 
.10745 .8537 m 
.31041 .60607 L 
s 
P 
p 
.004 w 
.31041 .60607 m 
.41969 .47274 L 
s 
P 
p 
.002 w 
.80439 .70962 m .81286 .68087 L .71254 .55555 L p 
.96 .79 .628 r 
F P 
s 
P 
p 
.002 w 
.70803 .52256 m .71254 .55555 L .81286 .68087 L p 
.963 .632 .275 r 
F P 
s 
P 
p 
.002 w 
.56906 .83754 m .56118 .8404 L .56873 .82049 L p 
0 0 .021 r 
F P 
s 
P 
p 
.002 w 
.56873 .82049 m .58229 .80258 L .56906 .83754 L p 
0 0 .021 r 
F P 
s 
P 
p 
.002 w 
.50694 .87869 m .52588 .86378 L .54545 .85629 L p 
.052 0 0 r 
F P 
s 
P 
p 
.002 w 
.52588 .86378 m .50694 .87869 L .47556 .87346 L p 
.48 .001 .041 r 
F P 
s 
P 
p 
.002 w 
.7472 .7517 m .78201 .73355 L .67878 .61119 L p 
.734 .8 .905 r 
F P 
s 
P 
p 
.002 w 
.67878 .61119 m .64185 .6311 L .7472 .7517 L p 
.734 .8 .905 r 
F P 
s 
P 
p 
.002 w 
.54134 .86556 m .54545 .85629 L .56118 .8404 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.56118 .8404 m .56906 .83754 L .54134 .86556 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.54545 .85629 m .54134 .86556 L .50694 .87869 L p 
.052 0 0 r 
F P 
s 
P 
p 
.002 w 
.71254 .55555 m .70287 .58564 L .80439 .70962 L p 
.96 .79 .628 r 
F P 
s 
P 
p 
.002 w 
.78201 .73355 m .80439 .70962 L .70287 .58564 L p 
.851 .821 .819 r 
F P 
s 
P 
p 
.002 w 
.44532 .7259 m .45111 .71905 L .42374 .74655 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.46508 .71787 m .48483 .70532 L .45111 .71905 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.45111 .71905 m .44532 .7259 L .46508 .71787 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.57271 .78118 m .58229 .80258 L .57759 .77051 L p 
.892 .602 .094 r 
F P 
s 
P 
p 
.002 w 
.57759 .77051 m .56731 .74391 L .57271 .78118 L p 
.892 .602 .094 r 
F P 
s 
P 
p 
.002 w 
.70287 .58564 m .67878 .61119 L .78201 .73355 L p 
.851 .821 .819 r 
F P 
s 
P 
p 
.002 w 
.53732 .72967 m .56731 .74391 L .54304 .72022 L p 
.7 .159 0 r 
F P 
s 
P 
p 
.002 w 
.54304 .72022 m .51635 .70903 L .53732 .72967 L p 
.7 .159 0 r 
F P 
s 
P 
p 
.002 w 
.42925 .74205 m .42374 .74655 L .40969 .78084 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.42374 .74655 m .42925 .74205 L .44532 .7259 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.47556 .87346 m .44792 .86428 L .42505 .83903 L p 
.751 .238 0 r 
F P 
s 
P 
p 
.002 w 
.44792 .86428 m .47556 .87346 L .50694 .87869 L p 
.028 .567 .847 r 
F P 
s 
P 
p 
.002 w 
.41279 .81322 m .42505 .83903 L .44792 .86428 L p 
0 .101 .655 r 
F P 
s 
P 
p 
.002 w 
.48339 .7201 m .51635 .70903 L .48483 .70532 L p 
.42 0 0 r 
F P 
s 
P 
p 
.002 w 
.48483 .70532 m .46508 .71787 L .48339 .7201 L p 
.42 0 0 r 
F P 
s 
P 
p 
.002 w 
.40969 .78084 m .42103 .76214 L .42925 .74205 L p 
0 0 0 r 
F P 
s 
P 
p 
.002 w 
.55713 .82202 m .56906 .83754 L .58229 .80258 L p 
.987 .882 .635 r 
F P 
s 
P 
p 
.002 w 
.58229 .80258 m .57271 .78118 L .55713 .82202 L p 
.987 .882 .635 r 
F P 
s 
P 
p 
.002 w 
.48439 .87031 m .50694 .87869 L .54134 .86556 L p 
.644 .895 .984 r 
F P 
s 
P 
p 
.002 w 
.50694 .87869 m .48439 .87031 L .44792 .86428 L p 
.028 .567 .847 r 
F P 
s 
P 
p 
.002 w 
.54174 .76214 m .57271 .78118 L .56731 .74391 L p 
.903 .58 .425 r 
F P 
s 
P 
p 
.002 w 
.56731 .74391 m .53732 .72967 L .54174 .76214 L p 
.903 .58 .425 r 
F P 
s 
P 
p 
.002 w 
.49538 .73217 m .53732 .72967 L .51635 .70903 L p 
.687 .288 .285 r 
F P 
s 
P 
p 
.002 w 
.51635 .70903 m .48339 .7201 L .49538 .73217 L p 
.687 .288 .285 r 
F P 
s 
P 
p 
.002 w 
.5246 .85487 m .54134 .86556 L .56906 .83754 L p 
.873 .929 .858 r 
F P 
s 
P 
p 
.002 w 
.56906 .83754 m .55713 .82202 L .5246 .85487 L p 
.873 .929 .858 r 
F P 
s 
P 
p 
.002 w 
.43267 .83506 m .44792 .86428 L .48439 .87031 L p 
.422 .583 .907 r 
F P 
s 
P 
p 
.002 w 
.44792 .86428 m .43267 .83506 L .41279 .81322 L p 
0 .101 .655 r 
F P 
s 
P 
p 
.002 w 
.4229 .78093 m .41279 .81322 L .43267 .83506 L p 
.276 .274 .677 r 
F P 
s 
P 
p 
.002 w 
.41279 .81322 m .4229 .78093 L .42103 .76214 L p 
0 0 .387 r 
F P 
s 
P 
p 
.002 w 
.54134 .86556 m .5246 .85487 L .48439 .87031 L p 
.644 .895 .984 r 
F P 
s 
P 
p 
.002 w 
.42925 .74205 m .45322 .75105 L .44532 .7259 L closepath p 
.398 .13 .386 r 
F P 
s 
P 
p 
.002 w 
.44532 .7259 m .45322 .75105 L .46508 .71787 L closepath p 
.456 .161 .375 r 
F P 
s 
P 
p 
.002 w 
.42103 .76214 m .45322 .75105 L .42925 .74205 L closepath p 
.384 .157 .442 r 
F P 
s 
P 
p 
.002 w 
.46508 .71787 m .45322 .75105 L .48339 .7201 L closepath p 
.529 .232 .407 r 
F P 
s 
P 
p 
.002 w 
.4229 .78093 m .45322 .75105 L .42103 .76214 L closepath p 
.416 .228 .515 r 
F P 
s 
P 
p 
.002 w 
.52793 .79772 m .55713 .82202 L .57271 .78118 L p 
.875 .697 .658 r 
F P 
s 
P 
p 
.002 w 
.57271 .78118 m .54174 .76214 L .52793 .79772 L p 
.875 .697 .658 r 
F P 
s 
P 
p 
.002 w 
.4977 .75099 m .54174 .76214 L .53732 .72967 L p 
.764 .476 .498 r 
F P 
s 
P 
p 
.002 w 
.53732 .72967 m .49538 .73217 L .4977 .75099 L p 
.764 .476 .498 r 
F P 
s 
P 
p 
.002 w 
.48339 .7201 m .45322 .75105 L .49538 .73217 L closepath p 
.589 .312 .463 r 
F P 
s 
P 
p 
.002 w 
.46443 .84006 m .48439 .87031 L .5246 .85487 L p 
.675 .705 .869 r 
F P 
s 
P 
p 
.002 w 
.48439 .87031 m .46443 .84006 L .43267 .83506 L p 
.422 .583 .907 r 
F P 
s 
P 
p 
.002 w 
.43452 .7934 m .45322 .75105 L .4229 .78093 L closepath p 
.473 .308 .576 r 
F P 
s 
P 
p 
.002 w 
.43267 .83506 m .43452 .7934 L .4229 .78093 L p 
.276 .274 .677 r 
F P 
s 
P 
p 
.002 w 
.43452 .7934 m .43267 .83506 L .46443 .84006 L p 
.507 .476 .757 r 
F P 
s 
P 
p 
.002 w 
.49948 .82641 m .5246 .85487 L .55713 .82202 L p 
.799 .727 .784 r 
F P 
s 
P 
p 
.002 w 
.55713 .82202 m .52793 .79772 L .49948 .82641 L p 
.799 .727 .784 r 
F P 
s 
P 
p 
.002 w 
.49538 .73217 m .45322 .75105 L .4977 .75099 L closepath p 
.623 .375 .521 r 
F P 
s 
P 
p 
.002 w 
.5246 .85487 m .49948 .82641 L .46443 .84006 L p 
.675 .705 .869 r 
F P 
s 
P 
p 
.002 w 
.4977 .75099 m .45322 .75105 L .48956 .77151 L closepath p 
.631 .414 .569 r 
F P 
s 
P 
p 
.002 w 
.48956 .77151 m .45322 .75105 L .47312 .78807 L closepath p 
.616 .427 .603 r 
F P 
s 
P 
p 
.002 w 
.47312 .78807 m .45322 .75105 L .45291 .79608 L closepath p 
.582 .413 .618 r 
F P 
s 
P 
p 
.002 w 
.45291 .79608 m .45322 .75105 L .43452 .7934 L closepath p 
.533 .373 .61 r 
F P 
s 
P 
p 
.002 w 
.46443 .84006 m .45291 .79608 L .43452 .7934 L p 
.507 .476 .757 r 
F P 
s 
P 
p 
.002 w 
.48956 .77151 m .52793 .79772 L .54174 .76214 L p 
.761 .559 .624 r 
F P 
s 
P 
p 
.002 w 
.54174 .76214 m .4977 .75099 L .48956 .77151 L p 
.761 .559 .624 r 
F P 
s 
P 
p 
.002 w 
.45291 .79608 m .46443 .84006 L .49948 .82641 L p 
.639 .56 .75 r 
F P 
s 
P 
p 
.002 w 
.49948 .82641 m .47312 .78807 L .45291 .79608 L p 
.639 .56 .75 r 
F P 
s 
P 
p 
.002 w 
.47312 .78807 m .49948 .82641 L .52793 .79772 L p 
.718 .583 .703 r 
F P 
s 
P 
p 
.002 w 
.52793 .79772 m .48956 .77151 L .47312 .78807 L p 
.718 .583 .703 r 
F P 
s 
P 
p 
P 
p 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{262, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004600017a000`40O003h00Oogoo1goo003oOol7
Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00
ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7
Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00
ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00^Goo0P00Bgoo002g
Ool20002Ool00`00Oomoo`18Ool00;Aoo`<000Aoo`03001oogoo04Qoo`00/Goo0`0027oo00<007oo
Ool0Agoo002_Ool2000<Ool00`00Oomoo`16Ool00:aoo`<000ioo`03001oogoo04Ioo`00ZGoo0`00
4Woo00<007ooOol0AGoo002WOol2000FOol00`00Oomoo`14Ool00:Aoo`<001Qoo`03001oogoo04Ao
o`00XWoo0P0077oo00<007ooOol0@goo002OOol3000NOol00`00Oomoo`13Ool009aoo`<0029oo`03
001oogoo049oo`00VWoo0P009Woo00<007ooOol0@Goo002GOol3000XOol00`00Oomoo`11Ool009Eo
o`8002aoo`03001oogoo041oo`00TWoo0`00;goo00<007ooOol0?goo002?Ool300000goo0000000_
Ool00`00Oomoo`0oOol008eoo`8000=oo`03001oo`00031oo`03001oogoo03ioo`00RWoo0`001Goo
00@007ooOol0031oo`03001oogoo03eoo`00Qgoo0`001goo00<007ooOol00Woo00<007ooOol0;Goo
00<007ooOol0?Goo0025Ool2000:Ool00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`0lOol0
089oo`<000]oo`03001oogoo00Aoo`03001oogoo02ioo`03001oogoo03]oo`00P7oo0P003Woo00<0
07ooOol01Goo00<007ooOol0;Goo00<007ooOol0>goo001mOol3000?Ool00`00Oomoo`07Ool00`00
Oomoo`0]Ool00`00Oomoo`0jOol007Yoo`<0019oo`03001oogoo00Qoo`03001oogoo02eoo`03001o
ogoo03Uoo`00N7oo0P0057oo00<007ooOol02Goo00<007ooOol0;Goo00<007ooOol0>Goo001eOol3
000FOol00`00Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`0hOol007=oo`8001Qoo`03001oogoo
00aoo`03001oogoo02aoo`03001oogoo03Qoo`00L7oo0`006Woo00<007ooOol03Goo00<007ooOol0
;7oo00<007ooOol0=goo001]Ool3000LOol00`00Oomoo`0>Ool00`00Oomoo`0]Ool00`00Oomoo`0f
Ool006]oo`8001moo`03001oogoo00moo`03001oogoo02aoo`03001oogoo03Ioo`00J7oo0`0087oo
00<007ooOol04Goo00<007ooOol0;7oo00<007ooOol0=Goo001UOol3000SOol00`00Oomoo`0AOol0
0`00Oomoo`0]Ool00`00Oomoo`0dOol006=oo`8002Eoo`03001oogoo01=oo`03001oogoo02aoo`03
001oogoo03Aoo`00H7oo0`009goo00<007ooOol057oo00<007ooOol0;7oo00<007ooOol0<goo001N
Ool2000YOol00`00Oomoo`0FOol00`00Oomoo`0/Ool00`00Oomoo`0bOol005]oo`<002]oo`03001o
ogoo01Ioo`03001oogoo02aoo`03001oogoo039oo`00F7oo0`00;Woo00<007ooOol05goo00<007oo
Ool0;7oo00<007ooOol0<Goo001FOol2000`Ool00`00Oomoo`0IOol00`00Oomoo`0/Ool00`00Oomo
o`0`Ool005=oo`<0039oo`03001oogoo01Yoo`03001oogoo02]oo`03001oogoo031oo`00D7oo0`00
=7oo00<007ooOol06goo00<007ooOol0;7oo00<007ooOol0;goo001>Ool2000gOol00`00Oomoo`0L
Ool00`00Oomoo`0/Ool00`00Oomoo`0^Ool004]oo`<003Qoo`03001oogoo01ioo`03001oogoo02]o
o`03001oogoo02ioo`00BGoo0P0000=oo`00Ool0>7oo00<007ooOol07goo00<007ooOol0:goo00<0
07ooOol0;Goo0016Ool30004Ool00`00Oomoo`0eOol00`00Oomoo`0POol00`00Oomoo`0[Ool00`00
Oomoo`0]Ool004=oo`<000Moo`8003Ioo`03001oogoo025oo`03001oogoo02]oo`03001oogoo02ao
o`00@Goo0P002goo0P00=7oo00<007ooOol08goo00<007ooOol0:goo00<007ooOol0:goo000nOol3
000>Ool2000cOol00`00Oomoo`0TOol00`00Oomoo`0ZOol00`00Oomoo`0[Ool003aoo`80015oo`03
001oo`00035oo`03001oogoo02Eoo`03001oogoo02]oo`03001oogoo02Yoo`00>Goo0`0057oo0P00
<Goo00<007ooOol09Woo00<007ooOol0:goo00<007ooOol0:Goo000fOol3000GOol00`00Ool0000_
Ool00`00Oomoo`0XOol00`00Oomoo`0ZOol00`00Oomoo`0YOol003Aoo`8001]oo`03001oo`0002io
o`03001oogoo02Qoo`03001oogoo02Yoo`8002Yoo`00<Goo0`007Woo00<007oo0000;7oo00<007oo
Ool0:Woo00<007ooOol09Woo0`00;7oo000^Ool3000QOol01000Oomoo`00:goo00<007ooOol0:goo
00<007ooOol08goo0P00;goo000/Ool2000UOol01000Oomoo`00:Goo00<007ooOol0;Goo00<007oo
Ool07goo0`00<Goo000ZOol2000XOol01000Oomoo`00:7oo00<007ooOol0;Goo00<007ooOol077oo
0`00=7oo000ZOol2000XOol01@00Oomoogoo00009Woo00<007ooOol0;goo00<007ooOol067oo0`00
=goo000ZOol00`00Ool0000XOol01@00Oomoogoo00009Goo00<007ooOol0<7oo00<007ooOol057oo
0`00>Woo000ZOol01000Oomoo`009goo00<007ooOol00Woo00<007ooOol08Woo00<007ooOol0<Goo
00<007ooOol047oo0`00?Goo000ZOol01@00Oomoogoo00009goo00D007ooOomoo`0002=oo`03001o
ogoo039oo`03001oogoo00eoo`<0041oo`00:Goo00<007ooOol00goo00<007ooOol09Goo00D007oo
Oomoo`00029oo`03001oogoo03=oo`03001oogoo00Uoo`<004=oo`00:Goo00<007ooOol017oo00<0
07ooOol097oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol0=Goo00<007ooOol01Woo0P00
AWoo000YOol00`00Oomoo`05Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0MOol00`00
Oomoo`0fOol00`00Oomoo`02Ool30018Ool002Uoo`03001oogoo00Ioo`03001oogoo02Aoo`03001o
ogoo009oo`03001oogoo01]oo`03001oogoo03Moo`03001oo`00008004]oo`00:Goo00<007ooOol0
1goo00<007ooOol08goo00<007ooOol00goo00<007ooOol06Woo00<007ooOol0=Woo0`00CWoo000Y
Ool00`00Oomoo`08Ool00`00Oomoo`0SOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`06
000^Ool30002Ool00`00Oomoo`1<Ool002Uoo`03001oogoo00Uoo`03001oogoo029oo`03001oogoo
00Aoo`03001oogoo01Eoo`D000A6g@8jWPH002Eoo`<000Aoo`03001oogoo04eoo`00:Goo00<007oo
Ool02Woo00<007ooOol08Woo00<007ooOol017oo00<007ooOol04Goo0`0000=Bo@0000001dKM1CZN
0R8m1@007Goo0`001goo00<007ooOol0CGoo000YOol00`00Oomoo`0;Ool00`00Oomoo`0ROol00`00
Oomoo`04Ool00`00Oomoo`0=Ool30004D_d00`00D_d00006A]d00`00>YhjWP03>Yh58Sd00`Vk0000
000HOol30009Ool00`00Oomoo`1>Ool002Uoo`03001oogoo00aoo`03001oogoo025oo`03001oogoo
00Aoo`03001oogoo00]oo`80009K7005001BoE;mD_d00003D_d00`00A]e6g@04A]d00`00>YhjWP03
>Yh58Sd22K/2000COol3000<Ool00`00Oomoo`1>Ool002Qoo`03001oogoo00ioo`03001oogoo025o
o`03001oogoo00Aoo`03001oogoo00Qoo`8000EK7004001BoE;m0003D_d00`00A]e6g@05A]d00`00
>YhjWP02>Yh00`008SdR?@028Sd010002K/9^`Vk0P003Woo0`003Woo00<007ooOol0Cgoo000XOol0
0`00Oomoo`0?Ool00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Oomoo`05Ool20008Fa`20005D_d0
0`00A]e6g@05A]d00`00>YhjWP02>Yh00`008SdR?@028Sd00`002K/9^`022K/20009Ool3000AOol0
0`00Oomoo`1?Ool002Qoo`03001oogoo011oo`03001oogoo021oo`03001oogoo00Eoo`03001oogoo
009oo`800003Ga/005/L00MK708000IBo@030016gDKM00E6g@03000jWSZN008jWP03000R?B8m008R
?@030009^`Vk0089^`030ET007oo00Eoo`8001=oo`03001oogoo051oo`00:7oo00<007ooOol04Goo
00<007ooOol087oo00<007ooOol01Goo00@007oo000000AO6`03001K75/L00EK708000MBo@030016
gDKM00E6g@03000jWSZN008jWP03000R?B8m008R?@060009^`Vk2K/0005I0P0000Aoo`00000001Eo
o`03001oogoo051oo`00:7oo00<007ooOol04Woo00<007ooOol087oo00<007ooOol017oo0P001elK
00<005/LFa`015/L00<005/L00001e;m00<004KMA]d014KM00<003ZN>Yh00cZN00<0028m8Sd00R8m
00D000Vk2K/9^`000081F@03001oogoo01Eoo`03001oogoo055oo`00:7oo00<007ooOol04goo00<0
07ooOol07goo00<007ooOol00goo00<005lKGa/01elK00<005/LFa`00e/L00D005/LFaaK700000MB
o@030016gDKM00A6g@03000jWSZN00<jWP03000R?B8m008R?@050009^`Vk2K/000020ET2000EOol0
0`00Oomoo`1AOol002Qoo`03001oogoo01Aoo`03001oogoo01moo`07001oogooOol006LJ00002ElK
00<005/LFa`00U/L00<005/LFa`00U/L00<005;mD_d01E;m00<004KMA]d014KM00<003ZN>Yh00SZN
00<0028m8Sd00R8m00<000Vk2K/00PVk00D0005I0ET1F@0001Aoo`03001oogoo055oo`00:7oo00<0
07ooOol057oo00<007ooOol087oo00<007oo00000fLJ00<005lKGa/01elK00@005/LFa`000IK7003
001BoE;m00EBo@030016gDKM00A6g@03000jWSZN008jWP03000R?B8m008R?@030009^`Vk0089^`05
0001F@5I0ET0000BOol00`00Oomoo`1BOol002Qoo`03001oogoo01Eoo`03001oogoo01moo`8000EW
6P03001O6elK00MO6`03001K700000IK7003001BoE;m00EBo@030016gDKM00E6g@03000jWSZN008j
WP03000R?B8m008R?@030009^`Vk0089^`040001F@5I0ET2000@Ool00`00Oomoo`1BOol002Qoo`03
001oogoo01Ioo`03001oogoo01eoo`03001W6P0000IW6P03001O6elK00MO6`03001K75/L00IK7003
001BoE;m00EBo@030016gDKM00A6g@03000jWSZN00<jWP03000R?B8m008R?@050009^`Vk2K/00003
0ET00`000?L0000>Ool00`00Oomoo`1COol002Moo`03001oogoo01Qoo`03001oogoo01]oo`05001W
6VLJIaX00006IaX00`00Ga]O6`06Ga/20008Fa`00`00D_eBo@05D_d00`00A]e6g@04A]d00`00>Yhj
WP03>Yh00`008SdR?@028Sd01@002K/9^`Vk00000`5I00<0003g00003Goo00<007ooOol0Dgoo000W
Ool00`00Oomoo`0IOol00`00Oomoo`0IOol00`00JaT00002IaX00`00IaYW6P04IaX00`00Ga]O6`05
Ga/01000Ga]O6`0025/L00<005;mD_d01E;m00<004KMA]d014KM00<003ZN>Yh00cZN00D0028m8SdR
?@0000@9^`060001F@5I0ET0003g0P002Woo00<007ooOol0E7oo000WOol00`00Oomoo`0JOol00`00
Oomoo`0GOol01@00JaU[6F/I00000VLJ00<006LJIaX016LJ00<005lKGa/015lK00D005lKGa]O6`00
00QK7003001BoE;m00EBo@030016gDKM00A6g@03000jWSZN008jWP03000R?B8m008R?@030009^`Vk
0089^`050001F@5I0ET000020?L00`00Oomoo`07Ool00`00Oomoo`1DOol002Moo`03001oogoo01]o
o`03001oogoo01Eoo`03001[6F/I00=[6@04001W6VLJ0006IaX00`00Ga]O6`02Ga/00`00Ga]O6`02
Ga/00`00FaaK7007Fa`00`00D_eBo@05D_d00`00A]e6g@04A]d00`00>YhjWP02>Yh00`008SdR?@02
8Sd00`002K/9^`022K/01@000ET1F@5I00000P3g00<007ooOol01Goo00<007ooOol0EGoo000WOol0
0`00Oomoo`0LOol00`00Oomoo`0DOol00`00JaU[6@04JaT00`00IaX00007IaX01@00Ga]O6elK0000
1ElK00<005/LFa`01U/L00<005;mD_d01U;m00<004KMA]d014KM00<003ZN>Yh00SZN00<0028m8Sd0
0R8m00D000Vk2K/9^`0000<1F@050000m`3g0?L00006Ool00`00Oomoo`1EOol002Moo`03001oogoo
01eoo`03001oogoo019oo`03001[6F/I00I[6@03001W6P0000MW6P03001O6`0000MO6`03001K75/L
00IK7003001BoE;m00IBo@030016gDKM00=6g@03000jWSZN00<jWP03000R?B8m008R?@050009^`Vk
2K/000030ET00`000?L0m`020005Ool00`00Oomoo`1EOol002Moo`03001oogoo01ioo`03001oogoo
011oo`03001[6F/I00Q[6@03001W6P0000MW6P8000QO6`03001K75/L00IK7003001BoE;m00EBo@03
0016gDKM00A6g@03000jWSZN00<jWP03000R?B8m008R?@050009^`Vk2K/000030ET00`000?L0m`02
0003Ool00`00Oomoo`1FOol002Moo`03001oogoo01moo`03001oogoo00ioo`03001_600000Y[6@80
00MW6P8000UO6`03001K75/L00IK7003001BoE;m00EBo@030016gDKM00A6g@03000jWSZN00<jWP05
000R?B8m8Sd000042K/01@000ET1F@5I00000P3g0P000Woo00<007ooOol0EWoo000WOol00`00Oomo
o`0POol00`00Oomoo`0<Ool01@00KaQ_66lH00002F/I00<006LJ00001VLJ00<006LJ00002ElK00<0
05/LFa`01U/L00<005;mD_d01E;m00<004KMA]d014KM00<003ZN>Yh00cZN00D0028m8SdR?@0000@9
^`040001F@5I00030?L00`1C0000001IOol002Moo`03001oogoo025oo`03001oogoo00Yoo`03001_
66lH00=_6003001[6F/I00M[6@03001W6P0000AW6P05001W6VLJIaX00009Ga/00`00FaaK7006Fa`0
0`00D_eBo@05D_d00`00A]e6g@04A]d00`00>YhjWP02>Yh00`008SdR?@028Sd00`002K/9^`022K/0
10000ET1F@000`3g00<0D`00Ool0F7oo000VOol00`00Oomoo`0SOol00`00Oomoo`09Ool00`00KaQ_
6004KaP00`00JaU[6@07JaT20002IaX00`00IaX00004IaX00`00Ga]O6`07Ga/00`00FaaK7006Fa`0
0`00D_eBo@05D_d00`00A]e6g@03A]d00`00>YhjWP03>Yh00`008SdR?@028Sd01@002K/9^`Vk0000
0`5I00H0003g0?L0001C001HOol002Ioo`03001oogoo02Aoo`03001oogoo00Moo`03001_66lH00I_
6003001[6F/I00M[6@D000EW6P03001O6elK00MO6`03001K75/L00IK7003001BoE;m00IBo@030016
gDKM00=6g@03000jWSZN00<jWP03000R?B8m008R?@050009^`Vk2K/000030ET01P000?L0m`0005<0
05Moo`009Woo00<007ooOol09Goo00<007ooOol01Goo00<006lHKaP026lH00<006/IJaT01f/I1000
1VLJ00<005lKGa/01elK00<005/LFa`01U/L00<005;mD_d01U;m00<004KMA]d00dKM00<003ZN>Yh0
0cZN00D0028m8SdR?@0000@9^`050001F@5I0ET000020?L00`0005<0001FOol002Ioo`03001oogoo
02Ioo`03001oogoo00=oo`03001c5`0000Y_6003001[6F/I00E[6@H000IW6P03001O6elK00MO6`03
001K75/L00IK7003001BoE;m00IBo@030016gDKM00=6g@03000jWSZN00<jWP05000R?B8m8Sd00004
2K/010000ET1F@000`3g0`00EGoo000VOol00`00Oomoo`0WOol00`00Oomoo`02Ool01000LaMc5`00
2VlH00<006/IJaT016/I1`001VLJ00<005lKGa/01elK00<005/LFa`01U/L00<005;mD_d01E;m00<0
04KMA]d014KM00<003ZN>Yh00cZN00D0028m8SdR?@0000@9^`040001F@5I00020?L00`0005<0001E
Ool002Ioo`03001oogoo02Qoo`04001oogoo0004LaL00`00KaQ_6008KaP00`00JaU[6@04JaT70006
IaX00`00Ga]O6`07Ga/00`00FaaK7006Fa`00`00D_eBo@05D_d00`00A]e6g@04A]d00`00>YhjWP02
>Yh00`008SdR?@028Sd01@002K/9^`Vk00000`5I00H0003g0?L0001C001DOol002Ioo`03001oogoo
02Uoo`03001oo`0000Ec5`03001_66lH00Q_6003001[6F/I00=[6@P000IW6P03001O6elK00MO6`03
001K75/L00IK7003001BoE;m00EBo@030016gDKM00=6g@03000jWSZN00<jWP03000R?B8m008R?@05
0009^`Vk2K/000030ET01P000?L0m`0005<005=oo`009Woo00<007ooOol0:Woo00<007<GLaL01G<G
00<006lHKaP026lH00<006/IJaT00V/I2@001VLJ00<005lKGa/01elK00<005/LFa`01E/L00<005;m
D_d01U;m00<004KMA]d00dKM00<003ZN>Yh00cZN00<0028m8Sd00R8m00D000Vk2K/9^`0000<1F@06
0000m`3g0000D`00DWoo000VOol00`00Oomoo`0ZOol00`00LaMc5`06LaL00`00KaQ_6008KaP01000
JaU[6@000V/I20001VLJ00<005lKGa/01elK00<005/LFa`01E/L00<005;mD_d01E;m3`000R8m00<0
00Vk2K/00PVk00@0005I0ET000<0m`<0055oo`009Woo00<007ooOol0:Woo0P0027<G00<006lHKaP0
26lH0P0016/I20001VLJ00<005lKGa/01UlK00<005/LFa`01U/L00<005;mD_d010003goo100010Vk
00@0005I0ET00080m`040000D`00001@Ool002Eoo`03001oogoo02Yoo`04001g5GLE0008LaL00`00
KaQ_6007KaP20005JaT80006IaX00`00Ga]O6`06Ga/00`00FaaK7006Fa`2000FOol300032K/01000
0ET1F@000P3g00@0001C000004moo`009Goo00<007ooOol0:Woo00D007LEMaEg5@0000Qc5`03001_
66lH00E_6003001_600000I[6@P000EW6P03001O6elK00MO6`03001K75/L00=K708001Moo`04001o
ogooOol200000`Vk0001F@020ET00`000?L0m`0200000fEPOomoo`1=Ool002Eoo`03001oogoo02Uo
o`03001g5GLE00=g5@03001c5g<G00Ic5`03001_66lH00A_6004001_66lH0006JaT80005IaX00`00
Ga]O6`07Ga/00`00FaaK7002000IOol00`00Oomoo`03Ool300020ET010000?L0m`3g0`00CWoo000U
Ool00`00Oomoo`0YOol00`00MaEg5@04MaD00`00LaMc5`06LaL00`00KaQ_6002KaP00`00KaQ_6002
KaP00`00JaU[6@04JaT80004IaX20008Ga/3000JOol00`00Oomoo`06Ool200020ET01`000?L0m`3g
001UH00004eoo`009Goo00<007ooOol0:7oo00<007LEMaD01WLE00<007<GLaL01W<G00@006lHKaP0
00I_6003001[6F/I00A[6@L000IW6P03001O6elK00=O6`8001eoo`03001oogoo00Qoo`040001F@5I
00020?L200000fEP001oo`1;Ool002Eoo`03001oogoo02Qoo`03001g5GLE00Mg5@03001c5g<G00Ic
5`8000Q_6003001[6F/I00A[6@L000IW6P03001O6elK008001moo`03001oogoo00Uoo`8000050ET0
003g0?L00002IF000`00Oomoo`19Ool002Eoo`03001oogoo02Qoo`8000Ug5@03001c5g<G00Ec5`80
00U_6003001[6F/I00A[6@L000IW6P80021oo`03001oogoo00aoo`030001F@000080m`03001UH000
04]oo`009Goo00<007ooOol09goo00@007[bN_8000Ug5@03001c5g<G00Ac5`8000Y_6003001[6F/I
00A[6@L000AW6P03001oogoo021oo`03001oogoo00eoo`800080m`04001UH6EP001:Ool002Eoo`03
001oogoo02Moo`05001jlW[bN_800009MaD00`00LaMc5`02LaL01000LaMc5`002VlH00<006/IJaT0
0f/I20000VLJ0P008Goo00<007ooOol03goo0P0000<0m`0000000VEP00<007ooOol0Agoo000UOol0
0`00Oomoo`0WOol00`00N_9jlP02N_800`00MaEg5@07MaD01000LaMc5`0017<G00<006lHKaP026lH
00<006/IJaT00f/I2@000Woo00<007ooOol07Woo00<007ooOol04Goo0P0000EjR000IF1UH00004Qo
o`0097oo00<007ooOol09goo00<007[bN_8017[b00<007LEMaD01gLE0P001W<G00<006lHKaP026lH
00<006/IJaT00f/I20000Woo00<007ooOol07Goo00<007ooOol04goo00<007Z8NXP00VEP00<007oo
Ool0AWoo000TOol00`00Oomoo`0WOol00`00N_9jlP05N_800`00MaEg5@06MaD20007LaL00`00KaQ_
6008KaP00`00JaU[6@03JaT80002Ool00`00Oomoo`0LOol00`00Oomoo`0COol01000NXQjR0000VEP
00<007ooOol0AGoo000TOol00`00Oomoo`0WOol20007N_800`00MaEg5@05MaD00`00MaD00007LaL0
0`00KaQ_6008KaP00`00JaU[6@03JaT80002Ool00`00Oomoo`0KOol00`00Oomoo`0DOol01000NXQj
R0000VEP00<007ooOol0A7oo000TOol00`00Oomoo`0WOol00`00NZl00007N_800`00MaEg5@03MaD0
1000MaEg5@0027<G00<006lHKaP026lH00<006/IJaT00f/I20000Woo00<007ooOol06Goo00<007oo
Ool05Goo00D007Z8NXQjR000009UH003001oogoo04=oo`0097oo00<007ooOol09goo00@007Z_NZl0
00MjlP05001g5GLEMaD00004MaD00`00LaMc5`06LaL00`00KaQ_6008KaP01P00JaU[6F/I001oo`P0
0003Ool007oo01Yoo`03001oogoo01Eoo`03001jR7Z8009jR004001UH6EP0014Ool002Aoo`03001o
ogoo02Moo`04001j[gZ_NZl20006N_800`00MaD00006MaD00`00LaMc5`06LaL00`00KaQ_6008KaP0
0`00JaT00003Ool70002Ool00`00Oomoo`0GOol00`00Oomoo`0FOol00`00NXQjR002NXP01000IF1U
H000A7oo000TOol00`00Oomoo`0WOol00`00NZmj[`02NZl00`00N_9jlP05N_800`00MaEg5@06MaD0
0`00LaMc5`06LaL00`00KaQ_6008KaP00`00Oomoo`03Ool70002Ool00`00Oomoo`0FOol00`00Oomo
o`0FOol00`00NXQjR003NXP01000IF1UH000@goo000TOol00`00Oomoo`0WOol00`00NZmj[`03NZl0
0`00N_9jlP04N_820008MaD00`00LaMc5`06LaL00`00KaQ_6006KaP00`00Oomoo`05Ool700000goo
001oo`0FOol00`00Oomoo`0GOol20005NXP01000IF1UH000@Woo000TOol00`00Oomoo`0WOol00`00
NZmj[`04NZl00`00N_9jlP02N_801000N_9jlP0027LE00<007<GLaL01W<G00<006lHKaP016lH00<0
07ooOol01goo1`0000=oo`00Ool05Goo00<007ooOol05Woo00@007/dNc@000EjR004001UH6EP0011
Ool002Aoo`03001oogoo02Moo`8000Ij[`04001jlW[b0004N_800`00MaEg5@06MaD00`00LaMc5`06
LaL00`00KaQ_6002KaP00`00Oomoo`08Ool800000goo001oo`0DOol00`00Oomoo`0FOol01@00NcAk
=7/d000017Z800D006EPIF1UH000041oo`008goo00<007ooOol0:7oo00<007YZ00001WZ_0P001W[b
00<007LEMaD01WLE00<007<GLaL01W<G00D006lHKaQ_600000]oo`T001Aoo`03001oogoo01Moo`05
001k=7/dNc@00005NXP01000IF1UH000@7oo000SOol00`00Oomoo`0XOol01000NVYjJP001GZ_0P00
1g[b00<007LEMaD01WLE00<007<GLaL01W<G00<006lH00003Goo2@004goo00<007ooOol05goo00<0
07/dNc@00W/d00<007Z8NXP00gZ800@006EPIF0003moo`008goo00<007ooOol0:Goo00@007YZNVX0
00Aj[`03001j[`0000MjlP03001g5GLE00Ig5@03001c5g<G00Ic5`03001oogoo00eoo`T0015oo`03
001oogoo01Moo`03001k=7/d00Ak=003001jR7Z800=jR004001UH6EP000nOol002=oo`03001oogoo
02Uoo`05001jJWYZNVX00002NZl01@00NZmj[gZ_00001g[b00<007LEMaD01WLE00<007<GLaL017<G
00<007ooOol03goo20004Goo00<007ooOol05goo00<007/dNc@01G/d00<007Z8NXP00gZ800@006EP
IF0003eoo`008goo00<007ooOol0:Goo00<007YZNVX00WYZ0P001GZ_00<007[bN_801G[b00<007LE
MaD01WLE00<007<GLaL00g<G00<007ooOol047oo20003goo00<007ooOol067oo00<007/dNc@01W/d
00<007Z8NXP00WZ800@006EPIF0003eoo`008goo00<007ooOol0:Goo0P000gYZ0P001WZ_00<007[b
N_801G[b00<007LEMaD01WLE00D007<GLaMc5`0001Aoo`P000ioo`03001oogoo01Moo`03001_FP00
00Qk=003001jR7Z8009jR004001UH6EP000lOol002=oo`03001oogoo02Yoo`@0009jJP03001j[gZ_
00Aj[`03001jlW[b00EjlP03001g5GLE00Ig5@04001c5g<G000EOol7000>Ool00`00Oomoo`0FOol0
1@00KeY_FVmJ00001g/d00<007Z8NXP00gZ800@006EPIF0003]oo`008goo00<007ooOol0:Woo00@0
0771000000=jJP03001j[gZ_00Aj[`03001jlW[b00EjlP03001g5GLE00Ig5@8001Moo`L000aoo`03
001oogoo01Ioo`03001_FVmJ009_FP03001k=7/d00Ik=003001jR7Z800=jR004001UH6EP000jOol0
02=oo`03001oogoo02]oo`<000AjJP03001j[gZ_00Aj[`03001jlW[b00EjlP03001g5GLE00Ig5@03
001oogoo01Ioo`L000]oo`03001oogoo01Eoo`03001_FVmJ00A_FP03001k=7/d00Ik=003001jR7Z8
00=jR004001UH6EP000iOol002=oo`03001oogoo02]oo`800003LL4007YZ00=jJP03001j[gZ_00Aj
[`03001jlW[b00EjlP03001g5GLE00Eg5@03001oogoo01Moo`L000Uoo`03001oogoo01Eoo`03001_
FVmJ00I_FP03001k=7/d00Ik=003001jR7Z8009jR004001UH6EP000iOol0029oo`03001oogoo02]o
o`03001oo`00009a`@03001jJWYZ009jJP03001j[gZ_00Aj[`03001jlW[b00EjlP03001g5GLE00=g
5@03001oogoo01Qoo`P000Qoo`03001oogoo01Aoo`03001_FVmJ00Q_FP03001k=7/d00Ik=003001j
R7Z8009jR004001UH6EP000hOol0029oo`03001oogoo02Yoo`03001oogoo0080009a`@8000=jJP03
001j[gZ_00Aj[`03001jlW[b00EjlP03001g5GLE009g5@03001oogoo01Uoo`P000Ioo`03001oogoo
01=oo`800003Gc`006mJ00U_FP03001k=7/d00Ik=003001jR7Z8009jR004001UH6EP000gOol0029o
o`03001oogoo02Yoo`06001oogoo001oo`000g7100D007YZNVYjJP0000Ij[`03001jlW[b00EjlP05
001g5GLEMaD0000LOol80005Ool00`00Oomoo`0AOol20004Gc`00`00KeY_FP07KeX00`00NcAk=006
Nc@00`00NXQjR003NXP00`00IF00000gOol0029oo`03001oogoo02Uoo`05001oogooOol00002Ool0
1@00LL5a`G7100000gYZ0P001GZ_00<007[bN_801G[b00@007LEMaD001eoo`P000Aoo`03001oogoo
00moo`8000MO?003001_FVmJ00M_FP03001k=7/d00Ik=003001jR7Z8009jR004001UH6EP000fOol0
029oo`03001oogoo02Qoo`03001oogoo009oo`04001oogooOol20002LL400`00NVYjJP02NVX00`00
NZmj[`03NZl00`00N_9jlP05N_82000OOol80002Ool00`00Oomoo`0>Ool20009Gc`00`00KeY_FP08
KeX00`00NcAk=006Nc@00`00NXQjR002NXP00`00IF00000fOol0029oo`03001oogoo02Moo`03001o
ogoo00=oo`03001oogoo009oo`<00003LL4007YZ00=jJP03001j[gZ_00=j[`03001jlW[b00EjlP03
001oogoo01ioo`P00003Ool007oo00aoo`<000aO?003001_FVmJ00Q_FP03001k=7/d00Ik=003001j
R7Z8009jR003001UH00003Eoo`008Woo00<007ooOol09Woo00<007ooOol017oo00<007ooOol00goo
00D0003E001a`@0000AjJP03001j[gZ_00=j[`03001jlW[b00AjlP03001oogoo01moo`P000]oo`<0
009C7P03001O?5ll00]O?003001_FVmJ00Q_FP03001k=7/d00Ik=003001jR7Z8009jR08003Eoo`00
8Woo00<007ooOol09Goo00<007ooOol01Goo00<007ooOol017oo00<0003E00000P0017YZ00<007Z_
NZl00gZ_00<007[bN_800W[b00<007ooOol08Goo20001goo0`001U<N00<005llGc`02ell00<006mJ
KeX026mJ00<007/dNc@01W/d00<007Z8NXP00WZ80P00=7oo000ROol00`00Oomoo`0UOol00`00Oomo
o`05Ool00`00Oomoo`05Ool00`000=D000020004NVX00`00NZmj[`03NZl01@00N_9jlW[b000097oo
1`0017oo0`002U<N00<005llGc`02ell00<006mJKeX01fmJ00<007/dNc@01g/d00@007Z8NXQjR080
03Aoo`008Woo00<007ooOol097oo00<007ooOol01Goo00<007ooOol01goo00@0003E0009g0<0009j
JP03001j[gZ_00=j[`04001jlW[b000UOol:000=Dah00`00GcaO?00<Gc`00`00KeY_FP07KeX00`00
NcAk=006Nc@00`00NXQjR002NXP2000cOol0025oo`03001oogoo02Aoo`03001oogoo00Ioo`03001o
ogoo00Qoo`060000e@002M`0029N10001GZ_0P0097oo1`0014Kn00<005<NDah035<N00<005llGc`0
2ell00<006mJKeX026mJ00<007/dNc@01W/d00<007Z8NXP00WZ800<007ooOol0<Goo000QOol00`00
Oomoo`0SOol00`00Oomoo`07Ool00`00Oomoo`09Ool01@000=D000WL0000129N20006Goo2P0034Kn
00<005<NDah035<N00<005llGc`02ell00<006mJKeX026mJ00<007/dNc@01W/d00D007Z8NXQjR000
03=oo`008Goo00<007ooOol08Woo00<007ooOol027oo00<007ooOol02Woo00D0003E0009g00000HR
GP03000^WRjN008^WQT000LngP030016oTKn00e6oP03001C7U<N00aC7P03001O?5ll00]O?003001_
FVmJ00Q_FP03001k=7/d00Ik=004001jR7Z8000cOol0025oo`03001oogoo029oo`03001oogoo00Qo
o`03001oogoo00]oo`050000e@002M`000068Uh00`00;Yh^WP07;Yh00`00=[hf_P0:=[h00`00?]hn
gP0;?]h00`00A_i6oP0=A_h00`00DaiC7P0<Dah00`00GcaO?00;Gc`00`00KeY_FP07KeX00`00NcAk
=007Nc@01000NXQjR000<Woo000QOol00`00Oomoo`0QOol00`00Oomoo`09Ool00`00Oomoo`0<Ool0
1@000=D000WL00001R9N00<002jN;Yh01bjN00<003Jn=[h02SJn00<003kN?]h02ckN00<004KnA_h0
3DKn00<005<NDah035<N00<005llGc`02ell00<006mJKeX01fmJ00<007/dNc@01g/d00<007Z80000
<Woo000QOol00`00Oomoo`0POol00`00Oomoo`0:Ool00`00Oomoo`0=Ool01@000=D000WL00001R9N
00<002jN;Yh01bjN00<003Jn=[h02SJn00<003kN?]h02ckN00<004KnA_h034Kn00<005<NDah03E<N
00<005llGc`02ell00<006mJKeX01fmJ00<007/dNc@01W/d00<007Z80000<Woo000QOol00`00Oomo
o`0OOol00`00Oomoo`0;Ool00`00Oomoo`0>Ool010000=D000WL0P001B9N00<002jN;Yh01bjN00<0
03Jn=[h02SJn00<003kN?]h02ckN00<004KnA_h034Kn00<005<NDah03E<N00<005llGc`02Ull00<0
06mJKeX026mJ00<007/dNc@01W/d0P00<Woo000QOol00`00Oomoo`0NOol00`00Oomoo`0<Ool00`00
Oomoo`0?Ool00`000=D000022M`00`008UhRGP038Uh00`00;Yh^WP07;Yh00`00=[hf_P0:=[h00`00
?]hngP0;?]h00`00A_i6oP0<A_h00`00DaiC7P0<Dah00`00GcaO?00;Gc`00`00KeY_FP08KeX00`00
NcAk=006Nc@2000aOol0025oo`03001oogoo01ioo`03001oogoo00aoo`03001oogoo011oo`<00089
g003000RGR9N00<RGP03000^WRjN00L^WP03000f_SJn00Xf_P03000ngSkN00/ngP030016oTKn00a6
oP03001C7U<N00aC7P03001O?5ll00]O?003001_FVmJ00M_FP03001k=7/d00Mk=003001oogoo02mo
o`008Goo00<007ooOol07Goo00<007ooOol03Goo00<007ooOol04Woo0P000PWL00<0029N8Uh00b9N
00<002jN;Yh01bjN00<003Jn=[h02SJn00<003kN?]h02SkN00<004KnA_h03DKn00<005<NDah035<N
00<005llGc`02ell00<006mJKeX01fmJ00<007/dNc@01W/d00<007ooOol0;goo000POol00`00Oomo
o`0MOol00`00Oomoo`0>Ool00`00Oomoo`0COol200022M`00`008UhRGP038Uh00`00;Yh^WP07;Yh0
0`00=[hf_P0:=[h00`00?]hngP0:?]h00`00A_i6oP0=A_h00`00DaiC7P0<Dah00`00GcaO?00;Gc`0
0`00KeY_FP07KeX00`00NcAk=004Nc@00`00Oomoo`0`Ool0021oo`03001oogoo01aoo`03001oogoo
00moo`03001oogoo01Aoo`800089g003000RGR9N00<RGP03000^WRjN00L^WP03000f_SJn00Xf_P03
000ngSkN00XngP030016oTKn00e6oP03001C7U<N00aC7P03001O?5ll00]O?003001_FVmJ00M_FP03
001k=7/d00=k=003001oogoo031oo`0087oo00<007ooOol06goo00<007ooOol047oo00<007ooOol0
5Goo0P000PWL00<0029N8Uh00b9N00<002jN;Yh01bjN00<003Jn=[h02SJn00<003kN?]h02SkN00<0
04KnA_h03DKn00<005<NDah035<N00<005llGc`02ell00<006mJKeX01fmJ00D007/dNcAk=00003=o
o`0087oo00<007ooOol06Woo00<007ooOol04Goo00<007ooOol05Woo0P000PWL00<0029N8Uh00b9N
00<002jN;Yh01bjN00<003Jn=[h02SJn00<003kN?]h02SkN00<004KnA_h03DKn00<005<NDah035<N
00<005llGc`02Ull00<006mJKeX026mJ00@007/dNc@003=oo`0087oo00<007ooOol06Woo00<007oo
Ool04Goo00<007ooOol05goo0P000PWL00<0029N8Uh00b9N00<002jN;Yh01bjN00<003Jn=[h02SJn
00<003kN?]h02SkN00<004KnA_h03DKn00<005<NDah035<N00<005llGc`02Ull00<006mJKeX01fmJ
00@007/dNc@003=oo`0087oo00<007ooOol06Goo00<007ooOol04Woo00<007ooOol067oo0P000PWL
00<0029N8Uh00b9N00<002jN;Yh012jN1@002cJn00<003kN?]h02SkN00<004KnA_h034Kn00<005<N
Dah035<N00<005llGc`02ell00<006mJKeX01fmJ0P00=7oo000POol00`00Oomoo`0HOol00`00Oomo
o`0COol00`00Oomoo`0IOol200022M`00`008UhRGP038Uh200000bjN000000020004=0060006=[h0
0`00?]hngP0:?]h00`00A_i6oP0<A_h00`00DaiC7P0<Dah00`00GcaO?00;Gc`00`00KeY_FP07KeX0
0`00Oomoo`0bOol0021oo`03001oogoo01Moo`03001oogoo01Aoo`03001oogoo01Yoo`800089g003
000RGR9N008RGPD000Ld0080009E:@<000@f_P03000ngSkN00/ngP030016oTKn00a6oP03001C7U<N
00aC7P03001O?5ll00]O?003001_FVmJ00E_FP03001oogoo03=oo`0087oo00<007ooOol05Woo00<0
07ooOol05Goo00<007ooOol06goo0P000PWL00<0029N00001P0013@00`001EDY00@005RP000000<f
_P03000ngSkN00/ngP030016oTKn00a6oP03001C7U<N00aC7P03001O?5ll00]O?003001_FVmJ00=_
FP03001oogoo03Aoo`0087oo00<007ooOol05Woo00<007ooOol057oo00<007ooOol07Goo0P000PWL
100000@hZ`00@>e0k@@000UE:@800003F:000000008f_P03000ngSkN00/ngP030016oTKn00a6oP03
001C7U<N00aC7P03001O?5ll00YO?003001_FVmJ009_FP03001oogoo03Eoo`007goo00<007ooOol0
5Woo00<007ooOol05Goo00<007ooOol07Woo1@000SR[00<0043]@>d00T3]00<004T^00002eDY00@0
05RPF:00008f_P03000ngSkN00/ngP030016oTKn00a6oP03001C7U<N00aC7P03001O?5ll00YO?005
001_FVmJKeX0000gOol001moo`03001oogoo01Eoo`03001oogoo01Ioo`03001oogoo01moo`<000<h
Z`050010kD3]@>d00003BBh00`00EBUE:@04EBT60002F:001000=[hf_P003CkN00<004KnA_h034Kn
00<005<NDah035<N00<005llGc`02Ull00<006mJ0000>7oo000OOol00`00Oomoo`0DOol00`00Oomo
o`0GOol00`00Oomoo`0NOol20002<8`01000>:/hZ`000T3]00<004T^BBh00TT^1`001F7_0`0000EH
X000000f_P0000dngP030016oTKn00a6oP03001C7U<N00aC7P03001O?5ll00YO?003001oogoo03Mo
o`007goo00<007ooOol04goo00<007ooOol067oo00<007ooOol07Woo00L0032<<8``S000>:/00002
@>d01000BBi9;TT^0P0000==L000HNl02F7_00<0079=LTd00P0000AHX000=[h000dngP030016oTKn
00a6oP03001C7U<N00]C7P03001O?5ll00QO?08003Yoo`007goo00<007ooOol04Woo00<007ooOol0
6Goo00<007ooOol07Goo00<0032<<8`00S2<00D003R[0010k@000099;P8000==L003001Qkf7_00QQ
k`03001bCG9=009bC@<00003=[h003kN00`ngP030016oTKn00a6oP03001C7U<N00]C7P03001O?5ll
00EO?08003aoo`007goo00<007ooOol04Woo00<007ooOol06Goo00<007ooOol077oo00@0032^0000
008`S005000hZ`000019;P020005CG000`00HNmQk`08HNl00`00LTebC@04LTd200000cJn000ngP0;
?]h00`00A_i6oP0<A_h00`00DaiC7P0<Dah00`00GcaO?002Gc`2000nOol001moo`03001oogoo015o
o`03001oogoo01Yoo`03001oogoo01]oo`8000<`[P800003<8`00000008000M=L003001Qkf7_00UQ
k`03001bCG9=00AbC@04000f_SJn000<?]h00`00A_i6oP0<A_h00`00DaiC7P0<Dah01000Gc`00000
@7oo000OOol00`00Oomoo`0@Ool00`00Oomoo`0KOol00`00Oomoo`0KOol00`00<:h`[P04<:h>000:
HNl00`00LTebC@04LTd20002=[h00`00?]hngP0:?]h00`00A_i6oP0<A_h00`00DaiC7P0;Dah20012
Ool001moo`03001oogoo00moo`03001oogoo01aoo`03001oogoo01Yoo`8000<`[PL000QA/P03001R
<`0000<000IQk`03001bCG9=00AbC@8000<f_P03000ngSkN00XngP030016oTKn00a6oP03001C7U<N
00IC7P@004Aoo`007goo00<007ooOol03Woo00<007ooOol07Goo00<007ooOol06Woo00<0032^0000
0P000SC`100000==/`0000001E6b00<0068cHS<0168c10000V7_00<0079=LTd0179=0P0013Jn00<0
03kN?]h02SkN00<004KnA_h034Kn00@005<NDaiC7P@004Qoo`007Woo00<007ooOol03goo00<007oo
Ool07Goo00<007ooOol06Goo0`0013C`00H003db000004Vc0002CK<20003DK800`00HS=R<`08HS<3
0006LTd20005=[h00`00?]hngP0:?]h00`00A_i6oP09A_h6001<Ool001ioo`03001oogoo00ioo`03
001oogoo01ioo`03001oogoo01Uoo`8000@dl007000m<P00AG<004Vc000014fc0`003F8c0`001G9=
0P001CJn00<003kN?]h02SkN00<004KnA_h00TKn1P00DWoo000NOol00`00Oomoo`0=Ool00`00Oomo
o`0OOol00`00Oomoo`0HOol30003=?001P00?C8m<P00AG<00099/`03001=/dfc00==/`03001R<f8c
00YR<`05001^eFkEK]D00004LTdI001HOol001ioo`03001oogoo00aoo`03001oogoo021oo`03001o
ogoo01Qoo`060000300<000dl0000Sdb00@004EcAG<00099/`03001=/dfc009=/`04001JEP00000:
HS<00`00K]E^e@02K]D20002LTd2001_Ool001ioo`03001oogoo00]oo`03001oogoo025oo`03001o
ogoo01Moo`800080308000<m<P040015LdEc0003BK<01000CK==/`0015YF00<0068cHS<01V8c00<0
06kEK]D01FkE1000Kgoo000NOol00`00Oomoo`0:Ool00`00Oomoo`0ROol00`00Oomoo`0GOol01@00
00`0300<00000cdb00D004EcAG=5L`0000=9/`03001=/`0000IJEP03001R<f8c00ER<`03001^eFkE
00M^e@8006moo`007Woo00<007ooOol02Woo00<007ooOol08Woo00<007ooOol05goo00@0000<OgD0
3080008m<P050015LdEcAG<00004BK<00`00FUIJEP06FUH20004HS<00`00K]E^e@08K]D2001_Ool0
01ioo`03001oogoo00Uoo`03001oogoo02=oo`03001oogoo01Moo`040000300<00028AD20004AG<0
0`00BK=9/`0200000e8g001JEP08FUH01@00HS=R<f8c00002FkE00@007nD000006ioo`007Woo00<0
07ooOol027oo00<007ooOol097oo00<007ooOol067oo00<0000<00000b4E0`000TEc0`000e8g00<0
05YFFUH025YF0`002VkE00@007nD000006ioo`007Woo00<007ooOol01goo00<007ooOol097oo00<0
07ooOol06Goo0P00124E00<0047h@OP00`001U8g00<005YFFUH02EYF00<006kEK]D01fkE00D007nD
OiAoU00006ioo`007Goo00<007ooOol01goo00<007ooOol09Goo00<007ooOol06Goo0P00124E00<0
047h@OP00T7h00<0058gDSL01E8g00<005YFFUH01eYF00<006Ki000026kE00D007nDOiAoU00006io
o`007Goo00<007ooOol01goo00<007ooOol09Goo00<007ooOol05goo1000124E00<0047h@OP00d7h
00<0058gDSL0158g00<005YFFUH01UYF00@006KiI_UVn@8000I^e@05001oU7nDOi@0001^Ool001eo
o`03001oogoo00Ioo`03001oogoo02Ioo`03001oogoo011oo`L0009K?@03000Q5B4E00<Q5@030011
n47h00=1n003001B=e8g00EB=`03001JEUYF00AJEP03001VnFKi00AVn@03001^eFkE009^e@05001o
U7nDOi@0001_Ool001eoo`03001oogoo00Eoo`03001oogoo02Moo`03001oogoo00Yoo`H000UK?@03
000Q5B4E00<Q5@030011n47h00=1n003001B=e8g00IB=`03001JEUYF009JEP03001VnFKi00IVn@05
001^eFkEK]D00003Oi@00`00Oomoo`1]Ool001eoo`03001oogoo00Aoo`03001oogoo02Qoo`03001o
ogoo00Aoo`H000mK?@8000<Q5@030011n47h00A1n003001B=e8g00MB=`04001JEUYF000:I_T30004
Oi@00`00Oomoo`1]Ool001eoo`03001oogoo00=oo`03001oogoo02Uoo`L001IK?@80008Q5@030011
n47h00E1n003001B=e8g00IB=`03001JEP0000eVn@05001oU7nDOi@0001`Ool001eoo`03001oogoo
00=oo`03001oogoo02Aoo`H001aK?@80008Q5@030011n47h00E1n003001B=e8g00IB=`8000eVn@03
001_^`00009oU003001oogoo06ioo`007Goo00<007ooOol00Woo00<007ooOol07goo1P008e/m0P00
00<Q5@00@OP01T7h00<0058gDSL0158g0P000UKK00<006KiI_T02FKi00@006nkKk/0009oU003001o
ogoo06ioo`007Goo00D007ooOomoo`0001aoo`8002eK?@040000M0000007@OP00`00DSMB=`02DSL2
0004E]/00`00I_UVn@08I_T00`00Kk]_^`02Kk/2001aOol001eoo`04001oogoo000GOol6000`Fcd0
0`0007@000040004@OP01000DSL000001eKK00<006KiI_T01VKi00<006nkKk/016nk00<007ooOol0
Kgoo000KOol20002Ool00`00Oomoo`0@Ool6000fFcd0100007@0M0000cIM1P002UKK00<006KiI_T0
16Ki00<006nkKk/016nk00<007ooOol0L7oo000KOol200000goo001oo`0<Ool6000mFcd00`0007@0
0008=Ud00`00E]]Ff`09E]/00`00I_UVn@02I_T00`00Kk]_^`04Kk/00`00Oomoo`1aOol001Yoo`D0
00Moo`H004AK?@030000M00000LfG@03001FfeKK00UFf`05001VnFKiI_T00006Kk/00`00Oomoo`1b
Ool001Yoo``004]K?@8000PfG@03001FfeKK00UFf`03001Vn@0000I_^`03001oogoo07=oo`006Goo
2000D5/m0`001cIM00<005KKE]/02EKK0P001fnk00<007ooOol0Lgoo000IOol:001=Fcd01000Oomo
o`0023IM00<005KKE]/01UKK0P000U>O0P0016nk00<007ooOol0M7oo000JOol:001;Fcd00`00Oomo
o`02Ool30006=Ud00`00E]]Ff`02E]/30006Dil200000fnk001oo`1fOol001aoo`T004UK?@03001o
ogoo00Eoo`H00004=Ud005KKE]/2000;Dil00`00Oomoo`1fOol001eoo`X004IK?@03001oogoo00Qo
o`<000030U/00000008000UCW`<007Yoo`007Woo2P00A5/m00<007ooOol037oo20000e>O0`00OGoo
000POol:0011Fcd00`00Oomoo`0BOol60020Ool0025oo`X003mK?@03001oogoo09Uoo`008Woo2P00
?E/m00<007ooOol0VWoo000TOol:000jFcd00`00Oomoo`2KOol002Eoo`X003QK?@03001oogoo09ao
o`009goo2@00=U/m00<007ooOol0WGoo000XOol:000cFcd00`00Oomoo`2NOol002Uoo`X0035K?@03
001oogoo09moo`00:goo2@00;e/m00<007ooOol0X7oo000/Ool:000/Fcd00`00Oomoo`2QOol002eo
o`X002YK?@03001oogoo0:9oo`00;goo2P009e/m00<007ooOol0Xgoo000`Ool:000UFcd00`00Oomo
o`2TOol0035oo`X002=K?@03001oogoo0:Eoo`00<goo2P0085/m00<007ooOol0YWoo000dOol:000N
Fcd00`00Oomoo`2WOol003Ioo`T001aK?@03001oogoo0:Qoo`00=goo2P006E/m00<007ooOol0ZGoo
000hOol:000GFcd00`00Oomoo`2ZOol003Yoo`T001EK?@03001oogoo0:]oo`00>goo2P004U/m00<0
07ooOol0[7oo000lOol:000@Fcd00`00Oomoo`2]Ool003ioo`X000eK?@03001oogoo0:ioo`00?goo
2P002e/m00<007ooOol0[goo0010Ool:0009Fcd00`00Oomoo`2`Ool0049oo`X000IK?@03001oogoo
0;5oo`00@goo2P0015/m00<007ooOol0/Woo0015Ool90002Fcd00`00Oomoo`2cOol004Ioo`X00;Io
o`00Agoo2P00]Goo0019Ool8002eOol004Yoo`H00;Ioo`00Bgoo1@00]Woo001=Ool2002gOol004io
o`03001oogoo0;Eoo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Mo
o`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003o
Ool7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Moo`00ogoo1goo003oOol7Ool00?moo`Mo
o`00ogoo1goo0000\
\>"],
  ImageRangeCache->{{{0, 261}, {286, 0}} -> {0.0315312, -0.0259655, 
  0.00358063, 0.00358063}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run again at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.20."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[.20] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.2`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 0\), ",", 
        \(Eo2 \[Rule] 0.809016994374947451`\), ",", \(Ei2 \[Rule] 0\), ",", 
        \(Ej2 \[Rule] \(-0.587785252292473181`\)\), ",", \(Ek2 \[Rule] 0\), 
        ",", \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 0\), ",", 
        \(Z3 \[Rule] 2.`\), ",", \(Eo3 \[Rule] 0.997726542119608694`\), ",", 
        \(Ei3 \[Rule] 0\), ",", \(Ej3 \[Rule] \(-0.0673924858574653118`\)\), 
        ",", \(Ek3 \[Rule] 0\), ",", \(alpha \[Rule] 0.359375583720747382`\), 
        ",", \(beta \[Rule] 1.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the cam-follower at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.20."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.21371 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0822276 1.16067 0.0290168 1.16067 [
[ 0 0 0 0 ]
[ 1 1.21371 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.21371 L
0 1.21371 L
closepath
clip
newpath
p
P
p
.004 w
.12138 .29274 m
.29743 .47808 L
s
P
p
.004 w
.57058 .1197 m
.72336 .32964 L
s
P
p
.004 w
.73396 .05677 m
.12138 .29274 L
s
P
p
.002 w
.50854 .50369 m .48335 .52182 L .36341 .38686 L p
.772 .764 .846 r
F P
s
P
p
.004 w
.51216 .54544 m
.58078 .64605 L
s
P
p
.004 w
.43379 .43055 m
.4534 .4593 L
s
P
p
.004 w
.49186 .51569 m
.51216 .54544 L
s
P
p
.004 w
.29743 .47808 m
.4097 .43895 L
s
P
p
.002 w
.48335 .52182 m .46059 .54312 L .33933 .40936 L p
.809 .769 .815 r
F P
s
P
p
.004 w
.75244 .3195 m
.87727 .276 L
s
P
p
.004 w
.42255 .43447 m
.75244 .3195 L
s
P
p
.002 w
.33933 .40936 m .36341 .38686 L .48335 .52182 L p
.809 .769 .815 r
F P
s
P
p
.002 w
.46059 .54312 m .44094 .56694 L .31838 .43435 L p
.843 .77 .781 r
F P
s
P
p
.002 w
.31838 .43435 m .33933 .40936 L .46059 .54312 L p
.843 .77 .781 r
F P
s
P
p
.002 w
.53541 .48928 m .50854 .50369 L .38989 .36751 L p
.73 .756 .873 r
F P
s
P
p
.002 w
.36341 .38686 m .38989 .36751 L .50854 .50369 L p
.772 .764 .846 r
F P
s
P
p
.004 w
.26473 .23752 m
.38299 .37255 L
s
P
p
.002 w
.44094 .56694 m .42502 .59258 L .3012 .46108 L p
.874 .766 .739 r
F P
s
P
p
.002 w
.3012 .46108 m .31838 .43435 L .44094 .56694 L p
.874 .766 .739 r
F P
s
P
p
.002 w
.56314 .47907 m .53541 .48928 L .41799 .35192 L p
.678 .741 .898 r
F P
s
P
p
.002 w
.38989 .36751 m .41799 .35192 L .53541 .48928 L p
.73 .756 .873 r
F P
s
P
p
.004 w
.87727 .276 m
.73396 .05677 L
s
P
p
.002 w
.42502 .59258 m .41334 .61926 L .28834 .48877 L p
.903 .756 .688 r
F P
s
P
p
.004 w
.2966 .49504 m
.29743 .47808 L
s
P
p
.002 w
.28834 .48877 m .3012 .46108 L .42502 .59258 L p
.903 .756 .688 r
F P
s
P
p
.002 w
.5909 .47341 m .56314 .47907 L .44687 .34059 L p
.613 .718 .92 r
F P
s
P
p
.004 w
.58078 .64605 m
.64913 .49437 L
s
P
p
.004 w
.64913 .49437 m
.72336 .32964 L
s
P
p
.002 w
.41799 .35192 m .44687 .34059 L .56314 .47907 L p
.678 .741 .898 r
F P
s
P
p
.002 w
.41334 .61926 m .40632 .64617 L .28026 .51656 L p
.93 .738 .621 r
F P
s
P
p
.004 w
.29499 .52793 m
.29649 .49727 L
s
P
p
.002 w
.28026 .51656 m .28834 .48877 L .41334 .61926 L p
.93 .738 .621 r
F P
s
P
p
.002 w
.6178 .47255 m .5909 .47341 L .47564 .33391 L p
.524 .68 .936 r
F P
s
P
p
.002 w
.44687 .34059 m .47564 .33391 L .5909 .47341 L p
.613 .718 .92 r
F P
s
P
p
.002 w
.40632 .64617 m .40424 .67246 L .27728 .54359 L p
.951 .703 .526 r
F P
s
P
p
.004 w
.29359 .55655 m
.29481 .53152 L
s
P
p
.002 w
.27728 .54359 m .28026 .51656 L .40632 .64617 L p
.951 .703 .526 r
F P
s
P
p
.002 w
.64298 .4766 m .6178 .47255 L .50342 .33216 L p
.395 .615 .939 r
F P
s
P
p
.002 w
.47564 .33391 m .50342 .33216 L .6178 .47255 L p
.524 .68 .936 r
F P
s
P
p
.002 w
.40424 .67246 m .40725 .69729 L .27958 .56898 L p
.956 .637 .382 r
F P
s
P
p
.004 w
.29246 .57967 m
.29342 .55998 L
s
P
p
.002 w
.27958 .56898 m .27728 .54359 L .40424 .67246 L p
.956 .637 .382 r
F P
s
P
p
.004 w
.34102 .35214 m
.4083 .45322 L
s
P
p
.004 w
.26473 .23752 m
.34102 .35214 L
s
P
p
.002 w
.66559 .48552 m .64298 .4766 L .5293 .33549 L p
.196 .498 .905 r
F P
s
P
p
.002 w
.50342 .33216 m .5293 .33549 L .64298 .4766 L p
.395 .615 .939 r
F P
s
P
p
.002 w
.40725 .69729 m .41573 .72087 L .28757 .59294 L p
.912 .509 .155 r
F P
s
P
p
.004 w
.29164 .59649 m
.29235 .58181 L
s
P
p
.002 w
.28757 .59294 m .27958 .56898 L .40725 .69729 L p
.912 .509 .155 r
F P
s
P
p
.004 w
.37155 .9072 m
.41865 .84841 L
s
P
p
.002 w
.68481 .49911 m .66559 .48552 L .55239 .34388 L p
0 .284 .779 r
F P
s
P
p
.002 w
.5293 .33549 m .55239 .34388 L .66559 .48552 L p
.196 .498 .905 r
F P
s
P
p
.002 w
.41573 .72087 m .43178 .74859 L .30323 .62098 L p
.809 .343 0 r
F P
s
P
p
.004 w
.46619 .78907 m
.58078 .64605 L
s
P
p
.004 w
.41865 .84841 m
.46619 .78907 L
s
P
p
.002 w
.30323 .62098 m .28757 .59294 L .41573 .72087 L p
.809 .343 0 r
F P
s
P
p
.002 w
.69992 .51702 m .68481 .49911 L .57188 .35719 L p
0 0 .484 r
F P
s
P
p
.002 w
.55239 .34388 m .57188 .35719 L .68481 .49911 L p
0 .284 .779 r
F P
s
P
p
.002 w
.43178 .74859 m .45526 .78007 L .32645 .6527 L p
.696 .203 0 r
F P
s
P
p
.002 w
.32645 .6527 m .30323 .62098 L .43178 .74859 L p
.696 .203 0 r
F P
s
P
p
.002 w
.57188 .35719 m .58702 .37505 L .69992 .51702 L p
0 0 .484 r
F P
s
P
p
.002 w
.7108 .53972 m .69992 .51702 L .58702 .37505 L p
.822 .389 0 r
F P
s
P
p
.025 w
.4083 .45322 m
.58078 .64605 L
s
P
p
.002 w
.50123 .9299 m .4604 .90251 L .49027 .87191 L p
.718 .583 .702 r
F P
s
P
p
.002 w
.4604 .90251 m .50123 .9299 L .49285 .95198 L p
.758 .559 .627 r
F P
s
P
p
.002 w
.42829 .87649 m .4604 .90251 L .44561 .94071 L p
.867 .689 .66 r
F P
s
P
p
.002 w
.49285 .95198 m .44561 .94071 L .4604 .90251 L p
.758 .559 .627 r
F P
s
P
p
.002 w
.44561 .94071 m .41085 .92084 L .42829 .87649 L p
.867 .689 .66 r
F P
s
P
p
.002 w
.41321 .85845 m .42829 .87649 L .41085 .92084 L p
.98 .867 .653 r
F P
s
P
p
.002 w
.41085 .92084 m .39783 .89726 L .41321 .85845 L p
.98 .867 .653 r
F P
s
P
p
.002 w
.06583 .87014 m .49498 .90866 L .27024 1.03365 L closepath p
.559 .747 .965 r
F P
s
P
p
.004 w
.27731 .88913 m
.29147 .59992 L
s
P
p
.004 w
.06583 .87014 m
.12138 .29274 L
s
P
p
.025 w
.06583 .87014 m
.27024 1.03365 L
s
P
p
.002 w
.71981 .57253 m .7108 .53972 L .59765 .39799 L p
.932 .558 .172 r
F P
s
P
p
.002 w
.58702 .37505 m .59765 .39799 L .7108 .53972 L p
.822 .389 0 r
F P
s
P
p
.002 w
.45526 .78007 m .48517 .81289 L .35631 .68567 L p
.572 .069 0 r
F P
s
P
p
.002 w
.35631 .68567 m .32645 .6527 L .45526 .78007 L p
.572 .069 0 r
F P
s
P
p
.004 w
.4083 .45322 m
.48624 .29304 L
s
P
p
.004 w
.48624 .29304 m
.57058 .1197 L
s
P
p
.002 w
.72675 .61499 m .71981 .57253 L .60608 .43139 L p
.962 .629 .295 r
F P
s
P
p
.002 w
.59765 .39799 m .60608 .43139 L .71981 .57253 L p
.932 .558 .172 r
F P
s
P
p
.002 w
.48517 .81289 m .51998 .84384 L .39136 .71663 L p
0 .079 .578 r
F P
s
P
p
.002 w
.39136 .71663 m .35631 .68567 L .48517 .81289 L p
0 .079 .578 r
F P
s
P
p
.002 w
.7306 .66454 m .72675 .61499 L .61211 .47482 L p
.973 .672 .379 r
F P
s
P
p
.002 w
.60608 .43139 m .61211 .47482 L .72675 .61499 L p
.962 .629 .295 r
F P
s
P
p
.002 w
.51998 .84384 m .52676 .8484 L p
.46657 .77855 L 0 .259 .739 r
F P
s
P
p
.002 w
.52676 .8484 m .55772 .86924 L .52395 .83564 L p
0 .259 .739 r
F P
s
P
p
.002 w
.52395 .83564 m .46657 .77855 L p
.52676 .8484 L 0 .259 .739 r
F P
s
P
p
.002 w
.55772 .86924 m .59607 .88538 L .54499 .83401 L p
.073 .466 .888 r
F P
s
P
p
.002 w
.59607 .88538 m .63258 .88921 L .5067 .76045 L p
.391 .659 .965 r
F P
s
P
p
.002 w
.5067 .76045 m .46892 .75748 L .59607 .88538 L p
.391 .659 .965 r
F P
s
P
p
.002 w
.56285 .86094 m .54856 .83025 L p
.57504 .85419 L 0 .2 .729 r
F P
s
P
p
.002 w
.54856 .83025 m .54735 .82765 L .54927 .82949 L p
0 .2 .729 r
F P
s
P
p
.002 w
.54927 .82949 m .57504 .85419 L p
.54856 .83025 L 0 .2 .729 r
F P
s
P
p
.002 w
.54499 .83401 m .53991 .82889 L p
.54306 .83604 L .073 .466 .888 r
F P
s
P
p
.54306 .83604 m .55772 .86924 L .54499 .83401 L .073 .466 .888 r
F
P
p
.002 w
.53991 .82889 m .529 .81792 L p
.52925 .8334 L .073 .466 .888 r
F P
s
P
p
.50484 .80268 m .52925 .8334 L .529 .81792 L .073 .466 .888 r
F
P
p
.52925 .8334 m .55772 .86924 L .53991 .82889 L .073 .466 .888 r
F
P
p
.44942 .76415 m .51998 .84384 L .46657 .77855 L 0 .259 .739 r
F
P
p
.002 w
.39136 .71663 m .51998 .84384 L p
.44942 .76415 L 0 .259 .739 r
F P
s
P
p
.002 w
.42966 .74183 m .39823 .72116 L p
.44942 .76415 L 0 .259 .739 r
F P
s
P
p
.002 w
.39823 .72116 m .39136 .71663 L p
.44942 .76415 L 0 .259 .739 r
F P
s
P
p
.002 w
.46892 .75748 m .42966 .74183 L .55772 .86924 L p
.073 .466 .888 r
F P
s
P
p
.002 w
.52759 .85669 m .50643 .82301 L .52154 .82472 L p
.461 .594 .898 r
F P
s
P
p
.002 w
.52154 .82472 m .5438 .82725 L p
.53771 .8383 L .461 .594 .898 r
F P
s
P
p
.52759 .85669 m .52154 .82472 L .53771 .8383 L .461 .594 .898 r
F
P
p
.002 w
.5438 .82725 m .54735 .82765 L p
.54647 .82894 L .461 .594 .898 r
F P
s
P
p
.52759 .85669 m .5438 .82725 L .54647 .82894 L .461 .594 .898 r
F
P
p
.002 w
.529 .81792 m .46892 .75748 L p
.50484 .80268 L .073 .466 .888 r
F P
s
P
p
.002 w
.5197 .81637 m .54506 .82672 L p
.52154 .82472 L .16 .642 .924 r
F P
s
P
p
.002 w
.54506 .82672 m .54735 .82765 L .5438 .82725 L p
.16 .642 .924 r
F P
s
P
p
.002 w
.5438 .82725 m .52154 .82472 L p
.54506 .82672 L .16 .642 .924 r
F P
s
P
p
.002 w
.5174 .81543 m .5197 .81637 L p
.50643 .82301 L .16 .642 .924 r
F P
s
P
p
.002 w
.52154 .82472 m .50643 .82301 L p
.5197 .81637 L .16 .642 .924 r
F P
s
P
p
.002 w
.56285 .86094 m .52759 .85669 L p
.53923 .83958 L .461 .594 .898 r
F P
s
P
p
.002 w
.54735 .82765 m .56168 .85843 L p
.53923 .83958 L .461 .594 .898 r
F P
s
P
p
.002 w
.56168 .85843 m .56285 .86094 L p
.53923 .83958 L .461 .594 .898 r
F P
s
P
p
.002 w
.46657 .77855 m .42966 .74183 L p
.44942 .76415 L 0 .259 .739 r
F P
s
P
p
.002 w
.73012 .7176 m .7306 .66454 L .61475 .52569 L p
.976 .707 .453 r
F P
s
P
p
.002 w
.61211 .47482 m .61475 .52569 L .7306 .66454 L p
.973 .672 .379 r
F P
s
P
p
.002 w
.72405 .76987 m .73012 .7176 L .61279 .58038 L p
.971 .74 .53 r
F P
s
P
p
.002 w
.61475 .52569 m .61279 .58038 L .73012 .7176 L p
.976 .707 .453 r
F P
s
P
p
.002 w
.71139 .81681 m .72405 .76987 L .60506 .63451 L p
.954 .772 .619 r
F P
s
P
p
.002 w
.61279 .58038 m .60506 .63451 L .72405 .76987 L p
.971 .74 .53 r
F P
s
P
p
.004 w
.28351 .60514 m
.4083 .45322 L
s
P
p
.004 w
.06583 .87014 m
.28351 .60514 L
s
P
p
.002 w
.69164 .8542 m .71139 .81681 L .5906 .68337 L p
.913 .8 .722 r
F P
s
P
p
.002 w
.60506 .63451 m .5906 .68337 L .71139 .81681 L p
.954 .772 .619 r
F P
s
P
p
.002 w
.63258 .88921 m .66503 .87888 L .54069 .74887 L p
.658 .776 .936 r
F P
s
P
p
.002 w
.54069 .74887 m .5067 .76045 L .63258 .88921 L p
.658 .776 .936 r
F P
s
P
p
.002 w
.49027 .87191 m .51845 .91223 L .50123 .9299 L p
.718 .583 .702 r
F P
s
P
p
.002 w
.52759 .85669 m .54003 .90355 L .51845 .91223 L p
.645 .563 .747 r
F P
s
P
p
.002 w
.51845 .91223 m .49027 .87191 L .52759 .85669 L p
.645 .563 .747 r
F P
s
P
p
.002 w
.51845 .91223 m .50123 .9299 L .5407 .95192 L closepath p
.623 .437 .609 r
F P
s
P
p
.002 w
.54003 .90355 m .51845 .91223 L .5407 .95192 L closepath p
.592 .425 .624 r
F P
s
P
p
.002 w
.46308 .84089 m .49027 .87191 L .4604 .90251 L p
.796 .719 .778 r
F P
s
P
p
.002 w
.50643 .82301 m .52759 .85669 L .49027 .87191 L p
.682 .699 .859 r
F P
s
P
p
.002 w
.49027 .87191 m .46308 .84089 L .50643 .82301 L p
.682 .699 .859 r
F P
s
P
p
.002 w
.50123 .9299 m .49285 .95198 L .5407 .95192 L closepath p
.637 .425 .578 r
F P
s
P
p
.002 w
.66503 .87888 m .69164 .8542 L .56904 .7226 L p
.826 .811 .837 r
F P
s
P
p
.002 w
.5906 .68337 m .56904 .7226 L .69164 .8542 L p
.913 .8 .722 r
F P
s
P
p
.002 w
.56904 .7226 m .54069 .74887 L .66503 .87888 L p
.826 .811 .837 r
F P
s
P
p
.002 w
.4604 .90251 m .42829 .87649 L .46308 .84089 L p
.796 .719 .778 r
F P
s
P
p
.002 w
.56285 .86094 m .56033 .90621 L .54003 .90355 L p
.526 .487 .755 r
F P
s
P
p
.002 w
.54003 .90355 m .52759 .85669 L .56285 .86094 L p
.526 .487 .755 r
F P
s
P
p
.002 w
.56033 .90621 m .54003 .90355 L .5407 .95192 L closepath p
.548 .39 .619 r
F P
s
P
p
.002 w
.44561 .94071 m .49285 .95198 L .49558 .97271 L p
.761 .482 .511 r
F P
s
P
p
.002 w
.49285 .95198 m .49558 .97271 L .5407 .95192 L closepath p
.63 .389 .534 r
F P
s
P
p
.002 w
.41085 .92084 m .44561 .94071 L .44997 .97674 L p
.893 .582 .451 r
F P
s
P
p
.002 w
.49558 .97271 m .44997 .97674 L .44561 .94071 L p
.761 .482 .511 r
F P
s
P
p
.002 w
.5867 .88398 m .57396 .91965 L .56033 .90621 L p
.327 .313 .69 r
F P
s
P
p
.002 w
.56033 .90621 m .56285 .86094 L .5867 .88398 L p
.327 .313 .69 r
F P
s
P
p
.002 w
.57396 .91965 m .56033 .90621 L .5407 .95192 L closepath p
.495 .332 .59 r
F P
s
P
p
.002 w
.57714 .9404 m .57396 .91965 L .5407 .95192 L closepath p
.445 .262 .537 r
F P
s
P
p
.002 w
.56885 .9629 m .57714 .9404 L .5407 .95192 L closepath p
.419 .201 .473 r
F P
s
P
p
.002 w
.55128 .98097 m .56885 .9629 L .5407 .95192 L closepath p
.432 .176 .424 r
F P
s
P
p
.002 w
.52926 .98962 m .55128 .98097 L .5407 .95192 L closepath p
.483 .202 .411 r
F P
s
P
p
.002 w
.50887 .98654 m .52926 .98962 L .5407 .95192 L closepath p
.547 .263 .436 r
F P
s
P
p
.002 w
.49558 .97271 m .50887 .98654 L .5407 .95192 L closepath p
.6 .333 .483 r
F P
s
P
p
.002 w
.44378 .82721 m .46308 .84089 L .42829 .87649 L p
.872 .907 .852 r
F P
s
P
p
.002 w
.48173 .81145 m .50643 .82301 L .46308 .84089 L p
.674 .884 .976 r
F P
s
P
p
.002 w
.46308 .84089 m .44378 .82721 L .48173 .81145 L p
.674 .884 .976 r
F P
s
P
p
.002 w
.44997 .97674 m .49558 .97271 L .50887 .98654 L p
.695 .316 .327 r
F P
s
P
p
.002 w
.42829 .87649 m .41321 .85845 L .44378 .82721 L p
.872 .907 .852 r
F P
s
P
p
.002 w
.57504 .85419 m .5867 .88398 L .56285 .86094 L p
0 .2 .729 r
F P
s
P
p
.002 w
.5924 .92009 m .57714 .9404 L .57396 .91965 L p
.011 0 .46 r
F P
s
P
p
.002 w
.57396 .91965 m .5867 .88398 L .5924 .92009 L p
.011 0 .46 r
F P
s
P
p
.002 w
.50643 .82301 m .48173 .81145 L .5174 .81543 L p
.16 .642 .924 r
F P
s
P
p
.002 w
.47277 1.001 m .50887 .98654 L .52926 .98962 L p
.474 0 .036 r
F P
s
P
p
.002 w
.50887 .98654 m .47277 1.001 L .44997 .97674 L p
.695 .316 .327 r
F P
s
P
p
.002 w
.41557 .96268 m .44997 .97674 L .47277 1.001 L p
.743 .226 0 r
F P
s
P
p
.002 w
.44997 .97674 m .41557 .96268 L .41085 .92084 L p
.893 .582 .451 r
F P
s
P
p
.002 w
.39783 .89726 m .41085 .92084 L .41557 .96268 L p
.942 .647 .191 r
F P
s
P
p
.002 w
.5779 .95958 m .56885 .9629 L .57714 .9404 L p
0 0 .031 r
F P
s
P
p
.002 w
.57714 .9404 m .5924 .92009 L .5779 .95958 L p
0 0 .031 r
F P
s
P
p
.002 w
.50831 1.00653 m .52926 .98962 L .55128 .98097 L p
.048 0 0 r
F P
s
P
p
.002 w
.52926 .98962 m .50831 1.00653 L .47277 1.001 L p
.474 0 .036 r
F P
s
P
p
.002 w
.54698 .99139 m .55128 .98097 L .56885 .9629 L p
0 0 0 r
F P
s
P
p
.002 w
.56885 .9629 m .5779 .95958 L .54698 .99139 L p
0 0 0 r
F P
s
P
p
.002 w
.55128 .98097 m .54698 .99139 L .50831 1.00653 L p
.048 0 0 r
F P
s
P
p
.002 w
.43771 .83511 m .44378 .82721 L .41321 .85845 L p
0 0 0 r
F P
s
P
p
.002 w
.45993 .82591 m .48173 .81145 L .44378 .82721 L p
0 0 0 r
F P
s
P
p
.002 w
.44378 .82721 m .43771 .83511 L .45993 .82591 L p
0 0 0 r
F P
s
P
p
.002 w
.58158 .89612 m .5924 .92009 L .5867 .88398 L p
.886 .592 .08 r
F P
s
P
p
.002 w
.5867 .88398 m .57504 .85419 L .58158 .89612 L p
.886 .592 .08 r
F P
s
P
p
.002 w
.54134 .83853 m .57504 .85419 L .54735 .82765 L p
.694 .151 0 r
F P
s
P
p
.002 w
.54735 .82765 m .5174 .81543 L .54134 .83853 L p
.694 .151 0 r
F P
s
P
p
.002 w
.41978 .85345 m .41321 .85845 L .39783 .89726 L p
0 0 0 r
F P
s
P
p
.002 w
.41321 .85845 m .41978 .85345 L .43771 .83511 L p
0 0 0 r
F P
s
P
p
.002 w
.47277 1.001 m .44183 .99087 L .41557 .96268 L p
.743 .226 0 r
F P
s
P
p
.002 w
.44183 .99087 m .47277 1.001 L .50831 1.00653 L p
.04 .577 .852 r
F P
s
P
p
.002 w
.41557 .96268 m .40184 .93372 L .39783 .89726 L p
.942 .647 .191 r
F P
s
P
p
.002 w
.40184 .93372 m .41557 .96268 L .44183 .99087 L p
0 .117 .668 r
F P
s
P
p
.002 w
.48064 .82829 m .5174 .81543 L .48173 .81145 L p
.419 0 0 r
F P
s
P
p
.002 w
.48173 .81145 m .45993 .82591 L .48064 .82829 L p
.419 0 0 r
F P
s
P
p
.002 w
.4108 .87614 m .39783 .89726 L .40184 .93372 L p
0 0 .399 r
F P
s
P
p
.002 w
.39783 .89726 m .4108 .87614 L .41978 .85345 L p
0 0 0 r
F P
s
P
p
.002 w
.56453 .94222 m .5779 .95958 L .5924 .92009 L p
.988 .88 .627 r
F P
s
P
p
.002 w
.5924 .92009 m .58158 .89612 L .56453 .94222 L p
.988 .88 .627 r
F P
s
P
p
.002 w
.48314 .99725 m .50831 1.00653 L .54698 .99139 L p
.649 .899 .983 r
F P
s
P
p
.002 w
.50831 1.00653 m .48314 .99725 L .44183 .99087 L p
.04 .577 .852 r
F P
s
P
p
.002 w
.54675 .87505 m .58158 .89612 L .57504 .85419 L p
.902 .576 .419 r
F P
s
P
p
.002 w
.57504 .85419 m .54134 .83853 L .54675 .87505 L p
.902 .576 .419 r
F P
s
P
p
.002 w
.49434 .8418 m .54134 .83853 L .5174 .81543 L p
.685 .286 .284 r
F P
s
P
p
.002 w
.5174 .81543 m .48064 .82829 L .49434 .8418 L p
.685 .286 .284 r
F P
s
P
p
.002 w
.5283 .97946 m .54698 .99139 L .5779 .95958 L p
.876 .93 .854 r
F P
s
P
p
.002 w
.5779 .95958 m .56453 .94222 L .5283 .97946 L p
.876 .93 .854 r
F P
s
P
p
.002 w
.42468 .95809 m .44183 .99087 L .48314 .99725 L p
.428 .588 .908 r
F P
s
P
p
.002 w
.44183 .99087 m .42468 .95809 L .40184 .93372 L p
0 .117 .668 r
F P
s
P
p
.002 w
.41321 .89729 m .40184 .93372 L .42468 .95809 L p
.282 .28 .68 r
F P
s
P
p
.002 w
.40184 .93372 m .41321 .89729 L .4108 .87614 L p
0 0 .399 r
F P
s
P
p
.002 w
.54698 .99139 m .5283 .97946 L .48314 .99725 L p
.649 .899 .983 r
F P
s
P
p
.002 w
.41978 .85345 m .44716 .86342 L .43771 .83511 L closepath p
.4 .133 .39 r
F P
s
P
p
.002 w
.43771 .83511 m .44716 .86342 L .45993 .82591 L closepath p
.456 .163 .378 r
F P
s
P
p
.002 w
.4108 .87614 m .44716 .86342 L .41978 .85345 L closepath p
.386 .161 .445 r
F P
s
P
p
.002 w
.45993 .82591 m .44716 .86342 L .48064 .82829 L closepath p
.529 .233 .409 r
F P
s
P
p
.002 w
.41321 .89729 m .44716 .86342 L .4108 .87614 L closepath p
.418 .231 .518 r
F P
s
P
p
.002 w
.53165 .91519 m .56453 .94222 L .58158 .89612 L p
.877 .696 .655 r
F P
s
P
p
.002 w
.58158 .89612 m .54675 .87505 L .53165 .91519 L p
.877 .696 .655 r
F P
s
P
p
.002 w
.49723 .86297 m .54675 .87505 L .54134 .83853 L p
.763 .474 .495 r
F P
s
P
p
.002 w
.54134 .83853 m .49434 .8418 L .49723 .86297 L p
.763 .474 .495 r
F P
s
P
p
.002 w
.48064 .82829 m .44716 .86342 L .49434 .8418 L closepath p
.589 .311 .463 r
F P
s
P
p
.002 w
.46063 .96339 m .48314 .99725 L .5283 .97946 L p
.678 .706 .869 r
F P
s
P
p
.002 w
.48314 .99725 m .46063 .96339 L .42468 .95809 L p
.428 .588 .908 r
F P
s
P
p
.002 w
.42653 .91122 m .44716 .86342 L .41321 .89729 L closepath p
.475 .311 .578 r
F P
s
P
p
.002 w
.42468 .95809 m .42653 .91122 L .41321 .89729 L p
.282 .28 .68 r
F P
s
P
p
.002 w
.42653 .91122 m .42468 .95809 L .46063 .96339 L p
.51 .478 .757 r
F P
s
P
p
.002 w
.49998 .9477 m .5283 .97946 L .56453 .94222 L p
.802 .728 .783 r
F P
s
P
p
.002 w
.56453 .94222 m .53165 .91519 L .49998 .9477 L p
.802 .728 .783 r
F P
s
P
p
.002 w
.49434 .8418 m .44716 .86342 L .49723 .86297 L closepath p
.623 .374 .52 r
F P
s
P
p
.002 w
.5283 .97946 m .49998 .9477 L .46063 .96339 L p
.678 .706 .869 r
F P
s
P
p
.002 w
.49723 .86297 m .44716 .86342 L .48834 .88611 L closepath p
.631 .413 .568 r
F P
s
P
p
.002 w
.48834 .88611 m .44716 .86342 L .47003 .90487 L closepath p
.617 .427 .602 r
F P
s
P
p
.002 w
.47003 .90487 m .44716 .86342 L .44734 .91406 L closepath p
.583 .414 .618 r
F P
s
P
p
.002 w
.44734 .91406 m .44716 .86342 L .42653 .91122 L closepath p
.534 .375 .611 r
F P
s
P
p
.002 w
.46063 .96339 m .44734 .91406 L .42653 .91122 L p
.51 .478 .757 r
F P
s
P
p
.002 w
.48834 .88611 m .53165 .91519 L .54675 .87505 L p
.761 .558 .622 r
F P
s
P
p
.002 w
.54675 .87505 m .49723 .86297 L .48834 .88611 L p
.761 .558 .622 r
F P
s
P
p
.002 w
.44734 .91406 m .46063 .96339 L .49998 .9477 L p
.641 .561 .749 r
F P
s
P
p
.002 w
.49998 .9477 m .47003 .90487 L .44734 .91406 L p
.641 .561 .749 r
F P
s
P
p
.002 w
.47003 .90487 m .49998 .9477 L .53165 .91519 L p
.719 .583 .702 r
F P
s
P
p
.002 w
.53165 .91519 m .48834 .88611 L .47003 .90487 L p
.719 .583 .702 r
F P
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{233, 283},
  ImageMargins->{{34, Inherited}, {Inherited, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Y00016a000`40O003h00OjGoo003YOol00>Uo
o`00jGoo003YOol00>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol00:Uo
o`8003ioo`00Ygoo0P000Woo00<007ooOol0>goo002TOol30004Ool00`00Oomoo`0kOol00:5oo`<0
00Qoo`03001oogoo03Yoo`00Wgoo0P0037oo00<007ooOol0>Goo002LOol3000>Ool00`00Oomoo`0i
Ool009Yoo`80019oo`03001oogoo03Qoo`00Ugoo0`005Goo00<007ooOol0=goo002EOol2000HOol0
0`00Oomoo`0gOol0099oo`<001]oo`03001oogoo03Ioo`00Sgoo0`007Woo00<007ooOol0=Woo002=
Ool2000ROol00`00Oomoo`0eOol008Yoo`<002Eoo`03001oogoo03Aoo`00R7oo0P00:7oo00<007oo
Ool0=7oo0024Ool4000[Ool00`00Oomoo`0cOol0089oo`@002ioo`03001oogoo039oo`00P7oo0P00
00Aoo`00Ool002ioo`03001oogoo039oo`00OGoo0`000goo00@007ooOol002ioo`03001oogoo035o
o`00Ngoo0P001Goo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol0<7oo001hOol30007Ool0
0`00Oomoo`03Ool00`00Oomoo`0[Ool00`00Oomoo`0`Ool007Ioo`8000Uoo`03001oogoo00Aoo`03
001oogoo02aoo`03001oogoo02moo`00Lgoo0`002goo00<007ooOol01Goo00<007ooOol0;7oo00<0
07ooOol0;Woo001`Ool3000=Ool00`00Oomoo`07Ool00`00Oomoo`0[Ool00`00Oomoo`0^Ool006io
o`80011oo`03001oogoo00Moo`03001oogoo02aoo`03001oogoo02eoo`00Jgoo0`004Goo00<007oo
Ool02Goo00<007ooOol0;7oo00<007ooOol0;7oo001YOol2000DOol00`00Oomoo`0:Ool00`00Oomo
o`0[Ool00`00Oomoo`0/Ool006Ioo`<001Eoo`03001oogoo00aoo`03001oogoo02]oo`03001oogoo
02]oo`00I7oo0P0067oo00<007ooOol037oo00<007ooOol0:goo00<007ooOol0:goo001QOol3000I
Ool00`00Oomoo`0>Ool00`00Oomoo`0[Ool00`00Oomoo`0ZOol005ioo`<001aoo`03001oogoo00mo
o`03001oogoo02]oo`03001oogoo02Uoo`00G7oo0P007Woo00<007ooOol047oo00<007ooOol0:goo
00<007ooOol0:Goo001IOol3000POol00`00Oomoo`0AOol00`00Oomoo`0[Ool00`00Oomoo`0XOol0
05Moo`80029oo`03001oogoo01=oo`03001oogoo02]oo`03001oogoo02Moo`00E7oo0`0097oo00<0
07ooOol057oo00<007ooOol0:Woo00<007ooOol09goo001AOol3000VOol00`00Oomoo`0EOol00`00
Oomoo`0[Ool00`00Oomoo`0VOol004moo`8002Uoo`03001oogoo01Ioo`03001oogoo02]oo`03001o
ogoo02Eoo`00C7oo0`00:Woo00<007ooOol067oo00<007ooOol0:Woo00<007ooOol09Goo001:Ool2
000]Ool00`00Oomoo`0HOol00`00Oomoo`0[Ool00`00Oomoo`0TOol004Moo`<002ioo`03001oogoo
01Yoo`03001oogoo02]oo`03001oogoo02=oo`00AGoo0P00<Goo00<007ooOol06goo00<007ooOol0
:Woo00<007ooOol08goo0012Ool3000bOol00`00Oomoo`0MOol00`00Oomoo`0ZOol00`00Oomoo`0R
Ool003moo`<003Eoo`03001oogoo01eoo`03001oogoo02]oo`03001oogoo025oo`00?Goo0P00=goo
00<007ooOol07goo00<007ooOol0:Woo00<007ooOol08Goo000jOol300000goo001oo`0fOol00`00
Oomoo`0POol00`00Oomoo`0ZOol00`00Oomoo`0POol003Qoo`8000Aoo`8003Eoo`03001oogoo025o
o`03001oogoo02Yoo`03001oogoo021oo`00=Goo0`001goo0P00=7oo00<007ooOol08Woo00<007oo
Ool0:Woo00<007ooOol07goo000bOol3000;Ool00`00Oomoo`0aOol00`00Oomoo`0TOol00`00Oomo
o`0ZOol00`00Oomoo`0NOol0031oo`8000ioo`80039oo`03001oogoo02Eoo`03001oogoo02Uoo`03
001oogoo01ioo`00;Goo0`004Goo0P00<7oo00<007ooOol09Woo00<007ooOol0:Woo00<007ooOol0
7Goo000[Ool2000EOol2000_Ool00`00Oomoo`0WOol00`00Oomoo`0ZOol00`00Oomoo`0LOol002Qo
o`<001Qoo`8002eoo`03001oogoo02Uoo`03001oogoo02Uoo`03001oogoo01aoo`009Woo0P006goo
00<007oo0000;7oo00<007ooOol0:Goo00<007ooOol0:Goo0P007Goo000SOol3000NOol00`00Ool0
000ZOol00`00Oomoo`0[Ool00`00Oomoo`0UOol3000OOol0021oo`<0029oo`03001oo`0002Uoo`03
001oogoo02aoo`03001oogoo025oo`<0029oo`007Woo0P009Goo00<007oo0000:7oo00<007ooOol0
;Woo00<007ooOol07Goo0`009Goo000LOol2000XOol00`00Ool0000WOol00`00Oomoo`0^Ool00`00
Oomoo`0JOol3000XOol001aoo`8002Uoo`03001oo`0002Ioo`03001oogoo02moo`03001oogoo01Mo
o`8002]oo`0077oo00<007oo0000:7oo00@007ooOol002Aoo`03001oogoo035oo`03001oogoo01=o
o`<002eoo`0077oo00@007ooOol002Qoo`04001oogoo000SOol00`00Oomoo`0aOol00`00Oomoo`0@
Ool3000`Ool001aoo`05001oogooOol0000XOol01000Oomoo`008Goo00<007ooOol0<goo00<007oo
Ool037oo0`00<goo000LOol00`00Oomoo`02Ool00`00Oomoo`0UOol01@00Oomoogoo000087oo00<0
07ooOol0=7oo00<007ooOol027oo0`00=Woo000KOol00`00Oomoo`04Ool00`00Oomoo`0UOol01@00
Oomoogoo00007Woo00<007ooOol0=Woo00<007ooOol017oo0`00>Goo000KOol00`00Oomoo`05Ool0
0`00Oomoo`0UOol01000Oomoo`007Woo00<007ooOol0=Woo00@007ooOomoo`<003aoo`006goo00<0
07ooOol01Woo00<007ooOol09Goo00@007ooOol001aoo`03001oogoo03Qoo`<003moo`006goo00<0
07ooOol01goo00<007ooOol097oo00D007ooOomoo`0001]oo`/002ioo`<0045oo`006goo00<007oo
Ool027oo00<007ooOol097oo00D007ooOomoo`0001Moo`@0009>g@030012_D:m00=2_@8bOPH002Eo
o`<00003Ool007oo045oo`006goo00<007ooOol027oo00<007ooOol09Goo00D007ooOomoo`0001=o
o`<0009>g@03001>gDkM009>g@030012_D:m00=2_@DbOP8Io0@001ioo`<000Aoo`03001oogoo041o
o`006goo00<007ooOol02Goo00<007ooOol097oo00<007ooOol00Woo00<007ooOol037oo10000UKl
00<004kM00001DkM00<004:m@[d014:m1C9n1AWl00<007ooOol067oo0`001Woo00<007ooOol0@Goo
000KOol00`00Oomoo`0:Ool00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`09Ool20007E_`2
0006C]d00`00@[e2_@03@[d00`00<WhbOP03<Wh56O`00`00Oomoo`0DOol30009Ool00`00Oomoo`11
Ool001]oo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo00Ioo`800003
Ga/005Kl00IFo08000M>g@030012_D:m00=2_@03000bOS9n008bOP03000Io1Wl008Io08001=oo`80
00]oo`03001oogoo049oo`006goo00<007ooOol037oo00<007ooOol08goo00<007ooOol00Woo00<0
07ooOol01Goo00<005lKGa/00UlK00<005KlE_`015Kl0P0024kM00<004:m@[d00d:m00<0039n<Wh0
0S9n00<001Wl6O`00QWl0P003goo0`003Goo00<007ooOol0@Woo000JOol00`00Oomoo`0>Ool00`00
Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`02Ool20006Ga/00`00E_aFo002E_`01000E_aFo000
24kM00<004:m@[d00d:m00<0039n<Wh00S9n00<001Wl6O`00QWl0P002goo0`003goo00<007ooOol0
@goo000JOol00`00Oomoo`0?Ool00`00Oomoo`0ROol00`00Oomoo`03Ool01000Oomoo`0025lK00<0
05KlE_`00UKl00D005KlE_aFo00000Q>g@030012_D:m00=2_@03000bOS9n008bOP03000Io1Wl008I
o0030CP007oo00Ioo`<0019oo`03001oogoo04=oo`006Woo00<007ooOol047oo00<007ooOol08Woo
00<007ooOol00goo0P0000=S6`00Ga/01elK00@005KlE_`000EFo003001>gDkM00E>g@030012_D:m
00A2_@03000bOS9n008bOP03000Io1Wl008Io08000=oo`<001Eoo`03001oogoo04=oo`006Woo00<0
07ooOol04Goo00<007ooOol08Woo00D007ooOomoo`0000AS6`03001O6elK00IO6`03001Fo00000IF
o003001>gDkM00E>g@030012_D:m00=2_@03000bOS9n00<bOP04000Io1Wl6O`5000GOol00`00Oomo
o`14Ool001Yoo`03001oogoo019oo`03001oogoo025oo`04001oo`000006Ha/00`00Ga]O6`06Ga/0
0`00E_aFo006E_`00`00C]e>g@05C]d00`00@[e2_@03@[d00`00<WhbOP02<Wh00`006O`Io0026O`3
000HOol00`00Oomoo`14Ool001Yoo`03001oogoo01=oo`03001oogoo025oo`03001S6f<K00IS6`03
001O6elK00IO6`8000MFo003001>gDkM00I>g@030012_D:m00=2_@03000bOS9n008bOP03000Io1Wl
008Io0<001Ioo`03001oogoo04Eoo`006Woo00<007ooOol057oo00<007ooOol07goo00<006LJ0000
26<K00<005lKGa/015lK00@005lKGa/000MFo003001>gDkM00I>g@030012_D:m00=2_@03000bOS9n
008bOP03000Io1Wl008Io003001YP7oo01Eoo`03001oogoo04Eoo`006Woo00<007ooOol05Goo00<0
07ooOol07Goo00<006LJIaX00P0026<K00<005lKGa/00elK00D005lKGa]O6`0000MFo003001>gDkM
00E>g@030012_D:m00A2_@03000bOS9n008bOP04000Io1Wl6O`3000DOol00`00Oomoo`16Ool001Yo
o`03001oogoo01Ioo`03001oogoo01]oo`03001W6VLJ009W6P8000QS6`05001O6elKGa/00005Ga/0
0`00E_aFo005E_`00`00C]e>g@05C]d00`00@[e2_@04@[d00`00<WhbOP02<Wh01`006O`Io1Wl001Y
P00001=oo`03001oogoo04Ioo`006Woo00<007ooOol05goo00<007ooOol06Goo00<006LJIaX00fLJ
0P002F<K00@005lKGa/000EO6`03001Fo5Kl00IFo003001>gDkM00E>g@030012_D:m00=2_@03000b
OS9n00<bOP03000Io1Wl00800003JH0007oo011oo`03001oogoo04Moo`006Goo00<007ooOol06Goo
00<007ooOol05goo00<006LJIaX01FLJ0P002F<K0P001elK00<005KlE_`01UKl00<004kMC]d01DkM
00<004:m@[d00d:m00<0039n<Wh00S9n00P001Wl6O`007HU001YP00047oo00<007ooOol0Agoo000I
Ool00`00Oomoo`0JOol00`00Oomoo`0EOol00`00IaYW6P07IaX20008Ha/20008Ga/00`00E_aFo005
E_`00`00C]e>g@06C]d00`00@[e2_@03@[d00`00<WhbOP02<Wh01`006O`Io000MREYP00000moo`03
001oogoo04Qoo`006Goo00<007ooOol06goo00<007ooOol04goo00<006/H000026LJ00<006LJ0000
1f<K0P002ElK00<005KlE_`01EKl00<004kMC]d01TkM00<004:m@[d00d:m00<0039n<Wh00S9n00L0
01Wl001f9@00JH00000>Ool00`00Oomoo`18Ool001Uoo`03001oogoo01aoo`03001oogoo015oo`05
001[66/HJaP00008IaX00`00IaX00006Ha/00`00Ha/00009Ga/00`00E_aFo005E_`00`00C]e>g@05
C]d00`00@[e2_@04@[d00`00<WhbOP02<Wh20002MRD00`00JH00000=Ool00`00Oomoo`18Ool001Uo
o`03001oogoo01eoo`03001oogoo00moo`03001[66/H00=[6003001W6VLJ00IW6P03001W6P0000AS
6`05001S6f<KHa/00009Ga/00`00E_aFo005E_`00`00C]e>g@05C]d00`00@[e2_@04@[d00`00<Whb
OP02<Wh01`00MREf9GHU001YP00000]oo`03001oogoo04Uoo`006Goo00<007ooOol07Woo00<007oo
Ool03Goo00<006/HJaP01F/H00<006LJIaX01FLJ00@006LJIaX000=S6`03001S6f<K009S6`03001O
6elK00MO6`03001Fo5Kl00EFo003001>gDkM00E>g@030012_D:m00A2_@03000bOS9n008bOP04001f
9GHUMRD2000;Ool00`00Oomoo`19Ool001Uoo`03001oogoo01moo`03001oogoo00]oo`03001[66/H
00M[6003001W6VLJ00EW6P06001W6VLJ001S6`001V<K00<005lKGa/01elK00<005KlE_`01EKl00<0
04kMC]d01DkM00<004:m@[d00d:m00<0039n<Wh00S9n00L007HUMREf9@00JH000009Ool00`00Oomo
o`1:Ool001Uoo`03001oogoo01moo`03001oogoo00Yoo`03001_5`0000Q[6003001W6VLJ00EW6P08
001W6VLJ001S6`00Ha/000AS6`03001O6elK00MO6`03001Fo5Kl00IFo003001>gDkM00E>g@030012
_D:m00=2_@04000bOS9n<Wh20003MRD00`00JH000008Ool00`00Oomoo`1:Ool001Uoo`03001oogoo
021oo`03001oogoo00Uoo`04001_5flG0008JaP00`00IaYW6P05IaX01000IaX0000026<K00<005lK
Ga/01elK00<005KlE_`01EKl00<004kMC]d01DkM00<004:m@[d014:m00H0039n<Wh007Z90003MRD0
0`00JH000006Ool00`00Oomoo`1;Ool001Uoo`03001oogoo025oo`03001oogoo00Moo`03001_5flG
009_5`03001[66/H00I[6003001W6VLJ00EW6P@000QS6`03001O6elK00MO6`03001Fo5Kl00EFo003
001>gDkM00E>g@030012_D:m00A2_@03000bOS9n008000Af9@03001YP00000Eoo`03001oogoo04]o
o`006Goo00<007ooOol08Woo00<007ooOol01Woo00<006lGKaL00flG00<006/HJaP01V/H00<006LJ
IaX00fLJ1P0026<K00<005lKGa/01elK00<005KlE_`01EKl00<004kMC]d01DkM00<004:m@[d014:m
00D0039n001jR@0000=f9@03001YP00000Aoo`03001oogoo04aoo`0067oo00<007ooOol097oo00<0
07ooOol017oo00<006lGKaL01FlG00<006/HJaP01V/H00@006LJIaYW6PP000QS6`03001O6elK00MO
6`03001Fo5Kl00EFo003001>gDkM00E>g@030012_D:m00A2_@80009jR@07001f9GHUMRD006V00000
0goo00<007ooOol0C7oo000HOol00`00Oomoo`0UOol00`00Oomoo`03Ool00`00KaM_5`06KaL00`00
JaQ[6006JaP01000IaYW6VLJ200026<K00<005lKGa/01elK00<005KlE_`01EKl00<004kMC]d01DkM
00<004:m@[d00d:m0P000gZ900L007HUMREf9@00JH000002Ool00`00Oomoo`1<Ool001Qoo`03001o
ogoo02Ioo`05001oogooOol0000:KaL00`00JaQ[6006JaP00`00IaYW6P090008Ha/00`00Ga]O6`07
Ga/00`00E_aFo005E_`00`00C]e>g@05C]d00`00@[e2_@03@[d00`00NXUjR@02NXT01P00MREf9GHU
001YP08004moo`0067oo00<007ooOol09goo00D007oo001c5P0000U_5`03001[66/H00M[6004001W
6P00IaX600000fLJ001S6`06Ha/00`00Ga]O6`08Ga/00`00E_aFo004E_`00`00C]e>g@05C]d00`00
@[e2_@04@[d01@00NXUjRGZ9000017HU00<006V00000Cgoo000HOol00`00Oomoo`0XOol20002LaH0
0`00KaM_5`07KaL00`00JaQ[6007JaP01000IaYW6VLJ1`0026<K00<005lKGa/01elK00<005KlE_`0
1EKl00<004kMC]d01DkM00<004:m@[d00T:m0P0017Z900L007HUMREf9@00JH00001?Ool001Qoo`03
001oogoo02Qoo`03001c5W<F009c5P03001_5flG00M_5`03001[66/H00E[6003001[600000=W6PL0
00QS6`03001O6elK00MO6`03001Fo5Kl00EFo003001>gDkM009>g@L00003Ool007Z900AjR@07001f
9GHUMRD006V00000CWoo000HOol00`00Oomoo`0XOol00`00LaIc5P03LaH00`00KaM_5`07KaL00`00
JaQ[6003JaP01000JaQ[60000fLJ200026<K00<005lKGa/01elK00<005KlE_`015Kl1@0027oo0P00
1GZ900L007HUMREf9@00JH00001=Ool001Qoo`03001oogoo02Moo`03001c5W<F00Ec5P03001_5flG
00M_5`05001[66/HJaP00004JaP01000IaYW6VLJ200026<K00<005lKGa/01elK00<005KlE_`00`00
3Goo00<007j/000017Z900<007HUMRD00WHU00<006V00000C7oo000HOol00`00Oomoo`0WOol00`00
LaIc5P06LaH00`00KaM_5`07KaL00`00JaP00006JaP01000IaYW6VLJ200026<K00<005lKGa/01elK
0P0047oo00<007j/00001GZ900<007HUMRD00WHU0P00C7oo000HOol00`00Oomoo`0WOol20008LaH0
0`00KaM_5`07KaL20007JaP01000IaYW6VLJ20001f<K00<005lKGa/01ElK0P004Woo00@007j/OZ`0
00EjR@07001f9GHUMRD006V00000Bgoo000GOol00`00Oomoo`0XOol00`00M_<00008LaH00`00KaM_
5`06KaL20008JaP01000IaYW6VLJ20001f<K00<005lKGa/00UlK0P0057oo00D007j/OZan[00000Ej
R@07001f9GHUMRD006V00000BWoo000GOol00`00Oomoo`0XOol01000M_=fl`0027<F00<006lGKaL0
16lG00@006lGKaL000Q[6004001W6VLJIaX80007Ha/01000Ga/000005Woo00<007j/OZ`00Wj/00<0
07Z9NXT00gZ900L007HUMREf9@00JH000019Ool001Moo`03001oogoo02Moo`03001flgKc009fl`03
001c5W<F00Ic5P03001_5flG009_5`03001_5flG009_5`03001[66/H00I[6004001W6VLJIaX70008
Ha/00`00Oomoo`0FOol00`00OZan[003OZ`00`00NXUjR@02NXT00`00MREf9@02MRD00`00JH000018
Ool001Moo`03001oogoo02Moo`03001flgKc00=fl`03001c5W<F00Ic5P04001_5flG0006KaL00`00
JaQ[6006JaP01000IaYW6VLJ1`001V<K00<007ooOol05goo00<007j/OZ`00gj/00<007Z9NXT00gZ9
00L007HUMREf9@00JH000018Ool001Moo`03001oogoo02Moo`03001flgKc00Afl`03001c5W<F00Ic
5P8000Q_5`03001[66/H00I[6004001W6VLJIaX70003Ha/2000JOol00`00OZan[004OZ`00`00NXUj
R@03NXT01`00MREf9GHU001YP00004Moo`005goo00<007ooOol09goo00<007KcM_<01GKc00<007<F
LaH01W<F00<006lGKaL01flG00<006/HJaP01V/H00<006LJIaX0200000AS6`00Ool001Yoo`03001n
[7j/00En[003001jRGZ900=jR@07001f9GHUMRD006V00000AWoo000GOol00`00Oomoo`0WOol20007
M_<00`00LaIc5P04LaH00`00LaH00009KaL00`00JaQ[6005JaP01000IaYW6VLJ20000Woo00<007oo
Ool067oo00<007j/OZ`01Wj/00<007Z9NXT00gZ900@007HUMREf9@8004Ioo`005goo00<007ooOol0
9goo00<007[@00001gKc00<007<FLaH00W<F00@007<FLaH000Y_5`03001[66/H00E[6004001W6VLJ
IaX70003Ool00`00Oomoo`0GOol00`00OZan[007OZ`00`00NXUjR@02NXT00`00MREf9@02MRD20015
Ool001Moo`03001oogoo02Ioo`05001jd7[@N]000007M_<01000LaIc5P0017<F00<006lGKaL026lG
00<006/HJaP01F/H00@006LJIaYW6PL0009oo`03001oogoo01Moo`8000Un[003001jRGZ9009jR@04
001f9GHUMRD20015Ool001Moo`03001oogoo02Ioo`03001jd7[@009jd003001flgKc00Efl`8000Ic
5P03001_5flG00M_5`03001[66/H00I[6004001W6VLJIaX70002Ool00`00Oomoo`0FOol00`00O/h0
0008OZ`00`00NXUjR@03NXT01000MREf9GHU0P00A7oo000FOol00`00Oomoo`0WOol00`00N]1jd003
N]000`00M_=fl`04M_<20007LaH00`00KaM_5`07KaL00`00JaQ[6006JaP01000IaX007oo1`0000=o
o`00Ool05goo00@007k>O/h000Qn[003001jRGZ900=jR@05001f9GHUMRD00014Ool001Ioo`03001o
ogoo02Moo`03001jd7[@00Ajd003001flgKc00=fl`03001fl`0000Mc5P03001_5flG00M_5`03001[
66/H00I[6004001oogooOol60002Ool00`00Oomoo`0EOol01000O/incP002Gj/00<007Z9NXT00WZ9
00D007HUMREf9@0004Aoo`005Woo00<007ooOol09goo0P001W[@00D007KcM_=fl`0000=fl`03001c
5W<F00Ec5P03001_5flG00M_5`03001[66/H00A[6003001oogoo00=oo`H0009oo`03001oogoo01Ao
o`05001ncWk>O/h00009OZ`00`00NXUjR@02NXT01000MREf9@00A7oo000FOol00`00Oomoo`0WOol0
0`00NX`00006N]000`00M_<00004M_<00`00LaIc5P06LaH00`00KaM_5`07KaL00`00JaQ[6002JaP0
0`00Oomoo`05Ool600000goo001oo`0EOol00`00O/incP02O/h00`00OZan[007OZ`00`00NXUjR@02
NXT01000MREf9@00@goo000FOol00`00Oomoo`0WOol01000NXajS0001W[@00<007KcM_<017Kc00<0
07<FLaH01W<F00<006lGKaL01flG00D006/HJaQ[600000Moo`L00003Ool007oo01Aoo`03001ncWk>
00=ncP03001n[7j/00In[003001jRGZ900=jR@03001f9@0004=oo`005Woo00<007ooOol09goo00D0
07Z<NXajS00000Ajd003001jd00000Ifl`03001c5W<F00Ic5P03001_5flG00M_5`03001[600000Uo
o`L00003Ool007oo01=oo`03001ncWk>00AncP03001n[7j/00In[003001jRGZ900=jR@8004=oo`00
5Woo00<007ooOol09goo00<007Z<NX`00WZ<00@007[@N]0000=jd003001flgKc00Afl`03001c5W<F
00Ic5P03001_5flG00M_5`03001oogoo00Uoo`P001Aoo`03001ncWk>00EncP03001n[7j/00In[003
001jRGZ9009jR@8004=oo`005Woo00<007ooOol09goo00<007Z<NX`00gZ<00<007[@000017[@00<0
07KcM_<017Kc00<007<FLaH01W<F00<006lGKaL01FlG00<007ooOol02goo20004goo00<007k>O/h0
1Gk>00<007j/OZ`01gj/00<007Z9NXT00WZ90P00@Woo000FOol00`00Oomoo`0WOol20005NX`00`00
N]1jd004N]000`00M_=fl`04M_<00`00LaIc5P06LaH00`00KaM_5`04KaL00`00Oomoo`0<Ool8000B
Ool00`00O/incP06O/h00`00OZan[007OZ`00`00NXUjR@02NXT00`00Oomoo`10Ool001Ioo`03001o
ogoo02Qoo`8000=jS003001jS00000Ijd003001flgKc00Afl`03001c5W<F00Ic5P03001_5flG009_
5`03001oogoo00ioo`L0015oo`8000UncP03001n[7j/00In[003001jRGZ9009jR@03001oogoo041o
o`005Goo00<007ooOol0:Goo00D007H4001jS00000=jS003001jd7[@00=jd003001flgKc00Efl`03
001c5W<F00Ic5P04001_5flG000BOol7000@Ool30009O/h00`00OZan[006OZ`01@00NXUjRGZ90000
@Woo000EOol00`00Oomoo`0ZOol00`00MP@00005NX`00`00N]1jd003N]000`00M_=fl`05M_<00`00
LaIc5P06LaH00`00KaL0000COol7000>Ool01@00Ool007k`00002Gk>00<007j/OZ`01Wj/00D007Z9
NXUjR@00045oo`005Goo00<007ooOol0:Woo0P0000=f1000NX`017Z<00<007[@N]000g[@00<007Kc
M_<01GKc00<007<FLaH01W<F00<007ooOol04goo1P003Woo00<007oo00000Wk`00<007k>O/h01gk>
00<007j/OZ`01Wj/00@007Z9NXT0045oo`005Goo00<007ooOol0:goo00@007H4MP@000EjS003001j
d7[@00=jd003001flgKc00Efl`03001c5W<F00Ac5P03001oogoo01Eoo`H000aoo`03001oo`0000=n
l003001ncWk>00MncP03001n[7j/00Mn[003001jR@00045oo`005Goo00<007ooOol0:Woo0`000WH4
00<007Z<NX`00gZ<00<007[@N]000g[@00<007KcM_<01GKc00<007<FLaH00g<F00<007ooOol05Goo
1`002goo00<007oo000017k`00<007k>O/h01gk>00<007j/OZ`01gj/0P00@Goo000EOol00`00Oomo
o`0YOol00`00Ool000020002MP@00`00NXajS003NX`00`00N]1jd003N]000`00M_=fl`05M_<01@00
LaIc5W<F00006Goo1`002Goo00@007ooOol000Enl003001ncWk>00MncP03001n[7j/00In[003001j
R@00041oo`005Goo00<007ooOol0:7oo00<007ooOol00P0000EU@000MPAf100000AjS003001jd7[@
00Ajd003001flgKc00Efl`04001c5W<F000JOol70008Ool01000Oomoo`001Wk`00<007k>O/h01gk>
00<007j/OZ`01Wj/0P00@7oo000EOol00`00Oomoo`0WOol02@00Oomoogoo001oo`00ID000002MP@0
0`00NXajS002NX`00`00N]1jd004N]000`00M_=fl`05M_<2000LOol70007Ool01000Oomoo`001gk`
00<007k>O/h01gk>00<007j/OZ`01Wj/00<007ooOol0?Woo000EOol00`00Oomoo`0WOol01`00Oomo
ogoo001oo`00009U@004001f17H40004NX`00`00N]1jd004N]000`00M_=fl`05M_<00`00Oomoo`0K
Ool70005Ool01@00Oomoogoo000027k`00<007k>O/h01gk>00<007j/OZ`01Gj/00<007ooOol0?Woo
000EOol00`00Oomoo`0VOol00`00Oomoo`02Ool01000Oomoo`000VE000@007H4MP@000AjS003001j
d7[@00Ajd003001flgKc00Afl`03001oogoo01aoo`L000Aoo`04001oogoo0009O_000`00O/incP08
O/h00`00OZan[004OZ`00`00Oomoo`0nOol001Eoo`03001oogoo02Eoo`03001oogoo00=oo`05001o
ogooOol00002ID001000MPAf100017Z<00<007[@N]0017[@00<007KcM_<00gKc00<007ooOol07Goo
1P000goo00D007ooOomoo`0000Ynl003001ncWk>00MncP03001n[7j/00An[003001oogoo03ioo`00
57oo00<007ooOol09Goo00<007ooOol017oo00@007ooOomoo`80009U@004001f17H40004NX`00`00
N]1jd004N]000`00M_=fl`02M_<00`00Oomoo`0NOol60002Ool01@00Oomoogoo00002gk`00<007k>
O/h01gk>00<007j/OZ`00gj/00<007ooOol0?Woo000DOol00`00Oomoo`0TOol00`00Oomoo`05Ool0
0`00Oomoo`02Ool20002ID000`00MPAf10020003NX`00`00N]1jd004N]001000M_=fl`008Woo1`00
17oo00<007k`O_002Wk`00<007k>O/h01gk>00<007j/OZ`00Wj/00<007ooOol0?Woo000DOol00`00
Oomoo`0TOol00`00Oomoo`05Ool00`00Oomoo`03Ool20002ID001@00MPAf17H400000gZ<00<007[@
N]0017[@00<007Kc00008Woo1`0017oo0P0037k`00<007k>O/h01gk>00D007j/OZan[000041oo`00
57oo00<007ooOol08goo00<007ooOol01Woo00<007ooOol017oo0P000VE000D007H4MPAf100000=j
S003001jd7[@00Ajd08002=oo`L0009oo`04001k4g/C000<O_000`00O/incP07O/h01@00OZan[7j/
0000?goo000DOol00`00Oomoo`0ROol00`00Oomoo`07Ool00`00Oomoo`04Ool00`00F<000002ID00
1@00MPAf17H400000gZ<00<007[@N]0017[@00<007ooOol08Woo1`0000=oo`00Na<00W/C00<007k`
O_002Gk`00<007k>O/h027k>00@007j/OZ`003moo`0057oo00<007ooOol08Goo00<007ooOol01goo
00<007ooOol01Woo00<005S000000VE000D007H4MPAf100000=jS003001jd7[@00=jd003001oogoo
02=oo`D0009oo`05001k4g/CNa<0000<O_000`00O/incP07O/h01000OZan[000?goo000DOol00`00
Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00F<000002ID001@00MPAf17H400000gZ<
00<007[@N]000W[@00<007ooOol08goo10000goo00<007/CNa<00W/C00<007k`O_002Wk`00<007k>
O/h01gk>00<007j/0000?goo000DOol00`00Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00F<000002ID001@00MPAf17H400000gZ<00@007[@N]0002Ioo`03001oo`0000=oo`03001k4g/C
00Ak4`03001nl7k`00Ynl003001ncWk>00MncP8003moo`0057oo00<007ooOol07goo00<007ooOol0
2Goo00<007ooOol02Goo00<005S000000VE000D007H4MPAf100000=jS003001jd00002Eoo`03001o
ogoo00Aoo`03001k4g/C00Ek4`03001nl7k`00Ynl003001ncWk>00MncP03001oogoo03eoo`0057oo
00<007ooOol07Woo00<007ooOol02Woo00<007ooOol02Goo0P0000EH`000ID1U@00000=f1004001j
S7Z<NX`2000TOol00`00Oomoo`05Ool00`00Na=k4`06Na<00`00O_1nl00:O_000`00O/incP06O/h0
0`00Oomoo`0mOol001=oo`03001oogoo01ioo`03001oogoo00]oo`03001oogoo00Yoo`800005F<00
06E0ID000003MP@01@00NXajS7Z<00008goo00<007ooOol01Woo00<007/CNa<01g/C00<007k`O_00
2Wk`00<007k>O/h01Gk>00<007ooOol0?Goo000COol00`00Oomoo`0MOol00`00Oomoo`0<Ool00`00
Oomoo`0;Ool200001ES0001U@6E000000gH400@007Z<NX`0029oo`03001oogoo00Ioo`03001k4g/C
00Uk4`03001nl7k`00Unl003001ncWk>00EncP03001oogoo03eoo`004goo00<007ooOol077oo00<0
07ooOol03Goo00<007ooOol037oo0P0000EH`000ID1U@00000=f1003001jS000029oo`03001oogoo
00Ioo`03001k4g/C00Yk4`03001nl7k`00Unl003001ncWk>00AncP03001oogoo03eoo`004goo00<0
07ooOol077oo00<007ooOol03Goo00<007ooOol03Goo0P0000EH`000001U@00000=f1003001jS000
021oo`03001oogoo00Ioo`03001g=`0000]k4`03001nl7k`00Ynl003001ncWk>00=ncP03001oogoo
03eoo`004goo00<007ooOol06goo00<007ooOol03Woo00<007ooOol03Woo0P000US000<006E00000
0gH40P007goo00<007ooOol01goo00@007LgMcL000]k4`03001nl7k`00Ynl003001ncWk>009ncP03
001oogoo03eoo`004goo00<007ooOol06Woo00<007ooOol03goo00<007ooOol03goo0P000US000<0
06E000000gH400<007ooOol077oo00<007ooOol01goo00<007LgMcL00WLg00<007/CNa<02G/C00<0
07k`O_002Wk`00D007k>O/incP0003moo`004goo00<007ooOol06Goo00<007ooOol047oo00<007oo
Ool047oo0P000US000<006E000000WH400<007ooOol077oo00<007ooOol01goo00<007LgMcL00gLg
00<007/CNa<02G/C00<007k`O_002Wk`00@007k>O/h003moo`004goo00<007ooOol067oo00<007oo
Ool04Goo00<007ooOol04Goo0P000US000<006E000000WH400<007ooOol06Woo00<007ooOol01goo
00<007LgMcL01GLg00<007/CNa<02G/C00<007k`O_002Gk`00@007k>O/h003moo`004goo00<007oo
Ool067oo00<007ooOol04Goo00<007ooOol04Woo0P000US000D006E0001f100001]oo`03001oogoo
00Qoo`03001g=gLg00Eg=`03001k4g/C00Yk4`03001nl7k`00Unl003001ncP0003moo`004goo00<0
07ooOol05goo00<007ooOol04Woo00<007ooOol04goo0P000US000@006E0000001Yoo`03001oogoo
00Qoo`03001g=gLg00Mg=`03001k4g/C00Yk4`03001nl7k`00Unl08003moo`004Woo00<007ooOol0
5goo00<007ooOol04goo00<007ooOol057oo0P000US000@006E0000001Qoo`03001oogoo00Uoo`03
001g=gLg00Qg=`03001k4g/C00Yk4`03001nl7k`00Unl003001oogoo03eoo`004Woo00<007ooOol0
5Woo00<007ooOol057oo00<007ooOol05Goo0`0000AH`000ID0001Qoo`03001oogoo00Qoo`03001g
=gLg00Yg=`03001k4g/C00Uk4`03001nl7k`00Unl003001oogoo03eoo`004Woo00<007ooOol05Goo
00<007ooOol05Goo00<007ooOol05Woo0P0000D15`00001U@00001Ioo`03001oogoo00Qoo`03001[
>P0000ag=`03001k4g/C00Uk4`03001nl7k`00Qnl003001oogoo03eoo`004Woo00<007ooOol05Goo
00<007ooOol05Goo00<007ooOol05goo0P0000@15`00000001Eoo`03001oogoo00Qoo`05001[>V/j
JcX0000<McL00`00Na=k4`09Na<00`00O_1nl006O_000`00Oomoo`0nOol0019oo`03001oogoo01Ao
o`03001oogoo01Ioo`03001oogoo01Qoo`8000040AL00000000COol00`00Oomoo`07Ool20005JcX0
0`00McMg=`0:McL00`00Na=k4`09Na<00`00O_1nl005O_000`00Oomoo`0nOol0019oo`03001oogoo
01=oo`03001oogoo01Moo`03001oogoo01Uoo`8000040AL00000000AOol00`00Oomoo`07Ool00`00
JcY[>P06JcX00`00McMg=`0:McL00`00Na=k4`09Na<00`00O_1nl004O_000`00Oomoo`0nOol0019o
o`03001oogoo019oo`03001oogoo01Qoo`03001oogoo01Yoo`8000815`80011oo`03001oogoo00Io
o`03001[>V/j00Q[>P03001g=gLg00Yg=`03001k4g/C00Uk4`03001nl7k`00=nl003001oogoo03io
o`004Woo00<007ooOol04Goo00<007ooOol067oo00<007ooOol077oo0P000P4G100037oo00<007oo
Ool01Goo0P002f/j00<007LgMcL02gLg00<007/CNa<02G/C00<007k`O_000Wk`00<007ooOol0?Woo
000BOol00`00Oomoo`0AOol00`00Oomoo`0HOol00`00Oomoo`0MOol200020AL00`002M`9g0030008
Ool00`00Oomoo`04Ool20002Ead00`00JcY[>P09JcX00`00McMg=`0:McL00`00Na=k4`0:Na<01@00
O_1nl7k`0000@7oo000BOol00`00Oomoo`0@Ool00`00Oomoo`0IOol00`00Oomoo`0OOol010000AL1
5`0010WL1P0000=oo`00Ool00goo0`001ELM00<006/jJcX02F/j00<007LgMcL02WLg00<007/CNa<0
2G/C00@007k`O_00045oo`004Woo00<007ooOol03goo00<007ooOol06Woo00<007ooOol087oo00<0
004G0AL00P0010WL00@003:n<[hb_PH000UG7@03001[>V/j00U[>P03001g=gLg00Yg=`03001k4g/C
00Uk4`03001nl000045oo`004Goo00<007ooOol03goo00<007ooOol06goo00<007ooOol08Goo00D0
004G0AL15`0000@9g003000b_S:n00Db_P03001G7ELM00QG7@03001[>V/j00U[>P03001g=gLg00Yg
=`03001k4g/C00Uk4`80045oo`004Goo00<007ooOol03Woo00<007ooOol077oo00<007ooOol08Woo
00<0004G0AL00P0010WL00<003:n<[h01C:n00<005LMEad025LM00<006/jJcX02F/j00<007LgMcL0
2WLg00<007/CNa<02G/C00<007ooOol0?goo000AOol00`00Oomoo`0>Ool00`00Oomoo`0LOol00`00
Oomoo`0SOol00`000AL15`0200042M`00`00<[hb_P05<[h00`00EaeG7@08Ead00`00JcY[>P09JcX0
0`00McMg=`0:McL00`00Na=k4`08Na<00`00Oomoo`0oOol0015oo`03001oogoo00eoo`03001oogoo
01eoo`03001oogoo02Aoo`0300015`4G008000@9g003000b_S:n00Db_P03001G7ELM00QG7@03001[
>V/j00U[>P03001g=gLg00Yg=`03001k4g/C00Mk4`03001oogoo03moo`004Goo00<007ooOol037oo
00<007ooOol07Woo00<007ooOol09Goo0P0000<15`002M`010WL00<003:n<[h01C:n00<005LMEad0
1eLM00<006/jJcX02V/j00<007LgMcL02WLg00<007/CNa<01G/C00<007ooOol0@7oo000AOol00`00
Oomoo`0;Ool00`00Oomoo`0OOol00`00Oomoo`0VOol200000`4G0009g0042M`00`00<[hb_P05<[h0
0`00EaeG7@07Ead00`00JcY[>P0:JcX00`00McMg=`0:McL00`00Na=k4`04Na<00`00Oomoo`10Ool0
015oo`03001oogoo00Yoo`03001oogoo021oo`03001oogoo02Moo`8000030AL000WL00@9g003000b
_S:n00Db_P03001G7ELM00MG7@03001[>V/j00U[>P03001g=gLg00]g=`03001k4g/C00=k4`03001o
ogoo041oo`004Goo00<007ooOol02Woo00<007ooOol087oo00<007ooOol09goo0`0000<15`002M`0
10WL00<003:n<[h01C:n00<005LMEad01eLM00<006/jJcX02F/j00<007LgMcL02WLg00<007/CNa<0
0g/C00<007ooOol0@7oo000AOol00`00Oomoo`09Ool00`00Oomoo`0QOol00`00Oomoo`0VOol00`00
Oomoo`0200000`4G0009g0042M`00`00<[hb_P05<[h00`00EaeG7@07Ead00`00JcY[>P09JcX00`00
McMg=`0:McL00`00Na=k4`02Na<00`00Oomoo`10Ool0015oo`03001oogoo00Qoo`03001oogoo029o
o`03001oogoo02Ioo`04001oogooOol200000`4G0009g0042M`00`00<[hb_P05<[h00`00EaeG7@07
Ead00`00JcY[>P09JcX00`00McMg=`0:McL01@00Na=k4g/C0000@Woo000@Ool00`00Oomoo`08Ool0
0`00Oomoo`0SOol00`00Oomoo`0UOol00`00Oomoo`03Ool200000`4G000000042M`00`00<[hb_P05
<[h00`00EaeG7@07Ead00`00JcY[>P09JcX00`00McMg=`0:McL00`00Na<00013Ool0011oo`03001o
ogoo00Moo`03001oogoo02Aoo`03001oogoo02Aoo`03001oogoo00=oo`L000@9g003000b_S:n00Db
_P03001G7ELM00MG7@03001[>V/j00U[>P03001g=gLg00Yg=`8004=oo`0047oo00<007ooOol01Woo
00<007ooOol09Goo00<007ooOol08goo00<007ooOol00Woo0`001C@01@0000<9g000<[h01S:n00<0
05LMEad01eLM00<006/jJcX02F/j00<007LgMcL02WLg00<007ooOol0@Goo000@Ool00`00Oomoo`06
Ool00`00Oomoo`0UOol00`00Oomoo`0ROol01000Oomoogoo0`001c@00`000UDY0`001c:n00<005LM
Ead01eLM00<006/jJcX02F/j00<007LgMcL027Lg00<007ooOol0@Woo000@Ool00`00Oomoo`05Ool0
0`00Oomoo`0VOol00`00Oomoo`0ROol00`00Ool000040004=0030006EBT30006<[h00`00EaeG7@08
Ead00`00JcY[>P09JcX00`00McMg=`07McL00`00Oomoo`12Ool0011oo`03001oogoo00Aoo`03001o
ogoo02Moo`03001oogoo025oo`@00004>:`0043]@>d4000:EBT00`00F80000020004<[h00`00EaeG
7@08Ead00`00JcY[>P09JcX00`00McMg=`05McL00`00Oomoo`13Ool0011oo`03001oogoo00=oo`03
001oogoo02Qoo`03001oogoo021oo`<0008h[0030010kD3]0090k@030019;P0000]E:@03001HP5R0
008000@b_P03001G7ELM00QG7@03001[>V/j00Q[>P03001g=gLg00Eg=`03001oogoo04=oo`0047oo
00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol07goo0`000cR/00D0043]@>e0k@0000=9;P03
001E:EDY00AE:@H0009HP08000@b_P03001G7ELM00QG7@03001[>V/j00Q[>P03001g=gLg00=g=`03
001oogoo04Aoo`0047oo00<007ooOol00Woo00<007ooOol0:7oo00<007ooOol087oo00@0032<<8`0
008h[0040010kD3]0004BBh70005HNl300000eR000000004<[h00`00EaeG7@08Ead00`00JcY[>P08
JcX00`00McMg=`02McL00`00Oomoo`14Ool0011oo`05001oogooOol0000[Ool00`00Oomoo`0OOol2
0002<8`00`00>:`00002@>d01000BBi9;TT^0P0000==L000HNl02F7_00<0079=LTd00P0000=HP000
<[h00c:n00<005LMEad025LM00<006/jJcX026/j00@007LgMcL004Moo`003goo00D007ooOomoo`00
02aoo`03001oogoo01ioo`8000<`S005000h[000@>d00002BBh20003CG000`00HNmQk`08HNl00`00
LTebC@02LTd30004<[h00`00EaeG7@07Ead00`00JcY[>P09JcX00`00McL00017Ool000moo`04001o
ogoo000]Ool00`00Oomoo`0MOol30003<8`01@00>:`00000BBh00P001Te`00<0067_HNl01f7_00<0
079=LTd0179=0P0013:n00<005LMEad01eLM00<006/jJcX02F/j00<007ooOol0AWoo000?Ool00`00
Ool0000^Ool00`00Oomoo`0LOol300001C2^00000000<8`0100024e`00<0067_HNl0267_00<0079=
LTd0179=00<003:n<[h00c:n00<005LMEad01eLM00<006/jJcX01f/j00<007ooOol0Agoo000>Ool4
000^Ool00`00Oomoo`0KOol30005<:h?0009HNl00`00LTebC@04LTd20005<[h00`00EaeG7@07Ead0
0`00JcY[>P05JcX00`00Oomoo`18Ool000eoo`D002ioo`03001oogoo01]oo`<000<`[PH000UA/P03
001R<`0000<000EQk`03001bCG9=00AbC@8000Hb_P03001G7ELM00MG7@03001[>V/j00=[>P03001o
ogoo04Uoo`0037oo2@00:goo00<007ooOol06Woo0`0000D`[P00000003C`00@00003CK<0000000IA
/P03001R<f8c00AR<`@00003HNl0079=00EbC@03001b@P0000Hb_P03001G7ELM00MG7@05001[>V/j
JcX0001<Ool000eooa<0021oo`03001oogoo01Uoo`03001oo`00008000<dl006000m<P000019/`00
0Tfc0P00156b00<0068cHS<0268c0P001W9=00@00792000000Hb_P03001G7ELM00MG7@03001[>P00
04eoo`003Woo20002TKn2`005Goo00<007ooOol067oo00<007oo00000P000cC`00L003db0015L`00
BK<00004CK<200000e6b001R<`0;HS<30005LTd01000LT8000001S:n00<005LMEad01ULM0P00CWoo
000?Ool8000DA_h;000:Ool00`00Oomoo`0GOol00`00Oomoo`030002=?001P00?C8m<P00AG<00099
/`03001=/dfc00==/`8000]R<`05001be7;DL]@00004LTd00`00LT8000050003<[h01000EaeG7ELM
1000D7oo000@Ool8000NA_h;000HOol02@00Oomoogoo00003000=?000002?C801000AG=5L`000dVc
00<004fcCK<00Tfc00@005iF000000UR<`03001be7;D009be080009bC@03001b@P0000Eoo`L005Ao
o`004Woo20009dKn2`003Goo00<007ooOol00P0000<0300000000cdb00@004EcAG<000=9/`05001=
/dfcCK<00004GUH00`00HS=R<`06HS<00`00L]Abe004L]@300000g92001oo`1OOol001=oo`P00356
oP/00003Ool007oo009oo`040000300<0003?C801@00AG=5LdEc000014Vc00@004fcCK<000ENEP03
001R<f8c00AR<`03001be7;D00Mbe003001b@P00061oo`0057oo2000>dKn1P000P0<0P000Sdb00D0
04EcAG=5L`0000A9/`03001=/`0000MNEP8000AR<`03001be7;D00Mbe0<0061oo`005Goo2000?dKn
00<0000<00000RDE0P0014Ec00<004VcBK<00TVc0P002UiF00D0068cHS=R<`0000Qbe005001oU000
LT80001OOol001Moo`P003e6oP030000300000<U5@<00095L`030019/`000080009B=`03001NEUiF
00QNEP<000Ube003001oU7nD008005moo`0067oo2000?4Kn00<0000<00000bDE00<0047h@OP01000
1E8g00<005iFGUH02UiF00<007;DL]@01W;D00@007nDOiAoU08005moo`006Goo2000?4Kn0P000bDE
00<0047h@OP00T7h00<0058gDSL01E8g00<005iFGUH025iF00<006Ki00001g;D00<007nDOi@00WnD
00<007ooOol0GGoo000JOol8000kA_h00`009ADU5@029AD00`00@OQ1n003@OP00`00DSMB=`04DSL0
0`00GUINEP07GUH01@00I_UVnFKi00001W;D00<007nDOi@00WnD00<007ooOol0GGoo000LOol8000i
A_h00`009ADU5@029AD00`00@OQ1n003@OP00`00DSMB=`05DSL00`00GUINEP05GUH00`00I_UVn@03
I_T20003L]@00`00OiAoU002Oi@00`00Oomoo`1NOol001eoo`P003Q6oP03000U5BDE008U5@030011
n47h00=1n003001B=e8g00IB=`03001NEUiF00=NEP03001VnFKi00IVn@04001be7;D0004Oi@00`00
Oomoo`1NOol001ioo`P003M6oP8000<U5@030011n47h00=1n003001B=e8g00IB=`03001NEUiF009N
EP03001VnFKi00QVn@8000EoU003001oogoo05ioo`007goo2000=dKn0P000RDE00<0047h@OP0147h
00<0058gDSL01U8g00@005iFGUH000aVn@03001oU7nD009oU003001oogoo05moo`008Goo1`00=TKn
0P000RDE00<0047h@OP0147h00<0058gDSL01U8g00<005iF000036Ki00<007>k00000gnD00<007oo
Ool0Ggoo000ROol8000eA_h200000bDE0011n005@OP00`00DSMB=`06DSL2000<I_T01@00Lk]c^g>k
00000WnD00<007ooOol0Ggoo000SOol8000dA_h0100007D000001T7h00<0058gDSL00e8g0`000UKK
00<006KiI_T026Ki00<007>kLk/00g>k0P00HWoo000TOol8000bA_h300000`1e000000020004@OP0
0`00DSL000020006E]/00`00I_UVn@06I_T00`00Lk]c^`05Lk/00`00Oomoo`1POol002Eoo`P002m6
oP80009oo`030000M@0000<fG@H000YFf`03001VnFKi00EVn@03001c^g>k00Ac^`03001oogoo065o
o`009goo2000:dKn0P001Goo00<0001e00001cIM00<005KKE]/02EKK00<006KiI_T00fKi00<007>k
Lk/017>k00<007ooOol0HWoo000XOol8000YA_h00`00Oomoo`06Ool20007=Ud00`00E]]Ff`0:E]/0
1@00I_UVnFKi00001W>k00<007ooOol0Hgoo000YOol8000VA_h2000:Ool20007=Ud00`00E]]Ff`0:
E]/00`00I_T00006Lk/00`00Oomoo`1TOol002Yoo`P002=6oP8000aoo`8000PfG@03001FfeKK00UF
f`8000Ic^`03001oogoo06Eoo`00;7oo20007dKn0P003goo0P0023IM00<005KKE]/01UKK0P000U>O
00<007>kLk/00W>k00<007ooOol0IWoo000]Ool8000LA_h2000BOol00`00=UdfG@06=Ud00`00E]]F
f`03E]/30005Dil200000g>k001oo`1XOol002ioo`P001Y6oP03001oogoo01=oo`D000@fG@03001F
feKK008000YCW`03001oogoo06Qoo`00;goo20005dKn0P0067oo2P0025>O0`00K7oo000aOol8000C
A_h2000NOol400021U/20003Dil3001_Ool0039oo`P00116oP8002Eoo`H0079oo`00<goo20003DKn
0P00Wgoo000dOol8000;A_h00`00Oomoo`2OOol003Ioo`P000M6oP800:9oo`00=goo200014Kn0P00
Y7oo000hOol800000dKn0000002VOol003Uoo`P00:Qoo`00>goo1`00Ygoo000lOol5002XOol003eo
o`<00:Uoo`00?Woo00<007ooOol0Z7oo003YOol00>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol0
0>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol0
0>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol0
0>Uoo`00jGoo003YOol00>Uoo`00jGoo003YOol00>Uoo`00\
\>"],
  ImageRangeCache->{{{0, 232}, {282, 0}} -> {0.0708406, -0.0257838, 
  0.00371371, 0.00371371}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Splined Cams"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In designing an arbitrary cam mechanism it is necessary to be able to \
describe an arbitrary cam surface, one that is not constrained to be a series \
of piecewise continuous functions each coded in by the user, such as the \
examples in the previous subsections. One way to define such an arbitrary \
curve or surface is with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects built with the ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. Thus, the required sequence of piecewise continuous functions \
is assembled by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", while the user merely inputs discrete data.\n\nWhile a cam surface so \
defined may work in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model, it may also create some numerical problems. One basic requirement \
for a valid ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " cam profile is that it have zeroth- and first-order continuity. The ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function uses cubic interpolation to fit the polynomials to the supplied \
data. This results in a curve that has zeroth-order, not first-order, \
continuity. Since the first-order discontinuities in an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam are typically small, such a cam usually works fine until it happens \
to seek a solution point that has its point of contact on the cam directly on \
a cusp in the interpolating function.\n\nTo get around this difficulty ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " provides a function for creating cubic spline objects that have zeroth-, \
first-, and second-order continuity at each knot point. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is similar to the ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function that is included with the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " packages, but it has been enhanced to allow 3D space curves, and the ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects it returns are differentiable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SplineFit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["data",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object representing ",
  StyleBox["data",
    FontSlant->"Italic"],
  " as a continuous cubic spline. ",
  StyleBox["data",
    FontSlant->"Italic"],
  " may be a list of 2D or 3D point coordinates.\n\n",
  StyleBox["SplineFunction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["range",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", <>",
    FontFamily->"Times"],
  StyleBox["][",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["number",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates the ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the independent parameter set to ",
  StyleBox["number",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The function for creating splines."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that explicitly specifies the values of the spline's parameter at each \
knot point. ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may be a list of numbers in ascending order. The default setting ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " implies ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] {0, 1, 2, ...}.\n\n",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the end conditions of the spline.\n\n",
  StyleBox["Natural",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies zero curvature at both ends of the spline.\n\n",
  StyleBox["Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies identical slope and curvature at both ends of the spline.\n\
\n",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vec, vec",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the direction vector at each end of the spline."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Options for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that it is necessary to provide a list of data points with identical \
first and last points if a ",
  StyleBox["Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " spline is desired. The ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting only ensures that the slope and curvature are continuous at the \
ends. The supplied data must provide zeroth-order continuity.\n\nA closed cam \
profile in 2D space could be defined with a ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are some data to be splined."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(knotpoints
       = {{0, 1.5}, {.75, .75}, {1, 0}, {.707, \(-.707\)}, {0, \(-1\)}, {
          \(-.707\), \(-.707\)}, {\(-1\), 0}, {\(-.75\), .75}, {0, 1.5}}; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now we generate a ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(splinelocus = SplineFit[knotpoints, EndConditions \[Rule] Closed]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("SplineFunction["\[InvisibleSpace]{0, 8}\[InvisibleSpace]",<>]"\),
      SequenceForm[ "SplineFunction[", {0, 8}, ",<>]"],
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData["Here is a plot of the spline."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[splinelocus[s], {s, 0, 8}, Compiled \[Rule] False, 
      AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.2488 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500001 0.475734 0.505467 0.475734 [
[.02427 .49297 -6 -9 ]
[.02427 .49297 6 0 ]
[.26213 .49297 -12 -9 ]
[.26213 .49297 12 0 ]
[.73787 .49297 -9 -9 ]
[.73787 .49297 9 0 ]
[.97573 .49297 -3 -9 ]
[.97573 .49297 3 0 ]
[.4875 .02973 -12 -4.5 ]
[.4875 .02973 0 4.5 ]
[.4875 .2676 -24 -4.5 ]
[.4875 .2676 0 4.5 ]
[.4875 .74333 -18 -4.5 ]
[.4875 .74333 0 4.5 ]
[.4875 .9812 -6 -4.5 ]
[.4875 .9812 0 4.5 ]
[.4875 1.21907 -18 -4.5 ]
[.4875 1.21907 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1.2488 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02427 .50547 m
.02427 .51172 L
s
[(-1)] .02427 .49297 0 1 Mshowa
.26213 .50547 m
.26213 .51172 L
s
[(-0.5)] .26213 .49297 0 1 Mshowa
.73787 .50547 m
.73787 .51172 L
s
[(0.5)] .73787 .49297 0 1 Mshowa
.97573 .50547 m
.97573 .51172 L
s
[(1)] .97573 .49297 0 1 Mshowa
.125 Mabswid
.07184 .50547 m
.07184 .50922 L
s
.11941 .50547 m
.11941 .50922 L
s
.16699 .50547 m
.16699 .50922 L
s
.21456 .50547 m
.21456 .50922 L
s
.30971 .50547 m
.30971 .50922 L
s
.35728 .50547 m
.35728 .50922 L
s
.40485 .50547 m
.40485 .50922 L
s
.45243 .50547 m
.45243 .50922 L
s
.54757 .50547 m
.54757 .50922 L
s
.59515 .50547 m
.59515 .50922 L
s
.64272 .50547 m
.64272 .50922 L
s
.69029 .50547 m
.69029 .50922 L
s
.78544 .50547 m
.78544 .50922 L
s
.83301 .50547 m
.83301 .50922 L
s
.88059 .50547 m
.88059 .50922 L
s
.92816 .50547 m
.92816 .50922 L
s
.25 Mabswid
0 .50547 m
1 .50547 L
s
.5 .02973 m
.50625 .02973 L
s
[(-1)] .4875 .02973 1 0 Mshowa
.5 .2676 m
.50625 .2676 L
s
[(-0.5)] .4875 .2676 1 0 Mshowa
.5 .74333 m
.50625 .74333 L
s
[(0.5)] .4875 .74333 1 0 Mshowa
.5 .9812 m
.50625 .9812 L
s
[(1)] .4875 .9812 1 0 Mshowa
.5 1.21907 m
.50625 1.21907 L
s
[(1.5)] .4875 1.21907 1 0 Mshowa
.125 Mabswid
.5 .07731 m
.50375 .07731 L
s
.5 .12488 m
.50375 .12488 L
s
.5 .17245 m
.50375 .17245 L
s
.5 .22003 m
.50375 .22003 L
s
.5 .31517 m
.50375 .31517 L
s
.5 .36275 m
.50375 .36275 L
s
.5 .41032 m
.50375 .41032 L
s
.5 .45789 m
.50375 .45789 L
s
.5 .55304 m
.50375 .55304 L
s
.5 .60061 m
.50375 .60061 L
s
.5 .64819 m
.50375 .64819 L
s
.5 .69576 m
.50375 .69576 L
s
.5 .79091 m
.50375 .79091 L
s
.5 .83848 m
.50375 .83848 L
s
.5 .88605 m
.50375 .88605 L
s
.5 .93363 m
.50375 .93363 L
s
.5 1.02877 m
.50375 1.02877 L
s
.5 1.07635 m
.50375 1.07635 L
s
.5 1.12392 m
.50375 1.12392 L
s
.5 1.17149 m
.50375 1.17149 L
s
.25 Mabswid
.5 0 m
.5 1.2488 L
s
0 0 m
1 0 L
1 1.2488 L
0 1.2488 L
closepath
clip
newpath
.5 Mabswid
.5 1.21907 m
.50401 1.21901 L
.50765 1.21885 L
.51186 1.21855 L
.51583 1.21814 L
.5229 1.21714 L
.53056 1.21566 L
.53899 1.21356 L
.54792 1.21082 L
.56388 1.20463 L
.59557 1.18769 L
.62996 1.16276 L
.69937 1.09388 L
.75994 1.01587 L
.85788 .8604 L
.89661 .79034 L
.92994 .722 L
.94226 .69248 L
.95326 .6621 L
.96159 .63436 L
.96759 .60923 L
.97014 .59586 L
.97242 .5812 L
.97417 .56644 L
.9749 .55835 L
.97543 .55077 L
.97563 .54732 L
.97581 .54356 L
.97594 .54024 L
.97604 .5367 L
.97612 .53352 L
.97617 .52999 L
.97619 .52678 L
.97619 .52376 L
.97616 .52017 L
.97613 .51837 L
.9761 .51639 L
.97601 .51288 L
.9759 .5096 L
.97557 .50214 L
.97508 .49411 L
.97376 .47866 L
.97209 .46426 L
.96672 .43129 L
.96017 .40194 L
.95141 .3708 L
.92977 .31268 L
.90357 .26034 L
.86796 .20631 L
.82946 .16207 L
Mistroke
.78436 .12292 L
.72975 .08779 L
.67366 .06188 L
.64095 .05065 L
.61067 .04253 L
.59563 .03926 L
.57966 .03633 L
.56578 .03423 L
.55086 .03242 L
.54242 .0316 L
.53473 .03098 L
.5269 .03048 L
.51965 .03013 L
.51555 .02998 L
.51121 .02986 L
.50895 .02982 L
.50684 .02978 L
.50452 .02975 L
.50203 .02974 L
.5 .02973 L
.49778 .02974 L
.49547 .02975 L
.49332 .02978 L
.48946 .02985 L
.48535 .02996 L
.48145 .03009 L
.47717 .03027 L
.46853 .03076 L
.46054 .03135 L
.45309 .03202 L
.43631 .03394 L
.4184 .03666 L
.38592 .04334 L
.35676 .05136 L
.30083 .07255 L
.27059 .0876 L
.24367 .10349 L
.19662 .1381 L
.15046 .18363 L
.11343 .23262 L
.08047 .29053 L
.05578 .34927 L
.04598 .37942 L
.03727 .41254 L
.0311 .44322 L
.02711 .4708 L
.02556 .48587 L
.02491 .49429 L
.02444 .50201 L
.02413 .50871 L
Mistroke
.024 .5125 L
.02391 .51604 L
.02385 .51975 L
.02382 .52313 L
.02381 .52499 L
.02381 .52702 L
.02384 .53071 L
.02387 .53251 L
.0239 .53441 L
.02399 .53781 L
.02411 .54146 L
.02428 .54546 L
.02469 .55259 L
.02517 .55923 L
.02638 .57159 L
.02809 .58479 L
.03359 .61471 L
.04059 .64224 L
.05931 .69646 L
.08777 .75975 L
.16896 .90611 L
.22118 .9885 L
.27588 1.06388 L
.33709 1.133 L
.365 1.15857 L
.3961 1.18225 L
.42206 1.19786 L
.44641 1.20881 L
.45995 1.21326 L
.47228 1.21625 L
.47912 1.21746 L
.48273 1.21796 L
.48654 1.21839 L
.48988 1.21869 L
.49354 1.21891 L
.49688 1.21903 L
.5 1.21907 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{237, 296},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003]0001:1000`40O003h00OkGoo001fOol00`00
Oomoo`1dOol007Ioo`03001oogoo07Aoo`00MWoo00<007ooOol0M7oo001fOol00`00Oomoo`1dOol0
07Ioo`03001oogoo07Aoo`00KWoo1@000goo00<007ooOol0M7oo001`Ool00`00Oomoo`03Ool00`00
Oomoo`1dOol006YooaX006Uoo`00HGoo2@001Woo00<007ooOol00goo00<007ooOol02goo1P00Hgoo
001MOol4000?Ool00`00Oomoo`03Ool00`00Oomoo`0AOol4001OOol005Yoo`<0019oo`8000Eoo`03
001oogoo01Eoo`@005]oo`00EWoo100077oo00<007ooOol06Goo1000Egoo001COol3000POol00`00
Oomoo`0MOol3001DOol0055oo`8002=oo`03001oogoo021oo`@0051oo`00CWoo0`009Goo00<007oo
Ool097oo0`00CGoo001;Ool3000XOol00`00Oomoo`0WOol2001;Ool004Uoo`8002]oo`03001oogoo
02Uoo`8004Uoo`00AWoo0`00;Goo00<007ooOol0:goo0P00Agoo0014Ool2000`Ool2000^Ool20015
Ool0049oo`80039oo`03001oogoo02moo`8004=oo`00@7oo0P00=7oo00<007ooOol0<Goo0P00@Goo
000nOol2000fOol00`00Oomoo`0cOol00`00Oomoo`0nOol003aoo`8003Qoo`03001oogoo03Aoo`80
03ioo`00>Woo0P00>Woo00<007ooOol0=Woo0P00?7oo000iOol00`00Oomoo`0jOol00`00Oomoo`0h
Ool00`00Oomoo`0iOol003Moo`8003eoo`03001oogoo03Uoo`8003Uoo`00=Woo00<007ooOol0?Goo
00<007ooOol0>goo00<007ooOol0=Woo000eOol00`00Oomoo`0nOol00`00Oomoo`0lOol2000fOol0
03=oo`80045oo`03001oogoo03ioo`8003Aoo`00<Woo00<007ooOol0@Goo0P00@Goo00<007ooOol0
<Goo000aOol00`00Oomoo`12Ool00`00Oomoo`11Ool00`00Oomoo`0`Ool002moo`8004Eoo`03001o
ogoo049oo`03001oogoo02moo`00;Woo00<007ooOol0AGoo00<007ooOol0@goo00<007ooOol0;Woo
000]Ool00`00Oomoo`16Ool00`00Oomoo`14Ool00`00Oomoo`0]Ool002aoo`03001oogoo04Moo`03
001oogoo04Eoo`8002eoo`00:goo00<007ooOol0B7oo00<007ooOol0Agoo00<007ooOol0:Woo000Z
Ool00`00Oomoo`19Ool00`00Oomoo`18Ool00`00Oomoo`0YOol002Uoo`03001oogoo04Yoo`03001o
ogoo04Uoo`03001oogoo02Qoo`00:7oo00<007ooOol0Bgoo00<007ooOol0BWoo00<007ooOol09goo
000WOol00`00Oomoo`1<Ool00`00Oomoo`1;Ool00`00Oomoo`0VOol002Ioo`03001oogoo04eoo`80
04eoo`03001oogoo02Eoo`009Goo00<007ooOol0CWoo00<007ooOol0CGoo00<007ooOol097oo000T
Ool00`00Oomoo`1?Ool00`00Oomoo`1>Ool00`00Oomoo`0SOol002=oo`03001oogoo051oo`03001o
ogoo04ioo`03001oogoo02=oo`008Woo00<007ooOol0DGoo00<007ooOol0Cgoo00<007ooOol08Woo
000ROol00`00Oomoo`1AOol00`00Oomoo`1@Ool00`00Oomoo`0QOol0025oo`03001oogoo059oo`03
001oogoo055oo`03001oogoo021oo`0087oo00<007ooOol0Dgoo00<007ooOol0DWoo00<007ooOol0
7goo000POol00`00Oomoo`1COol00`00Oomoo`1COol00`00Oomoo`0NOol001moo`03001oogoo05Ao
o`03001oogoo05Aoo`03001oogoo01eoo`007Woo00<007ooOol0EGoo00<007ooOol0E7oo00<007oo
Ool07Goo000NOol00`00Oomoo`1EOol00`00Oomoo`1EOol00`00Oomoo`0LOol001eoo`03001oogoo
05Ioo`8005Moo`03001oogoo01]oo`0077oo00<007ooOol0Egoo00<007ooOol0EWoo00<007ooOol0
6goo000LOol00`00Oomoo`1GOol00`00Oomoo`1GOol00`00Oomoo`0JOol001]oo`03001oogoo05Qo
o`03001oogoo05Qoo`03001oogoo01Uoo`006Woo00<007ooOol0FGoo00<007ooOol0FGoo00<007oo
Ool067oo000JOol00`00Oomoo`1IOol00`00Oomoo`1IOol00`00Oomoo`0HOol001Uoo`03001oogoo
05Yoo`03001oogoo05Yoo`03001oogoo01Moo`006Goo00<007ooOol0FWoo00<007ooOol0Fgoo00<0
07ooOol05Woo000HOol00`00Oomoo`1KOol00`00Oomoo`1KOol00`00Oomoo`0FOol001Moo`03001o
ogoo04aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo05aoo`03001o
ogoo01Eoo`005goo00<007ooOol0Bgoo00<007oo00001goo00<007oo000017oo00<007ooOol0G7oo
00<007ooOol05Goo000FOol00`00Oomoo`17Ool30002Ool00`00Ool00009Ool00`00Oomoo`02Ool2
001NOol00`00Oomoo`0DOol001Eoo`03001oogoo04eoo`03001oo`0000Moo`8000Eoo`03001oogoo
05eoo`03001oogoo01Aoo`005Goo00<007ooOol0CGoo00<007oo00001goo00<007ooOol017oo00<0
07ooOol0GWoo00<007ooOol04goo000DOol00`00Oomoo`1?Ool00`00Oomoo`06Ool30004Ool00`00
Oomoo`1NOol00`00Oomoo`0COol001Aoo`03001oogoo05moo`03001oogoo05moo`03001oogoo019o
o`004goo00<007ooOol0H7oo00<007ooOol0Ggoo00<007ooOol04Woo000COol00`00Oomoo`1POol0
0`00Oomoo`1POol00`00Oomoo`0AOol0019oo`03001oogoo065oo`03001oogoo061oo`03001oogoo
015oo`004Woo00<007ooOol0HGoo00<007ooOol0HGoo00<007ooOol047oo000AOol00`00Oomoo`1R
Ool00`00Oomoo`1QOol00`00Oomoo`0@Ool0015oo`03001oogoo069oo`03001oogoo069oo`03001o
ogoo00moo`0047oo00<007ooOol0Hgoo0P00Hgoo00<007ooOol03goo000@Ool00`00Oomoo`1SOol0
0`00Oomoo`1ROol00`00Oomoo`0?Ool0011oo`03001oogoo06=oo`03001oogoo06=oo`03001oogoo
00ioo`003goo00<007ooOol0I7oo00<007ooOol0Hgoo00<007ooOol03Woo000?Ool00`00Oomoo`1T
Ool00`00Oomoo`1TOol00`00Oomoo`0=Ool000ioo`03001oogoo06Eoo`03001oogoo06Aoo`03001o
ogoo00eoo`003Woo00<007ooOol0IGoo00<007ooOol0I7oo00<007ooOol03Goo000=Ool00`00Oomo
o`1VOol00`00Oomoo`1UOol00`00Oomoo`0<Ool000eoo`03001oogoo06Ioo`03001oogoo06Eoo`03
001oogoo00aoo`003Goo00<007ooOol0IWoo00<007ooOol0IGoo00<007ooOol037oo000<Ool00`00
Oomoo`1WOol00`00Oomoo`1VOol00`00Oomoo`0;Ool000aoo`03001oogoo06Moo`8006Moo`03001o
ogoo00]oo`0037oo00<007ooOol0Igoo00<007ooOol0Igoo00<007ooOol02Woo000<Ool00`00Oomo
o`1WOol00`00Oomoo`1WOol00`00Oomoo`0:Ool000]oo`03001oogoo06Qoo`03001oogoo06Moo`03
001oogoo00Yoo`002goo00<007ooOol0J7oo00<007ooOol0Igoo00<007ooOol02Woo000;Ool00`00
Oomoo`1XOol00`00Oomoo`1XOol00`00Oomoo`09Ool000Yoo`03001oogoo06Uoo`03001oogoo06Qo
o`03001oogoo00Uoo`002Woo00<007ooOol0JGoo00<007ooOol0J7oo00<007ooOol02Goo000:Ool0
0`00Oomoo`1YOol00`00Oomoo`1XOol00`00Oomoo`09Ool000Yoo`03001oogoo06Uoo`03001oogoo
06Uoo`03001oogoo00Qoo`002Goo00<007ooOol0JWoo00<007ooOol0JGoo00<007ooOol027oo0009
Ool00`00Oomoo`1ZOol00`00Oomoo`1YOol00`00Oomoo`08Ool000Uoo`03001oogoo06Yoo`8006]o
o`03001oogoo00Moo`002Goo00<007ooOol0JWoo00<007ooOol0JWoo00<007ooOol01goo0008Ool0
0`00Oomoo`1[Ool00`00Oomoo`1ZOol00`00Oomoo`07Ool000Qoo`03001oogoo06]oo`03001oogoo
06]oo`03001oogoo00Ioo`0027oo00<007ooOol0Jgoo00<007ooOol0Jgoo00<007ooOol01Woo0008
Ool00`00Oomoo`1[Ool00`00Oomoo`1[Ool00`00Oomoo`06Ool000Moo`03001oogoo06aoo`03001o
ogoo06]oo`03001oogoo00Ioo`001goo00<007ooOol0K7oo00<007ooOol0Jgoo00<007ooOol01Woo
0007Ool00`00Oomoo`1/Ool00`00Oomoo`1[Ool00`00Oomoo`06Ool000Moo`03001oogoo06aoo`03
001oogoo06aoo`03001oogoo00Eoo`001goo00<007ooOol0K7oo00<007ooOol0K7oo00<007ooOol0
1Goo0006Ool5000`Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool2000`Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool50005Ool000Ioo`03001oo`00035oo`03001o
o`0000Moo`03001oo`0002moo`03001oogoo02ioo`03001oo`0000Moo`03001oo`00035oo`03001o
ogoo00Eoo`000Woo0`0000Aoo`00Ool002aoo`<0009oo`03001oo`0000Uoo`03001oogoo02eoo`03
001oogoo02ioo`03001oo`0000Uoo`03001oogoo02moo`03001oogoo00Eoo`001Woo00<007oo0000
<Goo00<007oo00001goo0P00<7oo00<007ooOol0;Woo00<007oo00001goo0P00<Woo00<007ooOol0
1Goo0006Ool00`00Ool0000aOol00`00Ool00007Ool00`00Oomoo`0_Ool00`00Oomoo`0^Ool00`00
Ool00007Ool00`00Oomoo`0aOol00`00Oomoo`05Ool000Ioo`<0039oo`03001oogoo00Ioo`<002mo
o`03001oogoo02moo`03001oogoo00Ioo`<0031oo`8000Moo`001Woo00<007ooOol0KGoo00<007oo
Ool0K7oo00<007ooOol01Goo0006Ool00`00Oomoo`1]Ool00`00Oomoo`1]Ool00`00Oomoo`04Ool0
00Ioo`03001oogoo06eoo`03001oogoo06eoo`03001oogoo00Aoo`001Woo00<007ooOol0KGoo00<0
07ooOol0KGoo00<007ooOol017oo0006Ool00`00Oomoo`1]Ool00`00Oomoo`1]Ool00`00Oomoo`04
Ool00>d000001Goo0P002Woo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol017oo0005Ool00`00Oomoo`1^Ool00`00Oomoo`1]Ool00`00Oomoo`04Ool0
00Eoo`03001oogoo06ioo`03001oogoo06eoo`03001oogoo00Aoo`001Goo00<007ooOol0KWoo00<0
07ooOol0KGoo00<007ooOol017oo0005Ool00`00Oomoo`1^Ool00`00Oomoo`1]Ool00`00Oomoo`04
Ool000Eoo`03001oogoo06ioo`03001oogoo06eoo`03001oogoo00Aoo`001Goo00<007ooOol0KWoo
00<007ooOol0KGoo00<007ooOol017oo0005Ool00`00Oomoo`1^Ool00`00Oomoo`1]Ool00`00Oomo
o`04Ool000Ioo`03001oogoo06eoo`03001oogoo06eoo`03001oogoo00Aoo`001Woo00<007ooOol0
KGoo00<007ooOol0KGoo00<007ooOol017oo0006Ool00`00Oomoo`1]Ool2001^Ool00`00Oomoo`04
Ool000Ioo`03001oogoo06eoo`03001oogoo06eoo`03001oogoo00Aoo`001Woo00<007ooOol0KGoo
00<007ooOol0K7oo00<007ooOol01Goo0006Ool00`00Oomoo`1]Ool00`00Oomoo`1/Ool00`00Oomo
o`05Ool000Ioo`03001oogoo06eoo`03001oogoo06aoo`03001oogoo00Eoo`001Woo00<007ooOol0
KGoo00<007ooOol0K7oo00<007ooOol01Goo0006Ool00`00Oomoo`1]Ool00`00Oomoo`1/Ool00`00
Oomoo`05Ool000Ioo`03001oogoo06eoo`03001oogoo06aoo`03001oogoo00Eoo`001Woo00<007oo
Ool0KGoo00<007ooOol0K7oo00<007ooOol01Goo0006Ool00`00Oomoo`1]Ool00`00Oomoo`1[Ool0
0`00Oomoo`06Ool000Moo`03001oogoo06aoo`03001oogoo06]oo`03001oogoo00Ioo`001goo00<0
07ooOol0K7oo0P00K7oo00<007ooOol01Woo0007Ool00`00Oomoo`1/Ool00`00Oomoo`1[Ool00`00
Oomoo`06Ool000Moo`03001oogoo06aoo`03001oogoo06]oo`03001oogoo00Ioo`0027oo00<007oo
Ool0Jgoo00<007ooOol0Jgoo00<007ooOol01Woo0008Ool00`00Oomoo`1[Ool00`00Oomoo`1ZOol0
0`00Oomoo`07Ool000Qoo`03001oogoo06]oo`03001oogoo06Yoo`03001oogoo00Moo`0027oo00<0
07ooOol0Jgoo00<007ooOol0JWoo00<007ooOol01goo0008Ool00`00Oomoo`1[Ool00`00Oomoo`1Y
Ool00`00Oomoo`08Ool000Uoo`03001oogoo06Yoo`03001oogoo06Uoo`03001oogoo00Qoo`002Goo
00<007ooOol0JWoo00<007ooOol0JGoo00<007ooOol027oo0009Ool00`00Oomoo`1ZOol00`00Oomo
o`1XOol00`00Oomoo`09Ool000Uoo`03001oogoo06Yoo`03001oogoo06Qoo`03001oogoo00Uoo`00
2Woo00<007ooOol0JGoo0P00JGoo00<007ooOol02Goo000:Ool00`00Oomoo`1YOol00`00Oomoo`1X
Ool00`00Oomoo`09Ool000]oo`03001oogoo06Qoo`03001oogoo06Moo`03001oogoo00Yoo`002goo
00<007ooOol0J7oo00<007ooOol0Igoo00<007ooOol02Woo000;Ool00`00Oomoo`1XOol00`00Oomo
o`1WOol00`00Oomoo`0:Ool000aoo`03001oogoo06Moo`03001oogoo06Ioo`03001oogoo00]oo`00
37oo00<007ooOol0Igoo00<007ooOol0IWoo00<007ooOol02goo000<Ool00`00Oomoo`1WOol00`00
Oomoo`1VOol00`00Oomoo`0;Ool000eoo`03001oogoo06Ioo`03001oogoo06Ioo`03001oogoo00]o
o`003Goo00<007ooOol0IWoo00<007ooOol0IGoo00<007ooOol037oo000>Ool00`00Oomoo`1UOol0
0`00Oomoo`1UOol00`00Oomoo`0<Ool000ioo`03001oogoo06Eoo`8006Ioo`03001oogoo00aoo`00
3Woo00<007ooOol0IGoo00<007ooOol0I7oo00<007ooOol03Goo000?Ool00`00Oomoo`1TOol00`00
Oomoo`1TOol00`00Oomoo`0=Ool000moo`03001oogoo06Aoo`03001oogoo06=oo`03001oogoo00io
o`0047oo00<007ooOol0Hgoo00<007ooOol0Hgoo00<007ooOol03Woo000@Ool00`00Oomoo`1SOol0
0`00Oomoo`1ROol00`00Oomoo`0?Ool0011oo`03001oogoo06=oo`03001oogoo069oo`03001oogoo
00moo`004Goo00<007ooOol0HWoo00<007ooOol0HGoo00<007ooOol047oo000AOol00`00Oomoo`1R
Ool00`00Oomoo`1QOol00`00Oomoo`0@Ool0019oo`03001oogoo055oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo061oo`03001oogoo015oo`004Woo00<007ooOol0D7oo
00<007oo00001goo00<007oo000017oo00<007ooOol0H7oo00<007ooOol04Goo000BOol00`00Oomo
o`1@Ool00`00Ool00009Ool00`00Oomoo`02Ool2001POol00`00Oomoo`0BOol001=oo`03001oogoo
04moo`03001oo`0000Moo`8000Eoo`03001oogoo05moo`03001oogoo019oo`004goo00<007ooOol0
Cgoo00<007oo00001goo00<007ooOol017oo00<007ooOol0GWoo00<007ooOol04goo000DOol00`00
Oomoo`1?Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`1NOol00`00Oomoo`0COol001Aoo`03001o
ogoo05moo`03001oogoo05eoo`03001oogoo01Aoo`005Goo00<007ooOol0GWoo00<007ooOol0GGoo
00<007ooOol057oo000EOol00`00Oomoo`1NOol00`00Oomoo`1LOol00`00Oomoo`0EOol001Ioo`03
001oogoo05eoo`03001oogoo05aoo`03001oogoo01Eoo`005Woo00<007ooOol0GGoo00<007ooOol0
Fgoo00<007ooOol05Woo000GOol00`00Oomoo`1LOol00`00Oomoo`1KOol00`00Oomoo`0FOol001Qo
o`03001oogoo05]oo`03001oogoo05Yoo`03001oogoo01Moo`0067oo00<007ooOol0Fgoo0P00Fgoo
00<007ooOol05goo000IOol00`00Oomoo`1JOol00`00Oomoo`1IOol00`00Oomoo`0HOol001Uoo`03
001oogoo05Yoo`03001oogoo05Uoo`03001oogoo01Qoo`006Woo00<007ooOol0FGoo00<007ooOol0
F7oo00<007ooOol06Goo000JOol00`00Oomoo`1IOol00`00Oomoo`1HOol00`00Oomoo`0IOol001]o
o`03001oogoo05Qoo`03001oogoo05Moo`03001oogoo01Yoo`0077oo00<007ooOol0Egoo00<007oo
Ool0Egoo00<007ooOol06Woo000LOol00`00Oomoo`1GOol00`00Oomoo`1FOol00`00Oomoo`0KOol0
01eoo`03001oogoo05Ioo`03001oogoo05Ioo`03001oogoo01]oo`007Goo00<007ooOol0EWoo00<0
07ooOol0EGoo00<007ooOol077oo000NOol00`00Oomoo`1EOol00`00Oomoo`1EOol00`00Oomoo`0L
Ool001moo`03001oogoo05Aoo`8005Eoo`03001oogoo01eoo`007goo00<007ooOol0E7oo00<007oo
Ool0E7oo00<007ooOol07Goo000POol00`00Oomoo`1COol00`00Oomoo`1COol00`00Oomoo`0NOol0
021oo`03001oogoo05=oo`03001oogoo05=oo`03001oogoo01ioo`008Goo00<007ooOol0DWoo00<0
07ooOol0DWoo00<007ooOol07goo000ROol00`00Oomoo`1AOol00`00Oomoo`1BOol00`00Oomoo`0O
Ool0029oo`03001oogoo055oo`03001oogoo055oo`03001oogoo021oo`008goo00<007ooOol0D7oo
00<007ooOol0D7oo00<007ooOol08Goo000SOol00`00Oomoo`1@Ool00`00Oomoo`1@Ool00`00Oomo
o`0QOol002Aoo`03001oogoo04moo`03001oogoo04moo`03001oogoo029oo`0097oo00<007ooOol0
Cgoo00<007ooOol0CWoo00<007ooOol08goo000UOol00`00Oomoo`1>Ool00`00Oomoo`1>Ool00`00
Oomoo`0SOol002Ioo`03001oogoo04eoo`8004ioo`03001oogoo02Aoo`009Woo00<007ooOol0CGoo
00<007ooOol0CGoo00<007ooOol097oo000WOol00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomo
o`0UOol002Moo`03001oogoo04aoo`03001oogoo04]oo`03001oogoo02Ioo`00:7oo00<007ooOol0
Bgoo00<007ooOol0Bgoo00<007ooOol09Woo000YOol00`00Oomoo`1:Ool00`00Oomoo`1:Ool00`00
Oomoo`0WOol002Uoo`03001oogoo04Yoo`03001oogoo04Uoo`03001oogoo02Qoo`00:Woo00<007oo
Ool0BGoo00<007ooOol0BGoo00<007ooOol0:7oo000ZOol00`00Oomoo`19Ool00`00Oomoo`18Ool0
0`00Oomoo`0YOol002]oo`03001oogoo04Qoo`03001oogoo04Moo`03001oogoo02Yoo`00;7oo00<0
07ooOol0Agoo00<007ooOol0Agoo00<007ooOol0:Woo000/Ool00`00Oomoo`17Ool20017Ool00`00
Oomoo`0[Ool002eoo`03001oogoo04Ioo`03001oogoo04Eoo`03001oogoo02aoo`00;Goo00<007oo
Ool0AWoo00<007ooOol0AGoo00<007ooOol0;7oo000^Ool00`00Oomoo`15Ool00`00Oomoo`14Ool0
0`00Oomoo`0]Ool002moo`03001oogoo04Aoo`03001oogoo04Aoo`03001oogoo02eoo`00;goo00<0
07ooOol0A7oo00<007ooOol0@goo00<007ooOol0;Woo000`Ool00`00Oomoo`13Ool00`00Oomoo`12
Ool00`00Oomoo`0_Ool0031oo`03001oogoo04=oo`03001oogoo049oo`03001oogoo02moo`00<Goo
00<007ooOol0@Woo00<007ooOol0@Goo00<007ooOol0<7oo000bOol00`00Oomoo`0iOol50003Ool0
0`00Oomoo`10Ool00`00Oomoo`0aOol0039oo`03001oogoo03]oo`03001oogoo00=oo`03001oogoo
041oo`03001oogoo035oo`00<goo00<007ooOol0>Woo00<007ooOol00goo0P00@7oo00<007ooOol0
<Woo000cOol00`00Oomoo`0jOol00`00Oomoo`03Ool00`00Oomoo`0nOol00`00Oomoo`0cOol003Ao
o`03001oogoo03Uoo`03001oogoo00=oo`03001oogoo03ioo`03001oogoo03=oo`00=Goo00<007oo
Ool0=goo0P001Goo00<007ooOol0?Goo00<007ooOol0=7oo000eOol00`00Oomoo`0nOol00`00Oomo
o`0mOol00`00Oomoo`0dOol003Ioo`03001oogoo03eoo`03001oogoo03aoo`03001oogoo03Eoo`00
=goo00<007ooOol0?7oo00<007ooOol0>goo00<007ooOol0=Woo000hOol00`00Oomoo`0kOol00`00
Oomoo`0kOol00`00Oomoo`0fOol003Qoo`03001oogoo03]oo`03001oogoo03Yoo`03001oogoo03Mo
o`00>Goo00<007ooOol0>Woo00<007ooOol0>Goo00<007ooOol0>7oo000jOol00`00Oomoo`0iOol0
0`00Oomoo`0iOol00`00Oomoo`0hOol003Yoo`03001oogoo03Uoo`8003Uoo`03001oogoo03Uoo`00
>goo00<007ooOol0>7oo00<007ooOol0=goo00<007ooOol0>Woo000lOol00`00Oomoo`0gOol00`00
Oomoo`0fOol00`00Oomoo`0kOol003eoo`03001oogoo03Ioo`03001oogoo03Ioo`03001oogoo03]o
o`00?Goo00<007ooOol0=Woo00<007ooOol0=Goo00<007ooOol0?7oo000nOol00`00Oomoo`0eOol0
0`00Oomoo`0dOol00`00Oomoo`0mOol003moo`03001oogoo03Aoo`03001oogoo03=oo`03001oogoo
03ioo`00@7oo00<007ooOol0<goo00<007ooOol0<goo00<007ooOol0?Woo0010Ool00`00Oomoo`0c
Ool00`00Oomoo`0bOol00`00Oomoo`0oOol0045oo`03001oogoo039oo`03001oogoo035oo`03001o
ogoo041oo`00@Woo00<007ooOol0<Goo00<007ooOol0<7oo00<007ooOol0@Goo0013Ool00`00Oomo
o`0`Ool00`00Oomoo`0`Ool00`00Oomoo`11Ool004Aoo`03001oogoo02moo`80031oo`03001oogoo
049oo`00A7oo00<007ooOol0;goo00<007ooOol0;Woo00<007ooOol0@goo0015Ool00`00Oomoo`0^
Ool00`00Oomoo`0]Ool00`00Oomoo`14Ool004Ioo`03001oogoo02eoo`03001oogoo02eoo`03001o
ogoo04Aoo`00Agoo00<007ooOol0;7oo00<007ooOol0;7oo00<007ooOol0AGoo0018Ool00`00Oomo
o`0[Ool00`00Oomoo`0[Ool00`00Oomoo`16Ool004Uoo`03001oogoo02Yoo`03001oogoo02Yoo`03
001oogoo04Moo`00BWoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0B7oo001;Ool00`00
Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`19Ool004]oo`03001oogoo02Qoo`03001oogoo02Mo
o`03001oogoo04Yoo`00C7oo00<007ooOol09goo00<007ooOol09Woo00<007ooOol0Bgoo001=Ool0
0`00Oomoo`0VOol2000VOol00`00Oomoo`1<Ool004ioo`03001oogoo02Eoo`03001oogoo02=oo`80
04moo`00Cgoo00<007ooOol097oo00<007ooOol08Woo00<007ooOol0Cgoo001@Ool00`00Oomoo`0S
Ool00`00Oomoo`0QOol00`00Oomoo`1@Ool0055oo`03001oogoo029oo`03001oogoo021oo`03001o
ogoo055oo`00DWoo0P008Woo00<007ooOol07goo00<007ooOol0DWoo001DOol00`00Oomoo`0OOol0
0`00Oomoo`0NOol00`00Oomoo`1COol005Eoo`03001oogoo01ioo`03001oogoo01eoo`03001oogoo
05Aoo`00EWoo00<007ooOol07Goo00<007ooOol077oo00<007ooOol0EGoo001GOol2000MOol00`00
Oomoo`0KOol00`00Oomoo`1FOol005Uoo`03001oogoo01Yoo`03001oogoo01Yoo`03001oogoo05Mo
o`00FWoo00<007ooOol06Goo0P006Goo0P00FWoo001KOol2000IOol00`00Oomoo`0GOol00`00Oomo
o`1JOol005eoo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo05]oo`00GWoo0P005Woo00<0
07ooOol057oo0P00GWoo001POol00`00Oomoo`0COol00`00Oomoo`0COol00`00Oomoo`1NOol0065o
o`8001=oo`03001oogoo015oo`80065oo`00Hgoo00<007ooOol047oo00<007ooOol03goo0P00Hgoo
001TOol2000@Ool00`00Oomoo`0=Ool2001UOol006Ioo`8000ioo`03001oogoo00]oo`8006Moo`00
I7oo200017oo00<007ooOol00goo00<007ooOol027oo0`00JGoo001VOol00`00Oomoo`02Ool30000
17oo001oo`0017oo00<007ooOol017oo1000K7oo001VOol00`00Oomoo`05Ool?001`Ool006Ioo`03
001oogoo00Ioo`8000Eoo`03001oogoo07Aoo`00IWoo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol0M7oo001UOol20008Ool30004Ool00`00Oomoo`1dOol007Ioo`03001oogoo07Aoo`00MWoo
00<007ooOol0M7oo001fOol00`00Oomoo`1dOol007Ioo`03001oogoo07Aoo`00\
\>"],
  ImageRangeCache->{{{0, 236}, {295, 0}} -> {-1.05351, -1.06533, 0.00891748, 
  0.00891748}}]
}, Open  ]],

Cell[TextData[{
  "If it were desired to use this cam profile in a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model with a circular cam follower, the following constraint syntax could \
be used. This constraint implies that the cam is on body 2, the circular \
follower is on the origin of body 3 and has a radius of 0.2, the constraint \
is constraint 4, and the initial guess for the cam parameter ",
  StyleBox["s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is 2.0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a cam constraint that uses a splined cam."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CamToCircle1[4, Point[2, splinelocus[s]], {s, 2.0}, 
      Point[3, {0, 0}], .2]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["CamToCircle1", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Rolling Contact"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In order to have rolling contact between two cams, the arc length along \
the cam profile must be known as a function of the cam's controlling \
parameter. For cams that are built up from a sequence of piecewise continuous \
analytic functions, such as those shown in the first subsection of this \
chapter, it is often possible to build up a similar function that exactly \
represents the arc length of the cam. If a ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cam was used, the arc length cannot be explicitly stated, but ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " provides a function for approximating the arc length with another cubic \
spline."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ArcLength[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["splinefunc",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a one-dimensional ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object representing the arc length of the supplied ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A spline utility."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData["Example Mechanism"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following example models a snail-shaped cam profile rolling on a \
stationary line. The cam is defined with a ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and it is the single moving body in the mechanism. Note how the ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify the direction vector at the ends of the spline."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are data points for a snail profile."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(data = PolarToXY/@Table[{4 - i, i\ N[\[Pi]]}, {i, 1, 3, 0.2}]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is applied to the data."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(splinelocus = 
      SplineFit[data, 
        EndConditions \[Rule] {{.106, \(-.994\)}, {.152, \(-.476\)}}]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("SplineFunction["\[InvisibleSpace]{0, 10}\[InvisibleSpace]",<>]"\),
      SequenceForm[ "SplineFunction[", {0, 10}, ",<>]"],
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a plot of the spline."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[splinelocus[s], {s, 0, 10}, Compiled \[Rule] False, 
      AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .80423 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5925 0.189563 0.49473 0.189563 [
[.02381 .48223 -6 -9 ]
[.02381 .48223 6 0 ]
[.21337 .48223 -6 -9 ]
[.21337 .48223 6 0 ]
[.40294 .48223 -6 -9 ]
[.40294 .48223 6 0 ]
[.78206 .48223 -3 -9 ]
[.78206 .48223 3 0 ]
[.97163 .48223 -3 -9 ]
[.97163 .48223 3 0 ]
[.58 .1156 -12 -4.5 ]
[.58 .1156 0 4.5 ]
[.58 .30517 -12 -4.5 ]
[.58 .30517 0 4.5 ]
[.58 .68429 -6 -4.5 ]
[.58 .68429 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .80423 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .49473 m
.02381 .50098 L
s
[(-3)] .02381 .48223 0 1 Mshowa
.21337 .49473 m
.21337 .50098 L
s
[(-2)] .21337 .48223 0 1 Mshowa
.40294 .49473 m
.40294 .50098 L
s
[(-1)] .40294 .48223 0 1 Mshowa
.78206 .49473 m
.78206 .50098 L
s
[(1)] .78206 .48223 0 1 Mshowa
.97163 .49473 m
.97163 .50098 L
s
[(2)] .97163 .48223 0 1 Mshowa
.125 Mabswid
.06172 .49473 m
.06172 .49848 L
s
.09963 .49473 m
.09963 .49848 L
s
.13755 .49473 m
.13755 .49848 L
s
.17546 .49473 m
.17546 .49848 L
s
.25129 .49473 m
.25129 .49848 L
s
.2892 .49473 m
.2892 .49848 L
s
.32711 .49473 m
.32711 .49848 L
s
.36502 .49473 m
.36502 .49848 L
s
.44085 .49473 m
.44085 .49848 L
s
.47876 .49473 m
.47876 .49848 L
s
.51667 .49473 m
.51667 .49848 L
s
.55459 .49473 m
.55459 .49848 L
s
.63041 .49473 m
.63041 .49848 L
s
.66833 .49473 m
.66833 .49848 L
s
.70624 .49473 m
.70624 .49848 L
s
.74415 .49473 m
.74415 .49848 L
s
.81998 .49473 m
.81998 .49848 L
s
.85789 .49473 m
.85789 .49848 L
s
.8958 .49473 m
.8958 .49848 L
s
.93371 .49473 m
.93371 .49848 L
s
.25 Mabswid
0 .49473 m
1 .49473 L
s
.5925 .1156 m
.59875 .1156 L
s
[(-2)] .58 .1156 1 0 Mshowa
.5925 .30517 m
.59875 .30517 L
s
[(-1)] .58 .30517 1 0 Mshowa
.5925 .68429 m
.59875 .68429 L
s
[(1)] .58 .68429 1 0 Mshowa
.125 Mabswid
.5925 .15352 m
.59625 .15352 L
s
.5925 .19143 m
.59625 .19143 L
s
.5925 .22934 m
.59625 .22934 L
s
.5925 .26725 m
.59625 .26725 L
s
.5925 .34308 m
.59625 .34308 L
s
.5925 .38099 m
.59625 .38099 L
s
.5925 .4189 m
.59625 .4189 L
s
.5925 .45682 m
.59625 .45682 L
s
.5925 .53264 m
.59625 .53264 L
s
.5925 .57056 m
.59625 .57056 L
s
.5925 .60847 m
.59625 .60847 L
s
.5925 .64638 m
.59625 .64638 L
s
.5925 .07769 m
.59625 .07769 L
s
.5925 .03978 m
.59625 .03978 L
s
.5925 .00187 m
.59625 .00187 L
s
.5925 .72221 m
.59625 .72221 L
s
.5925 .76012 m
.59625 .76012 L
s
.5925 .79803 m
.59625 .79803 L
s
.25 Mabswid
.5925 0 m
.5925 .80423 L
s
0 0 m
1 0 L
1 .80423 L
0 .80423 L
closepath
clip
newpath
.5 Mabswid
.02381 .49473 m
.02514 .48492 L
.02698 .47472 L
.03328 .44823 L
.05425 .38397 L
.08598 .30973 L
.12957 .23044 L
.15291 .19612 L
.18001 .16257 L
.20476 .137 L
.23331 .11231 L
.29007 .07503 L
.32258 .05924 L
.35376 .04714 L
.38617 .03728 L
.41739 .03004 L
.44567 .02516 L
.46174 .02304 L
.47669 .02148 L
.49299 .02023 L
.50218 .01973 L
.50655 .01955 L
.51062 .01941 L
.51419 .01931 L
.51802 .01923 L
.5202 .0192 L
.52227 .01917 L
.52613 .01915 L
.53021 .01915 L
.53397 .01918 L
.53809 .01924 L
.54018 .01928 L
.54247 .01934 L
.55015 .0196 L
.55717 .01993 L
.56486 .02039 L
.57294 .021 L
.58649 .0223 L
.60121 .02411 L
.63291 .02951 L
.6611 .03612 L
.69275 .04578 L
.72159 .05692 L
.77487 .08445 L
.81943 .11583 L
.85978 .15275 L
.89786 .19814 L
.92715 .24446 L
.95098 .29692 L
.95968 .32303 L
Mistroke
.96705 .3518 L
.9697 .36502 L
.97202 .37911 L
.97373 .39241 L
.9749 .40444 L
.97535 .41053 L
.97573 .41721 L
.97588 .42057 L
.97601 .42416 L
.9761 .42755 L
.97615 .43063 L
.97618 .4337 L
.97619 .43653 L
.97617 .43964 L
.97613 .44292 L
.97607 .44577 L
.97599 .44843 L
.97575 .45449 L
.97538 .46103 L
.97487 .46789 L
.97365 .48006 L
.97189 .49303 L
.96946 .50704 L
.96365 .53213 L
.95693 .55427 L
.93719 .60142 L
.91394 .64105 L
.88394 .67937 L
.85119 .71091 L
.81312 .73837 L
.77536 .75837 L
.7388 .77211 L
.71769 .77775 L
.70727 .77994 L
.69763 .78163 L
.68908 .78284 L
.67966 .78387 L
.67479 .78428 L
.67023 .78459 L
.66541 .78483 L
.66271 .78493 L
.66024 .785 L
.65769 .78505 L
.65529 .78508 L
.65313 .78508 L
.6508 .78507 L
.64826 .78504 L
.64699 .78501 L
.64558 .78497 L
.6431 .7849 L
Mistroke
.64078 .7848 L
.63626 .78457 L
.63214 .78429 L
.62292 .78346 L
.6131 .78224 L
.60252 .78055 L
.58361 .77651 L
.5648 .77115 L
.54832 .76529 L
.5137 .74896 L
.4852 .73046 L
.45833 .70711 L
.43676 .68186 L
.42743 .66803 L
.41875 .65255 L
.41185 .63738 L
.40669 .62313 L
.40258 .60848 L
.39962 .59448 L
.39844 .58727 L
.39739 .57935 L
.39696 .5754 L
.39657 .57115 L
.39629 .56751 L
.39605 .56355 L
.39588 .55988 L
.39581 .55813 L
.39577 .55649 L
.39572 .55463 L
.3957 .55295 L
.39568 .55114 L
.39568 .55013 L
.39568 .5492 L
.39568 .54766 L
.3957 .54623 L
.39573 .54467 L
.39577 .543 L
.39582 .54127 L
.39588 .53963 L
.39603 .5366 L
.39623 .5333 L
.39646 .53024 L
.39699 .52467 L
.3977 .51889 L
.39862 .51291 L
.40067 .50291 L
.40294 .49473 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{296, 238},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004X0000kQ000`40O003h00O[Woo00<007ooOol0
Mgoo002^Ool2001hOol00:ioo`03001oogoo07Moo`00[Woo00<007ooOol0Mgoo002^Ool00`00Oomo
o`1gOol00:ioo`03001oogoo07Moo`00Sgoo5P002Goo00<007ooOol0Mgoo0026Ool9000FOol:001i
Ool0081oo`H002Qoo`P0079oo`00NGoo1`00;Woo00<007ooOol01Goo1P00K7oo001dOol5000eOol0
0`00Oomoo`0;Ool4001XOol0071oo`@003Yoo`03001oogoo00moo`@006Aoo`00KGoo0`00?Woo0P00
57oo0`00HGoo001ZOol30011Ool00`00Oomoo`0FOol4001MOol006Moo`<004Aoo`03001oogoo01Yo
o`<005Yoo`00IGoo0P00Agoo00<007ooOol07Goo0P00F7oo001SOol20019Ool00`00Oomoo`0OOol3
001EOol0065oo`8004]oo`03001oogoo029oo`8005=oo`00Ggoo0P00CGoo00<007ooOol097oo0P00
DGoo001MOol2001?Ool00`00Oomoo`0VOol2001?Ool005]oo`80055oo`03001oogoo02Qoo`8004eo
o`00FGoo0P00Dgoo00<007ooOol0:Woo0P00Bgoo001GOol2001EOol00`00Oomoo`0/Ool20019Ool0
05Eoo`8005Moo`8002moo`8004Moo`00Dgoo0P00FGoo00<007ooOol0<7oo0P00AGoo001BOol00`00
Oomoo`1IOol00`00Oomoo`0bOol20013Ool0051oo`8005aoo`03001oogoo03Aoo`03001oogoo041o
o`00Cgoo00<007ooOol0G7oo00<007ooOol0=Goo0P00@7oo001=Ool2001OOol00`00Oomoo`0gOol0
0`00Oomoo`0mOol004]oo`80065oo`03001oogoo03Qoo`03001oogoo03aoo`00BWoo00<007ooOol0
HGoo00<007ooOol0>Goo0P00?7oo0018Ool2001TOol00`00Oomoo`0kOol00`00Oomoo`0iOol004Mo
o`03001oogoo06Aoo`03001oogoo03aoo`03001oogoo03Qoo`00AGoo0P00H7oo0`0017oo00<007oo
Ool0?Goo0P00>7oo0014Ool00`00Oomoo`1POol00`00Oomoo`04Ool00`00Oomoo`0oOol00`00Oomo
o`0eOol004=oo`03001oogoo05aoo`<000=oo`03001oogoo00=oo`<0041oo`03001oogoo03Aoo`00
@Woo00<007ooOol0Hgoo00<007ooOol00goo00<007ooOol0@Goo00<007ooOol0<goo0011Ool00`00
Oomoo`1SOol00`00Ool00004Ool00`00Oomoo`12Ool00`00Oomoo`0bOol003moo`8006Moo`03001o
ogoo00=oo`03001oogoo04=oo`03001oogoo035oo`00?Woo00<007ooOol0KGoo00<007ooOol0A7oo
00<007ooOol0<7oo000mOol00`00Oomoo`1^Ool00`00Oomoo`15Ool00`00Oomoo`0_Ool003aoo`03
001oogoo06moo`03001oogoo04Ioo`8002moo`00>goo00<007ooOol0L7oo00<007ooOol0B7oo00<0
07ooOol0;7oo000jOol00`00Oomoo`1aOol00`00Oomoo`19Ool00`00Oomoo`0[Ool003Uoo`03001o
ogoo079oo`03001oogoo04Yoo`03001oogoo02Yoo`00>7oo00<007ooOol0Lgoo00<007ooOol0Bgoo
00<007ooOol0:Goo000gOol00`00Oomoo`1dOol2001=Ool00`00Oomoo`0XOol003Ioo`03001oogoo
07Eoo`03001oogoo04eoo`03001oogoo02Moo`00=Goo00<007ooOol0MWoo00<007ooOol0CWoo00<0
07ooOol09Woo000dOol00`00Oomoo`1gOol00`00Oomoo`1?Ool00`00Oomoo`0UOol003=oo`03001o
ogoo07Qoo`03001oogoo04moo`03001oogoo02Eoo`00<goo00<007ooOol0N7oo00<007ooOol0D7oo
00<007ooOol097oo000bOol00`00Oomoo`1iOol00`00Oomoo`1AOol00`00Oomoo`0SOol0035oo`03
001oogoo07Yoo`03001oogoo059oo`03001oogoo029oo`00<7oo00<007ooOol0Ngoo00<007ooOol0
Dgoo00<007ooOol08Goo000_Ool00`00Oomoo`1lOol00`00Oomoo`1DOol00`00Oomoo`0POol002mo
o`03001oogoo07aoo`03001oogoo05Aoo`03001oogoo021oo`00;Woo00<007ooOol0OGoo0P00EWoo
00<007ooOol07goo000]Ool00`00Oomoo`1nOol00`00Oomoo`1FOol00`00Oomoo`0NOol002aoo`03
001oogoo07moo`03001oogoo05Moo`03001oogoo01eoo`00;7oo00<007ooOol0Ogoo00<007ooOol0
F7oo00<007ooOol077oo000[Ool00`00Oomoo`20Ool00`00Oomoo`1HOol00`00Oomoo`0LOol002Yo
o`03001oogoo085oo`03001oogoo05Uoo`03001oogoo01]oo`00:Goo00<007ooOol0PWoo00<007oo
Ool0FWoo00<007ooOol06Woo000YOol00`00Oomoo`22Ool00`00Oomoo`1JOol00`00Oomoo`0JOol0
02Qoo`03001oogoo08=oo`03001oogoo05]oo`03001oogoo01Uoo`009goo00<007ooOol0Q7oo00<0
07ooOol0Fgoo00<007ooOol06Goo000WOol00`00Oomoo`24Ool00`00Oomoo`1LOol00`00Oomoo`0H
Ool002Ioo`03001oogoo08Eoo`8005ioo`03001oogoo01Moo`009Goo00<007ooOol0QWoo00<007oo
Ool0GGoo00<007ooOol05goo000UOol00`00Oomoo`26Ool00`00Oomoo`1NOol00`00Oomoo`0FOol0
02Aoo`03001oogoo08Moo`03001oogoo05moo`03001oogoo01Eoo`0097oo00<007ooOol0Qgoo00<0
07ooOol0Ggoo00<007ooOol05Goo000SOol00`00Oomoo`28Ool00`00Oomoo`1POol00`00Oomoo`0D
Ool002=oo`03001oogoo08Qoo`03001oogoo061oo`03001oogoo01Aoo`008Woo00<007ooOol0RGoo
00<007ooOol0HGoo00<007ooOol04goo000ROol00`00Oomoo`29Ool00`00Oomoo`1QOol00`00Oomo
o`0COol0025oo`03001oogoo08Yoo`03001oogoo069oo`03001oogoo019oo`008Goo00<007ooOol0
RWoo00<007ooOol0HWoo00<007ooOol04Woo000POol00`00Oomoo`2;Ool2001TOol00`00Oomoo`0A
Ool001moo`03001oogoo08aoo`03001oogoo06=oo`03001oogoo015oo`007goo00<007ooOol0S7oo
00<007ooOol0I7oo00<007ooOol047oo000NOol00`00Oomoo`2=Ool00`00Oomoo`1TOol00`00Oomo
o`0@Ool001ioo`03001oogoo08eoo`03001oogoo06Eoo`03001oogoo00moo`007Goo00<007ooOol0
SWoo00<007ooOol0IGoo00<007ooOol03goo000MOol00`00Oomoo`2>Ool00`00Oomoo`1VOol00`00
Oomoo`0>Ool001aoo`03001oogoo08moo`03001oogoo06Ioo`03001oogoo00ioo`0077oo00<007oo
Ool0Sgoo00<007ooOol0Igoo00<007ooOol03Goo000KOol00`00Oomoo`28Ool50003Ool00`00Oomo
o`1WOol00`00Oomoo`0=Ool001]oo`03001oogoo08Yoo`03001oogoo00=oo`03001oogoo06Moo`03
001oogoo00eoo`006Woo00<007ooOol0QGoo0`000goo00<007ooOol00goo0`00Igoo00<007ooOol0
3Goo000JOol00`00Oomoo`2;Ool00`00Oomoo`03Ool00`00Oomoo`1XOol00`00Oomoo`0<Ool001Uo
o`03001oogoo08aoo`03001oogoo00=oo`03001oogoo06Qoo`03001oogoo00aoo`006Goo00<007oo
Ool0Rgoo0P001Goo00<007ooOol0J7oo00<007ooOol037oo000HOol00`00Oomoo`2COol00`00Oomo
o`1XOol00`00Oomoo`0<Ool001Qoo`03001oogoo09=oo`03001oogoo06Uoo`03001oogoo00]oo`00
5goo00<007ooOol0U7oo00<007ooOol0JGoo00<007ooOol02goo000GOol00`00Oomoo`2DOol00`00
Oomoo`1YOol00`00Oomoo`0;Ool001Moo`03001oogoo09Aoo`03001oogoo06Yoo`03001oogoo00Yo
o`005Woo00<007ooOol0UGoo00<007ooOol0JWoo00<007ooOol02Woo000FOol00`00Oomoo`2EOol0
0`00Oomoo`1ZOol00`00Oomoo`0:Ool001Eoo`03001oogoo09Ioo`03001oogoo06]oo`03001oogoo
00Uoo`005Goo00<007ooOol0UWoo0P00K7oo00<007ooOol02Goo000DOol00`00Oomoo`2GOol00`00
Oomoo`1/Ool00`00Oomoo`08Ool001Aoo`03001oogoo09Moo`03001oogoo06aoo`03001oogoo00Qo
o`0057oo00<007ooOol0Ugoo00<007ooOol0K7oo00<007ooOol027oo000COol00`00Oomoo`2HOol0
0`00Oomoo`1/Ool00`00Oomoo`08Ool001=oo`03001oogoo09Qoo`03001oogoo06aoo`03001oogoo
00Qoo`004Woo00<007ooOol0VGoo00<007ooOol0K7oo00<007ooOol027oo000BOol00`00Oomoo`2I
Ool00`00Oomoo`1/Ool00`00Oomoo`08Ool0019oo`03001oogoo09Uoo`03001oogoo06aoo`03001o
ogoo00Qoo`004Goo00<007ooOol0VWoo00<007ooOol0KGoo00<007ooOol01goo000AOol00`00Oomo
o`2JOol00`00Oomoo`1]Ool00`00Oomoo`07Ool0011oo`03001oogoo09]oo`8006ioo`03001oogoo
00Moo`0047oo00<007ooOol0Vgoo00<007ooOol0KGoo00<007ooOol01goo000@Ool00`00Oomoo`2K
Ool00`00Oomoo`1^Ool00`00Oomoo`06Ool000moo`03001oogoo09aoo`03001oogoo06ioo`03001o
ogoo00Ioo`003goo00<007ooOol0W7oo00<007ooOol0KWoo00<007ooOol01Woo000?Ool00`00Oomo
o`2LOol00`00Oomoo`1^Ool00`00Oomoo`06Ool000ioo`03001oogoo09eoo`03001oogoo06ioo`03
001oogoo00Ioo`003Woo00<007ooOol0WGoo00<007ooOol0KWoo00<007ooOol01Woo000=Ool00`00
Oomoo`2NOol00`00Oomoo`1^Ool00`00Oomoo`06Ool000eoo`03001oogoo09ioo`03001oogoo06io
o`03001oogoo00Ioo`003Goo00<007ooOol0WWoo00<007ooOol0KWoo00<007ooOol01Woo000<Ool0
0`00Oomoo`2OOol2001_Ool00`00Oomoo`06Ool000aoo`03001oogoo09moo`03001oogoo06ioo`03
001oogoo00Ioo`0037oo00<007ooOol0Wgoo00<007ooOol0KWoo00<007ooOol01Woo000;Ool00`00
Oomoo`2POol00`00Oomoo`1^Ool00`00Oomoo`06Ool000]oo`03001oogoo0:1oo`03001oogoo06io
o`03001oogoo00Ioo`002Woo00<007ooOol0XGoo00<007ooOol0KWoo00<007ooOol01Woo000:Ool0
0`00Oomoo`2QOol00`00Oomoo`1^Ool00`00Oomoo`06Ool000Yoo`03001oogoo0:5oo`03001oogoo
06ioo`03001oogoo00Ioo`002Goo00<007ooOol0XWoo00<007ooOol0KWoo00<007ooOol01Woo0009
Ool00`00Oomoo`2ROol00`00Oomoo`1^Ool00`00Oomoo`06Ool000Uoo`03001oogoo0:9oo`03001o
ogoo06ioo`03001oogoo00Ioo`0027oo0P00=Woo0`00<goo1@00<goo0P00=7oo1@00<goo100027oo
0009Ool2000eOol00`00Oomoo`0eOol00`00Oomoo`0cOol00`00Oomoo`0eOol00`00Oomoo`0cOol0
1000Oomoo`0027oo0003Ool30002Ool2000aOol30003Ool00`00Oomoo`0^Ool30003Ool00`00Oomo
o`0cOol00`00Oomoo`0eOol00`00Oomoo`0dOol00`00Ool00008Ool000Qoo`03001oo`0003Ioo`03
001oogoo03Aoo`03001oogoo03=oo`03001oogoo03Eoo`03001oogoo03Aoo`03001oo`0000Qoo`00
27oo00<007oo0000=Goo00<007oo0000=Goo00<007ooOol0<goo00<007ooOol0=Goo00<007ooOol0
<goo00@007oo000000Qoo`0027oo0P00=goo00<007ooOol0<goo0P00=Goo00<007ooOol0=7oo0P00
=Woo00<007oo000027oo0008Ool00`00Oomoo`2SOol00`00Oomoo`1^Ool00`00Oomoo`06Ool000Mo
o`03001oogoo0:Aoo`03001oogoo06ioo`03001oogoo00Ioo`001goo00<007ooOol0Y7oo00<007oo
Ool0KWoo00<007ooOol01Woo0007Ool00`00Oomoo`2TOol00`00Oomoo`1]Ool00`00Oomoo`07Ool0
00Moo`03001oogoo0:Aoo`03001oogoo06eoo`03001oogoo00Moo`00o`00:0000Goo0007Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool000Moo`03001oogoo03Eoo`03001oogoo03Aoo`03001oogoo03Eoo`03001oogoo03Eo
o`03001oogoo03Aoo`8000Uoo`00MWoo00<007ooOol0=Goo00<007ooOol0K7oo00<007ooOol027oo
001fOol00`00Oomoo`0eOol00`00Oomoo`1/Ool00`00Oomoo`08Ool007Eoo`03001oogoo03Ioo`03
001oogoo06aoo`03001oogoo00Qoo`00MGoo00<007ooOol0=Woo00<007ooOol0K7oo00<007ooOol0
27oo001eOol00`00Oomoo`0fOol00`00Oomoo`1/Ool00`00Oomoo`08Ool007Eoo`03001oogoo03Io
o`03001oogoo06]oo`03001oogoo00Uoo`00MGoo00<007ooOol0=Woo00<007ooOol0Jgoo00<007oo
Ool02Goo001dOol00`00Oomoo`0gOol00`00Oomoo`1[Ool00`00Oomoo`09Ool007Aoo`03001oogoo
03Moo`8006aoo`03001oogoo00Uoo`00M7oo00<007ooOol0=goo00<007ooOol0Jgoo00<007ooOol0
2Goo001dOol00`00Oomoo`0gOol00`00Oomoo`1ZOol00`00Oomoo`0:Ool007Aoo`03001oogoo03Mo
o`03001oogoo06Yoo`03001oogoo00Yoo`00M7oo00<007ooOol0=goo00<007ooOol0JWoo00<007oo
Ool02Woo001dOol00`00Oomoo`0gOol00`00Oomoo`1ZOol00`00Oomoo`0:Ool007Aoo`03001oogoo
03Moo`03001oogoo06Uoo`03001oogoo00]oo`00M7oo00<007ooOol0=goo00<007ooOol0JGoo00<0
07ooOol02goo001dOol00`00Oomoo`0gOol00`00Oomoo`1YOol00`00Oomoo`0;Ool007Aoo`03001o
ogoo03Moo`03001oogoo06Qoo`03001oogoo00aoo`00M7oo00<007ooOol0=goo00<007ooOol0J7oo
00<007ooOol037oo001dOol00`00Oomoo`0gOol00`00Oomoo`1WOol00`00Oomoo`0=Ool007Eoo`03
001oogoo03Ioo`8006Qoo`03001oogoo00eoo`00MGoo00<007ooOol0=Woo00<007ooOol0IWoo00<0
07ooOol03Woo001eOol00`00Oomoo`0fOol00`00Oomoo`1VOol00`00Oomoo`0>Ool007Eoo`03001o
ogoo03Ioo`03001oogoo06Ioo`03001oogoo00ioo`00MGoo00<007ooOol0=Woo00<007ooOol0IGoo
00<007ooOol03goo001eOol00`00Oomoo`0fOol00`00Oomoo`1UOol00`00Oomoo`0?Ool007Eoo`03
001oogoo03Ioo`03001oogoo06Aoo`03001oogoo011oo`00MGoo00<007ooOol0=Woo00<007ooOol0
I7oo00<007ooOol047oo001eOol00`00Oomoo`0fOol00`00Oomoo`1SOol00`00Oomoo`0AOol007Eo
o`03001oogoo03Ioo`03001oogoo06=oo`03001oogoo015oo`00MWoo00<007ooOol0=Goo00<007oo
Ool0HWoo00<007ooOol04Woo001fOol00`00Oomoo`0eOol2001SOol00`00Oomoo`0BOol007Ioo`03
001oogoo03Eoo`03001oogoo065oo`03001oogoo01=oo`00Mgoo00<007ooOol0=7oo00<007ooOol0
H7oo00<007ooOol057oo001gOol00`00Oomoo`0dOol00`00Oomoo`1POol00`00Oomoo`0DOol007Qo
o`03001oogoo03=oo`03001oogoo05moo`03001oogoo01Eoo`00N7oo00<007ooOol0<goo00<007oo
Ool0Ggoo00<007ooOol05Goo001hOol00`00Oomoo`0cOol00`00Oomoo`1NOol00`00Oomoo`0FOol0
07Uoo`03001oogoo039oo`03001oogoo05eoo`03001oogoo01Moo`00NGoo00<007ooOol0<Woo00<0
07ooOol0GGoo00<007ooOol05goo001iOol00`00Oomoo`0bOol00`00Oomoo`1LOol00`00Oomoo`0H
Ool007Yoo`03001oogoo035oo`03001oogoo05]oo`03001oogoo01Uoo`00NWoo00<007ooOol0<Goo
0P00Fgoo00<007ooOol06Woo001kOol00`00Oomoo`0`Ool00`00Oomoo`1JOol00`00Oomoo`0JOol0
07]oo`03001oogoo031oo`03001oogoo05Uoo`03001oogoo01]oo`00O7oo00<007ooOol0;goo00<0
07ooOol0F7oo00<007ooOol077oo001lOol00`00Oomoo`0_Ool00`00Oomoo`1GOol00`00Oomoo`0M
Ool007eoo`03001oogoo02ioo`03001oogoo05Moo`03001oogoo01eoo`00OWoo00<007ooOol0;Goo
00<007ooOol0EWoo00<007ooOol07Woo001nOol00`00Oomoo`0]Ool00`00Oomoo`1EOol00`00Oomo
o`0OOol007moo`03001oogoo02aoo`03001oogoo05Aoo`03001oogoo021oo`00Ogoo00<007ooOol0
97oo1@000goo00<007ooOol0E7oo00<007ooOol087oo0020Ool00`00Oomoo`0UOol00`00Oomoo`03
Ool00`00Oomoo`1COol00`00Oomoo`0QOol0085oo`03001oogoo02Aoo`03001oogoo00=oo`<0059o
o`03001oogoo029oo`00PWoo00<007ooOol08goo00<007ooOol00goo00<007ooOol0DGoo00<007oo
Ool08goo0023Ool00`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`1@Ool00`00Oomoo`0TOol0
08=oo`03001oogoo025oo`8000Eoo`03001oogoo04moo`03001oogoo02Eoo`00Q7oo00<007ooOol0
9goo00<007ooOol0CGoo0P00:7oo0025Ool00`00Oomoo`0VOol00`00Oomoo`1<Ool00`00Oomoo`0X
Ool008Ioo`03001oogoo02Eoo`03001oogoo04]oo`03001oogoo02Uoo`00Qgoo00<007ooOol097oo
00<007ooOol0BWoo00<007ooOol0:Woo0028Ool00`00Oomoo`0SOol00`00Oomoo`19Ool00`00Oomo
o`0[Ool008Uoo`03001oogoo029oo`03001oogoo04Moo`8002ioo`00RWoo00<007ooOol08Goo00<0
07ooOol0AWoo00<007ooOol0;Woo002;Ool2000QOol20016Ool00`00Oomoo`0_Ool008eoo`03001o
ogoo01ioo`03001oogoo04=oo`80039oo`00SWoo00<007ooOol07Goo00<007ooOol0@Woo00<007oo
Ool0<Woo002?Ool00`00Oomoo`0LOol00`00Oomoo`11Ool00`00Oomoo`0cOol0091oo`8001aoo`03
001oogoo03moo`8003Ioo`00TWoo00<007ooOol06Goo00<007ooOol0?Woo00<007ooOol0=Woo002C
Ool2000IOol00`00Oomoo`0lOol2000iOol009Eoo`8001Moo`03001oogoo03Yoo`8003]oo`00Ugoo
00<007ooOol057oo00<007ooOol0>7oo0P00?Goo002HOol2000DOol00`00Oomoo`0fOol2000oOol0
09Yoo`80019oo`03001oogoo03Aoo`80045oo`00W7oo0P0047oo0P00<goo0P00@goo002NOol2000>
Ool00`00Oomoo`0_Ool30015Ool00:1oo`<000]oo`03001oogoo02eoo`8004Qoo`00Xgoo0P002Goo
00<007ooOol0:Woo0`00BWoo002UOol40005Ool00`00Oomoo`0WOol3001=Ool00:Uoo`H002Ioo`<0
051oo`00[Woo0P007goo1P00Dgoo002^Ool00`00Ool00008000?Ool7001IOol00:ioo`03001oogoo
00Qoo`l0061oo`00[Woo00<007ooOol0Mgoo002^Ool00`00Oomoo`1gOol00:ioo`03001oogoo07Mo
o`00[Woo0P00N7oo002^Ool00`00Oomoo`1gOol00001\
\>"],
  ImageRangeCache->{{{0, 295}, {237, 0}} -> {-3.12839, -2.60987, 0.0179012, 
  0.0179012}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To constrain the snail-wheel to be in rolling contact, the arc length \
function of both contacting surfaces must be known. Since one of the two \
surfaces in this model is flat and has a trivial arc length function, only \
the arc length function of the snail-wheel must be determined. The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["ArcLength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function may work quite slowly, because it involves numerically \
integrating each segment of the ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the arc length function of the snail spline."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(splinearc = ArcLength[splinelocus]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      \("SplineFunction["\[InvisibleSpace]{0, 10}\[InvisibleSpace]",<>]"\),
      SequenceForm[ "SplineFunction[", {0, 10}, ",<>]"],
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The snail-wheel is modeled with just three constraints."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint places the snail-wheel in contact with the surface of the \
ground. Note the initial guess for the cam parameter ",
  StyleBox["s",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " which sets the initial contact point at the bottom of the cam."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the angular orientation of the snail-wheel."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the arc length along the snail-wheel equal to the arc length along \
the flat surface. The arc length along the flat surface is simply the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the cam contact point."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Names are defined for each body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(cam = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the snail-wheel constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      CamToLine1[1, Point[cam, splinelocus[s]], {s, 2}, 
        Line[ground, {0, 0}, {1, 0}]], \n\t
      RotationLock1[2, cam, 2.0  \[Pi]\ T], \n\t
      Constraint[3, \n\t\t
        splinearc[s] == 
          \(Location[cam, splinelocus[s]]\)\[LeftDoubleBracket]1
            \[RightDoubleBracket]]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Reasonable initial guesses are set for the snail-wheel."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetGuess[X2 \[Rule] 4, Y2 \[Rule] 2.5]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now we run the model at three positions."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[{0, \(-0.2\), \(-0.4\)}] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      \({T \[Rule] 0, X2 \[Rule] 4.34518564923552119`, 
          Y2 \[Rule] 2.50884104028812293`, Th2 \[Rule] 0, 
          s \[Rule] 2.28681683248892086`}\), ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              RowBox[{"-", 
                StyleBox["0.2`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}]}], ",", 
            \(X2 \[Rule] 7.26072294979544619`\), ",", 
            \(Y2 \[Rule] 2.12281847689682834`\), ",", 
            \(Th2 \[Rule] \(-1.25663706143591724`\)\), ",", 
            \(s \[Rule] 4.26193988080569763`\)}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              RowBox[{"-", 
                StyleBox["0.4`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1]}]}], ",", 
            \(X2 \[Rule] 9.68032371800761382`\), ",", 
            \(Y2 \[Rule] 1.72878310459975281`\), ",", 
            \(Th2 \[Rule] \(-2.51327412287183449`\)\), ",", 
            \(s \[Rule] 6.21261708875191143`\)}], "}"}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Snail-wheel graphic at each solution point."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
  
%%Creator: Mathematica 
  
%%AspectRatio: .14489  
  
MathPictureStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
0.0238095 0.31746 0.00344968 0.31746 [ 
  
[ -0.001 -0.001 0 0 ] 
  
[ 1.001 .14589 0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
0 g 
  
p 
  
p 
  
.002 w 
  
0 0 m 
  
1 0 L 
  
s 
  
P 
  
p 
  
.002 w 
  
0 0 m 
  
0 .14489 L 
  
s 
  
P 
  
P 
  
p 
  
p 
  
.002 w 
  
0 .14489 m 
  
1 .14489 L 
  
s 
  
P 
  
p 
  
.002 w 
  
1 0 m 
  
1 .14489 L 
  
s 
  
P 
  
P 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 .14489 L 
  
0 .14489 L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
% Start of sub-graphic 
  
p 
  
0.0238095 0.00344968 0.321429 0.141437 MathSubStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
-0.0909091 0.0909091 0.00909091 0.0909091 [ 
  
[ 0 0 0 0 ] 
  
[ 1 .46364 0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 .46364 L 
  
0 .46364 L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
p 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(x)] .39502 .23717 -1.5 -0.9 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(y)] .30411 .32808 -1.5 -0.9 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(2)] .30411 .23717 -1.5 -0.9 Mshowa 
  
P 
  
.004 w 
  
.39502 .23717 m 
  
.30411 .23717 L 
  
.30411 .32808 L 
  
s 
  
.37684 .22808 m 
  
.39502 .23717 L 
  
.37684 .24626 L 
  
s 
  
.29502 .30989 m 
  
.30411 .32808 L 
  
.3132 .30989 L 
  
s 
  
P 
  
.01 w 
  
0 .00909 m 
  
1 .00909 L 
  
s 
  
.02 w 
  
.27309 .00909 Mdot 
  
P 
  
p 
  
p 
  
p 
  
.004 w 
  
.03138 .23717 m 
  
.03207 .23212 L 
  
.03313 .22644 L 
  
.03632 .21341 L 
  
.04665 .18228 L 
  
.06165 .1475 L 
  
.08062 .11278 L 
  
.10285 .08184 L 
  
.12768 .05714 L 
  
.14091 .04706 L 
  
.15462 .03838 L 
  
.16872 .03101 L 
  
.18318 .02485 L 
  
.19792 .01984 L 
  
.21289 .01587 L 
  
.22044 .01425 L 
  
.22803 .01287 L 
  
.23564 .0117 L 
  
.24327 .01074 L 
  
.25091 .01001 L 
  
.25473 .00972 L 
  
.25855 .00949 L 
  
.26046 .00939 L 
  
.26237 .00931 L 
  
.26428 .00924 L 
  
.26618 .00918 L 
  
.26809 .00914 L 
  
.27 .00911 L 
  
.2719 .00909 L 
  
.2738 .00909 L 
  
.2757 .0091 L 
  
.2776 .00913 L 
  
.2795 .00917 L 
  
.2814 .00922 L 
  
.28329 .00929 L 
  
.28518 .00937 L 
  
.28896 .00957 L 
  
.29648 .01013 L 
  
.30396 .01092 L 
  
.31137 .01192 L 
  
.31872 .01314 L 
  
.33319 .01625 L 
  
.34729 .02024 L 
  
.36095 .02512 L 
  
.38672 .03754 L 
  
.41011 .05323 L 
  
.43086 .0717 L 
  
.4487 .09244 L 
  
.46338 .11494 L 
  
.47465 .13872 L 
  
Mistroke 
  
.479 .15093 L 
  
.48249 .16328 L 
  
.48514 .17572 L 
  
.48615 .18196 L 
  
.48695 .18819 L 
  
.48754 .19441 L 
  
.48776 .19752 L 
  
.48785 .19907 L 
  
.48792 .20062 L 
  
.48799 .20217 L 
  
.48804 .20372 L 
  
.48808 .20527 L 
  
.4881 .20681 L 
  
.48811 .20836 L 
  
.48811 .2099 L 
  
.4881 .21143 L 
  
.48807 .21297 L 
  
.48803 .2145 L 
  
.48798 .21604 L 
  
.48784 .21909 L 
  
.48765 .22214 L 
  
.48741 .22517 L 
  
.48677 .2312 L 
  
.48593 .23717 L 
  
.48365 .24891 L 
  
.4806 .26034 L 
  
.47683 .27144 L 
  
.47237 .28216 L 
  
.46154 .30231 L 
  
.44842 .32047 L 
  
.43333 .33632 L 
  
.41661 .34964 L 
  
.39864 .36034 L 
  
.38932 .36469 L 
  
.37985 .36836 L 
  
.37026 .37135 L 
  
.36545 .37259 L 
  
.36062 .37366 L 
  
.3558 .37455 L 
  
.35098 .37527 L 
  
.34857 .37556 L 
  
.34617 .37581 L 
  
.34377 .37601 L 
  
.34138 .37617 L 
  
.34019 .37624 L 
  
.33899 .37629 L 
  
.3378 .37634 L 
  
.33661 .37637 L 
  
.33542 .3764 L 
  
.33424 .37641 L 
  
Mistroke 
  
.33305 .37641 L 
  
.33187 .3764 L 
  
.33069 .37639 L 
  
.32951 .37636 L 
  
.32833 .37632 L 
  
.32715 .37627 L 
  
.32248 .37598 L 
  
.32015 .37578 L 
  
.31784 .37554 L 
  
.31324 .37494 L 
  
.30421 .37331 L 
  
.29541 .37112 L 
  
.28689 .3684 L 
  
.2708 .36148 L 
  
.25624 .3528 L 
  
.24343 .34256 L 
  
.23251 .33092 L 
  
.2278 .32464 L 
  
.22362 .31807 L 
  
.21999 .31124 L 
  
.21692 .30418 L 
  
.21443 .2969 L 
  
.2125 .28947 L 
  
.21174 .28573 L 
  
.21111 .282 L 
  
.2106 .27828 L 
  
.21021 .27459 L 
  
.21006 .27276 L 
  
.20994 .27094 L 
  
.20984 .26913 L 
  
.20981 .26823 L 
  
.20978 .26734 L 
  
.20975 .26645 L 
  
.20973 .26557 L 
  
.20972 .26469 L 
  
.20972 .26381 L 
  
.20972 .26294 L 
  
.20973 .26207 L 
  
.20974 .26121 L 
  
.20976 .26036 L 
  
.20982 .25867 L 
  
.20986 .25783 L 
  
.2099 .257 L 
  
.21013 .25375 L 
  
.21028 .25217 L 
  
.21045 .25061 L 
  
.21085 .24761 L 
  
.21133 .24475 L 
  
.21189 .24205 L 
  
.2132 .23717 L 
  
Mistroke 
  
Mfstroke 
  
P 
  
P 
  
P 
  
P 
  
MathSubEnd 
  
P 
  
% End of sub-graphic 
  
% Start of sub-graphic 
  
p 
  
0.35119 0.00344968 0.64881 0.141437 MathSubStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
-0.0909091 0.0909091 0.00909091 0.0909091 [ 
  
[ 0 0 0 0 ] 
  
[ 1 .46364 0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 .46364 L 
  
0 .46364 L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
p 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(x)] .59725 .11561 -1.89011 .57784 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(y)] .65562 .23017 -1.89011 .57784 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(2)] .56916 .20207 -1.89011 .57784 Mshowa 
  
P 
  
.004 w 
  
.59725 .11561 m 
  
.56916 .20207 L 
  
.65562 .23017 L 
  
s 
  
.58298 .1301 m 
  
.59725 .11561 L 
  
.60028 .13572 L 
  
s 
  
.63552 .23319 m 
  
.65562 .23017 L 
  
.64113 .2159 L 
  
s 
  
P 
  
.01 w 
  
0 .00909 m 
  
1 .00909 L 
  
s 
  
.02 w 
  
.54008 .00909 Mdot 
  
P 
  
p 
  
p 
  
p 
  
.004 w 
  
.48488 .46145 m 
  
.46381 .44942 L 
  
.4374 .42997 L 
  
.40895 .40495 L 
  
.3818 .37618 L 
  
.36974 .36096 L 
  
.35924 .34549 L 
  
.35049 .3299 L 
  
.34342 .31424 L 
  
.33793 .29854 L 
  
.33574 .29068 L 
  
.3339 .28282 L 
  
.33241 .27497 L 
  
.33125 .26712 L 
  
.33079 .26321 L 
  
.3304 .25929 L 
  
.3301 .25538 L 
  
.32997 .25343 L 
  
.32986 .25148 L 
  
.32978 .24952 L 
  
.32971 .24757 L 
  
.32965 .24563 L 
  
.32962 .24368 L 
  
.3296 .24173 L 
  
.3296 .23979 L 
  
.32962 .23785 L 
  
.32965 .2359 L 
  
.3297 .23397 L 
  
.32977 .23203 L 
  
.32985 .23009 L 
  
.32995 .22816 L 
  
.3305 .22044 L 
  
.33087 .2166 L 
  
.3313 .21276 L 
  
.33232 .20512 L 
  
.33501 .18997 L 
  
.33854 .17505 L 
  
.34288 .16042 L 
  
.35393 .1323 L 
  
.36804 .10615 L 
  
.38505 .08248 L 
  
.40483 .06181 L 
  
.42698 .04442 L 
  
.45095 .03039 L 
  
.46345 .02467 L 
  
.47619 .01983 L 
  
.48911 .01588 L 
  
.49561 .01424 L 
  
.50213 .01283 L 
  
.50866 .01164 L 
  
Mistroke 
  
.51519 .01069 L 
  
.51845 .0103 L 
  
.52171 .00996 L 
  
.52497 .00968 L 
  
.52822 .00945 L 
  
.52985 .00936 L 
  
.53147 .00928 L 
  
.5331 .00922 L 
  
.53472 .00916 L 
  
.53634 .00913 L 
  
.53795 .0091 L 
  
.53957 .00909 L 
  
.54118 .00909 L 
  
.5428 .00911 L 
  
.54441 .00914 L 
  
.54762 .00924 L 
  
.54922 .00931 L 
  
.55082 .00939 L 
  
.55401 .00959 L 
  
.56036 .01015 L 
  
.56666 .01092 L 
  
.57908 .01305 L 
  
.5912 .01596 L 
  
.60299 .01964 L 
  
.62534 .02916 L 
  
.64574 .04138 L 
  
.66394 .05595 L 
  
.67976 .07248 L 
  
.69297 .09056 L 
  
.69854 .10007 L 
  
.70339 .10982 L 
  
.7075 .11976 L 
  
.71089 .12984 L 
  
.71355 .14001 L 
  
.71551 .15023 L 
  
.71623 .15534 L 
  
.71652 .15789 L 
  
.71677 .16043 L 
  
.71697 .16298 L 
  
.71714 .16552 L 
  
.7172 .16679 L 
  
.71726 .16805 L 
  
.7173 .16932 L 
  
.71733 .17058 L 
  
.71736 .17184 L 
  
.71737 .1731 L 
  
.71737 .17436 L 
  
.71736 .17562 L 
  
.71734 .17687 L 
  
.71731 .17813 L 
  
Mistroke 
  
.71727 .17937 L 
  
.71722 .18062 L 
  
.71691 .18558 L 
  
.71669 .18805 L 
  
.71643 .1905 L 
  
.71498 .20017 L 
  
.71401 .20491 L 
  
.71288 .20958 L 
  
.70685 .2275 L 
  
.70301 .23596 L 
  
.69867 .24405 L 
  
.68864 .25901 L 
  
.6771 .27217 L 
  
.66434 .28333 L 
  
.65064 .29235 L 
  
.6362 .29914 L 
  
.62877 .30168 L 
  
.62501 .30272 L 
  
.62123 .30362 L 
  
.61743 .30437 L 
  
.61361 .30497 L 
  
.6117 .30521 L 
  
.60978 .30541 L 
  
.60787 .30558 L 
  
.60691 .30565 L 
  
.60594 .3057 L 
  
.60498 .30575 L 
  
.60402 .30579 L 
  
.60306 .30582 L 
  
.6021 .30584 L 
  
.60114 .30585 L 
  
.60017 .30585 L 
  
.59921 .30584 L 
  
.59825 .30582 L 
  
.59633 .30576 L 
  
.59537 .30571 L 
  
.59441 .30566 L 
  
.5925 .30553 L 
  
.59059 .30536 L 
  
.5868 .30493 L 
  
.58306 .30437 L 
  
.57573 .30294 L 
  
.5687 .30111 L 
  
.56206 .29897 L 
  
.55027 .29399 L 
  
.54106 .28853 L 
  
Mfstroke 
  
P 
  
P 
  
P 
  
P 
  
MathSubEnd 
  
P 
  
% End of sub-graphic 
  
% Start of sub-graphic 
  
p 
  
0.678571 0.00344968 0.97619 0.141437 MathSubStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
-0.0909091 0.0909091 0.00909091 0.0909091 [ 
  
[ 0 0 0 0 ] 
  
[ 1 .46364 0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 .46364 L 
  
0 .46364 L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
p 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(x)] .71557 .11282 .33185 1.25712 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(y)] .84256 .09271 .33185 1.25712 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(2)] .78912 .16625 .33185 1.25712 Mshowa 
  
P 
  
.004 w 
  
.71557 .11282 m 
  
.78912 .16625 L 
  
.84256 .09271 L 
  
s 
  
.72494 .13086 m 
  
.71557 .11282 L 
  
.73563 .11615 L 
  
s 
  
.83922 .11276 m 
  
.84256 .09271 L 
  
.82451 .10207 L 
  
s 
  
P 
  
.01 w 
  
0 .00909 m 
  
1 .00909 L 
  
s 
  
.02 w 
  
.76041 .00909 Mdot 
  
P 
  
p 
  
p 
  
p 
  
.004 w 
  
s 
  
1 .33543 m 
  
.9918 .34287 L 
  
s 
  
.9918 .34287 m 
  
.96515 .36199 L 
  
.93256 .38131 L 
  
.91491 .39024 L 
  
.89681 .39825 L 
  
.87861 .40501 L 
  
.86957 .40783 L 
  
.86064 .41022 L 
  
.85182 .41217 L 
  
.84312 .41371 L 
  
.83881 .41433 L 
  
.83452 .41485 L 
  
.83027 .41527 L 
  
.82604 .4156 L 
  
.82394 .41573 L 
  
.82184 .41583 L 
  
.81975 .41591 L 
  
.81767 .41597 L 
  
.81559 .416 L 
  
.81352 .41602 L 
  
.81146 .41601 L 
  
.80941 .41597 L 
  
.80736 .41592 L 
  
.80532 .41584 L 
  
.80126 .41563 L 
  
.79722 .41533 L 
  
.79322 .41494 L 
  
.78529 .41394 L 
  
.77747 .41262 L 
  
.76216 .4091 L 
  
.74728 .40449 L 
  
.73284 .3989 L 
  
.70525 .38519 L 
  
.67958 .36858 L 
  
.65626 .34938 L 
  
.63574 .32789 L 
  
.61849 .30439 L 
  
.61123 .29198 L 
  
.60494 .2792 L 
  
.59962 .2661 L 
  
.59524 .25275 L 
  
.59181 .23924 L 
  
.58931 .22562 L 
  
.58841 .21879 L 
  
.58804 .21538 L 
  
.58774 .21197 L 
  
.58748 .20856 L 
  
.58729 .20515 L 
  
.58721 .20345 L 
  
.58715 .20175 L 
  
Mistroke 
  
.5871 .20005 L 
  
.58707 .19835 L 
  
.58705 .19666 L 
  
.58704 .19496 L 
  
.58705 .19327 L 
  
.58707 .19158 L 
  
.58711 .18989 L 
  
.58716 .18821 L 
  
.5873 .18485 L 
  
.5875 .1815 L 
  
.58775 .17816 L 
  
.58842 .17152 L 
  
.58932 .16494 L 
  
.59043 .15844 L 
  
.59328 .14566 L 
  
.59694 .13322 L 
  
.60138 .12117 L 
  
.61241 .09841 L 
  
.62607 .0777 L 
  
.64203 .05938 L 
  
.65996 .04376 L 
  
.67944 .03095 L 
  
.70005 .02102 L 
  
.71063 .01715 L 
  
.72133 .01404 L 
  
.72671 .01276 L 
  
.73209 .01168 L 
  
.73748 .01078 L 
  
.74286 .01008 L 
  
.74555 .0098 L 
  
.74823 .00957 L 
  
.75091 .00938 L 
  
.75358 .00924 L 
  
.75492 .00919 L 
  
.75625 .00915 L 
  
.75758 .00912 L 
  
.75891 .0091 L 
  
.76024 .00909 L 
  
.76157 .0091 L 
  
.76289 .00911 L 
  
.76422 .00914 L 
  
.76554 .00917 L 
  
.76686 .00922 L 
  
.76949 .00935 L 
  
.77211 .00953 L 
  
.77472 .00975 L 
  
.7799 .01031 L 
  
.78504 .01104 L 
  
.79513 .013 L 
  
.80496 .0156 L 
  
Mistroke 
  
.81447 .01881 L 
  
.82362 .02261 L 
  
.84067 .03189 L 
  
.85585 .04315 L 
  
.86906 .05605 L 
  
.88019 .07021 L 
  
.88914 .08526 L 
  
.89581 .10083 L 
  
.89828 .10873 L 
  
.89929 .11269 L 
  
.90016 .11665 L 
  
.90088 .12062 L 
  
.90145 .12458 L 
  
.90168 .12656 L 
  
.90187 .12854 L 
  
.90203 .13051 L 
  
.90215 .13249 L 
  
.9022 .13347 L 
  
.90224 .13446 L 
  
.90227 .13544 L 
  
.90228 .13642 L 
  
.90229 .1374 L 
  
.90229 .13838 L 
  
.90229 .13936 L 
  
.90227 .14034 L 
  
.90224 .14131 L 
  
.9022 .14229 L 
  
.9021 .14423 L 
  
.90196 .14617 L 
  
.90179 .14811 L 
  
.90133 .15195 L 
  
.90072 .15577 L 
  
.89905 .16329 L 
  
.89678 .17064 L 
  
.89397 .17778 L 
  
.88708 .19117 L 
  
.87908 .20295 L 
  
.8707 .21262 L 
  
.86267 .21969 L 
  
Mfstroke 
  
P 
  
P 
  
P 
  
P 
  
MathSubEnd 
  
P 
  
% End of sub-graphic 
  
P 
  
P 
  
% End of Graphics 
  
MathPictureEnd 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{469, 68},
  ImageMargins->{{0, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007E0000A1000`40O003h00OogooeWoo0005Oooo
003;0006Ool000Eoo`03001oogoo0?moolMoo`03001oogoo00Aoo`001Goo00<007ooOol0ogooagoo
00<007ooOol017oo0005Ool00`00Oomoo`08Oon9000=Oon8000=Oon9000:Ool00`00Oomoo`04Ool0
00Eoo`03001oogoo02=oo`<000Moo`03001oogoo00Eoo`<00:Ioo`<000Eoo`03001oogoo00Aoo`<0
0:9oo`<000Aoo`03001oogoo00Aoo`<002=oo`03001oogoo00Aoo`001Goo00<007ooOol08Goo0P00
5Goo0P00Xgoo00<007ooOol047oo0P00WWoo0P004Goo00<007ooOol087oo00<007ooOol017oo0005
Ool00`00Oomoo`0OOol2000IOol2002OOol2000EOol2002KOol00`00Oomoo`0AOol3000POol00`00
Oomoo`04Ool000Eoo`03001oogoo01eoo`8001eoo`8009]oo`8001Uoo`8009Qoo`03001oogoo01=o
o`04001oo`00000NOol00`00Oomoo`04Ool000Eoo`03001oogoo01]oo`80025oo`8009Qoo`03001o
ogoo01]oo`8009Eoo`03001oogoo01Aoo`05001oogooOol0000MOol00`00Oomoo`04Ool000Eoo`03
001oogoo01Yoo`03001oogoo02=oo`03001oogoo09=oo`80021oo`03001oogoo091oo`8001Ioo`03
001oo`0000=oo`03001oogoo01Yoo`03001oogoo00Aoo`001Goo00<007ooOol06Goo00<007ooOol0
9Goo0P00TWoo00<007ooOol08Goo00<007ooOol0SWoo00<007ooOol05Woo00@007oo0000009oo`03
001oogoo01Yoo`03001oogoo00Aoo`001Goo00<007ooOol067oo00<007ooOol0:7oo00<007ooOol0
SWoo00<007ooOol08goo00<007ooOol0S7oo00<007ooOol01Goo0P0000=oo`00Ool057oo00<007oo
Ool06Goo00<007ooOol017oo0005Ool00`00Oomoo`0GOol00`00Oomoo`0ZOol00`00Oomoo`2<Ool0
0`00Oomoo`0UOol00`00Oomoo`2:Ool00`00Oomoo`08Ool00`00Oomoo`0EOol00`00Oomoo`0HOol0
0`00Oomoo`04Ool000Eoo`03001oogoo01Ioo`03001oogoo02]oo`03001oogoo08]oo`03001oogoo
02Ioo`03001oogoo08Uoo`03001oogoo00Qoo`03001oo`0001Moo`03001oogoo01Moo`03001oogoo
00Aoo`001Goo00<007ooOol05Goo00<007ooOol0;Goo00<007ooOol0RGoo00<007ooOol07Goo0P00
00=oo`00Ool01Woo00<007ooOol0R7oo00<007ooOol06goo00<007ooOol017oo00<007ooOol05goo
00<007ooOol017oo0005Ool00`00Oomoo`0DOol00`00Oomoo`0_Ool00`00Oomoo`28Ool00`00Oomo
o`0OOol00`00Oomoo`06Ool00`00Oomoo`27Ool00`00Oomoo`0JOol30007Ool00`00Oomoo`0FOol0
0`00Oomoo`04Ool000Eoo`03001oogoo01Aoo`03001oogoo02moo`03001oogoo08Moo`03001oogoo
01moo`03001oo`0000Qoo`03001oogoo08Ioo`03001oogoo01]oo`8000Moo`03001oogoo01Ioo`03
001oogoo00Aoo`001Goo00<007ooOol04goo00<007ooOol0<Goo00<007ooOol0QGoo00<007ooOol0
7Goo00<007ooOol02goo00<007ooOol0QGoo00<007ooOol037oo10002goo00<007oo00001goo00<0
07ooOol05Woo00<007ooOol017oo0005Ool00`00Oomoo`0COol00`00Oomoo`0bOol00`00Oomoo`24
Ool00`00Oomoo`0LOol2000>Ool00`00Oomoo`24Ool00`00Oomoo`0<Ool30005Ool30003Ool00`00
Oomoo`08Ool00`00Oomoo`0FOol00`00Oomoo`04Ool000Eoo`03001oogoo019oo`03001oogoo03=o
o`03001oogoo08=oo`03001oogoo01aoo`<000ioo`03001oogoo08=oo`03001oogoo00ioo`03001o
o`0000Aoo`8000=oo`03001oogoo00Uoo`03001oogoo01Ioo`03001oogoo00Aoo`001Goo00<007oo
Ool04Woo00<007ooOol0=7oo00<007ooOol0PWoo00<007ooOol07Goo0P003Woo00<007ooOol0Pgoo
00<007ooOol04Goo00<007ooOol00goo00@007ooOol000]oo`03001oogoo01Ioo`03001oogoo00Ao
o`001Goo00<007ooOol04Goo00<007ooOol0=Goo00<007ooOol0PGoo00<007ooOol07Woo00<007oo
Ool03Goo00<007ooOol0PWoo00<007ooOol04goo0P000goo00<007oo000037oo00<007ooOol05Woo
00<007ooOol017oo0005Ool00`00Oomoo`0AOol00`00Oomoo`0eOol00`00Oomoo`21Ool00`00Oomo
o`0MOol00`00Oomoo`0?Ool00`00Oomoo`21Ool00`00Oomoo`0EOol5000=Ool00`00Oomoo`0FOol0
0`00Oomoo`04Ool000Eoo`03001oogoo011oo`03001oogoo03Ioo`03001oogoo081oo`03001oogoo
01ioo`03001oogoo00moo`03001oogoo085oo`03001oogoo01Ioo`800003Ool007oo00aoo`03001o
ogoo01Ioo`03001oogoo00Aoo`001Goo00<007ooOol047oo00<007ooOol0=goo00<007ooOol0Ogoo
00<007ooOol07Woo00<007ooOol03goo00<007ooOol0PGoo00<007ooOol067oo00<007ooOol037oo
00<007ooOol05Woo00<007ooOol017oo0005Ool00`00Oomoo`0?Ool00`00Oomoo`0hOol00`00Oomo
o`1oOol00`00Oomoo`0MOol00`00Oomoo`0@Ool00`00Oomoo`21Ool00`00Oomoo`0WOol00`00Oomo
o`0FOol00`00Oomoo`04Ool000Eoo`03001oogoo00moo`03001oogoo03Qoo`03001oogoo07ioo`03
001oogoo01ioo`03001oo`00008000ioo`03001oogoo085oo`03001oogoo02Ioo`03001oogoo01Mo
o`03001oogoo00Aoo`001Goo00<007ooOol03goo00<007ooOol0>7oo00<007ooOol0OWoo00<007oo
Ool07Woo00@007oo000000Yoo`8000=oo`03001oogoo085oo`03001oogoo02Eoo`03001oogoo01Qo
o`03001oogoo00Aoo`001Goo00<007ooOol03Woo00<007ooOol0>Goo00<007ooOol0OWoo00<007oo
Ool07Goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`0008=oo`03001oogoo02Eoo`03
001oogoo01Qoo`03001oogoo00Aoo`001Goo00<007ooOol03Woo00<007ooOol0>Goo0P00Ogoo00<0
07ooOol07Goo0P000goo00<007ooOol027oo00D007ooOomoo`0008=oo`03001oogoo02Aoo`03001o
ogoo01Uoo`03001oogoo00Aoo`001Goo00<007ooOol03Goo00<007ooOol0>goo00<007ooOol0OGoo
00<007ooOol07goo10002Goo00D007oo001oo`0008Aoo`03001oogoo02=oo`03001oogoo01Yoo`03
001oogoo00Aoo`001Goo00<007ooOol03Goo00<007ooOol0>Woo0P00OWoo0P0097oo0`000Woo00<0
07ooOol00Woo00<007oo00000P00Q7oo00<007ooOol08Woo00<007ooOol06goo00<007ooOol017oo
0005Ool00`00Oomoo`0=Ool00`00Oomoo`0jOol00`00Oomoo`1mOol00`00Oomoo`0VOol40007Ool0
0`00Oomoo`22Ool00`00Oomoo`10Ool00`00Oomoo`04Ool000Eoo`03001oogoo00eoo`03001oogoo
02]oo`8000eoo`03001oogoo07eoo`03001oogoo02Moo`@000Eoo`03001oogoo08=oo`03001oogoo
041oo`03001oogoo00Aoo`001Goo00<007ooOol03Goo00<007ooOol05Goo00<007ooOol02Woo3@00
2goo00<007ooOol0OGoo00<007ooOol0<7oo00<007ooOol0Pgoo00<007ooOol0@7oo00<007ooOol0
17oo0005Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`06Ool2000=Ool00`00Oomoo`1m
Ool00`00Oomoo`0_Ool00`00Oomoo`24Ool00`00Oomoo`10Ool00`00Oomoo`04Ool000Eoo`03001o
ogoo02Eoo`03001oogoo00Yoo`03001oo`00008000Qoo`800003Ool007oo00Eoo`03001oogoo07io
o`03001oogoo02ioo`03001oogoo08Ioo`03001oogoo03moo`03001oogoo00Aoo`001Goo00<007oo
Ool09Goo00<007ooOol02Woo00@007oo000000]oo`03001oogoo00Eoo`03001oogoo07ioo`8002mo
o`03001oogoo08Ioo`03001oogoo03moo`03001oogoo00Aoo`001Goo00<007ooOol09Goo00<007oo
Ool02Woo00D007ooOomoo`0000Uoo`03001oo`0000Ioo`03001oogoo07moo`03001oogoo02aoo`03
001oogoo08Moo`03001oogoo03moo`03001oogoo00Aoo`001Goo00<007ooOol09Goo00<007ooOol0
2Woo00D007ooOomoo`00015oo`03001oogoo081oo`03001oogoo02aoo`03001oogoo08Qoo`03001o
ogoo03ioo`03001oogoo00Aoo`001Goo00<007ooOol09Goo00<007ooOol02Woo00<007oo00000P00
4Goo00<007ooOol0P7oo00<007ooOol0:Woo0P00Rgoo00<007ooOol0?Woo00<007ooOol017oo0005
Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0COol00`00Oomoo`20Ool00`00Oomoo`0I
Ool2000=Ool2002>Ool00`00Oomoo`0mOol00`00Oomoo`04Ool000Eoo`03001oogoo02Eoo`03001o
ogoo00Yoo`03001oogoo019oo`03001oogoo089oo`03001oogoo01Yoo`<000Qoo`80091oo`03001o
ogoo03eoo`03001oogoo00Aoo`001Goo00<007ooOol09Woo00<007ooOol02Goo00<007ooOol04Woo
00<007ooOol0PWoo00<007ooOol07Goo2000Tgoo00<007ooOol0?7oo00<007ooOol017oo0005Ool0
0`00Oomoo`0VOol00`00Oomoo`07Ool01000Ool000004Woo00<007ooOol0Pgoo00<007ooOol0^Goo
00<007ooOol0>goo00<007ooOol017oo0005Ool00`00Oomoo`0WOol00`00Oomoo`07Ool2000BOol0
0`00Oomoo`24Ool00`00Oomoo`2iOol00`00Oomoo`0kOol00`00Oomoo`04Ool000Eoo`03001oogoo
02Moo`8000Uoo`03001oogoo00moo`03001oogoo08Ioo`03001oogoo0;Uoo`03001oogoo03Yoo`03
001oogoo00Aoo`001Goo00<007ooOol0:7oo00<007ooOol02Goo0P003Goo00<007ooOol0Qgoo00<0
07ooOol0^Woo00<007ooOol0;Woo00<007ooOol027oo00<007ooOol017oo0005Ool00`00Oomoo`0Y
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`29Ool00`00Oomoo`2jOol00`00Oomoo`0/
Ool00`00Oomoo`09Ool00`00Oomoo`04Ool000Eoo`03001oogoo02Yoo`8000Uoo`03001oogoo00Qo
o`8008eoo`03001oogoo0;Yoo`03001oogoo02Yoo`03001oogoo00Yoo`03001oogoo00Aoo`001Goo
00<007ooOol0;7oo00<007ooOol01Goo00<007oo00001goo0P00Sgoo00<007ooOol0^goo00<007oo
Ool09goo0P003Goo00<007ooOol017oo0005Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool01000Ool0
00001Goo00<007ooOol0T7oo00<007ooOol0^goo00<007ooOol09Goo00<007ooOol03Goo00<007oo
Ool017oo0005Ool00`00Oomoo`0^Ool60005Ool4002COol00`00Oomoo`2lOol00`00Oomoo`0ROol2
000@Ool00`00Oomoo`04Ool000Eoo`03001oogoo03=oo`H009Qoo`03001oogoo0;aoo`80021oo`80
019oo`03001oogoo00Aoo`001Goo00<007ooOol0dWoo00<007ooOol0_Goo0P0077oo0P0057oo00<0
07ooOol017oo0005Ool00`00Oomoo`3COol00`00Oomoo`2nOol2000IOol00`00Oomoo`0DOol00`00
Oomoo`04Ool000Eoo`03001oogoo0=Aoo`03001oogoo0;moo`<001=oo`<001Moo`03001oogoo00Ao
o`001Goo00<007ooOol0eGoo00<007ooOol0`Goo0P003Goo10006Woo00<007ooOol017oo0005Ool0
0`00Oomoo`3FOol00`00Oomoo`32Ool=000NOol00`00Oomoo`04Ool000Eoo`03001oogoo0=Moo`80
0>eoo`03001oogoo00Aoo`001Goo00<007ooOol0fGoo00<007ooOol0jWoo00<007ooOol017oo0005
Ool00`00Oomoo`3JOol00`00Oomoo`3YOol00`00Oomoo`04Ool000Eoo`03001oogoo0=]oo`800>Uo
o`03001oogoo00Aoo`001Goo00<007ooOol0gGoo00<007ooOol0iWoo00<007ooOol017oo0005Ool0
0`00Oomoo`3NOol2003VOol00`00Oomoo`04Ool000Eoo`03001oogoo0?moolMoo`03001oogoo00Ao
o`001Gooo`00b`001Woo0000\
\>"],
  ImageRangeCache->{{{0, 468}, {67, 0}} -> {-0.116025, -0.0140188, 0.0069061, 
  0.0069061}, {{16.75, 152.5}, {64.9375, 2}} -> {-0.357452, -0.267131, 
  0.0810334, 0.0810334}, {{166.125, 301.875}, {64.9375, 2}} -> {-12.4618,
   -0.267131, 0.0810334, 0.0810334}, {{315.438, 451.188}, {64.9375, 2}} ->
   {-24.5611, -0.267131, 0.0810334, 0.0810334}}]
}, Open  ]],

Cell[TextData["Analytic Snail-Wheel"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In fact, this particular mechanism could have been modeled without the use \
of the ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at all. The snail-wheel cam profile can be built from analytic functions \
and its arc length can be found using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s symbolic integration capability."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the definition of an analytic snail-wheel."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ansplinelocus = PolarToXY[{4 - s, s\ N[\[Pi]]}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\((4 - s)\)\ Cos[3.14159265358979311`\ s], 
      \((4 - s)\)\ Sin[3.14159265358979311`\ s]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the exact arc length function of the snail-wheel."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ansplinearc = 
      \[Integral]\(\@Plus@@\(\((\[PartialD]\_s ansplinelocus)\)\^2\)\) 
          \[DifferentialD]s\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.318309886183790702`\ 
        \((\(-6.28318530717958623`\) + 1.57079632679489655`\ s)\)\ 
        \@\(\(158.913670417429724`\[InvisibleSpace]\) - 
            78.9568352087148639`\ s + 9.86960440108935976`\ s\^2\) - 
      0.159154943091895351`\ 
        ArcSinh[\(12.5663706143591724`\[InvisibleSpace]\) - 
            3.14159265358979311`\ s]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of the exact arc length function and the approximate arc \
length function, normalized to the same parameter scale and offset."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[{ansplinearc - \((ansplinearc /. s \[Rule] 1)\), 
          splinearc[5\ \((s - 1)\)]}], {s, 1, 3}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.452381 0.476191 0.0147151 0.0462031 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10712 -6 -4.5 ]
[.01131 .10712 0 4.5 ]
[.01131 .19953 -6 -4.5 ]
[.01131 .19953 0 4.5 ]
[.01131 .29193 -6 -4.5 ]
[.01131 .29193 0 4.5 ]
[.01131 .38434 -6 -4.5 ]
[.01131 .38434 0 4.5 ]
[.01131 .47675 -12 -4.5 ]
[.01131 .47675 0 4.5 ]
[.01131 .56915 -12 -4.5 ]
[.01131 .56915 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(1.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(2)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(2.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10712 m
.03006 .10712 L
s
[(2)] .01131 .10712 1 0 Mshowa
.02381 .19953 m
.03006 .19953 L
s
[(4)] .01131 .19953 1 0 Mshowa
.02381 .29193 m
.03006 .29193 L
s
[(6)] .01131 .29193 1 0 Mshowa
.02381 .38434 m
.03006 .38434 L
s
[(8)] .01131 .38434 1 0 Mshowa
.02381 .47675 m
.03006 .47675 L
s
[(10)] .01131 .47675 1 0 Mshowa
.02381 .56915 m
.03006 .56915 L
s
[(12)] .01131 .56915 1 0 Mshowa
.125 Mabswid
.02381 .03782 m
.02756 .03782 L
s
.02381 .06092 m
.02756 .06092 L
s
.02381 .08402 m
.02756 .08402 L
s
.02381 .13022 m
.02756 .13022 L
s
.02381 .15332 m
.02756 .15332 L
s
.02381 .17643 m
.02756 .17643 L
s
.02381 .22263 m
.02756 .22263 L
s
.02381 .24573 m
.02756 .24573 L
s
.02381 .26883 m
.02756 .26883 L
s
.02381 .31504 m
.02756 .31504 L
s
.02381 .33814 m
.02756 .33814 L
s
.02381 .36124 m
.02756 .36124 L
s
.02381 .40744 m
.02756 .40744 L
s
.02381 .43054 m
.02756 .43054 L
s
.02381 .45364 m
.02756 .45364 L
s
.02381 .49985 m
.02756 .49985 L
s
.02381 .52295 m
.02756 .52295 L
s
.02381 .54605 m
.02756 .54605 L
s
.02381 .59225 m
.02756 .59225 L
s
.02381 .61536 m
.02756 .61536 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .04977 L
.10458 .08691 L
.14415 .12077 L
.18221 .15239 L
.22272 .18504 L
.26171 .21548 L
.30316 .24678 L
.34309 .27591 L
.3815 .30297 L
.42237 .33073 L
.46172 .35647 L
.49955 .38029 L
.53984 .40465 L
.57861 .42714 L
.61984 .45 L
.65954 .47102 L
.69774 .49029 L
.73838 .5098 L
.77751 .52761 L
.81909 .54548 L
.85916 .56168 L
.89771 .57633 L
.93871 .5909 L
.97619 .60332 L
s
.02381 .01472 m
.06244 .04271 L
.10458 .08449 L
.14415 .12155 L
.18221 .153 L
.22272 .18493 L
.26171 .21527 L
.30316 .24655 L
.34309 .27561 L
.3815 .30271 L
.42237 .33053 L
.46172 .35626 L
.49955 .38004 L
.53984 .40439 L
.57861 .42688 L
.61984 .44975 L
.65954 .47077 L
.69774 .49002 L
.73838 .50952 L
.77751 .52731 L
.81909 .54505 L
.85916 .56124 L
.89771 .57648 L
.93871 .59181 L
.97619 .60296 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{294, 181},
  ImageMargins->{{100, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004V0000]A000`40O003h00Oogoo9goo001=Ool5
0002Ool00`00Oomoo`02Ool00`00Oomoo`0iOol3000jOol30003Ool00`00Oomoo`02Ool00`00Oomo
o`0iOol2000;Ool004moo`03001oogoo00Ioo`03001oo`0003Yoo`03001oogoo03Yoo`03001oogoo
00Moo`03001oo`0003aoo`03001oogoo00Qoo`00Cgoo00<007ooOol027oo00<007ooOol0>Goo00<0
07ooOol0>Woo00<007ooOol027oo00<007ooOol0>Goo00<007ooOol02Goo001?Ool00`00Oomoo`06
Ool2000lOol00`00Oomoo`0jOol00`00Oomoo`06Ool2000mOol00`00Oomoo`08Ool004moo`03001o
ogoo00Ioo`03001oogoo03Yoo`03001oo`0003Yoo`03001oo`0000Moo`03001oogoo03Yoo`03001o
o`0000Yoo`00CWoo0P0027oo0`00>goo00<007ooOol0>Woo00<007ooOol01Woo0`00>goo00<007oo
Ool02Goo003oOolWOol00?moobMoo`004Woo00<007ooOol0ogoo4Woo000BOol00`00Oomoo`3oOolB
Ool0019oo`03001oogoo0?mooa9oo`004Woo00<007ooOol0ogoo4Woo000<Oooo000G0004Ool0019o
o`<000Yoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001o
ogoo00Qoo`004Woo00@007oo000003ioo`03001oogoo03moo`03001oogoo041oo`03001oogoo03mo
o`03001oogoo00Qoo`004Woo00<007ooOol00P00ogoo47oo000BOol01000Oomoogoo0`00ogoo3Woo
000BOol00`00Oomoo`02Ool3003oOol=Ool0019oo`8000Eoo`800?moo`aoo`004Woo00<007ooOol0
1Goo0`00ogoo2Woo000BOol00`00Oomoo`06Ool00`00Ool0003oOol9Ool0019oo`03001oogoo00Mo
o`03001oo`000?moo`Qoo`004Woo00<007ooOol027oo00<007oo0000ogoo1goo000BOol00`00Oomo
o`09Ool00`00Ool0003oOol6Ool0019oo`03001oogoo00Yoo`03001oo`000?moo`Eoo`004Woo0P00
37oo0`00ogoo17oo000BOol00`00Oomoo`0=Ool3003oOol2Ool0019oo`03001oogoo00ioo`03001o
o`000?moo`5oo`004Woo00<007ooOol03goo00<007oo0000ogoo000BOol00`00Oomoo`0@Ool00`00
Ool0003nOol0019oo`03001oogoo015oo`<00?eoo`004Woo0P0057oo0P00o7oo000BOol00`00Oomo
o`0DOol2003kOol0019oo`03001oogoo01Eoo`800?Yoo`004Woo00<007ooOol05Woo0P00nGoo000B
Ool00`00Oomoo`0HOol00`00Oomoo`3fOol000]oo`<000Aoo`03001oogoo01Uoo`03001oogoo0?Eo
o`002goo00<007ooOol017oo00<007ooOol06Woo00<007ooOol0m7oo000<Ool00`00Oomoo`03Ool3
000KOol00`00Oomoo`3cOol000aoo`03001oogoo00=oo`03001oogoo01aoo`800?=oo`002goo00<0
07oo000017oo00<007ooOol07Goo0P00lWoo000<Ool00`00Oomoo`03Ool00`00Oomoo`0NOol2003a
Ool0019oo`03001oogoo01moo`800?1oo`004Woo00<007ooOol087oo0P00kgoo000BOol2000ROol2
003^Ool0019oo`03001oogoo02=oo`03001oogoo0>]oo`004Woo00<007ooOol097oo0P00jgoo000B
Ool00`00Oomoo`0UOol2003ZOol0019oo`03001oogoo02Ioo`800>Uoo`004Woo00<007ooOol0:7oo
00<007ooOol0iWoo000BOol2000ZOol00`00Oomoo`3UOol0019oo`03001oogoo02Yoo`03001oogoo
0>Aoo`004Woo00<007ooOol0:goo0P00i7oo000BOol00`00Oomoo`0]Ool00`00Oomoo`3QOol0019o
o`03001oogoo02ioo`03001oogoo0>1oo`004Woo00<007ooOol0;goo00<007ooOol0ggoo000BOol0
0`00Oomoo`0`Ool00`00Oomoo`3NOol0019oo`80039oo`800=ioo`004Woo00<007ooOol0<goo00<0
07ooOol0fgoo000BOol00`00Oomoo`0dOol00`00Oomoo`3JOol0019oo`03001oogoo03Eoo`03001o
ogoo0=Uoo`0037oo0`000goo00<007ooOol0=Woo0P00fGoo000=Ool00`00Oomoo`02Ool00`00Oomo
o`0hOol00`00Oomoo`3FOol000]oo`@000=oo`<003Uoo`03001oogoo0=Eoo`002goo00<007oo0000
17oo00<007ooOol0>Woo00<007ooOol0e7oo000<Ool20004Ool00`00Oomoo`0kOol00`00Oomoo`3C
Ool000eoo`03001oogoo009oo`03001oogoo03aoo`800==oo`004Woo00<007ooOol0?Woo00<007oo
Ool0d7oo000BOol00`00Oomoo`0oOol00`00Oomoo`3?Ool0019oo`03001oogoo041oo`800<moo`00
4Woo0P00@goo00<007ooOol0c7oo000BOol00`00Oomoo`13Ool2003<Ool0019oo`03001oogoo04Eo
o`03001oogoo0<Uoo`004Woo00<007ooOol0AWoo0P00bGoo000BOol00`00Oomoo`18Ool00`00Oomo
o`36Ool0019oo`03001oogoo04Uoo`800<Ioo`004Woo0P00C7oo00<007ooOol0`goo000BOol00`00
Oomoo`1<Ool20033Ool0019oo`03001oogoo04ioo`03001oogoo0<1oo`004Woo00<007ooOol0Cgoo
00<007ooOol0_goo000BOol00`00Oomoo`1@Ool2002oOol0019oo`03001oogoo059oo`03001oogoo
0;aoo`004Woo00<007ooOol0Dgoo00<007ooOol0^goo000BOol2001EOol2002kOol0019oo`03001o
ogoo05Ioo`03001oogoo0;Qoo`004Woo00<007ooOol0Egoo0P00^7oo000BOol00`00Oomoo`1IOol0
0`00Oomoo`2eOol000]oo`8000Eoo`03001oogoo05Yoo`03001oogoo0;Aoo`002goo00<007oo0000
17oo00<007ooOol0Fgoo0P00]7oo000;Ool00`00Ool00004Ool3001MOol00`00Oomoo`2aOol000]o
o`8000Eoo`03001oogoo05ioo`03001oogoo0;1oo`002goo00<007ooOol017oo00<007ooOol0Ggoo
0P00/7oo000<Ool20004Ool00`00Oomoo`1QOol00`00Oomoo`2]Ool0019oo`03001oogoo069oo`80
0:eoo`004Woo00<007ooOol0I7oo00<007ooOol0ZWoo000BOol2001VOol00`00Oomoo`2YOol0019o
o`03001oogoo06Ioo`800:Uoo`004Woo00<007ooOol0J7oo00<007ooOol0YWoo000BOol00`00Oomo
o`1YOol00`00Oomoo`2UOol0019oo`03001oogoo06Yoo`800:Eoo`004Woo00<007ooOol0K7oo00<0
07ooOol0XWoo000BOol00`00Oomoo`1]Ool2002ROol0019oo`80071oo`03001oogoo09moo`004Woo
00<007ooOol0L7oo0P00Wgoo000BOol00`00Oomoo`1bOol2002MOol0019oo`03001oogoo07Aoo`03
001oogoo09Yoo`004Woo00<007ooOol0MGoo0P00VWoo000BOol00`00Oomoo`1gOol00`00Oomoo`2G
Ool0019oo`8007Uoo`8009Moo`004Woo00<007ooOol0NWoo0P00UGoo000BOol00`00Oomoo`1lOol0
0`00Oomoo`2BOol0019oo`03001oogoo07eoo`80099oo`004Woo00<007ooOol0Ogoo0P00T7oo000<
Ool00`00Oomoo`03Ool00`00Oomoo`21Ool00`00Oomoo`2=Ool000]oo`03001oo`0000Aoo`03001o
ogoo089oo`8008eoo`002goo00<007oo000017oo0`00Q7oo00<007ooOol0RWoo000<Ool00`00Oomo
o`03Ool00`00Oomoo`25Ool2002:Ool000]oo`03001oo`0000Aoo`03001oogoo08Moo`8008Qoo`00
37oo00<007ooOol00goo00<007ooOol0RGoo00<007ooOol0QGoo000BOol00`00Oomoo`2:Ool20025
Ool0019oo`03001oogoo08aoo`03001oogoo089oo`004Woo0P00SWoo0P00PWoo000BOol00`00Oomo
o`2?Ool20020Ool0019oo`03001oogoo095oo`8007ioo`004Woo00<007ooOol0Tgoo0P00O7oo000B
Ool00`00Oomoo`2EOol2001jOol0019oo`03001oogoo09Moo`03001oogoo07Moo`004Woo0P00VGoo
0P00Mgoo000BOol00`00Oomoo`2JOol2001eOol0019oo`03001oogoo09aoo`03001oogoo079oo`00
4Woo00<007ooOol0WGoo0P00LWoo000BOol00`00Oomoo`2OOol2001`Ool0019oo`03001oogoo0:5o
o`8006ioo`004Woo00<007ooOol0Xgoo00<007ooOol0Jgoo000BOol2002UOol2001[Ool0019oo`03
001oogoo0:Ioo`8006Uoo`004Woo00<007ooOol0Z7oo0P00Igoo000BOol00`00Oomoo`2ZOol2001U
Ool000Eoo`D0009oo`03001oogoo00=oo`03001oogoo0:aoo`8006=oo`001goo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`2^Ool00`00Oomoo`1POol000Moo`07001oogooOol007oo000017oo0`00
[goo0P00H7oo0007Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0;5oo`8005ioo`001goo00L0
07ooOomoo`00Ool00004Ool00`00Oomoo`2cOol2001LOol000Ioo`8000Aoo`03001oogoo00=oo`03
001oogoo0;Eoo`8005Yoo`004Woo00<007ooOol0]goo0`00Egoo000BOol00`00Oomoo`2jOol2001E
Ool0019oo`03001oogoo0;aoo`8005=oo`004Woo0P00_goo0`00D7oo000BOol00`00Oomoo`31Ool2
001>Ool0019oo`03001oogoo0<=oo`8004aoo`004Woo00<007ooOol0aGoo0P00BWoo000BOol00`00
Oomoo`37Ool20018Ool0019oo`03001oogoo0<Uoo`8004Ioo`004Woo0P00c7oo0P00A7oo000BOol0
0`00Oomoo`3=Ool30011Ool0019oo`03001oogoo0=1oo`8003moo`004Woo00<007ooOol0dWoo0P00
?Goo000BOol00`00Oomoo`3DOol3000jOol0019oo`03001oogoo0=Moo`8003Qoo`004Woo00<007oo
Ool0fGoo0`00=Goo000BOol2003MOol2000cOol0019oo`03001oogoo0=ioo`80035oo`004Woo00<0
07ooOol0h7oo0P00;goo000BOol00`00Oomoo`3ROol2000]Ool000Eoo`D00004Ool000000004Ool0
0`00Oomoo`3TOol3000ZOol000Moo`05001oogooOol00006Ool00`00Oomoo`3WOol3000WOol000Mo
o`03001oogoo009oo`03001oogoo00=oo`<00>Yoo`8002Eoo`001goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol0k7oo0`008Woo0007Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0>mo
o`<001moo`001Woo0P0017oo00<007ooOol00goo00<007ooOol0lWoo0`0077oo000BOol00`00Oomo
o`3eOol2000JOol0019oo`03001oogoo0?Moo`<001Moo`004Woo0P00ngoo0`0057oo000BOol00`00
Oomoo`3mOol4000@Ool0019oo`03001oogoo0?moo`9oo`@000aoo`004Woo00<007ooOol0ogoo1Woo
0P002Woo000BOol00`00Oomoo`3oOolBOol0019oo`03001oogoo0?mooa9oo`004Woo00<007ooOol0
ogoo4Woo000BOol2003oOolCOol00001\
\>"],
  ImageRangeCache->{{{0, 293}, {180, 0}} -> {0.85857, -0.972003, 0.00756265, 
  0.0779442}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Fourier Cams"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another method of modeling arbitrary cam profiles is by approximating the \
cam profile with a Fourier series of sine and cosine functions. This method \
guarantees a continuously differentiable cam profile and also may evaluate \
more quickly than a ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, provided only a relatively small number of terms are retained. \
One disadvantage of",
  StyleBox[" a Fourier s",
    FontFamily->"Times"],
  "eries based cam profile is that it does not pass exactly through the data \
points used to generate it. \n\nThe following example uses a series of points \
in Cartesian coordinates that are to lie on the surface of a closed cam \
profile. The profile has a protruding lobe for 1/4 of a turn and is \
approximately circular with a radius of 3.0 for the next 3/4 of a turn. The \
built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Fourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to generate the Fourier series."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here are the data to be transformed."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(data = 
      Join[{{3.08599, 0.61384}, {3.23358, 1.33939}, {3.20411, 2.14091}, {
            2.82843, 2.82843}, {2.14092, 3.20411}, {1.33939, 3.23358}, {
            0.61384, 3.08599}}, 
        Table[3\ {Cos[i], Sin[i]}, {i, \[Pi]/2, 2  \[Pi], 
            3\ \(\[Pi]/2\)/24}]]; \n\(len = Length[data]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Fourier is used to transform the data. Note that the zero-frequency term \
in each series must be divided by two to map correctly back into the time \
domain with ",
  StyleBox["Sin",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Cos",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(fourierdata = \(Fourier/@Transpose[data]\ 2\)\/N[\@len]; \)\), 
    \(\(fourierdata\[LeftDoubleBracket]1, 1\[RightDoubleBracket] /= 2; \)\), 
    \(\(fourierdata\[LeftDoubleBracket]2, 1\[RightDoubleBracket] /= 2; \)\)}],
   "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Here are the first 10 terms of the approximate periodic function."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(terms = 10; \)\), 
    \(\(fourierlocus = 
      \((\n\t\tTake[Re[#1], terms].Table[Cos[i\ s], {i, 0, terms - 1}] + \n
              \t\tTake[Im[#1], terms].Table[Sin[i\ s], {i, 0, terms - 1}]&)
          \)/@fourierdata; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Here is a plot of the Fourier profile along with the data points. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      Graphics[{PointSize[.018], Point/@data}, 
        AspectRatio \[Rule] Automatic], 
      ParametricPlot[Evaluate[fourierlocus], {s, 0, 2\ \[Pi]}, 
        DisplayFunction \[Rule] Identity]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.480844 0.152345 0.480844 0.152345 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.018 w
.95098 .57436 Mdot
.97346 .68489 Mdot
.96897 .807 Mdot
.91174 .91174 Mdot
.807 .96897 Mdot
.68489 .97346 Mdot
.57436 .95098 Mdot
.48084 .93788 Mdot
.39168 .9291 Mdot
.30594 .90309 Mdot
.22693 .86085 Mdot
.15767 .80402 Mdot
.10083 .73476 Mdot
.0586 .65574 Mdot
.03259 .57001 Mdot
.02381 .48084 Mdot
.03259 .39168 Mdot
.0586 .30594 Mdot
.10083 .22693 Mdot
.15767 .15767 Mdot
.22693 .10083 Mdot
.30594 .0586 Mdot
.39168 .03259 Mdot
.48084 .02381 Mdot
.57001 .03259 Mdot
.65574 .0586 Mdot
.73476 .10083 Mdot
.80402 .15767 Mdot
.86085 .22693 Mdot
.90309 .30594 Mdot
.9291 .39168 Mdot
.93788 .48084 Mdot
.5 Mabswid
.95198 .57511 m
.95825 .60641 L
.96539 .64251 L
.96874 .66143 L
.97188 .68217 L
.97317 .6924 L
.97421 .70216 L
.97503 .71167 L
.97561 .72063 L
.97584 .7254 L
.97603 .73055 L
.97611 .73349 L
.97615 .73628 L
.97619 .74153 L
.97618 .7442 L
.97614 .74704 L
.97602 .75217 L
.97591 .75531 L
.97577 .75827 L
.97544 .7638 L
.97507 .76866 L
.9746 .77379 L
.97352 .78296 L
.97202 .79278 L
.96996 .80349 L
.96423 .82533 L
.95583 .84797 L
.94574 .86831 L
.9347 .88578 L
.92265 .90126 L
.90827 .91633 L
.87881 .9394 L
.86076 .9498 L
.84292 .95795 L
.82255 .96508 L
.81168 .96806 L
.79991 .9707 L
.78934 .97258 L
.77967 .97394 L
.775 .97447 L
.76992 .97496 L
.76515 .97535 L
.76069 .97564 L
.75549 .9759 L
.75274 .976 L
.74978 .97609 L
.74669 .97615 L
.74375 .97618 L
.74112 .97619 L
.73825 .97618 L
Mistroke
.73307 .9761 L
.73018 .97602 L
.72756 .97593 L
.72247 .97571 L
.71769 .97544 L
.70726 .97467 L
.69633 .97361 L
.67705 .97117 L
.63504 .96397 L
.56468 .95 L
.53617 .94508 L
.50635 .94091 L
.47558 .93755 L
.44709 .93483 L
.41765 .9317 L
.40213 .92964 L
.3855 .92694 L
.35582 .92051 L
.32832 .91234 L
.29741 .90031 L
.26986 .88692 L
.22058 .85645 L
.17184 .81718 L
.1312 .77499 L
.09415 .7245 L
.07851 .69773 L
.06359 .66744 L
.05248 .64037 L
.0423 .60995 L
.03449 .57979 L
.02914 .55133 L
.02699 .53555 L
.02553 .5211 L
.02493 .51311 L
.02467 .50888 L
.02443 .50439 L
.02426 .50048 L
.02412 .49616 L
.02402 .49222 L
.02396 .48852 L
.02393 .48501 L
.02393 .48126 L
.02395 .47771 L
.024 .47449 L
.02408 .4707 L
.02421 .46658 L
.02453 .45911 L
.025 .45128 L
.02563 .44299 L
.02713 .42812 L
Mistroke
.02891 .41452 L
.03094 .40182 L
.03682 .37309 L
.0451 .34274 L
.05489 .31452 L
.07829 .26377 L
.11024 .21342 L
.14555 .17076 L
.19045 .12821 L
.23556 .09501 L
.28629 .06692 L
.31646 .05415 L
.34503 .0444 L
.37352 .03672 L
.40047 .03117 L
.41604 .02869 L
.43027 .02688 L
.43815 .02607 L
.44673 .02533 L
.45482 .02477 L
.45847 .02457 L
.46231 .02438 L
.46578 .02424 L
.46957 .02412 L
.47301 .02403 L
.47622 .02397 L
.48001 .02393 L
.48346 .02392 L
.48537 .02393 L
.48743 .02395 L
.49119 .024 L
.49444 .02407 L
.49803 .02417 L
.50526 .02447 L
.51196 .02485 L
.51822 .0253 L
.5337 .02678 L
.54781 .02861 L
.57938 .0344 L
.60834 .04182 L
.6348 .05044 L
.69255 .07577 L
.74536 .10815 L
.78847 .14309 L
.8285 .18464 L
.86642 .23525 L
.89628 .28853 L
.90816 .31663 L
.91844 .34808 L
.92547 .37773 L
Mistroke
.93004 .40496 L
.9338 .43665 L
.93672 .467 L
.93937 .49312 L
.9429 .5215 L
.95198 .57511 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{221, 221},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0000gA000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00GGoo6P00IWoo001GOol6000JOol5001QOol005Aoo`<002Eoo`D005ao
o`00Cgoo1@00;Goo0`00FGoo001:Ool5000eOol3001FOol004Moo`<003eoo`<005=oo`00A7oo0`00
@goo0`00D7oo0012Ool20019Ool2001>Ool0041oo`8004eoo`<004]oo`00?Woo0P00DWoo0`00B7oo
000lOol2001GOol20016Ool003Yoo`8005]oo`8004Aoo`00>7oo0P00Ggoo0P00@Woo000fOol2001S
Ool00`00Oomoo`0oOol003Aoo`8006Ioo`8003moo`00<goo00<007ooOol0J7oo0P00?Goo000bOol0
0`00Oomoo`1[Ool00`00Oomoo`0jOol0031oo`8006moo`8003Yoo`00;goo00<007ooOol0LGoo00<0
07ooOol0=goo000^Ool00`00Oomoo`1cOol00`00Oomoo`0fOol002eoo`03001oogoo07Eoo`8003Io
o`00:goo0P00NWoo00<007ooOol0<goo000ZOol00`00Oomoo`1kOol00`00Oomoo`0bOol002Uoo`03
001oogoo07eoo`03001oogoo035oo`00:7oo00<007ooOol0Ogoo0P00<Goo000WOol00`00Oomoo`22
Ool00`00Oomoo`0^Ool002Ioo`03001oogoo08Aoo`03001oogoo02eoo`009Goo00<007ooOol0QWoo
00<007ooOol0;7oo000TOol00`00Oomoo`28Ool00`00Oomoo`0[Ool002=oo`03001oogoo08Yoo`03
001oogoo02Yoo`008Woo00<007ooOol0S7oo00<007ooOol0:Goo000QOol00`00Oomoo`2>Ool00`00
Oomoo`0XOol0021oo`03001oogoo091oo`03001oogoo02Moo`007goo00<007ooOol0TWoo00<007oo
Ool09Woo000NOol00`00Oomoo`2DOol00`00Oomoo`0UOol001eoo`03001oogoo09Ioo`03001oogoo
02Aoo`0077oo00<007ooOol0V7oo00<007ooOol08goo000LOol00`00Oomoo`2HOol00`00Oomoo`0S
Ool001]oo`03001oogoo09Yoo`03001oogoo029oo`006Woo00<007ooOol0W7oo00<007ooOol08Goo
000IOol00`00Oomoo`2NOol00`00Oomoo`0POol001Qoo`03001oogoo09moo`03001oogoo021oo`00
5goo00<007ooOol0XGoo00<007ooOol07goo000GOol00`00Oomoo`2ROol00`00Oomoo`0NOol001Io
o`03001oogoo0:Aoo`03001oogoo01eoo`005Woo00<007ooOol0Y7oo00<007ooOol07Goo000EOol0
0`00Oomoo`2VOol00`00Oomoo`0LOol001Aoo`03001oogoo0:Qoo`03001oogoo01]oo`0057oo00<0
07ooOol0Z7oo00<007ooOol06goo000COol00`00Oomoo`2ZOol00`00Oomoo`0JOol001=oo`03001o
ogoo0:Yoo`03001oogoo01Yoo`004Woo00<007ooOol0[7oo00<007ooOol06Goo000BOol00`00Oomo
o`2/Ool00`00Oomoo`0IOol0015oo`03001oogoo0:ioo`03001oogoo01Qoo`004Goo00<007ooOol0
[goo00<007ooOol05goo000@Ool00`00Oomoo`2`Ool00`00Oomoo`0GOol0011oo`03001oogoo0;5o
o`03001oogoo01Ioo`003goo00<007ooOol0/Woo00<007ooOol05Woo000?Ool00`00Oomoo`2cOol0
0`00Oomoo`0EOol000ioo`03001oogoo0;Aoo`03001oogoo01Eoo`003Woo00<007ooOol0]Goo00<0
07ooOol057oo000=Ool00`00Oomoo`2fOol00`00Oomoo`0DOol000eoo`03001oogoo0;Ioo`03001o
ogoo01Aoo`0037oo00<007ooOol0^7oo00<007ooOol04goo000<Ool00`00Oomoo`2hOol00`00Oomo
o`0COol000]oo`03001oogoo0;Uoo`03001oogoo01=oo`002goo00<007ooOol0^Woo00<007ooOol0
4Woo000:Ool00`00Oomoo`2kOol00`00Oomoo`0BOol000Yoo`03001oogoo0;aoo`03001oogoo015o
o`002Goo00<007ooOol0_Goo00<007ooOol04Goo0009Ool00`00Oomoo`2nOol00`00Oomoo`0@Ool0
00Uoo`03001oogoo0;ioo`03001oogoo011oo`002Goo00<007ooOol0_Woo00<007ooOol047oo0009
Ool00`00Oomoo`2nOol00`00Oomoo`0@Ool000Qoo`03001oogoo0;moo`03001oogoo011oo`0027oo
00<007ooOol0`7oo00<007ooOol03goo0008Ool00`00Oomoo`30Ool00`00Oomoo`0?Ool000Qoo`03
001oogoo0<1oo`03001oogoo00moo`0027oo00<007ooOol0`7oo00<007ooOol03goo0007Ool00`00
Oomoo`31Ool00`00Oomoo`0?Ool000Moo`03001oogoo0<5oo`03001oogoo00moo`001goo00<007oo
Ool0`Goo00<007ooOol03goo0006Ool00`00Oomoo`33Ool00`00Oomoo`0>Ool000Ioo`03001oogoo
0<=oo`03001oogoo00ioo`001Woo00<007ooOol0`goo00<007ooOol03Woo0006Ool00`00Oomoo`33
Ool00`00Oomoo`0>Ool000Ioo`03001oogoo0<=oo`03001oogoo00ioo`001Woo00<007ooOol0`goo
00<007ooOol03Woo0005Ool00`00Oomoo`35Ool00`00Oomoo`0=Ool000Eoo`03001oogoo0<Eoo`03
001oogoo00eoo`001Goo00<007ooOol0aGoo00<007ooOol03Goo0005Ool00`00Oomoo`35Ool00`00
Oomoo`0=Ool000Eoo`03001oogoo0<Eoo`03001oogoo00eoo`001Goo00<007ooOol0aGoo00<007oo
Ool03Goo0005Ool00`00Oomoo`35Ool00`00Oomoo`0=Ool000Eoo`03001oogoo0<Ioo`03001oogoo
00aoo`001Goo00<007ooOol0aWoo00<007ooOol037oo0005Ool00`00Oomoo`36Ool00`00Oomoo`0<
Ool000Eoo`03001oogoo0<Ioo`03001oogoo00aoo`001Goo00<007ooOol0aWoo00<007ooOol037oo
0005Ool00`00Oomoo`36Ool00`00Oomoo`0<Ool000Eoo`03001oogoo0<Ioo`03001oogoo00aoo`00
1Goo00<007ooOol0aWoo00<007ooOol037oo0005Ool00`00Oomoo`36Ool00`00Oomoo`0<Ool000Eo
o`03001oogoo0<Ioo`03001oogoo00aoo`001Goo00<007ooOol0aWoo00<007ooOol037oo0005Ool0
0`00Oomoo`36Ool00`00Oomoo`0<Ool000Eoo`03001oogoo0<Moo`03001oogoo00]oo`001Goo00<0
07ooOol0agoo00<007ooOol02goo0005Ool00`00Oomoo`37Ool00`00Oomoo`0;Ool000Eoo`03001o
ogoo0<Moo`03001oogoo00]oo`001Goo00<007ooOol0agoo00<007ooOol02goo0005Ool00`00Oomo
o`37Ool00`00Oomoo`0;Ool000Eoo`03001oogoo0<Qoo`03001oogoo00Yoo`001Goo00<007ooOol0
b7oo00<007ooOol02Woo0006Ool00`00Oomoo`37Ool00`00Oomoo`0:Ool000Ioo`03001oogoo0<Mo
o`03001oogoo00Yoo`001Woo00<007ooOol0agoo00<007ooOol02Woo0006Ool00`00Oomoo`37Ool0
0`00Oomoo`0:Ool000Ioo`03001oogoo0<Qoo`03001oogoo00Uoo`001goo00<007ooOol0agoo00<0
07ooOol02Goo0007Ool00`00Oomoo`37Ool00`00Oomoo`09Ool000Moo`03001oogoo0<Moo`03001o
ogoo00Uoo`001goo00<007ooOol0agoo00<007ooOol02Goo0008Ool00`00Oomoo`36Ool00`00Oomo
o`09Ool000Qoo`03001oogoo0<Moo`03001oogoo00Qoo`0027oo00<007ooOol0agoo00<007ooOol0
27oo0008Ool00`00Oomoo`37Ool00`00Oomoo`08Ool000Uoo`03001oogoo0<Ioo`03001oogoo00Qo
o`002Goo00<007ooOol0aWoo00<007ooOol027oo0009Ool00`00Oomoo`36Ool00`00Oomoo`08Ool0
00Yoo`03001oogoo0<Ioo`03001oogoo00Moo`002Woo00<007ooOol0aWoo00<007ooOol01goo000:
Ool00`00Oomoo`36Ool00`00Oomoo`07Ool000]oo`03001oogoo0<Eoo`03001oogoo00Moo`002goo
00<007ooOol0aWoo00<007ooOol01Woo000;Ool00`00Oomoo`36Ool00`00Oomoo`06Ool000aoo`03
001oogoo0<Eoo`03001oogoo00Ioo`0037oo00<007ooOol0aGoo00<007ooOol01Woo000<Ool00`00
Oomoo`36Ool00`00Oomoo`05Ool000eoo`03001oogoo0<Eoo`03001oogoo00Eoo`003Goo00<007oo
Ool0aGoo00<007ooOol01Goo000>Ool00`00Oomoo`34Ool00`00Oomoo`05Ool000ioo`03001oogoo
0<Aoo`03001oogoo00Eoo`003goo00<007ooOol0`goo00<007ooOol01Goo000?Ool00`00Oomoo`33
Ool00`00Oomoo`05Ool0011oo`03001oogoo0<9oo`03001oogoo00Eoo`0047oo00<007ooOol0`goo
00<007ooOol017oo000AOol00`00Oomoo`32Ool00`00Oomoo`04Ool0015oo`03001oogoo0<9oo`03
001oogoo00Aoo`004Woo00<007ooOol0`Goo00<007ooOol017oo000BOol00`00Oomoo`31Ool00`00
Oomoo`04Ool001=oo`03001oogoo0<1oo`03001oogoo00Aoo`004goo00<007ooOol0`7oo00<007oo
Ool017oo000DOol00`00Oomoo`2oOol00`00Oomoo`04Ool001Eoo`03001oogoo0;ioo`03001oogoo
00Aoo`005Goo00<007ooOol0_Woo00<007ooOol017oo000FOol00`00Oomoo`2mOol00`00Oomoo`04
Ool001Moo`03001oogoo0;aoo`03001oogoo00Aoo`0067oo00<007ooOol0^goo00<007ooOol017oo
000HOol00`00Oomoo`2kOol00`00Oomoo`04Ool001Uoo`03001oogoo0;Yoo`03001oogoo00Aoo`00
6Woo00<007ooOol0^Goo00<007ooOol017oo000KOol00`00Oomoo`2hOol00`00Oomoo`04Ool001]o
o`03001oogoo0;Qoo`03001oogoo00Aoo`0077oo00<007ooOol0]goo00<007ooOol017oo000MOol0
0`00Oomoo`2fOol00`00Oomoo`04Ool001ioo`03001oogoo0;Eoo`03001oogoo00Aoo`007goo00<0
07ooOol0/goo00<007ooOol01Goo000POol00`00Oomoo`2bOol00`00Oomoo`05Ool0025oo`03001o
ogoo0;5oo`03001oogoo00Eoo`008Woo00<007ooOol0/7oo00<007ooOol01Goo000SOol00`00Oomo
o`2_Ool00`00Oomoo`05Ool002Aoo`03001oogoo0:ioo`03001oogoo00Eoo`009Goo00<007ooOol0
[7oo00<007ooOol01Woo000VOol00`00Oomoo`2[Ool00`00Oomoo`06Ool002Moo`800:]oo`03001o
ogoo00Ioo`00:Goo00<007ooOol0Z7oo00<007ooOol01Woo000ZOol00`00Oomoo`2VOol00`00Oomo
o`07Ool002]oo`03001oogoo0:Eoo`03001oogoo00Moo`00;7oo00<007ooOol0Xgoo00<007ooOol0
27oo000]Ool2002SOol00`00Oomoo`08Ool002moo`03001oogoo0:1oo`03001oogoo00Qoo`00<7oo
00<007ooOol0WWoo00<007ooOol02Goo000aOol2002NOol00`00Oomoo`09Ool003=oo`03001oogoo
09Yoo`03001oogoo00Yoo`00=7oo0P00VWoo00<007ooOol02Woo000fOol2002GOol00`00Oomoo`0;
Ool003Qoo`03001oogoo09=oo`03001oogoo00aoo`00>Goo0P00TWoo00<007ooOol03Goo000kOol0
0`00Oomoo`2>Ool00`00Oomoo`0>Ool003aoo`8008eoo`03001oogoo00moo`00?Woo0P00Rgoo00<0
07ooOol03goo0010Ool30027Ool00`00Oomoo`0@Ool004=oo`@0089oo`03001oogoo015oo`00Agoo
0`00OWoo00<007ooOol04Woo001:Ool3001jOol00`00Oomoo`0COol004eoo`@007Eoo`03001oogoo
01Aoo`00DGoo1@00Kgoo00<007ooOol05Goo001FOol9001TOol2000HOol005moo`H005eoo`03001o
ogoo01Qoo`00IGoo3@00Cgoo00<007ooOol06Goo001bOol70016Ool2000LOol007Uoo`D003moo`80
01ioo`00OWoo1000>Goo0P0087oo0022Ool4000bOol3000ROol008Ioo`@002aoo`8002Eoo`00RWoo
1P008Goo1@009goo002@Ool7000FOol4000/Ool009MooaH0031oo`00gGoo003MOol00=eoo`00gGoo
003MOol00001\
\>"],
  ImageRangeCache->{{{0, 220}, {220, 0}} -> {-3.15632, -3.15632, 0.0298369, 
  0.0298369}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Cam Constraints within a Multistage Constraint"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When a cam constraint is used within a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, the extra degrees of freedom that are introduced by the cam \
constraint must be dealt with when the cam constraint is not active. The \
following example shows how a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint might be used with a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["CamToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Here is an example of a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with a cam constraint."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(TimeSwitch[1, \n\t
      CamToPlane1[1, \n\t\tPoint[cam, camsurf], {alpha, 1.2}, {beta, 2.4}, 
        Plane[follower, {0, 0, 0}, {0, 2, 0}, {2, 1, 0}]], \n\t2.5, \n
      \t{RelativeAngle1[2, \n\t\t\tAxis[follower, {0, 0, 1}], 
          Axis[ground, {1, 0, 0}], \[Pi]/2], \n\t\t
        Constraint[3, {alpha == 1.5, beta == 2.5}]}]\)], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When the value of time exceeds 2.5 the one mechanical degree of freedom \
that was constrained by ",
  StyleBox["CamToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is constrained by ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", while the values of the two cam surface parameters ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are constrained to be equal to two constants. \n\nIf this technique were \
not used, the values of ",
  StyleBox["alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["beta",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would be unconstrained after ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 2.5 and the model would not run. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Involute Gears "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A single pair of involute gear teeth can be modeled with ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as a pair of cam surfaces. ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " provides a function for generating the involute profiles based on the \
standard gear tooth specifications."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Involute[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["baserad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["pitchrad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a parametric function representing an involute gear tooth, as a \
function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". The involute has a base circle radius of ",
  StyleBox["baserad",
    FontSlant->"Italic"],
  " and a pitch circle radius of ",
  StyleBox["pitchrad",
    FontSlant->"Italic"],
  " centered at {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "}. The involute profile is rotationally located such that the point where \
the profile intersects the pitch circle lies on a ray that passes through {",
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  "} in the direction of the specified angle ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ". If ",
  StyleBox["pitchrad",
    FontSlant->"Italic"],
  " is negative, the profile spirals outward in the clockwise direction. The \
involute locus travels from the base circle to the pitch circle as ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " goes from 0 to sqrt(",
  StyleBox["pitchrad ",
    FontSlant->"Italic"],
  "^ 2 - ",
  StyleBox["baserad ",
    FontSlant->"Italic"],
  "^ 2) / ",
  StyleBox["baserad",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The involute gear tooth function. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Interference",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Involute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Setting ",
  StyleBox["Interference",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies that the ",
  StyleBox["Involute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " locus shall blend into a straight line from the point where the involute \
profile meets the base circle to the center of the base circle."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["Involute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following example uses two gear tooth loci (functions of the symbols ",
  
  StyleBox["g1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["g2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") located on a pair of mating gears. Note that the coordinates of the \
center point and the rotation angle of the involute are given in local \
coordinates. The tooth loci are not placed onto their respective bodies until \
they are put into ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " point objects."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a pair of tooth loci. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(locuspoint1 = Involute[g1, {0, 0}, 4.0, 5.0, 0]; \)\), 
    \(locuspoint2 = Involute[g2, {0, 0}, 5.6, 7.0, \[Pi]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          StyleBox["5.59999999999999964`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], " ", 
          \((Cos[\(3.03509376238307737`\[InvisibleSpace]\) + g2] + 
              g2\ Sin[\(3.03509376238307737`\[InvisibleSpace]\) + g2])\)}], 
        ",", 
        RowBox[{
          StyleBox["5.59999999999999964`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2], " ", 
          \((\(-g2\)\ Cos[\(3.03509376238307737`\[InvisibleSpace]\) + g2] + 
              Sin[\(3.03509376238307737`\[InvisibleSpace]\) + g2])\)}]}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Four constraints are used to model the two gear teeth.\n \nA ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the center of gear 1 to be located at {0, 0}. \nA ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint rotates gear 1. \nA ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the center of gear 2 to be located at {12, 0}. \nA ",
  StyleBox["CamToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used to enforce the contact of the gear teeth."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the involute gear model constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(gear1 = 2; \)\), 
    \(\(gear2 = 3; \)\), 
    \(SetConstraints[\n\t
      Revolute2[1, Point[ground, {0, 0}], Point[gear1, {0, 0}]], \n\t
      RotationLock1[2, gear1, 2.0  \[Pi]\ T], \n\t
      Revolute2[3, \n\t\tPoint[ground, {12, 0}], Point[gear2, {0, 0}]], \n\t
      CamToCam1[4, Point[gear1, locuspoint1], {g1, 1}, 
        Point[gear2, locuspoint2], {g2, 1}]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.01. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.01, Solution \[Rule] Velocity]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.01`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.0628318530717958623`\), ",", 
        \(X3 \[Rule] 11.9999999999999996`\), ",", \(Y3 \[Rule] 0.`\), ",", 
        \(Th3 \[Rule] \(-0.0448798950512110117`\)\), ",", 
        \(g1 \[Rule] 0.687168146928251744`\), ",", 
        \(g2 \[Rule] 0.794879895051258689`\), ",", \(X2d \[Rule] 0.`\), ",", 
        \(Y2d \[Rule] 0.`\), ",", \(Th2d \[Rule] 6.28318530717958534`\), ",", 
        \(X3d \[Rule] 0.`\), ",", \(Y3d \[Rule] 0.`\), ",", 
        \(Th3d \[Rule] \(-4.48798950512827854`\)\), ",", 
        \(g1d \[Rule] \(-6.283185307179588`\)\), ",", 
        \(g2d \[Rule] 4.48798950512827765`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the two gear teeth. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.125 0.125 0.5 0.125 [ 
[ -0.001 -0.001 0 0 ] 
[ 1.001 1.001 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 0 m 
0 1 L 
s 
P 
P 
p 
p 
.002 w 
0 1 m 
1 1 L 
s 
P 
p 
.002 w 
1 0 m 
1 1 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 1 L 
0 1 L 
closepath 
clip 
newpath 
p 
p 
p 
p 
.004 w 
.37452 .47817 m 
.37456 .47817 L 
.3746 .47817 L 
.37465 .47817 L 
.37469 .47817 L 
.37473 .47817 L 
.37477 .47817 L 
.37482 .47817 L 
.37484 .47817 L 
.37487 .47817 L 
.3749 .47817 L 
.37493 .47817 L 
.37495 .47817 L 
.37498 .47817 L 
.37502 .47817 L 
.37505 .47817 L 
.37508 .47817 L 
.37512 .47817 L 
.37515 .47817 L 
.37519 .47817 L 
.37526 .47817 L 
.37534 .47817 L 
.37552 .47817 L 
.3757 .47818 L 
.37613 .47819 L 
.37662 .47821 L 
.3778 .47828 L 
.37924 .4784 L 
.38094 .47858 L 
.38289 .47883 L 
.38756 .4796 L 
.39321 .4808 L 
.39981 .48252 L 
.40734 .48485 L 
.41573 .48788 L 
.42495 .4917 L 
.43494 .49637 L 
.44563 .50199 L 
.45696 .50862 L 
.46886 .51634 L 
.48124 .5252 L 
.49403 .53527 L 
.50714 .5466 L 
.52048 .55925 L 
.53396 .57325 L 
.54747 .58864 L 
.56092 .60545 L 
.5742 .62371 L 
.58721 .64344 L 
.59984 .66464 L 
Mistroke 
Mfstroke 
P 
P 
P 
p 
p 
p 
.004 w 
.68301 .60556 m 
.68285 .60558 L 
.6824 .60564 L 
.68165 .60571 L 
.68059 .60579 L 
.67922 .60587 L 
.67842 .60591 L 
.678 .60592 L 
.67755 .60593 L 
.67709 .60594 L 
.6766 .60595 L 
.67635 .60596 L 
.6761 .60596 L 
.67584 .60596 L 
.67558 .60596 L 
.67544 .60596 L 
.67531 .60596 L 
.67517 .60597 L 
.67504 .60597 L 
.6749 .60597 L 
.67476 .60596 L 
.67462 .60596 L 
.67448 .60596 L 
.67433 .60596 L 
.67419 .60596 L 
.6739 .60596 L 
.6736 .60596 L 
.6733 .60595 L 
.67268 .60594 L 
.67205 .60593 L 
.67072 .60589 L 
.66931 .60583 L 
.66783 .60575 L 
.66465 .60553 L 
.66117 .60523 L 
.65333 .60428 L 
.64433 .60281 L 
.63422 .60073 L 
.62302 .59793 L 
.61078 .59433 L 
.59755 .58982 L 
.58338 .58433 L 
.56835 .57777 L 
.55251 .57006 L 
.53593 .56112 L 
.51869 .55088 L 
.50088 .53926 L 
.48258 .5262 L 
.46388 .51165 L 
.44487 .49554 L 
Mistroke 
.42566 .47784 L 
.40634 .45849 L 
.38703 .43745 L 
Mfstroke 
P 
P 
P 
p 
.004 w 
newpath 
-0.125 .5 .5 0 365.73 arc 
s 
newpath 
1.375 .5 .7 0 365.73 arc 
s 
.035 w 
.48115 .52513 Mdot 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{153, 153},
  ImageMargins->{{55, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002I0000VA000`40O003h00OQWoo0P004Goo002H
0001Ool00003001oogoo085oo`03001oogoo011oo`40005oo`000P00PGoo00<007ooOol04Goo0@00
0Goo00001000Ool00000OWoo00<007ooOol04Woo0@000Goo00001000Oomoogoo1000NGoo00<007oo
Ool04goo0@000Goo00000`00Oomoo`05Ool00`00Oomoo`1fOol00`00Oomoo`0COol10001Ool00003
001oogoo00Ioo`@007=oo`03001oogoo01Aoo`40005oo`0000<007ooOol02Woo0P00L7oo00<007oo
Ool05Goo0@000Goo00000`00Oomoo`0<Ool00`00Oomoo`1/Ool00`00Oomoo`0FOol10001Ool00003
001oogoo00eoo`8006]oo`03001oogoo01Moo`40005oo`0000<007ooOol03goo0P00J7oo00<007oo
Ool067oo0@000Goo00000`00Oomoo`0AOol00`00Oomoo`1UOol00`00Oomoo`0HOol10001Ool00003
001oogoo019oo`8006Aoo`03001oogoo01Uoo`40005oo`0000<007ooOol057oo00<007ooOol0H7oo
00<007ooOol06Woo0@000Goo00000`00Oomoo`0EOol2001POol00`00Oomoo`0JOol10001Ool00003
001oogoo01Moo`8005eoo`03001oogoo01]oo`40005oo`0000<007ooOol06Goo00<007ooOol0FWoo
00<007ooOol06goo0@000Goo00000`00Oomoo`0JOol00`00Oomoo`1HOol00`00Oomoo`0LOol10001
Ool00003001oogoo01]oo`03001oogoo05Ioo`03001oogoo01eoo`40005oo`0000<007ooOol077oo
00<007ooOol0E7oo00<007ooOol07Woo0@000Goo00000`00Oomoo`0MOol2001DOol00`00Oomoo`0N
Ool10001Ool00003001oogoo01moo`03001oogoo051oo`03001oogoo01moo`40005oo`0000<007oo
Ool087oo00<007ooOol0CWoo00<007ooOol087oo0@000Goo00000`00Oomoo`0POol00`00Oomoo`1>
Ool00`00Oomoo`0POol10001Ool00003001oogoo025oo`03001oogoo04aoo`03001oogoo025oo`40
005oo`0000<007ooOol08Woo00<007ooOol0Bgoo00<007ooOol08Goo0@000Goo00000`00Oomoo`0S
Ool00`00Oomoo`19Ool00`00Oomoo`0ROol10001Ool00003001oogoo02Aoo`03001oogoo04Qoo`03
001oogoo029oo`40005oo`0000<007ooOol09Goo00<007ooOol0AWoo00<007ooOol08goo0@000Goo
00000`00Oomoo`0UOol00`00Oomoo`16Ool00`00Oomoo`0SOol10001Ool00003001oogoo02Ioo`03
001oogoo04Aoo`03001oogoo02Aoo`40005oo`0000<007ooOol09goo00<007ooOol0@goo00<007oo
Ool097oo0@000Goo00000`00Oomoo`0WOol00`00Oomoo`12Ool00`00Oomoo`0UOol10001Ool00003
001oogoo02Qoo`03001oogoo041oo`03001oogoo02Ioo`40005oo`0000<007ooOol0:Goo00<007oo
Ool0?goo00<007ooOol09Woo0@000Goo00000`00Oomoo`0YOol00`00Oomoo`0oOol00`00Oomoo`0V
Ool10001Ool00003001oogoo02Yoo`03001oogoo03eoo`03001oogoo02Moo`40005oo`0000<007oo
Ool0:Woo00<007ooOol0?Goo00<007ooOol09goo0@000Goo00000`00Oomoo`0[Ool00`00Oomoo`0k
Ool00`00Oomoo`0XOol10001Ool00003001oogoo02aoo`03001oogoo03Yoo`03001oogoo02Qoo`40
005oo`0000<007ooOol0;7oo00<007ooOol0>Woo00<007ooOol0:7oo0@000Goo00000`00Oomoo`0]
Ool00`00Oomoo`0iOol00`00Oomoo`0XOol10001Ool00003001oogoo02eoo`03001oogoo03Uoo`03
001oogoo02Qoo`40005oo`0000<007ooOol0;Woo00<007ooOol0=goo00<007ooOol0:Goo0@000Goo
00000`00Oomoo`0_Ool00`00Oomoo`0fOol00`00Oomoo`0YOol10001Ool00003001oogoo02moo`03
001oogoo03Ioo`03001oogoo02Uoo`40005oo`0000<007ooOol0<7oo00<007ooOol0=7oo00<007oo
Ool0:Woo0@000Goo00000`00Oomoo`0`Ool00`00Oomoo`0dOol00`00Oomoo`0ZOol10001Ool00003
001oogoo031oo`03001oogoo03=oo`03001oogoo02]oo`40005oo`0000<007ooOol0<7oo00<007oo
Ool0<goo00<007ooOol0:goo0@000Goo00000`00Oomoo`0aOol00`00Oomoo`0bOol00`00Oomoo`0[
Ool10001Ool00003001oogoo039oo`03001oogoo035oo`03001oogoo02]oo`40005oo`0000<007oo
Ool0<Woo00<007ooOol0<Goo00<007ooOol0:goo0@000Goo00000`00Oomoo`0bOol00`00Oomoo`0`
Ool00`00Oomoo`0/Ool10001Ool00003001oogoo039oo`03001oogoo031oo`03001oogoo02aoo`40
005oo`0000<007ooOol0<goo00<007ooOol0;goo00<007ooOol0;7oo0@000Goo00000`00Oomoo`0c
Ool00`00Oomoo`0_Ool00`00Oomoo`0/Ool10001Ool00003001oogoo03=oo`03001oogoo02moo`03
001oogoo02aoo`40005oo`0000<007ooOol0<goo00<007ooOol0;goo00<007ooOol0;7oo0@000Goo
00000`00Oomoo`0dOol00`00Oomoo`0]Ool00`00Oomoo`0]Ool10001Ool00003001oogoo03Aoo`03
001oogoo02eoo`03001oogoo02eoo`40005oo`0000<007ooOol0=7oo00<007ooOol0;Goo00<007oo
Ool0;Goo0@000Goo00000`00Oomoo`0dOol00`00Oomoo`0]Ool00`00Oomoo`0]Ool10001Ool00003
001oogoo03Aoo`03001oogoo02eoo`03001oogoo02eoo`40005oo`0000<007ooOol0=Goo00<007oo
Ool0;7oo00<007ooOol0;Goo0@000Goo00000`00Oomoo`0eOol00`00Oomoo`0/Ool00`00Oomoo`0]
Ool10001Ool00003001oogoo03Eoo`03001oo`0002aoo`03001oogoo02eoo`40005oo`0000<007oo
Ool0=Goo00@007ooOol002Yoo`03001oogoo02ioo`40005oo`0000<007ooOol0=Goo00D007ooOomo
o`0002Uoo`03001oogoo02ioo`40005oo`0000<007ooOol0=Goo00<007ooOol00Woo00<007ooOol0
9Woo00<007ooOol0;Woo0@000Goo00000`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`0UOol0
0`00Oomoo`0^Ool10001Ool00003001oogoo03Eoo`03001oogoo00Aoo`03001oogoo02Aoo`03001o
ogoo02ioo`40005oo`0000<007ooOol0=Goo0`001Goo00<007ooOol08goo00<007ooOol0;Woo0@00
0Goo00000`00Oomoo`0eOol00`00Oomoo`030003Ool00`00Oomoo`0ROol00`00Oomoo`0^Ool10001
Ool00003001oogoo03Ioo`03001oogoo009oo`<00003Ool007oo029oo`03001oogoo02ioo`40005o
o`0000<007ooOol0=Woo00<007ooOol01Goo0`008Woo00<007ooOol0;Woo0@000Goo00000`00Oomo
o`0fOol00`00Oomoo`07Ool3000POol00`00Oomoo`0^Ool10001Ool00003001oogoo03Ioo`03001o
ogoo00Qoo`<001moo`03001oogoo02ioo`40005oo`0000<007ooOol0=Goo00<007ooOol02goo1000
77oo00<007ooOol0;Woo0@000Goo00000`00Oomoo`0eOol00`00Oomoo`0<Ool4000KOol00`00Oomo
o`0^Ool10001Ool00003001oogoo03Eoo`03001oogoo00aoo`D001Yoo`03001oogoo02ioo`40005o
o`0000<007ooOol0=Goo00<007ooOol03Goo0P0000=oo`0000006Goo00<007ooOol0;Woo0@000Goo
00000`00Oomoo`0eOol00`00Oomoo`0AOol2000HOol00`00Oomoo`0^Ool10001Ool00003001oogoo
03Eoo`03001oogoo019oo`8001Moo`03001oogoo02ioo`40005oo`0000<007ooOol0=Goo00<007oo
Ool04goo0`005Goo00<007ooOol0;Woo0@000Goo00000`00Oomoo`0eOol00`00Oomoo`0EOol2000E
Ool00`00Oomoo`0]Ool10001Ool00003001oogoo03Eoo`03001oogoo01Eoo`03001oo`000080019o
o`03001oogoo02eoo`40005oo`0000<007ooOol0=Goo00<007ooOol05Woo00@007ooOomoo`80011o
o`03001oogoo02eoo`40005oo`0000<007ooOol0=7oo00<007ooOol067oo00<007ooOol00Woo0P00
3Woo00<007ooOol0;Goo0@000Goo00000`00Oomoo`0dOol00`00Oomoo`0IOol00`00Oomoo`03Ool2
000<Ool00`00Oomoo`0]Ool10001Ool00003001oogoo03Aoo`03001oogoo01Yoo`03001oogoo00Ao
o`@000Qoo`03001oogoo02eoo`40005oo`0000<007ooOol0=7oo00<007ooOol06goo00<007ooOol0
1goo1P0000=oo`000000;goo0@000Goo00000`00Oomoo`0dOol00`00Oomoo`0LOol00`00Oomoo`0;
Ool4000_Ool10001Ool00003001oogoo03=oo`03001oogoo01eoo`03001oogoo00moo`03001oogoo
02aoo`40005oo`0000<007ooOol0<goo00<007ooOol07Woo00<007ooOol03Woo00<007ooOol0;7oo
0@000Goo00000`00Oomoo`0cOol00`00Oomoo`0OOol00`00Oomoo`0=Ool00`00Oomoo`0/Ool10001
Ool00003001oogoo03=oo`03001oogoo01moo`03001oogoo00eoo`03001oogoo02aoo`40005oo`00
00<007ooOol0<Woo00<007ooOol08Goo00<007ooOol037oo00<007ooOol0;7oo0@000Goo00000`00
Oomoo`0bOol00`00Oomoo`0ROol00`00Oomoo`0;Ool00`00Oomoo`0/Ool10001Ool00003001oogoo
039oo`03001oogoo029oo`03001oogoo00aoo`03001oogoo02]oo`40005oo`0000<007ooOol0<Woo
00<007ooOol08goo00<007ooOol02goo00<007ooOol0:goo0@000Goo00000`00Oomoo`0aOol00`00
Oomoo`0bOol00`00Oomoo`0[Ool10001Ool00003001oogoo031oo`03001oogoo03=oo`03001oogoo
02]oo`40005oo`0000<007ooOol0<7oo00<007ooOol0<goo00<007ooOol0:goo0@000Goo00000`00
Oomoo`0`Ool00`00Oomoo`0dOol00`00Oomoo`0ZOol10001Ool00003001oogoo031oo`03001oogoo
03Aoo`03001oogoo02Yoo`40005oo`0000<007ooOol0;goo00<007ooOol0=Woo00<007ooOol0:Goo
0@000Goo00000`00Oomoo`0_Ool00`00Oomoo`0fOol00`00Oomoo`0YOol10001Ool00003001oogoo
02ioo`03001oogoo03Moo`03001oogoo02Uoo`40005oo`0000<007ooOol0;Goo00<007ooOol0>Goo
00<007ooOol0:7oo0@000Goo00000`00Oomoo`0]Ool00`00Oomoo`0iOol00`00Oomoo`0XOol10001
Ool00003001oogoo02aoo`03001oogoo03Yoo`03001oogoo02Qoo`40005oo`0000<007ooOol0;7oo
00<007ooOol0>Woo00<007ooOol0:7oo0@000Goo00000`00Oomoo`0[Ool00`00Oomoo`0kOol00`00
Oomoo`0XOol10001Ool00003001oogoo02Yoo`03001oogoo03eoo`03001oogoo02Moo`40005oo`00
00<007ooOol0:Woo00<007ooOol0?Goo00<007ooOol09goo0@000Goo00000`00Oomoo`0YOol00`00
Oomoo`0oOol00`00Oomoo`0VOol10001Ool00003001oogoo02Uoo`03001oogoo03moo`03001oogoo
02Ioo`40005oo`0000<007ooOol0:7oo00<007ooOol0@7oo00<007ooOol09Woo0@000Goo00000`00
Oomoo`0WOol00`00Oomoo`12Ool00`00Oomoo`0UOol10001Ool00003001oogoo02Moo`03001oogoo
04=oo`03001oogoo02Aoo`40005oo`0000<007ooOol09Woo00<007ooOol0A7oo00<007ooOol097oo
0@000Goo00000`00Oomoo`0UOol00`00Oomoo`16Ool00`00Oomoo`0SOol10001Ool00003001oogoo
02Eoo`03001oogoo04Ioo`03001oogoo02=oo`40005oo`0000<007ooOol097oo00<007ooOol0B7oo
00<007ooOol08Woo0@000Goo00000`00Oomoo`0SOol00`00Oomoo`19Ool00`00Oomoo`0ROol10001
Ool00003001oogoo029oo`03001oogoo04]oo`03001oogoo025oo`40005oo`0000<007ooOol08Goo
00<007ooOol0C7oo00<007ooOol08Goo0@000Goo00000`00Oomoo`0POol00`00Oomoo`1>Ool00`00
Oomoo`0POol10001Ool00003001oogoo021oo`03001oogoo04ioo`03001oogoo021oo`40005oo`00
00<007ooOol07goo00<007ooOol0D7oo00<007ooOol07goo0@000Goo00000`00Oomoo`0MOol2001D
Ool00`00Oomoo`0NOol10001Ool00003001oogoo01aoo`03001oogoo05Aoo`03001oogoo01ioo`40
005oo`0000<007ooOol06goo00<007ooOol0EWoo00<007ooOol07Goo0@000Goo00000`00Oomoo`0J
Ool00`00Oomoo`1GOol00`00Oomoo`0MOol10001Ool00003001oogoo01Uoo`03001oogoo05Uoo`03
001oogoo01aoo`40005oo`0000<007ooOol05goo0P00GGoo00<007ooOol06goo0@000Goo00000`00
Oomoo`0FOol00`00Oomoo`1NOol00`00Oomoo`0JOol10001Ool00003001oogoo01Aoo`80069oo`03
001oogoo01Uoo`40005oo`0000<007ooOol04goo00<007ooOol0HWoo00<007ooOol06Goo0@000Goo
00000`00Oomoo`0AOol2001VOol00`00Oomoo`0HOol10001Ool00003001oogoo011oo`03001oogoo
06Ioo`03001oogoo01Qoo`40005oo`0000<007ooOol03Woo0P00JWoo00<007ooOol05goo0@000Goo
00000`00Oomoo`0<Ool2001]Ool00`00Oomoo`0FOol10001Ool00003001oogoo00]oo`03001oogoo
06ioo`03001oogoo01Eoo`40005oo`0000<007ooOol01goo1000LWoo00<007ooOol057oo0@000Goo
00000`00Oomoo`05Ool2001gOol00`00Oomoo`0COol10001Ool00003001oogoo009oo`<007Uoo`03
001oogoo01=oo`40005oo`0000<007ooOol00P00OGoo00<007ooOol04Woo0@000Goo00030020Ool0
0`00Oomoo`0AOol10001Ool00003001oogoo085oo`03001oogoo011oo`40005oo`00V0000Goo0000
\
\>"],
  ImageRangeCache->{{{0, 152}, {152, 0}} -> {0.99196, -4.00804, 0.0527374, 
  0.0527374}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Note that the angular velocity ratio of the two gears is equal to the ratio \
of the radii of the base circles."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(-\(Th2d\/Th3d\)\) /. %, 5.6\/4.0}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1.39999999999999902`, 1.39999999999999991`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following statements generate the graphics in this section. These ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands are defined in Chapter 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Cam-Follower Mechanism"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Needs[\"Mech`Mech2D`\"] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p1 = Graphics[{PointSize[.015],\n  Line[{{-3.5,4},{-4,4},{-4,-4},{4,-4},\n   \
     {1,-4},{0,0},{-1,-4}}],\n  Point[{0,0}],Point[{-3.5,4}]},\n    \
AspectRatio \[Rule] Automatic,\n    PlotRange \[Rule] \
{{-4.5,4.5},{-4.5,5.5}}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t1 = Graphics[\n  {Text[\"P1 {0,0}\",  { 0, 0},{-0.4,-1.5}],\n   \
Text[\"{-3.5,4}\",  {-3.5, 4},{-1.1, 1.6}],\n   Text[\"P2\",        {-3.5, \
4},{-1.5,-1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g1 = Show[{p1,t1}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p2 = Graphics[{ PointSize[.015],Thickness[.02],\n  Vertex[follower, \
{0,{0.5,-1},{6.5,-1}}],\n  RGBColor[0,0,1],Edge[follower, {{0,0},{3.5,0}}], \n\
  Facet[follower, {{2.5,0},{4.5,0},{6.5,-1},{0.5,-1}}]},  \n    AspectRatio \
\[Rule] Automatic,\n    PlotRange \[Rule] {{-4.5,4.5},{-4.5,5.5}}];"], "Input",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t2 = Graphics[{Text[\"P1\",{-3.5,4},  {0,-1.8}],\n  \
Text[\"P2\",Location[follower,{0.5,-1}],  {0,1.7}],\n  \
Text[\"P3\",Location[follower,{6.5,-1}],  {0,1.7}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g2 = Show[{p2,t2}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p3 = Graphics[{ Circle[{0,0},1.0],\n  \
PointSize[.018],Point[Location[cam,camprof]],Point[{0,0}]},\n  AspectRatio \
\[Rule] Automatic,\n  PlotRange \[Rule] {{-4.5,4.5},{-4.5,5.5}} ];"], "Input",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t3 = Graphics[{Text[\"P1\",{0,0},  {-1.8,0}],\n  Text[\" P2 \
at\\nalpha=0\",Location[cam,camprof],  {-0.9,1.3}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"g3 = Show[{p3,t3,\n  CamPlot[ Point[cam, camprof], {alpha, 0, 2 N[\[Pi]]} \
]}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[{{g1,g3},{g2,Graphics[{}]}},\n  Frame \[Rule] True,\n  \
GraphicsSpacing \[Rule] 0]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{p1,p2,p3,\n  \
Graphics[{PointSize[.018],Point[Location[cam,camprof]]}]}/.LastSolve[]];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Snail-Wheel   "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"g1={Graphics[{LocalAxes[cam,1],\n              \
Thickness[.01],Line[{{1,0},{12,0}}],\n              \
PointSize[.02],Point[Location[cam,splinelocus[s]]]},\n              \
AspectRatio \[Rule] Automatic,PlotRange \[Rule] {{1,12},{-.1,5}}],\n    \
CamPlot[Point[cam, splinelocus[s]], {s, 0, 10}]};"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[g1/.#]&/@%  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[GraphicsArray[List/@%,Frame \[Rule] True]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Gear Teeth "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{ \n  CamPlot[Point[gear1, locuspoint1], {g1, 0, 1.1}],\n  \
CamPlot[Point[gear2, locuspoint2], {g2, 0, 1.0}],\n  Graphics[{Circle[{0,0}, \
4.0],\n            Circle[{12,0},5.6],PointSize[.035],\n            \
Point[Location[gear1, locuspoint1]]}]}/.LastSolve[],\n    DisplayFunction \
\[Rule] $DisplayFunction,\n    PlotRange \[Rule] {{1,9},{-4,4}},\n    Frame \
\[Rule] True, \n    FrameTicks \[Rule] None]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["3D Cam-Follower Mechanism  "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Needs[\"Mech`Mech3D`\"] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p1=Graphics3D[{PointSize[.015],\n  Line[{{2,0,-2},{-2,0,-2},{-2,0,2},{ 0,0, \
0},{1,0,-2},\n        {1,2,-2},{ 0,2, 0},{-2,2,2},{-2,2,-2},{2,2,-2},\n       \
 {2,0,-2}}], \n  Line[{{0,0,0},{-1,0,-2},{-1,2,-2},{0,2,0}}],\n  \
Line[{{-2,0,-2},{-2,2,-2}}]},\n    PlotRange \[Rule] \
{{-2.3,2.3},{-0.3,2.3},{-2.3,2.3}},\n    Boxed \[Rule] False];      "], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t1=Graphics3D[      \n  {Text[\"P1\",        { 0,0,0},{-1,-2.0}],\n   \
Text[\"P2\",        { 0,2,0},{-1,-2.0}],\n   Text[\"P3\",        {-2,0,2},{0, \
-1.6}],\n   Text[\"P4\",        {-2,2,2},{0, -1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g1=Show[{p1,t1}]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p2=Graphics3D[{Thickness[.025],\n  Line[{{0,0,0},{0,2,0}}]},\n    PlotRange \
\[Rule] {{-2.3,2.3},{-0.3,2.3},{-2.3,2.3}},\n    Boxed \[Rule] False];      \
"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t2=Graphics3D[{ \n  Text[\"P1\",{0,0,0},  { 1.6, 1.6}],\n  \
Text[\"P2\",{0,2,0},  {-1.6,-1.6}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"g2=Show[{p2,t2, \n  CamPlot[Point[cam, camsurf], {alpha, 0, 2 \[Pi]}, {beta, \
0.3, 1.7},\n  PlotPoints \[Rule] {35,2}]}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"p3=Graphics3D[{Thickness[.025],\n  Line[{{-2,0,2},{-2,2,2}}],\n  \
Facet[follower, {{0,0,0},{2,1,0},{0,2,0}}],\n  Sphere[Axis[follower, {2,1,0}, \
{0,1,0}], 0.5, 12]},\n    PlotRange \[Rule] \
{{-2.3,2.3},{-0.3,2.3},{-2.3,2.3}},\n    Boxed \[Rule] False];  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"t3=Graphics3D[{ \n  Text[\"P1\",{-2,0,2},  {0, 2.0}],\n  \
Text[\"P2\",{-2,2,2},  {0,-2.0}],\n  Text[\"P3\",Location[follower,{2,1,0}], \
{-5,0}]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["g3=Show[{p3,t3}/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[{{g1,g2},{g3,Graphics[{}]}},\n  Frame \[Rule] True, \
GraphicsSpacing \[Rule] 0]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{p1,p2,p3,CamPlot[Point[cam, camsurf],\n  {alpha, 0, 2 \[Pi]}, {beta, \
0.3, 1.7},\n  PlotPoints \[Rule] {35,2}]}/.LastSolve[],\n  PlotRange \[Rule] \
All]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]   "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["6.2  Gear Constraints"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " provides several special constraint functions for modeling gear-type \
relationships. These constraints do not, in fact, model the interactions of \
the individual gear teeth. They simply enforce the nominal rotational \
relationship that is expected of a pair of gears. An example of involute gear \
tooth modeling can be found in Section 6.1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Gear Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The 2D gear constraints provided by ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cover three elementary cases of a gear-drive relationship. In each case, \
a simple rotational relationship is enforced between two bodies."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TwoGears2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, point2, rad2, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a gear set. The centers of the two gears, ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", are constrained to be ",
  StyleBox["rad1 ",
    FontSlant->"Italic"],
  "+ ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  " units apart, and the rotational positions of the gears are related as per \
their respective radii. The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the gears, is given by the formula ",
  
  StyleBox["C = rad1 e1 + rad2 e2",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["TwoPulleys2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, point2, rad2, dist, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pulley and belt set. The centers of the two pulleys, ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", are constrained to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the rotational positions of the pulleys are related as \
per their respective radii. ",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " becomes singular if ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  " = ",
  StyleBox["rad2. ",
    FontSlant->"Italic"],
  "The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the pulleys, is given by the formula \
",
  StyleBox["C = rad1 e1 - rad2 e2",
    FontSlant->"Italic"],
  ".\n\nIn each of the above constraints, ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined by the following: \nPlace the two gears in any valid \
position. Construct a vector ",
  StyleBox["v",
    FontSlant->"Italic"],
  " from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " is the angle measured in radians from ",
  StyleBox["v",
    FontSlant->"Italic"],
  " to the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the first gear. ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is the angle measured from ",
  StyleBox["v",
    FontSlant->"Italic"],
  " to the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the second gear. \n\n",
  StyleBox["TwoGears1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, point2, rad2, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is identical to ",
    FontFamily->"Times"],
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ", except that the distance between the centers of the two gears is not \
constrained.",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Two gear constraints."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RackAndPinion2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, rad, axis, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a rack and pinion gear set. The center of the pinion ",
  StyleBox["point",
    FontSlant->"Italic"],
  " is constrained to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units to the left of the axis of the rack (",
  StyleBox["axis",
    FontSlant->"Italic"],
  "). The angular orientation of the rack and pinion are related as per the \
pinion radius. The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is the distance, measured parallel to the ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", from the origin of the ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point",
    FontSlant->"Italic"],
  " when the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the pinion is parallel to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A special gear constraint."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Each gear constraint requires an initial position constant to set the \
initial relative rotational positions of the two gears. Physically, the \
constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " specifies which gear teeth are mating when the gears are first assembled, \
on a continuum.\n\nThe following ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint would be used to model a pair of gears with pitch radii of 4.0 \
and 6.0, respectively, and local origins at {0, 0}. This method of setting \
the initial position constant causes the two gears to have angular \
coordinates of zero simultaneously, regardless of the relative positions of \
the centers of the gears.\n\nNote that using ",
  StyleBox["Angle[gear1",
    FontFamily->"courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["0",
    FontFamily->"courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["gear2",
    FontFamily->"courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["0]",
    FontFamily->"courier",
    FontWeight->"Bold"],
  StyleBox[
  " in the orientation constant would produce invalid results if the centers \
of the gears were to move relative to each other, because the orientation \
\"constant\" is not constant.",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is an example of a gear constraint."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(gear1 = 2; \)\), 
    \(\(gear2 = 3; \)\), 
    \(TwoGears2[1, Point[gear1, 0], 4.0, Point[gear2, 0], 6.0, 
      \(-\((4.0 + 6.0)\)\)\ Angle[gear1, 0, gear2, 0]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["TwoGears2", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "When an Euler solution method is used in a 2D model (",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "), an extra symbol must be added to the model to keep track of the gross \
rotations of each gear. This is because the degenerate Euler parameters can \
only uniquely represent rotations from 0 to 2 pi. The extra symbol can be \
generated automatically by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or it can be specified with an optional argument to each gear \
constraint.\n\nThese extra symbols, and their initial guesses, are analogous \
to the extra symbols introduced by all cam constraints and the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " gear constraints."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TwoGears2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point2, rad2, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the format for specifying explicitly the extra symbol that is used to \
track the gross rotation of the gears with the Euler solution method. The \
symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " represents the total rotation of the first gear with respect to a ray \
that passes through the centers of both gears. Extra symbols that are not \
explicitly specified are created in the form ",
  StyleBox["Th",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Optional arguments for gear constraints with the Euler method."], "Special4",\

  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"See the appendix for the optional arguments to other gear constraints. "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Example 2D Gear Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " gear constraints a 2D model is developed that uses a pair of gears, a \
pair of pulleys and a belt, and a rack and pinion. The input to the model is \
the specified rotation of the drive gear. This, in turn, rotates the driven \
gear, which is the same body as the drive pulley. The drive pulley rotates \
the driven pulley, which is the same body as the pinion. The rotation of the \
pinion causes the rack to translate. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a 2D gear-drive mechanism graphic."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .54792  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.123205 0.0496978 0.162139 0.0496978 [ 
[ -0.001 -0.001 0 0 ] 
[ 1.001 .54892 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 0 m 
0 .54792 L 
s 
P 
P 
p 
p 
.002 w 
0 .54792 m 
1 .54792 L 
s 
P 
p 
.002 w 
1 0 m 
1 .54792 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 .54792 L 
0 .54792 L 
closepath 
clip 
newpath 
p 
p 
1 0 0 r 
.004 w 
newpath 
.12321 .16214 .0994 0 365.73 arc 
s 
newpath 
.37169 .16214 .14909 0 365.73 arc 
s 
.08 w 
.12321 .16214 Mdot 
P 
p 
0 1 0 r 
.004 w 
newpath 
.65719 .36093 .14909 0 365.73 arc 
s 
newpath 
.37169 .16214 .0994 0 365.73 arc 
s 
.08 w 
.37169 .16214 Mdot 
p 
.004 w 
.41626 .07329 m 
.72403 .22766 L 
s 
.55538 .46986 m 
.30383 .23476 L 
s 
P 
P 
p 
0 0 1 r 
.004 w 
newpath 
.65719 .36093 .07455 0 365.73 arc 
s 
.08 w 
.65719 .36093 Mdot 
P 
p 
0 1 1 r 
.37982 .53487 m 
.37982 .43548 L 
.97619 .43548 L 
.97619 .53487 L 
F 
P 
p 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .19278 .16214 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .12321 .23172 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(1)] .12321 .16214 -1.5 -0.9 Mshowa 
P 
.004 w 
.19278 .16214 m 
.12321 .16214 L 
.12321 .23172 L 
s 
.17887 .15518 m 
.19278 .16214 L 
.17887 .1691 L 
s 
.11625 .2178 m 
.12321 .23172 L 
.13016 .2178 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .17949 .20304 -0.33185 -1.25712 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .08231 .21843 -0.33185 -1.25712 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(2)] .12321 .16214 -0.33185 -1.25712 Mshowa 
P 
.004 w 
.17949 .20304 m 
.12321 .16214 L 
.08231 .21843 L 
s 
.17233 .18923 m 
.17949 .20304 L 
.16415 .20049 L 
s 
.08486 .20308 m 
.08231 .21843 L 
.09612 .21126 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .43526 .13384 -1.98042 -0.45613 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .39999 .2257 -1.98042 -0.45613 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(3)] .37169 .16214 -1.98042 -0.45613 Mshowa 
P 
.004 w 
.43526 .13384 m 
.37169 .16214 L 
.39999 .2257 L 
s 
.41971 .13314 m 
.43526 .13384 L 
.42537 .14586 L 
s 
.38798 .21582 m 
.39999 .2257 L 
.40069 .21016 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .72407 .34175 -1.85535 -0.61706 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .67636 .42781 -1.85535 -0.61706 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(4)] .65719 .36093 -1.85535 -0.61706 Mshowa 
P 
.004 w 
.72407 .34175 m 
.65719 .36093 L 
.67636 .42781 L 
s 
.70877 .3389 m 
.72407 .34175 L 
.71261 .35228 L 
s 
.66584 .41635 m 
.67636 .42781 L 
.67922 .41252 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .74758 .43548 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .678 .50505 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(5)] .678 .43548 -1.5 -0.9 Mshowa 
P 
.004 w 
.74758 .43548 m 
.678 .43548 L 
.678 .50505 L 
s 
.73367 .42852 m 
.74758 .43548 L 
.73367 .44243 L 
s 
.67105 .49114 m 
.678 .50505 L 
.68496 .49114 L 
s 
P 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{311, 170},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004g0000ZQ000`40O003h00Oogoo>7oo00000goo
0000003o000c0002Ool00003Ool007oo0?mooc9oo`40005oo`5oo`0000=oo`00Ool0ogoo<Woo0@00
0Goo0Goo00000goo001oo`3oOolbOol10001Ool1Ool00003Ool007oo06Yoo`el0;Yoo`40005oo`5o
o`0000=oo`00Ool0IWoo17`03Goo17`0]Woo0@000Goo0Goo00000goo001oo`1QOol5O00EOol5O02a
Ool10001Ool1Ool00003Ool007oo05moo`9l01moo`9l0:moo`40005oo`5oo`0000=oo`00Ool0GGoo
0W`08goo0W`0[Goo0@000Goo0Goo00000goo001oo`1KOol2O00WOol2O02[Ool10001Ool1Ool00003
Ool007oo05Uoo`9l02]oo`9l0:Uoo`40005oo`5oo`0000=oo`00Ool0Egoo0W`0;goo0W`0Ygoo0@00
0Goo0Goo00000goo001oo`1EOol2O00cOol2O02UOol10001Ool1Ool00003Ool007oo05Aoo`03O01o
ogoo03Eoo`03O01oogoo0:9oo`40005oo`5oo`0000=oo`00Ool0E7oo00=l07ooOol0=Woo00=l07oo
Ool0XGoo0@000Goo0Goo00000goo001oo`1BOol2O00jOol00g`0Oomoo`2POol10001Ool1Ool00003
Ool007oo055oo`03O01oogoo03]oo`03O01oogoo09moo`40005oo`5oo`0000=oo`00Ool0D7oo00=l
07ooOol0?Goo00=l07ooOol0WWoo0@000Goo0Goo00000goo001oo`1>Ool2O011Ool2O02NOol10001
Ool1Ool00003Ool007oo01moo`Ul02Eoo`03O01oogoo01]oo`T3h1ioo`03O01oogoo09aoo`40005o
o`5oo`0000=oo`00Ool077oo0g`02Goo1W`07goo00=l07ooOol067oo0`?P2Goo1P?P6Goo00=l07oo
Ool0Vgoo0@000Goo0Goo00000goo001oo`0IOol3O00BOol3O00KOol00g`0Oomoo`0GOol20n0BOol3
0n0GOol00g`0Oomoo`2JOol10001Ool1Ool00003Ool007oo01Ioo`=l01Qoo`9l01Uoo`03O01oogoo
01Aoo`<3h1Moo`83h1Ioo`03O01oogoo09Uoo`40005oo`5oo`0000=oo`00Ool057oo0W`07Goo00=l
07ooOol05Goo00=l07ooOol04goo0P?P77oo0P?P57oo00=l07ooOol0VGoo0@000Goo0Goo00000goo
001oo`0COol00g`0Oomoo`0NOol00g`0Oomoo`0COol00g`0Oomoo`0BOol20n0POol20n0COol00g`0
Oomoo`2HOol10001Ool1Ool00003Ool007oo019oo`03O01oogoo021oo`9l019oo`03O01oogoo019o
o`030n1oogoo025oo`<3h15oo`03O01oogoo09Qoo`40005oo`5oo`0000=oo`00Ool04Goo00=l07oo
Ool08goo00=l07ooOol03goo00=l07ooOol04Goo00<3h7ooOol08goo00@3h7oo0n03h11oo`03O01o
ogoo09Moo`40005oo`5oo`0000=oo`00Ool047oo00=l07ooOol09Goo00=l07ooOol03Goo00=l07oo
Ool04Goo00<3h7ooOol09Goo00<3h7ooOol00P?P3Woo00=l07ooOol0Ugoo0@000Goo0Goo00000goo
001oo`0>Ool2O00YOol00g`0Oomoo`0<Ool00g`0Oomoo`0@Ool00`?POomoo`0WOol010?POomoogoo
0P?P3Goo00=l07ooOol0UWoo0@000Goo0Goo00000goo001oo`0=Ool00g`0Oomoo`0ZOol00g`0Oomo
o`0:Ool00g`0Oomoo`0@Ool00`?POomoo`0YOol00`?POomoo`02Ool20n0;Ool00g`0Oomoo`2FOol1
0001Ool1Ool00003Ool007oo00aoo`03O01oogoo02aoo`03O01oogoo00Uoo`03O01oogoo00moo`03
0n1oogoo02]oo`030n1oogoo00=oo`83h0Yoo`03O01oogoo09Eoo`40005oo`5oo`0000=oo`00Ool0
2goo00=l07ooOol0;Woo00=l07ooOol01goo00=l07ooOol03goo00<3h7ooOol0;Goo00<3h7ooOol0
17oo0P?P27oo00=l07ooOol0UGoo0@000Goo0Goo00000goo001oo`0;Ool00g`0Oomoo`0_Ool00g`0
Oomoo`06Ool00g`0Oomoo`0>Ool00`?POomoo`0_Ool00`?POomoo`05Ool20n07Ool00g`0Oomoo`2D
Ool10001Ool1Ool00003Ool007oo00Yoo`03O01oogoo035oo`03O01oogoo00Aoo`03O01oogoo00mo
o`030n1oogoo031oo`030n1oogoo00Ioo`83h0Eoo`03O01oogoo09Aoo`40005oo`5oo`0000=oo`00
Ool02Woo00=l07ooOol0<Goo00=l07ooOol017oo00=l07ooOol03Woo00<3h7ooOol0<Goo00<3h7oo
Ool027oo0P?P17oo00=l07ooOol0Tgoo0@000Goo0Goo00000goo001oo`09Ool00g`0Oomoo`0cOol0
0g`0Oomoo`02Ool00g`0Oomoo`0>Ool00`?POomoo`0cOol00`?POomoo`09Ool20n02Ool00g`0Oomo
o`2COol10001Ool1Ool00003Ool007oo00Qoo`03O01oogoo03Aoo`03O01oogoo009oo`03O01oogoo
00ioo`030n1oogoo03=oo`030n1oogoo00]oo`83h003Ooml07oo09=oo`40005oo`5oo`0000=oo`00
Ool027oo00=l07ooOol0=Goo00El07ooOomoog`000moo`030n1oogoo03Eoo`030n1oogoo00aoo`83
h9Aoo`40005oo`5oo`0000=oo`00Ool01goo00=l07ooOol0=Woo00El07ooOomoog`000moo`030n1o
ogoo03Eoo`030n1oogoo00eoo`03O003h0?P099oo`40005oo`5oo`0000=oo`00Ool01goo00=l07oo
Ool067oo0g`06goo00El07ooOomoog`000ioo`030n1oogoo01Qoo`<3h1]oo`030n1oogoo00eoo`03
O01oogoo0083h91oo`40005oo`5oo`0000=oo`00Ool01goo00=l07ooOol05Goo2G`06Goo00=l07oo
O0003goo00<3h7ooOol05Goo2@?P6Goo00<3h7ooOol03Goo00Al07ooOomoo`83h8ioo`40005oo`5o
o`0000=oo`00Ool01Woo00=l07ooOol057oo3G`05goo00=l07ooO0003Woo00<3h7ooOol057oo3@?P
2Goo1P0027oo00<3h7ooOol03Goo00=l07ooOol00goo0P?PS7oo0@000Goo0Goo00000goo001oo`06
Ool00g`0Oomoo`0COol?O00FOol00g`0Ooml000>Ool00`?POomoo`0COol?0n0:Ool30002Ool20000
0goo001oo`02Ool00`?POomoo`0=Ool00g`0Oomoo`05Ool20n2:Ool10001Ool1Ool00003Ool007oo
00Ioo`03O01oogoo019ooa5l01Ioo`9l00ioo`030n1oogoo019ooa43h0Moo`800003Ool007oo00Ao
o`03001oogoo00=oo`030n1oogoo00aoo`03O01oogoo00Moo`83h8Qoo`40005oo`5oo`0000=oo`00
Ool01Woo00=l07ooOol04Goo4g`05Goo00=l07ooOol03Goo00<3h7ooOol04Goo4`?P17oo0P000goo
00<007ooOol00Woo00<007oo000017oo00<3h7ooOol037oo00=l07ooOol02Goo0P?PQWoo0@000Goo
0Goo00000goo001oo`06Ool00g`0Oomoo`0AOolCO00EOol00g`0Oomoo`0=Ool00`?POomoo`0AOolC
0n02Ool20004Ool00`00Oomoo`0:Ool00`?POomoo`0=Ool00g`0Oomoo`0:Ool20n24Ool10001Ool1
Ool00003Ool007oo00Eoo`03O01oogoo015ooaEl01Aoo`03O01oogoo00eoo`030n1oogoo011ooa<3
h0<001=oo`030n1oogoo00eoo`03O01oogoo00aoo`030n1oogoo085oo`40005oo`5oo`0000=oo`00
Ool01Goo00=l07ooOol04Goo5G`01goo00<007ooOol02Woo00=l07ooOol03Goo00<3h7ooOol047oo
4@?P0P000P?P57oo00<3h7ooOol03Goo00=l07ooOol03Goo0P?PPGoo0@000Goo0Goo00000goo001o
o`05Ool00g`0Oomoo`0AOolEO008Ool00`00Oomoo`09Ool00g`0Oomoo`0=Ool00`?POomoo`0@Ool?
0n0200040n0EOol00`?POomoo`0<Ool00g`0Oomoo`0?Ool20n1oOol10001Ool1Ool00003Ool007oo
00Eoo`03O01oogoo011ooaMl00Qoo`8000Uoo`03O01oogoo00eoo`030n1oogoo00moo`h3h08000L3
h1Aoo`030n1oogoo00aoo`03O01oogoo015oo`83h7eoo`40005oo`5oo`0000=oo`00Ool01Goo00=l
07ooOol047oo37`05P0027oo00=l07ooOol03Goo00<3h7ooOol03goo30?P0P002@?P57oo00<3h7oo
Ool037oo00=l07ooOol04goo0P?PNgoo0@000Goo0Goo00000goo001oo`05Ool00g`0Oomoo`0@Ool;
O0040008O008Ool20009Ool00g`0Oomoo`0=Ool00`?POomoo`0?Ool<0n0010000n03h0?P0`0010?P
57oo00<3h7ooOol037oo00=l07ooOol05Goo0P?PNGoo0@000Goo0Goo00000goo001oo`05Ool00g`0
Oomoo`0AOol9O0001000O00007`00`001G`01goo0P000goo0P0000=oo`00Ool00goo00=l07ooOol0
3Goo00<3h7ooOol047oo30?P00<000?P0n000P?P00@000?P0n03h1Aoo`030n1oogoo00eoo`03O01o
ogoo01Moo`83h7Moo`40005oo`5oo`0000=oo`00Ool01Woo00=l07ooOol047oo2G`000<007`00000
0W`00P001G`03Woo00<007ooOol00goo00=l07ooOol03Goo00<3h7ooOol047oo30?P00D000?P0n03
h00000@3h1Aoo`030n1oogoo00eoo`03O01oogoo01Uoo`83h7Eoo`40005oo`5oo`0000=oo`00Ool0
1Woo00=l07ooOol047oo27`000<007`000000P0000=l0000O0000P000g`03Goo00<007oo000017oo
00=l07ooOol03Goo00<3h7ooOol047oo3@?P00D000?P0n03h00000<3h1Aoo`030n1oogoo00eoo`03
O01oogoo01]oo`83h7=oo`40005oo`5oo`0000=oo`00Ool01Woo00=l07ooOol04Goo1W`000<007`0
O0000P000W`000H007`0O01l0000O00EOol00g`0Oomoo`0=Ool00`?POomoo`0AOol<0n000`000n00
000200020n0EOol00`?POomoo`0<Ool00g`0Oomoo`0NOol20n1aOol10001Ool1Ool00003Ool007oo
00Ioo`03O01oogoo015oo`El0003001l07`0009l00@000Al008001Aoo`9l00ioo`030n1oogoo015o
o`d3h0030003h0?P00<3h1Eoo`030n1oogoo00aoo`03O01oogoo021oo`83h6moo`40005oo`5oo`00
00=oo`00Ool01Woo00=l07ooOol04Woo17`000<007`0O0000W`00P001W`00Woo00<007ooOol04Goo
0W`03Woo00<3h7ooOol04Woo30?P00<000?P0n000P?P5Woo00<3h7ooOol037oo00=l07ooOol08Woo
0P?PKGoo0@000Goo0Goo00000goo001oo`06Ool00g`0Oomoo`0COol2O0000`00O01l0002O0030005
O004Ool20002Ool00`00Oomoo`0;Ool00g`0Ooml000>Ool00`?POomoo`0COol<0n000`000n03h00F
Ool00`?POomoo`0=Ool00g`0Oomoo`0TOol20n1[Ool10001Ool1Ool00003Ool007oo00Moo`03O01o
ogoo01=oo`03001l07`000Al0003001l07`000=l00Moo`03001oo`0000eoo`03O01oog`000moo`03
0n1oogoo01=oo`/3h0030003h7oo01Ioo`030n1oogoo00eoo`03O01oogoo02Ioo`83h6Uoo`40005o
o`5oo`0000=oo`00Ool01goo00=l07ooOol04Woo00<007ooOol01G`000@007`0O01l00Yoo`03001o
o`0000aoo`03O01oog`000moo`030n1oogoo01Eoo`T3h003Ool007oo01Ioo`030n1oogoo00aoo`03
O01oogoo02Uoo`83h6Moo`40005oo`5oo`0000=oo`00Ool01goo00=l07ooOol04Woo00<007ooOol0
0goo0W`000<007ooOol02Goo1@002goo00El07ooOomoog`000moo`030n1oogoo01Moo`<3h0Aoo`03
001oogoo01Aoo`030n1oogoo00eoo`03O01oogoo02]oo`83h6Eoo`40005oo`5oo`0000=oo`00Ool0
27oo00=l07ooOol03Goo00@007ooOol000Qoo`03001oogoo00aoo`<000Yoo`05O01oogooOoml000?
Ool00`?POomoo`0OOol00`00Oomoo`0COol00`?POomoo`0=Ool00g`0Oomoo`0]Ool20n1SOol10001
Ool1Ool00003Ool007oo00Qoo`03O01oogoo00eoo`03001oo`0000Uoo`03001oogoo01Qoo`03O01o
ogoo009oo`03O01oogoo00ioo`030n1oogoo01ioo`03001oogoo019oo`030n1oogoo00ioo`03O01o
ogoo02moo`83h65oo`40005oo`5oo`0000=oo`00Ool02Goo00=l07ooOol037oo0P002Woo00<007oo
Ool067oo00=l07ooOol00Woo00=l07ooOol03Woo00<3h7ooOol07goo00<007oo00004Goo00<3h7oo
Ool03Goo00=l07ooOol0<Woo0P?PGgoo0@000Goo0Goo00000goo001oo`09Ool00g`0Oomoo`0;Ool0
1@00Ool007oo000027oo00<007ooOol05goo00=l07ooOol017oo00=l07ooOol03Woo00<3h7ooOol0
7Woo00<007oo000047oo00<3h7ooOol03Woo00=l07ooOol097oo3@?P0goo0P?PGGoo0@000Goo0Goo
00000goo001oo`0:Ool00g`0Oomoo`0:Ool40009Ool00`00Oomoo`0<Ool200000goo001oo`06Ool0
0g`0Oomoo`04Ool00g`0Oomoo`0>Ool00`?POomoo`0LOol00`00Oomoo`02000@Ool00`?POomoo`0=
Ool00g`0Oomoo`0POol50n0=Ool40n000goo0n03h01KOol10001Ool1Ool00003Ool007oo00Yoo`03
O01oogoo00Yoo`8000Uoo`05001oo`00Ool0000>Ool00`00Oomoo`05Ool00g`0Oomoo`06Ool00g`0
Oomoo`0>Ool00`?POomoo`0LOol01000Ool000003goo00<3h7ooOol03Woo00=l07ooOol077oo10?P
5Woo1@?PFGoo0@000Goo0Goo00000goo001oo`0;Ool00g`0Oomoo`0DOol01000Ool000003Woo00<0
07oo00001Goo00=l07ooOol01goo00=l07ooOol03goo00<3h7ooOol077oo0`000Woo0P002Woo00<3
h7ooOol03goo00=l07ooOol06Woo0P?P7goo0P?PEgoo0@000Goo0Goo00000goo001oo`0<Ool00g`0
Oomoo`07Ool2000;Ool3000EOol00g`0Oomoo`09Ool00g`0Oomoo`0?Ool00`?POomoo`0MOol01@00
Oomoogoo00002Goo00<3h7ooOol03goo00=l07ooOol06Goo0P?P8goo0P?PEGoo0@000Goo0Goo0000
0goo001oo`0=Ool00g`0Oomoo`07Ool00`00Oomoo`09Ool2000EOol00g`0Oomoo`0:Ool00g`0Oomo
o`0@Ool00`?POomoo`0POol00`00Oomoo`06Ool00`?POomoo`0@Ool00g`0Oomoo`0GOol20n0WOol2
0n1COol10001Ool1Ool00003Ool007oo00ioo`03O01oogoo00Ioo`03001oogoo00Yoo`03001oogoo
01=oo`03O01oogoo00Yoo`03O01oogoo015oo`030n1oogoo01ioo`03001oo`0000Moo`030n1oogoo
00moo`03O01oogoo01Ioo`83h2]oo`83h55oo`40005oo`5oo`0000=oo`00Ool03Woo00=l07ooOol0
1Goo00<007oo00003Goo0P004Goo00=l07ooOol037oo00=l07ooOol047oo00<3h7ooOol07Woo00@0
07oo000000Eoo`030n1oogoo011oo`03O01oogoo01Aoo`83h2moo`83h4moo`40005oo`5oo`0000=o
o`00Ool03goo0W`01Goo00@007oo000000eoo`03001oogoo00ioo`03O01oogoo00eoo`03O01oogoo
015oo`030n1oogoo02Eoo`030n1oogoo011oo`03O01oogoo01Aoo`030n1oogoo035oo`030n1oogoo
04aoo`40005oo`5oo`0000=oo`00Ool04Goo0W`057oo00<007ooOol037oo0W`04Goo00=l07ooOol0
4Goo0P?P97oo00<3h7ooOol04Goo00=l07ooOol04goo00<3h7ooOol0<goo00<3h7ooOol0Bgoo0@00
0Goo0Goo00000goo001oo`0COol00g`0Oomoo`0@Ool00`00Ool0000;Ool2O00DOol00g`0Oomoo`0A
Ool30n0POol20n0COol00g`0Oomoo`0BOol20n0gOol00`?POomoo`1:Ool10001Ool1Ool00003Ool0
07oo01Aoo`9l011oo`04001oo`000009Ool00g`0Oomoo`0EOol00g`0Oomoo`0AOol010?POol3h0?P
77oo0P?P57oo00=l07ooOol04Goo0P?P>Woo0P?PBWoo0@000Goo0Goo00000goo001oo`0FOol2O00I
Ool2O00IOol00g`0Oomoo`0AOol00`?POomoo`020n0HOol20n0FOol00g`0Oomoo`0@Ool00`?POomo
o`0lOol00`?POomoo`17Ool10001Ool1Ool00003Ool007oo01Qoo`9l01Aoo`=l01]oo`03O01oogoo
019oo`83h09oo`030n1oogoo019oo`<3h1Moo`03O01oogoo015oo`030n1oogoo03eoo`030n1oogoo
04Ioo`40005oo`5oo`0000=oo`00Ool06Woo1G`037oo0g`07goo00=l07ooOol04goo00<3h7ooOol0
1@?P37oo0`?P6Goo00=l07ooOol04Goo00<3h7ooOol0?Woo00<3h7ooOol0AWoo0@000Goo0Goo0000
0goo001oo`0OOol<O00ROol00g`0Oomoo`0DOol00`?POomoo`04Ool<0n0KOol00g`0Oomoo`0AOol0
0`?POomoo`10Ool00`?POomoo`15Ool10001Ool1Ool00003Ool007oo04ioo`03O01oogoo01Aoo`03
0n1oogoo02Yoo`03O01oogoo011oo`030n1oogoo049oo`83h4Eoo`40005oo`5oo`0000=oo`00Ool0
Cgoo0W`05Goo00<3h7ooOol09goo0W`04Woo00<3h7ooOol0A7oo00<3h7ooOol0@goo0@000Goo0Goo
00000goo001oo`1AOol00g`0Oomoo`0COol00`?POomoo`0UOol00g`0Oomoo`0AOol00`?POomoo`16
Ool00`?POomoo`12Ool10001Ool1Ool00003Ool007oo059oo`03O01oogoo01=oo`030n1oogoo02=o
o`03O01oogoo015oo`030n1oogoo04Qoo`030n1oogoo045oo`40005oo`5oo`0000=oo`00Ool0Dgoo
0W`057oo00<3h7ooOol08Goo00=l07ooOol04Woo00<3h7ooOol0BGoo00<3h7ooOol0@7oo0@000Goo
0Goo00000goo001oo`1DOol00g`0Oomoo`0COol00`?POomoo`0OOol00g`0Oomoo`0BOol00`?POomo
o`1:Ool00`?POomoo`10Ool10001Ool1Ool00003Ool007oo05Eoo`03O01oogoo01=oo`030n1oogoo
01eoo`03O01oogoo01=oo`030n1oogoo04]oo`030n1oogoo03moo`40005oo`5oo`0000=oo`00Ool0
EWoo0W`057oo00<3h7ooOol06Woo0W`05Goo00<3h7ooOol087oo2P0O8Woo00<3h7ooOol0?goo0@00
0Goo0Goo00000goo001oo`1HOol2O00COol00`?POomoo`0GOol2O00GOol00`?POomoo`0MOol301l:
Ool401lOOol00`?POomoo`0nOol10001Ool1Ool00003Ool007oo05Yoo`9l019oo`83h1Eoo`9l01Qo
o`030n1oogoo01aoo`807a5oo`807aeoo`030n1oogoo03ioo`40005oo`5oo`0000=oo`00Ool0G7oo
0W`04Woo00<3h7ooOol047oo0W`06Woo00<3h7ooOol06Woo0P0O5Goo0P0O77oo00<3h7ooOol0?Goo
0@000Goo0Goo00000goo001oo`1NOol2O00AOol00`?POomoo`0=Ool2O00KOol00`?POomoo`0IOol2
01lIOol00`0OOomoo`0IOol00`?POomoo`0mOol10001Ool1Ool00003Ool007oo061oo`=l00moo`03
0n1oogoo00Uoo`=l01eoo`030n1oogoo01Qoo`0301moogoo01Yoo`0301moogoo01Uoo`030n1oogoo
03aoo`40005oo`5oo`0000=oo`00Ool0Hgoo17`037oo00<3h7ooOol017oo17`07goo00<3h7ooOol0
6Goo00<07gooOol06goo0P0O6Goo00<3h7ooOol0?7oo0@000Goo0Goo00000goo001oo`1WOol=O000
0`?PO01l0003O00SOol00`?POomoo`0GOol201lOOol00`0OOomoo`0HOol00`?POomoo`0kOol10001
Ool1Ool00003Ool007oo07Eoo`030n1oogoo02Aoo`030n1oogoo01Moo`0301moogoo021oo`0301mo
ogoo01Moo`030n1oogoo03]oo`40005oo`5oo`0000=oo`00Ool0MWoo00<3h7ooOol08goo00<3h7oo
Ool05goo00<07gooOol08Goo00<07gooOol05goo00<3h7ooOol0>Woo0@000Goo0Goo00000goo001o
o`1gOol00`?POomoo`0QOol00`?POomoo`0GOol00`0OOomoo`0SOol00`0OOomoo`0FOol00`?POomo
o`0jOol10001Ool1Ool00003Ool007oo07Qoo`030n1oogoo021oo`030n1oogoo01Ioo`0301moogoo
02Aoo`0301moogoo01Ioo`030n1oogoo03Yoo`40005oo`5oo`0000=oo`00Ool0NGoo00<3h7ooOol0
7goo00<3h7ooOol05Goo00<07gooOol047oo0`0O4goo00<07gooOol05Goo00<3h7ooOol0>Woo0@00
0Goo0Goo00000goo001oo`1jOol00`?POomoo`0NOol00`?POomoo`0EOol00`0OOomoo`0=Ool901l@
Ool00`0OOomoo`0FOol00`?POomoo`0iOol10001Ool1Ool00003Ool007oo07]oo`83h1ioo`030n1o
ogoo01Aoo`0301moogoo00aoo`d07`moo`0301moogoo01Eoo`030n1oogoo03Uoo`40005oo`5oo`00
00=oo`00Ool0OGoo00<3h7ooOol06goo00<3h7ooOol057oo00<07gooOol02goo3`0O3Woo00<07goo
Ool05Goo00<3h7ooOol0>Goo0@000Goo0Goo00000goo001oo`1nOol00`?POomoo`0JOol00`?POomo
o`0DOol00`0OOomoo`0:OolA01l8Ool20004Ool00`0OOomoo`0DOol00`?POomoo`0iOol10001Ool1
Ool00003Ool007oo07moo`030n1oogoo01Qoo`030n1oogoo01Eoo`0301moogoo00Uooa<07`Uoo`<0
0003Ool07goo01Eoo`030n1oogoo03Uoo`40005oo`5oo`0000=oo`00Ool0P7oo00<3h7ooOol05goo
00<3h7ooOol057oo00<07gooOol02Woo4`0O1goo10000Woo0P0000=oo`00Ool04Woo00<3h7ooOol0
>Goo0@000Goo0Goo00000goo001oo`21Ool00`?POomoo`0FOol00`?POomoo`0DOol00`0OOomoo`09
OolE01l2Ool40002Ool01`00Oomoogoo01moo`0001Aoo`030n1oogoo03Uoo`40005oo`5oo`0000=o
o`00Ool0PWoo00<3h7ooOol05Goo00<3h7ooOol057oo00<07gooOol02Goo500O0`001Goo00<007oo
Ool00goo00<007oo000057oo00<3h7ooOol0>7oo0@000Goo0Goo00000goo001oo`23Ool00`?POomo
o`0DOol00`?POomoo`0DOol00`0OOomoo`09OolA01l300000`0OOomoo`0;Ool00`0OOomoo`0DOol0
0`?POomoo`0hOol10001Ool1Ool00003Ool007oo08Aoo`030n1oogoo01=oo`030n1oogoo01Aoo`03
01moogoo00Qoo`h07`@000D07`aoo`0301moogoo01Aoo`030n1oogoo03Qoo`40005oo`5oo`0000=o
o`00Ool0QGoo00<3h7ooOol04Woo00<3h7ooOol057oo00<07gooOol027oo300O0P002@0O37oo00<0
7gooOol057oo00<3h7ooOol0>7oo0@000Goo0Goo00000goo001oo`26Ool00`?POomoo`0AOol00`?P
Oomoo`0DOol00`0OOomoo`08Ool<01l0100001l07`0O0P001@0O37oo00<07gooOol057oo00<3h7oo
Ool0>7oo0@000Goo0Goo00000goo001oo`27Ool00`?POomoo`0@Ool00`?POomoo`0DOol00`0OOomo
o`09Ool<01l00`0001l00002000401l=Ool00`0OOomoo`0DOol00`?POomoo`0hOol10001Ool1Ool0
0003Ool007oo08Qoo`83h11oo`030n1oogoo01Aoo`0301moogoo00Uoo``07`0500007`0001l00004
01l<Ool00`0OOomoo`0DOol00`?POomoo`0iOol10001Ool1Ool00003Ool007oo08Yoo`030n1oogoo
00eoo`030n1oogoo01Aoo`0301moogoo00Uoo``07`0400007`0O000501l<Ool00`0OOomoo`0DOol0
0`?POomoo`0iOol10001Ool1Ool00003Ool007oo08]oo`030n1oogoo00aoo`030n1oogoo01Eoo`03
01moogoo00Uoo`/07`0400007`0O000401l=Ool00`0OOomoo`0DOol00`?POomoo`0iOol10001Ool1
Ool00003Ool007oo08aoo`030n1oogoo00aoo`030n1oogoo01Aoo`0301moogoo00Uoo``07`030000
7`0O00@07`eoo`0301moogoo01Aoo`030n1oogoo03Uoo`40005oo`5oo`0000=oo`00Ool0SGoo00<3
h7ooOol02goo00<3h7ooOol057oo00<07gooOol02Woo2`0O00<0000O01l00`0O3Woo00<07gooOol0
57oo00<3h7ooOol0>Goo0@000Goo0Goo00000goo001oo`2>Ool00`?POomoo`0:Ool00`?POomoo`0D
Ool00`0OOomoo`0;Ool:01l00`0001l07`0201l>Ool00`0OOomoo`0EOol00`?POomoo`0iOol10001
Ool1Ool00003Ool007oo08moo`030n1oogoo00Uoo`030n1oogoo01Aoo`0301moogoo00aoo`X07`03
00007`0O00moo`0301moogoo01Eoo`030n1oogoo03Uoo`40005oo`5oo`0000=oo`00Ool0T7oo00<3
h7ooOol027oo00<3h7ooOol05Goo00<07gooOol03Goo200O00<007ooOol03Woo00<07gooOol05Goo
00<3h7ooOol0>Woo0@000Goo0Goo00000goo001oo`2AOol00`?POomoo`07Ool00`?POomoo`0EOol0
0`0OOomoo`0@Ool301l2Ool00`00Oomoo`0>Ool00`0OOomoo`0EOol00`?POomoo`0jOol10001Ool1
Ool00003Ool007oo099oo`030n1oogoo00Ioo`030n1oogoo01Ioo`0301moogoo01Eoo`03001oogoo
00aoo`0301moogoo01Ioo`030n1oogoo03Yoo`40005oo`5oo`0000=oo`00Ool0Tgoo00<3h7ooOol0
1Woo00<3h7ooOol05Woo00<07gooOol057oo00<007ooOol037oo00<07gooOol05Woo00<3h7ooOol0
>Woo0@000Goo0Goo00000goo001oo`2DOol00`?POomoo`05Ool00`?POomoo`0GOol00`0OOomoo`0C
Ool00`00Oomoo`0:Ool201lHOol00`?POomoo`0kOol10001Ool1Ool00003Ool007oo09Eoo`83h0Io
o`030n1oogoo01Moo`0301moogoo019oo`03001oogoo00Uoo`0301moogoo01Qoo`030n1oogoo03]o
o`40005oo`5oo`0000=oo`00Ool0Ugoo00<3h7ooOol00goo00<3h7ooOol067oo00<07gooOol04Woo
00<007oo000027oo00<07gooOol067oo00<3h7ooOol0>goo0@000Goo0Goo00000goo001oo`2HOol0
0`?POomoo`03Ool00`?POomoo`0HOol00`0OOomoo`0>Ool01P00Oomoo`00Ool000Moo`0301moogoo
01Qoo`030n1oogoo03aoo`40005oo`5oo`0000=oo`00Ool0VGoo00<3h7ooOol00Woo00<3h7ooOol0
6Goo00<07gooOol03Woo00@007oo000000Moo`0301moogoo01Uoo`030n1oogoo03aoo`40005oo`5o
o`0000=oo`00Ool0VWoo00D3h7ooOomoo`?P01aoo`0301moogoo00ioo`<000Eoo`807a]oo`030n1o
ogoo03eoo`40005oo`5oo`0000=oo`00Ool0Vgoo00D3h7ooOomoo`?P01aoo`0301moogoo00moo`03
001oogoo0080000301moogoo00Uoo`03001oogoo00moo`030n1oogoo03eoo`40005oo`5oo`0000=o
o`00Ool0W7oo00@3h7ooOol3h1eoo`D07`ioo`807`03001oogoo00]oo`8000ioo`030n1oogoo03io
o`40005oo`5oo`0000=oo`00Ool0WGoo00@3h7ooOol3h25oo`@07`Ioo`@07`9oo`03001oogoo00eo
o`8000aoo`030n1oogoo03ioo`40005oo`5oo`0000=oo`00Ool0WWoo00<3h7oo0n009Goo1P0O0Woo
5`002Woo00<3h7ooOol0?goo0@000Goo0Goo00000goo001oo`1cOomK0ol01@000ol3o`000ol00P00
30?o0P00A`?o1goo0@000Goo0Goo00000goo001oo`1cOomK0ol00`000ol00002000<0ol200040ol2
00000`?o0003o`100ol7Ool10001Ool1Ool00003Ool007oo07=ooe/3o`050003o`?o0ol0000D0ol0
0`000ol3o`100ol7Ool10001Ool1Ool00003Ool007oo07=ooe/3o`050003o`?o0ol0000C0ol00`00
0ol000110ol7Ool10001Ool1Ool00003Ool007oo07=ooe/3o`040003o`00001H0ol7Ool10001Ool1
Ool00003Ool007oo07=ooe/3o`030003o`00008005L3o`Moo`40005oo`5oo`0000=oo`00Ool0Lgoo
F`?o00<000?o0ol0F@?o1goo0@000Goo0Goo00000goo001oo`1cOomK0ol00`000ol3o`1I0ol7Ool1
0001Ool1Ool00003Ool007oo07=ooe/3o`030003o`?o05T3o`Moo`40005oo`5oo`0000=oo`00Ool0
LgooF`?o00<000?o0ol0F@?o1goo0@000Goo0Goo00000goo001oo`1cOomK0ol00`000ol3o`1I0ol7
Ool10001Ool1Ool00003Ool007oo07=ooe/3o`030003o`?o05T3o`Moo`40005oo`5oo`0000=oo`00
Ool0LgooF`?o00<000?o0ol0F@?o1goo0@000Goo0Goo00000goo001oo`1cOomK0ol00`000ol3o`1I
0ol7Ool10001Ool1Ool00003Ool007oo07=ooe/3o`030003o`?o05T3o`Moo`40005oo`5oo`0000=o
o`00Ool0LgooF`?o00<000?o0ol0F@?o1goo0@000Goo0Goo00000goo001oo`1cOomI0ol01@000ol0
00?o0000F@?o1goo0@000Goo0Goo00000goo001oo`1cOomI0ol010000ol00000FP?o1goo0@000Goo
0Goo00000goo001oo`1cOomJ0ol3001J0ol7Ool10001Ool1Ool00003Ool007oo07=ooeX3o`8005/3
o`Moo`40005oo`5oo`0000=oo`00Ool0LgooF`?o00<000?o0ol0F@?o1goo0@000Goo0Goo00000goo
001oo`1cOomM0ol2001H0ol7Ool10001Ool1Ool00003Ool007oo07=ooeh3o`030003o`?o05H3o`Mo
o`40005oo`5oo`0000=oo`00Ool0LgooGP?o00<000?o0ol0EP?o1goo0@000Goo0Goo00000goo001o
o`1cOomM0ol00`000ol0001G0ol7Ool10001Ool1Ool00003Ool007oo07=ooed3o`040003o`00001F
0ol7Ool10001Ool1Ool00003Ool007oo07=ookL3o`Moo`40005oo`5oo`0000=oo`00Ool0Lgoo]`?o
1goo0@000Goo0Goo00000goo001oo`1cOong0ol7Ool10001Ool1Ool00003Ool007oo07=ookL3o`Mo
o`40005oo`5oo`0000=oo`00Ool0ogoo<Woo0@000Goo0Goo00000goo001oo`3oOolbOol10001Ool1
Ool00003Ool007oo0?mooc9oo`40005oo`5oo`0000=oo`000000o`00<`000Woo0000\
\>"],
  ImageRangeCache->{{{0, 310}, {169, 0}} -> {-2.56701, -3.28268, 0.0654757, 
  0.0654757}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Five bodies are used in the gear-drive model. No body objects are defined \
because no explicit point coordinates are used in the model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(drivegear = 2; \)\), 
    \(\(drivepulley = 3; \)\), 
    \(\(pinion = 4; \)\), 
    \(\(rack = 5; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Eight constraints are required to model the gear-drive mechanism."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint locates the center of the drive gear at the origin of the \
ground body."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the rotation of the drive gear."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the rotation of the drive pulley and specifies the \
distance between the drive gear and the drive pulley."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint prevents the drive pulley from orbiting the drive gear."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the rotation of the pinion and specifies the distance \
between the drive pulley and the pinion."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint prevents the pinion from orbiting the drive pulley."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RackAndPinion2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the translation of the rack and specifies the \
orthogonal distance between the rack axis and the pinion center."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Parallel1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the rack axis to be parallel to a horizontal line on \
the ground, which prevents the rack from orbiting the pinion. "
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the constraints for the gear model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRevolute2[1, Point[drivegear, 0], Point[ground, 0]], 
      \n\tRotationLock1[2, drivegear, ground, 2\ N[\[Pi]]\ T], \n\t
      TwoGears2[3, Point[drivegear, 0], 2.0, Point[drivepulley, 0], 3.0, 0], 
      \n\tRelativeY1[4, Point[drivepulley, 0], 0], \n\t
      TwoPulleys2[5, \n\t\tPoint[drivepulley, 0], 2.0, Point[pinion, 0], 3.0, 
        7.0, Angle[drivepulley, 0, pinion, 0]], \n\t
      RelativeY1[6, Point[pinion, 0], 4], \n\t
      RackAndPinion2[7, \n\t\tPoint[pinion, 0], \(-1.5\), 
        Axis[rack, 0, {1, 0}], 0], \n\t
      Parallel1[8, \n\t\tVector[rack, {1, 0}], Vector[ground, {1, 0}]]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Initial guesses for the drive pulley, rack, and pinion must be set or the \
model will not converge. Almost any guesses greater than zero will do. "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This sets the initial guesses for the next solution attempt only. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetGuess[X3 \[Rule] 5, X4 \[Rule] 10, Y4 \[Rule] 4, X5 \[Rule] 10, 
      Y5 \[Rule] 6]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 0, Y2 \[Rule] 0, Th2 \[Rule] 0, X3 \[Rule] 5, 
      Y3 \[Rule] 0, Th3 \[Rule] 0, X4 \[Rule] 10, Y4 \[Rule] 4, 
      Th4 \[Rule] 0, X5 \[Rule] 10, Y5 \[Rule] 6, Th5 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Because of the presence of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the driving constraint, the model can be run through its intended \
range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the angular coordinate of the drive gear."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.314159265358979311`\), ",", 
        \(X3 \[Rule] 5.`\), ",", \(Y3 \[Rule] 0.`\), ",", 
        \(Th3 \[Rule] \(-0.209439510239319526`\)\), ",", 
        \(X4 \[Rule] 10.7445626465380295`\), ",", \(Y4 \[Rule] 4.`\), ",", 
        \(Th4 \[Rule] \(-0.139626340159546359`\)\), ",", 
        \(X5 \[Rule] 10.9540021567773472`\), ",", \(Y5 \[Rule] 5.5`\), ",", 
        \(Th5 \[Rule] 0.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.25."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SolveMech[0.25]\)\[LeftDoubleBracket]{4, 7, 10}
        \[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({Th2 \[Rule] 1.570796326794897`, Th3 \[Rule] \(-1.04719755119659785`\), 
      Th4 \[Rule] \(-0.698131700797731813`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the gear-drive mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.25."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .53052  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.12005 0.0481201 0.156992 0.0481201 [ 
[ -0.001 -0.001 0 0 ] 
[ 1.001 .53152 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 0 m 
0 .53052 L 
s 
P 
P 
p 
p 
.002 w 
0 .53052 m 
1 .53052 L 
s 
P 
p 
.002 w 
1 0 m 
1 .53052 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 .53052 L 
0 .53052 L 
closepath 
clip 
newpath 
p 
p 
1 0 0 r 
.004 w 
newpath 
.12005 .15699 .09624 0 365.73 arc 
s 
newpath 
.36065 .15699 .14436 0 365.73 arc 
s 
.08 w 
.12005 .15699 Mdot 
P 
p 
0 1 0 r 
.004 w 
newpath 
.63708 .34947 .14436 0 365.73 arc 
s 
newpath 
.36065 .15699 .09624 0 365.73 arc 
s 
.08 w 
.36065 .15699 Mdot 
p 
.004 w 
.4038 .07097 m 
.7018 .22043 L 
s 
.53851 .45494 m 
.29494 .2273 L 
s 
P 
P 
p 
0 0 1 r 
.004 w 
newpath 
.63708 .34947 .07218 0 365.73 arc 
s 
.08 w 
.63708 .34947 Mdot 
P 
p 
0 1 1 r 
.39875 .51789 m 
.39875 .42165 L 
.97619 .42165 L 
.97619 .51789 L 
F 
P 
p 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .18742 .15699 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .12005 .22436 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(1)] .12005 .15699 -1.5 -0.9 Mshowa 
P 
.004 w 
.18742 .15699 m 
.12005 .15699 L 
.12005 .22436 L 
s 
.17394 .15025 m 
.18742 .15699 L 
.17394 .16373 L 
s 
.11331 .21089 m 
.12005 .22436 L 
.12679 .21089 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .12005 .22436 1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .05268 .15699 1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(2)] .12005 .15699 1.5 -0.9 Mshowa 
P 
.004 w 
.12005 .22436 m 
.12005 .15699 L 
.05268 .15699 L 
s 
.12679 .21089 m 
.12005 .22436 L 
.11331 .21089 L 
s 
.06616 .15025 m 
.05268 .15699 L 
.06616 .16373 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .39433 .09865 -2.04904 .32942 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .41899 .19068 -2.04904 .32942 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(3)] .36065 .15699 -2.04904 .32942 Mshowa 
P 
.004 w 
.39433 .09865 m 
.36065 .15699 L 
.41899 .19068 L 
s 
.38176 .10695 m 
.39433 .09865 L 
.39343 .11369 L 
s 
.40396 .18977 m 
.41899 .19068 L 
.41069 .1781 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .68869 .30617 -2.11325 -0.11093 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .68038 .40108 -2.11325 -0.11093 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(4)] .63708 .34947 -2.11325 -0.11093 Mshowa 
P 
.004 w 
.68869 .30617 m 
.63708 .34947 L 
.68038 .40108 L 
s 
.67403 .30967 m 
.68869 .30617 L 
.68269 .31999 L 
s 
.66656 .39509 m 
.68038 .40108 L 
.67688 .38643 L 
s 
P 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .75484 .42165 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .68747 .48902 -1.5 -0.9 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(5)] .68747 .42165 -1.5 -0.9 Mshowa 
P 
.004 w 
.75484 .42165 m 
.68747 .42165 L 
.68747 .48902 L 
s 
.74136 .41492 m 
.75484 .42165 L 
.74136 .42839 L 
s 
.68073 .47555 m 
.68747 .48902 L 
.69421 .47555 L 
s 
P 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{316, 167},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004l0000Ya000`40O003h00Oogoo?Goo00000goo
0000003o000h0002Ool00003Ool007oo0?moocMoo`40005oo`5oo`0000=oo`00Ool0ogoo=goo0@00
0Goo0Goo00000goo001oo`3oOolgOol10001Ool1Ool00003Ool007oo06Mooa5l0;ioo`40005oo`5o
o`0000=oo`00Ool0HWoo1G`04Goo17`0^Woo0@000Goo0Goo00000goo001oo`1POol2O00JOol2O02h
Ool10001Ool1Ool00003Ool007oo05ioo`9l01ioo`9l0;Ioo`40005oo`5oo`0000=oo`00Ool0G7oo
0W`08Woo0W`0]7oo0@000Goo0Goo00000goo001oo`1JOol2O00VOol2O02bOol10001Ool1Ool00003
Ool007oo05Qoo`9l02Yoo`9l0;1oo`40005oo`5oo`0000=oo`00Ool0EWoo0W`0;Woo0W`0[Woo0@00
0Goo0Goo00000goo001oo`1DOol2O00bOol2O02/Ool10001Ool1Ool00003Ool007oo05=oo`03O01o
ogoo03Aoo`03O01oogoo0:Uoo`40005oo`5oo`0000=oo`00Ool0Dgoo00=l07ooOol0=Goo00=l07oo
Ool0Z7oo0@000Goo0Goo00000goo001oo`1AOol2O00iOol00g`0Oomoo`2WOol10001Ool1Ool00003
Ool007oo051oo`03O01oogoo03Yoo`03O01oogoo0:Ioo`40005oo`5oo`0000=oo`00Ool0Cgoo00=l
07ooOol0?7oo00=l07ooOol0YGoo0@000Goo0Goo00000goo001oo`1>Ool00g`0Oomoo`0nOol2O02U
Ool10001Ool1Ool00003Ool007oo01aoo`ml029oo`03O01oogoo01Moo`l3h1Yoo`03O01oogoo0:=o
o`40005oo`5oo`0000=oo`00Ool06Goo0g`03goo0g`07Woo00=l07ooOol05Goo0`?P3goo0`?P67oo
00=l07ooOol0XWoo0@000Goo0Goo00000goo001oo`0GOol2O00EOol2O00KOol00g`0Oomoo`0DOol2
0n0EOol20n0FOol00g`0Oomoo`2ROol10001Ool1Ool00003Ool007oo01Ioo`03O01oogoo01Moo`9l
01Uoo`03O01oogoo01=oo`030n1oogoo01Moo`83h1Eoo`03O01oogoo0:5oo`40005oo`5oo`0000=o
o`00Ool057oo0W`077oo0W`05Goo0W`057oo0P?P77oo0P?P57oo0W`0XGoo0@000Goo0Goo00000goo
001oo`0BOol2O00POol00g`0Oomoo`0AOol00g`0Oomoo`0BOol20n0POol20n0COol00g`0Oomoo`2O
Ool10001Ool1Ool00003Ool007oo015oo`03O01oogoo025oo`9l015oo`03O01oogoo015oo`030n1o
ogoo025oo`<3h19oo`03O01oogoo09ioo`40005oo`5oo`0000=oo`00Ool047oo00=l07ooOol097oo
0W`03Woo00=l07ooOol04Goo00<3h7ooOol097oo0`?P47oo00=l07ooOol0WWoo0@000Goo0Goo0000
0goo001oo`0?Ool00g`0Oomoo`0WOol00g`0Oomoo`0;Ool00g`0Oomoo`0@Ool00`?POomoo`0WOol3
0n0?Ool00g`0Oomoo`2MOol10001Ool1Ool00003Ool007oo00ioo`03O01oogoo02Uoo`03O01oogoo
00Uoo`03O01oogoo011oo`030n1oogoo021oo`800003Ool007oo00Aoo`040n1oo`?P0n0=Ool00g`0
Oomoo`2MOol10001Ool1Ool00003Ool007oo00eoo`03O01oogoo02]oo`03O01oogoo00Qoo`03O01o
ogoo00moo`030n1oogoo02=oo`03001oogoo00Eoo`030n1oogoo0083h0aoo`03O01oogoo09aoo`40
005oo`5oo`0000=oo`00Ool03Goo00=l07ooOol0:goo00=l07ooOol01goo00=l07ooOol047oo00<3
h7ooOol08Woo00<007oo00001Woo00<3h7ooOol00Woo0P?P2Woo00=l07ooOol0W7oo0@000Goo0Goo
00000goo001oo`0<Ool00g`0Oomoo`0]Ool00g`0Oomoo`06Ool00g`0Oomoo`0?Ool00`?POomoo`0O
Ool00`00Oomoo`0;Ool00`?POomoo`03Ool20n09Ool00g`0Oomoo`2KOol10001Ool1Ool00003Ool0
07oo00]oo`03O01oogoo02ioo`03O01oogoo00Eoo`03O01oogoo00moo`030n1oogoo01ioo`<000eo
o`030n1oogoo00Eoo`83h0Moo`03O01oogoo09]oo`40005oo`5oo`0000=oo`00Ool02Woo00=l07oo
Ool0<7oo00=l07ooOol017oo00=l07ooOol03Woo00<3h7ooOol07Goo0P0000=oo`0000003Woo00<3
h7ooOol01Woo0P?P1Woo00=l07ooOol0VWoo0@000Goo0Goo00000goo001oo`0:Ool00g`0Oomoo`0a
Ool00g`0Oomoo`03Ool00g`0Oomoo`0>Ool00`?POomoo`0OOol00`00Ool0000?Ool00`?POomoo`07
Ool20n04Ool00g`0Oomoo`2JOol10001Ool1Ool00003Ool007oo00Uoo`03O01oogoo039oo`03O01o
ogoo00=oo`03O01oogoo00eoo`030n1oogoo021oo`03001oo`0000moo`030n1oogoo00Uoo`83h0=o
o`03O01oogoo09Uoo`40005oo`5oo`0000=oo`00Ool02Goo00=l07ooOol0<goo00=l07ooOol00Woo
00=l07ooOol03Goo00<3h7ooOol07goo00<007ooOol04Goo00<3h7ooOol02Woo0P?P00=oog`0Ool0
VWoo0@000Goo0Goo00000goo001oo`08Ool00g`0Oomoo`0dOol01G`0OomoogooO0003goo00<3h7oo
Ool087oo00<007ooOol04Goo00<3h7ooOol037oo0P?PVgoo0@000Goo0Goo00000goo001oo`07Ool0
0g`0Oomoo`0eOol01G`0OomoogooO0003Woo00<3h7ooOol087oo00<007ooOol04Woo00<3h7ooOol0
3Goo00=l00?P0n00VGoo0@000Goo0Goo00000goo001oo`07Ool00g`0Oomoo`0HOol3O00KOol00g`0
Ooml000?Ool00`?POomoo`0HOol30n05Ool00`00Oomoo`0COol00`?POomoo`0<Ool00g`0Oomoo`02
0n2GOol10001Ool1Ool00003Ool007oo00Ioo`03O01oogoo01Ioo`Ul01Qoo`03O01oog`000ioo`03
0n1oogoo01Ioo`T3h003Ool007oo01Eoo`030n1oogoo00eoo`04O01oogooOol20n2EOol10001Ool1
Ool00003Ool007oo00Ioo`03O01oogoo01Aoo`el01Ioo`03O01oog`000ioo`030n1oogoo01Aoo`/3
h0030003h7oo01Eoo`030n1oogoo00eoo`03O01oogoo00=oo`83h9=oo`40005oo`5oo`0000=oo`00
Ool01Woo00=l07ooOol04goo3g`05Woo0W`03Woo00<3h7ooOol04goo30?P00<000?P0n005Woo00<3
h7ooOol037oo00=l07ooOol01Goo0P?PTGoo0@000Goo0Goo00000goo001oo`06Ool00g`0Oomoo`0B
OolAO00EOol2O00>Ool00`?POomoo`0BOol<0n000`000n03h0020n0EOol00`?POomoo`0<Ool00g`0
Oomoo`07Ool20n2?Ool10001Ool1Ool00003Ool007oo00Ioo`03O01oogoo015ooa=l01Aoo`9l00io
o`030n1oogoo015oo`d3h0030003h0?P00<3h1Aoo`030n1oogoo00aoo`03O01oogoo00Uoo`83h8eo
o`40005oo`5oo`0000=oo`00Ool01Woo00=l07ooOol04Goo4g`057oo0W`03Woo00<3h7ooOol04Goo
30?P00<000?P0n0010?P57oo00<3h7ooOol037oo00=l07ooOol02goo0P?PRgoo0@000Goo0Goo0000
0goo001oo`06Ool00g`0Oomoo`0@OolEO00COol2O00>Ool00`?POomoo`0@Ool=0n0400040n0COol0
0`?POomoo`0=Ool00g`0Oomoo`0<Ool20n29Ool10001Ool1Ool00003Ool007oo00Ioo`03O01oogoo
00Yoo`03001oogoo00=ooaEl00Ioo`8000]oo`9l00ioo`030n1oogoo011oo``3h0050003h0?P0n00
00040n0COol00`?POomoo`0=Ool00g`0Oomoo`0>Ool20n27Ool10001Ool1Ool00003Ool007oo00Io
o`03O01oogoo00Qoo`8000IooaEl00Qoo`8000Yoo`03O01oogoo00aoo`030n1oogoo011oo``3h004
0003h0?P00050n0DOol00`?POomoo`0<Ool00g`0Oomoo`0@Ool20n25Ool10001Ool1Ool00003Ool0
07oo00Ioo`03O01oogoo008000Aoob/000Qoo`03O01oogoo00aoo`030n1oogoo00moo``3h0030003
h0?P0083h0030003h0?P00<3h1=oo`030n1oogoo00aoo`03O01oogoo019oo`83h8=oo`40005oo`5o
o`0000=oo`00Ool01Woo00El07ooOomoo`0000Eoo`8000Ioo`al0003001l07`000Ql00Moo`8000Yo
o`03O01oogoo00aoo`030n1oogoo00moo`d3h0D000D3h1=oo`030n1oogoo00aoo`03O01oogoo01Ao
o`83h85oo`40005oo`5oo`0000=oo`00Ool01Woo00El07ooOomoo`0000Moo`8000Aoo`Il00<000=l
0003001l0000008000Il00Eoo`8000Aoo`800003Ool007oo009oo`9l00ioo`030n1oogoo00moo`l3
h08000H3h19oo`030n1oogoo00eoo`03O01oogoo01Ioo`83h7moo`40005oo`5oo`0000=oo`00Ool0
1Woo00Il07ooOol007oo000=Ool5O0020004O0001000O01l00001W`03Woo00<007ooOol00Woo0W`0
3Woo00<3h7ooOol047oo40?P0P000`?P4goo00<3h7ooOol037oo00=l07ooOol06Goo0P?POGoo0@00
0Goo0Goo00000goo001oo`06Ool01G`0Oomoo`00Ool00P0037oo1g`000D007`0O01l0000009l0003
001l07`000Al00eoo`03001oo`0000=oo`9l00ioo`030n1oogoo011ooa83h08000030n1oogoo015o
o`030n1oogoo00aoo`03O01oogoo01]oo`83h7]oo`40005oo`5oo`0000=oo`00Ool01Woo00=l07oo
Ool047oo1g`000D007`0O01l0000009l0003001l07`000Al01=oo`9l00ioo`030n1oogoo011ooa@3
h003001oogoo015oo`030n1oogoo00aoo`03O01oogoo01eoo`83h7Uoo`40005oo`5oo`0000=oo`00
Ool01Woo00=l07ooOol04Goo17`00`000g`000@007`0000000El01Aoo`9l00ioo`030n1oogoo015o
oa<3h003Ool0000000=oo`03001oogoo00=oo`8000Ioo`030n1oogoo00aoo`03O01oogoo01moo`83
h7Moo`40005oo`5oo`0000=oo`00Ool01Woo00=l07ooOol04Goo2W`000<007`0O0001W`057oo0W`0
3Woo00<3h7ooOol04Goo4`?P0goo0P000Woo00<007ooOol00goo00<007ooOol017oo00<3h7ooOol0
37oo00=l07ooOol08Goo0P?PMGoo0@000Goo0Goo00000goo001oo`06Ool00g`0Oomoo`0BOol9O000
0`00O01l0005O00DOol00g`0Ooml000>Ool00`?POomoo`0BOolA0n06Ool30005Ool00`00Oomoo`03
Ool00`?POomoo`0=Ool00g`0Oomoo`0SOol20n1cOol10001Ool1Ool00003Ool007oo00Moo`03O01o
ogoo019oo`Ql0003001l07`000Al01Eoo`03O01oog`000moo`030n1oogoo019oo`l3h0Uoo`8000=o
o`03001oo`0000Aoo`030n1oogoo00eoo`03O01oogoo02Eoo`83h75oo`40005oo`5oo`0000=oo`00
Ool01goo00=l07ooOol04goo1g`000<007`0O0000g`05Goo00Al07ooOoml00moo`030n1oogoo01=o
o`d3h0Moo`H0009oo`04001oo`000002Ool00`?POomoo`0=Ool00g`0Oomoo`0XOol20n1_Ool10001
Ool1Ool00003Ool007oo00Qoo`03O01oogoo01Aoo`El0004001l07`0O00GOol01G`0OomoogooO000
3goo00<3h7ooOol057oo2@?P5goo00<3h7ooOol03Goo00=l07ooOol0:Woo0P?PKGoo0@000Goo0Goo
00000goo001oo`08Ool00g`0Oomoo`0GOol2O0000`00Oomoo`0HOol01G`0OomoogooO0003goo00<3
h7ooOol05goo0`?P6Woo00<3h7ooOol03Goo00=l07ooOol0;7oo0P?PJgoo0@000Goo0Goo00000goo
001oo`09Ool00g`0Oomoo`0HOol00`00Oomoo`0GOol00g`0Oomoo`03Ool00g`0Oomoo`0=Ool00`?P
Oomoo`0bOol00`?POomoo`0>Ool00g`0Oomoo`0^Ool20n1YOol10001Ool1Ool00003Ool007oo00Uo
o`03O01oogoo01Qoo`03001oogoo01Moo`03O01oogoo00=oo`03O01oogoo00eoo`030n1oogoo039o
o`030n1oogoo00eoo`03O01oogoo035oo`83h6Moo`40005oo`5oo`0000=oo`00Ool02Woo00=l07oo
Ool05goo00<007ooOol05Woo00=l07ooOol017oo00=l07ooOol03Woo00<3h7ooOol0<7oo00<3h7oo
Ool03Woo00=l07ooOol08Goo4@?P00=oo`?P0n00IGoo0@000Goo0Goo00000goo001oo`0;Ool00g`0
Oomoo`0FOol00`00Oomoo`0FOol00g`0Oomoo`04Ool00g`0Oomoo`0?Ool00`?POomoo`0_Ool00`?P
Oomoo`0=Ool00g`0Oomoo`0MOol50n0AOol50n1SOol10001Ool1Ool00003Ool007oo00]oo`03O01o
ogoo01=oo`06001oogoo001oo`005Goo00=l07ooOol01Woo00=l07ooOol03Woo00<3h7ooOol0;Woo
00<3h7ooOol03Woo00=l07ooOol06goo0P?P6Woo0`?PHGoo0@000Goo0Goo00000goo001oo`0<Ool0
0g`0Oomoo`0COol01000Ool000005Goo00=l07ooOol01goo00=l07ooOol03goo00<3h7ooOol0;7oo
00<3h7ooOol03Woo00=l07ooOol06Woo0P?P7Woo0`?PGgoo0@000Goo0Goo00000goo001oo`0=Ool0
0g`0Oomoo`0BOol01000Ool000005Goo00=l07ooOol027oo00=l07ooOol03goo00<3h7ooOol0:goo
00<3h7ooOol03Woo00=l07ooOol067oo0P?P8Woo0`?PGGoo0@000Goo0Goo00000goo001oo`0>Ool0
0g`0Oomoo`0BOol2000EOol00g`0Oomoo`09Ool00g`0Oomoo`0@Ool00`?POomoo`0YOol00`?POomo
o`0>Ool00g`0Oomoo`0GOol20n0VOol20n1LOol10001Ool1Ool00003Ool007oo00moo`03O01oogoo
019oo`04001oo`00000AOol00g`0Oomoo`0;Ool00g`0Oomoo`0@Ool00`?POomoo`0WOol00`?POomo
o`0?Ool00g`0Oomoo`0EOol20n0ZOol20n1JOol10001Ool1Ool00003Ool007oo011oo`03O01oogoo
01Aoo`03001oogoo00eoo`9l00ioo`03O01oogoo011oo`83h2Ioo`83h15oo`03O01oogoo01Aoo`83
h2ioo`83h5Qoo`40005oo`5oo`0000=oo`00Ool04Goo00=l07ooOol02Goo0P0000=oo`00Ool01Goo
00<007ooOol037oo00=l07ooOol03goo00=l07ooOol047oo0P?P97oo00<3h7ooOol04Goo00=l07oo
Ool04Woo0P?P<Woo0P?PEWoo0@000Goo0Goo00000goo001oo`0BOol00g`0Oomoo`0:Ool00`00Oomo
o`04Ool00`00Ool0000<Ool00g`0Oomoo`0@Ool00g`0Oomoo`0AOol20n0ROol00`?POomoo`0AOol0
0g`0Oomoo`0BOol00`?POomoo`0dOol00`?POomoo`1COol10001Ool1Ool00003Ool007oo01=oo`9l
00Uoo`03001oo`0000Eoo`04001oo`000009Ool2O00DOol00g`0Oomoo`0AOol30n0NOol20n0DOol0
0g`0Oomoo`0BOol00`?POomoo`0eOol00`?POomoo`1BOol10001Ool1Ool00003Ool007oo01Eoo`03
O01oogoo01Uoo`9l01Moo`03O01oogoo015oo`030n1oo`?P01]oo`83h1Eoo`03O01oogoo015oo`83
h3Uoo`83h59oo`40005oo`5oo`0000=oo`00Ool05Woo0g`05goo00=l07ooOol067oo00=l07ooOol0
4Goo00<3h7oo0n000P?P5goo00<3h7ooOol057oo00=l07ooOol04Goo00<3h7ooOol0>Woo00<3h7oo
Ool0D7oo0@000Goo0Goo00000goo001oo`0IOol3O00BOol2O00KOol00g`0Oomoo`0BOol010?POomo
ogoo0`?P4Woo0P?P5Woo00=l07ooOol04Goo00<3h7ooOol0?7oo00<3h7ooOol0Cgoo0@000Goo0Goo
00000goo001oo`0LOol3O009Ool6O00NOol00g`0Oomoo`0BOol20n04Ool30n09Ool60n0HOol00g`0
Oomoo`0@Ool00`?POomoo`0nOol20n1?Ool10001Ool1Ool00003Ool007oo01moo`Ul02Eoo`9l01Ao
o`030n1oogoo00Aoo`T3h1eoo`03O01oogoo011oo`030n1oogoo041oo`030n1oogoo04eoo`40005o
o`5oo`0000=oo`00Ool0CWoo00=l07ooOol04goo00<3h7ooOol0:7oo00=l07ooOol047oo00<3h7oo
Ool0@Woo00<3h7ooOol0C7oo0@000Goo0Goo00000goo001oo`1?Ool00g`0Oomoo`0COol00`?POomo
o`0VOol00g`0Oomoo`0@Ool00`?POomoo`14Ool00`?POomoo`1;Ool10001Ool1Ool00003Ool007oo
051oo`9l01Aoo`030n1oogoo02=oo`9l01=oo`030n1oogoo04Eoo`030n1oogoo04Yoo`40005oo`5o
o`0000=oo`00Ool0DWoo00=l07ooOol04Woo00<3h7ooOol08Goo00=l07ooOol04Woo00<3h7ooOol0
Agoo00<3h7ooOol0BGoo0@000Goo0Goo00000goo001oo`1COol00g`0Oomoo`0BOol00`?POomoo`0P
Ool00g`0Oomoo`0AOol00`?POomoo`18Ool00`?POomoo`19Ool10001Ool1Ool00003Ool007oo05Ao
o`03O01oogoo019oo`030n1oogoo01eoo`9l01=oo`030n1oogoo04Yoo`030n1oogoo04Qoo`40005o
o`5oo`0000=oo`00Ool0EGoo00=l07ooOol04Woo00<3h7ooOol06goo00=l07ooOol04Woo00<3h7oo
Ool08Woo1P0O8goo00<3h7ooOol0B7oo0@000Goo0Goo00000goo001oo`1FOol00g`0Oomoo`0BOol0
0`?POomoo`0IOol00g`0Oomoo`0COol00`?POomoo`0MOol501l6Ool401lPOol00`?POomoo`17Ool1
0001Ool1Ool00003Ool007oo05Moo`9l01=oo`030n1oogoo01Ioo`9l01Eoo`030n1oogoo01aoo`80
7`moo`807aioo`030n1oogoo04Moo`40005oo`5oo`0000=oo`00Ool0FGoo0W`04Woo00<3h7ooOol0
4goo0W`05goo00<3h7ooOol06Woo0P0O4goo0P0O7Goo00<3h7ooOol0AWoo0@000Goo0Goo00000goo
001oo`1KOol2O00AOol00`?POomoo`0@Ool2O00HOol00`?POomoo`0JOol00`0OOomoo`0EOol201lK
Ool00`?POomoo`16Ool10001Ool1Ool00003Ool007oo05eoo`Al00ioo`030n1oogoo00]oo`Al01Yo
o`030n1oogoo01Uoo`0301moogoo01Qoo`807aYoo`030n1oogoo04Eoo`40005oo`5oo`0000=oo`00
Ool0HGoo0g`037oo0P?P2Goo0W`07Goo00<3h7ooOol06Goo00<07gooOol06Woo00<07gooOol067oo
00<3h7ooOol0AGoo0@000Goo0Goo00000goo001oo`1TOol6O008Ool00`?POoml0006O00OOol00`?P
Oomoo`0GOol201lNOol00`0OOomoo`0HOol00`?POomoo`14Ool10001Ool1Ool00003Ool007oo06Yo
o`Ul00030n1oogoo02Aoo`030n1oogoo01Ioo`0301moogoo01moo`807aQoo`030n1oogoo04Aoo`40
005oo`5oo`0000=oo`00Ool0M7oo00<3h7ooOol08goo00<3h7ooOol05Woo00<07gooOol07Goo0`00
00H07goo000007oo000DOol00`?POomoo`13Ool10001Ool1Ool00003Ool007oo07Eoo`030n1oogoo
029oo`030n1oogoo01Eoo`0301moogoo01]oo`<00005Ool00000Ool07`02Ool00`00Oomoo`0COol0
0`?POomoo`13Ool10001Ool1Ool00003Ool007oo07Ioo`030n1oogoo021oo`030n1oogoo01Ioo`03
01moogoo01ioo`80009oo`0501moo`00Ool0000DOol00`?POomoo`13Ool10001Ool1Ool00003Ool0
07oo07Moo`030n1oogoo01moo`030n1oogoo01Eoo`0301moogoo01ioo`03001oo`0000=oo`0301mo
ogoo01Eoo`030n1oogoo04=oo`40005oo`5oo`0000=oo`00Ool0N7oo00<3h7ooOol07Woo00<3h7oo
Ool057oo00<07gooOol047oo0`0O2Woo0P0000=oo`00Ool00goo00<07gooOol05Goo00<3h7ooOol0
@goo0@000Goo0Goo00000goo001oo`1iOol00`?POomoo`0MOol00`?POomoo`0DOol00`0OOomoo`0=
Ool901l6Ool01@00Oomoogoo00001Goo00<07gooOol05Goo00<3h7ooOol0@Woo0@000Goo0Goo0000
0goo001oo`1jOol00`?POomoo`0KOol00`?POomoo`0EOol00`0OOomoo`0;Ool=01l3Ool00`00Oomo
o`08Ool00`0OOomoo`0EOol00`?POomoo`12Ool10001Ool1Ool00003Ool007oo07]oo`030n1oogoo
01Yoo`030n1oogoo01Aoo`0301moogoo00]oo`l07`03Ool007oo00]oo`0301moogoo01Aoo`030n1o
ogoo049oo`40005oo`5oo`0000=oo`00Ool0O7oo00<3h7ooOol06Goo00<3h7ooOol057oo00<07goo
Ool02Woo400O00<007ooOol02goo00<07gooOol057oo00<3h7ooOol0@Woo0@000Goo0Goo00000goo
001oo`1mOol00`?POomoo`0HOol00`?POomoo`0COol00`0OOomoo`0:Ool@01l00`0001l07`0=Ool0
0`0OOomoo`0DOol00`?POomoo`11Ool10001Ool1Ool00003Ool007oo07ioo`030n1oogoo01Moo`03
0n1oogoo01=oo`0301moogoo00Yoo`l07`0400007`0O01l=Ool00`0OOomoo`0DOol00`?POomoo`11
Ool10001Ool1Ool00003Ool007oo07moo`030n1oogoo01Ioo`030n1oogoo01=oo`0301moogoo00Uo
o`h07`8000D07`aoo`0301moogoo01Aoo`030n1oogoo045oo`40005oo`5oo`0000=oo`00Ool0P7oo
0P?P5Woo00<3h7ooOol04goo00<07gooOol02Goo3@0O00<0000O01l01@0O37oo00<07gooOol057oo
00<3h7ooOol0@Goo0@000Goo0Goo00000goo001oo`22Ool00`?POomoo`0COol00`?POomoo`0COol0
0`0OOomoo`09Ool<01l00`0001l07`02000401l<Ool00`0OOomoo`0DOol00`?POomoo`11Ool10001
Ool1Ool00003Ool007oo08=oo`030n1oogoo019oo`030n1oogoo01=oo`0301moogoo00Qoo``07`03
00007`0O00<000D07`]oo`0301moogoo01Aoo`030n1oogoo045oo`40005oo`5oo`0000=oo`00Ool0
Q7oo00<3h7ooOol04Goo00<3h7ooOol04goo00<07gooOol027oo3@0O00D0000O00007`0000D07`]o
o`0301moogoo01Aoo`030n1oogoo045oo`40005oo`5oo`0000=oo`00Ool0QGoo00<3h7ooOol047oo
00<3h7ooOol04goo00<07gooOol027oo3P0O00<0000O00001P0O2goo00<07gooOol057oo00<3h7oo
Ool0@Goo0@000Goo0Goo00000goo001oo`26Ool00`?POomoo`0?Ool00`?POomoo`0COol00`0OOomo
o`09Ool=01l00`0001l0000501l<Ool00`0OOomoo`0DOol00`?POomoo`11Ool10001Ool1Ool00003
Ool007oo08Moo`030n1oogoo00ioo`030n1oogoo01=oo`0301moogoo00Uoo`h07`0300007`0O00@0
7`aoo`0301moogoo01Aoo`030n1oogoo045oo`40005oo`5oo`0000=oo`00Ool0R7oo00<3h7ooOol0
3Goo00<3h7ooOol057oo00<07gooOol027oo3`0O00<0000O01l00`0O2goo00<07gooOol057oo00<3
h7ooOol0@Woo0@000Goo0Goo00000goo001oo`29Ool00`?POomoo`0<Ool00`?POomoo`0DOol00`0O
Oomoo`09Ool?01l0100001l07`0O37oo00<07gooOol057oo00<3h7ooOol0@Woo0@000Goo0Goo0000
0goo001oo`2:Ool00`?POomoo`0;Ool00`?POomoo`0EOol00`0OOomoo`08Ool@01l00`0001l07`0;
Ool00`0OOomoo`0EOol00`?POomoo`12Ool10001Ool1Ool00003Ool007oo08]oo`030n1oogoo00]o
o`030n1oogoo01Aoo`0301moogoo00Uoo`l07`0300007goo00]oo`0301moogoo01Eoo`030n1oogoo
049oo`40005oo`5oo`0000=oo`00Ool0S7oo00<3h7ooOol02Woo00<3h7ooOol057oo00<07gooOol0
2Woo3`0O00<007ooOol02Woo00<07gooOol05Goo00<3h7ooOol0@Woo0@000Goo0Goo00000goo001o
o`2=Ool00`?POomoo`09Ool00`?POomoo`0DOol00`0OOomoo`0;Ool=01l2Ool00`00Oomoo`08Ool0
0`0OOomoo`0EOol00`?POomoo`13Ool10001Ool1Ool00003Ool007oo08ioo`030n1oogoo00Qoo`03
0n1oogoo01Eoo`807`eoo`T07`Eoo`04001oogoo0006Ool00`0OOomoo`0EOol00`?POomoo`13Ool1
0001Ool1Ool00003Ool007oo08moo`83h0Qoo`030n1oogoo01Ioo`0301moogoo00ioo`<07`Uoo`03
001oo`0000Eoo`0301moogoo01Ioo`030n1oogoo04=oo`40005oo`5oo`0000=oo`00Ool0TGoo00<3
h7ooOol01Woo00<3h7ooOol05Woo00<07gooOol06Woo0P0017oo0P0067oo00<3h7ooOol0@goo0@00
0Goo0Goo00000goo001oo`2BOol00`?POomoo`05Ool00`?POomoo`0FOol00`0OOomoo`0HOol01@00
Ool007oo00000goo00<07`00Ool05Woo00<3h7ooOol0A7oo0@000Goo0Goo00000goo001oo`2COol0
0`?POomoo`04Ool00`?POomoo`0GOol00`0OOomoo`0HOol40002Ool00`0OOol0000GOol00`?POomo
o`14Ool10001Ool1Ool00003Ool007oo09Aoo`030n1oogoo00=oo`030n1oogoo01Qoo`0301moogoo
01Uoo`800006Ool07goo001oo`005Goo00<3h7ooOol0AGoo0@000Goo0Goo00000goo001oo`2EOol0
0`?POomoo`03Ool00`?POomoo`0HOol00`0OOomoo`0JOol01@0OOomoo`00Ool00P0057oo00<3h7oo
Ool0AGoo0@000Goo0Goo00000goo001oo`2FOol00`?POomoo`02Ool00`?POomoo`0IOol201lIOol0
0`0OOomoo`0HOol00`?POomoo`16Ool10001Ool1Ool00003Ool007oo09Moo`030n1oogoo009oo`03
0n1oogoo01Yoo`0301moogoo01Eoo`0301moogoo01Uoo`030n1oogoo04Ioo`40005oo`5oo`0000=o
o`00Ool0V7oo00D3h7ooOomoo`?P01eoo`<07a9oo`807aAoo`03001oogoo00Aoo`030n1oogoo04Mo
o`40005oo`5oo`0000=oo`00Ool0VGoo00D3h7ooOomoo`?P01moo`807`aoo`@07aMoo`8000Aoo`03
0n1oogoo04Moo`40005oo`5oo`0000=oo`00Ool0VWoo00@3h7ooOol3h25oo``07`UooaH00003Ool3
h7oo04Uoo`40005oo`5oo`0000=oo`00Ool0NWooFP?o00<000?o0ol040?o0P00A@?o27oo0@000Goo
0Goo00000goo001oo`1jOomJ0ol00`000ol3o`0>0ol200170ol8Ool10001Ool1Ool00003Ool007oo
07YooeX3o`030003o`?o00<00143o`8000030ol000?o03h3o`Qoo`40005oo`5oo`0000=oo`00Ool0
NWooFP?o00<000?o0ol00P?o00<000?o0ol04@?o00<000?o0ol0?P?o27oo0@000Goo0Goo00000goo
001oo`1jOomJ0ol00`000ol3o`020ol00`000ol3o`0@0ol00`000ol0000o0ol8Ool10001Ool1Ool0
0003Ool007oo07YooeX3o`030003o`?o008005D3o`Qoo`40005oo`5oo`0000=oo`00Ool0NWooFP?o
00<000?o0ol00`00E0?o27oo0@000Goo0Goo00000goo001oo`1jOomJ0ol00`000ol3o`1G0ol8Ool1
0001Ool1Ool00003Ool007oo07YooeX3o`030003o`?o05L3o`Qoo`40005oo`5oo`0000=oo`00Ool0
NWooFP?o00<000?o0ol0E`?o27oo0@000Goo0Goo00000goo001oo`1jOomJ0ol00`000ol3o`1G0ol8
Ool10001Ool1Ool00003Ool007oo07YooeX3o`030003o`?o05L3o`Qoo`40005oo`5oo`0000=oo`00
Ool0NWooFP?o00<000?o0ol0E`?o27oo0@000Goo0Goo00000goo001oo`1jOomJ0ol00`000ol3o`1G
0ol8Ool10001Ool1Ool00003Ool007oo07YooeX3o`030003o`?o05L3o`Qoo`40005oo`5oo`0000=o
o`00Ool0NWooFP?o00<000?o0ol0E`?o27oo0@000Goo0Goo00000goo001oo`1jOomH0ol00`000ol0
00020ol00`000ol3o`1D0ol8Ool10001Ool1Ool00003Ool007oo07YooeP3o`050003o`000ol0001G
0ol8Ool10001Ool1Ool00003Ool007oo07YooeT3o`<005P3o`Qoo`40005oo`5oo`0000=oo`00Ool0
NWooF@?o0`00F0?o27oo0@000Goo0Goo00000goo001oo`1jOomJ0ol00`000ol3o`1G0ol8Ool10001
Ool1Ool00003Ool007oo07Yooed3o`8005D3o`Qoo`40005oo`5oo`0000=oo`00Ool0NWooGP?o00<0
00?o0ol0D`?o27oo0@000Goo0Goo00000goo001oo`1jOomN0ol00`000ol3o`1C0ol8Ool10001Ool1
Ool00003Ool007oo07Yooed3o`030003o`0005@3o`Qoo`40005oo`5oo`0000=oo`00Ool0NWooG@?o
00@000?o000005<3o`Qoo`40005oo`5oo`0000=oo`00Ool0NWoo]0?o27oo0@000Goo0Goo00000goo
001oo`1jOond0ol8Ool10001Ool1Ool00003Ool007oo07Yook@3o`Qoo`40005oo`5oo`0000=oo`00
Ool0NWoo]0?o27oo0@000Goo0Goo00000goo001oo`3oOolgOol10001Ool1Ool00003Ool007oo0?mo
ocMoo`40005oo`5oo`0000=oo`00Ool0ogoo=goo0@000Goo0Goo00000goo0000003o000h0002Ool0
0001\
\>"],
  ImageRangeCache->{{{0, 315}, {166, 0}} -> {-2.60406, -3.28334, 0.0666662, 
  0.0666662}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Gear Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The 3D gear constraints provided by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cover six elementary cases of a gear-drive relationship. In each case the \
gear constraints simply enforce a nominal rotational relationship between two \
bodies. The interactions of individual teeth on the gears is not modeled.\n\n\
Each of the gear constraints must be passed an additional symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " that is used by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to keep track of the relative rotations of the gears. These symbols can \
be arbitrarily chosen, as long as all symbols in all gear constraints in a \
single model are unique. The values of these symbols are calculated by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time and included in the solution rules. Essentially, each new \
symbol is another dependent variable to be solved for, just like the \
coordinates of each body.\n\nThe numerical values of the added symbols \
correspond to the rotation of the first of the two gears in each pair, \
relative to the mutual orientation of the pair of gears in space."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ParallelGears5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["axis2, rad2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a gear set. The axes of the two gears ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " are constrained to be parallel and ",
  StyleBox["rad1 + rad2",
    FontSlant->"Italic"],
  " units apart, and the origins of the two axes are constrained to be \
adjacent. The rotational positions of the gears are related as per their \
respective radii. The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the gears, is given by the formula ",
  
  StyleBox["C = rad1 e1 + rad2 e2",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["ParallelGears4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["axis2, rad2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is identical to ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " except that the origins of the two axes are not constrained to be \
adjacent. Thus, the two gears are free to slide on their axes, relative to \
each other. \n\n",
  StyleBox["TwoPulleys5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, rad2, dist, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pair of pulleys and a belt. The axes of the two pulleys, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", are constrained to be parallel and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the origins of these two axes are constrained to be \
adjacent. The rotational positions of the two pulleys are related as per \
their respective radii. The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the pulleys, is given by the formula \
",
  StyleBox["C = rad1 e1 - rad2 e2",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["TwoPulleys4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, rad2, dist, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is identical to ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " except that the origins of the two axes are not constrained to be \
adjacent. \n \nIn each of these constraints, ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined by the following: \nPlace the two gears in any valid \
position. Construct a vector ",
  StyleBox["v",
    FontSlant->"Italic"],
  " from the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis2. e1",
    FontSlant->"Italic"],
  " is the angle measured in radians from ",
  StyleBox["v",
    FontSlant->"Italic"],
  " to the reference direction of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", as projected on a plane that is normal to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is the angle measured from ",
  StyleBox["v",
    FontSlant->"Italic"],
  " to the reference direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", as projected on a plane that is normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Two gear constraints."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Each gear constraint requires an initial orientation constant to set the \
initial relative rotations of the two gears. In most simple gear trains the \
gears are initially aligned so the orientation constant can be zero. \n\nThe \
only significant differences between ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are that the separation distance of the two gears can be set \
independently from the gear radii with ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and that the direction of relative rotation of the two gears is reversed. \
The direction of rotation constrained by ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be reversed by negating one of the two pulley radii."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RackAndPinion5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha,",
    FontSlant->"Italic"],
  " ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["axis2,",
    FontSlant->"Italic"],
  " ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a rack and pinion gear set. ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " represents the rotational axis of the pinion, and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " represents the rack. ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is parallel to the cut of the teeth of the rack, and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and its reference direction lie in the plane of the rack. The axis of the \
pinion is constrained to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units away from, and parallel to, the axis of the rack, and the origins \
of the two axes are constrained to be adjacent. The rotational orientation of \
the pinion is related to that of the rack as per the pinion radius.\n\n",
  StyleBox["RackAndPinion4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum,",
    FontSlant->"Italic"],
  " ",
  StyleBox["axis1,",
    FontSlant->"Italic"],
  " ",
  StyleBox["rad,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha,",
    FontSlant->"Italic"],
  " ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2,",
    FontSlant->"Italic"],
  " ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is identical to ",
  StyleBox["RackAndPinion5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " except that the origins of the axes are not constrained to be adjacent. \n\
\nThe constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is the distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", measured in the direction of the rack (the reference direction of ",
  StyleBox["axis2)",
    FontSlant->"Italic"],
  " when the reference direction of the pinion is parallel to the reference \
direction of the rack. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A special gear constraint."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["OrthogonalGears5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum,",
    FontSlant->"Italic"],
  " ",
  StyleBox["axis1,",
    FontSlant->"Italic"],
  " ",
  StyleBox["teeth1,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha,",
    FontSlant->"Italic"],
  " ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["axis2,",
    FontSlant->"Italic"],
  " ",
  StyleBox["teeth2,",
    FontSlant->"Italic"],
  " ",
  StyleBox["dist,",
    FontSlant->"Italic"],
  " ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pair of gears on orthogonal axes, such as a worm gear or bevel \
gear set. The axes of the two gears, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", are constrained to be orthogonal and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the origins of the two axes are constrained to be \
adjacent. The rotational positions of the worm and gear are related as per \
their respective tooth counts ",
  StyleBox["teeth1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["teeth2. ",
    FontSlant->"Italic"],
  "If ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " is omitted it defaults to zero. \n\nThe constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the two gears, is given by the \
formula\n",
  StyleBox["C = teeth1 e1 + teeth2 e2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined by the following:\nPlace the two gears in any valid \
position. ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " is the projected angle, in radians, measured from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to the reference direction of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", as projected on a plane that is normal to ",
  StyleBox["axis1.",
    FontSlant->"Italic"],
  " ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is the angle measured from ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to the reference direction of ",
  StyleBox["axis2.",
    FontSlant->"Italic"],
  " "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Another special gear constraint."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "As with ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the direction of relative rotation specified by ",
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be reversed by negating ",
  StyleBox["teeth1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["teeth2.",
    FontSlant->"Italic"],
  " "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LeadScrew5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum,",
    FontSlant->"Italic"],
  " ",
  StyleBox["axis1,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", axis2, ",
  StyleBox["pitch,",
    FontSlant->"Italic"],
  " ",
  StyleBox["C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a lead screw. ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to be parallel and coincident with ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the axial translation of the two axes is controlled per the pitch \
and relative rotation of the two screws. The relative angular orientation of \
the two screws is determined by the angle between the reference directions of \
",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2.",
    FontSlant->"Italic"],
  " \n\nThe symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " tracks the rotation of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", relative to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is the distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", measured in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", when the relative rotation between the two parts of the screw is zero. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A screw constraint."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ConstantVelocity4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, ratio, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a constant velocity joint. The origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to be coincident with the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the relative spin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is constrained to be equal to ",
  StyleBox["ratio",
    FontSlant->"Italic"],
  " times the spin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ". The relative spin of the axes is determined by the angle between the \
reference directions of each axis, and the cross product of the two axes. If \
",
  StyleBox["ratio",
    FontSlant->"Italic"],
  " is omitted it defaults to 1. \n\nThe symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " tracks the relative spin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ". The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is relative spin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " when the spin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is zero. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A constant velocity joint."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The following ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models a pair of gears with pitch radii of 4.0 and 6.0 \
respectively, and axis origins at local {0, 0, 0} on each body. The \
rotational axis of each gear is in its local ",
  StyleBox["z",
    FontSlant->"Italic"],
  " direction, and the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " direction on each gear is used as its reference direction. Setting the \
initial position constant to zero causes the reference directions of the two \
gears, the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axes, and the vector from the center of ",
  StyleBox["gear1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the center of ",
  StyleBox["gear2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to be simultaneously parallel."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a gear constraint example. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gear1 = 2; \)\), 
    \(\(gear2 = 3; \)\), 
    \(ParallelGears5[1, \n\tAxis[gear1, 0, {0, 0, 1}, {1, 0, 0}], 
      4.0, {rotsym, 0}, Axis[gear2, 0, {0, 0, 1}, {1, 0, 0}], 6.0, 0]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["ParallelGears5", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Example 3D Gear Mechanism "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " gear constraints a 3D model is developed that uses a pair of orthogonal \
bevel gears, a pair of parallel spur gears, and a rack and pinion gear set. \
The input to the model is the specified rotation of the first bevel gear, the \
drive bevel. This, in turn, rotates the driven bevel gear, which is the same \
body as the drive spur gear. The drive spur rotates the driven spur, which is \
the same body as the pinion. The rotation of the pinion causes the rack to \
translate. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the 3D gear-drive mechanism."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.1378  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.0599557 1.12604 0.028151 1.12604 [ 
[ 0 0 0 0 ] 
[ 1 1.1378 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 1.1378 L 
0 1.1378 L 
closepath 
clip 
newpath 
p 
.002 w 
.19567 .26701 m 
.06969 .14894 L 
s 
.06969 .14894 m 
.02815 1.06275 L 
s 
.02815 1.06275 m 
.16883 1.10965 L 
s 
.16883 1.10965 m 
.19567 .26701 L 
s 
.93133 .16592 m 
.97185 1.06954 L 
s 
.97185 1.06954 m 
.90403 1.01401 L 
s 
.90403 1.01401 m 
.86601 .02815 L 
s 
.86601 .02815 m 
.93133 .16592 L 
s 
.19567 .26701 m 
.06969 .14894 L 
s 
.06969 .14894 m 
.86601 .02815 L 
s 
.86601 .02815 m 
.93133 .16592 L 
s 
.93133 .16592 m 
.19567 .26701 L 
s 
.16883 1.10965 m 
.97185 1.06954 L 
s 
.97185 1.06954 m 
.90403 1.01401 L 
s 
.90403 1.01401 m 
.02815 1.06275 L 
s 
.02815 1.06275 m 
.16883 1.10965 L 
s 
P 
p 
.002 w 
.32657 .2793 m .26299 .32934 L .21965 .3975 L p 
.631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.40156 .25453 m .32657 .2793 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.4774 .25904 m .40156 .25453 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.54292 .29294 m .4774 .25904 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.58783 .35202 m .54292 .29294 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.6044 .42779 m .58783 .35202 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.26054 .39927 m .29004 .35277 L .26299 .32934 L p 
.336 .114 .422 r 
F P 
s 
P 
p 
.002 w 
.26299 .32934 m .21965 .3975 L .26054 .39927 L p 
.336 .114 .422 r 
F P 
s 
P 
p 
.002 w 
.32657 .2793 m .26299 .32934 L .29004 .35277 L p 
.393 .107 .355 r 
F P 
s 
P 
p 
.002 w 
.58919 .50849 m .6044 .42779 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.54411 .58096 m .58919 .50849 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.4764 .63318 m .54411 .58096 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.39733 .65672 m .4764 .63318 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.31983 .6483 m .39733 .65672 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.24923 .45151 m .26054 .39927 L .21965 .3975 L p 
.341 .19 .526 r 
F P 
s 
P 
p 
.002 w 
.25605 .61008 m .31983 .6483 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.21527 .54883 m .25605 .61008 L p 
.21965 .3975 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.21965 .3975 m .20278 .47429 L .21527 .54883 L p 
.631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.21965 .3975 m .20278 .47429 L .24923 .45151 L p 
.341 .19 .526 r 
F P 
s 
P 
p 
.002 w 
.29004 .35277 m .33342 .3187 L .32657 .2793 L p 
.393 .107 .355 r 
F P 
s 
P 
p 
.002 w 
.40156 .25453 m .32657 .2793 L .33342 .3187 L p 
.494 .171 .348 r 
F P 
s 
P 
p 
.002 w 
.24002 .37915 m .2473 .41502 L .20004 .42063 L p 
.417 .419 .754 r 
F P 
s 
P 
p 
.002 w 
.20004 .42063 m .18912 .3679 L .24002 .37915 L p 
.417 .419 .754 r 
F P 
s 
P 
p 
.002 w 
.20278 .47429 m .20004 .42063 L .2473 .41502 L p 
.405 .324 .651 r 
F P 
s 
P 
p 
.002 w 
.20004 .42063 m .18912 .3679 L .1714 .32325 L p 
.979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.20278 .47429 m .20004 .42063 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.25799 .50193 m .24923 .45151 L .20278 .47429 L p 
.394 .3 .63 r 
F P 
s 
P 
p 
.002 w 
.20278 .47429 m .21527 .54883 L .25799 .50193 L p 
.394 .3 .63 r 
F P 
s 
P 
p 
.002 w 
.33342 .3187 m .38446 .30201 L .40156 .25453 L p 
.494 .171 .348 r 
F P 
s 
P 
p 
.002 w 
.4774 .25904 m .40156 .25453 L .38446 .30201 L p 
.601 .277 .393 r 
F P 
s 
P 
p 
.002 w 
.2473 .41502 m .24923 .45151 L .20278 .47429 L p 
.405 .324 .651 r 
F P 
s 
P 
p 
.002 w 
.19692 .52165 m .20278 .47429 L .24923 .45151 L p 
.324 .158 .495 r 
F P 
s 
P 
p 
.002 w 
.19692 .52165 m .20278 .47429 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.22836 .34898 m .24002 .37915 L .18912 .3679 L p 
.363 .48 .844 r 
F P 
s 
P 
p 
.002 w 
.18912 .3679 m .1714 .32325 L .22836 .34898 L p 
.363 .48 .844 r 
F P 
s 
P 
p 
.002 w 
.24923 .45151 m .24551 .48352 L .19692 .52165 L p 
.324 .158 .495 r 
F P 
s 
P 
p 
.002 w 
.18307 .55602 m .19692 .52165 L .24551 .48352 L p 
.072 0 .154 r 
F P 
s 
P 
p 
.002 w 
.18307 .55602 m .19692 .52165 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.28588 .54298 m .25799 .50193 L .21527 .54883 L p 
.47 .409 .707 r 
F P 
s 
P 
p 
.002 w 
.21527 .54883 m .25605 .61008 L .28588 .54298 L p 
.47 .409 .707 r 
F P 
s 
P 
p 
.002 w 
.38446 .30201 m .43579 .30537 L .4774 .25904 L p 
.601 .277 .393 r 
F P 
s 
P 
p 
.002 w 
.54292 .29294 m .4774 .25904 L .43579 .30537 L p 
.685 .387 .463 r 
F P 
s 
P 
p 
.002 w 
.21393 .32896 m .22836 .34898 L .1714 .32325 L p 
.156 .478 .897 r 
F P 
s 
P 
p 
.002 w 
.1714 .32325 m .14915 .29319 L .21393 .32896 L p 
.156 .478 .897 r 
F P 
s 
P 
p 
.002 w 
.1629 .57196 m .18307 .55602 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.13917 .56619 m .1629 .57196 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.11545 .53853 m .13917 .56619 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.09566 .49259 m .11545 .53853 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.0833 .4356 m .09566 .49259 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.08058 .37724 m .0833 .4356 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.08792 .32747 m .08058 .37724 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.10384 .29441 m .08792 .32747 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.12544 .28271 m .10384 .29441 L p 
.1714 .32325 L .979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.1714 .32325 m .14915 .29319 L .12544 .28271 L p 
.979 .767 .548 r 
F P 
s 
P 
p 
.002 w 
.33342 .3187 m .29004 .35277 L .26054 .39927 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.38446 .30201 m .33342 .3187 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.43579 .30537 m .38446 .30201 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.47977 .32863 m .43579 .30537 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.50953 .36868 m .47977 .32863 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.52016 .41966 m .50953 .36868 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.5096 .47368 m .52016 .41966 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.4793 .52214 m .5096 .47368 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.43404 .55722 m .4793 .52214 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.38114 .57335 m .43404 .55722 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.32906 .56821 m .38114 .57335 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.28588 .54298 m .32906 .56821 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.25799 .50193 m .28588 .54298 L p 
.26054 .39927 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.26054 .39927 m .24923 .45151 L .25799 .50193 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.2473 .41502 m .24002 .37915 L .22836 .34898 L p 
.984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.24923 .45151 m .2473 .41502 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.26325 .38365 m .28595 .34789 L .3129 .37323 L p 
.909 .872 .789 r 
F P 
s 
P 
p 
.002 w 
.3129 .37323 m .2907 .40828 L .26325 .38365 L p 
.909 .872 .789 r 
F P 
s 
P 
p 
.002 w 
.34561 .34758 m .3129 .37323 L .28595 .34789 L p 
.816 .878 .891 r 
F P 
s 
P 
p 
.002 w 
.34561 .34758 m .3129 .37323 L .2907 .40828 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.32906 .56821 m .28588 .54298 L .25605 .61008 L p 
.547 .496 .751 r 
F P 
s 
P 
p 
.002 w 
.25605 .61008 m .31983 .6483 L .32906 .56821 L p 
.547 .496 .751 r 
F P 
s 
P 
p 
.002 w 
.43579 .30537 m .47977 .32863 L .54292 .29294 L p 
.685 .387 .463 r 
F P 
s 
P 
p 
.002 w 
.58783 .35202 m .54292 .29294 L .47977 .32863 L p 
.737 .478 .538 r 
F P 
s 
P 
p 
.002 w 
.24551 .48352 m .24923 .45151 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.25458 .42374 m .26325 .38365 L .2907 .40828 L p 
.971 .823 .638 r 
F P 
s 
P 
p 
.002 w 
.2907 .40828 m .28229 .44763 L .25458 .42374 L p 
.971 .823 .638 r 
F P 
s 
P 
p 
.002 w 
.38406 .33512 m .34561 .34758 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.42262 .3378 m .38406 .33512 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.45553 .35542 m .42262 .3378 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.47768 .38556 m .45553 .35542 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.48546 .42374 m .47768 .38556 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.47747 .46408 m .48546 .42374 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.45482 .50024 m .47747 .46408 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.42106 .52645 m .45482 .50024 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.38156 .5386 m .42106 .52645 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.34257 .53492 m .38156 .5386 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.31012 .51619 m .34257 .53492 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.28903 .48549 m .31012 .51619 L p 
.2907 .40828 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.2907 .40828 m .28229 .44763 L .28903 .48549 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.28595 .34789 m .3193 .32168 L .34561 .34758 L p 
.816 .878 .891 r 
F P 
s 
P 
p 
.002 w 
.38406 .33512 m .34561 .34758 L .3193 .32168 L p 
.678 .845 .963 r 
F P 
s 
P 
p 
.002 w 
.24551 .48352 m .23659 .5064 L .18307 .55602 L p 
.072 0 .154 r 
F P 
s 
P 
p 
.002 w 
.1629 .57196 m .18307 .55602 L .23659 .5064 L p 
.545 .873 .6 r 
F P 
s 
P 
p 
.002 w 
.26132 .46228 m .25458 .42374 L .28229 .44763 L p 
.979 .686 .376 r 
F P 
s 
P 
p 
.002 w 
.28229 .44763 m .28903 .48549 L .26132 .46228 L p 
.979 .686 .376 r 
F P 
s 
P 
p 
.002 w 
.3193 .32168 m .35848 .30887 L .38406 .33512 L p 
.678 .845 .963 r 
F P 
s 
P 
p 
.002 w 
.42262 .3378 m .38406 .33512 L .35848 .30887 L p 
.44 .735 .99 r 
F P 
s 
P 
p 
.002 w 
.23659 .5064 m .24551 .48352 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.19877 .32235 m .21393 .32896 L .14915 .29319 L p 
.415 0 0 r 
F P 
s 
P 
p 
.002 w 
.14915 .29319 m .12544 .28271 L .19877 .32235 L p 
.415 0 0 r 
F P 
s 
P 
p 
.002 w 
.2827 .49349 m .26132 .46228 L .28903 .48549 L p 
.788 .318 0 r 
F P 
s 
P 
p 
.002 w 
.28903 .48549 m .31012 .51619 L .2827 .49349 L p 
.788 .318 0 r 
F P 
s 
P 
p 
.002 w 
.35848 .30887 m .39773 .31148 L .42262 .3378 L p 
.44 .735 .99 r 
F P 
s 
P 
p 
.002 w 
.45553 .35542 m .42262 .3378 L .39773 .31148 L p 
0 .42 .851 r 
F P 
s 
P 
p 
.002 w 
.22363 .51656 m .23659 .5064 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.20848 .51206 m .22363 .51656 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.19341 .49312 m .20848 .51206 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.18087 .46236 m .19341 .49312 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.17296 .42458 m .18087 .46236 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.17103 .38596 m .17296 .42458 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.17538 .35288 m .17103 .38596 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.18518 .33059 m .17538 .35288 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.19877 .32235 m .18518 .33059 L p 
.22836 .34898 L .984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.22836 .34898 m .21393 .32896 L .19877 .32235 L p 
.984 .77 .535 r 
F P 
s 
P 
p 
.002 w 
.38114 .57335 m .32906 .56821 L .31983 .6483 L p 
.614 .558 .768 r 
F P 
s 
P 
p 
.002 w 
.31983 .6483 m .39733 .65672 L .38114 .57335 L p 
.614 .558 .768 r 
F P 
s 
P 
p 
.002 w 
.47977 .32863 m .50953 .36868 L .58783 .35202 L p 
.737 .478 .538 r 
F P 
s 
P 
p 
.002 w 
.6044 .42779 m .58783 .35202 L .50953 .36868 L p 
.759 .545 .607 r 
F P 
s 
P 
p 
.002 w 
.31569 .5125 m .2827 .49349 L .31012 .51619 L p 
0 .32 .755 r 
F P 
s 
P 
p 
.002 w 
.31012 .51619 m .34257 .53492 L .31569 .5125 L p 
0 .32 .755 r 
F P 
s 
P 
p 
.002 w 
.39773 .31148 m .43119 .32933 L .45553 .35542 L p 
0 .42 .851 r 
F P 
s 
P 
p 
.002 w 
.47768 .38556 m .45553 .35542 L .43119 .32933 L p 
.674 .203 0 r 
F P 
s 
P 
p 
.002 w 
.23659 .5064 m .22363 .51656 L .1629 .57196 L p 
.545 .873 .6 r 
F P 
s 
P 
p 
.002 w 
.13917 .56619 m .1629 .57196 L .22363 .51656 L p 
.812 .959 .908 r 
F P 
s 
P 
p 
.002 w 
.35538 .51615 m .31569 .5125 L .34257 .53492 L p 
.368 .725 .988 r 
F P 
s 
P 
p 
.002 w 
.34257 .53492 m .38156 .5386 L .35538 .51615 L p 
.368 .725 .988 r 
F P 
s 
P 
p 
.002 w 
.43119 .32933 m .45367 .35996 L .47768 .38556 L p 
.674 .203 0 r 
F P 
s 
P 
p 
.002 w 
.48546 .42374 m .47768 .38556 L .45367 .35996 L p 
.972 .665 .291 r 
F P 
s 
P 
p 
.002 w 
.3193 .32168 m .28595 .34789 L .26325 .38365 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43404 .55722 m .38114 .57335 L .39733 .65672 L p 
.67 .596 .763 r 
F P 
s 
P 
p 
.002 w 
.39733 .65672 m .45085 .64079 L p 
.43404 .55722 L .67 .596 .763 r 
F P 
s 
P 
p 
.002 w 
.44992 .5857 m .43404 .55722 L p 
.45085 .64079 L .67 .596 .763 r 
F P 
s 
P 
p 
.002 w 
.4793 .52214 m .45106 .54403 L p 
.4764 .63318 L .713 .613 .743 r 
F P 
s 
P 
p 
.002 w 
.45106 .54403 m .43404 .55722 L .44992 .5857 L p 
.713 .613 .743 r 
F P 
s 
P 
p 
.002 w 
.44992 .5857 m .4764 .63318 L p 
.45106 .54403 L .713 .613 .743 r 
F P 
s 
P 
p 
.4519 .51335 m .44937 .55255 L .44878 .51787 L .986 .838 .613 r 
F 
P 
p 
.002 w 
.4593 .50261 m .45106 .54403 L p 
.4519 .51335 L .986 .838 .613 r 
F P 
s 
P 
p 
.002 w 
.45106 .54403 m .44937 .55255 L p 
.4519 .51335 L .986 .838 .613 r 
F P 
s 
P 
p 
.002 w 
.44301 .58449 m .41785 .56276 L p 
.44878 .51787 L .986 .838 .613 r 
F P 
s 
P 
p 
.002 w 
.44937 .55255 m .44301 .58449 L p 
.44878 .51787 L .986 .838 .613 r 
F P 
s 
P 
p 
.002 w 
.45085 .64079 m .4764 .63318 L .44992 .5857 L p 
.67 .596 .763 r 
F P 
s 
P 
p 
.002 w 
.50953 .36868 m .5199 .41841 L p 
.56182 .40126 L .759 .545 .607 r 
F P 
s 
P 
p 
.002 w 
.57233 .37764 m .5199 .41841 L p 
.48095 .40548 L .817 .901 .9 r 
F P 
s 
P 
p 
.002 w 
.5199 .41841 m .50457 .43032 L .50071 .42626 L p 
.817 .901 .9 r 
F P 
s 
P 
p 
.002 w 
.50071 .42626 m .48095 .40548 L p 
.5199 .41841 L .817 .901 .9 r 
F P 
s 
P 
p 
.002 w 
.52016 .41966 m .6044 .42779 L p 
.56182 .40126 L .759 .545 .607 r 
F P 
s 
P 
p 
.002 w 
.5199 .41841 m .52016 .41966 L p 
.56182 .40126 L .759 .545 .607 r 
F P 
s 
P 
p 
.002 w 
.58919 .50849 m .6044 .42779 L .52016 .41966 L p 
.76 .588 .664 r 
F P 
s 
P 
p 
.002 w 
.35848 .30887 m .3193 .32168 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.39773 .31148 m .35848 .30887 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43119 .32933 m .39773 .31148 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.45367 .35996 m .43119 .32933 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.4615 .39882 m .45367 .35996 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.45326 .43996 m .4615 .39882 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.4301 .47686 m .45326 .43996 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.39564 .50366 m .4301 .47686 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.35538 .51615 m .39564 .50366 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.31569 .5125 m .35538 .51615 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.2827 .49349 m .31569 .5125 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.26132 .46228 m .2827 .49349 L p 
.26325 .38365 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.26325 .38365 m .25458 .42374 L .26132 .46228 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.18518 .33059 m .19877 .32235 L .12544 .28271 L p 
.732 .271 .157 r 
F P 
s 
P 
p 
.002 w 
.12544 .28271 m .10384 .29441 L .18518 .33059 L p 
.732 .271 .157 r 
F P 
s 
P 
p 
.002 w 
.39564 .50366 m .35538 .51615 L .38156 .5386 L p 
.658 .864 .978 r 
F P 
s 
P 
p 
.002 w 
.38156 .5386 m .42106 .52645 L .39564 .50366 L p 
.658 .864 .978 r 
F P 
s 
P 
p 
.002 w 
.45367 .35996 m .4615 .39882 L .48546 .42374 L p 
.972 .665 .291 r 
F P 
s 
P 
p 
.002 w 
.47747 .46408 m .48546 .42374 L .4615 .39882 L p 
.986 .839 .612 r 
F P 
s 
P 
p 
.002 w 
.22363 .51656 m .20848 .51206 L .13917 .56619 L p 
.812 .959 .908 r 
F P 
s 
P 
p 
.002 w 
.4615 .39882 m .45326 .43996 L .47747 .46408 L p 
.986 .839 .612 r 
F P 
s 
P 
p 
.002 w 
.45482 .50024 m .47747 .46408 L .45326 .43996 L p 
.921 .897 .787 r 
F P 
s 
P 
p 
.002 w 
.45326 .43996 m .4301 .47686 L .45482 .50024 L p 
.921 .897 .787 r 
F P 
s 
P 
p 
.002 w 
.43465 .47926 m .48095 .40548 L .50457 .43032 L p 
.921 .898 .787 r 
F P 
s 
P 
p 
.002 w 
.50457 .43032 m .4593 .50261 L .43465 .47926 L p 
.921 .898 .787 r 
F P 
s 
P 
p 
.002 w 
.52016 .41966 m .5096 .47368 L .58919 .50849 L p 
.76 .588 .664 r 
F P 
s 
P 
p 
.002 w 
.57233 .37764 m .50457 .43032 L .4593 .50261 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.4764 .63318 m .54411 .58096 L .4793 .52214 L p 
.713 .613 .743 r 
F P 
s 
P 
p 
.002 w 
.54411 .58096 m .58919 .50849 L .5096 .47368 L p 
.744 .61 .71 r 
F P 
s 
P 
p 
.002 w 
.4301 .47686 m .39564 .50366 L .42106 .52645 L p 
.818 .904 .901 r 
F P 
s 
P 
p 
.002 w 
.42106 .52645 m .45482 .50024 L .4301 .47686 L p 
.818 .904 .901 r 
F P 
s 
P 
p 
.002 w 
.48095 .40548 m .55012 .35161 L .57233 .37764 L p 
.817 .901 .9 r 
F P 
s 
P 
p 
.002 w 
.65323 .35209 m .57233 .37764 L .55012 .35161 L p 
.669 .855 .971 r 
F P 
s 
P 
p 
.002 w 
.65323 .35209 m .57233 .37764 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.41785 .56276 m .43465 .47926 L .4593 .50261 L p 
.986 .838 .613 r 
F P 
s 
P 
p 
.002 w 
.5096 .47368 m .4793 .52214 L .54411 .58096 L p 
.744 .61 .71 r 
F P 
s 
P 
p 
.002 w 
.73594 .35782 m .65323 .35209 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.80834 .39487 m .73594 .35782 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.85906 .45867 m .80834 .39487 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.87939 .54007 m .85906 .45867 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.86513 .62642 m .87939 .54007 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.81798 .70357 m .86513 .62642 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.74552 .75865 m .81798 .70357 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.65987 .78275 m .74552 .75865 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.57514 .77256 m .65987 .78275 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.50462 .73065 m .57514 .77256 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.45858 .66445 m .50462 .73065 L p 
.4593 .50261 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.4593 .50261 m .44301 .58449 L .45858 .66445 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.11545 .53853 m .13917 .56619 L .20848 .51206 L p 
.803 .828 .87 r 
F P 
s 
P 
p 
.002 w 
.55012 .35161 m .63262 .32533 L .65323 .35209 L p 
.669 .855 .971 r 
F P 
s 
P 
p 
.002 w 
.73594 .35782 m .65323 .35209 L .63262 .32533 L p 
.441 .735 .989 r 
F P 
s 
P 
p 
.002 w 
.43351 .64425 m .41785 .56276 L .44301 .58449 L p 
.977 .674 .324 r 
F P 
s 
P 
p 
.002 w 
.44301 .58449 m .45858 .66445 L .43351 .64425 L p 
.977 .674 .324 r 
F P 
s 
P 
p 
.002 w 
.20848 .51206 m .19341 .49312 L .11545 .53853 L p 
.803 .828 .87 r 
F P 
s 
P 
p 
.004 w 
.20389 .666 m 
.20848 .51206 L 
s 
P 
p 
.004 w 
.20848 .51206 m 
.21123 .41966 L 
s 
P 
p 
.004 w 
.20389 .666 m 
.21582 .62299 L 
s 
P 
p 
.002 w 
.17538 .35288 m .18518 .33059 L .10384 .29441 L p 
.76 .445 .453 r 
F P 
s 
P 
p 
.002 w 
.10384 .29441 m .08792 .32747 L .17538 .35288 L p 
.76 .445 .453 r 
F P 
s 
P 
p 
.004 w 
.28915 .34751 m 
.34807 .40305 L 
s 
P 
p 
.004 w 
.34412 .65256 m 
.34641 .50845 L 
s 
P 
p 
.004 w 
.34641 .50845 m 
.34807 .40305 L 
s 
P 
p 
.004 w 
.18138 .61817 m 
.20389 .666 L 
s 
P 
p 
.002 w 
.63262 .32533 m .71693 .33092 L .73594 .35782 L p 
.441 .735 .989 r 
F P 
s 
P 
p 
.002 w 
.80834 .39487 m .73594 .35782 L .71693 .33092 L p 
.063 .465 .886 r 
F P 
s 
P 
p 
.002 w 
.48026 .71167 m .43351 .64425 L .45858 .66445 L p 
.772 .299 0 r 
F P 
s 
P 
p 
.002 w 
.45858 .66445 m .50462 .73065 L .48026 .71167 L p 
.772 .299 0 r 
F P 
s 
P 
p 
.002 w 
.19341 .49312 m .18087 .46236 L .09566 .49259 L p 
.781 .731 .806 r 
F P 
s 
P 
p 
.002 w 
.09566 .49259 m .11545 .53853 L .19341 .49312 L p 
.781 .731 .806 r 
F P 
s 
P 
p 
.002 w 
.55012 .35161 m .48095 .40548 L .43465 .47926 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.22952 .61331 m 
.20389 .666 L 
s 
P 
p 
.002 w 
.17103 .38596 m .17538 .35288 L .08792 .32747 L p 
.759 .533 .59 r 
F P 
s 
P 
p 
.002 w 
.63262 .32533 m .55012 .35161 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.71693 .33092 m .63262 .32533 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.71693 .33092 m .7907 .36847 L .80834 .39487 L p 
.063 .465 .886 r 
F P 
s 
P 
p 
.002 w 
.7907 .36847 m .71693 .33092 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.85906 .45867 m .80834 .39487 L .7907 .36847 L p 
0 0 .504 r 
F P 
s 
P 
p 
.002 w 
.7907 .36847 m .84235 .43337 L .85906 .45867 L p 
0 0 .504 r 
F P 
s 
P 
p 
.002 w 
.84235 .43337 m .7907 .36847 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.40416 .37188 m 
.45329 .39028 L 
s 
P 
p 
.004 w 
.34807 .40305 m 
.45329 .39028 L 
s 
P 
p 
.004 w 
.45329 .39028 m 
.48661 .38624 L 
s 
P 
p 
.004 w 
.48661 .38624 m 
.59715 .37282 L 
s 
P 
p 
.004 w 
.41476 .40445 m 
.45329 .39028 L 
s 
P 
p 
.004 w 
.21123 .41966 m 
.45329 .39028 L 
s 
P 
p 
.004 w 
.40366 .42079 m 
.45329 .39028 L 
s 
P 
p 
.002 w 
.86296 .51636 m .84235 .43337 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.84826 .6045 m .86296 .51636 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.79999 .68336 m .84826 .6045 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.72593 .73975 m .79999 .68336 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.63848 .76453 m .72593 .73975 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.55206 .75429 m .63848 .76453 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.48026 .71167 m .55206 .75429 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43351 .64425 m .48026 .71167 L p 
.43465 .47926 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43465 .47926 m .41785 .56276 L .43351 .64425 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.20389 .666 m 
.19481 .60839 L 
s 
P 
p 
.004 w 
.39482 .38726 m 
.45329 .39028 L 
s 
P 
p 
.004 w 
.34412 .65256 m 
.35445 .6091 L 
s 
P 
p 
.004 w 
.55634 .38741 m 
.59715 .37282 L 
s 
P 
p 
.002 w 
.18087 .46236 m .17296 .42458 L .0833 .4356 L p 
.767 .659 .744 r 
F P 
s 
P 
p 
.002 w 
.0833 .4356 m .09566 .49259 L .18087 .46236 L p 
.767 .659 .744 r 
F P 
s 
P 
p 
.002 w 
.08792 .32747 m .08058 .37724 L .17103 .38596 L p 
.759 .533 .59 r 
F P 
s 
P 
p 
.002 w 
.17296 .42458 m .17103 .38596 L .08058 .37724 L p 
.76 .597 .676 r 
F P 
s 
P 
p 
.004 w 
.17103 .38596 m 
.21123 .41966 L 
s 
P 
p 
.002 w 
.55206 .75429 m .48026 .71167 L .50462 .73065 L p 
0 .272 .702 r 
F P 
s 
P 
p 
.002 w 
.50462 .73065 m .57514 .77256 L .55206 .75429 L p 
0 .272 .702 r 
F P 
s 
P 
p 
.002 w 
.89082 .84162 m .8879 .76453 L .44171 .80019 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.44171 .80019 m .44127 .87418 L .89082 .84162 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.57514 .77256 m .65987 .78275 L .63848 .76453 L p 
.269 .696 .966 r 
F P 
s 
P 
p 
.002 w 
.72593 .73975 m .63848 .76453 L .65987 .78275 L p 
.604 .888 .99 r 
F P 
s 
P 
p 
.002 w 
.65987 .78275 m .74552 .75865 L .72593 .73975 L p 
.604 .888 .99 r 
F P 
s 
P 
p 
.002 w 
.8879 .76453 m .44171 .80019 L .41597 .78275 L p 
.457 .814 .997 r 
F P 
s 
P 
p 
.002 w 
.41532 .85826 m .41597 .78275 L .44171 .80019 L p 
.995 .775 .489 r 
F P 
s 
P 
p 
.002 w 
.44171 .80019 m .44127 .87418 L .41532 .85826 L p 
.995 .775 .489 r 
F P 
s 
P 
p 
.002 w 
.08058 .37724 m .0833 .4356 L .17296 .42458 L p 
.76 .597 .676 r 
F P 
s 
P 
p 
.004 w 
.14685 .3657 m 
.17103 .38596 L 
s 
P 
p 
.004 w 
.32022 .60414 m 
.34412 .65256 L 
s 
P 
p 
.004 w 
.54622 .35429 m 
.59715 .37282 L 
s 
P 
p 
.002 w 
.87415 .8242 m .41532 .85826 L .44127 .87418 L p 
.429 .809 .991 r 
F P 
s 
P 
p 
.002 w 
.44127 .87418 m .89082 .84162 L .87415 .8242 L p 
.429 .809 .991 r 
F P 
s 
P 
p 
.004 w 
.36977 .59913 m 
.34412 .65256 L 
s 
P 
p 
.004 w 
.54644 .40382 m 
.59715 .37282 L 
s 
P 
p 
.004 w 
.34412 .65256 m 
.33526 .59408 L 
s 
P 
p 
.004 w 
.5382 .36972 m 
.59715 .37282 L 
s 
P 
p 
.002 w 
.87939 .54007 m .85906 .45867 L .84235 .43337 L p 
.896 .578 .083 r 
F P 
s 
P 
p 
.002 w 
.63848 .76453 m .55206 .75429 L .57514 .77256 L p 
.269 .696 .966 r 
F P 
s 
P 
p 
.002 w 
.84235 .43337 m .86296 .51636 L .87939 .54007 L p 
.896 .578 .083 r 
F P 
s 
P 
p 
.002 w 
.86513 .62642 m .87939 .54007 L .86296 .51636 L p 
.995 .855 .517 r 
F P 
s 
P 
p 
.002 w 
.79999 .68336 m .72593 .73975 L .74552 .75865 L p 
.807 .956 .912 r 
F P 
s 
P 
p 
.002 w 
.74552 .75865 m .81798 .70357 L .79999 .68336 L p 
.807 .956 .912 r 
F P 
s 
P 
p 
.002 w 
.41597 .78275 m .87128 .74546 L .8879 .76453 L p 
.457 .814 .997 r 
F P 
s 
P 
p 
.002 w 
.87415 .8242 m .87128 .74546 L .41597 .78275 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.41597 .78275 m .41532 .85826 L .87415 .8242 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.86296 .51636 m .84826 .6045 L .86513 .62642 L p 
.995 .855 .517 r 
F P 
s 
P 
p 
.002 w 
.81798 .70357 m .86513 .62642 L .84826 .6045 L p 
.936 .951 .765 r 
F P 
s 
P 
p 
.004 w 
.58029 .48043 m 
.62827 .53228 L 
s 
P 
p 
.004 w 
.63113 .75827 m 
.63162 .79694 L 
s 
P 
p 
.004 w 
.62827 .53228 m 
.63113 .75827 L 
s 
P 
p 
.004 w 
.85731 .50821 m 
.89651 .50409 L 
s 
P 
p 
.004 w 
.62827 .53228 m 
.85731 .50821 L 
s 
P 
p 
.002 w 
.84826 .6045 m .79999 .68336 L .81798 .70357 L p 
.936 .951 .765 r 
F P 
s 
P 
p 
.004 w 
.86155 .51433 m 
.89651 .50409 L 
s 
P 
p 
.004 w 
.85005 .5177 m 
.86155 .51433 L 
s 
P 
p 
.004 w 
.63162 .79694 m 
.63665 .76297 L 
s 
P 
p 
.004 w 
.63665 .76297 m 
.63831 .75179 L 
s 
P 
p 
.002 w 
.89082 .84162 m .8879 .76453 L .87128 .74546 L p 
.975 .748 .326 r 
F P 
s 
P 
p 
.004 w 
.84082 .48365 m 
.89651 .50409 L 
s 
P 
p 
.004 w 
.61207 .75984 m 
.63162 .79694 L 
s 
P 
p 
.004 w 
.60432 .74512 m 
.61207 .75984 L 
s 
P 
p 
.002 w 
.87128 .74546 m .87415 .8242 L .89082 .84162 L p 
.975 .748 .326 r 
F P 
s 
P 
p 
.004 w 
.58214 .71653 m 
.63113 .75827 L 
s 
P 
p 
.004 w 
.63211 .8359 m 
.63463 1.03529 L 
s 
P 
p 
.004 w 
.63113 .75827 m 
.63211 .8359 L 
s 
P 
p 
.004 w 
.86557 .7389 m 
.90572 .73558 L 
s 
P 
p 
.004 w 
.69308 .75315 m 
.86557 .7389 L 
s 
P 
p 
.004 w 
.63113 .75827 m 
.69308 .75315 L 
s 
P 
p 
.004 w 
.84262 .53618 m 
.89651 .50409 L 
s 
P 
p 
.004 w 
.63162 .79694 m 
.65026 .75669 L 
s 
P 
p 
.004 w 
.65026 .75669 m 
.65769 .74063 L 
s 
P 
p 
.004 w 
.89651 .50409 m 
.83559 .50119 L 
s 
P 
p 
.004 w 
.62554 .75351 m 
.63162 .79694 L 
s 
P 
p 
.004 w 
.62311 .73609 m 
.62554 .75351 L 
s 
P 
p 
.004 w 
.63463 1.03529 m 
.64177 .98361 L 
s 
P 
p 
.004 w 
.86987 .74383 m 
.90572 .73558 L 
s 
P 
p 
.004 w 
.85807 .74654 m 
.86987 .74383 L 
s 
P 
p 
.004 w 
.60667 .98033 m 
.63463 1.03529 L 
s 
P 
p 
.004 w 
.84867 .71279 m 
.90572 .73558 L 
s 
P 
p 
.004 w 
.6613 .97702 m 
.63463 1.03529 L 
s 
P 
p 
.004 w 
.85055 .7678 m 
.90572 .73558 L 
s 
P 
p 
.004 w 
.63463 1.03529 m 
.62593 .97367 L 
s 
P 
p 
.004 w 
.90572 .73558 m 
.84339 .73325 L 
s 
P 
p 
.002 w 
.93133 .16592 m 
.97185 1.06954 L 
s 
.97185 1.06954 m 
.90403 1.01401 L 
s 
.90403 1.01401 m 
.86601 .02815 L 
s 
.86601 .02815 m 
.93133 .16592 L 
s 
.16883 1.10965 m 
.97185 1.06954 L 
s 
.97185 1.06954 m 
.90403 1.01401 L 
s 
.90403 1.01401 m 
.02815 1.06275 L 
s 
.02815 1.06275 m 
.16883 1.10965 L 
s 
P 
p 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .45329 .39028 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .20389 .666 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .10053 .32687 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(2)] .21123 .41966 1.3 1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .59715 .37282 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .34412 .65256 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .24671 .3075 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(3)] .34807 .40305 1.3 1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .89651 .50409 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .63162 .79694 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .54559 .44293 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(4)] .62827 .53228 1.3 1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .90572 .73558 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .63463 1.03529 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .54664 .68629 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(5)] .63113 .75827 1.3 1.3 Mshowa 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{253, 288},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003m000181000`40O003h00OoGoo003mOol00?eo
o`00oGoo003mOol00?eoo`00oGoo003mOol00=Moo`@0029oo`00d7oo1`000goo00<007ooOol087oo
003:Ool6000:Ool2000QOol00<=oo`L0011oo`80025oo`00_7oo1`005goo00<007oo000087oo002f
Ool6000NOol00`00Ool0000POol00:moo`L002Aoo`04001oogoo000OOol00:Qoo`L002]oo`04001o
ogoo000OOol00:9oo`H0039oo`05001oogooOol0000NOol009]oo`L003Qoo`05001oogooOol0000N
Ool009Aoo`L003moo`03001oogoo009oo`03001oogoo01]oo`00SGoo1`00AWoo00<007ooOol00Woo
00<007ooOol06goo0027Ool6001=Ool00`00Oomoo`03Ool00`00Oomoo`0JOol0081oo`L005=oo`03
001oogoo00=oo`03001oogoo01Yoo`00NGoo1`00Fgoo00<007ooOol00goo00<007ooOol06Goo001c
Ool6001ROol00`00Oomoo`03Ool00`00Oomoo`0IOol006aoo`L006Qoo`03001oogoo00Aoo`03001o
ogoo01Qoo`00IGoo1`00Kgoo00<007ooOol017oo00<007ooOol067oo001OOol6001fOol00`00Oomo
o`04Ool00`00Oomoo`0HOol005Qoo`L007aoo`03001oogoo00Eoo`03001oogoo01Moo`00DGoo1`00
Pgoo00<007ooOol01Goo00<007ooOol05goo001:Ool7002:Ool00`00Oomoo`06Ool00`00Oomoo`0F
Ool004Aoo`H0095oo`03001oogoo00Ioo`03001oogoo01Ioo`00?Goo1`00Ugoo00<007ooOol01goo
00<007ooOol05Goo000fOol7002NOol00`00Oomoo`07Ool00`00Oomoo`0EOol0031oo`H00:Eoo`03
001oogoo00Qoo`03001oogoo01Aoo`00:Goo1`00Zgoo00<007ooOol027oo00<007ooOol057oo000R
Ool7002bOol00`00Oomoo`09Ool00`00Oomoo`0COol001aoo`H00;Uoo`03001oogoo00Uoo`03001o
ogoo01=oo`005Goo1`00_goo00<007ooOol02Woo00<007ooOol04Woo000AOol40036Ool00`00Oomo
o`0:Ool00`00Oomoo`0BOol0015oo`800<Qoo`03001oogoo00]oo`03001oogoo015oo`004Goo00<0
07oo0000agoo00<007ooOol02goo00<007ooOol04Goo000AOol01000Oomoo`00aWoo00<007ooOol0
37oo00<007ooOol047oo000AOol01@00Oomoogoo0000aGoo00<007ooOol02Goo10004Woo000AOol0
0`00Oomoo`02Ool00`00Oomoo`32Ool00`00Oomoo`02Ool70003Ool00`00Oomoo`0@Ool0015oo`03
001oogoo00=oo`03001oogoo0;moo`L000Yoo`03001oogoo011oo`004Goo00<007ooOol017oo00<0
07ooOol0]goo1`000Woo00<007ooOol037oo00<007ooOol047oo000AOol00`00Oomoo`05Ool2002_
Ool80009Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool0015oo`03001oogoo00Moo`03001oogoo0:Eo
o`L0015oo`03001oogoo00aoo`03001oogoo011oo`004Goo00<007ooOol027oo00<007ooOol0WGoo
1`0067oo00<007ooOol037oo00<007ooOol047oo000AOol00`00Oomoo`09Ool00`00Oomoo`2EOol7
000OOol00`00Oomoo`0<Ool00`00Oomoo`0@Ool0011oo`03001oogoo00]oo`03001oogoo08eoo`L0
02Moo`03001oogoo00]oo`03001oogoo011oo`0047oo00<007ooOol037oo00<007ooOol0QGoo1`00
;Woo00<007ooOol02goo00<007ooOol047oo000@Ool00`00Oomoo`0=Ool00`00Oomoo`1mOol7000e
Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool0011oo`03001oogoo00ioo`03001oogoo07Eoo`L003ao
o`03001oogoo00]oo`03001oogoo011oo`0047oo00<007ooOol03goo00<007ooOol0KGoo1`00@goo
00<007ooOol037oo00<007ooOol03goo000@Ool00`00Oomoo`0@Ool00`00Oomoo`1TOol8001:Ool0
0`00Oomoo`0<Ool00`00Oomoo`0?Ool0011oo`03001oogoo015oo`03001oogoo05aoo`L0059oo`03
001oogoo00aoo`03001oogoo00moo`0047oo00<007ooOol04Woo00<007ooOol0E7oo1`00FGoo00<0
07ooOol037oo00<007ooOol03goo000@Ool00`00Oomoo`0COol00`00Oomoo`1<Ool7001POol00`00
Oomoo`0<Ool00`00Oomoo`0?Ool0011oo`03001oogoo01Aoo`03001oogoo04Aoo`L006Moo`03001o
ogoo00aoo`03001oogoo00moo`0047oo00<007ooOol05Goo00<007ooOol0?7oo1`00KWoo00<007oo
Ool037oo00<007ooOol03goo000@Ool00`00Oomoo`0FOol2000eOol7001eOol00`00Oomoo`0<Ool0
0`00Oomoo`0?Ool0011oo`03001oogoo01Qoo`03001oogoo02]oo`L007aoo`03001oogoo00aoo`03
001oogoo00moo`0047oo00<007ooOol06Goo00<007ooOol08goo1`00Pgoo00<007ooOol037oo00<0
07ooOol03goo000@Ool00`00Oomoo`0JOol00`00Oomoo`0JOol8002:Ool00`00Oomoo`0<Ool00`00
Oomoo`0?Ool0011oo`03001oogoo01]oo`03001oogoo019oo`L001Yoo`/006eoo`03001oogoo00ao
o`03001oogoo00moo`0047oo00<007ooOol077oo00<007ooOol02Woo1`007Woo0`0000<lZ`00C@`0
24d<2P00Hgoo00<007ooOol037oo00<007ooOol03goo000@Ool00`00Oomoo`0MOol00`00Oomoo`02
Ool7000ROol30003?:/00`00C@a=300@C@`01000EHh00000HGoo00<007ooOol037oo00<007ooOol0
3goo000@Ool00`00Oomoo`0NOol4000UOol40006?:/00`00C@a=300?C@`00`00EHiESP02EHh2001O
Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool0011oo`03001oogoo01ioo`03001oogoo02=oo`<000Tl
Z`03001=34d<00m=3003001ESUF>00EESP8005eoo`03001oogoo00aoo`03001oogoo00moo`0047oo
00<007ooOol07Woo00<007ooOol087oo0`0033b[00<004d<C@`03Td<00<005F>EHh025F>0P00Fgoo
00<007ooOol037oo00<007ooOol03goo000@Ool00`00Oomoo`0NOol00`00Oomoo`0NOol2000>?:/0
0`00C@a=300>C@`00`00EHiESP0;EHh2001IOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool0011oo`03
001oogoo00aoo`03001oogoo00moo`03001oogoo01eoo`8000llZ`03001=34d<00e=3003001ESUF>
00iESP8005Moo`03001oogoo00aoo`03001oogoo00moo`003goo00<007ooOol02goo0P000Ud500<0
07ooOol03Goo00<007ooOol06goo0P0000<`J`00?:/03Sb[00<004d<C@`03Dd<00<005F>EHh045F>
0P00EGoo00<007ooOol037oo00<007ooOol03goo000?Ool00`00Oomoo`09Ool20005G@D2000=Ool0
0`00Oomoo`0JOol00`00<6/`J`02<6/00`00?:/lZ`0;?:/00`00C@a=300=C@`00`00EHiESP0CEHh2
001COol00`00Oomoo`0<Ool00`00Oomoo`0?Ool000moo`03001oogoo00Qoo`8000QM1@8000]oo`03
001oogoo01Uoo`03000`Jc1[00<`J`03000lZcb[00/lZ`03001=34d<00a=3003001ESUF>01=ESP80
0003GO4007oo055oo`03001oogoo00aoo`03001oogoo00moo`003goo00<007ooOol01goo00<0067>
HLh00P0025d50P002Goo00<007ooOol067oo00<0031[<6/0131[00<003b[?:/02Sb[00<004d<C@`0
34d<00<005F>EHh04UF>0P0015ga00<007ooOol0Cgoo00<007ooOol037oo00<007ooOol03goo000?
Ool00`00Oomoo`07Ool00`00HLiQcP02HLh20008G@D20007Ool00`00Oomoo`0GOol00`00<6/`J`05
<6/00`00?:/lZ`09?:/80007C@`00`00EHiESP0AEHh20006GO400`00Oomoo`1@Ool00`00Oomoo`0<
Ool00`00Oomoo`0>Ool000moo`03001oogoo00Ioo`03001QcV7>00EQcP8000QM1@8000Eoo`03001o
ogoo01Eoo`8000P`J`03000lZcb[00<lZ`H000QAe0P0019ESP03001MlEga00MMl@03001oogoo04mo
o`03001oogoo00aoo`03001oogoo00ioo`003goo00<007ooOol01Woo00<0067>HLh01f7>0P0025d5
0P000goo00<007ooOol057oo00<0031[<6/02C1[00<003b[?:/00P001U7D1P002U7D0P003UF>0P00
2ega00<007ooOol0CWoo00<007ooOol037oo00<007ooOol03Woo000?Ool00`00Oomoo`05Ool00`00
HLiQcP0:HLh30007G@D200000goo001oo`0DOol00`00<6/`J`0:<6/3000>DM@2000:DM@2000:EHh2
000>GO400`00Oomoo`1=Ool00`00Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03001oogoo00Eoo`03
001QcV7>00eQcP8000MM1@8001Aoo`03000`Jc1[00T`J`8001=Ae003001Ae57D00UAe08000IESP80
015Ml@03001oogoo04aoo`03001oogoo00aoo`03001oogoo00ioo`003goo00<007ooOol017oo00<0
067>HLh0467>0P001ed500<007ooOol03goo0P002S1[0P005U7D0P002e7D0P000UF>0P004ega00<0
07ooOol0C7oo00<007ooOol037oo00<007ooOol03Woo000?Ool00`00Oomoo`04Ool2000CHLh20003
G@D200000glA0000000>Ool00`00<6/`J`09<6/00`00DMAAe00HDM@2000;DM@2000FGO400`00Oomo
o`0<Ool<000cOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03001oogoo00Aoo`03001R<P00
0080019QcP<000Eo4@03001oogoo00Moo`@000X`J`8001eAe003001Ae57D00YAe003001MlEga01AM
l@03001oogoo00Moo`@000aAe0`002Moo`03001oogoo00aoo`03001oogoo00ioo`003goo00<007oo
Ool017oo00<0068bHS800V8b0`00467>00<007lAOa401GlA00<007ooOol01goo1000231[00<0057D
DM@07U7D00<0057DDM@02E7D00<005gaGO405Ega00<007ooOol00goo0`00757D0P009Goo00<007oo
Ool037oo00<007ooOol03Woo000?Ool00`00Oomoo`04Ool00`00HS9R<P05HS83000<HLh00`00Oa5o
4@07Oa400`00Oomoo`05Ool00`00Ool00002:6d00`00<6/`J`04<6/00`00DMAAe00PDM@00`00DMAA
e009DM@00`00GO5Ml@0EGO45000QDM@2000SOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03
001oogoo00=oo`03001R<V8b00UR<P@000QQcP03001o4GlA00Mo4@03001oogoo00Eoo`@0008XK@80
008`J`8002AAe003001Ae57D00UAe003001MlEga019Ml@<002MAe080025oo`03001oogoo00aoo`03
001oogoo00ioo`003goo00<007ooOol00goo00<0068bHS803F8b0`001F7>00<007lAOa4027lA00<0
07ooOol017oo00<002Q]:6d01BQ]0P009U7D0P002e7D00<005gaGO403Ega1000;57D0P007goo00<0
07ooOol037oo00<007ooOol03Woo000?Ool00`00Oomoo`03Ool00`00HS9R<P03HS840009HS830000
0f7>001o4@0;Oa400`00Oomoo`03Ool00`00:6dXK@05:6d00`00DM@0000VDM@2000:DM@00`00GO5M
l@0;GO42000bDM@2000MOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03001oogoo00=oo`03
001R<V8b00AR<P03001R<P0000aR<P8000eo4@Aoo`03000XKBQ]00HXK@04001Ae57D000VDM@2000:
DM@00`00GO5Ml@09GO42000eDM@2000KOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03001o
ogoo00=oo`03001R<V8b00=R<P03001R<P0000iR<P03001o4GlA00]o4@04001oogoo0008:6d00`00
DMAAe002DM@00`00DMAAe00TDM@2000:DM@00`00GO5Ml@06GO420002DM@2000eDM@2000IOol00`00
Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03001oogoo00=oo`03001R<V8b00=R<P@000eR<P03001o
4GlA00]o4@04001oogoo0007:6d00`00DMAAe004DM@00`00DMAAe003DM@2000NDM@2000;DM@00`00
GO5Ml@04GO400`00DMAAe004DM@3000dDM@2000GOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool000mo
o`03001oogoo009oo`03001R<V8b00iR<P03001R<V8b00AR<P03001o4GlA00ao4@8000PXK@03001A
e57D00EAe003001Ae57D00AAe003001Ae57D01]Ae003001nZ@0000YAe004001MlEgaGO43000:DM@3
000cDM@2000EOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03001oogoo009oo`03001R<V8b
00mR<P03001R<V8b009R<P03001o4GlA00eo4@8000LXK@03001Ae57D00MAe003001Ae57D009Ae003
001Ae57D00mAe08000aAe003001nZ@0000YAe0<00004HS<0057DDM@80004DM@2000cDM@00`00Oomo
o`0BOol00`00Oomoo`0<Ool00`00Oomoo`0>Ool000moo`03001oogoo009oo`03001R<V8b011R<P05
001R<V8bHS80000@Oa400`00:6dXK@04:6d00`00DMAAe009DM@20003DM@00`00DMAAe00@DM@2000:
DM@01000OZT000002E7D00@0068cHS<000]Ae0P0039Ae003001oogoo015oo`03001oogoo00aoo`03
001oogoo00ioo`003Woo00<007ooOol00goo1P003V8b0P0000=R<P00Oa403glA00<002Q]:6d012Q]
3U7D0P0000=Ae000DM@04e7D0`001e7D00@007jYOZT000UAe0<000IAe0d003=Ae003001oogoo015o
o`03001oogoo00aoo`03001oogoo00ioo`003Woo00<007ooOol00goo00<0069eHWD00f9e3000168b
0P0017lA0`002GlA00<002Q]:6d00bQ]00<0057DDM@03E7D0P00657D0`00157D00D007jYOZUnZ@00
00MAe0X000EAe0H003IAe003001oogoo011oo`03001oogoo00aoo`03001oogoo00ioo`003Woo00<0
07ooOol00goo00<0069eHWD03f9e1P0017lA00<007lAOa402GlA00<002Q]:6d00bQ]00<0057DDM@0
3U7D00<0057DDM@03E7D2000157D0P000U7D00@007jYOZUnZ@T000aAe080009Ae08003UAe003001o
ogoo00moo`03001oogoo00aoo`03001oogoo00ioo`003Woo00<007ooOol00goo00<0069eHWD0569e
0P0017lA00<007lAOa402GlA00<002Q]:6d00RQ]00<0057DDM@03e7D00<0057DDM@0557D300000=n
Z@00DM@0157D00<0057DDM@03E7D0P00?57D00<007ooOol03Woo00<007ooOol037oo00<007ooOol0
3Woo000>Ool00`00Oomoo`03Ool00`00HWERM@0DHWD01000Oa4000000WlA00<007lAOa402GlA00D0
02Q]:6dXK@0001=Ae003001Ae57D00eAe0T00004DM@000000002DM@01@00OZUnZGjY0000157D00<0
057DDM@0357D0P002U7D00@0057DDM@0031Ae003001oogoo00ioo`03001oogoo00eoo`03001oogoo
00eoo`003Woo00<007ooOol00goo00<0069eHWD0569e00@007lAOa5o4@800003Oa4007lA00Uo4@D0
01AAe003001Ae57D00=Ae0T000MAe0@000AAe003001nZGjY009nZ@04001Ae000000=DM@2000=DM@2
000bDM@00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool000ioo`03001oogoo00=oo`03
001RMF9e01ARM@03001o4GlA009o4@8000ao4@<Xd003001Ae57D011Ae0T000eAe0800003DM@0057D
00EAe08000=nZ@8000iAe003001Ae57D00eAe08003=Ae003001oogoo00aoo`03001oogoo00eoo`03
001oogoo00eoo`003Woo00<007ooOol00goo00<0069eHWD0569e00<007lAOa400glA00<007lAOa40
2WlA00@002S@:=0000UAe0T000=Ae003001Ae57D00iAe0800003DM@0000000MAe003001oD`00009n
Z@03001Ae57D01aAe004001Ae57D000cDM@00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0=
Ool000ioo`03001oogoo00=oo`03001RMF9e01ARM@03001o4GlA00Ao4@8000Yo4@05000Xd000001A
e008000<DM@00`00DMAAe00@DM@00`00DMAAe006DM@01000Oe=oDgmC0P00EU7D00<007ooOol02goo
00<007ooOol03Goo00<007ooOol03Goo000>Ool00`00Oomoo`03Ool00`00HWERM@0DHWD00`00Oa5o
4@06Oa400`00Oa5o4@03Oa49000DDM@00`00DMAAe00>DM@20009DM@01P00Oe=oD`00Oe<005MAe003
001oogoo00]oo`03001oogoo00aoo`03001oogoo00eoo`003Woo00<007ooOol00goo00<0069eHWD0
569e00<007lAOa401glA1@0017lA00<002S@00005U7D00<0057DDM@0357D0P002e7D0`0000=oD`00
DM@0F57D00<007ooOol02Woo00<007ooOol037oo00<007ooOol03Goo000>Ool00`00Oomoo`03Ool0
0`00HWERM@0DHWD00`00Oa5o4@07Oa400`00Oa5o4@06Oa400`00:=00000FDM@00`00DMAAe00;DM@0
0`00DMAAe00;DM@4001KDM@00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool000ioo`03
001oogoo00=oo`03001RMF9e00mRM@H000Uo4@03001o4GlA00Io4@<001IAe003001Ae57D01UAe004
001oDgmC001KDM@00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool000ioo`03001oogoo
00=oo`03001RMF9e00=RM@`000ER]`03001o4GlA00Mo4@03001o4GlA00Io4@<001IAe003001Ae57D
01UAe003001oD`0005eAe003001oogoo00Qoo`03001oogoo00aoo`03001oogoo00eoo`003Woo00<0
07ooOol00goo1P004F:g00<007lAOa401glA00<007lAOa401WlA0`005U7D00<0057DDM@0657D00<0
07mC0000Ge7D00<007ooOol01goo00<007ooOol037oo00<007ooOol03Goo000>Ool00`00Oomoo`03
Ool00`00H[MR]`0EH[L00`00Oa5o4@06Oa400`00Oa5o4@06Oa43000FDM@00`00DMAAe00HDM@00`00
Oe<0001ODM@20008Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Aoo`03001R
]f:g01AR]`03001o4GlA00Io4@03001o4GlA00Io4@03001Ae00001IAe003001Ae57D01QAe080061A
e08000Qoo`03001oogoo00aoo`03001oogoo00eoo`003Woo00<007ooOol017oo00<006:gH[L056:g
00<007lAOa401WlA00<007lAOa401WlA00@0057DDM@001EAe003001Ae57D01MAe080069Ae08000Mo
o`03001oogoo00aoo`03001oogoo00eoo`003Woo00<007ooOol017oo00<006:gH[L056:g00<007lA
Oa401WlA00<007lAOa401WlA00@0057DDM@001EAe003001Ae57D01MAe080069Ae003001b@P0000Io
o`03001oogoo00aoo`03001oogoo00eoo`003Woo00<007ooOol017oo00<006:gH[L05F:g00<007lA
Oa401GlA00<007lAOa401WlA00@0057DDM@001EAe003001Ae57D01IAe08006=Ae003001b@P0000Io
o`03001oogoo00aoo`03001oogoo00eoo`003Woo00<007ooOol01Goo00<006:gH[L056:g00<007lA
Oa401GlA00<007lAOa401WlA00@0057DDM@001EAe003001Ae57D01EAe08006AAe004001b@W920005
Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Eoo`03001R]f:g01=R]`8000Mo
4@03001o4GlA00Io4@800003DM@0057D01AAe003001Ae57D01EAe08006EAe003001b@P0000Eoo`03
001oogoo00aoo`03001oogoo00eoo`003Woo00<007ooOol01Goo00<006:gH[L04F:g0P0000=Rn@00
Oa401GlA00<007lAOa401WlA00<0034d00000U7D00<0057DDM@04U7D00<0057DDM@0557D0P006e7D
1000Ae7D00<0079200001Goo00<007ooOol037oo00<007ooOol03Goo000=Ool00`00Oomoo`06Ool0
0`00H[MR]`0>H[L30004H_T00`00Oa5o4@03Oa400`00Oa5o4@06Oa400`00<C@00002DM@00`00DMAA
e00BDM@00`00DMAAe00CDM@2000MDM@00`00DM@00017DM@01000LT9b@P0017oo00<007ooOol037oo
00<007ooOol03Goo000=Ool00`00Oomoo`07Ool00`00H[MR]`0:H[L30007H_T00`00Oa5o4@03Oa40
0`00Oa5o4@06Oa400`00<C@00003DM@00`00DMAAe00ADM@00`00DMAAe00CDM@00`00DMAAe00KDM@0
0`00DM@00018DM@01000LT9b@P0017oo00<007ooOol037oo00<007ooOol03Goo000=Ool00`00Oomo
o`07Ool00`00H[MR]`08H[L2000:H_T00`00Oa5o4@03Oa400`00Oa5o4@06Oa401000<C@a=0000e7D
00<0057DDM@0457D00<0057DDM@04U7D0P007E7D1000B57D00<00792000017oo00<007ooOol037oo
00<007ooOol03Goo000=Ool00`00Oomoo`07Ool00`00H[MR]`05H[L3000=H_T00`00Oa5o4@02Oa40
0`00Oa5o4@06Oa401000<C@a=000157D00<0057DDM@03e7D00<0057DDM@04E7D00<006^L0000957D
00<0057DDM@0@U7D00<00792000017oo00<007ooOol03Goo00<007ooOol037oo000=Ool00`00Oomo
o`07Ool00`00H[MR]`02H[L3000@H_T00`00Oa5o4@02Oa400`00Oa5o4@06Oa401000<C@a=000157D
00<0057DDM@03e7D00<0057DDM@03e7D0P000V^L00<0057DDM@08e7D00<0057DDM@0?E7D0P000U7D
00@00792LT8000=oo`03001oogoo00eoo`03001oogoo00aoo`003Goo00<007ooOol027oo00@006:g
000001ARn@05001o4GlAOa400007Oa401@00<C@a=34d00001E7D00<0057DDM@03U7D00<0057DDM@0
3U7D00D006^LJia[W00002MAe003001Ae57D03iAe0<0009b@P05001oogooOol0000?Ool00`00Oomo
o`0<Ool000eoo`03001oogoo00Qoo`8001IRn@05001o4GlAOa400007Oa400`00<C@a=002<C@00`00
DMAAe003DM@00`00DMAAe00=DM@00`00DMAAe00=DM@00`00Jia[W002Ji`00`00DMAAe00VDM@00`00
DMAAe002DM@3000kDM@30003Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Qo
o`03001RnF;i01=Rn@800005Ie/007lAOa400007Oa400`00<C@a=002<C@00`00DMAAe004DM@2000=
DM@00`00DMAAe00;DM@20005Ji`00`00DMAAe00WDM@00`00DMAAe002DM@00`00DMAAe00jDM@00`00
LT80000200000goo001oo`0>Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Uoo`03001RnF;i011R
n@8000AWF`03001o4@0000Io4@03000a=34d00<a=003001Ae57D00EAe08000aAe003001Ae57D00YA
e003001[W6^L00E[W003001Ae57D02QAe003001Ae00000<003EAe0P00003LT8007oo00<000ioo`03
001oogoo00aoo`003Goo00<007ooOol02Goo00<006;iH_T03V;i0P001VMK00<007lA00001WlA00<0
034d<C@00S4d00<003ff00001e7D0`002U7D00<0057DDM@0257D0P0026^L00<0057DDM@0:E7D0P00
00=Ae000DM@0>e7D00<0079200001`0037oo00<007ooOol037oo000=Ool00`00Oomoo`0:Ool00`00
H_URn@0<H_T00`00Ie]WF`07Ie/20005Oa400`00<C@a=002<C@01000?KHm]P002E7D0`00257D00<0
057DDM@01E7D0`000UMo0P001F^L00<0057DDM@0:U7D00@0057D000003QAe0d000eoo`03001oogoo
00aoo`003Goo00<007ooOol02Woo00<006;iH_T02V;i0P002fMK0P000glA00<0034d<C@00S4d00<0
03ff?KH00Sff00<0057DDM@01e7D00<0005H000010000e7D00@0057DDMAAe0@000MGO`03001[W6^L
009[W003001Ae57D02]Ae003001Ae00002iAe0X000AAe0@00003Ool0000000moo`03001oogoo00ao
o`003Goo00<007ooOol02goo00<006;iH_T01f;i0P0036MK0P0000AWg@00000000@a=003000m]Sff
00@m]P03001Ae57D00MAe0040001F0000002;_l7000<Egl01@00Jia[W6^L0000;U7D00<0057DDM@0
8e7D2P00357D0P0000MAe000LT9b@P00Ool0000?Ool00`00Oomoo`0<Ool000eoo`03001oogoo00]o
o`03001RnF;i00IRn@03001WFfMK00YWF`800005Imd006OMImd00004<C@00`00?KHm]P05?KH00`00
DMAAe008DM@200000`5H000^o`03;_l00`00;_l^o`02000<Egl200000f^L001Ae00^DM@00`00DMAA
e00IDM@9000IDM@400000goo001oo`0>Ool00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`03001R
nF;i00=Rn@8000aWF`07001WgFOMImd006OM0000134d00<003ff?KH01cff00<0057DDM@02E7D0`00
0bko00<002ko;_l00Rko00<005MoEgl02UMo0`00<57D00<0057DDM@03U7D2P008U7D0P0000Eb@P00
Oomoo`0000=oo`04001oogoo0007Ool00`00Oomoo`0<Ool000eoo`03001oogoo00aoo`04001RnF;i
H_T2000=Ie/00`00ImeWg@02Imd20005<C@00`00?KHm]P08?KH00`00DMAAe00:DM@300000bko000^
o`04;_l00`00EgmGO`06Egl30002DM@00`00DMAAe00_DM@00`00DMAAe003DM@:000ZDM@20002Og02
0002Ool00`00Oomoo`02Ool20008Ool00`00Oomoo`0<Ool000eoo`03001oogoo00eoo`<000eWF`80
00EWg@8000@a=003000m]Sff00Xm]P03001Ae57D00]Ae0H000<^o`80009GO`@000AAe003001Ae57D
035Ae0D0039Ae0800003DM@007m`009oL0800003Ool007oo00=oo`8000Qoo`03001oogoo00aoo`00
3Goo00<007ooOol03Goo00<006MKIe/036MK00<006OMImd016OM0P0000Eoo`00<C@a=00000dm]P03
001Ae57D00eAe004001Ae57DDM@70008DM@00`00DMAAe00aDM@00`00DMAAe00cDM@01@00DMAAe57D
00000gm`0P0000=oo`00Ool00Woo00@007ooOol000Moo`03001oogoo00aoo`003Goo00<007ooOol0
3Woo00<006MKIe/02VMK00<006OMImd016OM00L007oo001oo`00<C@0000??KH00`00DMAAe00<DM@0
0`00DMAAe00@DM@00`00DMAAe00aDM@00`00DMAAe00gDM@00`00Og1oL002Og000`00Ool0000>Ool0
0`00Oomoo`0<Ool000eoo`03001oogoo00moo`03001WFfMK00MWF`8000EWg@80009oo`04001oo`00
000@?KH3000<DM@00`00DMAAe00@DM@00`00DMAAe00aDM@00`00DMAAe00gDM@00`00Og1oL002Og00
0`00Ool0000>Ool00`00Oomoo`0<Ool000eoo`03001oogoo011oo`03001WFfMK00EWF`03001WgFOM
00AWg@8000=oo`03001oo`00010m]P050015n4GhAOP0000;DM@00`00DMAAe00@DM@00`00DMAAe00a
DM@00`00DMAAe00gDM@00`00Og1oL002Og000`00Ool0000>Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo011oo`03001WFfMK00AWF`03001WgFOM00AWg@8000Aoo`04001oogoo000??KH00`00AOQ5n002
AOP00`00DMAAe008DM@00`00DMAAe00?DM@00`00DMAAe00bDM@00`00DMAAe00fDM@00`00Og1oL003
Og000`00Ool0000>Ool00`00Oomoo`0<Ool000eoo`03001oogoo015oo`04001WFfMKIe/20006Imd3
0004Ool01000Oomoo`003Sff00<004GhAOP014Gh0P00257D00<0057DDM@03e7D00<0057DDM@0<U7D
00<0057DDM@0=U7D00<007m`Og000Wm`00@007ooOol000ioo`03001oogoo00aoo`0037oo00<007oo
Ool04goo00<006MK00001fOM0P0000=oo`00Ool00goo00D007ooOomoo`0000dm]P030015n4Gh00I5
n003001Ae57D00EAe003001Ae57D00mAe003001Ae57D039Ae003001Ae57D03IAe003001oL7m`009o
L004001oogoo000>Ool00`00Oomoo`0<Ool000aoo`03001oogoo01Aoo`8000IWg@80009oo`03001o
ogoo009oo`03001oogoo009oo`03000m]Sff00Tm]P030015n4Gh00Q5n08000EAe003001Ae57D00]A
e0D003AAe003001Ae57D03IAe003001oL7m`009oL004001oogoo000>Ool00`00Oomoo`0<Ool000ao
o`03001oogoo01Ioo`<0009Wg@05001oogooOol00005Ool00`00Oomoo`02Ool00`00?KHm]P09?KH0
0`00AOQ5n00:AOP70009DM@30004EWP00`00DMAAe00bDM@00`00DMAAe00fDM@00`00Og1oL002Og00
1000Oomoo`003Woo00<007ooOol037oo000<Ool00`00Oomoo`0IOol20004Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00?KHm]P07?KH00`00AOQ5n00;AOP00`00CSQ>>002CSP00`00CSP000080008
EWP00`00DMAAe00aDM@00`00DMAAe00eDM@00`00Og1oL003Og001000Oomoo`003goo00<007ooOol0
2goo000<Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00?KHm]P06?KH00`00
AOQ5n00;AOP00`00CSQ>>002CSP00`00CSQ>>006CSP00`00EWQFN007EWP00`00DMAAe00aDM@00`00
DMAAe00eDM@00`00Og1oL003Og001000Oomoo`003goo00<007ooOol02goo000<Ool00`00Oomoo`0O
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00?KHm]P05?KH00`00AOQ5n00<AOP01@00CSQ>>4hh
00002Dhh00<005IhEWP01eIh00<0057DDM@0<E7D00<0057DDM@0=E7D00<007m`Og000gm`00@007oo
Ool000moo`03001oogoo00]oo`0037oo00<007ooOol07goo00<007ooOol00goo00<007ooOol01Goo
00<003ff?KH013ff00<004GhAOP034Gh00D004hhCSQ>>00000Y>>003001FN5Ih00IFN003001Ae57D
035Ae003001Ae57D03EAe003001oL7m`009oL005001oogooOol0000?Ool00`00Oomoo`0;Ool000ao
o`03001oogoo01moo`03001oogoo009oo`03001oogoo00Moo`03000m]Sff008m]P030015n4Gh00a5
n003001>>4hh009>>003001>>4hh00Q>>003001FN5Ih00IFN003001Ae57D035Ae003001Ae57D03EA
e003001oL7m`009oL005001oogooOol0000?Ool00`00Oomoo`0;Ool000aoo`03001oogoo01moo`03
001oogoo009oo`03001oogoo00Moo`03000m]Sff008m]P030015n4Gh00a5n006001>>4hh001>>000
2Thh00<005IhEWP01eIh00<0057DDM@0<57D00<0057DDM@0=E7D00<007m`Og000Wm`00D007ooOomo
o`0000moo`03001oogoo00]oo`0037oo00<007ooOol07goo00<007ooOol00Woo00<007ooOol027oo
00@003ff?KH000m5n006001>>4hh001>>0002Thh00<005IhEWP01eIh00<0057DDM@0<57D00<0057D
DM@0=57D00<007m`Og000gm`00D007ooOomoo`0000moo`03001oogoo00]oo`0037oo00<007ooOol0
7goo00<007ooOol00Woo00<007ooOol02Goo00<003ff00003dGh00H004hhCSP004hh0006CSP01@00
CSQ>>4hh00002EIh00<0057DDM@0<57D00<0057DDM@0=57D00<007m`Og000gm`00D007ooOomoo`00
00moo`03001oogoo00]oo`0037oo00<007ooOol07goo00<007ooOol00Woo00<007ooOol02Goo0P00
3dGh0P000Thh00<004hh00001Dhh00<004hhCSP00dhh00<005IhEWP01UIh00<0057DDM@0<57D00<0
057DDM@0=57D00<007m`Og000gm`00D007ooOomoo`0000moo`03001oogoo00]oo`0037oo00<007oo
Ool07goo00H007ooOol007oo000<Ool00`00AOQ5n00=AOP20003CSP20002CSP01000CSQ>>0001Dhh
00<005IhEWP01UIh00<0057DDM@0<57D00<0057DDM@0<e7D00<007OH000017m`00D007ooOomoo`00
00moo`03001oogoo00]oo`0037oo00<007ooOol07goo00H007ooOol007oo0005Ool00`00Oomoo`05
Ool2000>AOP01000CSQ>>4hh0P000Thh00<004hh00001Thh00<005IhEWP01UIh00<0057DDM@0<57D
00<0057DDM@0<e7D00@007OHMmP0009oL003001oogoo009oo`03001oogoo00eoo`03001oogoo00]o
o`0037oo00<007ooOol07Woo0P000Woo00<007oo00001Goo00<007ooOol01goo00<004GhAOP02dGh
00@004hhCSQ>>0800005CSP004hhCSP00006CSP00`00EWQFN007EWP00`00DMAAe00_DM@00`00DMAA
e00bDM@00`00MmQgf002MmP00`00Og000004Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03
001oogoo01ioo`80009oo`03001oo`0000Aoo`03001oogoo00Uoo`8000]5n080009>>0800004CSP0
04hh0007CSP00`00EWQFN007EWP00`00DMAAe00_DM@00`00DMAAe00bDM@00`00MmQgf003MmP20004
Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool000aoo`03001oogoo01moo`04001oogooOol20002Ool0
0`00Ool0000=Ool20009AOP20002CSP2000014hh001>>0001dhh00<005IhEWP01eIh00<0057DDM@0
;e7D00<0057DDM@0<E7D00<007OHMmP01GOH00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0
2goo000<Ool00`00Oomoo`0OOol01000Oomoogoo0P000Woo0P0047oo00<004GhAOP01DGh00D004hh
CSP004hh00800003CSP0000000U>>003001FN5Ih00IFN003001Ae57D02mAe003001Ae57D031Ae003
001gf7OH00Egf003001oogoo00=oo`03001oogoo00eoo`03001oogoo00]oo`0037oo00<007ooOol0
7goo0P000Woo0P0000Aoo`00Ool0015oo`8000E5n005001>>4hh001>>00300000dhh001>>008CSP0
0`00EWQFN006EWP00`00DMAAe00_DM@00`00DMAAe00`DM@00`00MmQgf005MmP00`00Oomoo`04Ool0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool000aoo`03001oogoo01moo`80009oo`800003Ool0000001Ao
o`030015n4Gh0095n004001>>4hhCSP5000:CSP00`00EWQFN007EWP00`00DMAAe00^DM@00`00DMAA
e00_DM@00`00MmQgf005MmP00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool000aoo`03
001oogoo01moo`04001oo`00Ool200000goo0000000EOol20002AOP01P00CSQ>>4hh001>>0<000Y>
>003001FN5Ih00MFN003001Ae57D02iAe003001Ae57D02mAe003001gf7OH00Egf003001oogoo00Eo
o`03001oogoo00aoo`03001oogoo00]oo`0037oo00<007ooOol07goo00@007oo001oo`@001Qoo`<0
00A>>0<000]>>003001FN5Ih00MFN003001Ae57D02iAe003001Ae57D02iAe003001gf7OH00Egf003
001oogoo00Ioo`03001oogoo00aoo`03001oogoo00]oo`0037oo00<007ooOol07goo00<007ooOol0
1@006Woo200034hh00<005IhEWP00UIh100000=oo`00DM@0;e7D00<0057DDM@0;57D00<007OHMmP0
1GOH00<007ooOol01goo00<007ooOol037oo00<007ooOol02goo000;Ool00`00Oomoo`0POol01@00
Oomoo`00Ool00P0087oo2P001Dhh00<005Ih00000`0017oo00<0057DDM@0;U7D00<0057DDM@0;57D
00<007OHMmP01GOH00<007ooOol01goo00<007ooOol037oo00<007ooOol02goo000;Ool00`00Oomo
o`0POol01000Oomoogoo0`00:Woo1`002Goo00<0057DDM@0;E7D00<0057DDM@0:e7D00<007OHMmP0
1GOH00<007ooOol027oo00<007ooOol037oo00<007ooOol02goo000;Ool00`00Oomoo`0POol01000
Oomoogoo0P00?7oo00<0057DDM@0;57D00<0057DDM@0:e7D00<007OHMmP01GOH00<007ooOol027oo
00<007ooOol037oo00<007ooOol02goo000;Ool00`00Oomoo`0POol00`00Oomoo`02Ool00`00Oomo
o`0kOol00`00DMAAe00[DM@00`00DMAAe00ZDM@00`00MmQgf005MmP00`00Oomoo`09Ool00`00Oomo
o`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo021oo`03001oogoo02Moo`8001Moo`03001Ae57D
02]Ae003001Ae57D02UAe003001gf7OH00Egf003001oogoo00Yoo`03001oogoo00eoo`03001oogoo
00Yoo`002goo00<007ooOol087oo00<007ooOol0:7oo00<007ooOol05Woo00<0057DDM@0:U7D00<0
057DDM@0:E7D00<007OHMmP01GOH00<007ooOol02Woo00<007ooOol03Goo00<007ooOol02Woo000;
Ool00`00Oomoo`0POol00`00Oomoo`0XOol00`00Oomoo`0GOol00`00DMAAe00YDM@00`00DMAAe00X
DM@00`00MmQgf005MmP00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001o
ogoo021oo`03001oogoo00Aoo`80025oo`03001oo`0001Qoo`03001Ae57D02UAe003001Ae57D02QA
e003001gf7OH00Egf003001oogoo00]oo`03001oogoo00eoo`03001oogoo00Yoo`002goo00<007oo
Ool087oo00<007ooOol01Goo00<007ooOol07goo00<007oo00006Goo00<0057DDM@0:57D00<0057D
DM@09e7D00<007OHMmP01GOH00<007ooOol037oo00<007ooOol03Goo00<007ooOol02Woo000;Ool0
0`00Oomoo`0OOol00`00Oomoo`06Ool00`00Oomoo`0NOol200000goo0000000IOol00`00DMAAe00W
DM@00`00DMAAe00UDM@200000fOM001gf004MmP00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00Oomo
o`0:Ool000]oo`03001oogoo01moo`03001oogoo00Eoo`03001oo`0003eoo`03001Ae57D02MAe003
001Ae57D02AAe003001WgFOM009Wg@03001gf7OH009gf003001oogoo00eoo`03001oogoo00eoo`03
001oogoo00Yoo`002goo00<007ooOol07goo00<007ooOol01Goo00<007oo0000?Woo00<0057DDM@0
9U7D00<0057DDM@08e7D00<006OMImd016OM00@007OHMmP0011oo`03001oogoo00eoo`03001oogoo
00Yoo`002goo00<007ooOol07goo00<007ooOol017oo0P0000=oo`000000?Woo00<0057DDM@09E7D
00<0057DDM@08E7D0P0026OM00<007OH000047oo00<007ooOol03Goo00<007ooOol02Woo000;Ool0
0`00Oomoo`0OOol00`00Oomoo`18Ool00`00DMAAe00TDM@00`00DMAAe00PDM@00`00ImeWg@09Imd0
0`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool000]oo`03001oogoo01moo`03001oogoo
04Qoo`03001Ae57D011Ae0@0011Ae003001Ae57D01mAe003001WgFOM00QWg@80019oo`03001oogoo
00eoo`03001oogoo00Yoo`002goo00<007ooOol07goo00<007ooOol0BGoo00<0057DDM@0457D00<0
057D0000457D00<0057DDM@07E7D0P002VOM00<007ooOol01goo0P002Goo00<007ooOol03Goo00<0
07ooOol02Woo000;Ool00`00Oomoo`0OOol00`00Oomoo`1:Ool2000?DM@00`00DM@00004DM@00`00
DMAAe00:DM@00`00DMAAe00LDM@00`00ImeWg@09Imd00`00Oomoo`0:Ool20007Ool00`00Oomoo`0=
Ool00`00Oomoo`0:Ool000]oo`03001oogoo01moo`03001oogoo04]oo`<000eAe0@000AAe003001A
e57D00EAe005001Ae57DDM@0000MDM@00`00ImeWg@08Imd2000?Ool30004Ool00`00Oomoo`0=Ool0
0`00Oomoo`0:Ool000]oo`03001oogoo01moo`03001oogoo04aoo`<001EAe003001Ae57D00=Ae003
001Ae000009Ae003001Ae57D01UAe08000YWg@03001oogoo019oo`80009oo`03001oogoo00eoo`03
001oogoo00Yoo`002goo00<007ooOol07goo00<007ooOol0CWoo0`00557D0P001E7D00@0057DDM@0
01YAe003001WgFOM00UWg@03001oogoo01Eoo`<000moo`03001oogoo00Yoo`002goo00<007ooOol0
7goo00<007ooOol0Cgoo00<0004F00005E7D00<0057DDM@00P000e7D00<0057DDM@05e7D00<006OM
Imd026OM0P003Woo200017oo0`003Goo00<007ooOol02Woo000;Ool00`00Oomoo`0OOol00`00Oomo
o`1@Ool4000DDM@00`00DM@00002DM@00`00DM@0000GDM@2000:Imd00`00Oomoo`0FOol9000;Ool0
0`00Oomoo`0:Ool000]oo`03001oogoo01moo`03001oogoo059oo`@001=Ae0D00003DM@0057D00AA
e003001Ae57D00eAe08000]Wg@03001oogoo00iooa4000aoo`03001oogoo00Yoo`002Woo00<007oo
Ool087oo00<007ooOol0E7oo00<0004F00004E7D00<0057D00000U7D00<0057D0000157D00<0057D
DM@02U7D10000TnO00<006OMImd01VOM0P000goo3P000goo20000Woo0P003Woo00<007ooOol02Woo
000:Ool00`00Oomoo`0POol00`00Oomoo`1EOol4000?DM@00`00DMAAe00300000e7D001Ae003DM@0
0`00DMAAe006DM@40005Cil?0005Ool<0002DM@20000157D000007oo0P0000=oo`00Ool03Goo00<0
07ooOol02Woo000:Ool00`00Oomoo`0POol00`00Oomoo`1GOol4000>DM@01P00DMAAe57D001Ae080
009Ae003001Ae57D00AAe0`000=?W`03001WgFOM009Wg@`0015Ae003001njP0000=oo`03001oogoo
00aoo`03001oogoo00Yoo`002Woo00<007ooOol087oo00<007ooOol0FGoo2000257D00@0057DDMAA
e0@0009Ae0P000Q?W``001aAe0<000=oo`03001oogoo00eoo`03001oogoo00Uoo`002Woo00<007oo
Ool087oo00<007ooOol0Fgoo0P0012;N2P000U7D00<0057D00001P000TnO2`009U7D0`000WkZ00@0
07ooOol000=oo`04001oogoo0008Ool00`00Oomoo`09Ool000Yoo`03001oogoo021oo`03001oogoo
05aoo`<000`RgPd002mAe080009Ae007001njWkZO^X007oo000017oo0P002Goo00<007ooOol02Goo
000:Ool00`00Oomoo`0POol00`00Oomoo`1NOol200000b;N000000090002DM@300000e7D001Ae00b
DM@00`00DMAAe002DM@01`00O^YnjWkZ001oo`0000Aoo`8000Uoo`03001oogoo00Uoo`002Woo00<0
07ooOol087oo00<007ooOol0EGoo30002e7D00<0057D00000`00>E7D00L007kZO^YnjP00Ool00003
Ool01000Oomoo`0027oo00<007ooOol02Goo000:Ool00`00Oomoo`0POol00`00Oomoo`1:Ool;000G
DM@00`00DM@00003000iDM@01`00O^YnjWkZ001oo`0000moo`03001oogoo00Uoo`002Woo00<007oo
Ool087oo00<007ooOol0?Woo30008e7D0`0000=Ae000DM@0>57D00L007kZO^YnjP00Ool0000?Ool0
0`00Oomoo`09Ool000Yoo`03001oogoo021oo`03001oogoo03Qoo`H002mAe0@003YAe007001njWkZ
O^X007oo00003goo00<007ooOol02Goo000:Ool00`00Oomoo`0POol00`00Oomoo`0hOol00`00DMAA
e00cDM@3000kDM@01P00O^YnjP00Ool000moo`03001oogoo00Uoo`002Woo00<007ooOol087oo00<0
07ooOol0>7oo00<0057DDM@0<e7D0P00?57D00H007kZO^X007oo000?Ool00`00Oomoo`09Ool000Yo
o`03001oogoo021oo`03001oogoo03Qoo`03001Ae57D03AAe003001Ae57D03YAe006001njWkZ001o
o`003goo00<007ooOol02Goo000:Ool00`00Oomoo`0POol00`00Oomoo`0hOol00`00DMAAe00dDM@0
0`00DMAAe00jDM@01P00O^YnjP00Ool000moo`03001oogoo00Uoo`002Woo00<007ooOol087oo00<0
07ooOol0>7oo00<0057DDM@0=57D00<0057DDM@0>U7D00H007kZO^X007oo000?Ool00`00Oomoo`09
Ool000Yoo`03001oogoo021oo`03001oogoo03Qoo`03001Ae57D03AAe003001Ae57D03YAe004001n
jWkZO^X2000?Ool00`00Oomoo`09Ool000Yoo`03001oogoo01moo`03001oogoo03Uoo`03001Ae57D
03AAe0<003YAe004001njWkZO^X2000?Ool00`00Oomoo`09Ool000Yoo`03001oogoo01moo`03001o
ogoo03Uoo`03001Ae57D03AAe003001Ae00003YAe004001njWkZO^X2000?Ool00`00Oomoo`09Ool0
00Yoo`03001oogoo01moo`03001oogoo03Uoo`03001Ae57D03AAe003001Ae00003YAe004001njWkZ
O^X2000?Ool00`00Oomoo`09Ool000Yoo`03001oogoo01moo`03001oogoo03Uoo`03001Ae57D03AA
e0800003DM@0057D039Ae0L000=njP8000moo`03001oogoo00Uoo`002Woo00<007ooOol07goo00<0
07ooOol0>Goo00<0057DDM@0=57D0P0000=Ae000DM@09E7D3@001cLo00<007kZO^X00P003goo00<0
07ooOol02Goo000:Ool00`00Oomoo`0OOol00`00Oomoo`0iOol00`00DMAAe00dDM@200000e7D0000
000HDM@=000E=cl01000O^X000003goo00<007ooOol02Goo0009Ool00`00Oomoo`0POol00`00Oomo
o`0iOol00`00DMAAe00dDM@00`00DMAAe00=DM@=000R=cl01000O^X000003goo00<007ooOol02Goo
0009Ool00`00Oomoo`0POol00`00Oomoo`0iOol00`00DMAAe00dDM@01000DMAAe57D3000<3Lo0`00
3goo00<007ooOol02Goo0009Ool00`00Oomoo`0POol00`00Oomoo`0iOol00`00DMAAe00[DM@=000f
=cl9000?Ool00`00Oomoo`09Ool000Uoo`03001oogoo021oo`03001oogoo03Uoo`03001Ae57D01iA
e0d000Tg?`03000g?cLo02Tg?`h000Qoo`03001oogoo00ioo`03001oogoo00Qoo`002Goo00<007oo
Ool087oo00<007ooOol0>Goo00<0057DDM@04E7D3@005SLo00<003Lo=cl06cLo3P005goo00<007oo
Ool03Goo00<007ooOol027oo0009Ool00`00Oomoo`0POol00`00Oomoo`0iOol00`00DMAAe004DM@=
000S=cl00`00=clg?`0==cl>000UOol00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo
021oo`03001oogoo03Uoo`L0030g?`03000g?`0000d003=oo`03001oogoo00eoo`03001oogoo00Qo
o`002Goo00<007ooOol087oo00<007ooOol0>Woo0P00:3Lo3P00@Goo00<007ooOol03Goo00<007oo
Ool027oo0009Ool00`00Oomoo`0POol00`00Oomoo`0lOol2000H=cl>000<Ool00`00Oomoo`10Ool0
0`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo021oo`03001oogoo03ioo`8000Pg?`h0
01Yoo`03001oogoo041oo`03001oogoo00eoo`03001oogoo00Qoo`002Goo00<007ooOol087oo00<0
07ooOol0@7oo2000:7oo00<007ooOol0@7oo00<007ooOol03Goo00<007ooOol027oo0009Ool00`00
Oomoo`0POol00`00Oomoo`1`Ool00`00Oomoo`10Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uo
o`03001oogoo021oo`03001oogoo071oo`03001oogoo041oo`03001oogoo00eoo`03001oogoo00Qo
o`002Goo00<007ooOol087oo00<007ooOol0L7oo00<007ooOol0@7oo00<007ooOol03Goo00<007oo
Ool027oo0009Ool00`00Oomoo`0POol00`00Oomoo`1`Ool00`00Oomoo`10Ool00`00Oomoo`0=Ool0
0`00Oomoo`08Ool000Uoo`03001oogoo021oo`03001oogoo071oo`03001oogoo041oo`03001oogoo
00eoo`03001oogoo00Qoo`002Goo00<007ooOol087oo00<007ooOol0L7oo00<007ooOol0@7oo00<0
07ooOol03Goo00<007ooOol027oo0009Ool00`00Oomoo`0POol00`00Oomoo`1`Ool00`00Oomoo`10
Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo021oo`03001oogoo071oo`03001o
ogoo041oo`03001oogoo00eoo`03001oogoo00Qoo`002Goo00<007ooOol087oo00<007ooOol0L7oo
00<007ooOol0@7oo00<007ooOol03Goo00<007ooOol027oo0009Ool00`00Oomoo`0POol00`00Oomo
o`1`Ool00`00Oomoo`10Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo021oo`03
001oogoo071oo`03001oogoo041oo`03001oogoo00eoo`03001oogoo00Qoo`002Goo00<007ooOol0
87oo00<007ooOol0L7oo00<007ooOol0@7oo00<007ooOol03Goo00<007ooOol027oo0008Ool00`00
Oomoo`0QOol00`00Oomoo`1`Ool00`00Oomoo`10Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool000Qo
o`03001oogoo021oo`03001oogoo075oo`03001oogoo041oo`03001oogoo00eoo`03001oogoo00Qo
o`0027oo00<007ooOol087oo00<007ooOol0LGoo00<007ooOol0@7oo00<007ooOol03Woo00<007oo
Ool01goo0008Ool00`00Oomoo`0POol00`00Oomoo`1aOol00`00Oomoo`10Ool00`00Oomoo`0>Ool0
0`00Oomoo`07Ool000Qoo`03001oogoo021oo`03001oogoo075oo`03001oogoo041oo`03001oogoo
00ioo`03001oogoo00Moo`0027oo00<007ooOol087oo00<007ooOol0LGoo00<007ooOol0@7oo00<0
07ooOol03Woo00<007ooOol01goo0008Ool00`00Oomoo`0POol00`00Oomoo`1aOol00`00Oomoo`10
Ool00`00Oomoo`0>Ool00`00Oomoo`07Ool000Qoo`03001oogoo021oo`03001oogoo075oo`03001o
ogoo041oo`03001oogoo00ioo`03001oogoo00Moo`0027oo00<007ooOol087oo00<007ooOol0LGoo
00<007ooOol0@7oo00<007ooOol03Woo00<007ooOol01goo0008Ool00`00Oomoo`0POol00`00Oomo
o`1aOol00`00Oomoo`11Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool000Qoo`03001oogoo021oo`03
001oogoo075oo`03001oogoo045oo`03001oogoo00eoo`03001oogoo00Moo`0027oo00<007ooOol0
87oo00<007ooOol0LGoo00<007ooOol0@Goo00<007ooOol03Goo00<007ooOol01goo0008Ool00`00
Oomoo`0POol00`00Oomoo`1_Ool00`00Ool00013Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool000Qo
o`03001oogoo021oo`03001oogoo06moo`03001oo`0000Ioo`03001oogoo03Yoo`03001oogoo00eo
o`03001oogoo00Moo`0027oo00<007ooOol087oo00<007ooOol0JWoo00<007ooOol00Woo00<007oo
00001Woo00<007ooOol0>Woo00<007ooOol03Goo00<007ooOol01goo0008Ool00`00Oomoo`0POol0
0`00Oomoo`1ZOol00`00Oomoo`02Ool01@00Ool007oo00000goo00<007ooOol0>goo00<007ooOol0
3Goo00<007ooOol01goo0008Ool00`00Oomoo`0POol00`00Oomoo`1[Ool02@00Oomoogoo001oo`00
Ool00003Ool00`00Oomoo`0kOol00`00Oomoo`0=Ool00`00Oomoo`07Ool000Qoo`03001oogoo021o
o`03001oogoo06]oo`03001oogoo009oo`800005Ool007ooOol0000nOol00`00Oomoo`0=Ool00`00
Oomoo`07Ool000Qoo`03001oogoo021oo`03001oogoo06aoo`04001oogooOol200001Goo001oogoo
0000?Woo00<007ooOol03Goo00<007ooOol01goo0008Ool00`00Oomoo`0POol00`00Oomoo`1/Ool0
1000Oomoogoo0`000Woo00<007ooOol0?Goo00<007ooOol03Goo00<007ooOol01goo0008Ool00`00
Oomoo`0POol00`00Oomoo`1]Ool00`00Oomoo`030002Ool00`00Oomoo`0mOol00`00Oomoo`0=Ool0
0`00Oomoo`07Ool000Qoo`03001oogoo021oo`03001oogoo06eoo`03001oogoo00<00003Ool007oo
03moo`03001oogoo00eoo`03001oogoo00Moo`0027oo00<007ooOol087oo00<007ooOol0KWoo00<0
07oo00000P0000=oo`00Ool0=Woo2P003goo00<007ooOol01goo0007Ool00`00Oomoo`0QOol00`00
Oomoo`1^Ool00`00Ool00003000VOolB000:Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool000Moo`03
001oogoo025oo`03001oogoo06moo`D001Aooa8001eoo`8000aoo`03001oogoo00Moo`001goo00<0
07ooOol08Goo00<007ooOol0Kgoo00@007oo0000009ooa<0035oo`03001oogoo00Yoo`03001oogoo
00Ioo`001goo00<007ooOol08Goo00<007ooOol0Hgoo4P00AGoo00<007ooOol02Goo00<007ooOol0
1Woo0007Ool00`00Oomoo`0QOol00`00Oomoo`1AOolB000=Ool20019Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool000Moo`03001oogoo025oo`03001oogoo03iooa<0021oo`03001oogoo04Qoo`03001o
ogoo00Moo`03001oogoo00Ioo`001goo00<007ooOol08Goo00<007ooOol0;7oo4P00Ogoo0P001goo
00<007ooOol01Woo0007Ool00`00Oomoo`0QOol00`00Oomoo`0JOolB002COol00`00Oomoo`04Ool0
0`00Oomoo`06Ool000Moo`03001oogoo021oo`03001oogoo00Qooa<005Uoo`8004]oo`03001oogoo
00=oo`03001oogoo00Ioo`001goo00<007ooOol06Goo4P00KGoo00<007ooOol0BWoo00<007ooOol0
0Woo00<007ooOol01Woo0007Ool00`00Oomoo`07OolB0007Ool00`00Oomoo`1eOol00`00Oomoo`1;
Ool01@00Oomoogoo000027oo0007Ool:000IOol00`00Oomoo`1dOol00`00Ool0001=Ool200000goo
001oo`07Ool000Uoo`<001ioo`03001oogoo07Aoo`03001oo`0004moo`8000Qoo`0037oo0`006goo
00<007ooOol0Lgoo0P0000=oo`000000AGoo2`0027oo000?Ool3000HOol00`00Oomoo`2YOolD000C
Ool0019oo`<001Eoo`03001oogoo09Eooa@002Moo`005Goo0`004Woo00<007ooOol0PGoo5000>goo
000HOol2000@Ool00`00Oomoo`1]OolD001?Ool001Yoo`<000eoo`03001oogoo05QooaD006=oo`00
7Goo0`002Woo00<007ooOol0A7oo5000N7oo000POol30007Ool00`00Oomoo`0`OolD002<Ool002=o
o`<000Aoo`03001oogoo01aooa@00:1oo`009Woo0`0000=oo`00Ool02Goo5000]7oo000YOol<0038
Ool00?eoo`00oGoo003mOol00?eoo`00oGoo003mOol00?eoo`00\
\>"],
  ImageRangeCache->{{{0, 252}, {287, 0}} -> {0.0532403, -0.0254886, 
  0.00352411, 0.00352411}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Five bodies are used in the gear-drive model. No body objects are defined \
because no explicit point coordinates are used in the model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(drivebevel = 2; \)\), 
    \(\(drivespur = 3; \)\), 
    \(\(pinion = 4; \)\), 
    \(\(rack = 5; \)\), 
    \(X = {1, 0, 0}; \nY = {0, 1, 0}; \nZ = {0, 0, 1}; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Eight constraints are required to model the gear-drive mechanism."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the rotational axis of the drive bevel. The drive \
bevel rotates about an axis originating at the global origin and pointing in \
the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction, which is coincident with the drive bevel's local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint specifies the rotation of the drive bevel."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An ",
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint enforces the gear relationship between the drive bevel and the \
driven bevel (drive spur). The ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects that are used to specify the axes of each gear contain several \
critical data. The origins of the two axes are to be adjacent, thus they are \
located on the gear axes at the intended point of intersection of the axes."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Note that the local coordinate axes of the drive spur are initially \
rotationally aligned with the local axes of the drive bevel. Thus, the \
reference direction of each gear is initially parallel to the rotational axis \
of its neighbor, which results in an orientation constant of zero. Note also \
that these are straight cut bevel gears, so the offset distance between their \
axes is also zero."], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint removes the one remaining degree of freedom from the drive \
spur, its freedom to orbit drive bevel."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint enforces the gear relationship between the drive spur and the \
driven spur (pinion). The rotational axes of these two gears are to be \
parallel, so they both point in the local ",
  StyleBox["z",
    FontSlant->"Italic"],
  " direction. The orientation constant allows the two gears to be initially \
aligned with the global axes."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint prevents the pinion from orbiting the drive spur."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RackAndPinion5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the translation of the rack and the orthogonal \
distance between the rack axis and the pinion center. The radius of the rack \
is specified as -3.0 to put the pinion on the correct side of the rack for \
this model."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint prevents the rack from orbiting the pinion."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the complete constraint set for the gear-drive model."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      Revolute5[1, Axis[drivebevel, 0, X], Axis[ground, 0, X]], \n\t
      ProjectedAngle1[2, Vector[drivebevel, Y], Vector[ground, Y], 
        Vector[ground, X], 2\ \[Pi]\ T], \n\t
      OrthogonalGears5[3, Axis[drivebevel, {2, 0, 0}, X, Z], 2, {rotSym1, 0}, 
        Axis[drivespur, 0, Z, X], 3, 0], \n\t
      RelativeY1[4, Point[drivespur, {0, 0, \(-2\)}], 0], \n\t
      ParallelGears5[5, \n\t\tAxis[drivespur, 0, Z, X], 1.5, {rotSym2, 0}, 
        Axis[pinion, 0, Z, X], 3.0, \(-1\)/6\ \[Pi]\ \((1.5 + 3.0)\)], \n\t
      RelativeY1[6, Point[pinion, 0], 2.25], \n\t
      RackAndPinion5[7, Axis[pinion, 0, Z, X], \(-3.0\), {rotSym3, 0}, 
        Axis[rack, 0, Z, X], 0], \n\t
      Orthogonal1[8, \n\t\tVector[rack, {1, 0, 0}], 
        Vector[ground, {0, 1, 0}]]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Initial guesses for the rack and pinion must be set or the model will not \
converge. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This sets the necessary initial guesses."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetGuess[X3 \[Rule] 2, Y3 \[Rule] 0, Z3 \[Rule] 0, X4 \[Rule] 6, 
      Y4 \[Rule] 2.25, Z4 \[Rule] 0, X5 \[Rule] 6, Y5 \[Rule] 5.25, 
      Z5 \[Rule] 0, rotSym2 \[Rule] .5]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Because of the presence of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the driving constraint, the model can be run through its intended \
range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the angular coordinate of the drive bevel. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 0\), ",", 
        \(Eo2 \[Rule] 0.987688340595137859`\), ",", 
        \(Ei2 \[Rule] 0.156434465040230907`\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] 2.`\), ",", \(Y3 \[Rule] 0\), 
        ",", \(Z3 \[Rule] 0\), ",", \(Eo3 \[Rule] 0.994521895368274044`\), 
        ",", \(Ei3 \[Rule] 0\), ",", \(Ej3 \[Rule] 0\), ",", 
        \(Ek3 \[Rule] \(-0.104528463267654592`\)\), ",", 
        \(X4 \[Rule] 5.89711431702997401`\), ",", 
        RowBox[{"Y4", "\[Rule]", 
          StyleBox["2.25`",
            StyleBoxAutoDelete->True,
            PrintPrecision->3]}], ",", \(Z4 \[Rule] 0\), ",", 
        \(Eo4 \[Rule] 0.998629534754574166`\), ",", \(Ei4 \[Rule] 0\), ",", 
        \(Ej4 \[Rule] 0\), ",", \(Ek4 \[Rule] 0.0523359562429447144`\), ",", 
        \(X5 \[Rule] 5.5829550516709876`\), ",", \(Y5 \[Rule] 5.25`\), ",", 
        \(Z5 \[Rule] 0\), ",", \(Eo5 \[Rule] 1.`\), ",", \(Ei5 \[Rule] 0\), 
        ",", \(Ej5 \[Rule] 0\), ",", \(Ek5 \[Rule] 0\), ",", 
        \(rotSym1 \[Rule] \(-0.314159265358995831`\)\), ",", 
        \(rotSym2 \[Rule] 0.733038285837622716`\), ",", 
        \(rotSym3 \[Rule] \(-0.104719755119661961`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.25."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({rotSym1, rotSym2, rotSym3} /. SolveMech[0.25]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-1.57079632679489584`\), 1.57079632679489566`, 
      \(-0.523598775598298438`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the gear-drive mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.25."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.21796  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.0960005 1.19957 0.0299893 1.19957 [ 
[ 0 0 0 0 ] 
[ 1 1.21796 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 1.21796 L 
0 1.21796 L 
closepath 
clip 
newpath 
p 
.002 w 
.19993 .27243 m 
.07149 .14918 L 
s 
.07149 .14918 m 
.02999 1.13899 L 
s 
.02999 1.13899 m 
.17327 1.18798 L 
s 
.17327 1.18798 m 
.19993 .27243 L 
s 
.92977 .17195 m 
.97001 1.1481 L 
s 
.97001 1.1481 m 
.8959 1.09092 L 
s 
.8959 1.09092 m 
.85893 .02999 L 
s 
.85893 .02999 m 
.92977 .17195 L 
s 
.19993 .27243 m 
.07149 .14918 L 
s 
.07149 .14918 m 
.85893 .02999 L 
s 
.85893 .02999 m 
.92977 .17195 L 
s 
.92977 .17195 m 
.19993 .27243 L 
s 
.17327 1.18798 m 
.97001 1.1481 L 
s 
.97001 1.1481 m 
.8959 1.09092 L 
s 
.8959 1.09092 m 
.02999 1.13899 L 
s 
.02999 1.13899 m 
.17327 1.18798 L 
s 
P 
p 
.002 w 
.2892 .35181 m .236 .41776 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.36083 .30773 m .2892 .35181 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.27533 .42815 m .31157 .38321 L .2892 .35181 L p 
.353 .109 .398 r 
F P 
s 
P 
p 
.002 w 
.2892 .35181 m .236 .41776 L .27533 .42815 L p 
.353 .109 .398 r 
F P 
s 
P 
p 
.002 w 
.36083 .30773 m .2892 .35181 L .31157 .38321 L p 
.428 .127 .351 r 
F P 
s 
P 
p 
.002 w 
.25692 .48163 m .27533 .42815 L .236 .41776 L p 
.337 .164 .493 r 
F P 
s 
P 
p 
.002 w 
.236 .41776 m .20875 .49631 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.236 .41776 m .20875 .49631 L .25692 .48163 L p 
.337 .164 .493 r 
F P 
s 
P 
p 
.002 w 
.4409 .29196 m .36083 .30773 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.31157 .38321 m .36039 .35327 L .36083 .30773 L p 
.428 .127 .351 r 
F P 
s 
P 
p 
.002 w 
.4409 .29196 m .36083 .30773 L .36039 .35327 L p 
.533 .207 .362 r 
F P 
s 
P 
p 
.002 w 
.25918 .53592 m .25692 .48163 L .20875 .49631 L p 
.375 .265 .598 r 
F P 
s 
P 
p 
.002 w 
.20875 .49631 m .2117 .57643 L .24511 .64644 L p 
.631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.20875 .49631 m .2117 .57643 L .25918 .53592 L p 
.375 .265 .598 r 
F P 
s 
P 
p 
.002 w 
.24574 .42452 m .25327 .4619 L .20336 .46731 L p 
.417 .419 .754 r 
F P 
s 
P 
p 
.002 w 
.20336 .46731 m .19207 .41231 L .24574 .42452 L p 
.417 .419 .754 r 
F P 
s 
P 
p 
.002 w 
.20628 .52342 m .20336 .46731 L .25327 .4619 L p 
.407 .325 .651 r 
F P 
s 
P 
p 
.002 w 
.20336 .46731 m .19207 .41231 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.20037 .57305 m .20628 .52342 L .20336 .46731 L p 
.981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.25327 .4619 m .25531 .50004 L .20628 .52342 L p 
.407 .325 .651 r 
F P 
s 
P 
p 
.002 w 
.20037 .57305 m .20628 .52342 L .25531 .50004 L p 
.329 .162 .498 r 
F P 
s 
P 
p 
.002 w 
.23375 .39319 m .24574 .42452 L .19207 .41231 L p 
.362 .479 .844 r 
F P 
s 
P 
p 
.002 w 
.19207 .41231 m .17384 .36593 L .23375 .39319 L p 
.362 .479 .844 r 
F P 
s 
P 
p 
.002 w 
.19207 .41231 m .17384 .36593 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.51798 .30738 m .4409 .29196 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.36039 .35327 m .41477 .34278 L .4409 .29196 L p 
.533 .207 .362 r 
F P 
s 
P 
p 
.002 w 
.51798 .30738 m .4409 .29196 L .41477 .34278 L p 
.633 .316 .416 r 
F P 
s 
P 
p 
.002 w 
.28211 .58299 m .25918 .53592 L .2117 .57643 L p 
.445 .375 .685 r 
F P 
s 
P 
p 
.002 w 
.2117 .57643 m .24511 .64644 L .28211 .58299 L p 
.445 .375 .685 r 
F P 
s 
P 
p 
.002 w 
.18626 .60917 m .20037 .57305 L .25158 .53356 L p 
.086 0 .166 r 
F P 
s 
P 
p 
.002 w 
.25531 .50004 m .25158 .53356 L .20037 .57305 L p 
.329 .162 .498 r 
F P 
s 
P 
p 
.002 w 
.16568 .62608 m .18626 .60917 L .20037 .57305 L p 
.981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.14143 .62034 m .16568 .62608 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.11717 .59177 m .14143 .62034 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.0969 .54411 m .11717 .59177 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.08418 .48485 m .0969 .54411 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.08128 .424 m .08418 .48485 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.08863 .37193 m .08128 .424 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.10477 .33709 m .08863 .37193 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.12678 .32444 m .10477 .33709 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.15102 .33491 m .12678 .32444 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.17384 .36593 m .15102 .33491 L p 
.20037 .57305 L .981 .769 .542 r 
F P 
s 
P 
p 
.002 w 
.21894 .37254 m .23375 .39319 L .17384 .36593 L p 
.152 .476 .896 r 
F P 
s 
P 
p 
.002 w 
.17384 .36593 m .15102 .33491 L .21894 .37254 L p 
.152 .476 .896 r 
F P 
s 
P 
p 
.002 w 
.41477 .34278 m .46679 .35356 L .51798 .30738 L p 
.633 .316 .416 r 
F P 
s 
P 
p 
.002 w 
.58049 .35256 m .51798 .30738 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.58049 .35256 m .51798 .30738 L .46679 .35356 L p 
.706 .42 .489 r 
F P 
s 
P 
p 
.002 w 
.31157 .38321 m .27533 .42815 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.36039 .35327 m .31157 .38321 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.27533 .42815 m .25692 .48163 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.61836 .42148 m .58049 .35256 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.62485 .50393 m .61836 .42148 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.32266 .61558 m .28211 .58299 L .24511 .64644 L p 
.522 .47 .74 r 
F P 
s 
P 
p 
.002 w 
.59815 .58687 m .62485 .50393 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.54218 .65669 m .59815 .58687 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.4661 .70187 m .54218 .65669 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.38249 .7153 m .4661 .70187 L p 
.24511 .64644 L .631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.24511 .64644 m .30486 .69549 L .38249 .7153 L p 
.631 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.24511 .64644 m .30486 .69549 L .32266 .61558 L p 
.522 .47 .74 r 
F P 
s 
P 
p 
.002 w 
.41477 .34278 m .36039 .35327 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.25692 .48163 m .25918 .53592 L .28211 .58299 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.25327 .4619 m .24574 .42452 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.25158 .53356 m .25531 .50004 L .25327 .4619 L p 
.986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.27686 .41642 m .30472 .38188 L .33216 .40804 L p 
.883 .882 .828 r 
F P 
s 
P 
p 
.002 w 
.33216 .40804 m .30486 .44191 L .27686 .41642 L p 
.883 .882 .828 r 
F P 
s 
P 
p 
.002 w 
.36895 .38554 m .33216 .40804 L .30472 .38188 L p 
.776 .877 .92 r 
F P 
s 
P 
p 
.002 w 
.33216 .40804 m .30486 .44191 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.36895 .38554 m .33216 .40804 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.26273 .45746 m .27686 .41642 L .30486 .44191 L p 
.957 .849 .695 r 
F P 
s 
P 
p 
.002 w 
.30486 .44191 m .29107 .4822 L .26273 .45746 L p 
.957 .849 .695 r 
F P 
s 
P 
p 
.002 w 
.30486 .44191 m .29107 .4822 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.004 w 
.23191 .2801 m 
.22302 .22199 L 
s 
P 
p 
.002 w 
.30472 .38188 m .34221 .35888 L .36895 .38554 L p 
.776 .877 .92 r 
F P 
s 
P 
p 
.002 w 
.46679 .35356 m .41477 .34278 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.40989 .37777 m .36895 .38554 L .34221 .35888 L p 
.611 .823 .982 r 
F P 
s 
P 
p 
.002 w 
.40989 .37777 m .36895 .38554 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.25158 .53356 m .24249 .55761 L .18626 .60917 L p 
.086 0 .166 r 
F P 
s 
P 
p 
.002 w 
.16568 .62608 m .18626 .60917 L .24249 .55761 L p 
.522 .856 .578 r 
F P 
s 
P 
p 
.002 w 
.24574 .42452 m .23375 .39319 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.26449 .499 m .26273 .45746 L .29107 .4822 L p 
.988 .747 .477 r 
F P 
s 
P 
p 
.002 w 
.29107 .4822 m .29292 .52301 L .26449 .499 L p 
.988 .747 .477 r 
F P 
s 
P 
p 
.002 w 
.29107 .4822 m .29292 .52301 L .3103 .55827 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.004 w 
.22302 .22199 m 
.19752 .27348 L 
s 
P 
p 
.004 w 
.22302 .22199 m 
.24602 .26681 L 
s 
P 
p 
.004 w 
.21138 .26007 m 
.22302 .22199 L 
s 
P 
p 
.004 w 
.2194 .35569 m 
.22302 .22199 L 
s 
P 
p 
.002 w 
.46679 .35356 m .50859 .38438 L .58049 .35256 L p 
.706 .42 .489 r 
F P 
s 
P 
p 
.002 w 
.61836 .42148 m .58049 .35256 L .50859 .38438 L p 
.747 .503 .562 r 
F P 
s 
P 
p 
.002 w 
.34221 .35888 m .38387 .35085 L .40989 .37777 L p 
.611 .823 .982 r 
F P 
s 
P 
p 
.002 w 
.50859 .38438 m .46679 .35356 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.44893 .38603 m .40989 .37777 L .38387 .35085 L p 
.31 .661 .973 r 
F P 
s 
P 
p 
.002 w 
.44893 .38603 m .40989 .37777 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.22926 .56842 m .24249 .55761 L .25158 .53356 L p 
.986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.21377 .56395 m .22926 .56842 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.19835 .5444 m .21377 .56395 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.18549 .51249 m .19835 .5444 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.17734 .47319 m .18549 .51249 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.17528 .43292 m .17734 .47319 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.17964 .3983 m .17528 .43292 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.18959 .37483 m .17964 .3983 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.20344 .36594 m .18959 .37483 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.21894 .37254 m .20344 .36594 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.23375 .39319 m .21894 .37254 L p 
.25158 .53356 L .986 .771 .53 r 
F P 
s 
P 
p 
.002 w 
.28208 .53484 m .26449 .499 L .29292 .52301 L p 
.889 .475 .066 r 
F P 
s 
P 
p 
.002 w 
.29292 .52301 m .3103 .55827 L .28208 .53484 L p 
.889 .475 .066 r 
F P 
s 
P 
p 
.002 w 
.20344 .36594 m .21894 .37254 L .15102 .33491 L p 
.421 0 0 r 
F P 
s 
P 
p 
.004 w 
.21894 .37254 m 
.2194 .35569 L 
s 
P 
p 
.004 w 
.21638 .46738 m 
.21894 .37254 L 
s 
P 
p 
.002 w 
.15102 .33491 m .12678 .32444 L .20344 .36594 L p 
.421 0 0 r 
F P 
s 
P 
p 
.002 w 
.37492 .62835 m .32266 .61558 L .30486 .69549 L p 
.593 .54 .765 r 
F P 
s 
P 
p 
.002 w 
.30486 .69549 m .38249 .7153 L .37492 .62835 L p 
.593 .54 .765 r 
F P 
s 
P 
p 
.002 w 
.38387 .35085 m .42357 .35915 L .44893 .38603 L p 
.31 .661 .973 r 
F P 
s 
P 
p 
.002 w 
.48016 .40931 m .44893 .38603 L .42357 .35915 L p 
0 .231 .712 r 
F P 
s 
P 
p 
.002 w 
.48016 .40931 m .44893 .38603 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.53355 .43095 m .50859 .38438 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.53743 .48629 m .53355 .43095 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.51926 .54177 m .53743 .48629 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.48176 .58848 m .51926 .54177 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.43092 .61892 m .48176 .58848 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.37492 .62835 m .43092 .61892 L p 
.28211 .58299 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.28211 .58299 m .32266 .61558 L .37492 .62835 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.49869 .44429 m .48016 .40931 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.50143 .4857 m .49869 .44429 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.48778 .52711 m .50143 .4857 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.45978 .56197 m .48778 .52711 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.42184 .58475 m .45978 .56197 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.38 .59193 m .42184 .58475 L p 
.3103 .55827 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.31307 .55948 m .28208 .53484 L .3103 .55827 L p 
0 .107 .573 r 
F P 
s 
P 
p 
.002 w 
.3103 .55827 m .34083 .58254 L .38 .59193 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.3103 .55827 m .34083 .58254 L .31307 .55948 L p 
0 .107 .573 r 
F P 
s 
P 
p 
.002 w 
.24249 .55761 m .22926 .56842 L .16568 .62608 L p 
.522 .856 .578 r 
F P 
s 
P 
p 
.002 w 
.50859 .38438 m .53355 .43095 L .61836 .42148 L p 
.747 .503 .562 r 
F P 
s 
P 
p 
.002 w 
.62485 .50393 m .61836 .42148 L .53355 .43095 L p 
.762 .562 .627 r 
F P 
s 
P 
p 
.002 w 
.42357 .35915 m .4553 .38276 L .48016 .40931 L p 
0 .231 .712 r 
F P 
s 
P 
p 
.002 w 
.49869 .44429 m .48016 .40931 L .4553 .38276 L p 
.823 .397 0 r 
F P 
s 
P 
p 
.002 w 
.35291 .56895 m .31307 .55948 L .34083 .58254 L p 
.21 .628 .952 r 
F P 
s 
P 
p 
.002 w 
.34083 .58254 m .38 .59193 L .35291 .56895 L p 
.21 .628 .952 r 
F P 
s 
P 
p 
.002 w 
.14143 .62034 m .16568 .62608 L .22926 .56842 L p 
.81 .963 .908 r 
F P 
s 
P 
p 
.002 w 
.43092 .61892 m .37492 .62835 L .38249 .7153 L p 
.653 .586 .767 r 
F P 
s 
P 
p 
.002 w 
.38249 .7153 m .4661 .70187 L .43092 .61892 L p 
.653 .586 .767 r 
F P 
s 
P 
p 
.002 w 
.30472 .38188 m .27686 .41642 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.34221 .35888 m .30472 .38188 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.27686 .41642 m .26273 .45746 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.4553 .38276 m .47407 .41831 L .49869 .44429 L p 
.823 .397 0 r 
F P 
s 
P 
p 
.002 w 
.50143 .4857 m .49869 .44429 L .47407 .41831 L p 
.993 .744 .417 r 
F P 
s 
P 
p 
.002 w 
.38387 .35085 m .34221 .35888 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.39551 .56154 m .35291 .56895 L .38 .59193 L p 
.577 .835 .994 r 
F P 
s 
P 
p 
.002 w 
.38 .59193 m .42184 .58475 L .39551 .56154 L p 
.577 .835 .994 r 
F P 
s 
P 
p 
.002 w 
.26273 .45746 m .26449 .499 L .28208 .53484 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.53355 .43095 m .53608 .46699 L p 
.55732 .44995 L .762 .562 .627 r 
F P 
s 
P 
p 
.002 w 
.47407 .41831 m .47677 .46046 L .50143 .4857 L p 
.993 .744 .417 r 
F P 
s 
P 
p 
.002 w 
.48778 .52711 m .50143 .4857 L .47677 .46046 L p 
.971 .869 .678 r 
F P 
s 
P 
p 
.002 w 
.47677 .46046 m .46278 .50266 L .48778 .52711 L p 
.971 .869 .678 r 
F P 
s 
P 
p 
.002 w 
.54373 .45746 m .53608 .46699 L p 
.46278 .50266 L .892 .908 .83 r 
F P 
s 
P 
p 
.002 w 
.53608 .46699 m .48778 .52711 L .47577 .51536 L p 
.892 .908 .83 r 
F P 
s 
P 
p 
.002 w 
.47577 .51536 m .46278 .50266 L p 
.53608 .46699 L .892 .908 .83 r 
F P 
s 
P 
p 
.002 w 
.53743 .48629 m .62485 .50393 L p 
.55732 .44995 L .762 .562 .627 r 
F P 
s 
P 
p 
.002 w 
.53608 .46699 m .53743 .48629 L p 
.55732 .44995 L .762 .562 .627 r 
F P 
s 
P 
p 
.002 w 
.59815 .58687 m .62485 .50393 L .53743 .48629 L p 
.757 .598 .68 r 
F P 
s 
P 
p 
.002 w 
.18959 .37483 m .20344 .36594 L .12678 .32444 L p 
.732 .273 .159 r 
F P 
s 
P 
p 
.002 w 
.12678 .32444 m .10477 .33709 L .18959 .37483 L p 
.732 .273 .159 r 
F P 
s 
P 
p 
.002 w 
.46406 .59908 m .43092 .61892 L .45376 .67277 L p 
.7 .609 .752 r 
F P 
s 
P 
p 
.002 w 
.42184 .58475 m .45978 .56197 L .43419 .53824 L p 
.772 .901 .932 r 
F P 
s 
P 
p 
.002 w 
.45978 .56197 m .48778 .52711 L .46278 .50266 L p 
.892 .908 .83 r 
F P 
s 
P 
p 
.002 w 
.46278 .50266 m .43419 .53824 L .45978 .56197 L p 
.892 .908 .83 r 
F P 
s 
P 
p 
.002 w 
.46028 .61055 m .43458 .58772 L p 
.47154 .54561 L .971 .869 .678 r 
F P 
s 
P 
p 
.002 w 
.48778 .52711 m .46406 .59908 L p 
.47154 .54561 L .971 .869 .678 r 
F P 
s 
P 
p 
.002 w 
.46406 .59908 m .46028 .61055 L p 
.47154 .54561 L .971 .869 .678 r 
F P 
s 
P 
p 
.002 w 
.48176 .58848 m .46406 .59908 L p 
.4661 .70187 L .7 .609 .752 r 
F P 
s 
P 
p 
.002 w 
.45376 .67277 m .4661 .70187 L p 
.46406 .59908 L .7 .609 .752 r 
F P 
s 
P 
p 
.002 w 
.4661 .70187 m .54218 .65669 L .48176 .58848 L p 
.7 .609 .752 r 
F P 
s 
P 
p 
.002 w 
.22926 .56842 m .21377 .56395 L .14143 .62034 L p 
.81 .963 .908 r 
F P 
s 
P 
p 
.002 w 
.42357 .35915 m .38387 .35085 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43419 .53824 m .39551 .56154 L .42184 .58475 L p 
.772 .901 .932 r 
F P 
s 
P 
p 
.004 w 
.48819 .21719 m 
.47136 .27375 L 
s 
P 
p 
.002 w 
.62023 .41132 m .54373 .45746 L .5199 .43159 L p 
.773 .895 .929 r 
F P 
s 
P 
p 
.002 w 
.46278 .50266 m .5199 .43159 L .54373 .45746 L p 
.892 .908 .83 r 
F P 
s 
P 
p 
.002 w 
.70669 .39545 m .62023 .41132 L .54373 .45746 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.79082 .4128 m .70669 .39545 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.86002 .46176 m .79082 .4128 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.90316 .53584 m .86002 .46176 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.91254 .62408 m .90316 .53584 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.88579 .71249 m .91254 .62408 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.82679 .78647 m .88579 .71249 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.7452 .83378 m .82679 .78647 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.53743 .48629 m .51926 .54177 L .59815 .58687 L p 
.757 .598 .68 r 
F P 
s 
P 
p 
.002 w 
.54218 .65669 m .59815 .58687 L .51926 .54177 L p 
.735 .613 .722 r 
F P 
s 
P 
p 
.002 w 
.65462 .84697 m .7452 .83378 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.56974 .82466 m .65462 .84697 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.51926 .54177 m .48176 .58848 L .54218 .65669 L p 
.735 .613 .722 r 
F P 
s 
P 
p 
.002 w 
.50359 .77137 m .56974 .82466 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.46554 .69611 m .50359 .77137 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.46028 .61055 m .46554 .69611 L p 
.54373 .45746 L .629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.54373 .45746 m .48778 .52711 L .46028 .61055 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.43458 .58772 m .46278 .50266 L .48778 .52711 L p 
.971 .869 .678 r 
F P 
s 
P 
p 
.002 w 
.4553 .38276 m .42357 .35915 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.5199 .43159 m .5979 .3844 L .62023 .41132 L p 
.773 .895 .929 r 
F P 
s 
P 
p 
.002 w 
.70669 .39545 m .62023 .41132 L .5979 .3844 L p 
.6 .828 .986 r 
F P 
s 
P 
p 
.004 w 
.4407 .25411 m 
.48819 .21719 L 
s 
P 
p 
.004 w 
.48819 .21719 m 
.45374 .25311 L 
s 
P 
p 
.004 w 
.48468 .27296 m 
.48819 .21719 L 
s 
P 
p 
.004 w 
.41489 .34995 m 
.48819 .21719 L 
s 
P 
p 
.002 w 
.47407 .41831 m .4553 .38276 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.47677 .46046 m .47407 .41831 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.35943 .45039 m 
.41489 .34995 L 
s 
P 
p 
.002 w 
.46278 .50266 m .47677 .46046 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43419 .53824 m .46278 .50266 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.39551 .56154 m .43419 .53824 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.35291 .56895 m .39551 .56154 L p 
.28208 .53484 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.28208 .53484 m .31307 .55948 L .35291 .56895 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43972 .67488 m .43458 .58772 L .46028 .61055 L p 
.993 .746 .432 r 
F P 
s 
P 
p 
.002 w 
.46028 .61055 m .46554 .69611 L .43972 .67488 L p 
.993 .746 .432 r 
F P 
s 
P 
p 
.002 w 
.11717 .59177 m .14143 .62034 L .21377 .56395 L p 
.804 .831 .872 r 
F P 
s 
P 
p 
.002 w 
.21377 .56395 m .19835 .5444 L .11717 .59177 L p 
.804 .831 .872 r 
F P 
s 
P 
p 
.002 w 
.5979 .3844 m .686 .368 L .70669 .39545 L p 
.6 .828 .986 r 
F P 
s 
P 
p 
.002 w 
.79082 .4128 m .70669 .39545 L .686 .368 L p 
.327 .665 .974 r 
F P 
s 
P 
p 
.002 w 
.17964 .3983 m .18959 .37483 L .10477 .33709 L p 
.76 .445 .453 r 
F P 
s 
P 
p 
.002 w 
.10477 .33709 m .08863 .37193 L .17964 .3983 L p 
.76 .445 .453 r 
F P 
s 
P 
p 
.004 w 
.29916 .39367 m 
.35943 .45039 L 
s 
P 
p 
.002 w 
.47829 .75149 m .43972 .67488 L .46554 .69611 L p 
.871 .451 .018 r 
F P 
s 
P 
p 
.002 w 
.46554 .69611 m .50359 .77137 L .47829 .75149 L p 
.871 .451 .018 r 
F P 
s 
P 
p 
.002 w 
.79886 .91715 m .79674 .83774 L .34195 .87366 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.34195 .87366 m .34083 .95002 L .79886 .91715 L p 
.629 .461 .636 r 
F P 
s 
P 
p 
.002 w 
.56974 .82466 m .65462 .84697 L .63202 .82828 L p 
.109 .583 .912 r 
F P 
s 
P 
p 
.002 w 
.72441 .81466 m .63202 .82828 L .65462 .84697 L p 
.508 .843 .998 r 
F P 
s 
P 
p 
.002 w 
.65462 .84697 m .7452 .83378 L .72441 .81466 L p 
.508 .843 .998 r 
F P 
s 
P 
p 
.002 w 
.79674 .83774 m .34195 .87366 L .31343 .85608 L p 
.453 .813 .996 r 
F P 
s 
P 
p 
.002 w 
.31208 .93394 m .31343 .85608 L .34195 .87366 L p 
.991 .773 .511 r 
F P 
s 
P 
p 
.002 w 
.34195 .87366 m .34083 .95002 L .31208 .93394 L p 
.991 .773 .511 r 
F P 
s 
P 
p 
.002 w 
.19835 .5444 m .18549 .51249 L .0969 .54411 L p 
.782 .733 .807 r 
F P 
s 
P 
p 
.002 w 
.0969 .54411 m .11717 .59177 L .19835 .5444 L p 
.782 .733 .807 r 
F P 
s 
P 
p 
.002 w 
.686 .368 m .5979 .3844 L .5199 .43159 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.686 .368 m .77169 .38542 L .79082 .4128 L p 
.327 .665 .974 r 
F P 
s 
P 
p 
.002 w 
.77169 .38542 m .686 .368 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.86002 .46176 m .79082 .4128 L .77169 .38542 L p 
0 .315 .79 r 
F P 
s 
P 
p 
.002 w 
.77169 .38542 m .84214 .43511 L .86002 .46176 L p 
0 .315 .79 r 
F P 
s 
P 
p 
.002 w 
.84214 .43511 m .77169 .38542 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.88601 .51049 m .84214 .43511 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.89544 .60043 m .88601 .51049 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.86801 .69064 m .89544 .60043 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.8077 .76624 m .86801 .69064 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.72441 .81466 m .8077 .76624 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.63202 .82828 m .72441 .81466 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.50359 .77137 m .56974 .82466 L .54556 .80569 L p 
.453 0 0 r 
F P 
s 
P 
p 
.002 w 
.54556 .80569 m .63202 .82828 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.54556 .80569 m .47829 .75149 L .50359 .77137 L p 
.453 0 0 r 
F P 
s 
P 
p 
.002 w 
.47829 .75149 m .54556 .80569 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43972 .67488 m .47829 .75149 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.43458 .58772 m .43972 .67488 L p 
.5199 .43159 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.5199 .43159 m .46278 .50266 L .43458 .58772 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.47152 .50231 m 
.58486 .55481 L 
s 
P 
p 
.004 w 
.41797 .41797 m 
.46932 .43733 L 
s 
P 
p 
.004 w 
.35943 .45039 m 
.45421 .49429 L 
s 
P 
p 
.004 w 
.45421 .49429 m 
.47152 .50231 L 
s 
P 
p 
.004 w 
.42893 .45182 m 
.46932 .43733 L 
s 
P 
p 
.004 w 
.21638 .46738 m 
.46932 .43733 L 
s 
P 
p 
.004 w 
.41755 .46907 m 
.46932 .43733 L 
s 
P 
p 
.002 w 
.17528 .43292 m .17964 .3983 L .08863 .37193 L p 
.759 .533 .59 r 
F P 
s 
P 
p 
.004 w 
.40845 .43425 m 
.46932 .43733 L 
s 
P 
p 
.002 w 
.77898 .89963 m .31208 .93394 L .34083 .95002 L p 
.425 .809 .99 r 
F P 
s 
P 
p 
.002 w 
.34083 .95002 m .79886 .91715 L .77898 .89963 L p 
.425 .809 .99 r 
F P 
s 
P 
p 
.002 w 
.18549 .51249 m .17734 .47319 L .08418 .48485 L p 
.767 .66 .744 r 
F P 
s 
P 
p 
.002 w 
.08418 .48485 m .0969 .54411 L .18549 .51249 L p 
.767 .66 .744 r 
F P 
s 
P 
p 
.002 w 
.08863 .37193 m .08128 .424 L .17528 .43292 L p 
.759 .533 .59 r 
F P 
s 
P 
p 
.002 w 
.17734 .47319 m .17528 .43292 L .08128 .424 L p 
.76 .598 .676 r 
F P 
s 
P 
p 
.004 w 
.17528 .43292 m 
.21638 .46738 L 
s 
P 
p 
.002 w 
.08128 .424 m .08418 .48485 L .17734 .47319 L p 
.76 .598 .676 r 
F P 
s 
P 
p 
.004 w 
.1506 .41222 m 
.17528 .43292 L 
s 
P 
p 
.002 w 
.90316 .53584 m .86002 .46176 L .84214 .43511 L p 
.661 .245 0 r 
F P 
s 
P 
p 
.004 w 
.54882 .54258 m 
.58486 .55481 L 
s 
P 
p 
.002 w 
.63202 .82828 m .54556 .80569 L .56974 .82466 L p 
.109 .583 .912 r 
F P 
s 
P 
p 
.002 w 
.8077 .76624 m .72441 .81466 L .7452 .83378 L p 
.748 .944 .946 r 
F P 
s 
P 
p 
.002 w 
.7452 .83378 m .82679 .78647 L .8077 .76624 L p 
.748 .944 .946 r 
F P 
s 
P 
p 
.002 w 
.31343 .85608 m .77697 .8186 L .79674 .83774 L p 
.453 .813 .996 r 
F P 
s 
P 
p 
.002 w 
.77898 .89963 m .77697 .8186 L .31343 .85608 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.31343 .85608 m .31208 .93394 L .77898 .89963 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.55172 .50915 m 
.58486 .55481 L 
s 
P 
p 
.004 w 
.52537 .55762 m 
.58486 .55481 L 
s 
P 
p 
.002 w 
.84214 .43511 m .88601 .51049 L .90316 .53584 L p 
.661 .245 0 r 
F P 
s 
P 
p 
.002 w 
.91254 .62408 m .90316 .53584 L .88601 .51049 L p 
.957 .699 .252 r 
F P 
s 
P 
p 
.004 w 
.52995 .52462 m 
.58486 .55481 L 
s 
P 
p 
.002 w 
.88601 .51049 m .89544 .60043 L .91254 .62408 L p 
.957 .699 .252 r 
F P 
s 
P 
p 
.002 w 
.88579 .71249 m .91254 .62408 L .89544 .60043 L p 
.986 .901 .613 r 
F P 
s 
P 
p 
.004 w 
.5435 .80407 m 
.55194 .79384 L 
s 
P 
p 
.004 w 
.51796 .83505 m 
.5198 .83282 L 
s 
P 
p 
.004 w 
.5198 .83282 m 
.5435 .80407 L 
s 
P 
p 
.004 w 
.60285 .53302 m 
.65209 .58595 L 
s 
P 
p 
.004 w 
.51796 .83505 m 
.51934 .83248 L 
s 
P 
p 
.004 w 
.51934 .83248 m 
.53727 .79919 L 
s 
P 
p 
.004 w 
.53727 .79919 m 
.65209 .58595 L 
s 
P 
p 
.004 w 
.65209 .58595 m 
.86191 .68315 L 
s 
P 
p 
.002 w 
.89544 .60043 m .86801 .69064 L .88579 .71249 L p 
.986 .901 .613 r 
F P 
s 
P 
p 
.002 w 
.82679 .78647 m .88579 .71249 L .86801 .69064 L p 
.9 .962 .822 r 
F P 
s 
P 
p 
.002 w 
.86801 .69064 m .8077 .76624 L .82679 .78647 L p 
.9 .962 .822 r 
F P 
s 
P 
p 
.004 w 
.86191 .68315 m 
.89812 .69992 L 
s 
P 
p 
.002 w 
.79886 .91715 m .79674 .83774 L .77697 .8186 L p 
.989 .762 .377 r 
F P 
s 
P 
p 
.004 w 
.51796 .83505 m 
.5181 .83258 L 
s 
P 
p 
.004 w 
.5181 .83258 m 
.52149 .77313 L 
s 
P 
p 
.004 w 
.51796 .83505 m 
.51889 .83214 L 
s 
P 
p 
.004 w 
.51889 .83214 m 
.53621 .77783 L 
s 
P 
p 
.004 w 
.51796 .83505 m 
.5216 .83229 L 
s 
P 
p 
.004 w 
.5216 .83229 m 
.55814 .80463 L 
s 
P 
p 
.004 w 
.55814 .80463 m 
.56863 .79668 L 
s 
P 
p 
.004 w 
.47635 .78965 m 
.53186 .83146 L 
s 
P 
p 
.004 w 
.53207 .91139 m 
.53259 1.11642 L 
s 
P 
p 
.004 w 
.53186 .83146 m 
.53207 .91139 L 
s 
P 
p 
.004 w 
.53186 .83146 m 
.63028 .82343 L 
s 
P 
p 
.004 w 
.70079 .81769 m 
.81093 .80871 L 
s 
P 
p 
.004 w 
.63028 .82343 m 
.70079 .81769 L 
s 
P 
p 
.002 w 
.77697 .8186 m .77898 .89963 L .79886 .91715 L p 
.989 .762 .377 r 
F P 
s 
P 
p 
.004 w 
.8665 .68878 m 
.89812 .69992 L 
s 
P 
p 
.004 w 
.8561 .68512 m 
.8665 .68878 L 
s 
P 
p 
.004 w 
.53259 1.11642 m 
.54138 1.06325 L 
s 
P 
p 
.004 w 
.77528 .81697 m 
.81093 .80871 L 
s 
P 
p 
.004 w 
.76354 .81969 m 
.77528 .81697 L 
s 
P 
p 
.004 w 
.861 .65105 m 
.89812 .69992 L 
s 
P 
p 
.004 w 
.50475 1.05993 m 
.53259 1.11642 L 
s 
P 
p 
.004 w 
.75332 .78512 m 
.81093 .80871 L 
s 
P 
p 
.004 w 
.83404 .70197 m 
.89812 .69992 L 
s 
P 
p 
.004 w 
.56028 1.05657 m 
.53259 1.11642 L 
s 
P 
p 
.004 w 
.75461 .84173 m 
.81093 .80871 L 
s 
P 
p 
.004 w 
.89812 .69992 m 
.84093 .66846 L 
s 
P 
p 
.004 w 
.53259 1.11642 m 
.52336 1.05318 L 
s 
P 
p 
.004 w 
.81093 .80871 m 
.74661 .80637 L 
s 
P 
p 
.002 w 
.92977 .17195 m 
.97001 1.1481 L 
s 
.97001 1.1481 m 
.8959 1.09092 L 
s 
.8959 1.09092 m 
.85893 .02999 L 
s 
.85893 .02999 m 
.92977 .17195 L 
s 
.17327 1.18798 m 
.97001 1.1481 L 
s 
.97001 1.1481 m 
.8959 1.09092 L 
s 
.8959 1.09092 m 
.02999 1.13899 L 
s 
.02999 1.13899 m 
.17327 1.18798 L 
s 
P 
p 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .46932 .43733 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .1034 .37264 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .22302 .22199 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(2)] .21638 .46738 1.3 1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .48819 .21719 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .58486 .55481 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .25587 .35293 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(3)] .35943 .45039 1.3 1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .89812 .69992 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .51796 .83505 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .56735 .49486 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(4)] .65209 .58595 1.3 1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .81093 .80871 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .53259 1.11642 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .43631 .75949 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(5)] .53186 .83146 1.3 1.3 Mshowa 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{235, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003[00017a000`40O003h00Ojgoo003[Ool00>]o
o`00jgoo003[Ool00>]oo`00jgoo003[Ool00<Eoo`@0029oo`00_goo1P000goo0P008Goo002hOol7
0009Ool2000QOol00;9oo`H0011oo`03001oo`00021oo`00Zgoo1`005Woo00<007oo000087oo002T
Ool7000MOol01000Oomoo`007goo002NOol6000TOol01000Oomoo`007goo002GOol7000ZOol01@00
Oomoogoo00007Woo002AOol6000aOol01@00Oomoogoo00007Woo002:Ool7000gOol00`00Oomoo`02
Ool00`00Oomoo`0KOol008Aoo`H003ioo`03001oogoo009oo`03001oogoo01]oo`00OGoo1`00A7oo
00<007ooOol00goo00<007ooOol06Woo001fOol7001;Ool00`00Oomoo`03Ool00`00Oomoo`0JOol0
071oo`H0059oo`03001oogoo00Aoo`03001oogoo01Uoo`00JGoo1`00FGoo00<007ooOol00goo00<0
07ooOol06Goo001SOol6001POol00`00Oomoo`04Ool00`00Oomoo`0HOol005aoo`L006Ioo`03001o
ogoo00Aoo`03001oogoo01Qoo`00EWoo1P00KGoo00<007ooOol01Goo00<007ooOol05goo001?Ool7
001cOol00`00Oomoo`05Ool00`00Oomoo`0GOol004Qoo`L007Yoo`03001oogoo00Ioo`03001oogoo
01Ioo`00@Woo1P00PGoo00<007ooOol01Woo00<007ooOol05Woo000kOol70027Ool00`00Oomoo`07
Ool00`00Oomoo`0EOol003Eoo`H008ioo`03001oogoo00Moo`03001oogoo01Eoo`00;Woo1`00U7oo
00<007ooOol027oo00<007ooOol057oo000XOol6002KOol00`00Oomoo`08Ool00`00Oomoo`0DOol0
025oo`L00:5oo`03001oogoo00Uoo`03001oogoo01=oo`006Woo1`00Z7oo00<007ooOol02Goo00<0
07ooOol04goo000DOol6002_Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol0011oo`@00;Eoo`03001o
ogoo00Yoo`03001oogoo019oo`0047oo0P00]goo00<007ooOol02goo00<007ooOol04Goo000@Ool0
0`00Ool0002fOol00`00Oomoo`0;Ool00`00Oomoo`0AOol0011oo`04001oogoo002eOol00`00Oomo
o`0<Ool00`00Oomoo`0@Ool0011oo`05001oogooOol0002dOol00`00Oomoo`0<Ool00`00Oomoo`0@
Ool0011oo`03001oogoo009oo`03001oogoo0;5oo`03001oogoo00Yoo`@0015oo`0047oo00<007oo
Ool00goo00<007ooOol0/7oo00<007ooOol00goo1`000goo00<007ooOol03goo000@Ool00`00Oomo
o`04Ool00`00Oomoo`2^Ool7000:Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Eoo`03001oogoo
0:Ioo`L00003Ool007oo00ioo`03001oogoo00moo`0047oo00<007ooOol01Woo00<007ooOol0WGoo
200027oo00<007ooOol03Goo00<007ooOol03goo000@Ool00`00Oomoo`07Ool00`00Oomoo`2EOol7
000@Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool0011oo`03001oogoo00Qoo`03001oogoo08eoo`L0
01Moo`03001oogoo00eoo`03001oogoo00moo`0047oo00<007ooOol02Goo00<007ooOol0QGoo1`00
7Woo00<007ooOol03Goo00<007ooOol03goo000?Ool00`00Oomoo`0;Ool00`00Oomoo`1mOol7000U
Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool000moo`03001oogoo00aoo`03001oogoo07Eoo`L002eo
o`03001oogoo00aoo`03001oogoo00moo`003goo00<007ooOol03Goo0P00KWoo1`00=7oo00<007oo
Ool037oo00<007ooOol03goo000?Ool00`00Oomoo`0?Ool00`00Oomoo`1>Ool00`00Oomoo`0COol7
000kOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool000moo`03001oogoo011oo`03001oogoo00moo`03
001oogoo03Uoo`<000eoo`P0049oo`03001oogoo00aoo`03001oogoo00moo`003goo00<007ooOol0
4Goo00<007ooOol03Goo0P00>Woo10001Woo1`00BWoo00<007ooOol03Goo00<007ooOol03Woo000?
Ool00`00Oomoo`0BOol00`00Oomoo`0<Ool3000hOol;001AOol00`00Oomoo`0=Ool00`00Oomoo`0>
Ool000moo`03001oogoo01=oo`03001oogoo00Yoo`@003Eoo`P005Moo`03001oogoo00eoo`03001o
ogoo00ioo`003goo00<007ooOol057oo00<007ooOol02Goo1@00;Goo200000=oo`00Ool00P0000=o
o`00Ool0EWoo00<007ooOol03Goo00<007ooOol03Woo000?Ool00`00Oomoo`0EOol00`00Oomoo`07
Ool2000017oo000000009Woo1`001Woo00<007oo00000Woo0P0000=oo`0000000Woo00<007ooOol0
DGoo00<007ooOol03Goo00<007ooOol03Woo000?Ool00`00Oomoo`0FOol00`00Oomoo`06Ool20000
0goo00000003000MOol7000;Ool200001Woo001oogoo001oo`80009oo`8005Aoo`03001oogoo00eo
o`03001oogoo00ioo`003goo00<007ooOol05goo00<007ooOol017oo00@007oo001oo`D001Ioo`L0
015oo`04001oogoo0003Ool01000Ool000000Woo0P00E7oo00<007ooOol03Goo00<007ooOol03Woo
000?Ool00`00Oomoo`0HOol00`00Oomoo`03Ool20002Ool200000goo0000000>Ool8000NOol01`00
Ool007oo001oo`00009oo`03001oogoo055oo`03001oogoo00eoo`03001oogoo00ioo`003goo00<0
07ooOol06Goo00L007ooOomoo`00Ool00002Ool50007Ool7000VOol01@00Ool007oo0000F7oo00<0
07ooOol03Goo00<007ooOol03Woo000?Ool00`00Oomoo`0JOol01000Oomoo`0017oo0P000goo1`00
;7oo00H007ooOol007oo001HOol00`00Oomoo`0=Ool00`00Oomoo`0>Ool000moo`03001oogoo01]o
o`8000=oo`L0039oo`04001oogoo0002Ool00`00Oomoo`1FOol00`00Oomoo`0=Ool00`00Oomoo`0>
Ool000moo`03001oogoo01aoo`@0009oo`03001oo`0003Aoo`04001oogoo0002Ool00`00Oomoo`1F
Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool000moo`03001oogoo01aoo`03001oogoo00=oo`03001o
o`0003=oo`03001oogoo05eoo`03001oogoo00eoo`03001oogoo00ioo`003goo00<007ooOol077oo
00<007ooOol00goo00<007oo0000<goo00<007ooOol0GGoo00<007ooOol03Goo00<007ooOol03Woo
000?Ool00`00Oomoo`0LOol00`00Oomoo`03Ool00`00Oomoo`0bOol00`00Oomoo`1NOol00`00Oomo
o`0=Ool00`00Oomoo`0>Ool000moo`03001oogoo01aoo`03001oogoo009oo`03001oogoo02moo`D0
061oo`03001oogoo00eoo`03001oogoo00ioo`003goo00<007ooOol077oo00<007ooOol00Woo00<0
07ooOol0:Woo1@0000E4b`00DDd0055=00@005aoo`03001oogoo00eoo`03001oogoo00ioo`003goo
00<007ooOol077oo00<007ooOol00Woo00<007ooOol09Woo10001TC;00<0055=00001E5=1@00Egoo
00<007ooOol03Goo00<007ooOol03Woo000?Ool00`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomo
o`0QOol50009A</00`00DDd0000;DDd4001COol00`00Oomoo`0=Ool00`00Oomoo`0>Ool000moo`03
001oogoo01aoo`03001oogoo009oo`03001oogoo01ioo`<000i4b`80011AC@<0051oo`03001oogoo
00eoo`03001oogoo00ioo`003goo00<007ooOol077oo00<007ooOol00Woo00<007ooOol077oo0`00
3dC;00<0055=00004E5=00@005V_000004ioo`03001oogoo00eoo`03001oogoo00ioo`003Woo00<0
07ooOol07Goo00<007ooOol00Woo00<007ooOol06Woo0P000SB;00<004C;A</03DC;0P004E5=00<0
05V_FJl00UV_00<007ooOol0Bgoo00<007ooOol03Goo00<007ooOol03Woo000>Ool00`00Oomoo`0M
Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00=8/dR`02=8/00`00A<]4b`0<A</00`00DDd0000@
DDd00`00FJmI[`04FJl00`00Oomoo`1:Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool000ioo`03001o
ogoo00aoo`8000moo`03001oogoo009oo`03001oogoo01Moo`8000DdR`030014bdC;00a4b`80011A
C@03001I[eV_00II[`8004]oo`03001oogoo00aoo`03001oogoo00ioo`003Woo00<007ooOol02Woo
0P000Ud50`0037oo00<007ooOol00Woo00<007ooOol05Goo0P001cB;00<004C;A</02dC;00<0055=
00003e5=00<005V_FJl02EV_00<007ooOol0B7oo00<007ooOol037oo00<007ooOol03Woo000>Ool0
0`00Oomoo`08Ool20005G@D4000:Ool00`00Oomoo`02Ool00`00Oomoo`0COol20009=8/00`00A<]4
b`0;A</2000>DDd2000=FJl20018Ool00`00Oomoo`0<Ool00`00Oomoo`0>Ool000ioo`03001oogoo
00Moo`8000QM1@800003=00007oo00Moo`03001oogoo009oo`03001oogoo019oo`03000dRcB;00Td
R`030014bdC;00Y4b`03001AC@0000eAC@03001I[eV_00mI[`03001oogoo04Eoo`03001oogoo00eo
o`03001oogoo00eoo`003Woo00<007ooOol01Woo00<0067>HLh00P0025d510001Woo00<007ooOol0
0Woo00<007ooOol047oo0P0033B;00<004C;A</024C;10003E5=00<005V_FJl04EV_00<007ooOol0
A7oo00<007ooOol03Goo00<007ooOol03Goo000>Ool00`00Oomoo`06Ool00`00HLiQcP02HLh20008
G@D01000=000000017oo00<007ooOol00Woo00<007ooOol03Woo0P003SB;00<004C;A</014C;1000
0e7D1@00255=00<005V_FJl04eV_0P00A7oo00<007ooOol03Goo00<007ooOol03Goo000>Ool00`00
Oomoo`05Ool00`00HLiQcP05HLh20007G@D200001C@0001oogoo00001Goo00<007ooOol03Goo00<0
03B;=8/03SB;00<004C;A</01@001E7D00<0057DDM@00e7D10000e5=00<005V_FJl05UV_00<007oo
Ool0@Goo00<007ooOol03Goo00<007ooOol03Goo000>Ool00`00Oomoo`05Ool00`00HLiQcP07HLh2
0007G@D50005Ool00`00Oomoo`0<Ool00`00;6`0000>=8/40005DM@5000:DM@3000GFJl200000ehA
001oo`11Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Aoo`03001QcV7>00YQ
cP<000IM1@@000Aoo`03001oogoo00]oo`04000/K2a/000;=8/3000=DM@4000:DM@2000CFJl20003
GQ400`00Oomoo`10Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool000ioo`03001oogoo00Aoo`03001Q
cV7>00eQcP8000IM1@@0009oo`03001oogoo00]oo`05000/K2a/;6`00008=8/2000?DM@00`00DMAA
e002DM@00`00DMAAe009DM@00`00FJmI[`0>FJl20006GQ400`00Oomoo`0oOol00`00Oomoo`0=Ool0
0`00Oomoo`0=Ool000ioo`03001oogoo00=oo`03001QcV7>011QcP8000IM1@D000aoo`03000/K2a/
008/K003000dRcB;00@dR`80015Ae003001Ae57D00=Ae003001Ae57D00UAe003001I[eV_00]I[`80
00QN4@03001oogoo019oo`D002Qoo`03001oogoo00eoo`03001oogoo00eoo`003Woo00<007ooOol0
0goo0P004f7>0P000Ud50P000Wl@0`002goo00<002a/;6`012a/00@003B;=8/dR`80019Ae003001A
e57D00EAe08000YAe08000UI[`8000]N4@03001oogoo00aoo`D000EAe0D002=oo`03001oogoo00eo
o`03001oogoo00eoo`003Woo00<007ooOol00goo00<0068b00000`004F7>0P001Wl@0P0027oo1000
1Ra/0`00557D00<0057DDM@01e7D00<0057DDM@02E7D00<005V_FJl015V_0P003EhA00<007ooOol0
1Woo1P003e7D1@007Woo00<007ooOol03Goo00<007ooOol03Goo000>Ool00`00Oomoo`03Ool00`00
HS9R<P03HS84000>HLh00`00Oa1o4004Oa020009Ool00`00;6`00006;6`00`00DMAAe00CDM@00`00
DMAAe009DM@00`00DMAAe009DM@20002FJl2000@GQ400`00Oomoo`05000JDM@5000IOol00`00Oomo
o`0=Ool00`00Oomoo`0=Ool000ioo`03001oogoo00=oo`03001R<V8b00MR<P<000YQcP03001o47l@
00Eo4003001o400000Moo`03000/K00000H/K003001Ae57D01=Ae003001Ae57D00]Ae003001Ae57D
00YAe080019N4@<002AAe0<001Ioo`03001oogoo00eoo`03001oogoo00eoo`003Woo00<007ooOol0
0goo00<0068bHS800V8b0P001V8b10001V7>00<007l@Oa001Gl@00<007l@00001Woo1@0012a/00<0
057DDM@0557D00<0057DDM@02e7D0P002e7D00<005hAGQ403ehA0P00:U7D0P0057oo00<007ooOol0
3Goo00<007ooOol03Goo000>Ool00`00Oomoo`03Ool00`00HS9R<P03HS800`00HS9R<P08HS840000
0f7>001o4007Oa001000Oa1o400017oo00<002a/;6`01Ra/00<0057D0000557D00<0057DDM@03E7D
0P002e7D00<005hAGQ4035hA0P00;U7D00<007ooOol04Goo00<007ooOol03Goo00<007ooOol03Goo
000>Ool00`00Oomoo`02Ool00`00HS9R<P04HS800`00HS9R<P0<HS820008Oa001000Oa1o47l@17oo
00<002a/;6`01Ba/00D0057DDMAAe00001=Ae003001Ae57D00eAe003001YP00000YAe003001N4EhA
00]N4@03001Ae57D02mAe003001oogoo011oo`03001oogoo00eoo`03001oogoo00eoo`003Woo00<0
07ooOol00Woo00<0068bHS800f8b00<0068b00003V8b00<007l@Oa001Wl@00D007l@Oa1o4000009o
o`03000/K2a/00H/K003001Ae57D009Ae003001Ae57D00mAe003001Ae57D00mAe003001YP00000YA
e003001N4EhA00QN4@8003=Ae080011oo`03001oogoo00eoo`03001oogoo00eoo`003Woo00<007oo
Ool00Woo00<0068bHS800f8b00<0068b00003V8b00<007l@Oa001Wl@00L007l@Oa1o4000Ool00008
;6`00`00DMAAe004DM@00`00DMAAe00>DM@00`00DMAAe00?DM@01000JH1YP0002E7D00<005hAGQ40
1ehA00<0057DDM@0=E7D00<007ooOol03Goo00<007ooOol03Goo00<007ooOol03Goo000>Ool00`00
Oomoo`02Ool00`00HS9R<P02HS8200000f8b00000006HS800`00HS9R<P04HS800`00Oa1o4006Oa00
0`00Oa1o4002Oa000`00;6`/K006;6`00`00DMAAe006DM@00`00DMAAe002DM@20008DM@00`00DMAA
e00ADM@01000JH1YP0002E7D00<005hAGQ4015hA0P00>E7D0P003Goo00<007ooOol03Goo00<007oo
Ool03Goo000>Ool00`00Oomoo`02Ool00`00HS9R<P0>HS800`00HS9R<P02HS800`00Oa1o4007Oa00
0`00Oa1o4002Oa000`00;6`/K005;6`00`00DMAAe008DM@00`00DMAAe003DM@00`00DMAAe005DM@0
0`00DMAAe00ADM@01000JH1YP0002E7D00<005hAGQ400UhA0P00?E7D00<007ooOol02Woo00<007oo
Ool03Goo00<007ooOol03Goo000>Ool00`00Oomoo`02Ool00`00HS9R<P0?HS801@00HS9R<V8b0000
27l@00<007l@Oa0017l@00<002a/;6`012a/00<0057DDM@02E7D00D0057DDMAAe00000MAe003001A
e57D00IAe08000]Ae004001YP6V00009DM@01000GQ5N4@00@57D0P002Woo00<007ooOol03Goo00<0
07ooOol03Goo000>Ool00`00Oomoo`02Ool6000=HS8200000f8b001o4007Oa000`00Oa1o4004Oa05
00000ba/001Ae00<DM@20002DM@00`00DMAAe003DM@00`00DMAAe009DM@30008DM@200000fV0001A
e008DM@30013DM@00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool000eoo`03001oogoo
00=oo`03001RMF9e00=RM@/000AR<P8000=o40<0009o4003001o47l@00Eo40@X[`8000mAe003001A
e00000EAe003001Ae57D00aAe0<000EAe005001nk@00JH000007DM@20016DM@00`00Oomoo`06Ool0
0`00Oomoo`0=Ool00`00Oomoo`0=Ool000eoo`03001oogoo00=oo`03001RMF9e00iRM@H000=o4003
001o47l@009o4003001o47l@00Eo40DX[`03001Ae57D00iAe003001Ae57D00=Ae003001Ae57D011A
e0<0009Ae003001nkGk]008000IAe003001Ae57D04MAe08000Ioo`03001oogoo00eoo`03001oogoo
00eoo`003Goo00<007ooOol00goo00<0069eHWD04f9e0P000gl@00D007l@Oa1o400000Mo4005000X
[bR_::l0000BDM@00`00DMAAe002DM@00`00DMAAe006DM@@0003O^d20004DM@00`00DMAAe01:DM@0
0`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0=Ool000eoo`03001oogoo00=oo`03001RMF9e
01=RM@03001o4000009o4005001o47l@Oa000007Oa001@00::lX[bR_00004e7D00@0057DDM@000]A
e0P00006DM@00000001Ae00017k]00D0057DDMAAe00004iAe003001oogoo009oo`03001oogoo00eo
o`03001oogoo00eoo`003Goo00<007ooOol00goo00<0069eHWD04f9e00<007l@Oa000P0000Eo4000
Oa1o400000Mo4005000X[bR_::l0000DDM@00`00DM@00002DM@90007DM@30004DM@00`00O^enk@02
O^d01000DMAAe000CU7D00<007ooOol00goo00<007ooOol03Goo00<007ooOol037oo000=Ool00`00
Oomoo`03Ool00`00HWERM@0CHWD01000Oa1o47l@0P000gl@00<007l@Oa001Gl@00D002R_::lX[`00
015Ae0P000iAe0@000EAe003001nkGk]009nk@03001Ae000051Ae003001oogoo009oo`03001oogoo
00eoo`03001oogoo00aoo`003Goo00<007ooOol00goo00<0069eHWD04f9e00<007l@Oa000gl@00@0
07l@Oa0000Qo4003000X[`0000YAe0P000EAe08000eAe0800003DM@0057D00IAe003001nkGk]009n
k@80055Ae08000=oo`03001oogoo00eoo`03001oogoo00aoo`003Goo00<007ooOol00goo00<0069e
HWD04f9e00<007l@Oa0017l@00<007l@000027l@00@002R_001Ae0T000mAe08000aAe08000QAe003
001nkGk]009nk@03001Ae57D055Ae005001oogooOol0000?Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo00=oo`03001RMF9e01=RM@03001o47l@00Eo408000Ao40P001YAe08000UAe003001Ae57D00QA
e006001nkGk]001nk@00E57D00@007ooOol000moo`03001oogoo00aoo`003Goo00<007ooOol00goo
00<0069eHWD04f9e00<007l@Oa001Wl@1@0017l@00<002R_00007E7D0P001E7D0P002e7D0`0000=n
k@00DM@0E57D0P0000=oo`00Ool03Woo00<007ooOol037oo000=Ool00`00Oomoo`03Ool00`00HWER
M@0CHWD00`00Oa1o400?Oa000`00::l0000ODM@20002DM@00`00DMAAe00:DM@00`00OgD00002001G
DM@00`00Ool0000?Ool00`00Oomoo`0<Ool000eoo`03001oogoo00=oo`03001RMF9e00iRM@H0015o
4003000X[`00025Ae08000eAe0800003OgD0000005MAe0<000moo`03001oogoo00aoo`003Goo00<0
07ooOol00goo00<0069eHWD00f9e2`001F:g00<007l@Oa003gl@0`008e7D0P002e7D00@007meOgD0
05UAe08000moo`03001oogoo00aoo`003Goo00<007ooOol00goo1P0046:g00<007l@Oa003gl@0`00
9E7D0P00257D00@007meOgD005YAe08000moo`03001oogoo00aoo`003Goo00<007ooOol00goo00<0
06:gH[L056:g00<007l@Oa003Wl@0`009e7D0P001U7D00<007me0000G57D0P003Woo00<007ooOol0
37oo000=Ool00`00Oomoo`03Ool00`00H[MR]`0DH[L00`00Oa1o400>Oa03000YDM@20004DM@2001M
DM@2000>Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Aoo`03001R]f:g01=R]`03001o47l@00io
40<002]Ae080009Ae08005eAe0<000eoo`03001oogoo00aoo`003Goo00<007ooOol017oo00<006:g
H[L04f:g00<007l@Oa003Wl@0`00;E7D0`00GU7D00<0057D00003Goo00<007ooOol037oo000=Ool0
0`00Oomoo`04Ool00`00H[MR]`0DH[L00`00Oa1o400=Oa0200000e7D001Ae00/DM@4001LDM@01000
DM@0000037oo00<007ooOol037oo000=Ool00`00Oomoo`04Ool00`00H[MR]`0DH[L00`00Oa1o400=
Oa0200000e7D001Ae00[DM@20003DM@2000?DM@00`00DMAAe018DM@01000DMAAe00037oo00<007oo
Ool037oo000=Ool00`00Oomoo`04Ool00`00H[MR]`0CH[L2000?Oa020002DM@00`00DMAAe00XDM@2
0006DM@2000>DM@00`00DMAAe017DM@00`00DMAAe002000;Ool00`00Oomoo`0<Ool000eoo`03001o
ogoo00Eoo`03001R]f:g00mR]`<00003I_T007l@00eo4003000]4`00009Ae003001Ae57D02MAe003
001c^P0000QAe08000aAe003001Ae57D04MAe003001Ae57D00<000Yoo`03001oogoo00aoo`003Goo
00<007ooOol01Goo00<006:gH[L036:g0`001FKi00<007l@Oa002gl@00<002dC00000e7D00<0057D
DM@09E7D00@007>jLkX000YAe08000]Ae003001Ae57D00@0049Ae006001Ae57D001jb0002Woo00<0
07ooOol037oo000=Ool00`00Oomoo`05Ool00`00H[MR]`09H[L30008I_T00`00Oa1o400;Oa000`00
;A<00004DM@00`00DMAAe00TDM@00`00LkX0000=DM@20002DM@00`00DMAAe005DM@01P00DMAAe000
DM@0049Ae004001Ae57D0002N/P00`00Oomoo`07Ool00`00Oomoo`0<Ool000eoo`03001oogoo00Eo
o`03001R]f:g00IR]`<000aVn@03001o47l@00Yo4003000]4`0000AAe003001Ae57D02=Ae004001c
^W>j000?DM@50005DM@01@00DM@0057D0000@e7D00@0057DDM@0009jb003001oogoo00Moo`03001o
ogoo00aoo`003Goo00<007ooOol01Woo00<006:gH[L00V:g0`003fKi00<007l@Oa002Wl@00<002dC
00001E7D00<0057DDM@08E7D00D007>jLkYc^P00019Ae0@000AAe0D000=Ae003001Ae57D03aAe005
001Ae57DDM@00002N/P00`00Oomoo`06Ool00`00Oomoo`0<Ool000aoo`03001oogoo00Moo`03001R
]`00008001=Vn@03001o47l@00Uo40800003>GD0057D00AAe003001Ae57D01mAe005001c^W>jLkX0
000EDM@30003DM@00`00DMAAe006DM@00`00DMAAe00kDM@01@00DMAAe57D00000W[800<007ooOol0
1Woo00<007ooOol037oo000<Ool00`00Oomoo`07Ool2000FI_T00`00Oa1o4008Oa020002>GD00`00
DMAAe004DM@00`00DMAAe00LDM@200001F>M001c^W>j00005U7D10000U7D00<0057DDM@01U7D00<0
057DDM@00U7D0`00=E7D00D0057DDMAAe000009jb003001oogoo00Ioo`03001oogoo00aoo`0037oo
00<007ooOol01goo00<006KiI_T04fKi0P0000=WF`00Oa0027l@00<003Ue>GD00SUe00<0057DDM@0
157D0P006U7D0P0016>M0P006E7D100000=Ae000DM@01e7D00<0057DDM@00U7D00<0057DDM@0=57D
00D0057DDMAAe000009jb003001oogoo00Ioo`03001oogoo00aoo`0037oo00<007ooOol027oo00<0
06KiI_T046Ki0P0016MK00<007l@Oa001Gl@00<003Ue>GD00cUe00<0057DDM@01E7D0P005e7D0P00
1f>M00<0057DDM@06E7D10002E7D00<0057D00000`00=E7D00D0057DDMAAe000009jb003001oogoo
00Ioo`03001oogoo00aoo`0037oo00<007ooOol027oo00<006KiI_T03VKi0P001VMK00<007l@Oa00
1Gl@00<003Ue>GD013Ue00<0057DDM@01E7D0P00557D0P002F>M00<0057DDM@03e7D3`002E7D0P00
00=Ae000DM@0=E7D00D0057DDMAAe000009jb003001oogoo00Moo`03001oogoo00]oo`0037oo00<0
07ooOol02Goo00<006KiI_T036Ki00<006MKIe/01fMK00<007l@Oa000gl@00<003Ue>GD01CUe00<0
057DDM@01U7D10003U7D0`002V>M00<0057DDM@0:57D00@0057D000003IAe005001Ae57DDM@00003
N/P00`00Oomoo`06Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Uoo`03001VnFKi00YVn@8000]W
F`80009o4003000iMCUe00LiM@03001Ae57D00IAe08000036Yh00000008000EAe0D000=;G`03001S
WF>M00MSW@03001Ae57D02UAe003001Ae00003MAe004001Ae57D0003N/P00`00Oomoo`06Ool00`00
Oomoo`0;Ool000aoo`03001oogoo00Yoo`03001VnFKi00MVn@8000aWF`03001WgFOM008000XiM@03
001Ae57D00QAe003000JWQZN008JWPD000U;G`03001SWF>M00ISW@03001Ae57D02YAe003001Ae57D
03IAe004001Ae57D0003N/P00`00Oomoo`06Ool00`00Oomoo`0;Ool000aoo`03001oogoo00Yoo`03
001VnFKi00IVn@03001WFfMK00YWF`8000=Wg@03000iMCUe00XiM@03001Ae57D00QAe08000DJWP03
001;Gd]O00U;G`03001SWF>M00ASW@03001Ae57D025Ae08000UAe003001Ae57D03EAe004001Ae57D
0003N/P00`00Oomoo`06Ool00`00Oomoo`0;Ool000aoo`03001oogoo00]oo`03001VnFKi00=Vn@80
00aWF`03001WgFOM009Wg@03000iMCUe00/iM@03001Ae57D00UAe08000DJWP03001;Gd]O00U;G`03
001SWF>M009SW@8002AAe003001Ae57D00QAe003001Ae57D03AAe005001Ae57DDM@00002N/P00`00
Oomoo`06Ool00`00Oomoo`0;Ool000aoo`03001oogoo00]oo`04001VnFKiI_T2000=Ie/01000ImeW
gFOM0P003cUe00<0057DDM@02U7D0P0011ZN00<004]OBel02D]O00H006>M0000057D000TDM@00`00
DMAAe009DM@00`00DMAAe00cDM@01@00DMAAe57D00000W[800<007ooOol01Woo00<007ooOol02goo
000<Ool00`00Oomoo`0<Ool3000=Ie/20003Imd3000>>GD00`00@OL0000=DM@300026Yh00`00Bem;
G`07Bel30002DM@00`00DMAAe00RDM@00`00DM@0000;DM@2000cDM@01@00DMAAe57D00000W[800<0
07ooOol01Woo00<007ooOol02goo000<Ool00`00Oomoo`0<Ool00`00Ie]WF`0<Ie/00`00ImeWg@02
Imd200000goo000iM@0=>GD01000@OM1m`003e7D10000d]O1@001E7D00<0057DDM@08U7D00<0057D
00002U7D00<0057DDM@00P00<E7D00D0057DDMAAe000009jb003001oogoo00Ioo`03001oogoo00]o
o`0037oo00<007ooOol03Goo00<006MKIe/02VMK00<006OMImd00VOM0P000goo00<003Ue>GD02SUe
00<0047g@OL00T7g00<0057DDM@03e7D10002U7D00<0057DDM@08E7D0P0000=Ae00000002E7D00<0
057DDM@00U7D0P00;e7D00D0057DDMAAe000009jb003001oogoo00Ioo`03001oogoo00]oo`0037oo
00<007ooOol03Woo00<006MKIe/01fMK0P0016OM0P0017oo00<003Ue>GD02SUe00<0047g@OL00d7g
0P007E7D00<0057DDM@0;U7D00<0057DDM@01E7D0P00;E7D00D0057DDMAAe000009jb003001oogoo
00Ioo`03001oogoo00]oo`0037oo00<007ooOol03goo00<006MKIe/01FMK00<006OMImd00fOM0P00
1Woo00<003Ue>GD023Ue00<0047g@OL01T7g00<0057DDM@06U7D00<0057DDM@0;U7D00<0057DDM@0
1e7D0P00:e7D00@0057DDMAAe080009jb003001oogoo00Eoo`03001oogoo00]oo`0037oo00<007oo
Ool03goo00<006MKIe/016MK00<006OMImd00fOM0P001goo00<003Ue>GD01cUe00<0047g@OL0247g
00<0057DDM@06E7D00<0057DDM@0;E7D00<0057DDM@02U7D0P00:E7D00H0057DDM@007nC0002N/P0
0`00Oomoo`05Ool00`00Oomoo`0;Ool000aoo`03001oogoo011oo`04001WFfMKIe/20004Imd40008
Ool00`00>GDiM@06>GD00`00@OM1m`09@OL00`00DMAAe00HDM@00`00DMAAe00]DM@00`00DMAAe00<
DM@2000WDM@01000DMAAe0000WnC00<007[800001goo00<007ooOol02goo000<Ool00`00Oomoo`0A
Ool00`00Ie/00005Imd300000goo001oo`07Ool00`00>GDiM@05>GD00`00@OM1m`0;@OL2000HDM@0
0`00DMAAe00/DM@00`00DMAAe00?DM@2000UDM@01000DMAAe0000gnC0P001goo00<007ooOol02goo
000<Ool00`00Oomoo`0BOol30003Imd20003Ool00`00Oomoo`07Ool00`00>GDiM@04>GD00`00@OM1
m`0;@OL00`00BSP00003000@DM@5000^DM@00`00DMAAe00ADM@3000RDM@01000DMAAe0000gnC0P00
1goo00<007ooOol02goo000<Ool00`00Oomoo`0EOol30005Ool00`00Oomoo`07Ool00`00>GDiM@03
>GD00`00@OM1m`0<@OL00`00BSQ:>003BSP40006DM@60003DUP2000]DM@00`00DMAAe00EDM@2000P
DM@00`00DM@00005Oi<00`00Oomoo`05Ool00`00Oomoo`0;Ool000aoo`03001oogoo01eoo`03001o
ogoo00Qoo`05000iMCUe>GD0000>@OL00`00BSQ:>008BSP6000:DUP00`00DMAAe00[DM@00`00DMAA
e00GDM@2000NDM@00`00DM@00005Oi<00`00Oomoo`05Ool00`00Oomoo`0;Ool000aoo`03001oogoo
01eoo`03001oogoo00Qoo`05000iMCUe>GD0000>@OL00`00BSQ:>00:BSP00`00DUQBF00;DUP00`00
DMAAe00ZDM@00`00DMAAe00JDM@2000LDM@00`00DM@00004Oi<00`00Oomoo`06Ool00`00Oomoo`0;
Ool000aoo`03001oogoo01eoo`03001oogoo00Uoo`03000iM@0000m1m`03001:>4Xh00Y:>003001B
F59H00aBF003001Ae57D02UAe003001Ae57D01aAe08001YAe003001Ae00000AoT`03001oogoo00Io
o`03001oogoo00]oo`0037oo00<007ooOol07Goo00<007ooOol02Goo00<003Ue00003d7g00<004Xh
BSP02TXh00<0059HDUP0359H00<0057DDM@0:57D00<0057DDM@07e7D0P00657D0P001GnC00<007oo
Ool01Woo00<007ooOol02goo000;Ool00`00Oomoo`0NOol00`00Oomoo`0:Ool00`00@OM1m`0>@OL0
0`00BSQ:>00:BSP00`00DUQBF00<DUP00`00DMAAe00WDM@00`00DMAAe00RDM@2000FDM@20005Oi<0
0`00Oomoo`06Ool00`00Oomoo`0;Ool000]oo`03001oogoo01ioo`03001oogoo00]oo`030011md7g
00a1m`03001:>4Xh00]:>003001BF59H00aBF003001Ae57D02MAe003001Ae57D02AAe0<000mAe004
001Ae57DDM@20004Oi<00`00Oomoo`07Ool00`00Oomoo`0;Ool000]oo`03001oogoo01ioo`03001o
ogoo00aoo`030011md7g00]1m`03001:>4Xh00a:>003001BF59H00]BF003001Ae57D02IAe003001A
e57D02QAe08000iAe004001Ae57D0005Oi<00`00Oomoo`07Ool00`00Oomoo`0;Ool000]oo`03001o
ogoo01eoo`03001oogoo00ioo`8000]1m`03001:>4Xh00a:>003001BF59H00]BF003001Ae57D02IA
e003001Ae57D02YAe08000aAe004001Ae57D0005Oi<00`00Oomoo`07Ool00`00Oomoo`0;Ool000]o
o`03001oogoo01eoo`03001oogoo011oo`030011md7g00Q1m`03001:>4Xh00a:>003001BF59H00]B
F003001Ae57D02EAe003001Ae57D02eAe08000]Ae003001Ae00000AoT`03001oogoo00Uoo`03001o
ogoo00Yoo`002goo00<007ooOol07Goo00<007ooOol04Goo00<0047g@OL01T7g00<004XhBSP03DXh
00<0059HDUP02e9H00<0057DDM@09E7D00<0057DDM@0;e7D0P000U7D00<0057DDM@01E7D0P0017nC
00<007ooOol02Goo00<007ooOol02Woo000;Ool00`00Oomoo`0MOol00`00Oomoo`0BOol00`00@OM1
m`05@OL00`00BSQ:>00=BSP00`00DUQBF00;DUP00`00DMAAe00TDM@00`00DMAAe00bDM@200000e7D
00000005DM@20004Oi<00`00Oomoo`09Ool00`00Oomoo`0:Ool000]oo`03001oogoo01eoo`03001o
ogoo01=oo`030011md7g00A1m`03001:>4Xh00e:>003001BF59H00]BF003001Ae57D02AAe003001A
e57D03AAe0800003DM@0000000=Ae08000AoT`03001oogoo00Uoo`03001oogoo00Yoo`002goo00<0
07ooOol07Goo00<007ooOol057oo00<0047g@OL00d7g00<004XhBSP03DXh00<0059HDUP02e9H00<0
057DDM@08e7D00<0057DDM@0=e7D0P0000MAe000001Ae000Oi<00002Oi<00`00Oomoo`0:Ool00`00
Oomoo`0:Ool000]oo`03001oogoo01eoo`03001oogoo01Eoo`8000=1m`03001:>4Xh00e:>003001B
F59H00aBF003001Ae57D029Ae003001Ae57D03UAe0D00005Oi<00000Oi<0000<Ool00`00Oomoo`0:
Ool000]oo`03001oogoo01eoo`03001oogoo01Moo`030011m`00011:>003001BF59H00aBF003001A
e57D025Ae003001Ae57D03]Ae0H00003Oi<0000000aoo`03001oogoo00Yoo`002goo00<007ooOol0
7Goo00<007ooOol067oo0P0044Xh00<0059HDUP03E9H00<0057DDM@07e7D00<0057DDM@0?U7D1P00
3Goo00<007ooOol02Woo000;Ool00`00Oomoo`0MOol00`00Oomoo`0IOol3000?BSP00`00DUQBF00<
DUP00`00DMAAe00ODM@00`00DMAAe00mDM@01000LmX007nC100037oo00<007ooOol02Woo000;Ool0
0`00Oomoo`0MOol00`00Oomoo`0LOol4000;BSP00`00DUQBF00=DUP00`00DMAAe00MDM@00`00DMAA
e00gDM@@000;Ool00`00Oomoo`0:Ool000]oo`03001oogoo01eoo`03001oogoo021oo`D000I:>003
001BF59H00QBF0H001mAe003001Ae57D03eAe004001cfW?JLmX200000gnC001oo`0<Ool00`00Oomo
o`0:Ool000]oo`03001oogoo01eoo`03001oogoo02Eoo`@0009:>004001BF59HDUP70006Ool00`00
DMAAe00KDM@00`00DMAAe00mDM@00`00LmYcfP03LmX00`00Oi=oo`0=Ool00`00Oomoo`0:Ool000]o
o`03001oogoo01eoo`03001oogoo02Uoo`H000eoo`03001Ae57D01]Ae003001Ae57D03aAe003001c
fW?J00AcfP8000ioo`03001oogoo00Yoo`002goo00<007ooOol07Goo00<007ooOol0?Goo00<0057D
DM@06E7D00<0057DDM@0?57D00<007?JLmX01G?J00<007ooOol03Goo00<007ooOol02Woo000;Ool0
0`00Oomoo`0MOol00`00Oomoo`0mOol00`00DMAAe00IDM@00`00DMAAe00kDM@00`00LmYcfP05LmX2
000?Ool00`00Oomoo`0:Ool000]oo`03001oogoo01eoo`03001oogoo03ioo`03001Ae57D01MAe003
001Ae57D03]Ae003001cfW?J00IcfP8000Aoo`04001oogoo0007Ool00`00Oomoo`0:Ool000]oo`03
001oogoo01eoo`03001oogoo03ioo`03001Ae57D01MAe003001Ae57D03]Ae003001cfW?J00EcfP03
001oo`0000Eoo`8000Qoo`03001oogoo00Yoo`002goo00<007ooOol07Goo00<007ooOol0?goo00<0
057DDM@05E7D00<0057DDM@0>e7D00<007?JLmX01G?J00@007ooOol000Eoo`8000Qoo`03001oogoo
00Yoo`002goo00<007ooOol07Goo00<007ooOol0?goo00<0057DDM@05E7D00<0057DDM@0>U7D00<0
07?JLmX01G?J00D007ooOomoo`0000Aoo`04001oogoo0007Ool00`00Oomoo`0:Ool000]oo`03001o
ogoo01eoo`03001oogoo041oo`03001Ae57D01=Ae003001Ae57D03YAe003001cfW?J00EcfP03001o
ogoo009oo`03001oogoo00eoo`03001oogoo00Yoo`002goo00<007ooOol07Goo00<007ooOol0@7oo
00<0057DDM@04U7D00<0057DDM@0>U7D00<007?JLmX01G?J00<007ooOol00goo00<007ooOol03Goo
00<007ooOol02Woo000;Ool00`00Oomoo`0MOol00`00Oomoo`11Ool00`00DMAAe00ADM@00`00DMAA
e00iDM@00`00LmYcfP06LmX00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool000Yoo`03
001oogoo01ioo`03001oogoo049oo`03001Ae57D00mAe003001Ae57D03YAe003001cfW?J00EcfP03
001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Yoo`002Woo00<007ooOol07Woo00<007ooOol0
@goo0P003e7D00<0057DDM@0>E7D00<007?JLmX01G?J00<007ooOol01Goo00<007ooOol03Goo00<0
07ooOol02Woo000:Ool00`00Oomoo`0NOol00`00Oomoo`15Ool00`00DMAAe00;DM@00`00DMAAe00i
DM@00`00LmYcfP05LmX00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool000Yoo`03001o
ogoo01ioo`03001oogoo04Ioo`03001Ae57D00YAe003001Ae57D03MAe0800003Gmh007?J00AcfP03
001oogoo00Moo`03001oogoo00ioo`03001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol0
Agoo00<0057DDM@00U7D00<0057DDM@00e7D00<0057DDM@0=U7D0P0015oN00D007?JLmYcfP0000Yo
o`03001oogoo00ioo`03001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol0B7oo00D0057D
DMAAe000009Ae004001Ae57D000gDM@00`00GmiOgP04Gmh01@00LmYcfW?J00002Woo00<007ooOol0
3Woo00<007ooOol02Goo000:Ool00`00Oomoo`0NOol00`00Oomoo`19Ool200001e7D001Ae57D001A
e00003IAe08000QOgP03001cfP0000]oo`03001oogoo00ioo`03001oogoo00Uoo`002Woo00<007oo
Ool07Woo00<007ooOol0>Goo10003Woo0P0000EAe000DMAAe000031Ae080009Ae08000]OgP03001o
ogoo00Yoo`03001oogoo00ioo`03001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol0>Woo
00<007oo000017oo00<007ooOol01Woo00L007oo001Ae000DM@0000cDM@2000;Gmh2000=Ool00`00
Oomoo`0>Ool00`00Oomoo`09Ool000Yoo`03001oogoo01ioo`03001oogoo03Uoo`03001oo`0000Io
o`03001oogoo00Aoo`03001oo`0000<00005DM@0057DDM@00003DM@00`00DMAAe00YDM@2000015oN
000000001UoN0P003goo00<007ooOol03Woo00<007ooOol02Goo000:Ool00`00Oomoo`0NOol00`00
Oomoo`0iOol40006Ool20006Ool50002DM@00`00DMAAe002000ZDM@20006Gmh300000eoN0000000B
Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03001oogoo01ioo`03001oogoo04Eoo`04001o
ogooOol3000017oo000007oo0P000U7D00<0057DDM@0:E7D00<005oNGmh02EoN0P004goo00<007oo
Ool03Goo00<007ooOol02Goo000:Ool00`00Oomoo`0MOol00`00Oomoo`17Ool01`00Oomoo`00Ool0
07oo00800003Ool00000008002YAe180015oo`03001oogoo00eoo`03001oogoo00Uoo`002Woo00<0
07ooOol07Goo00<007ooOol0B7oo1@0000Aoo`00Ool0009oo`D002EAe1<0019oo`03001oogoo00eo
o`03001oogoo00Uoo`002Woo00<007ooOol07Goo00<007ooOol0BWoo00<007oo00000`000Woo00@0
07ooOol0008>G@@001MAe0X000YOgP@00003Ool0000001Aoo`03001oogoo00eoo`03001oogoo00Uo
o`002Woo00<007ooOol07Goo00<007ooOol0Bgoo0`0000Aoo`00000000Aoo`8000@>G@@000]Ae0h0
00A3G`03001OgUoN009OgPL0009oo`03001oogoo01Aoo`03001oogoo00eoo`03001oogoo00Uoo`00
2Woo00<007ooOol07Goo00<007ooOol0C7oo100027oo00<000iM3Ud01@iM4P000T=O3P001U7D0`00
5goo00<007ooOol03Goo00<007ooOol02Goo000:Ool00`00Oomoo`0MOol00`00Oomoo`1<Ool30006
Ool<00033Ud@000DDM@01000O``000005Woo00<007ooOol03Goo00<007ooOol02Goo000:Ool00`00
Oomoo`0MOol00`00Oomoo`1<Ool200000goo000000040004Ool>000ODM@30003O``00`00Oomoo`03
Ool01000Oomoo`0037oo00<007ooOol03Goo00<007ooOol02Goo000:Ool00`00Oomoo`0MOol00`00
Oomoo`1<Ool=000[DM@20002DM@00`00O`ao3002O``00`00Oomoo`03Ool2000=Ool00`00Oomoo`0=
Ool00`00Oomoo`09Ool000Yoo`03001oogoo01eoo`03001oogoo03ioo`h000=Ae003001Ae57D035A
e003001Ae57D009Ae003001o37l<009o3003001oogoo00=oo`8000eoo`03001oogoo00eoo`03001o
ogoo00Uoo`002Woo00<007ooOol07Goo00<007ooOol0<Goo3@004E7D00<0057DDM@0=U7D00<007l<
O``00Wl<00<007ooOol00Woo00@007ooOol000aoo`03001oogoo00eoo`03001oogoo00Uoo`002Woo
00<007ooOol07Goo00<007ooOol08goo3P00757D0`00>57D00<007l<O``00Wl<00<007ooOol04Woo
00<007ooOol03Goo00<007ooOol02Goo000:Ool00`00Oomoo`0MOol00`00Oomoo`0LOol7000[DM@2
000hDM@00`00O`ao3002O``00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`09Ool000Yoo`03
001oogoo01eoo`03001oogoo01aoo`03001Ae57D02mAe08003QAe003001o37l<009o3003001oogoo
019oo`03001oogoo00eoo`03001oogoo00Uoo`002Woo00<007ooOol07Goo00<007ooOol077oo00<0
057DDM@0;U7D00<0057D0000>E7D00D007l<O`ao300001Aoo`03001oogoo00eoo`03001oogoo00Uo
o`002Goo00<007ooOol07Woo00<007ooOol077oo00<0057DDM@0;U7D00<0057D0000>E7D00D007l<
O`ao300001Aoo`03001oogoo00eoo`03001oogoo00Uoo`002Goo00<007ooOol07Woo00<007ooOol0
77oo00<0057DDM@0;E7D0P0000=Ae0000000>57D00D007l<O`ao300001Aoo`03001oogoo00eoo`03
001oogoo00Uoo`002Goo00<007ooOol07Woo00<007ooOol077oo00<0057DDM@0<57D00<0057DDM@0
=e7D00D007l<O`ao300001Aoo`03001oogoo00eoo`03001oogoo00Uoo`002Goo00<007ooOol07Woo
00<007ooOol077oo00<0057DDM@0<57D00<0057DDM@0=e7D00D007l<O`ao300001Aoo`03001oogoo
00ioo`03001oogoo00Qoo`002Goo00<007ooOol07Woo00<007ooOol077oo00<0057DDM@0<57D00<0
057DDM@0=e7D00D007l<O`ao300001Aoo`03001oogoo00ioo`03001oogoo00Qoo`002Goo00<007oo
Ool07Woo00<007ooOol077oo00<0057DDM@0<57D00<0057DDM@0=e7D00D007l<O`ao300001Aoo`03
001oogoo00ioo`03001oogoo00Qoo`002Goo00<007ooOol07Woo00<007ooOol077oo00<0057DDM@0
<57D00<0057DDM@0=e7D00D007l<O`ao300001Aoo`03001oogoo00ioo`03001oogoo00Qoo`002Goo
00<007ooOol07Woo00<007ooOol077oo00<0057DDM@0<57D00<0057DDM@0=e7D00D007l<O`ao3000
01Aoo`03001oogoo00ioo`03001oogoo00Qoo`002Goo00<007ooOol07Woo00<007ooOol077oo00<0
057DDM@0<57D00<0057DDM@0<E7D1`000gl<00<007ooOol04Woo00<007ooOol03Woo00<007ooOol0
27oo0009Ool00`00Oomoo`0NOol00`00Oomoo`0LOol00`00DMAAe00`DM@00`00DMAAe00SDM@>0007
=cl01000O`ao300057oo00<007ooOol03Woo00<007ooOol027oo0009Ool00`00Oomoo`0NOol00`00
Oomoo`0LOol00`00DMAAe00`DM@00`00DMAAe00EDM@>000F=cl00`00O``0000DOol00`00Oomoo`0>
Ool00`00Oomoo`08Ool000Uoo`03001oogoo01ioo`03001oogoo01aoo`03001Ae57D031Ae003001A
e57D00QAe0d002Dg?`8001Eoo`03001oogoo00eoo`03001oogoo00Qoo`002Goo00<007ooOol07Woo
00<007ooOol077oo00<0057DDM@0;E7D3P00;3Lo20005Goo00<007ooOol03Goo00<007ooOol027oo
0009Ool00`00Oomoo`0NOol00`00Oomoo`0LOol00`00DMAAe00PDM@=0003=cl00`00=clg?`0U=cl?
000MOol00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo01ioo`03001oogoo01aoo`03
001Ae57D019Ae0h0010g?`03000g?cLo01Dg?a0002aoo`03001oogoo00eoo`03001oogoo00Qoo`00
2Goo00<007ooOol07Woo00<007ooOol077oo00<0057DDM@0157D3P007SLo00<003Lo=cl01SLo3`00
?7oo00<007ooOol03Goo00<007ooOol027oo0009Ool00`00Oomoo`0NOol00`00Oomoo`0LOol7000V
=cl?001;Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo01ioo`03001oogoo01eo
o`8001Xg?a0000Ioo`03001oogoo055oo`03001oogoo00eoo`03001oogoo00Qoo`002Goo00<007oo
Ool07Woo00<007ooOol07goo0P002CLo3`005Woo00<007ooOol0DGoo00<007ooOol03Goo00<007oo
Ool027oo0009Ool00`00Oomoo`0NOol00`00Oomoo`0QOol9000UOol00`00Oomoo`1AOol00`00Oomo
o`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo01ioo`03001oogoo04moo`03001oogoo055oo`03
001oogoo00eoo`03001oogoo00Qoo`002Goo00<007ooOol07Woo00<007ooOol0Cgoo00<007ooOol0
DGoo00<007ooOol03Goo00<007ooOol027oo0009Ool00`00Oomoo`0MOol00`00Oomoo`1@Ool00`00
Oomoo`1AOol00`00Oomoo`0=Ool00`00Oomoo`08Ool000Uoo`03001oogoo01eoo`03001oogoo051o
o`03001oogoo055oo`03001oogoo00eoo`03001oogoo00Qoo`002Goo00<007ooOol07Goo00<007oo
Ool0D7oo00<007ooOol0DGoo00<007ooOol03Goo00<007ooOol027oo0009Ool00`00Oomoo`0MOol0
0`00Oomoo`1@Ool00`00Oomoo`1AOol00`00Oomoo`0=Ool00`00Oomoo`08Ool000Qoo`03001oogoo
01ioo`03001oogoo051oo`03001oogoo055oo`03001oogoo00eoo`03001oogoo00Qoo`0027oo00<0
07ooOol07Woo00<007ooOol0D7oo00<007ooOol0DGoo00<007ooOol03Goo00<007ooOol027oo0008
Ool00`00Oomoo`0NOol00`00Oomoo`1@Ool00`00Oomoo`1AOol00`00Oomoo`0>Ool00`00Oomoo`07
Ool000Qoo`03001oogoo01ioo`03001oogoo051oo`03001oogoo055oo`03001oogoo00ioo`03001o
ogoo00Moo`0027oo00<007ooOol07Woo00<007ooOol0D7oo00<007ooOol0DGoo00<007ooOol03Woo
00<007ooOol01goo0008Ool00`00Oomoo`0NOol00`00Oomoo`1@Ool00`00Oomoo`1AOol00`00Oomo
o`0>Ool00`00Oomoo`07Ool000Qoo`03001oogoo01ioo`03001oogoo051oo`03001oogoo055oo`03
001oogoo00ioo`03001oogoo00Moo`0027oo00<007ooOol07Woo00<007ooOol0D7oo00<007ooOol0
DGoo00<007ooOol03Woo00<007ooOol01goo0008Ool00`00Oomoo`0NOol00`00Oomoo`1@Ool00`00
Oomoo`1AOol00`00Oomoo`0>Ool00`00Oomoo`07Ool000Qoo`03001oogoo01ioo`03001oogoo051o
o`03001oogoo055oo`03001oogoo00ioo`03001oogoo00Moo`0027oo00<007ooOol07Woo00<007oo
Ool0D7oo00<007ooOol0DGoo00<007ooOol03Woo00<007ooOol01goo0008Ool00`00Oomoo`0NOol0
0`00Oomoo`1@Ool00`00Oomoo`1AOol00`00Oomoo`0>Ool00`00Oomoo`07Ool000Qoo`03001oogoo
01ioo`03001oogoo051oo`03001oogoo055oo`03001oogoo00ioo`03001oogoo00Moo`0027oo00<0
07ooOol07Woo00<007ooOol0D7oo00<007ooOol0DWoo00<007ooOol03Goo00<007ooOol01goo0008
Ool00`00Oomoo`0NOol00`00Oomoo`1@Ool00`00Oomoo`1BOol00`00Oomoo`0=Ool00`00Oomoo`07
Ool000Qoo`03001oogoo01ioo`03001oogoo051oo`03001oogoo059oo`03001oogoo00eoo`03001o
ogoo00Moo`0027oo00<007ooOol07Woo00<007ooOol0D7oo00<007ooOol0DWoo00<007ooOol03Goo
00<007ooOol01goo0008Ool00`00Oomoo`0NOol00`00Oomoo`1>Ool00`00Ool0001DOol00`00Oomo
o`0=Ool00`00Oomoo`07Ool000Qoo`03001oogoo01ioo`03001oogoo04ioo`03001oo`0000Ioo`03
001oogoo04]oo`03001oogoo00eoo`03001oogoo00Moo`0027oo00<007ooOol07Woo00<007ooOol0
BWoo00L007ooOomoo`00Ool00005Ool00`00Oomoo`1<Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool0
00Qoo`03001oogoo01ioo`03001oogoo04Yoo`09001oogooOol007oo001oo`0000=oo`03001oogoo
04aoo`03001oogoo00eoo`03001oogoo00Moo`0027oo00<007ooOol07Woo00<007ooOol0Bgoo00@0
07ooOomoo`800005Ool007ooOol0001?Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool000Qoo`03001o
ogoo01ioo`03001oogoo04]oo`04001oogooOol200001Goo001oogoo0000Cgoo00<007ooOol03Goo
00<007ooOol01goo0008Ool00`00Oomoo`0NOol00`00Oomoo`1<Ool00`00Oomoo`030002Ool00`00
Oomoo`1>Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool000Qoo`03001oogoo01ioo`03001oogoo04ao
o`03001oogoo00<0009oo`03001oogoo04ioo`03001oogoo00eoo`03001oogoo00Moo`0027oo00<0
07ooOol07Woo00<007ooOol0CGoo00<007oo00000P0000=oo`00Ool0D7oo00<007ooOol03Goo00<0
07ooOol01goo0007Ool00`00Oomoo`0OOol00`00Oomoo`1=Ool00`00Ool0000200000goo001oo`18
Ool9000?Ool00`00Oomoo`07Ool000Moo`03001oogoo01moo`03001oogoo04ioo`D003Uooa4000Uo
o`03001oogoo00aoo`03001oogoo00Moo`001goo00<007ooOol07goo00<007ooOol0CWoo1@00:7oo
4@006goo0P003Goo00<007ooOol01Woo0007Ool00`00Oomoo`0OOol00`00Oomoo`1?Ool3000IOol@
000^Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool000Moo`03001oogoo01moo`03001oogoo04moo`<0
00Qooa4003moo`03001oogoo00Uoo`03001oogoo00Ioo`001goo00<007ooOol07goo00<007ooOol0
BGoo4@00DGoo00<007ooOol027oo00<007ooOol01Woo0007Ool00`00Oomoo`0NOol00`00Oomoo`0i
OolA0007Ool00`00Oomoo`1IOol00`00Oomoo`07Ool00`00Oomoo`06Ool000Moo`03001oogoo01io
o`03001oogoo02Qooa4007Eoo`8000Moo`03001oogoo00Ioo`001goo00<007ooOol07Woo00<007oo
Ool05goo4@00R7oo00<007ooOol017oo00<007ooOol01Woo0007Ool00`00Oomoo`0NOol00`00Oomo
o`07Ool@002JOol00`00Oomoo`03Ool00`00Oomoo`06Ool000Moo`03001oogoo01Mooa4004aoo`80
05eoo`03001oogoo009oo`03001oogoo00Ioo`001goo00<007ooOol01Woo4@001goo00<007ooOol0
E7oo00<007ooOol0G7oo00D007ooOomoo`0000Qoo`001goo2@0067oo00<007ooOol0E7oo00<007oo
Ool0GGoo0P0000=oo`00Ool01goo0009Ool3000LOol00`00Oomoo`1COol00`00Ool0001POol20008
Ool000aoo`<001Uoo`03001oogoo05=oo`03001oo`0005Moo`/000Qoo`003goo0`005Woo00<007oo
Ool0DWoo0P0000=oo`000000@Woo50004goo000BOol3000COol00`00Oomoo`24OolE000WOol001Eo
o`<0011oo`03001oogoo06mooaD003aoo`0067oo0`003Goo00<007ooOol0Fgoo5000DGoo000KOol3
000:Ool00`00Oomoo`16OolE001UOol001ioo`<000Moo`03001oogoo035ooaD007Yoo`008Goo0`00
17oo00<007ooOol07Goo5000Sgoo000TOol300000goo001oo`09OolE002SOol002Moo``00;Qoo`00
jgoo003[Ool00>]oo`00jgoo003[Ool00>]oo`00jgoo0000\
\>"],
  ImageRangeCache->{{{0, 234}, {286, 0}} -> {0.0800249, -0.0267817, 
  0.00356257, 0.00356257}}]
}, Open  ]],

Cell[TextData[{
  "From the sizes of the gears in this model and the fact that the drive \
bevel is turning at one revolution per second, we can calculate what the \
velocity of the rack should be. This can also be found directly from the \
velocity of the rack in the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Rack velocity = drivebevel angular velocity * \n  drivebevel radius / \
drivenbevel radius *\n  drivespur radius  / drivenspur radius * \n  pinion \
radius "], "Print",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the rack velocity, calculated explicitly and from the model. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(1.0\[Times]2\ \[Pi]\[Times]2.0\[Times]1.5\[Times]3.0\)\/\(3.0
        \[Times]3.0\)\), 
    \(Magnitude[Velocity[rack, 0]] /. 
      SolveMech[.25, Solution \[Rule] Velocity]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(6.28318530717958623`\)], "Output"],

Cell[BoxData[
    \(6.28318530717958623`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["General Rotational Relationships"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If the spatial gear constraints provided by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will not serve to model a more abstract rotational relationship, similar \
constraints can be built up from the basic kinematic constraints. The \
following example shows how to duplicate the function of the ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint with a set of other ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints. \n\nThis model consists of one moving body, the gear, and \
one stationary body, the pinion. The radius 3.0 gear orbits the stationary \
radius 1.0 pinion. The ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is effectively replaced by the set of the following six \
constraints."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axes of the two gears to be parallel."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the origins of the two gear axes to be adjacent."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint holds the gears the correct distance apart."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint sets the relative rotation of the pinion equal to the value of \
an extra symbol that is added to the model."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint sets the relative rotation of the gear equal to another extra \
symbol that is added to the model."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A general ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function relates the two extra symbols that control the relative rotation \
of the two gears to each other."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"This combination constrains seven degrees of freedom, but it adds two \
degrees of freedom by adding two variables to the model. Thus, a total of \
five degrees of freedom are constrained. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are names for the body numbers. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(pinion = 1; \)\), 
    \(\(gear = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the equivalent ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cs[1] = {\n\t\t
        Parallel2[1, Vector[pinion, {0, 0, 1}], Vector[gear, {0, 0, 1}]], \n
        \t\tPointOnPlane1[2, Point[gear, 0], 
          Plane[pinion, 0, {1, 0, 0}, {0, 1, 0}]], \n\t\t
        RelativeDistance1[3, \n\t\t\tPoint[pinion, 0], Point[gear, 0], 4.0], 
        \n\t\tProjectedAngle1[4, \n\t\t\tVector[pinion, {1, 0, 0}], 
          Line[pinion, 0, gear, 0], Vector[pinion, {0, 0, 1}], rSym1], \n\t\t
        ProjectedAngle1[5, \n\t\t\tVector[gear, {1, 0, 0}], 
          Line[pinion, 0, gear, 0], Vector[pinion, {0, 0, 1}], rSym2], \n\t\t
        Constraint[6, \n\t\t\t
          rSym1\ 1 + rSym2\ 3 == 0, {{rSym1, 0}, {rSym2, 0}}]}; \)\)], "Input",\

  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"We define a driving constraint to move the gear vertically so as to orbit \
the pinion. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cs[2] = RelativeY1[7, Point[gear, 0], T]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be passed a flat constraint list."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Flatten[{cs[1], cs[2]}]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["One initial guess is needed."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetGuess[X2 \[Rule] 4]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 1.0. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 1, X2 \[Rule] 3.87298334620745254`, Y2 \[Rule] 1.`, 
      Z2 \[Rule] 0.`, Eo2 \[Rule] 0.985845228140659202`, Ei2 \[Rule] 0.`, 
      Ej2 \[Rule] 0.`, Ek2 \[Rule] 0.167657943898575219`, 
      rSym1 \[Rule] \(-0.252680255142059806`\), 
      rSym2 \[Rule] 0.0842267517140199473`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the two-gear model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 1.0. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .85164  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.0201893 0.955913 -0.0310769 0.955913 [ 
[ 0 0 0 0 ] 
[ 1 .85164 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 .85164 L 
0 .85164 L 
closepath 
clip 
newpath 
p 
.002 w 
.1643 .23287 m 
.05564 .14165 L 
s 
.05564 .14165 m 
.0239 .78116 L 
s 
.0239 .78116 m 
.14226 .82774 L 
s 
.14226 .82774 m 
.1643 .23287 L 
s 
.94388 .13269 m 
.9761 .77657 L 
s 
.9761 .77657 m 
.92468 .7203 L 
s 
.92468 .7203 m 
.89339 .0239 L 
s 
.89339 .0239 m 
.94388 .13269 L 
s 
.1643 .23287 m 
.05564 .14165 L 
s 
.05564 .14165 m 
.89339 .0239 L 
s 
.89339 .0239 m 
.94388 .13269 L 
s 
.94388 .13269 m 
.1643 .23287 L 
s 
.14226 .82774 m 
.9761 .77657 L 
s 
.9761 .77657 m 
.92468 .7203 L 
s 
.92468 .7203 m 
.0239 .78116 L 
s 
.0239 .78116 m 
.14226 .82774 L 
s 
P 
p 
.002 w 
.21787 .33053 m .26122 .31372 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.18552 .36629 m .21787 .33053 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.26122 .31372 m .21787 .33053 L .17919 .29963 L p 
.703 .859 .956 r 
F P 
s 
P 
p 
.002 w 
.21787 .33053 m .18552 .36629 L .14588 .33646 L p 
.865 .874 .843 r 
F P 
s 
P 
p 
.002 w 
.14588 .33646 m .17919 .29963 L .21787 .33053 L p 
.865 .874 .843 r 
F P 
s 
P 
p 
.002 w 
.17253 .41177 m .18552 .36629 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.18552 .36629 m .17253 .41177 L .13236 .38318 L p 
.954 .824 .678 r 
F P 
s 
P 
p 
.002 w 
.13236 .38318 m .14588 .33646 L .18552 .36629 L p 
.954 .824 .678 r 
F P 
s 
P 
p 
.002 w 
.26122 .31372 m .30438 .32043 L .33588 .34928 L p 
.63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.30438 .32043 m .26122 .31372 L .2237 .28221 L p 
.333 .692 .981 r 
F P 
s 
P 
p 
.002 w 
.17919 .29963 m .2237 .28221 L .26122 .31372 L p 
.703 .859 .956 r 
F P 
s 
P 
p 
.002 w 
.18248 .4552 m .17253 .41177 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.17253 .41177 m .18248 .4552 L .14235 .42773 L p 
.969 .66 .375 r 
F P 
s 
P 
p 
.002 w 
.14235 .42773 m .13236 .38318 L .17253 .41177 L p 
.969 .66 .375 r 
F P 
s 
P 
p 
.002 w 
.2237 .28221 m .26791 .28892 L .30438 .32043 L p 
.333 .692 .981 r 
F P 
s 
P 
p 
.002 w 
.33588 .34928 m .30438 .32043 L .26791 .28892 L p 
.506 0 0 r 
F P 
s 
P 
p 
.002 w 
.21311 .48501 m .18248 .4552 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.18248 .4552 m .21311 .48501 L .17361 .45825 L p 
.642 .111 0 r 
F P 
s 
P 
p 
.002 w 
.17361 .45825 m .14235 .42773 L .18248 .4552 L p 
.642 .111 0 r 
F P 
s 
P 
p 
.002 w 
.25655 .49288 m .21311 .48501 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.30106 .47627 m .25655 .49288 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.33428 .43954 m .30106 .47627 L p 
.33588 .34928 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.33588 .34928 m .34698 .3929 L .33428 .43954 L p 
.63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.26791 .28892 m .3001 .31841 L .33588 .34928 L p 
.506 0 0 r 
F P 
s 
P 
p 
.002 w 
.34698 .3929 m .33588 .34928 L .3001 .31841 L p 
.967 .643 .301 r 
F P 
s 
P 
p 
.002 w 
.21311 .48501 m .25655 .49288 L .21812 .46619 L p 
.236 .661 .959 r 
F P 
s 
P 
p 
.002 w 
.21812 .46619 m .17361 .45825 L .21311 .48501 L p 
.236 .661 .959 r 
F P 
s 
P 
p 
.002 w 
.43014 .26935 m .55666 .19388 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.35068 .39325 m .43014 .26935 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.55666 .19388 m .43014 .26935 L .39712 .23596 L p 
.772 .881 .925 r 
F P 
s 
P 
p 
.002 w 
.3001 .31841 m .31131 .36316 L .34698 .3929 L p 
.967 .643 .301 r 
F P 
s 
P 
p 
.002 w 
.43014 .26935 m .35068 .39325 L .3151 .3635 L p 
.913 .885 .792 r 
F P 
s 
P 
p 
.002 w 
.3151 .3635 m .39712 .23596 L .43014 .26935 L p 
.913 .885 .792 r 
F P 
s 
P 
p 
.002 w 
.25655 .49288 m .30106 .47627 L .26385 .44896 L p 
.687 .879 .97 r 
F P 
s 
P 
p 
.002 w 
.26385 .44896 m .21812 .46619 L .25655 .49288 L p 
.687 .879 .97 r 
F P 
s 
P 
p 
.002 w 
.33428 .43954 m .34698 .3929 L .31131 .36316 L p 
.969 .842 .663 r 
F P 
s 
P 
p 
.002 w 
.33787 .53639 m .35068 .39325 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.30106 .47627 m .33428 .43954 L .29809 .41111 L p 
.872 .898 .848 r 
F P 
s 
P 
p 
.002 w 
.31131 .36316 m .29809 .41111 L .33428 .43954 L p 
.969 .842 .663 r 
F P 
s 
P 
p 
.002 w 
.35068 .39325 m .33787 .53639 L .30137 .51063 L p 
.987 .797 .564 r 
F P 
s 
P 
p 
.002 w 
.30137 .51063 m .3151 .3635 L .35068 .39325 L p 
.987 .797 .564 r 
F P 
s 
P 
p 
.002 w 
.29809 .41111 m .26385 .44896 L .30106 .47627 L p 
.872 .898 .848 r 
F P 
s 
P 
p 
.002 w 
.55666 .19388 m .70055 .18609 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.70055 .18609 m .55666 .19388 L .52727 .15794 L p 
.535 .781 .988 r 
F P 
s 
P 
p 
.002 w 
.39712 .23596 m .52727 .15794 L .55666 .19388 L p 
.772 .881 .925 r 
F P 
s 
P 
p 
.002 w 
.17919 .29963 m .2237 .28221 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.14588 .33646 m .17919 .29963 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.13236 .38318 m .14588 .33646 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.2237 .28221 m .26791 .28892 L .3001 .31841 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.14235 .42773 m .13236 .38318 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.39759 .66375 m .33787 .53639 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.33787 .53639 m .39759 .66375 L .36218 .64146 L p 
.909 .506 .124 r 
F P 
s 
P 
p 
.002 w 
.36218 .64146 m .30137 .51063 L .33787 .53639 L p 
.909 .506 .124 r 
F P 
s 
P 
p 
.002 w 
.17361 .45825 m .14235 .42773 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.21083 .70695 m 
.21708 .50067 L 
s 
P 
p 
.002 w 
.70055 .18609 m .82606 .25112 L .8981 .37589 L p 
.63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.82606 .25112 m .70055 .18609 L .67513 .14928 L p 
.079 .469 .89 r 
F P 
s 
P 
p 
.002 w 
.52727 .15794 m .67513 .14928 L .70055 .18609 L p 
.535 .781 .988 r 
F P 
s 
P 
p 
.002 w 
.21812 .46619 m .17361 .45825 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.26385 .44896 m .21812 .46619 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.1568 .32402 m 
.22094 .37327 L 
s 
P 
p 
.004 w 
.21708 .50067 m 
.21812 .46619 L 
s 
P 
p 
.004 w 
.21812 .46619 m 
.22094 .37327 L 
s 
P 
p 
.002 w 
.29809 .41111 m .26385 .44896 L p 
.3001 .31841 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.3001 .31841 m .31131 .36316 L .29809 .41111 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.22094 .37327 m 
.31131 .36316 L 
s 
P 
p 
.002 w 
.39712 .23596 m .52727 .15794 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.3151 .3635 m .39712 .23596 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.31131 .36316 m 
.31563 .36267 L 
s 
P 
p 
.002 w 
.30137 .51063 m .3151 .3635 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.31563 .36267 m 
.34486 .3594 L 
s 
P 
p 
.002 w 
.52727 .15794 m .67513 .14928 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.51825 .74058 m .39759 .66375 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.39759 .66375 m .51825 .74058 L .48593 .72025 L p 
.384 0 0 r 
F P 
s 
P 
p 
.002 w 
.48593 .72025 m .36218 .64146 L .39759 .66375 L p 
.384 0 0 r 
F P 
s 
P 
p 
.004 w 
.21083 .70695 m 
.22693 .64613 L 
s 
P 
p 
.002 w 
.67513 .14928 m .80405 .21554 L .82606 .25112 L p 
.079 .469 .89 r 
F P 
s 
P 
p 
.002 w 
.8981 .37589 m .82606 .25112 L .80405 .21554 L p 
.638 .23 0 r 
F P 
s 
P 
p 
.004 w 
.18083 .64091 m 
.21083 .70695 L 
s 
P 
p 
.004 w 
.47878 .31152 m 
.5455 .33695 L 
s 
P 
p 
.002 w 
.36218 .64146 m .30137 .51063 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.34486 .3594 m 
.5455 .33695 L 
s 
P 
p 
.002 w 
.67513 .14928 m .80405 .21554 L .87794 .34357 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.24522 .63562 m 
.21083 .70695 L 
s 
P 
p 
.004 w 
.47864 .37757 m 
.5455 .33695 L 
s 
P 
p 
.004 w 
.21083 .70695 m 
.19858 .63025 L 
s 
P 
p 
.004 w 
.4673 .33317 m 
.5455 .33695 L 
s 
P 
p 
.002 w 
.66964 .74202 m .51825 .74058 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.51825 .74058 m .66964 .74202 L .64171 .72137 L p 
.336 .76 .975 r 
F P 
s 
P 
p 
.002 w 
.64171 .72137 m .48593 .72025 L .51825 .74058 L p 
.336 .76 .975 r 
F P 
s 
P 
p 
.002 w 
.80851 .66398 m .66964 .74202 L p 
.8981 .37589 L .63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.8981 .37589 m .89281 .52826 L .80851 .66398 L p 
.63 .463 .637 r 
F P 
s 
P 
p 
.002 w 
.80405 .21554 m .87794 .34357 L .8981 .37589 L p 
.638 .23 0 r 
F P 
s 
P 
p 
.002 w 
.89281 .52826 m .8981 .37589 L .87794 .34357 L p 
.982 .79 .384 r 
F P 
s 
P 
p 
.002 w 
.48593 .72025 m .36218 .64146 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.66964 .74202 m .80851 .66398 L .78497 .64057 L p 
.733 .951 .948 r 
F P 
s 
P 
p 
.002 w 
.78497 .64057 m .64171 .72137 L .66964 .74202 L p 
.733 .951 .948 r 
F P 
s 
P 
p 
.004 w 
.49706 .72033 m 
.50394 .70797 L 
s 
P 
p 
.004 w 
.46948 .76989 m 
.4942 .72546 L 
s 
P 
p 
.002 w 
.80851 .66398 m .89281 .52826 L .87216 .50047 L p 
.934 .96 .762 r 
F P 
s 
P 
p 
.002 w 
.87794 .34357 m .87216 .50047 L .89281 .52826 L p 
.982 .79 .384 r 
F P 
s 
P 
p 
.002 w 
.87216 .50047 m .78497 .64057 L .80851 .66398 L p 
.934 .96 .762 r 
F P 
s 
P 
p 
.004 w 
.46002 .69111 m 
.46167 .70481 L 
s 
P 
p 
.004 w 
.46167 .70481 m 
.46948 .76989 L 
s 
P 
p 
.002 w 
.64171 .72137 m .48593 .72025 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.46948 .76989 m 
.48593 .72025 L 
s 
P 
p 
.004 w 
.48593 .72025 m 
.58237 .42922 L 
s 
P 
p 
.004 w 
.5336 .38021 m 
.58237 .42922 L 
s 
P 
p 
.004 w 
.46948 .76989 m 
.48075 .69285 L 
s 
P 
p 
.004 w 
.46948 .76989 m 
.51547 .72046 L 
s 
P 
p 
.004 w 
.51547 .72046 m 
.52524 .70996 L 
s 
P 
p 
.002 w 
.78497 .64057 m .64171 .72137 L p 
.87794 .34357 L .627 .458 .634 r 
F P 
s 
P 
p 
.002 w 
.87794 .34357 m .87216 .50047 L .78497 .64057 L p 
.627 .458 .634 r 
F P 
s 
P 
p 
.004 w 
.87216 .50047 m 
.92284 .51293 L 
s 
P 
p 
.004 w 
.58237 .42922 m 
.87216 .50047 L 
s 
P 
p 
.004 w 
.87745 .50759 m 
.92284 .51293 L 
s 
P 
p 
.004 w 
.8849 .47998 m 
.92284 .51293 L 
s 
P 
p 
.004 w 
.87328 .46989 m 
.8849 .47998 L 
s 
P 
p 
.004 w 
.86288 .46086 m 
.87328 .46989 L 
s 
P 
p 
.004 w 
.85544 .52733 m 
.92284 .51293 L 
s 
P 
p 
.004 w 
.84122 .53037 m 
.85544 .52733 L 
s 
P 
p 
.004 w 
.92284 .51293 m 
.84431 .48534 L 
s 
P 
p 
.002 w 
.94388 .13269 m 
.9761 .77657 L 
s 
.9761 .77657 m 
.92468 .7203 L 
s 
.92468 .7203 m 
.89339 .0239 L 
s 
.89339 .0239 m 
.94388 .13269 L 
s 
.14226 .82774 m 
.9761 .77657 L 
s 
.9761 .77657 m 
.92468 .7203 L 
s 
.92468 .7203 m 
.0239 .78116 L 
s 
.0239 .78116 m 
.14226 .82774 L 
s 
P 
p 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .5455 .33695 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .21083 .70695 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .06788 .25573 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(1)] .22094 .37327 1.3 1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .92284 .51293 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .46948 .76989 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .46558 .31185 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(2)] .58237 .42922 1.3 1.3 Mshowa 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 240},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000l1000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003gOol4000OOol00?1oo`L0
00=oo`03001oogoo01eoo`00jGoo1`002Woo0P007Woo003ROol7000AOol2000NOol00=Yoo`P001Qo
o`03001oo`0001eoo`00dgoo1`0087oo00<007oo00007Goo003<Ool7000WOol01000Oomoo`0077oo
0035Ool7000^Ool01000Oomoo`0077oo002nOol7000eOol01@00Oomoogoo00006goo002gOol7000l
Ool01@00Oomoogoo00006goo002`Ool70013Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00:Uoo`L0
04]oo`05001oogooOol0000JOol00:5oo`P0059oo`03001oogoo009oo`03001oogoo01Moo`00VWoo
1`00FWoo00<007ooOol00Woo00<007ooOol05goo002COol7001QOol00`00Oomoo`03Ool00`00Oomo
o`0FOol008aoo`L006Qoo`03001oogoo00=oo`03001oogoo01Ioo`00QGoo1`00Kgoo00<007ooOol0
17oo00<007ooOol05Goo001nOol7001fOol00`00Oomoo`04Ool00`00Oomoo`0EOol007Moo`L007eo
o`03001oogoo00Eoo`03001oogoo01Aoo`00L7oo1`00Q7oo00<007ooOol01Goo00<007ooOol057oo
001YOol7002;Ool00`00Oomoo`06Ool00`00Oomoo`0COol0065oo`P0099oo`03001oogoo00Ioo`03
001oogoo01=oo`00FWoo1`00VWoo00<007ooOol01goo00<007ooOol04Woo001COol7002QOol00`00
Oomoo`07Ool00`00Oomoo`0BOol004aoo`L00:Qoo`03001oogoo00Qoo`03001oogoo015oo`00AGoo
1`00[goo00<007ooOol027oo00<007ooOol04Goo000nOol7002fOol00`00Oomoo`09Ool00`00Oomo
o`0@Ool003Moo`L00;eoo`03001oogoo00Uoo`03001oogoo011oo`00<7oo1`00a7oo00<007ooOol0
2Woo00<007ooOol03goo000XOol8003;Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool0025oo`L00==o
o`03001oogoo00]oo`03001oogoo00ioo`006Woo1`00fWoo00<007ooOol027oo100047oo000COol7
003QOol00`00Oomoo`080003Ool00`00Oomoo`0>Ool000moo`@00>=oo`P000]oo`03001oogoo00io
o`003goo0P00gGoo20001Woo00<007ooOol02Woo00<007ooOol03Woo000?Ool00`00Ool0002UOol7
000XOol8000>Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool000moo`03001oogoo008009Eoo`h000MA
e08001ioo`P001Ioo`03001oogoo00Yoo`03001oogoo00ioo`003goo00<007ooOol00Woo00<007oo
Ool0Q7oo3P005e7D0P005Goo1`007Woo00<007ooOol02Woo00<007ooOol03Woo000?Ool00`00Oomo
o`03Ool00`00Oomoo`1lOol7000WDM@2000;Ool8000UOol00`00Oomoo`0:Ool00`00Oomoo`0>Ool0
00moo`03001oogoo00Aoo`03001oogoo07Uoo`80031Ae0800003Ool0000000H002eoo`03001oogoo
00Yoo`03001oogoo00ioo`003goo00<007ooOol01Goo00<007ooOol0MWoo0P00=57D0P00=7oo00<0
07ooOol02Woo00<007ooOol03Woo000?Ool00`00Oomoo`06Ool2001eOol00`00DMAAe00fDM@2000b
Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool000moo`03001oogoo00Qoo`03001oogoo071oo`8003]A
e080031oo`03001oogoo00]oo`03001oogoo00eoo`003Woo00<007ooOol02Woo00<007ooOol0KGoo
0P00?e7D0P00;Woo00<007ooOol02goo00<007ooOol03Goo000>Ool00`00Oomoo`0;Ool00`00Oomo
o`1[Ool00`00DMAAe011DM@00`00Oomoo`0[Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool000ioo`03
001oogoo00aoo`03001oogoo06Qoo`8004EAe08002]oo`03001oogoo00]oo`03001oogoo00eoo`00
3Woo00<007ooOol03Goo0P00IWoo0P00BE7D0P00:Goo00<007ooOol02goo00<007ooOol03Goo000>
Ool00`00Oomoo`0?Ool00`00Oomoo`1ROol00`00DMAAe01;DM@2000WOol00`00Oomoo`0;Ool00`00
Oomoo`0=Ool000ioo`03001oogoo011oo`03001oogoo05eoo`@0051Ae08002Eoo`03001oogoo00]o
o`03001oogoo00eoo`003Woo00<007ooOol04Goo00<007ooOol0E7oo2P00E57D0P008goo00<007oo
Ool02goo00<007ooOol03Goo000>Ool00`00Oomoo`0BOol00`00Oomoo`1;Ool80006Ool2001HDM@2
000QOol00`00Oomoo`0;Ool00`00Oomoo`0=Ool000ioo`03001oogoo01=oo`8004=oo`P000eoo`03
001Ae57D05YAe08001moo`03001oogoo00]oo`03001oogoo00eoo`003Woo00<007ooOol05Goo00<0
07ooOol0>7oo20004goo0P00Ge7D0P007Goo00<007ooOol02goo00<007ooOol03Goo000>Ool00`00
Oomoo`0FOol00`00Oomoo`0`Ool7000IOol2001SDM@2000KOol00`00Oomoo`0;Ool00`00Oomoo`0=
Ool000ioo`03001oogoo01Moo`03001oogoo02Moo`P001moo`03001Ae57D06EAe003001oogoo01Qo
o`03001oogoo00]oo`03001oogoo00eoo`003Woo00<007ooOol067oo00<007ooOol07Woo20009Goo
0P00JE7D00<007ooOol067oo00<007ooOol02Woo00<007ooOol03Goo000>Ool00`00Oomoo`0IOol2
000FOol8000[Ool2001[DM@00`00Oomoo`0HOol00`00Oomoo`0:Ool00`00Oomoo`0=Ool000ioo`03
001oogoo01]oo`03001oogoo00]oo`P0039oo`03001Ae57D06aAe003001oogoo01Moo`03001oogoo
00Yoo`03001oogoo00eoo`003Woo00<007ooOol077oo00<007ooOol00Woo2000>7oo0P00Ke7D0P00
67oo00<007ooOol02Woo00<007ooOol03Goo000>Ool00`00Oomoo`0MOol4000nOol2001bDM@00`00
Oomoo`0FOol00`00Oomoo`0:Ool00`00Oomoo`0=Ool000ioo`03001oogoo01eoo`03001oogoo03io
o`03001Ae57D079Ae08001Moo`03001oogoo00Yoo`03001oogoo00eoo`003Woo00<007ooOol07Goo
00<007ooOol0?Goo00<0057DDM@0M57D0P005Woo00<007ooOol02Woo00<007ooOol03Goo000>Ool0
0`00Oomoo`0MOol00`00Oomoo`0mOol00`00DMAAe01eDM@2000EOol00`00Oomoo`0;Ool00`00Oomo
o`0<Ool000eoo`03001oogoo01ioo`03001oogoo03aoo`03001Ae57D07IAe08001Eoo`03001oogoo
00]oo`03001oogoo00aoo`003Goo00<007ooOol07Woo00<007ooOol0>goo00<0057DDM@0N57D0P00
57oo00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`0NOol00`00Oomoo`0kOol00`00
DMAAe01hDM@00`00D>00000COol00`00Oomoo`0;Ool00`00Oomoo`0<Ool000eoo`03001oogoo01io
o`03001oogoo03Yoo`03001Ae57D07YAe08001=oo`03001oogoo00]oo`03001oogoo00aoo`003Goo
00<007ooOol07Woo00<007ooOol0>Woo00<0057DDM@0Ne7D0P004Woo00<007ooOol02goo00<007oo
Ool037oo000=Ool00`00Oomoo`0NOol00`00Oomoo`0iOol00`00DMAAe01lDM@2000BOol00`00Oomo
o`0;Ool00`00Oomoo`0<Ool000eoo`03001oogoo01ioo`03001oogoo03Qoo`03001Ae57D07iAe080
015oo`03001oogoo00]oo`03001oogoo00aoo`003Goo00<007ooOol07Woo00<007ooOol0>7oo00<0
057DDM@0OU7D0P004Goo00<007ooOol02goo00<007ooOol037oo000=Ool00`00Oomoo`04Ool4000F
Ool00`00Oomoo`0gOol00`00DMAAe020DM@2000@Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool000eo
o`03001oogoo00Eoo`03001oo`0001Ioo`03001oogoo03Ioo`03001Ae57D085Ae003001@h00000mo
o`03001oogoo00]oo`03001oogoo00aoo`003Goo00<007ooOol017oo00<007oo00005Woo00<007oo
Ool03Goo1@009Goo00<0057DDM@0PU7D0P003goo00<007ooOol02goo00<007ooOol037oo000=Ool0
0`00Oomoo`04Ool4000EOol00`00Oomoo`0;Ool20005DM@6000NOol00`00DMAAe024DM@2000>Ool0
0`00Oomoo`0;Ool00`00Oomoo`0<Ool000eoo`03001oogoo01eoo`03001oogoo00Uoo`8000eAe0@0
01Uoo`03001Ae57D08EAe08000ioo`03001oogoo00]oo`03001oogoo00aoo`003Goo00<007ooOol0
7Goo00<007ooOol01Woo0`004e7D00<007ooOol05Woo00<0057DDM@0QU7D0P003Goo00<007ooOol0
2goo00<007ooOol037oo000=Ool00`00Oomoo`0MOol00`00Oomoo`04Ool2000GDM@2000EOol00`00
DMAAe027DM@2000>Ool00`00Oomoo`0:Ool00`00Oomoo`0<Ool000eoo`03001oogoo01eoo`03001o
ogoo009oo`8001YAe08001=oo`03001Ae57D08UAe08000eoo`03001oogoo00Yoo`03001oogoo00ao
o`003Goo00<007ooOol07Goo00D007ooOomoo`0001eAe080019oo`03001Ae57D08YAe08000aoo`03
001oogoo00Yoo`03001oogoo00aoo`003Goo00<007ooOol07Goo00@007ooOol0021Ae003001oogoo
00ioo`03001Ae57D08]Ae08000aoo`03001oogoo00Yoo`03001oogoo00aoo`003Goo00<007ooOol0
7Goo00<007oo00008U7D0P003Woo00<0057DDM@08E7D0P00JE7D0P002goo00<007ooOol02Woo00<0
07ooOol037oo000=Ool00`00Oomoo`0MOol2000TDM@2000<Ool00`00DMAAe00TDM@3001VDM@2000;
Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo01ioo`03001Ae57D02AAe08000Yo
o`03001Ae57D02QAe08006EAe08000Yoo`03001oogoo00]oo`03001oogoo00]oo`0037oo00<007oo
Ool07Goo0P009U7D0`002Goo00<0057DDM@0:U7D0`00HU7D0P002Woo00<007ooOol02goo00<007oo
Ool02goo000<Ool00`00Oomoo`0MOol2000VDM@01000NXT000001goo00<0057DDM@0;U7D0`00H57D
0P002Goo00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0LOol00`00DMAAe002000U
DM@01000NXT000001Goo00<0057DDM@0<U7D0P00Ge7D0P0027oo00<007ooOol02goo00<007ooOol0
2goo000<Ool00`00Oomoo`0KOol00`00DMAAe003DM@00`00DMAAe00RDM@00`00NXUjR@020004Ool0
0`00DMAAe00RDM@;0007DM@3001LDM@20008Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03
001oogoo01Yoo`03001Ae57D00EAe003001Ae57D025Ae004001jRGZ9NXT20002Ool00`00DMAAe00U
DM@00`00DM@00006DM@<001KDM@20007Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001o
ogoo01Yoo`03001Ae57D00IAe08000AAe0D001QAe003001jRGZ900=jR@8002MAe003001Ae00000AA
e0X0009Ae08005aAe08000Moo`03001oogoo00]oo`03001oogoo00]oo`0037oo00<007ooOol06Goo
00<0057DDM@02E7D00<0057DDM@00e7D00<0057DDM@06E7D00<007Z9NXT00gZ900<0057DDM@08e7D
2@002U7D0P00Ge7D0P001Woo00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0IOol0
0`00DMAAe00:DM@00`00DMAAe002DM@00`00DMAAe00IDM@00`00NXUjR@02NXT00`00DMAAe00JDM@:
000ADM@2001QDM@20006Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo01Uoo`03
001Ae57D00]Ae005001Ae57DDM@0000KDM@00`00NXUjR@02NXT00`00DMAAe00ADM@9000JDM@00`00
DMAAe01QDM@30005Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool000aoo`03001oogoo01Qoo`03001A
e57D00eAe0800003DM@0057D01YAe005001jRGZ9NXT0000:DM@:000QDM@2001TDM@01000Ob`00000
17oo00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0HOol00`00DMAAe00?DM@2000L
DM@00`00NXT00003DM@8000YDM@2000;DM@01000DMAAe000Ee7D00@007l/Ob`000Aoo`03001oogoo
00]oo`03001oogoo00]oo`0037oo00<007ooOol067oo00<0057DDM@0457D00<0057DDM@05U7D2P00
<57D00<0057DDM@0357D0P00F57D00<007l/Ob`00P000goo00<007ooOol02goo00<007ooOol02goo
000<Ool00`00Oomoo`0HOol00`00DMAAe00ADM@2000>DM@80004DM@2000bDM@2000?DM@2001HDM@0
1@00Obao;7l/00000goo00<007ooOol02goo00<007ooOol02goo000<Ool00`00Oomoo`0GOol00`00
DMAAe00DDM@00`00DMAAe003DM@8000;DM@00`00OeD0000`DM@2000@DM@01000DMAAe000Ee7D00<0
07l/Ob`00Wl/00@007ooOol000eoo`03001oogoo00]oo`0037oo00<007ooOol05goo00<0057DDM@0
5E7D1@004e7D00<007mE0000;U7D0P00KE7D00<007l/Ob`00Wl/00@007ooOol000eoo`03001oogoo
00]oo`0037oo00<007ooOol05goo00<0057DDM@05E7D00<0057DDM@05E7D00<007mE0000;E7D00<0
057DDM@0KE7D00<007l/Ob`00gl/00@007ooOol000aoo`03001oogoo00]oo`0037oo00<007ooOol0
5Woo00<0057DDM@05U7D00<0057DDM@05E7D00<007mE0000?57D00<0057DDM@0GU7D00<007l/Ob`0
0gl/00@007ooOol000aoo`03001oogoo00]oo`0037oo00<007ooOol05Woo00<0057DDM@05U7D00<0
057DDM@0557D00@007mEOeD003eAe003001Ae57D05aAe003001o;7l/00Ao;004001oogoo000<Ool0
0`00Oomoo`0;Ool000aoo`03001oogoo01Ioo`03001Ae57D01IAe003001Ae57D01AAe003001oE@00
03mAe003001Ae57D05]Ae003001o;7l/00Ao;004001oogoo000=Ool00`00Oomoo`0:Ool000]oo`03
001oogoo01Moo`03001Ae57D01IAe003001Ae57D01AAe003001oE@00041Ae003001Ae57D05YAe003
001o;7l/00Ao;004001oogoo000=Ool00`00Oomoo`0:Ool000]oo`03001oogoo01Qoo`03001Ae57D
01EAe003001Ae57D01=Ae004001oEGmE0011DM@00`00DMAAe002DM@3001DDM@00`00Obao;004Ob`0
1000Oomoo`003Goo00<007ooOol02Woo000;Ool00`00Oomoo`0HOol00`00DMAAe00EDM@00`00DMAA
e00CDM@01000OeEoE@00@U7D00D0057DDMAAe00005IAe003001o;7l/00Ao;004001oogoo000=Ool0
0`00Oomoo`0:Ool000]oo`03001oogoo01Qoo`03001Ae57D01EAe003001Ae57D01=Ae004001oEGmE
0013DM@01@00DMAAe57D0000EE7D00<007l/Ob`017l/00@007ooOol000eoo`03001oogoo00Yoo`00
2goo00<007ooOol067oo00<0057DDM@05E7D00<0057DDM@04e7D00@007mEOeD004AAe004001Ae57D
001EDM@00`00Obao;004Ob`01000Oomoo`003Goo00<007ooOol02Woo000;Ool00`00Oomoo`0IOol0
0`00DMAAe00DDM@00`00DMAAe00BDM@01@00OeEoEGmE0000AE7D0P0000=Ae000DM@0De7D00<007l/
Ob`017l/00@007ooOol000eoo`03001oogoo00Yoo`002goo00<007ooOol06Goo00<0057DDM@0557D
00<0057DDM@04U7D00D007mEOeEoE@0004IAe08005EAe003001o;7l/00Ao;004001oogoo000=Ool0
0`00Oomoo`0:Ool000]oo`03001oogoo01Uoo`03001Ae57D01AAe003001Ae57D015Ae003001_V`00
009oE@03001Ae57D04EAe003001Ae57D05=Ae003001o;7l/00=o;005001oogooOol0000=Ool00`00
Oomoo`0:Ool000]oo`03001oogoo01Uoo`03001Ae57D01=Ae003001Ae57D015Ae004001_VfnKKi/3
0018DM@00`00DMAAe01BDM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;
Ool00`00Oomoo`0JOol00`00DMAAe00BDM@00`00DMAAe00@DM@00`00Ki]_V`03Ki/00`00DMAAe018
DM@00`00DMAAe01ADM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool0
0`00Oomoo`0JOol00`00DMAAe00BDM@00`00DMAAe00?DM@00`00Ki]_V`04Ki/00`00DMAAe019DM@0
0`00DMAAe01@DM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool00`00
Oomoo`0JOol00`00DMAAe00BDM@00`00DMAAe00>DM@00`00Ki]_V`05Ki/00`00DMAAe01:DM@3001?
DM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool00`00Oomoo`0KOol0
0`00DMAAe00ADM@00`00DMAAe00>DM@00`00Ki]_V`05Ki/00`00DMAAe01:DM@00`00DMAAe004001;
DM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool00`00Oomoo`0LOol0
0`00DMAAe00@DM@00`00DMAAe00=DM@00`00Ki]_V`06Ki/00`00DMAAe019DM@00`00DMAAe005DM@4
0017DM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool00`00Oomoo`0M
Ool00`00DMAAe00?DM@00`00DMAAe00<DM@00`00Ki]_V`07Ki/00`00DMAAe019DM@00`00DMAAe009
DM@40013DM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool00`00Oomo
o`0NOol00`00DMAAe00>DM@00`00DMAAe00;DM@00`00Ki]_V`08Ki/00`00DMAAe019DM@00`00DMAA
e00=DM@4000oDM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool00`00
Oomoo`0NOol2000?DM@00`00DMAAe009DM@2000;Ki/00`00DMAAe018DM@00`00DMAAe00BDM@4000k
DM@00`00Obao;003Ob`01@00Oomoogoo00003Goo00<007ooOol02Woo000;Ool00`00Oomoo`0NOol0
0`00Ool0000>DM@00`00DMAAe007DM@20002Eil00`00Ki]_V`08Ki/00`00DMAAe018DM@00`00DMAA
e00FDM@4000gDM@00`00Obao;003Ob`00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
00]oo`03001oogoo01ioo`04001oogoo000=DM@00`00DMAAe004DM@30005Eil20008Ki/00`00DMAA
e018DM@00`00DMAAe00JDM@4000cDM@00`00Obao;003Ob`00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool000]oo`03001oogoo01ioo`04001oogooOol40009DM@01000DMAAe57D0`002UNO
00<006nKKi/016nK00<0057DDM@0B57D00<0057DDM@07e7D1000;e7D00<007l/Ob`00gl/00<007oo
Ool00Woo00<007ooOol02goo00<007ooOol02Goo000:Ool00`00Oomoo`0OOol00`00Oomoo`02Ool2
00000ajn000000040003DM@01000DM@000003UNO00<006nKKi/00fnK00<0057DDM@0B57D00<0057D
DM@08e7D1000:57D00<0057D00001Wl/00<007ooOol00Woo00<007ooOol02goo00<007ooOol02Goo
000:Ool00`00Oomoo`0OOol00`00Oomoo`04Ool00`007[hN_P047[h5000AEil00`00Ki]_V`02Ki/0
0`00DMAAe018DM@00`00DMAAe00WDM@4000UDM@20006Ob`00`00Oomoo`02Ool00`00Oomoo`0;Ool0
0`00Oomoo`09Ool000Yoo`03001oogoo01moo`03001oogoo00Eoo`03000N_Qjn00HN_P<0015GW`80
009_V`03001Ae57D04MAe003001Ae57D02aAe0@0029Ae08000Eo;003001oogoo009oo`03001oogoo
00]oo`03001oogoo00Uoo`002Woo00<007ooOol07goo00<007ooOol01Woo0P001Qjn00@001jn7[h0
019GW`03001_V`0004UAe003001Ae57D031Ae0@001iAe003001o;00000Ao;003001oogoo009oo`03
001oogoo00]oo`03001oogoo00Uoo`002Woo00<007ooOol07goo00<007ooOol027oo00<001jn7[h0
0ajn00D001jn7[hN_P00015GW`<004UAe003001Ae57D03AAe0@001YAe004001o;7l/0003Ob`00`00
Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool000Yoo`03001oogoo01moo`03001oogoo00Uo
o`03000N_Qjn008N_P03000N_Qjn008N_P8000eGW`80009oo`03001Ae57D04IAe003001Ae57D03UA
e0@001IAe005001o;7l/Ob`00002Ob`00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool0
00Yoo`03001oogoo01ioo`03001oogoo00]oo`80008N_P03000N_Qjn00@N_P03001GWeNO00QGW`80
00Aoo`03001Ae57D04IAe003001Ae57D03eAe0@0019Ae003001o;7l/009o;003001o;00000Aoo`03
001oogoo00]oo`03001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol03Goo10001Qjn00<0
05NOEil015NO0`001Woo00<0057DDM@0AU7D00<0057DDM@0@E7D10001e7D0P001E7D00<007l/Ob`0
0gl/0P0017oo00<007ooOol02goo00<007ooOol02Goo000:Ool00`00Oomoo`0NOol00`00Oomoo`0?
Ool00`00Ool0000500000ajn00000002Eil20009Ool00`00DMAAe015DM@00`00DMAAe016DM@40005
DM@30002DM@00`00Obao;004Ob`20003Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool000Yoo`03001o
ogoo01ioo`03001oogoo00moo`03001oogoo00Eoo`D000Yoo`03001Ae57D04IAe003001Ae57D04YA
e0@000AAe0<000Eo;004001oogoo0002Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool000Yoo`03001o
ogoo01ioo`03001oogoo00moo`03001oogoo01Aoo`03001Ae57D04IAe003001Ae57D04iAe0@0009A
e0@0009o;007001oogooOol007oo00003Goo00<007ooOol02Goo000:Ool00`00Oomoo`0NOol00`00
Oomoo`0?Ool00`00Oomoo`0DOol00`00DMAAe015DM@00`00DMAAe01CDM@500000gl/000000020003
Ool2000=Ool00`00Oomoo`09Ool000Yoo`03001oogoo01ioo`03001oogoo00moo`03001oogoo01Ao
o`03001Ae57D04EAe003001Ae57D05AAe004001gf000Ob`800000goo0000000<Ool00`00Oomoo`09
Ool000Yoo`03001oogoo01ioo`03001oogoo00moo`03001oogoo01Aoo`03001Ae57D04EAe003001A
e57D05AAe003001gf00000d000]oo`03001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol0
3goo00<007ooOol057oo00<0057DDM@0A57D00<0057DDM@0E57D00D007OHMmQgf00000=o;003001o
ogoo00L000Yoo`03001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol03goo00<007ooOol0
57oo00<0057DDM@0A57D00<0057DDM@0E57D00<007OHMmP00WOH00D007l/Ob`007oo00D000eoo`03
001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol03goo00<007ooOol05Goo00<0057DDM@0
@e7D00<0057DDM@0De7D00<007OHMmP017OH100017oo00<007ooOol02goo00<007ooOol02Goo000:
Ool00`00Oomoo`0NOol00`00Oomoo`0?Ool00`00Oomoo`0EOol00`00DMAAe012DM@00`00DMAAe01C
DM@00`00MmQgf00600000gl/001oo`04Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool000Yoo`03001o
ogoo01ioo`03001oogoo00moo`03001oogoo01Ioo`03001Ae57D045Ae003001Ae57D059Ae0@000Ig
f08000Eoo`03001oogoo00]oo`03001oogoo00Uoo`002Woo00<007ooOol07Woo00<007ooOol03goo
00<007ooOol05Woo00<0057DDM@0@E7D00<0057DDM@0Ce7D10002WOH00<007ooOol017oo00<007oo
Ool02goo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0GOol0
0`00DMAAe00oDM@00`00DMAAe01BDM@00`00MmQgf008MmP00`00Oomoo`05Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomo
o`0GOol00`00DMAAe00oDM@00`00DMAAe01BDM@00`00MmQgf008MmP00`00Oomoo`05Ool01000Oomo
ogoo0P0027oo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0H
Ool00`00DMAAe00nDM@00`00DMAAe01ADM@00`00MmQgf008MmP00`00Oomoo`06Ool01000Oomoogoo
0P0027oo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0HOol0
0`00DMAAe00mDM@00`00DMAAe01BDM@00`00MmQgf008MmP00`00Oomoo`06Ool01000Oomoo`000Woo
00<007ooOol01Goo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomo
o`0IOol00`00DMAAe00lDM@00`00DMAAe01ADM@00`00MmQgf008MmP00`00Oomoo`07Ool00`00Oomo
o`0;Ool00`00Oomoo`08Ool000Uoo`03001oogoo01moo`03001oogoo00moo`03001oogoo01Uoo`03
001Ae57D03aAe003001Ae57D051Ae003001gf7OH00Qgf003001oogoo00Qoo`03001oogoo00]oo`03
001oogoo00Qoo`002Goo00<007ooOol07goo00<007ooOol03Woo00<007ooOol06goo00<0057DDM@0
>U7D00<0057DDM@0DE7D00<007OHMmP027OH00<007ooOol027oo00<007ooOol02goo00<007ooOol0
27oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00DMAAe00jDM@00`00
DMAAe01@DM@00`00MmQgf008MmP00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool000Uo
o`03001oogoo01moo`03001oogoo00ioo`03001oogoo01]oo`03001Ae57D03YAe003001Ae57D051A
e003001gf7OH00Qgf003001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Qoo`002Goo00<007oo
Ool07goo00<007ooOol03Woo00<007ooOol077oo00<0057DDM@0>57D00<0057DDM@0D57D00<007OH
MmP027OH00<007ooOol02Woo00<007ooOol02goo00<007ooOol027oo0009Ool00`00Oomoo`0OOol0
0`00Oomoo`0>Ool00`00Oomoo`0LOol00`00DMAAe00hDM@00`00DMAAe01?DM@00`00MmQgf008MmP0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool000Uoo`03001oogoo01moo`03001oogoo
00ioo`03001oogoo01eoo`03001Ae57D03MAe003001Ae57D04mAe003001gf7OH00Qgf003001oogoo
00]oo`03001oogoo00]oo`03001oogoo00Qoo`002Goo00<007ooOol07goo00<007ooOol03Woo00<0
07ooOol07Goo00<0057DDM@0=U7D00<0057DDM@0Ce7D00<007OHMmP027OH00<007ooOol037oo00<0
07ooOol02goo00<007ooOol027oo0009Ool00`00Oomoo`0OOol00`00Oomoo`0>Ool00`00Oomoo`0N
Ool00`00DMAAe00eDM@00`00DMAAe01>DM@00`00MmQgf009MmP00`00Oomoo`0<Ool00`00Oomoo`0;
Ool00`00Oomoo`08Ool000Uoo`03001oogoo01ioo`03001oogoo00moo`03001oogoo01ioo`03001A
e57D03EAe003001Ae57D04iAe003001gf7OH00Qgf003001oogoo00eoo`03001oogoo00]oo`03001o
ogoo00Qoo`002Goo00<007ooOol07Woo00<007ooOol03goo00<007ooOol07goo00<0057DDM@0=57D
00<0057DDM@0CE7D00<007OHMmP027OH00<007ooOol03Woo00<007ooOol02goo00<007ooOol027oo
0009Ool00`00Oomoo`0NOol00`00Oomoo`0?Ool00`00Oomoo`0OOol00`00DMAAe00cDM@00`00DMAA
e01>DM@00`00MmQgf008MmP00`00Oomoo`0>Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool000Uoo`03
001oogoo01ioo`03001oogoo00moo`03001oogoo021oo`03001Ae57D039Ae003001Ae57D04eAe003
001gf7OH00Qgf003001oogoo00moo`03001oogoo00]oo`03001oogoo00Qoo`002Goo00<007ooOol0
7Woo00<007ooOol03goo00<007ooOol087oo00<0057DDM@0<U7D00<0057DDM@0C57D00<007OHMmP0
27OH00<007ooOol047oo00<007ooOol02goo00<007ooOol027oo0009Ool00`00Oomoo`0NOol00`00
Oomoo`0?Ool00`00Oomoo`0POol00`00DMAAe00aDM@00`00DMAAe01=DM@00`00MmQgf008MmP00`00
Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool000Qoo`03001oogoo01moo`03001oogoo00mo
o`03001oogoo025oo`03001Ae57D031Ae003001Ae57D04aAe003001gf7OH00Qgf003001oogoo015o
o`03001oogoo00aoo`03001oogoo00Moo`0027oo00<007ooOol07goo00<007ooOol03goo00<007oo
Ool08Goo00<0057DDM@0<57D00<0057DDM@0C57D00<007OHMmP027OH00<007ooOol04Woo00<007oo
Ool02goo00<007ooOol01goo0008Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0ROol0
0`00DMAAe00^DM@00`00DMAAe01<DM@00`00MmQgf008MmP00`00Oomoo`0COol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool000Qoo`03001oogoo01moo`03001oogoo00moo`03001oogoo029oo`03001Ae57D
02iAe003001Ae57D04]Ae003001gf7OH00Qgf003001oogoo01Aoo`03001oogoo00]oo`03001oogoo
00Moo`0027oo00<007ooOol07goo00<007ooOol03goo00<007ooOol08goo00<0057DDM@0;E7D00<0
057DDM@0Be7D00<007OHMmP027OH00<007ooOol057oo00<007ooOol02goo00<007ooOol01goo0008
Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00DMAAe00/DM@00`00DMAAe01;
DM@00`00MmQgf008MmP00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool000Qoo`03001o
ogoo01moo`03001oogoo00moo`03001oogoo02Aoo`03001Ae57D02]Ae003001Ae57D04YAe003001g
f7OH00Ugf003001oogoo01Eoo`03001oogoo00]oo`03001oogoo00Moo`0027oo00<007ooOol07goo
00<007ooOol02Woo00<007ooOol00Woo00<007ooOol097oo00<0057DDM@0:e7D00<0057DDM@0BU7D
00<007OHMmP027OH00<007ooOol05Woo00<007ooOol02goo00<007ooOol01goo0008Ool00`00Oomo
o`0OOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0UOol00`00DMAAe00YDM@00`00DMAA
e01:DM@00`00MmQgf008MmP00`00Oomoo`0GOol00`00Oomoo`0;Ool00`00Oomoo`07Ool000Qoo`03
001oogoo01moo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo01aoo`03
001Ae57D02UAe003001Ae57D04YAe003001gf7OH00Qgf003001oogoo01Moo`03001oogoo00]oo`03
001oogoo00Moo`0027oo00<007ooOol07goo00<007ooOol01Goo00<007ooOol00goo00D007ooOomo
o`0000Moo`03001oogoo01ioo`03001Ae57D02QAe003001Ae57D04UAe003001gf7OH00Qgf003001o
ogoo01Qoo`03001oogoo00]oo`03001oogoo00Moo`0027oo00<007ooOol07goo00<007ooOol01Goo
00<007ooOol00goo00D007ooOomoo`0000Moo`03001oogoo01ioo`03001Ae57D02MAe003001Ae57D
04QAe0800003Gmh007OH00Qgf003001oogoo01Qoo`03001oogoo00]oo`03001oogoo00Moo`0027oo
00<007ooOol07goo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`00009oo`05001oogoo
Ool0000ROol2000WDM@00`00DMAAe016DM@20004Gmh00`00MmQgf005MmP00`00Oomoo`0IOol00`00
Oomoo`0;Ool00`00Oomoo`07Ool000Qoo`03001oogoo01moo`03001oogoo00Ioo`03001oogoo009o
o`05001oogooOol00002Ool01@00Oomoogoo000097oo00<0057DDM@0957D00<0057DDM@0A57D0P00
1eoN00<007OHMmP00gOH00<007ooOol06Woo00<007ooOol02goo00<007ooOol01goo0008Ool00`00
Oomoo`0OOol00`00Oomoo`07Ool01@00Oomoogoo00000goo00@007ooOol0009oo`03001oogoo02Ao
o`8002=Ae003001Ae57D04AAe003001OgUoN00QOgP03001gf7OH009gf003001oogoo01Yoo`03001o
ogoo00]oo`03001oogoo00Moo`0027oo00<007ooOol07goo00<007ooOol01goo00D007ooOomoo`00
009oo`04001oogoo0003Ool00`00Oomoo`0VOol2000QDM@00`00DMAAe012DM@2000<Gmh01000MmQg
f0007Goo00<007ooOol02goo00<007ooOol01goo0008Ool00`00Oomoo`0OOol00`00Oomoo`08Ool0
1`00Oomoogoo001oo`00009oo`04001oogoo000[Ool00`00DMAAe00NDM@00`00DMAAe010DM@2000?
Gmh00`00MmP0000MOol00`00Oomoo`0;Ool00`00Oomoo`07Ool000Qoo`03001oogoo01moo`03001o
ogoo00Qoo`07001oogooOol007oo00000Woo00@007ooOol002aoo`8001eAe003001Ae57D03mAe080
019OgP03001oogoo01aoo`03001oogoo00]oo`03001oogoo00Moo`0027oo00<007ooOol07goo00<0
07ooOol02Goo00H007ooOol007oo0002Ool00`00Ool0000_Ool00`00DMAAe00JDM@00`00DMAAe00n
DM@00`00GmiOgP0@Gmh2000OOol00`00Oomoo`0;Ool00`00Oomoo`07Ool000Qoo`03001oogoo01mo
o`03001oogoo00Uoo`08001oogoo001oo`00Ool0009oo`03001oogoo02ioo`8001YAe003001Ae57D
03aAe080015OgP80025oo`03001oogoo00aoo`03001oogoo00Ioo`001goo00<007ooOol087oo00<0
07ooOol02Woo00T007oo001oo`00Ool007oo0000<goo0P005e7D00<0057DDM@0>e7D0P004EoN0P00
8goo00<007ooOol037oo00<007ooOol01Woo0007Ool00`00Oomoo`0POol00`00Oomoo`0:Ool00`00
Oomoo`02000017oo001oo`00=Goo00<0057DDM@0557D00<0057DDM@0>U7D00<005oNGmh045oN00<0
07ooOol08goo00<007ooOol037oo00<007ooOol01Woo0007Ool00`00Oomoo`0OOol00`00Oomoo`0<
Ool01@00Ool00000Ool00P00=goo0P00557D00<0057DDM@0>57D0P004EoN0P009Woo00<007ooOol0
37oo00<007ooOol01Woo0007Ool00`00Oomoo`0OOol00`00Oomoo`0<Ool00`00Ool0000200000goo
001oo`0hOol00`00DMAAe00@DM@00`00DMAAe00gDM@2000AGmh2000YOol00`00Oomoo`0;Ool00`00
Oomoo`06Ool000Moo`03001oogoo01moo`03001oogoo00eoo`D003]oo`8000IAe003001Ae57D00MA
e003001Ae57D03EAe080015OgP8002]oo`03001oogoo00]oo`03001oogoo00Ioo`001goo00<007oo
Ool07goo00<007ooOol03Goo1@00?Goo0P00157D00<0057DDM@00e7D00D0057DDMAAe00003IAe003
001OgUoN00mOgP8002eoo`03001oogoo00]oo`03001oogoo00Ioo`001goo00<007ooOol07goo00<0
07ooOol03Woo0`00@7oo00D0057DDMAAe00000EAe004001Ae57D000eDM@2000AGmh00`00Oomoo`0]
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool000Moo`03001oogoo01moo`03001oogoo00ioo`<0045o
o`800003DM@0057D00AAe004001Ae57D000cDM@2000AGmh2000`Ool00`00Oomoo`0;Ool00`00Oomo
o`06Ool000Moo`03001oogoo01moo`03001oogoo00moo`03001oogoo049oo`8000AAe005001Ae57D
DM@0000aDM@2000AGmh2000bOol00`00Oomoo`0;Ool00`00Oomoo`06Ool000Moo`03001oogoo01mo
o`03001oogoo00moo`03001oogoo04=oo`8000=Ae004001Ae57D000aDM@00`00GmiOgP0?Gmh2000d
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool000Moo`03001oogoo01moo`03001oogoo05Eoo`06001o
o`00001Ae0000U7D00<0057DDM@01e7D00<0057DDM@08e7D0P004EoN00<007ooOol0=7oo00<007oo
Ool02goo00<007ooOol01Woo0007Ool00`00Oomoo`0OOol00`00Oomoo`1EOol01000Oomoogoo0P00
0U7D00<0057DDM@01U7D00<0057DDM@08U7D0P004EoN0P00=goo00<007ooOol02goo00<007ooOol0
1Woo0007Ool00`00Oomoo`0OOol00`00Oomoo`1EOol00`00Oomoo`02Ool30008DM@00`00DMAAe00Q
DM@2000AGmh2000iOol00`00Oomoo`0;Ool00`00Oomoo`06Ool000Moo`03001oogoo01moo`03001o
ogoo015oo`8004=oo`06001oogooOol007oo;@004EoN0P00=7oo20003Goo00<007ooOol01Woo0007
Ool00`00Oomoo`0OOol00`00Oomoo`0BOol00`00Oomoo`11Ool01000Oomoo`000Woo0`0012/O00<0
02/O:al08b/O00<005oNGmh035oN0P009goo3`0027oo00<007ooOol02Woo00<007ooOol01Woo0007
Ool00`00Oomoo`0OOol00`00Oomoo`0BOol00`00Oomoo`11Ool02@00Oomoo`00Ool007oo001oo`02
00000b/O000[7`0V:al2000;Gmh00`00Oomoo`0HOol?000HOol00`00Oomoo`09Ool00`00Oomoo`06
Ool000Moo`03001oogoo01moo`03001oogoo015oo`03001oo`00049oo`08001oogoo001oo`00Ool0
00=oo`8002T[7`03001OgUoN00IOgP8000aoo`l002Qoo`03001oogoo00Qoo`03001oogoo00Ioo`00
1goo00<007ooOol07goo00<007ooOol04Goo00<007oo0000@Woo00D007ooOol007oo008000=oo`03
001oogoo008002P[7`03001OgUoN00=OgQ0003Qoo`03001oogoo00Moo`03001oogoo00Ioo`001goo
00<007ooOol07goo00<007ooOol047oo0P0000=oo`000000@Goo00<007ooOol00P0000Eoo`00Oomo
o`0000EooaH000/[7`l004Moo`03001oogoo00Ioo`03001oogoo00Ioo`001goo00<007ooOol07goo
00<007ooOol0EWoo00@007oo001oo`80009oo`03001oogoo01IooaX004aoo`03001oogoo00Ioo`03
001oogoo00Eoo`001Woo00<007ooOol087oo00<007ooOol0EWoo00P007oo000007oo001oo`002Woo
3`00Igoo00<007ooOol01Goo00<007ooOol01Goo0006Ool00`00Oomoo`0POol00`00Oomoo`1FOol0
0`00Ool0000?001gOol00`00Oomoo`04Ool00`00Oomoo`05Ool000Ioo`03001oogoo021oo`03001o
ogoo04Yooa400003Ool007oo089oo`03001oogoo00=oo`03001oogoo00Eoo`001Woo00<007ooOol0
87oo00<007ooOol0>goo3`003Goo0`0000=oo`00Ool0Q7oo00<007ooOol00Woo00<007ooOol01Goo
0006Ool00`00Oomoo`0POol00`00Oomoo`0/Ool?000LOol40027Ool01@00Oomoogoo00001goo0006
Ool00`00Oomoo`0POol00`00Oomoo`0MOol?000[Ool30029Ool01000Oomoo`001goo0006Ool00`00
Oomoo`0POol00`00Oomoo`0?Ool>000jOol2002;Ool00`00Ool00007Ool000Ioo`03001oogoo021o
o`03001oogoo00l004Qoo`03001oogoo08]oo`8000Moo`001Woo00<007ooOol057oo3`00ggoo2000
1goo0006Ool00`00Oomoo`05Ool?000<Ool00`00Oomoo`3?Ool@000?Ool000Ioo`P001Yoo`03001o
ogoo05Yoo`8006Eoo`l001moo`0027oo0P007Woo00<007ooOol0Fgoo00<007ooOol0Dgoo4000;Woo
000:Ool3000KOol00`00Oomoo`1KOol00`00Oomoo`13Ool@000nOol000eoo`<001Qoo`03001oogoo
05Yoo`03001oo`0003Eoo`l004ioo`0047oo0P005Woo00<007ooOol0FWoo00<007oo00009Goo4000
GGoo000BOol3000COol00`00Oomoo`1IOol200000goo0000000EOol?001]Ool001Eoo`80015oo`03
001oogoo06=ooa0007aoo`005goo0`003Woo00<007ooOol0Dgoo4000S7oo000JOol3000;Ool00`00
Oomoo`14Ool?002LOol001eoo`8000Uoo`03001oogoo03Aooa000:]oo`007goo0`001Woo00<007oo
Ool09Goo3`00^goo000ROol30003Ool00`00Oomoo`0EOol@003:Ool002Eoo`800003Ool007oo00Io
oa000=Yoo`009goo2@00jWoo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00
ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {239, 0}} -> {-0.021806, 0.0325057, 0.00372773,
   0.00372773}}]
}, Open  ]],

Cell[TextData[{
  "In general, this method of constraining the relative rotation between two \
moving bodies can be used to model any type of rotational linkage. The ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function that is used to relate the two extra variables can contain and \
algebraic expression that is arbitrarily complex. This allows abstract or \
nonlinear relationships to be modeled. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following statements generate the graphics in this section. These ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " commands are defined in Chapter 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2D Gear Drive Mechanism"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
graph = Graphics[{PointSize[.08],
  {RGBColor[1,0,0],Circle[{0,0},2.0],Circle[{5,0},3.0],
   Point[{0,0}]},
  {RGBColor[0,1,0],Circle[Location[pinion,0],3.0],
   Circle[{5,0},2.0], Point[{5,0}],
   Tangent[Point[drivepulley, 0],2.0, Point[pinion, 0], 3.0]},
  {RGBColor[0,0,1],Circle[Location[pinion,0],1.5],
   Point[Location[pinion,0]]},
  {RGBColor[0,1,1],Bar[Line[rack,{-6,0},{6,0}],2,0]},
  LocalAxes[All,1.4]},
  AspectRatio->Automatic,Frame->True,FrameTicks->None];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[graph/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["3D Gear Drive Mechanism"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph = Graphics3D[{\n  Bar[Line[drivebevel, {-1,0,0}, 0], {2.0, 4.0/3}, \
16],\n  Bar[Line[drivespur,  {0,0,-2}, {0,0,-4.0/3}], {3.0, 2.0}  , 16],\n  \
Bar[Line[drivespur, {0,0,-4.0/3}, {0,0,-1.0/3}], 1.5, 16],\n  \
Bar[Line[pinion, {0,0,-4.0/3}, {0,0,-1.0/3}], 3.0, 16],\n  Box[rack, \
{{-3,0,-4.0/3}, {3,1,-1.0/3}}],\n  \
LocalAxes[{drivebevel,drivespur,pinion,rack}, 3.5]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[graph/.LastSolve[],ViewPoint->{1,1,3}, ViewVertical->{0,1,0}];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["General Gear "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph = Graphics3D[{\n  Bar[Line[pinion, 0, {0,0,-1}], 1.0, 12],\n  \
Bar[Line[gear,   0, {0,0,-1}], 3.0, 12],\n  LocalAxes[{pinion,gear}, \
3.5]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[graph/.LastSolve[],ViewPoint->{1,1,3}, ViewVertical->{0,1,0}];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 700},
WindowMargins->{{80, Automatic}, {Automatic, 17}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 83, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1839, 57, 78, 2, 47, "Subsection"],
Cell[1920, 61, 857, 18, 185, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2814, 84, 121, 3, 33, "Section",
  PageBreakAbove->True],
Cell[2938, 89, 672, 13, 128, "Text"],

Cell[CellGroupData[{
Cell[3635, 106, 98, 2, 47, "Subsection"],
Cell[3736, 110, 735, 22, 112, "Text"],

Cell[CellGroupData[{
Cell[4496, 136, 193, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[4714, 148, 203, 4, 66, "Input"],
Cell[4920, 154, 15568, 494, 131, 4916, 356, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20537, 654, 193, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[20755, 666, 273, 5, 85, "Input"],
Cell[21031, 673, 16124, 506, 196, 5326, 367, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[37182, 1183, 1178, 33, 171, "Text"],
Cell[38363, 1218, 6070, 236, 332, "Special3"],
Cell[44436, 1456, 122, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[44561, 1461, 1749, 56, 231, "Text"],
Cell[46313, 1519, 2610, 105, 163, "Special3"],
Cell[48926, 1626, 136, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[49065, 1631, 1138, 39, 133, "Text"],

Cell[CellGroupData[{
Cell[50228, 1674, 188, 8, 24, "SmallText"],
Cell[50419, 1684, 84, 2, 25, "Input"]
}, Open  ]],
Cell[50518, 1689, 258, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[50801, 1704, 130, 3, 25, "Input"],
Cell[50934, 1709, 210, 4, 86, "Output"]
}, Open  ]],
Cell[51159, 1716, 543, 24, 54, "Text"],
Cell[51705, 1742, 108, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[51838, 1748, 175, 3, 45, "Input"],
Cell[52016, 1753, 21858, 743, 229, 7189, 556, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[73889, 2499, 838, 32, 93, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[74764, 2536, 104, 2, 31, "Subsection"],
Cell[74871, 2540, 334, 10, 53, "Text"],

Cell[CellGroupData[{
Cell[75230, 2554, 118, 2, 24, "SmallText"],
Cell[75351, 2558, 22044, 671, 295, 3914, 442, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[97410, 3232, 94, 2, 43, "Subsubsection"],
Cell[97507, 3236, 1100, 36, 151, "Text"],

Cell[CellGroupData[{
Cell[98632, 3276, 157, 4, 24, "SmallText"],
Cell[98792, 3282, 223, 6, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99052, 3293, 113, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[99190, 3299, 158, 3, 45, "Input"],
Cell[99351, 3304, 21572, 617, 290, 5818, 416, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[120950, 3925, 89, 2, 43, "Subsubsection"],
Cell[121042, 3929, 123, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[121190, 3935, 140, 3, 24, "SmallText"],
Cell[121333, 3940, 130, 4, 65, "Input"]
}, Open  ]],
Cell[121478, 3947, 234, 5, 59, "Special1"],
Cell[121715, 3954, 352, 10, 60, "Special1"],
Cell[122070, 3966, 349, 6, 76, "Special1"],

Cell[CellGroupData[{
Cell[122444, 3976, 133, 3, 24, "SmallText"],
Cell[122580, 3981, 30776, 706, 421, 5058, 384, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153393, 4692, 135, 3, 24, "SmallText"],
Cell[153531, 4697, 136, 3, 45, "Input"]
}, Open  ]],
Cell[153682, 4703, 95, 2, 43, "Subsubsection"],
Cell[153780, 4707, 258, 8, 53, "Text"],
Cell[154041, 4717, 267, 9, 43, "Special1"],
Cell[154311, 4728, 266, 9, 43, "Special1"],
Cell[154580, 4739, 389, 13, 44, "Special1"],
Cell[154972, 4754, 512, 15, 79, "Special1"],
Cell[155487, 4771, 503, 15, 73, "Text"],

Cell[CellGroupData[{
Cell[156015, 4790, 136, 3, 24, "SmallText"],
Cell[156154, 4795, 366, 6, 145, "Input"]
}, Open  ]],
Cell[156535, 4804, 91, 2, 43, "Subsubsection"],
Cell[156629, 4808, 476, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[157130, 4826, 191, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[157346, 4838, 81, 2, 25, "Input"],
Cell[157430, 4842, 602, 14, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[158081, 4862, 205, 8, 24, "SmallText"],
Cell[158289, 4872, 21462, 678, 295, 4089, 458, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179788, 5555, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[180001, 5567, 81, 2, 25, "Input"],
Cell[180085, 5571, 606, 14, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[180740, 5591, 205, 8, 24, "SmallText"],
Cell[180948, 5601, 20878, 653, 295, 3870, 438, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[201863, 6259, 190, 8, 24, "SmallText"],
Cell[202056, 6269, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[202174, 6277, 98, 2, 31, "Subsection"],
Cell[202275, 6281, 1664, 37, 341, "Text"],

Cell[CellGroupData[{
Cell[203964, 6322, 193, 8, 24, "SmallText"],
Cell[204160, 6332, 154, 4, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204351, 6341, 113, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[204489, 6347, 233, 4, 65, "Input"],
Cell[204725, 6353, 47160, 1188, 226, 11511, 742, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[251912, 7545, 1262, 34, 189, "Text"],
Cell[253177, 7581, 5939, 240, 301, "Special3"],
Cell[259119, 7823, 127, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[259249, 7828, 7453, 310, 317, "Special3"],
Cell[266705, 8140, 131, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[266839, 8145, 2436, 62, 478, "Text"],
Cell[269278, 8209, 3314, 133, 209, "Special3"],
Cell[272595, 8344, 136, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[272734, 8349, 1060, 36, 114, "Text"],

Cell[CellGroupData[{
Cell[273819, 8389, 188, 8, 24, "SmallText"],
Cell[274010, 8399, 84, 2, 25, "Input"]
}, Open  ]],
Cell[274109, 8404, 258, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[274392, 8419, 152, 3, 45, "Input"],
Cell[274547, 8424, 546, 10, 192, "Output"]
}, Open  ]],
Cell[275108, 8437, 472, 20, 54, "Text"],

Cell[CellGroupData[{
Cell[275605, 8461, 121, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[275751, 8467, 279, 6, 65, "Input"],
Cell[276033, 8475, 59274, 1040, 269, 6428, 382, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[335334, 9519, 838, 32, 93, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[336209, 9556, 104, 2, 31, "Subsection"],
Cell[336316, 9560, 341, 10, 72, "Text"],

Cell[CellGroupData[{
Cell[336682, 9574, 114, 2, 24, "SmallText"],
Cell[336799, 9578, 53915, 2238, 295, 23711, 1860, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[390729, 11819, 94, 2, 43, "Subsubsection"],
Cell[390826, 11823, 1454, 49, 189, "Text"],
Cell[392283, 11874, 157, 4, 24, "SmallText"],
Cell[392443, 11880, 174, 4, 65, "Input"],
Cell[392620, 11886, 90, 2, 43, "Subsubsection"],
Cell[392713, 11890, 124, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[392862, 11896, 143, 4, 24, "SmallText"],
Cell[393008, 11902, 130, 4, 65, "Input"]
}, Open  ]],
Cell[393153, 11909, 356, 6, 93, "Special1"],
Cell[393512, 11917, 434, 12, 77, "Special1"],
Cell[393949, 11931, 312, 6, 76, "Special1"],
Cell[394264, 11939, 123, 2, 24, "SmallText"],
Cell[394390, 11943, 58790, 2113, 468, 18885, 1614, "GraphicsData", 
"PostScript", "Graphics"],

Cell[CellGroupData[{
Cell[453205, 14060, 229, 7, 24, "SmallText"],
Cell[453437, 14069, 147, 4, 45, "Input"]
}, Open  ]],
Cell[453599, 14076, 95, 2, 43, "Subsubsection"],
Cell[453697, 14080, 175, 4, 52, "Text"],
Cell[453875, 14086, 265, 9, 43, "Special1"],
Cell[454143, 14097, 265, 9, 43, "Special1"],
Cell[454411, 14108, 382, 13, 44, "Special1"],
Cell[454796, 14123, 758, 26, 80, "Special1"],
Cell[455557, 14151, 711, 22, 92, "Text"],

Cell[CellGroupData[{
Cell[456293, 14177, 136, 3, 24, "SmallText"],
Cell[456432, 14182, 545, 11, 205, "Input"]
}, Open  ]],
Cell[456992, 14196, 91, 2, 43, "Subsubsection"],
Cell[457086, 14200, 645, 22, 92, "Text"],

Cell[CellGroupData[{
Cell[457756, 14226, 191, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[457972, 14238, 81, 2, 25, "Input"],
Cell[458056, 14242, 767, 14, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[458872, 14262, 204, 8, 24, "SmallText"],
Cell[459079, 14272, 51440, 2063, 295, 21175, 1684, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[510556, 16340, 193, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[510774, 16352, 81, 2, 25, "Input"],
Cell[510858, 16356, 773, 14, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[511680, 16376, 195, 8, 24, "SmallText"],
Cell[511878, 16386, 49998, 2075, 292, 19466, 1693, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[561913, 18466, 191, 8, 24, "SmallText"],
Cell[562107, 18476, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[562225, 18484, 92, 2, 31, "Subsection"],
Cell[562320, 18488, 2515, 65, 441, "Text"],
Cell[564838, 18555, 1299, 52, 101, "Special3"],
Cell[566140, 18609, 137, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[566280, 18614, 1915, 67, 256, "Special3"],
Cell[568198, 18683, 204, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[568405, 18694, 754, 23, 130, "Text"],

Cell[CellGroupData[{
Cell[569184, 18721, 189, 8, 24, "SmallText"],
Cell[569376, 18731, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569497, 18738, 112, 2, 24, "SmallText"],
Cell[569612, 18742, 227, 5, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569876, 18752, 198, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[570099, 18764, 127, 3, 45, "Input"],
Cell[570229, 18769, 202, 4, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[570458, 18777, 108, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[570591, 18783, 168, 3, 45, "Input"],
Cell[570762, 18788, 21796, 562, 304, 5003, 349, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[592573, 19353, 580, 15, 92, "Text"],

Cell[CellGroupData[{
Cell[593178, 19372, 129, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[593332, 19379, 139, 3, 45, "Input"],
Cell[593474, 19384, 62, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[593597, 19392, 95, 2, 31, "Subsection"],
Cell[593695, 19396, 781, 17, 148, "Text"],
Cell[594479, 19415, 534, 20, 56, "Special3"],
Cell[595016, 19437, 120, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[595139, 19442, 100, 2, 43, "Subsubsection"],
Cell[595242, 19446, 594, 17, 92, "Text"],

Cell[CellGroupData[{
Cell[595861, 19467, 120, 2, 24, "SmallText"],
Cell[595984, 19471, 129, 3, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[596150, 19479, 185, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[596360, 19490, 169, 5, 45, "Input"],
Cell[596532, 19497, 204, 4, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[596785, 19507, 108, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[596918, 19513, 169, 3, 45, "Input"],
Cell[597090, 19518, 18261, 527, 246, 5135, 359, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[615378, 20049, 699, 19, 111, "Text"],

Cell[CellGroupData[{
Cell[616102, 20072, 132, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[616259, 20079, 93, 2, 25, "Input"],
Cell[616355, 20083, 204, 4, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[616586, 20091, 94, 2, 43, "Subsubsection"],
Cell[616683, 20095, 130, 3, 33, "Text"],
Cell[616816, 20100, 431, 13, 61, "Special1"],
Cell[617250, 20115, 236, 8, 26, "Special1"],
Cell[617489, 20125, 399, 12, 60, "Special1"],

Cell[CellGroupData[{
Cell[617913, 20141, 111, 2, 24, "SmallText"],
Cell[618027, 20145, 101, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[618165, 20153, 116, 2, 24, "SmallText"],
Cell[618284, 20157, 381, 9, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[618702, 20171, 135, 3, 24, "SmallText"],
Cell[618840, 20176, 103, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[618980, 20183, 119, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[619124, 20189, 101, 2, 25, "Input"],
Cell[619228, 20193, 1156, 27, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[620433, 20226, 122, 2, 24, "SmallText"],
Cell[620558, 20230, 21792, 1558, 76, 13139, 1446, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[642365, 21791, 103, 2, 43, "Subsubsection"],
Cell[642471, 21795, 458, 13, 73, "Text"],

Cell[CellGroupData[{
Cell[642954, 21812, 130, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[643109, 21819, 106, 2, 25, "Input"],
Cell[643218, 21823, 127, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[643394, 21831, 137, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[643556, 21838, 173, 4, 35, "Input"],
Cell[643732, 21844, 380, 7, 73, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[644161, 21857, 224, 5, 40, "SmallText"],

Cell[CellGroupData[{
Cell[644410, 21866, 185, 4, 65, "Input"],
Cell[644598, 21872, 11392, 367, 189, 3785, 267, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[656051, 22246, 92, 2, 31, "Subsection"],
Cell[656146, 22250, 1145, 27, 225, "Text"],
Cell[657294, 22279, 115, 2, 24, "SmallText"],
Cell[657412, 22283, 366, 7, 125, "Input"],
Cell[657781, 22292, 416, 14, 40, "SmallText"],
Cell[658200, 22308, 281, 5, 88, "Input"],
Cell[658484, 22315, 148, 4, 24, "SmallText"],
Cell[658635, 22321, 287, 6, 105, "Input"],
Cell[658925, 22329, 149, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[659099, 22337, 266, 6, 85, "Input"],
Cell[659368, 22345, 11701, 335, 229, 3630, 229, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[671118, 22686, 126, 2, 31, "Subsection"],
Cell[671247, 22690, 760, 26, 93, "Text"],
Cell[672010, 22718, 215, 8, 24, "SmallText"],
Cell[672228, 22728, 414, 8, 165, "Input"],
Cell[672645, 22738, 981, 34, 151, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[673663, 22777, 95, 2, 31, "Subsection"],
Cell[673761, 22781, 431, 13, 73, "Text"],
Cell[674195, 22796, 2240, 86, 145, "Special3"],
Cell[676438, 22884, 137, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[676578, 22889, 683, 24, 71, "Special3"],
Cell[677264, 22915, 205, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[677472, 22926, 648, 20, 92, "Text"],

Cell[CellGroupData[{
Cell[678145, 22950, 109, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[678279, 22956, 176, 3, 45, "Input"],
Cell[678458, 22961, 653, 16, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[679138, 22981, 705, 20, 132, "Text"],

Cell[CellGroupData[{
Cell[679868, 23005, 124, 2, 24, "SmallText"],
Cell[679995, 23009, 458, 10, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[680490, 23024, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[680703, 23036, 101, 2, 25, "Input"],
Cell[680807, 23040, 873, 16, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[681729, 23062, 108, 2, 24, "SmallText"],
Cell[681840, 23066, 12048, 315, 161, 2541, 192, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[693925, 23386, 191, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[694141, 23394, 95, 2, 37, "Input"],
Cell[694239, 23398, 78, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[694366, 23405, 191, 8, 24, "SmallText"],
Cell[694560, 23415, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[694678, 23423, 91, 2, 31, "Subsection"],
Cell[694772, 23427, 264, 8, 53, "Text"],
Cell[695039, 23437, 105, 2, 43, "Subsubsection"],
Cell[695147, 23441, 99, 2, 25, "Input"],
Cell[695249, 23445, 306, 6, 115, "Input"],
Cell[695558, 23453, 238, 5, 79, "Input"],
Cell[695799, 23460, 94, 2, 25, "Input"],
Cell[695896, 23464, 373, 7, 115, "Input"],
Cell[696272, 23473, 240, 5, 61, "Input"],
Cell[696515, 23480, 107, 2, 25, "Input"],
Cell[696625, 23484, 261, 6, 97, "Input"],
Cell[696889, 23492, 191, 4, 61, "Input"],
Cell[697083, 23498, 169, 4, 61, "Input"],
Cell[697255, 23504, 180, 4, 61, "Input"],
Cell[697438, 23510, 172, 5, 61, "Input"],
Cell[697613, 23517, 97, 2, 43, "Subsubsection"],
Cell[697713, 23521, 372, 7, 133, "Input"],
Cell[698088, 23530, 92, 2, 25, "Input"],
Cell[698183, 23534, 123, 2, 25, "Input"],
Cell[698309, 23538, 94, 2, 43, "Subsubsection"],
Cell[698406, 23542, 491, 8, 205, "Input"],
Cell[698900, 23552, 86, 2, 25, "Input"],
Cell[698989, 23556, 110, 2, 43, "Subsubsection"],
Cell[699102, 23560, 99, 2, 25, "Input"],
Cell[699204, 23564, 427, 8, 151, "Input"],
Cell[699634, 23574, 282, 5, 97, "Input"],
Cell[699919, 23581, 93, 2, 25, "Input"],
Cell[700015, 23585, 232, 5, 79, "Input"],
Cell[700250, 23592, 174, 4, 61, "Input"],
Cell[700427, 23598, 211, 4, 79, "Input"],
Cell[700641, 23604, 333, 6, 115, "Input"],
Cell[700977, 23612, 224, 5, 79, "Input"],
Cell[701204, 23619, 105, 2, 25, "Input"],
Cell[701312, 23623, 177, 4, 43, "Input"],
Cell[701492, 23629, 238, 5, 79, "Input"],
Cell[701733, 23636, 88, 2, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[701870, 23644, 122, 3, 33, "Section",
  PageBreakAbove->True],
Cell[701995, 23649, 470, 10, 90, "Text"],

Cell[CellGroupData[{
Cell[702490, 23663, 99, 2, 47, "Subsection"],
Cell[702592, 23667, 335, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[702952, 23680, 3320, 122, 314, "Special3"],
Cell[706275, 23804, 124, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[706436, 23812, 1128, 41, 100, "Special3"],
Cell[707567, 23855, 129, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[707711, 23861, 1462, 41, 244, "Text"],

Cell[CellGroupData[{
Cell[709198, 23906, 119, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[709342, 23912, 261, 6, 105, "Input"],
Cell[709606, 23920, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[709692, 23925, 1042, 29, 190, "Text"],

Cell[CellGroupData[{
Cell[710759, 23958, 1138, 38, 101, "Special3"],
Cell[711900, 23998, 168, 5, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[712083, 24006, 149, 4, 33, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[712269, 24015, 105, 2, 31, "Subsection"],
Cell[712377, 24019, 608, 13, 110, "Text"],

Cell[CellGroupData[{
Cell[713010, 24036, 121, 2, 24, "SmallText"],
Cell[713134, 24040, 22690, 490, 178, 3394, 247, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[735861, 24535, 89, 2, 43, "Subsubsection"],
Cell[735953, 24539, 211, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[736189, 24547, 140, 3, 24, "SmallText"],
Cell[736332, 24552, 191, 6, 105, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[736572, 24564, 94, 2, 29, "Subsubsection"],
Cell[736669, 24568, 140, 3, 33, "Text"],
Cell[736812, 24573, 252, 9, 43, "Special1"],
Cell[737067, 24584, 224, 8, 26, "Special1"],
Cell[737294, 24594, 295, 9, 43, "Special1"],
Cell[737592, 24605, 236, 8, 26, "Special1"],
Cell[737831, 24615, 287, 9, 43, "Special1"],
Cell[738121, 24626, 232, 8, 26, "Special1"],
Cell[738356, 24636, 306, 9, 43, "Special1"],
Cell[738665, 24647, 304, 9, 43, "Special1"],

Cell[CellGroupData[{
Cell[738994, 24660, 123, 2, 24, "SmallText"],
Cell[739120, 24664, 686, 12, 285, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[739855, 24682, 91, 2, 29, "Subsubsection"],
Cell[739949, 24686, 225, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[740199, 24695, 149, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[740373, 24703, 146, 3, 25, "Input"],
Cell[740522, 24708, 235, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[740784, 24715, 619, 21, 74, "Text"],

Cell[CellGroupData[{
Cell[741428, 24740, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[741641, 24752, 74, 2, 25, "Input"],
Cell[741718, 24756, 665, 13, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[742432, 24775, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[742645, 24787, 138, 3, 25, "Input"],
Cell[742786, 24792, 152, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[742987, 24800, 203, 8, 24, "SmallText"],
Cell[743193, 24810, 22040, 483, 175, 3375, 247, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[765270, 25298, 190, 8, 24, "SmallText"],
Cell[765463, 25308, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[765593, 25317, 99, 2, 31, "Subsection"],
Cell[765695, 25321, 1301, 28, 284, "Text"],

Cell[CellGroupData[{
Cell[767021, 25353, 4660, 165, 420, "Special3"],
Cell[771684, 25520, 124, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[771823, 25526, 971, 25, 189, "Text"],

Cell[CellGroupData[{
Cell[772819, 25555, 2656, 97, 237, "Special3"],
Cell[775478, 25654, 129, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[775644, 25662, 2483, 98, 205, "Special3"],
Cell[778130, 25762, 135, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[778280, 25768, 452, 18, 54, "Text"],

Cell[CellGroupData[{
Cell[778757, 25790, 1858, 72, 160, "Special3"],
Cell[780618, 25864, 122, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[780777, 25872, 1599, 58, 160, "Special3"],
Cell[782379, 25932, 129, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[782523, 25938, 951, 29, 131, "Text"],

Cell[CellGroupData[{
Cell[783499, 25971, 189, 8, 24, "SmallText"],
Cell[783691, 25981, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[783812, 25988, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[783951, 25994, 246, 6, 105, "Input"],
Cell[784200, 26002, 64, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[784325, 26010, 106, 2, 31, "Subsection"],
Cell[784434, 26014, 665, 14, 129, "Text"],

Cell[CellGroupData[{
Cell[785124, 26032, 115, 2, 24, "SmallText"],
Cell[785242, 26036, 64384, 2813, 296, 29466, 2377, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[849663, 28854, 89, 2, 43, "Subsubsection"],
Cell[849755, 28858, 211, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[849991, 28866, 143, 4, 24, "SmallText"],
Cell[850137, 28872, 250, 7, 165, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[850436, 28885, 94, 2, 29, "Subsubsection"],
Cell[850533, 28889, 140, 3, 33, "Text"],
Cell[850676, 28894, 494, 16, 60, "Special1"],
Cell[851173, 28912, 228, 8, 26, "Special1"],
Cell[851404, 28922, 589, 15, 78, "Special1"],
Cell[851996, 28939, 479, 8, 76, "Special2"],
Cell[852478, 28949, 281, 9, 43, "Special1"],
Cell[852762, 28960, 517, 14, 77, "Special1"],
Cell[853282, 28976, 230, 8, 26, "Special1"],
Cell[853515, 28986, 410, 11, 60, "Special1"],
Cell[853928, 28999, 225, 8, 26, "Special1"],

Cell[CellGroupData[{
Cell[854178, 29011, 143, 4, 24, "SmallText"],
Cell[854324, 29017, 850, 15, 325, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[855223, 29038, 91, 2, 29, "Subsubsection"],
Cell[855317, 29042, 161, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[855503, 29050, 119, 2, 24, "SmallText"],
Cell[855625, 29054, 239, 4, 45, "Input"]
}, Open  ]],
Cell[855879, 29061, 616, 21, 74, "Text"],

Cell[CellGroupData[{
Cell[856520, 29086, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[856733, 29098, 82, 2, 25, "Input"],
Cell[856818, 29102, 1445, 26, 143, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[858312, 29134, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[858525, 29146, 105, 2, 25, "Input"],
Cell[858633, 29150, 118, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[858800, 29158, 203, 8, 24, "SmallText"],
Cell[859006, 29168, 63534, 2803, 295, 29349, 2376, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[922555, 31974, 417, 11, 72, "Text"],
Cell[922975, 31987, 232, 5, 76, "Print"],

Cell[CellGroupData[{
Cell[923232, 31996, 152, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[923409, 32004, 237, 5, 78, "Input"],
Cell[923649, 32011, 54, 1, 29, "Output"],
Cell[923706, 32014, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[923833, 32023, 112, 2, 31, "Subsection"],
Cell[923948, 32027, 953, 25, 170, "Text"],
Cell[924904, 32054, 228, 8, 26, "Special1"],
Cell[925135, 32064, 239, 8, 26, "Special1"],
Cell[925377, 32074, 231, 8, 26, "Special1"],
Cell[925611, 32084, 294, 9, 43, "Special1"],
Cell[925908, 32095, 284, 9, 43, "Special1"],
Cell[926195, 32106, 285, 9, 43, "Special1"],
Cell[926483, 32117, 264, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[926772, 32126, 116, 2, 24, "SmallText"],
Cell[926891, 32130, 102, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[927030, 32138, 208, 8, 24, "SmallText"],
Cell[927241, 32148, 721, 13, 305, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[927999, 32166, 168, 4, 24, "SmallText"],
Cell[928170, 32172, 105, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[928312, 32179, 205, 7, 24, "SmallText"],
Cell[928520, 32188, 98, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[928655, 32195, 107, 2, 24, "SmallText"],
Cell[928765, 32199, 87, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[928889, 32206, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[929102, 32218, 71, 2, 25, "Input"],
Cell[929176, 32222, 324, 5, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[929549, 32233, 197, 8, 24, "SmallText"],
Cell[929749, 32243, 38254, 1294, 248, 11639, 960, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[968018, 33540, 500, 11, 91, "Text"],

Cell[CellGroupData[{
Cell[968543, 33555, 191, 8, 24, "SmallText"],
Cell[968737, 33565, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[968855, 33573, 91, 2, 31, "Subsection"],
Cell[968949, 33577, 264, 8, 53, "Text"],
Cell[969216, 33587, 106, 2, 43, "Subsubsection"],
Cell[969325, 33591, 545, 14, 223, "Input"],
Cell[969873, 33607, 100, 2, 25, "Input"],
Cell[969976, 33611, 106, 2, 43, "Subsubsection"],
Cell[970085, 33615, 454, 8, 169, "Input"],
Cell[970542, 33625, 146, 4, 43, "Input"],
Cell[970691, 33631, 96, 2, 43, "Subsubsection"],
Cell[970790, 33635, 224, 5, 79, "Input"],
Cell[971017, 33642, 146, 4, 43, "Input"],
Cell[971166, 33648, 85, 2, 25, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

