(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    426052,      15681]*)
(*NotebookOutlinePosition[    426993,      15713]*)
(*  CellTagsIndexPosition[    426949,      15709]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["8.  Inverse Dynamics", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers ",
  StyleBox["Mechanical Systems'",
    FontSlant->"Italic"],
  "s basic dynamic modeling capabilities for fully constrained models. If \
mass properties are defined for the bodies in a model, ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " can calculate the inertial loads on the model and the resulting reaction \
forces. Because the inertial loads are a function of the velocity and \
acceleration of the bodies, a model must have some dependence on time in \
order to have nonzero inertial loads. The forces that result from an inverse \
dynamic analysis are represented in the same manner as those of a static \
analysis, in the form of Lagrange multipliers (generalized forces). The free \
response dynamics of underconstrained systems is covered in Chapter 10."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["8.1  Inertia Properties"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "In order for any inertial loads to exist in a mechanism model, the bodies \
of the mechanism must have nonzero inertia properties, mass and inertia. The \
inertia properties of the bodies in a model are defined in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " body objects, and then added to the current model with the ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Body Options"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " body objects are used to define specific properties of a body in a \
mechanism model. Properties are defined with options to the ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Body[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object that defines the properties of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". Each property of the body is specified with an option."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The body object builder."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Two of the options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that are used for basic kinematic models are ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which are discussed in Section 2.1. The remaining three options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are used to define the inertia properties of a body."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["M",
    FontSlant->"Italic"],
  " specifies the mass of the body. ",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be specified by a number or an expression that evaluates to a number \
at run time.\n\n",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["I",
    FontSlant->"Italic"],
  " specifies the centroidal moment of inertia of the body. ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be specified by a number or an expression that evaluates to a number \
at run time. \n \n",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the location of the centroid of the body, in local coordinates. \
Centroid must be specified by a list of two numbers or two expressions that \
evaluate to numbers at run time.\n\n",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the default setting for all options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This setting leaves the current value of the property unchanged. If \
unspecified, the mass, inertia, and centroid of a body are 0, 0, and {0, 0}, \
respectively. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "2D inertia property options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["3D"], "Special5",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["M",
    FontSlant->"Italic"],
  " specifies the mass of the body. ",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be specified by a number or an expression that evaluates to a number \
at run time.\n\n",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the centroidal moments and products of inertia of the body. ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be specified by a list of six numbers or six expressions that \
evaluate to numbers at run time. These numbers are used to build the local \
inertia matrix of the body: \n",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Ixy",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Izx",
    FontSlant->"Italic"],
  StyleBox["},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n",
  StyleBox[" {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixy",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Iyy",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Iyz",
    FontSlant->"Italic"],
  StyleBox["},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n",
  StyleBox[" {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Izx",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Iyz",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Izz",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n \n",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the location of the centroid of the body, in local coordinates. \
",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be specified by a list of three numbers or three expressions that \
evaluate to numbers at run time. \n \n",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the default setting for all options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This setting leaves the current value of the property unchanged. If \
unspecified, the mass, inertia, and centroid of a body are 0, {0, 0, 0, 0, 0, \
0}, and {0, 0, 0}, respectively. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "3D inertia property options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Executing the ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function does not, in itself, have any affect on the current ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. The returned ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data objects must be added to the model with the ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetBodies[Body[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bn",
    FontSlant->"Italic"],
  StyleBox["um, opti",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["ons",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["... ",
    FontFamily->"Times"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " adds the inertia and geometry data contained in the body objects to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s internal database."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The body object processing function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Examples"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To use the 2D example mechanism of Section 1.2 in a dynamic analysis, \
inertia properties would be added with body objects and the ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The crankshaft-piston mechanism used three ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " bodies: the ground, crankshaft, and the piston. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the bodies in the model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crankshaft = 2; \)\), 
    \(\(piston = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"For this example, it is assumed that the constraints of the \
crankshaft-piston model have already been defined as they were in Section \
1.2. \n\nThere is no use in adding inertia properties to the ground body, as \
it cannot move, and therefore can sustain no inertial loads. The inertia \
properties of the crankshaft and piston are defined and added to the model."],
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the mass and inertia properties for the crankshaft and piston."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(bd[2] = Body[crankshaft, Mass \[Rule] 10, Inertia \[Rule] 0.4]; \)\), 
  
    \(bd[3] = Body[piston, Mass \[Rule] 2, Inertia \[Rule] 0.01]\)}], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(SysBody[3, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The inertia properties must be incorporated into the model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[2], bd[3]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Because the default setting for all options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which leaves the current values of properties unchanged, a single \
inertia property can be changed without affecting the rest of the model. An \
example is changing the location of the centroid of the piston without \
changing any other body properties."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This moves the centroid of the piston only. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[Body[piston, Centroid \[Rule] {0, 0.1}]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Each of the inertia property options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be interrogated to find the current settings of a body property. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mass[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the mass of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n \n",
  StyleBox["Inertia[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the moment of inertia (2D) or inertia matrix (3D) of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n \n",
  StyleBox["Centroid[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the local coordinates of the centroid of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Inertia property functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData["Here is the mass of the crankshaft."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mass[crankshaft]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(10\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package so that ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may be loaded. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Compound Inertia Properties"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The centroidal inertia properties of a 3D body in a mechanism model must \
be determined before the dynamic reaction forces in a model can be found. For \
complex 3D bodies, the values of the moments and products of inertia can be \
quite difficult to determine manually. This problem is alleviated by the \
availability of 3D solid modeling systems that can generally calculate the \
inertia properties of any solid body that they are capable of modeling.\n\nIf \
the inertia properties of a body must be found manually, the body can be \
subdivided into several elementary geometrical components such as spheres, \
cylinders, or plates. ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " provides several functions to aid in manipulating the inertia properties \
of a body or multiple bodies. These functions can make the task of \
determining the inertia properties of a slightly complex body more \
manageable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ParallelAxis[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", mass, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the parallel axis theorem to transform the inertia properties of a \
body into or out of a centroidal reference frame. Assuming that the ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, ...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are centroidal inertia properties of a body, ",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx', Iyy', ...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of inertia properties with respect to a noncentroidal reference frame in \
which ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the vector from the origin of the noncentroidal frame to the centroid. \
\n \n",
  StyleBox["ParallelAxis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid, mass, inertia, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies that the centroidal reference frame in which the specified \
inertia properties are calculated is rotated ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about the axis ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with respect to the noncentroidal frame. \n \n",
  StyleBox["CompositeInertia[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid1, mass1, inertia1, rotation1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ..., ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroidn, massn, inertian, rotationn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid, mass, inertia",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of the centroidal inertia properties of a composite body, made up of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " subcomponents. Given a local reference frame affixed to the composite \
body, each argument to ",
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the centroidal inertia properties of a subcomponent of the \
composite body, with respect to the local reference frame. If a ",
  StyleBox["rotationi",
    FontSlant->"Italic"],
  " is omitted, it is assumed to be ",
  StyleBox["{0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", that is, no rotation. \n \n",
  StyleBox["PrincipalAxes[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["I1, I2, I3",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1, axis2, axis3",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["I1... 3",
    FontSlant->"Italic"],
  " are the principal moments of inertia and ",
  StyleBox["axis1... 3",
    FontSlant->"Italic"],
  " are the corresponding principal axes of the body represented by the given \
inertia properties. ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1, axis2, axis3",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is effectively the rotation matrix from the reference frame in which the \
",
  StyleBox["Ixx",
    FontSlant->"Italic"],
  "... were specified to the principal axes reference frame."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Utilities for manipulating 3D inertia properties."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Inertia[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the inertia matrix: \n",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Ixy",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Izx",
    FontSlant->"Italic"],
  StyleBox["},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n",
  StyleBox[" {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixy",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Iyy",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Iyz",
    FontSlant->"Italic"],
  StyleBox["},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n",
  StyleBox[" {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Izx",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Iyz",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Izz",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another usage of ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Inertia Transformations"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The following example takes the inertia properties of a triangular plate \
that are calculated in a noncentroidal reference frame and convert them to a \
centroidal frame. The plate is an isosceles right triangle with two one-unit \
sides."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Triangular plate "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .98132  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.0113471 1.03258 0.0258146 1.03258 [ 
[(0)] .95161 .26226 -1 .14166 Msboxa 
[(0.5)] .89212 .19237 -1 .15138 Msboxa 
[(1)] .82493 .11344 -1 .16252 Msboxa 
[(1.5)] .74844 .02358 -1 .17544 Msboxa 
[(0)] .09579 .12528 -0.03924 1 Msboxa 
[(0.5)] .29719 .08989 -0.02101 1 Msboxa 
[(1)] .51008 .0525 -0.00161 1 Msboxa 
[(1.5)] .73548 .01291 .01908 1 Msboxa 
[(0)] .35614 .39556 1 -0.13516 Msboxa 
[(0.5)] .35355 .57646 1 -0.11116 Msboxa 
[(1)] .35088 .76327 1 -0.08636 Msboxa 
[(1.5)] .34814 .95629 1 -0.06072 Msboxa 
[ 0 0 0 0 ] 
[ 1 .98132 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.94992 .27708 m 
.73573 .02581 L 
s 
P 
p 
.002 w 
.93883 .26407 m 
.93244 .26498 L 
s 
P 
[(0)] .95161 .26226 -1 .14166 Mshowa 
p 
.002 w 
.87935 .1943 m 
.87297 .19527 L 
s 
P 
[(0.5)] .89212 .19237 -1 .15138 Mshowa 
p 
.002 w 
.81219 .11551 m 
.80581 .11654 L 
s 
P 
[(1)] .82493 .11344 -1 .16252 Mshowa 
p 
.002 w 
.73573 .02581 m 
.72937 .02693 L 
s 
P 
[(1.5)] .74844 .02358 -1 .17544 Mshowa 
p 
.001 w 
.92749 .25077 m 
.92365 .25132 L 
s 
P 
p 
.001 w 
.91588 .23715 m 
.91204 .2377 L 
s 
P 
p 
.001 w 
.90399 .2232 m 
.90016 .22377 L 
s 
P 
p 
.001 w 
.89182 .20893 m 
.88799 .2095 L 
s 
P 
p 
.001 w 
.86658 .17932 m 
.86275 .1799 L 
s 
P 
p 
.001 w 
.85349 .16396 m 
.84966 .16456 L 
s 
P 
p 
.001 w 
.84007 .14822 m 
.83624 .14882 L 
s 
P 
p 
.001 w 
.8263 .13207 m 
.82248 .13268 L 
s 
P 
p 
.001 w 
.7977 .09851 m 
.79387 .09914 L 
s 
P 
p 
.001 w 
.78282 .08106 m 
.779 .0817 L 
s 
P 
p 
.001 w 
.76755 .06314 m 
.76373 .06379 L 
s 
P 
p 
.001 w 
.75185 .04473 m 
.74804 .04539 L 
s 
P 
p 
.001 w 
.94992 .27708 m 
.94608 .27762 L 
s 
P 
P 
p 
p 
.002 w 
.05626 .14502 m 
.73573 .02581 L 
s 
P 
p 
.002 w 
.09529 .13817 m 
.09503 .14462 L 
s 
P 
[(0)] .09579 .12528 -0.03924 1 Mshowa 
p 
.002 w 
.29692 .1028 m 
.29678 .10925 L 
s 
P 
[(0.5)] .29719 .08989 -0.02101 1 Mshowa 
p 
.002 w 
.51006 .06541 m 
.51005 .07186 L 
s 
P 
[(1)] .51008 .0525 -0.00161 1 Mshowa 
p 
.002 w 
.73573 .02581 m 
.73585 .03227 L 
s 
P 
[(1.5)] .73548 .01291 .01908 1 Mshowa 
p 
.001 w 
.13474 .13125 m 
.1346 .13512 L 
s 
P 
p 
.001 w 
.17462 .12425 m 
.17449 .12813 L 
s 
P 
p 
.001 w 
.21494 .11718 m 
.21483 .12105 L 
s 
P 
p 
.001 w 
.2557 .11003 m 
.2556 .1139 L 
s 
P 
p 
.001 w 
.33859 .09549 m 
.33853 .09936 L 
s 
P 
p 
.001 w 
.38074 .08809 m 
.38069 .09197 L 
s 
P 
p 
.001 w 
.42336 .08062 m 
.42332 .08449 L 
s 
P 
p 
.001 w 
.46646 .07305 m 
.46644 .07693 L 
s 
P 
p 
.001 w 
.55416 .05767 m 
.55417 .06154 L 
s 
P 
p 
.001 w 
.59876 .04984 m 
.59879 .05372 L 
s 
P 
p 
.001 w 
.64389 .04193 m 
.64393 .0458 L 
s 
P 
p 
.001 w 
.68954 .03392 m 
.6896 .03779 L 
s 
P 
p 
.001 w 
.05626 .14502 m 
.05609 .14889 L 
s 
P 
P 
p 
p 
.002 w 
.36943 .35827 m 
.36102 .95551 L 
s 
P 
p 
.002 w 
.36893 .39383 m 
.37532 .39296 L 
s 
P 
[(0)] .35614 .39556 1 -0.13516 Mshowa 
p 
.002 w 
.36638 .57503 m 
.37279 .57432 L 
s 
P 
[(0.5)] .35355 .57646 1 -0.11116 Mshowa 
p 
.002 w 
.36374 .76216 m 
.37017 .76161 L 
s 
P 
[(1)] .35088 .76327 1 -0.08636 Mshowa 
p 
.002 w 
.36102 .95551 m 
.36746 .95511 L 
s 
P 
[(1.5)] .34814 .95629 1 -0.06072 Mshowa 
p 
.001 w 
.36842 .42961 m 
.37226 .42911 L 
s 
P 
p 
.001 w 
.36792 .46562 m 
.37176 .46513 L 
s 
P 
p 
.001 w 
.36741 .50186 m 
.37125 .50139 L 
s 
P 
p 
.001 w 
.36689 .53833 m 
.37074 .53788 L 
s 
P 
p 
.001 w 
.36586 .61198 m 
.36971 .61157 L 
s 
P 
p 
.001 w 
.36533 .64916 m 
.36918 .64877 L 
s 
P 
p 
.001 w 
.36481 .68658 m 
.36866 .68621 L 
s 
P 
p 
.001 w 
.36427 .72425 m 
.36813 .7239 L 
s 
P 
p 
.001 w 
.3632 .80032 m 
.36706 .80001 L 
s 
P 
p 
.001 w 
.36266 .83874 m 
.36652 .83844 L 
s 
P 
p 
.001 w 
.36212 .8774 m 
.36598 .87713 L 
s 
P 
p 
.001 w 
.36157 .91632 m 
.36543 .91607 L 
s 
P 
p 
.001 w 
.36943 .35827 m 
.37326 .35773 L 
s 
P 
P 
0 0 m 
1 0 L 
1 .98132 L 
0 .98132 L 
closepath 
clip 
newpath 
p 
.002 w 
.36943 .35827 m 
.36102 .95551 L 
s 
.36102 .95551 m 
.97419 .91827 L 
s 
.97419 .91827 m 
.94992 .27708 L 
s 
.94992 .27708 m 
.36943 .35827 L 
s 
.05626 .14502 m 
.73573 .02581 L 
s 
.73573 .02581 m 
.75052 .80109 L 
s 
.75052 .80109 m 
.02581 .85706 L 
s 
.02581 .85706 m 
.05626 .14502 L 
s 
.36943 .35827 m 
.36102 .95551 L 
s 
.36102 .95551 m 
.02581 .85706 L 
s 
.02581 .85706 m 
.05626 .14502 L 
s 
.05626 .14502 m 
.36943 .35827 L 
s 
.94992 .27708 m 
.73573 .02581 L 
s 
.73573 .02581 m 
.75052 .80109 L 
s 
.75052 .80109 m 
.97419 .91827 L 
s 
.97419 .91827 m 
.94992 .27708 L 
s 
P 
p 
.002 w 
.38687 .36023 m .2036 .23424 L .74655 .31013 L closepath p 
.612 .789 .966 r 
F P 
s 
P 
p 
.002 w 
.38687 .36023 m .74655 .31013 L .74729 .34785 L p 
.641 .492 .664 r 
F P 
s 
P 
p 
.002 w 
.74729 .34785 m .38642 .39639 L .38687 .36023 L p 
.641 .492 .664 r 
F P 
s 
P 
p 
.002 w 
.2036 .23424 m .38687 .36023 L .38642 .39639 L p 
.928 .732 .617 r 
F P 
s 
P 
p 
.002 w 
.38642 .39639 m .20243 .27429 L .2036 .23424 L p 
.928 .732 .617 r 
F P 
s 
P 
p 
.002 w 
.38642 .39639 m .20243 .27429 L .74729 .34785 L closepath p 
.606 .792 .97 r 
F P 
s 
P 
p 
.004 w 
.38001 .90839 m 
.38642 .39639 L 
s 
P 
p 
.004 w 
.39792 .83605 m 
.38001 .90839 L 
s 
P 
p 
.004 w 
.34542 .83237 m 
.38001 .90839 L 
s 
P 
p 
.004 w 
.43162 .79433 m 
.38001 .90839 L 
s 
P 
p 
.002 w 
.74655 .31013 m .2036 .23424 L .20243 .27429 L p 
.766 .591 .662 r 
F P 
s 
P 
p 
.004 w 
.11661 .19586 m 
.20301 .25423 L 
s 
P 
p 
.002 w 
.20243 .27429 m .74729 .34785 L .74655 .31013 L p 
.766 .591 .662 r 
F P 
s 
P 
p 
.004 w 
.74692 .32896 m 
.90083 .30789 L 
s 
P 
p 
.004 w 
.83539 .33078 m 
.90083 .30789 L 
s 
P 
p 
.004 w 
.38001 .90839 m 
.35711 .78871 L 
s 
P 
p 
.004 w 
.82213 .28061 m 
.90083 .30789 L 
s 
P 
p 
.004 w 
.90083 .30789 m 
.79373 .37606 L 
s 
P 
p 
.004 w 
.77441 .30523 m 
.90083 .30789 L 
s 
P 
p 
.004 w 
.12279 .23193 m 
.11661 .19586 L 
s 
P 
p 
.004 w 
.11661 .19586 m 
.17618 .29441 L 
s 
P 
p 
.004 w 
.16222 .18498 m 
.11661 .19586 L 
s 
P 
p 
.004 w 
.23156 .22874 m 
.11661 .19586 L 
s 
P 
p 
.002 w 
.05626 .14502 m 
.73573 .02581 L 
s 
.73573 .02581 m 
.75052 .80109 L 
s 
.75052 .80109 m 
.02581 .85706 L 
s 
.02581 .85706 m 
.05626 .14502 L 
s 
.94992 .27708 m 
.73573 .02581 L 
s 
.73573 .02581 m 
.75052 .80109 L 
s 
.75052 .80109 m 
.97419 .91827 L 
s 
.97419 .91827 m 
.94992 .27708 L 
s 
P 
p 
p 
.002 w 
.94992 .27708 m 
.73573 .02581 L 
s 
P 
p 
.002 w 
.93883 .26407 m 
.93244 .26498 L 
s 
P 
[(0)] .95161 .26226 -1 .14166 Mshowa 
p 
.002 w 
.87935 .1943 m 
.87297 .19527 L 
s 
P 
[(0.5)] .89212 .19237 -1 .15138 Mshowa 
p 
.002 w 
.81219 .11551 m 
.80581 .11654 L 
s 
P 
[(1)] .82493 .11344 -1 .16252 Mshowa 
p 
.002 w 
.73573 .02581 m 
.72937 .02693 L 
s 
P 
[(1.5)] .74844 .02358 -1 .17544 Mshowa 
p 
.001 w 
.92749 .25077 m 
.92365 .25132 L 
s 
P 
p 
.001 w 
.91588 .23715 m 
.91204 .2377 L 
s 
P 
p 
.001 w 
.90399 .2232 m 
.90016 .22377 L 
s 
P 
p 
.001 w 
.89182 .20893 m 
.88799 .2095 L 
s 
P 
p 
.001 w 
.86658 .17932 m 
.86275 .1799 L 
s 
P 
p 
.001 w 
.85349 .16396 m 
.84966 .16456 L 
s 
P 
p 
.001 w 
.84007 .14822 m 
.83624 .14882 L 
s 
P 
p 
.001 w 
.8263 .13207 m 
.82248 .13268 L 
s 
P 
p 
.001 w 
.7977 .09851 m 
.79387 .09914 L 
s 
P 
p 
.001 w 
.78282 .08106 m 
.779 .0817 L 
s 
P 
p 
.001 w 
.76755 .06314 m 
.76373 .06379 L 
s 
P 
p 
.001 w 
.75185 .04473 m 
.74804 .04539 L 
s 
P 
p 
.001 w 
.94992 .27708 m 
.94608 .27762 L 
s 
P 
P 
p 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .11661 .19586 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .90083 .30789 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .38001 .90839 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(1)] .38665 .37828 1.3 1.3 Mshowa 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{278, 273},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004F00014A000`40O003h00Oogoo5goo003oOolG
Ool00?mooaMoo`00ogoo5goo0032Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`15Ool00<Aoo`03
001oogoo00Ioo`03001oo`0004Ioo`00a7oo00<007ooOol027oo00<007ooOol0A7oo0034Ool00`00
Oomoo`06Ool20017Ool00<Aoo`03001oogoo00Ioo`03001oogoo04Ioo`00`goo0P0027oo0`00AWoo
003oOolGOol00?mooaMoo`00cGoo1@000Woo00<007ooOol00Woo00<007ooOol0>Woo003?Ool00`00
Oomoo`06Ool00`00Ool0000kOol00<moo`03001oogoo00Qoo`03001oogoo03Uoo`00RWoo1@00@7oo
00<007ooOol01Woo0P00?7oo002<Ool00`00Oomoo`0hOol30005Ool00`00Oomoo`06Ool00`00Oomo
o`0kOol008aoo`03001oogoo039oo`H0009oo`8000=oo`8000Qoo`<003]oo`00S7oo00<007ooOol0
;7oo1P0027oo00<007oo0000BWoo002<Ool00`00Oomoo`0WOol50002Ool00`00Oomoo`09Ool01000
Oomoo`00BGoo002;Ool2000SOol6000COol01000Oomoo`00BGoo002ZOol600000goo001oo`0FOol0
1000Oomoogoo0P00Agoo002UOol5000OOol00`00Oomoo`02Ool00`00Oomoo`15Ool009moo`L002=o
o`03001oogoo00=oo`03001oogoo04Aoo`00VGoo1P00:Woo00<007ooOol017oo00<007ooOol0@goo
001>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0hOol7000_Ool00`00Oomoo`05Ool0
0`00Oomoo`12Ool004eoo`03001oo`0000Moo`03001oo`0003Aoo`D000Ioo`03001oogoo02eoo`03
001oogoo00Eoo`8004=oo`00CGoo00<007oo00002Goo00<007ooOol0;7oo1P00>goo00<007ooOol0
1goo00<007ooOol0@7oo001=Ool00`00Ool00007Ool2000YOol60005Ool00`00Oomoo`0iOol00`00
Oomoo`07Ool00`00Oomoo`10Ool004eoo`03001oo`0000Moo`03001oogoo02=oo`D004Moo`03001o
ogoo00Qoo`03001oogoo03moo`00CWoo00<007ooOol01Woo0`007Goo1P0017oo00<007ooOol0AGoo
00<007ooOol02Goo00<007ooOol0?Woo001aOol6001BOol00`00Oomoo`09Ool2000oOol006aoo`D0
00Aoo`03001oogoo055oo`03001oogoo00]oo`03001oogoo03aoo`00IWoo1P00GGoo00<007ooOol0
37oo00<007ooOol0>goo001POol60004Ool00`00Oomoo`1LOol00`00Oomoo`0=Ool00`00Oomoo`0j
Ool001eoo`03001oogoo03]oo`D006Uoo`03001oogoo00eoo`8003]oo`0077oo00<007oo0000=Woo
1P0017oo00<007ooOol0Igoo00<007ooOol03Goo0P00>goo000LOol00`00Ool0000`Ool6001dOol0
0`00Oomoo`0?Ool00`00Oomoo`03Ool5000`Ool001aoo`03001oo`0002]oo`D000Aoo`03001oogoo
07=oo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo031oo`0077oo00<007oo00009Goo1P00
Ogoo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0<7oo000MOol00`00Oomoo`0MOol70004
Ool00`00Oomoo`1nOol00`00Oomoo`0@Ool30004Ool00`00Oomoo`0`Ool003Qoo`H008]oo`03001o
ogoo01=oo`05001oogooOol0000bOol003=oo`D000Eoo`03001oogoo08Uoo`03001oogoo01Aoo`04
001oo`00000bOol002eoo`L009Ioo`03001oogoo01=oo`03001oogoo03=oo`009goo1P00WGoo00<0
07ooOol057oo0P00<goo000ROol500000goo001oo`2POol00`00Oomoo`0DOol2000cOol001aoo`H0
0:Qoo`03001oogoo01Ioo`03001oogoo031oo`005Woo1P0000=oo`00Ool0Zgoo00<007ooOol05goo
00<007ooOol0;goo000COol30007Ool00`00Oomoo`2ZOol00`00Oomoo`0HOol00`00Oomoo`0^Ool0
01=oo`<00;Aoo`03001oogoo01Moo`<002moo`004goo00@007ooOol00;=oo`03001oogoo01Uoo`03
001oogoo02eoo`004goo00@007ooOomoo`800;5oo`03001oogoo01Yoo`03001oogoo02aoo`004goo
00<007ooOol00goo00<007ooOol0[Woo00<007ooOol06goo00<007ooOol0:goo000COol00`00Oomo
o`04Ool2002^Ool00`00Oomoo`0KOol2000/Ool001=oo`03001oogoo00Ioo`03001oogoo0:]oo`03
001oogoo01eoo`03001oogoo02Uoo`004goo00<007ooOol01goo0P00Zgoo00<007ooOol07Woo00<0
07ooOol0:7oo000COol00`00Oomoo`09Ool00`00Oomoo`2XOol00`00Oomoo`0OOol00`00Oomoo`0W
Ool001=oo`03001oogoo00Yoo`03001oogoo0:Moo`03001oogoo01ioo`8002Uoo`004goo00<007oo
Ool02goo0P00Ygoo00<007ooOol087oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol057oo000COol00`00Oomoo`0=Ool00`00Oomoo`08Ool2002JOol00`00Oomoo`0QOol0
0`00Oomoo`03Ool00`00Ool00007Ool00`00Ool0000EOol0019oo`03001oogoo00moo`8000Aoo`@0
09aoo`03001oogoo029oo`03001oogoo009oo`03001oo`0000Uoo`03001oogoo01=oo`004Woo00<0
07ooOol04Goo1000X7oo00<007ooOol08Goo0`000goo00<007oo00001goo0P005Woo000BOol00`00
Oomoo`0>Ool300000goo0000002QOol00`00Oomoo`0TOol01P00Oomoo`00Ool000Moo`03001oogoo
01Eoo`004Woo00<007ooOol03Woo1`00X7oo00<007ooOol09Goo00@007ooOol000Qoo`<001Eoo`00
4Woo00<007ooOol03Woo0P0000Aoo`00Oomoo`@009eoo`03001oogoo02Ioo`03001oogoo021oo`00
4Woo00<007ooOol03goo0P0000=oo`0000000goo1@00VGoo00<007ooOol09Goo0P008Woo000BOol0
0`00Oomoo`0?Ool20003Ool01000Oomoogoo0P000Woo1000UGoo00<007ooOol09goo00<007ooOol0
7goo000BOol00`00Oomoo`0?Ool300000goo001oo`020003Ool00`00Oomoo`03Ool4002AOol00`00
Oomoo`0XOol00`00Oomoo`0NOol0019oo`03001oogoo00moo`04001oo`000004Ool01000Oomoogoo
0P001goo1000SGoo00<007ooOol0:Goo00<007ooOol07Goo000BOol00`00Oomoo`0@Ool30005Ool2
0003Ool00`00Oomoo`08Ool40029Ool00`00Oomoo`0XOol3000NOol0019oo`03001oogoo011oo`04
001oogoo0006Ool20002Ool2000<Ool20027Ool00`00Oomoo`0[Ool00`00Oomoo`0KOol0019oo`03
001oogoo011oo`05001oogooOol00007Ool01@00Oomoogoo0000U7oo00<007ooOol0;7oo00<007oo
Ool06Woo000BOol00`00Oomoo`0DOol00`00Oomoo`06Ool20002Ool20002Ool4002<Ool00`00Oomo
o`0/Ool00`00Oomoo`0JOol0019oo`03001oogoo01Eoo`03001oogoo00Moo`07001oogooOol007oo
00000f9E1`00QGoo00<007ooOol0;7oo0P006goo000BOol00`00Oomoo`0EOol00`00Oomoo`08Ool2
0002Ool2000:HUD8001mOol00`00Oomoo`0^Ool00`00Oomoo`0HOol0019oo`03001oogoo01Ioo`03
001oogoo00Uoo`04001oogoo000BHUD7001fOol00`00Oomoo`0_Ool00`00Oomoo`0GOol0019oo`03
001oogoo01Moo`03001oogoo00Uoo`<001URE@L006moo`03001oogoo031oo`03001oogoo01Ioo`00
4Woo00<007ooOol05goo00<007ooOol02goo00<0069EHUD07V9E2000Igoo00<007ooOol0;goo00<0
07oo00001Woo00<007ooOol03Woo000BOol00`00Oomoo`0HOol00`00Oomoo`0:Ool00`00HUERE@0V
HUD7001POol00`00Oomoo`0bOol00`00Oomoo`02Ool00`00Ool0000?Ool0019oo`03001oogoo01Qo
o`03001oogoo00Yoo`03001REF9E02eRE@L005Uoo`03001oogoo03=oo`07001oogooOol007oo0000
3goo000BOol00`00Oomoo`0IOol00`00Oomoo`09Ool00`00HUERE@0dHUD8001AOol00`00Oomoo`0a
Ool30003Ool00`00Ool0000?Ool0019oo`03001oogoo01Yoo`03001oogoo00Qoo`03001REF9E03aR
E@L004Yoo`03001oogoo03Aoo`06001oogoo001oo`003goo000BOol00`00Oomoo`0JOol00`00Oomo
o`08Ool00`00HUERE@13HUD70013Ool00`00Oomoo`0eOol01000Oomoo`0047oo000BOol00`00Oomo
o`0KOol00`00Oomoo`07Ool40019HUD7000lOol00`00Oomoo`0cOol4000BOol0015oo`03001oogoo
01eoo`03001oogoo00Moo`800003Ccl0000000H004QRE@P003Aoo`03001oogoo01=oo`8001Moo`L0
009oo`80019oo`004Goo00<007ooOol07Goo00<007ooOol02Goo00<004loCcl01Tlo2000B69E1`00
;Goo00<007ooOol05Goo0`003Goo1`002Woo00<007ooOol047oo000AOol00`00Oomoo`0NOol00`00
Oomoo`09Ool2000>Ccl70018HUD7000VOol00`00Oomoo`0HOol20004Ool7000AOol00`00Oomoo`0@
Ool0015oo`03001oogoo01ioo`03001oogoo00]oo`8001=??`P004MRE@P001ioo`03001oogoo01Mo
o`L001Qoo`03001oogoo011oo`004Goo00<007ooOol07goo00<007ooOol037oo00<004loCcl064lo
2000Af9E1`005goo00<007ooOol047oo1`001Woo0`005Woo00<007ooOol047oo000AOol00`00Oomo
o`0_Ool2000PCcl70017HUD7000@Ool00`00Oomoo`08Ool8000@Ool3000COol00`00Oomoo`0@Ool0
015oo`03001oogoo035oo`03001??dlo02A??`P004IRE@P000Qoo`04001oogooOol7000KOol2000A
Ool00`00Oomoo`0@Ool0015oo`03001oogoo039oo`8002a??`P004IRE@`000Iooa4000eoo`<000io
o`03001oogoo011oo`004Goo00<007ooOol0=7oo00<004loCcl0<Dlo1`00Af9E00<0069E000067oo
4P0037oo00<007ooOol047oo000AOol00`00Oomoo`0eOol2000hCcl8000oHUD00`00HUD0000MOol<
000=Ool00`00Oomoo`0@Ool0015oo`03001oogoo03Moo`03001??dlo03e??`P003MRE@03001RE@00
01Eoo`P000Eoo`D000moo`03001oogoo011oo`004Goo00<007ooOol0>7oo0P00ADlo2000<69E0P00
37oo2@002Woo0`000Woo00<007ooOol03goo00<007ooOol047oo000AOol00`00Oomoo`0jOol2001;
Ccl7000YHUD20004Ool8000@Ool30003Ool20006Ool2000:Ool00`00Oomoo`0@Ool0015oo`03001o
ogoo03aoo`03001??dlo04m??`P0025RE@H001Eoo`<000Eoo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo011oo`004Goo00<007ooOol0?Goo0P00Edlo20006F9E0P005goo0P001Woo0P002Woo
00<007ooOol02Goo00<007ooOol03goo000AOol00`00Oomoo`0oOol00`00Ccm??`1LCcl7000BHUD2
000MOol2000;Ool00`00Ool0000:Ool00`00Oomoo`0?Ool0015oo`03001oogoo041oo`8006=??`P0
00YRE@8001aoo`03001oogoo00]oo`03001oo`0000Yoo`03001oogoo00moo`004Goo00<007ooOol0
@Woo00<004loCcl03Dlo1@00ETlo20000V9E0P006Woo0P003Goo0P0000=oo`0000002Goo00<007oo
Ool03goo000AOol00`00Oomoo`13Ool2000?Ccl00`00Ccm??`1NCcl4000IOol00`00Oomoo`0KOol0
0`00Oomoo`0?Ool0015oo`03001oogoo04Eoo`8000e??`03001??dlo05I??`P0009oo`03001oogoo
01Ioo`8001ioo`03001oogoo00moo`004Goo00<007ooOol0Agoo00<004loCcl02Tlo00<004loCcl0
Cdlo1`002Woo00<007ooOol057oo0P0087oo00<007ooOol03goo000AOol00`00Oomoo`18Ool2000:
Ccl00`00Ccm??`18Ccl7000AOol00`00Oomoo`0COol00`00Oomoo`0POol00`00Oomoo`0?Ool0015o
o`03001oogoo04Yoo`03001??dlo00I??`80049??`P001Qoo`03001oogoo015oo`8002=oo`03001o
ogoo00moo`004Goo00<007ooOol0Bgoo0P00@dlo1`0087oo00<007ooOol047oo00<007ooOol08goo
00<007ooOol03goo000@Ool00`00Oomoo`1>Ool00`00Ccm??`0iCcl7000WOol00`00Oomoo`0>Ool2
000VOol00`00Oomoo`0?Ool0011oo`03001oogoo04moo`80035??`P002ioo`03001oogoo00aoo`80
02Qoo`03001oogoo00moo`0047oo00<007ooOol0DGoo00<004loCcl09dlo1`00=Woo00<007ooOol0
2goo00<007ooOol0:7oo00<007ooOol03goo000@Ool00`00Oomoo`1BOol2000OCcl8000mOol00`00
Oomoo`0fOol00`00Oomoo`0?Ool0011oo`03001oogoo05Aoo`8001I??`L004Eoo`03001oogoo03Io
o`03001oogoo00moo`0047oo00<007ooOol0E7oo00<007oo00003Tlo1`00C7oo00<007ooOol0=Woo
00<007ooOol03goo000@Ool00`00Oomoo`1=Ool00`00Oomoo`04Ool00`00Oomoo`020004Ccl8001C
Ool00`00Oomoo`0fOol00`00Oomoo`0?Ool0011oo`03001oogoo04aoo`03001oo`0000Eoo`<0009o
o`@005]oo`03001oogoo03Ioo`03001oogoo00moo`0047oo00<007ooOol0C7oo00<007oo00001Goo
00<007ooOol00Woo00<007ooOol0G7oo00<007ooOol0=Woo00<007ooOol03goo000@Ool00`00Oomo
o`1<Ool00`00Ool00005Ool00`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0fOol00`00Oomo
o`0?Ool0011oo`03001oogoo04aoo`03001oo`0000Eoo`03001oogoo009oo`03001oogoo05aoo`03
001oogoo03Ioo`03001oogoo00moo`0047oo00<007ooOol0CGoo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol0G7oo00<007ooOol0=Woo00<007ooOol03goo000@Ool00`00Oomoo`1DOol00`00
Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0fOol00`00Oomoo`0?Ool0011oo`03001oogoo05Ao
o`03001oogoo009oo`03001oogoo05aoo`03001oogoo03Ioo`03001oogoo00moo`0047oo00<007oo
Ool0E7oo00<007ooOol00Woo00<007ooOol0G7oo00<007ooOol0=Woo00<007ooOol03goo000@Ool0
0`00Oomoo`1DOol00`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0fOol00`00Oomoo`0?Ool0
011oo`03001oogoo05Aoo`8000=oo`03001oogoo05aoo`03001oogoo03Ioo`03001oogoo00moo`00
47oo00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol0G7oo00<007ooOol0=Woo00<007ooOol0
3goo000@Ool00`00Oomoo`1DOol00`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0fOol00`00
Oomoo`0?Ool0011oo`03001oogoo05Aoo`03001oogoo009oo`03001oogoo05aoo`03001oogoo03Mo
o`03001oogoo00ioo`0047oo00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol0G7oo00<007oo
Ool0=goo00<007ooOol03Woo000@Ool00`00Oomoo`1DOol00`00Oomoo`02Ool00`00Oomoo`1LOol0
0`00Oomoo`0gOol00`00Oomoo`0>Ool0011oo`03001oogoo05Aoo`03001oogoo009oo`03001oogoo
05aoo`03001oogoo03Moo`03001oogoo00ioo`0047oo00<007ooOol0E7oo00<007ooOol00Woo00<0
07ooOol0G7oo00<007ooOol0=goo00<007ooOol03Woo000?Ool00`00Oomoo`1EOol00`00Oomoo`02
Ool00`00Oomoo`1LOol00`00Oomoo`0gOol00`00Oomoo`0>Ool000moo`03001oogoo05Eoo`03001o
ogoo009oo`03001oogoo05aoo`03001oogoo03Moo`03001oogoo00ioo`003goo00<007ooOol0EGoo
0P000goo00<007ooOol0G7oo00<007ooOol0=goo00<007ooOol03Woo000?Ool00`00Oomoo`1EOol0
0`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0gOol00`00Oomoo`0>Ool000moo`03001oogoo
05Eoo`03001oogoo009oo`03001oogoo05aoo`03001oogoo03Moo`03001oogoo00ioo`003goo00<0
07ooOol0EGoo00<007ooOol00Woo00<007ooOol0G7oo00<007ooOol0=goo00<007ooOol03Woo000?
Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomoo`0gOol00`00Oomoo`0>
Ool000moo`03001oogoo05Eoo`03001oogoo009oo`03001oogoo05aoo`03001oogoo03Moo`03001o
ogoo00ioo`003goo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0G7oo00<007ooOol0=goo
00<007ooOol03Woo000?Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`1LOol00`00Oomo
o`0gOol00`00Oomoo`0>Ool000moo`03001oogoo05Eoo`03001oogoo009oo`03001oogoo05aoo`03
001oogoo03Moo`03001oogoo00ioo`003goo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0
G7oo00<007ooOol0=goo00<007ooOol03Woo000?Ool00`00Oomoo`1DOol20004Ool00`00Oomoo`1L
Ool00`00Oomoo`0gOol00`00Oomoo`0>Ool000moo`03001oogoo05Eoo`03001oogoo009oo`03001o
ogoo05aoo`03001oogoo03Moo`03001oogoo00ioo`003goo00<007ooOol0E7oo00<007ooOol00goo
00<007ooOol0G7oo00<007ooOol0=goo00<007ooOol03Woo000?Ool00`00Oomoo`1DOol00`00Oomo
o`03Ool00`00Oomoo`1MOol00`00Oomoo`0fOol00`00Oomoo`0>Ool000moo`03001oogoo05Aoo`03
001oogoo00=oo`03001oogoo05eoo`03001oogoo03Ioo`03001oogoo00ioo`003goo00<007ooOol0
E7oo00<007ooOol00goo00<007ooOol0GGoo00<007ooOol0=Woo00<007ooOol03Woo000?Ool00`00
Oomoo`1DOol00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0fOol00`00Oomoo`0>Ool000mo
o`03001oogoo05Aoo`03001oogoo009oo`03001oogoo05ioo`03001oogoo03Ioo`03001oogoo00io
o`003goo00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol0=Woo00<007oo
Ool03Woo000?Ool00`00Oomoo`1DOol20003Ool00`00Oomoo`1NOol00`00Oomoo`0fOol00`00Oomo
o`0>Ool000moo`03001oogoo05Aoo`03001oogoo009oo`03001oogoo05ioo`03001oogoo03Ioo`03
001oogoo00ioo`003goo00<007ooOol0E7oo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol0
=Woo00<007ooOol03Woo000>Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`1NOol00`00
Oomoo`0gOol00`00Oomoo`0=Ool000ioo`03001oogoo05Eoo`03001oogoo009oo`03001oogoo05io
o`03001oogoo03Moo`03001oogoo00eoo`003Woo00<007ooOol0EGoo00<007ooOol00Woo00<007oo
Ool0GWoo00<007ooOol0=goo00<007ooOol03Goo000>Ool00`00Oomoo`1EOol00`00Oomoo`02Ool0
0`00Oomoo`1NOol00`00Oomoo`0gOol00`00Oomoo`0=Ool000ioo`03001oogoo05Eoo`03001oogoo
009oo`03001oogoo05ioo`03001oogoo03Moo`03001oogoo00eoo`003Woo00<007ooOol0EGoo00<0
07ooOol00Woo00<007ooOol0GWoo00<007ooOol0=goo00<007ooOol03Goo000>Ool00`00Oomoo`15
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`1N
Ool00`00Oomoo`0gOol00`00Oomoo`0=Ool000ioo`03001oogoo04Aoo`03001oo`0000Moo`03001o
o`0000Aoo`<0009oo`03001oogoo05ioo`03001oogoo03Moo`03001oogoo00eoo`003Woo00<007oo
Ool0A7oo00<007oo00002Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0GWoo00<007oo
Ool0=goo00<007ooOol03Goo000>Ool00`00Oomoo`14Ool00`00Ool00007Ool20005Ool00`00Oomo
o`02Ool00`00Oomoo`1NOol00`00Oomoo`0gOol00`00Oomoo`0=Ool000ioo`03001oogoo04Aoo`03
001oo`0000Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo05ioo`03001oogoo03Moo`03
001oogoo00eoo`003Woo00<007ooOol0AGoo00<007ooOol01Woo0`0017oo00<007ooOol00Woo00<0
07ooOol0GWoo00<007ooOol0=goo00<007ooOol03Goo000>Ool00`00Oomoo`1EOol00`00Oomoo`02
Ool00`00Oomoo`1NOol00`00Oomoo`0gOol00`00Oomoo`0=Ool000ioo`03001oogoo05Eoo`03001o
ogoo009oo`03001oogoo05ioo`03001oogoo03Moo`03001oogoo00eoo`003Woo00<007ooOol0EGoo
00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol0=goo00<007ooOol03Goo000>Ool00`00Oomo
o`1EOol00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0gOol00`00Oomoo`0=Ool000ioo`03
001oogoo05Eoo`03001oogoo009oo`03001oogoo05ioo`03001oogoo03Moo`03001oogoo00eoo`00
3Woo00<007ooOol0EGoo0P000goo00<007ooOol0GWoo00<007ooOol0=goo00<007ooOol03Goo000>
Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0gOol00`00Oomoo`0=
Ool000ioo`03001oogoo05Eoo`03001oogoo009oo`03001oogoo05ioo`03001oogoo03Moo`03001o
ogoo00eoo`003Woo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol0=goo
00<007ooOol03Goo000>Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomo
o`0gOol00`00Oomoo`0=Ool000ioo`03001oogoo05Eoo`03001oogoo009oo`03001oogoo05ioo`03
001oogoo03Moo`03001oogoo00eoo`003Woo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0
GWoo00<007ooOol0=goo00<007ooOol03Goo000=Ool00`00Oomoo`1FOol00`00Oomoo`02Ool00`00
Oomoo`1NOol00`00Oomoo`0gOol00`00Oomoo`0=Ool000eoo`03001oogoo05Ioo`03001oogoo009o
o`03001oogoo05ioo`03001oogoo03Moo`03001oogoo00eoo`003Goo00<007ooOol0EWoo00<007oo
Ool00Woo00<007ooOol0GWoo00<007ooOol0=goo00<007ooOol03Goo000=Ool00`00Oomoo`1FOol2
0003Ool00`00Oomoo`1NOol00`00Oomoo`0gOol00`00Oomoo`0=Ool000eoo`03001oogoo05Ioo`03
001oogoo009oo`03001oogoo05ioo`03001oogoo03Qoo`03001oogoo00aoo`003Goo00<007ooOol0
EWoo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol0>7oo00<007ooOol037oo000=Ool00`00
Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0hOol00`00Oomoo`0<Ool000eo
o`03001oogoo05Ioo`03001oogoo009oo`03001oogoo05ioo`03001oogoo03Qoo`03001oogoo00ao
o`003Goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0GWoo00<007ooOol0>7oo00<007oo
Ool037oo000=Ool00`00Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0hOol0
0`00Oomoo`0<Ool000eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo05ioo`03001oogoo
03Qoo`03001oogoo00aoo`003Goo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0GWoo00<0
07ooOol0>7oo00<007ooOol037oo000=Ool00`00Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`1N
Ool00`00Oomoo`0hOol00`00Oomoo`0<Ool000eoo`03001oogoo05Ioo`8000=oo`03001oogoo05io
o`03001oogoo03Qoo`03001oogoo00aoo`003Goo00<007ooOol0EWoo00<007ooOol00Woo00<007oo
Ool0GWoo00<007ooOol0>7oo00<007ooOol037oo000=Ool00`00Oomoo`1FOol00`00Oomoo`02Ool0
0`00Oomoo`1NOol00`00Oomoo`0hOol00`00Oomoo`0<Ool000eoo`03001oogoo05Ioo`03001oogoo
009oo`03001oogoo05ioo`03001oogoo03Qoo`03001oogoo00aoo`003Goo00<007ooOol0EWoo00<0
07ooOol00Woo00<007ooOol0GWoo00<007ooOol0>7oo00<007ooOol037oo000=Ool00`00Oomoo`1F
Ool00`00Oomoo`02Ool00`00Oomoo`1NOol00`00Oomoo`0hOol00`00Oomoo`0<Ool000eoo`03001o
ogoo05Ioo`03001oogoo009oo`03001oogoo05moo`03001oogoo03Moo`03001oogoo00aoo`003Goo
00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol0Ggoo00<007ooOol0=goo00<007ooOol037oo
000=Ool00`00Oomoo`1FOol00`00Oomoo`02Ool00`00Oomoo`1OOol00`00Oomoo`0gOol00`00Oomo
o`0<Ool000eoo`03001oogoo05Ioo`03001oogoo009oo`03001oogoo05moo`03001oogoo03Moo`03
001oogoo00aoo`003Goo00<007ooOol0EWoo0P000goo00<007ooOol0Ggoo00<007ooOol0=goo00<0
07ooOol037oo000<Ool00`00Oomoo`1GOol00`00Oomoo`02Ool00`00Oomoo`1OOol00`00Oomoo`0g
Ool00`00Oomoo`0<Ool000aoo`03001oogoo05Moo`03001oogoo009oo`03001oogoo05moo`03001o
ogoo03Moo`03001oogoo00aoo`0037oo00<007ooOol0Egoo00<007ooOol00Woo00<007ooOol0Ggoo
00<007ooOol0=goo00<007ooOol037oo000<Ool00`00Oomoo`1GOol00`00Oomoo`02Ool00`00Oomo
o`1OOol00`00Oomoo`0gOol00`00Oomoo`0<Ool000aoo`03001oogoo05Moo`03001oogoo009oo`03
001oogoo05moo`03001oogoo03Moo`03001oogoo00aoo`0037oo00<007ooOol0Egoo00<007ooOol0
0Woo00<007ooOol0Ggoo00<007ooOol0=goo00<007ooOol037oo000<Ool00`00Oomoo`1GOol00`00
Oomoo`02Ool00`00Oomoo`1OOol00`00Oomoo`0gOol00`00Oomoo`0<Ool000aoo`03001oogoo05Mo
o`03001oogoo009oo`03001oogoo05moo`03001oogoo03Moo`03001oogoo00aoo`0037oo00<007oo
Ool0Egoo00<007ooOol00Woo00<007ooOol0Ggoo00<007ooOol0=goo00<007ooOol037oo000<Ool0
0`00Oomoo`1>Ool50004Ool00`00Oomoo`02Ool00`00Oomoo`1OOol00`00Oomoo`0hOol00`00Oomo
o`0;Ool000aoo`03001oogoo051oo`03001oogoo00=oo`<000=oo`03001oogoo05moo`03001oogoo
03Qoo`03001oogoo00]oo`0037oo00<007ooOol0D7oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol0Ggoo00<007ooOol0>7oo00<007ooOol02goo000<Ool00`00Oomoo`1@Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`1OOol00`00Oomoo`0hOol00`00Oomoo`0;Ool000aoo`03001o
ogoo051oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo05moo`03001oogoo03Qoo`03001o
ogoo00]oo`0037oo00<007ooOol0Cgoo0P001Woo00<007ooOol00Woo00<007ooOol0Ggoo00<007oo
Ool0>7oo00<007ooOol02goo000<Ool00`00Oomoo`1GOol01@00Oomoogoo0000HWoo00<007ooOol0
>7oo00<007ooOol02goo000<Ool00`00Oomoo`1GOol01@00Oomoogoo0000HWoo00<007ooOol0>7oo
00<007ooOol02goo000<Ool00`00Oomoo`1EOol00`00Ool00003Ool00`00Oomoo`1POol00`00Oomo
o`0hOol00`00Oomoo`0;Ool000aoo`03001oogoo05Eoo`03001oo`0000=oo`03001oogoo00]oo`03
001oogoo059oo`03001oogoo03Qoo`03001oogoo00]oo`0037oo00<007ooOol0EGoo00<007oo0000
0goo00<007ooOol02goo00<007ooOol0DWoo00<007ooOol0>7oo00<007ooOol02goo000<Ool00`00
Oomoo`1FOol20003Ool00`00Oomoo`0:Ool00`00Oomoo`1=Ool7000jOol00`00Oomoo`0;Ool000ao
o`03001oogoo05Ioo`8000=oo`03001oogoo00Yoo`03001oogoo041oo`d000Moo`8003Qoo`03001o
ogoo00]oo`0037oo00<007ooOol0EWoo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0=7oo
3@005Woo0P00=Woo00<007ooOol02goo000<Ool00`00Oomoo`1FOol00`00Oomoo`02Ool00`00Oomo
o`09Ool00`00Oomoo`0WOol=000UOol2000dOol00`00Oomoo`0;Ool000]oo`03001oogoo05Moo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo01]oo`d003Aoo`80039oo`03001oogoo00]oo`00
2goo00<007ooOol0Egoo00<007ooOol00Woo00<007ooOol027oo00<007ooOol03Woo3@00@goo0P00
<7oo00<007ooOol02goo000;Ool00`00Oomoo`1GOol20003Ool00`00Oomoo`07Ool00`00Oomoo`02
Ool=001BOol2000^Ool00`00Oomoo`0;Ool000]oo`03001oogoo05Moo`8000=oo`03001oogoo00`0
065oo`8002aoo`03001oogoo00]oo`002goo00<007ooOol0DWoo3@001Woo00<007ooOol0IWoo00<0
07ooOol0:Goo00<007ooOol02goo000;Ool00`00Oomoo`15Ool=00000goo001oo`02Ool20003Ool0
0`00Oomoo`02Ool01@00Oomoogoo0000JGoo0P00:Goo00<007ooOol02goo000;Ool00`00Oomoo`0h
Ool=000>Ool01000Oomoogoo0P000goo00<007ooOol00Woo00D007ooOomoo`0006]oo`8002Moo`03
001oogoo00]oo`002goo00<007ooOol0:goo3@0077oo00H007ooOol007oo0002Ool01@00Oomoogoo
00000goo00<007ooOol0K7oo0P009Goo00<007ooOol02goo000;Ool00`00Oomoo`0NOol=000YOol0
1P00Oomoo`00Ool0009oo`05001oogooOol00003Ool00`00Oomoo`1^Ool2000SOol00`00Oomoo`0;
Ool000]oo`03001oogoo015oo`d003Moo`05001oo`00Ool00002Ool01@00Oomoogoo00000Woo00<0
07ooOol0LGoo0P008Goo00<007ooOol02goo000;Ool00`00Oomoo`04Ool=0014Ool01@00Ool007oo
00000Woo00D007ooOomoo`00009oo`03001oogoo07=oo`8001moo`03001oogoo00]oo`002goo1`00
DWoo0P0000Eoo`00Oomoo`00009oo`04001oogoo001hOol2000MOol00`00Oomoo`0;Ool000eoo`<0
05Aoo`80009oo`03001oo`00009oo`04001oogoo001jOol00`00Oomoo`0JOol00`00Oomoo`0;Ool0
011oo`@0055oo`06001oogoo001oo`000Woo00<007oo0000O7oo0P006Woo00<007ooOol02goo000D
Ool3001>Ool01P00Oomoo`00Ool0009oo`03001oo`0007ioo`8001Uoo`03001oogoo00Yoo`005goo
0`00Bgoo00P007ooOol007oo001oo`000Woo00<007ooOol0OWoo0P005goo00<007ooOol02Woo000J
Ool40017Ool2000027oo001oo`00Ool007oo0023Ool2000EOol00`00Oomoo`0:Ool001ioo`<004Ao
o`800008Ool007oo001oo`00Ool008Eoo`8001=oo`03001oogoo00Yoo`008Goo0`00@Goo00@007oo
001oo`800003Ool0000008Qoo`80015oo`03001oogoo00Yoo`0097oo1000?Goo00@007oo001oo`<0
0003Ool007oo08Uoo`8000moo`03001oogoo00Yoo`00:7oo0`00>Woo00<007ooOol01@00SGoo00<0
07ooOol037oo00<007ooOol02Woo000[Ool3000gOol00`00Oomoo`05002>Ool2000<Ool00`00Oomo
o`0:Ool002ioo`@003=oo`04001oogooOol3002AOol2000:Ool00`00Oomoo`0:Ool0039oo`<0031o
o`04001oogooOol3002COol20008Ool00`00Oomoo`0:Ool003Eoo`<002eoo`03001oogoo009oo`03
001oogoo09Aoo`8000Ioo`03001oogoo00Yoo`00>7oo1000:Goo00<007ooOol00Woo00<007ooOol0
UWoo0P0017oo00<007ooOol02Woo000lOol3000VOol00`00Oomoo`2MOol20002Ool00`00Oomoo`0:
Ool003moo`<002=oo`800:1oo`<000aoo`00@Woo10007goo00<007ooOol0VGoo2@0037oo0016Ool3
000LOol00`00Oomoo`29Ool@000EOol004Uoo`<001Uoo`03001oogoo07Uooa0002Eoo`00C7oo1000
5Goo00<007ooOol017oo1000H7oo4@00=Goo001@Ool3000BOol00`00Oomoo`05Ool00`00Ool0001@
Ool@0016Ool005=oo`<000moo`03001oogoo00Aoo`03001oo`00041ooa4005Ioo`00EWoo10002goo
00<007ooOol017oo1000;goo4000Igoo001JOol30008Ool00`00Oomoo`0WOol@001gOol0059oo`D0
009oo`04001oogooOol30005Ool00`00Oomoo`0FOolA0027Ool005Aoo`03001oogoo00Ioo`03001o
o`0000@00003Ool0000000Mooa0009Qoo`00E7oo00<007ooOol027oo00<007ooOol00Woo2P00Z7oo
001DOol00`00Oomoo`06Ool2002gOol005Aoo`03001oogoo00Ioo`03001oogoo0;Ioo`00Dgoo0P00
27oo0`00]Woo003oOolGOol00?mooaMoo`00ogoo5goo0000\
\>"],
  ImageRangeCache->{{{0, 277}, {272, 0}} -> {-0.0263581, -0.0557882, 
  0.00360717, 0.00360717}}]
}, Open  ]],

Cell[TextData[
"The inertia properties of the plate, in the shown reference frame, can be \
integrated directly or found in an engineering or mathematics handbook."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the basic inertia properties of the plate."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ixx = 
      \[Integral]\_0\%1
          \((\[Integral]\_0\%\(1 - x\)\(y\^2\) \[DifferentialD]y)\) 
          \[DifferentialD]x\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(1\/12\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["iyy",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is known by symmetry."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(iyy = ixx; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(izz = 
      \[Integral]\_0\%1
          \((\[Integral]\_0\%\(1 - x\)\((x\^2 + y\^2)\) \[DifferentialD]y)\) 
          \[DifferentialD]x\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(1\/6\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ixy = 
      \[Integral]\_0\%1
          \((\[Integral]\_0\%\(1 - x\)\(\(-x\)\ y\) \[DifferentialD]y)\) 
          \[DifferentialD]x\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-\(1\/24\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["iyz",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["izx",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are zero because the plate has zero thickness."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(iyz = \(izx = 0\); \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"The location of the centroid of the plate can also be found by direct \
integration, knowing that the mass of the plate is 1/2 because the density of \
the plate is one unit mass per unit area. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the mass and centroid location."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(mass = 1\/2; \)\)], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cent = 
      \(\[Integral]\_0\%1
            \((\[Integral]\_0\%\(1 - x\){x, y, 0} \[DifferentialD]y)\) 
            \[DifferentialD]x\)\/mass\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1\/3, 1\/3, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "To use the ",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to transform noncentroidal inertia properties into a centroidal \
reference frame, instead of vice versa, the vector from the centroid to the \
origin of the noncentroidal frame is specified in the centroidal reference \
frame coordinates, and a negative mass is specified. Note that the sign of \
the centroid vector is irrelevant, but it must be given in the correct \
reference frame if there is any relative rotation between the frames. \n\n",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the centroidal inertias ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, ...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that are reduced in magnitude relative to the noncentroidal properties. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the centroidal inertia properties of the plate."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(centinertia = 
      ParallelAxis[cent, \(-mass\), {ixx, iyy, izz, ixy, iyz, izx}]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1\/36, 1\/36, 1\/18, 1\/72, 0, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The principal axes of inertia of the plate can be found with the ",
  StyleBox["PrincipalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. Note that the list of the three principal axes of inertia forms \
the rotation matrix from the local reference frame of the inertia properties \
to the principal reference frame."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the principal inertias and axes of the plate. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(princeaxis = PrincipalAxes[centinertia]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{1\/18, 1\/24, 
        1\/72}, {{0, 0, 1}, {1\/\@2, 1\/\@2, 0}, {\(-\(1\/\@2\)\), 1\/\@2, 
          0}}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This rotates the original inertia matrix into the principal frame."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(princeaxis\[LeftDoubleBracket]2\[RightDoubleBracket].Inertia[
        centinertia].Transpose[
        princeaxis\[LeftDoubleBracket]2\[RightDoubleBracket]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{1\/18, 0, 0}, {0, 1\/24, 0}, {0, 0, 1\/72}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Composite Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to add the inertia properties of several bodies together \
and return the centroidal inertia properties of their superset. In the \
following example, the inertia properties of the triangular plate are added \
to the inertia properties of a cylinder that is attached to the plate and \
rotated through a 30-degree angle about the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis, as shown below. The radius of the cylinder is 0.25 and the length \
is 1 unit. The bottom surface of the cylinder is coplanar with the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the plate."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["A composite body "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .84325  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.0249947 0.999789 -0.0468249 0.999789 [ 
[(0)] .96189 .23266 -1 .08765 Msboxa 
[(0.5)] .93856 .16967 -1 .09198 Msboxa 
[(1)] .91289 .10036 -1 .09676 Msboxa 
[(1.5)] .8845 .02373 -1 .10206 Msboxa 
[(-0.5)] .12232 .08907 -0.0377 1 Msboxa 
[(0)] .30252 .07066 -0.02086 1 Msboxa 
[(0.5)] .48735 .05177 -0.00353 1 Msboxa 
[(1)] .677 .03239 .01432 1 Msboxa 
[(1.5)] .87166 .0125 .0327 1 Msboxa 
[(0)] .22873 .3391 1 -0.0847 Msboxa 
[(0.5)] .22468 .49448 1 -0.07386 Msboxa 
[(1)] .22052 .65434 1 -0.0627 Msboxa 
[(1.5)] .21624 .81889 1 -0.05121 Msboxa 
[ 0 0 0 0 ] 
[ 1 .84325 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.95385 .24565 m 
.87207 .02499 L 
s 
P 
p 
.002 w 
.94944 .23375 m 
.94321 .2343 L 
s 
P 
[(0)] .96189 .23266 -1 .08765 Mshowa 
p 
.002 w 
.92611 .17081 m 
.91989 .17139 L 
s 
P 
[(0.5)] .93856 .16967 -1 .09198 Mshowa 
p 
.002 w 
.90045 .10156 m 
.89423 .10216 L 
s 
P 
[(1)] .91289 .10036 -1 .09676 Mshowa 
p 
.002 w 
.87207 .02499 m 
.86585 .02563 L 
s 
P 
[(1.5)] .8845 .02373 -1 .10206 Mshowa 
p 
.001 w 
.94495 .22163 m 
.94121 .22196 L 
s 
P 
p 
.001 w 
.94037 .20928 m 
.93663 .20961 L 
s 
P 
p 
.001 w 
.93571 .1967 m 
.93197 .19703 L 
s 
P 
p 
.001 w 
.93095 .18388 m 
.92722 .18422 L 
s 
P 
p 
.001 w 
.92118 .1575 m 
.91744 .15785 L 
s 
P 
p 
.001 w 
.91615 .14392 m 
.91241 .14427 L 
s 
P 
p 
.001 w 
.91102 .13008 m 
.90728 .13044 L 
s 
P 
p 
.001 w 
.90578 .11596 m 
.90205 .11632 L 
s 
P 
p 
.001 w 
.895 .08687 m 
.89127 .08724 L 
s 
P 
p 
.001 w 
.88944 .07188 m 
.88571 .07225 L 
s 
P 
p 
.001 w 
.88377 .05657 m 
.88004 .05695 L 
s 
P 
p 
.001 w 
.87798 .04095 m 
.87425 .04133 L 
s 
P 
p 
.001 w 
.95385 .24565 m 
.95012 .24598 L 
s 
P 
P 
p 
p 
.002 w 
.05095 .1088 m 
.87207 .02499 L 
s 
P 
p 
.002 w 
.12185 .10156 m 
.12162 .10781 L 
s 
P 
[(-0.5)] .12232 .08907 -0.0377 1 Mshowa 
p 
.002 w 
.30226 .08315 m 
.30213 .0894 L 
s 
P 
[(0)] .30252 .07066 -0.02086 1 Mshowa 
p 
.002 w 
.48731 .06426 m 
.48728 .07051 L 
s 
P 
[(0.5)] .48735 .05177 -0.00353 1 Mshowa 
p 
.002 w 
.67718 .04489 m 
.67727 .05113 L 
s 
P 
[(1)] .677 .03239 .01432 1 Mshowa 
p 
.002 w 
.87207 .02499 m 
.87227 .03124 L 
s 
P 
[(1.5)] .87166 .0125 .0327 1 Mshowa 
p 
.001 w 
.15757 .09792 m 
.15744 .10166 L 
s 
P 
p 
.001 w 
.19347 .09425 m 
.19335 .098 L 
s 
P 
p 
.001 w 
.22955 .09057 m 
.22945 .09432 L 
s 
P 
p 
.001 w 
.26581 .08687 m 
.26572 .09062 L 
s 
P 
p 
.001 w 
.33889 .07941 m 
.33883 .08316 L 
s 
P 
p 
.001 w 
.37571 .07565 m 
.37566 .0794 L 
s 
P 
p 
.001 w 
.41272 .07188 m 
.41268 .07563 L 
s 
P 
p 
.001 w 
.44992 .06808 m 
.44989 .07183 L 
s 
P 
p 
.001 w 
.52489 .06043 m 
.52489 .06418 L 
s 
P 
p 
.001 w 
.56267 .05657 m 
.56268 .06032 L 
s 
P 
p 
.001 w 
.60064 .0527 m 
.60067 .05645 L 
s 
P 
p 
.001 w 
.63881 .0488 m 
.63885 .05255 L 
s 
P 
p 
.001 w 
.71575 .04095 m 
.71582 .0447 L 
s 
P 
p 
.001 w 
.75452 .03699 m 
.7546 .04074 L 
s 
P 
p 
.001 w 
.7935 .03301 m 
.79359 .03676 L 
s 
P 
p 
.001 w 
.83268 .02901 m 
.83279 .03276 L 
s 
P 
p 
.001 w 
.08631 .10519 m 
.08616 .10894 L 
s 
P 
P 
p 
p 
.002 w 
.24198 .30747 m 
.22872 .81825 L 
s 
P 
p 
.002 w 
.24118 .33805 m 
.24741 .33752 L 
s 
P 
[(0)] .22873 .3391 1 -0.0847 Mshowa 
p 
.002 w 
.23715 .49356 m 
.24338 .4931 L 
s 
P 
[(0.5)] .22468 .49448 1 -0.07386 Mshowa 
p 
.002 w 
.23299 .65356 m 
.23923 .65317 L 
s 
P 
[(1)] .22052 .65434 1 -0.0627 Mshowa 
p 
.002 w 
.22872 .81825 m 
.23496 .81793 L 
s 
P 
[(1.5)] .21624 .81889 1 -0.05121 Mshowa 
p 
.001 w 
.24039 .3688 m 
.24412 .36849 L 
s 
P 
p 
.001 w 
.23958 .39972 m 
.24332 .39942 L 
s 
P 
p 
.001 w 
.23878 .43083 m 
.24251 .43053 L 
s 
P 
p 
.001 w 
.23796 .4621 m 
.2417 .46182 L 
s 
P 
p 
.001 w 
.23633 .52519 m 
.24007 .52493 L 
s 
P 
p 
.001 w 
.2355 .55701 m 
.23924 .55675 L 
s 
P 
p 
.001 w 
.23467 .58901 m 
.23841 .58876 L 
s 
P 
p 
.001 w 
.23383 .62119 m 
.23758 .62095 L 
s 
P 
p 
.001 w 
.23215 .68612 m 
.23589 .68589 L 
s 
P 
p 
.001 w 
.2313 .71886 m 
.23504 .71865 L 
s 
P 
p 
.001 w 
.23044 .7518 m 
.23419 .75159 L 
s 
P 
p 
.001 w 
.22958 .78493 m 
.23333 .78473 L 
s 
P 
p 
.001 w 
.24198 .30747 m 
.24571 .30714 L 
s 
P 
P 
0 0 m 
1 0 L 
1 .84325 L 
0 .84325 L 
closepath 
clip 
newpath 
p 
.002 w 
.24198 .30747 m 
.22872 .81825 L 
s 
.22872 .81825 m 
.97501 .78004 L 
s 
.97501 .78004 m 
.95385 .24565 L 
s 
.95385 .24565 m 
.24198 .30747 L 
s 
.05095 .1088 m 
.87207 .02499 L 
s 
.87207 .02499 m 
.89225 .64214 L 
s 
.89225 .64214 m 
.02499 .69478 L 
s 
.02499 .69478 m 
.05095 .1088 L 
s 
.24198 .30747 m 
.22872 .81825 L 
s 
.22872 .81825 m 
.02499 .69478 L 
s 
.02499 .69478 m 
.05095 .1088 L 
s 
.05095 .1088 m 
.24198 .30747 L 
s 
.95385 .24565 m 
.87207 .02499 L 
s 
.87207 .02499 m 
.89225 .64214 L 
s 
.89225 .64214 m 
.97501 .78004 L 
s 
.97501 .78004 m 
.95385 .24565 L 
s 
P 
p 
.002 w 
.45234 .29291 m .3569 .17104 L .78041 .2645 L closepath p 
.611 .789 .967 r 
F P 
s 
P 
p 
.002 w 
.45234 .29291 m .78041 .2645 L .78117 .29646 L p 
.665 .504 .657 r 
F P 
s 
P 
p 
.002 w 
.78117 .29646 m .45213 .32423 L .45234 .29291 L p 
.665 .504 .657 r 
F P 
s 
P 
p 
.002 w 
.3841 .25517 m .42996 .28046 L .42034 .29728 L p 
.711 .562 .684 r 
F P 
s 
P 
p 
.002 w 
.42034 .29728 m .26113 .57572 L p 
.36815 .29675 L .711 .562 .684 r 
F P 
s 
P 
p 
.3841 .25517 m .42034 .29728 L .36815 .29675 L .711 .562 .684 r 
F 
P 
p 
.002 w 
.45234 .29291 m .45224 .30855 L p 
.43018 .27673 L .994 .784 .512 r 
F P 
s 
P 
p 
.002 w 
.43084 .26545 m .45234 .29291 L p 
.43018 .27673 L .994 .784 .512 r 
F P 
s 
P 
p 
.002 w 
.42472 .37004 m .2976 .59323 L p 
.42307 .29673 L .596 .42 .613 r 
F P 
s 
P 
p 
.42996 .28046 m .42908 .29553 L .42307 .29673 L .596 .42 .613 r 
F 
P 
p 
.42908 .29553 m .42472 .37004 L .42307 .29673 L .596 .42 .613 r 
F 
P 
p 
.45543 .29027 m .41494 .2383 L .58863 .2637 L .607 .792 .97 r 
F 
P 
p 
.41494 .2383 m .39701 .2153 L .49127 .23911 L .607 .792 .97 r 
F 
P 
p 
.41494 .2383 m .49127 .23911 L .58863 .2637 L .607 .792 .97 r 
F 
P 
p 
.002 w 
.46882 .27471 m .4303 .24677 L p 
.42262 .24816 L .18 .536 .925 r 
F P 
s 
P 
p 
.43018 .27673 m .38179 .20694 L .43084 .26545 L .994 .784 .512 r 
F 
P 
p 
.002 w 
.3569 .17104 m .38164 .20263 L p 
.38179 .20694 L .994 .784 .512 r 
F P 
s 
P 
p 
.002 w 
.38164 .20263 m .43084 .26545 L p 
.38179 .20694 L .994 .784 .512 r 
F P 
s 
P 
p 
.40665 .25107 m .38193 .21131 L .45224 .30855 L .994 .784 .512 r 
F 
P 
p 
.38193 .21131 m .3569 .17104 L .38179 .20694 L .994 .784 .512 r 
F 
P 
p 
.38193 .21131 m .38179 .20694 L .45224 .30855 L .994 .784 .512 r 
F 
P 
p 
.002 w 
.38223 .22028 m .34412 .206 L p 
.3841 .25517 L .18 .536 .925 r 
F P 
s 
P 
p 
.002 w 
.38223 .22028 m .37212 .23785 L p 
.38283 .23796 L .711 .561 .682 r 
F P 
s 
P 
p 
.3841 .25517 m .40665 .25107 L .38223 .22028 L .18 .536 .925 r 
F 
P 
p 
.3841 .25517 m .42473 .25087 L .40555 .25127 L .18 .536 .925 r 
F 
P 
p 
.3841 .25517 m .43771 .26753 L .42473 .25087 L .18 .536 .925 r 
F 
P 
p 
.002 w 
.36214 .23944 m .3841 .25517 L .21473 .54985 L p 
.794 .672 .729 r 
F P 
s 
P 
p 
.002 w 
.26113 .57572 m .21473 .54985 L .3841 .25517 L p 
.711 .562 .684 r 
F P 
s 
P 
p 
.002 w 
.35325 .2286 m .36214 .23944 L .3841 .25517 L p 
.18 .536 .925 r 
F P 
s 
P 
p 
.35325 .2286 m .3841 .25517 L .34412 .206 L .18 .536 .925 r 
F 
P 
p 
.002 w 
.34366 .23477 m .36214 .23944 L p 
.21473 .54985 L .794 .672 .729 r 
F P 
s 
P 
p 
.002 w 
.21473 .54985 m .17805 .5268 L p 
.34366 .23477 L .794 .672 .729 r 
F P 
s 
P 
p 
.002 w 
.37212 .23785 m .20457 .52884 L p 
.38426 .28067 L .711 .561 .682 r 
F P 
s 
P 
p 
.45991 .29603 m .58863 .2637 L .73407 .30043 L .607 .792 .97 r 
F 
P 
p 
.45543 .29027 m .58863 .2637 L .45991 .29603 L .607 .792 .97 r 
F 
P 
p 
.002 w 
.48269 .29298 m .46882 .27471 L p 
.43771 .26753 L .18 .536 .925 r 
F P 
s 
P 
p 
.3841 .25517 m .44682 .27922 L .43771 .26753 L .18 .536 .925 r 
F 
P 
p 
.44682 .27922 m .48269 .29298 L .43771 .26753 L .18 .536 .925 r 
F 
P 
p 
.002 w 
.45213 .32423 m .42908 .29553 L p 
.43205 .29558 L .994 .784 .512 r 
F P 
s 
P 
p 
.002 w 
.4675 .29493 m .48269 .29298 L p 
.3841 .25517 L .18 .536 .925 r 
F P 
s 
P 
p 
.002 w 
.3841 .25517 m .42996 .28046 L .4675 .29493 L p 
.18 .536 .925 r 
F P 
s 
P 
p 
.002 w 
.2976 .59323 m .26113 .57572 L .42996 .28046 L p 
.596 .42 .613 r 
F P 
s 
P 
p 
.002 w 
.42908 .29553 m .38283 .23796 L p 
.43205 .29558 L .994 .784 .512 r 
F P 
s 
P 
p 
.43205 .29558 m .38283 .23796 L .38238 .22474 L .994 .784 .512 r 
F 
P 
p 
.40555 .25127 m .40679 .25124 L .40665 .25107 L .18 .536 .925 r 
F 
P 
p 
.002 w 
.1771 .52135 m .34269 .23453 L .34366 .23477 L p 
.794 .672 .729 r 
F P 
s 
P 
p 
.002 w 
.17805 .5268 m .1771 .52135 L p 
.34366 .23477 L .794 .672 .729 r 
F P 
s 
P 
p 
.002 w 
.3274 .21614 m .34269 .23453 L p 
.17689 .52117 L .913 .856 .773 r 
F P 
s 
P 
p 
.002 w 
.34269 .23453 m .1771 .52135 L .17689 .52117 L p 
.913 .856 .773 r 
F P 
s 
P 
p 
.002 w 
.34412 .206 m .33629 .20791 L .35325 .2286 L p 
.18 .536 .925 r 
F P 
s 
P 
p 
.002 w 
.38223 .22028 m .34412 .206 L .31928 .24898 L p 
.588 .409 .606 r 
F P 
s 
P 
p 
.002 w 
.17689 .52117 m .15884 .50643 L p 
.3274 .21614 L .913 .856 .773 r 
F P 
s 
P 
p 
.002 w 
.31928 .24898 m .16764 .5113 L p 
.36876 .23856 L .588 .409 .606 r 
F P 
s 
P 
p 
.38223 .22028 m .31928 .24898 L .36876 .23856 L .588 .409 .606 r 
F 
P 
p 
.002 w 
.16764 .5113 m .20457 .52884 L .38223 .22028 L p 
.588 .409 .606 r 
F P 
s 
P 
p 
.002 w 
.20457 .52884 m .25322 .55595 L .38573 .32459 L p 
.711 .561 .682 r 
F P 
s 
P 
p 
.44144 .30703 m .38236 .22412 L .40665 .25107 L .994 .784 .512 r 
F 
P 
p 
.38236 .22412 m .38226 .22122 L .40665 .25107 L .994 .784 .512 r 
F 
P 
p 
.36684 .20233 m .36656 .20052 L .40665 .25107 L .994 .784 .512 r 
F 
P 
p 
.44106 .30844 m .35663 .18801 L .44144 .30703 L .994 .784 .512 r 
F 
P 
p 
.002 w 
.38283 .23796 m .35637 .20503 L p 
.38238 .22474 L .994 .784 .512 r 
F P 
s 
P 
p 
.002 w 
.35663 .18801 m .3569 .17104 L p 
.40665 .25107 L .994 .784 .512 r 
F P 
s 
P 
p 
.40665 .25107 m .42473 .25087 L .42262 .24816 L .18 .536 .925 r 
F 
P 
p 
.40679 .25124 m .42473 .25087 L .40665 .25107 L .18 .536 .925 r 
F 
P 
p 
.40665 .25107 m .42262 .24816 L .38223 .22028 L .18 .536 .925 r 
F 
P 
p 
.002 w 
.4303 .24677 m .41494 .2383 L p 
.42262 .24816 L .18 .536 .925 r 
F P 
s 
P 
p 
.002 w 
.41494 .2383 m .38223 .22028 L p 
.42262 .24816 L .18 .536 .925 r 
F P 
s 
P 
p 
.002 w 
.41494 .2383 m .38223 .22028 L p 
.38283 .23796 L .711 .561 .682 r 
F P 
s 
P 
p 
.43434 .29562 m .40665 .25107 L .44208 .29574 L .994 .784 .512 r 
F 
P 
p 
.002 w 
.42908 .29553 m .3812 .23594 L p 
.40339 .23126 L .607 .792 .97 r 
F P 
s 
P 
p 
.43771 .26753 m .46882 .27471 L .42262 .24816 L .18 .536 .925 r 
F 
P 
p 
.42908 .29553 m .39701 .2153 L .45543 .29027 L .607 .792 .97 r 
F 
P 
p 
.002 w 
.38573 .32459 m .4303 .24677 L p 
.38502 .30335 L .711 .561 .682 r 
F P 
s 
P 
p 
.38502 .30335 m .20457 .52884 L .38573 .32459 L .711 .561 .682 r 
F 
P 
p 
.38236 .22412 m .36684 .20233 L .38226 .22122 L .994 .784 .512 r 
F 
P 
p 
.36684 .20233 m .35663 .18801 L .36656 .20052 L .994 .784 .512 r 
F 
P 
p 
.42908 .29553 m .45543 .29027 L .45991 .29603 L .607 .792 .97 r 
F 
P 
p 
.43434 .29562 m .44208 .29574 L .45224 .30855 L .994 .784 .512 r 
F 
P 
p 
.002 w 
.45224 .30855 m .45213 .32423 L p 
.43434 .29562 L .994 .784 .512 r 
F P 
s 
P 
p 
.002 w 
.43056 .29738 m .42908 .29553 L p 
.73407 .30043 L .607 .792 .97 r 
F P 
s 
P 
p 
.45213 .32423 m .44106 .30844 L .44144 .30703 L .994 .784 .512 r 
F 
P 
p 
.002 w 
.73407 .30043 m .45213 .32423 L .43056 .29738 L p 
.607 .792 .97 r 
F P 
s 
P 
p 
.002 w 
.42996 .28046 m .4675 .29493 L .42472 .37004 L p 
.596 .42 .613 r 
F P 
s 
P 
p 
.002 w 
.46882 .27471 m .4303 .24677 L .38573 .32459 L p 
.799 .677 .73 r 
F P 
s 
P 
p 
.002 w 
.38573 .32459 m .25322 .55595 L p 
.39326 .37328 L .799 .677 .73 r 
F P 
s 
P 
p 
.46882 .27471 m .38573 .32459 L .39326 .37328 L .799 .677 .73 r 
F 
P 
p 
.002 w 
.35637 .20503 m .35663 .18801 L p 
.38238 .22474 L .994 .784 .512 r 
F P 
s 
P 
p 
.40339 .23126 m .35637 .20503 L .39701 .2153 L .607 .792 .97 r 
F 
P 
p 
.002 w 
.3812 .23594 m .35637 .20503 L p 
.40339 .23126 L .607 .792 .97 r 
F P 
s 
P 
p 
.002 w 
.31046 .59572 m .2976 .59323 L .42472 .37004 L p 
.104 0 .262 r 
F P 
s 
P 
p 
.002 w 
.42472 .37004 m .4675 .29493 L p 
.42103 .38393 L .104 0 .262 r 
F P 
s 
P 
p 
.42103 .38393 m .31046 .59572 L .42472 .37004 L .104 0 .262 r 
F 
P 
p 
.41494 .2383 m .38283 .23796 L .38426 .28067 L .711 .561 .682 r 
F 
P 
p 
.38283 .23796 m .37212 .23785 L .38426 .28067 L .711 .561 .682 r 
F 
P 
p 
.002 w 
.4303 .24677 m .41494 .2383 L p 
.38426 .28067 L .711 .561 .682 r 
F P 
s 
P 
p 
.38502 .30335 m .38426 .28067 L .20457 .52884 L .711 .561 .682 r 
F 
P 
p 
.4303 .24677 m .38426 .28067 L .38502 .30335 L .711 .561 .682 r 
F 
P 
p 
.002 w 
.35637 .20503 m .78117 .29646 L .73407 .30043 L p 
.607 .792 .97 r 
F P 
s 
P 
p 
.004 w 
.44919 .76552 m 
.44939 .73646 L 
s 
P 
p 
.004 w 
.8536 .28618 m 
.91641 .26886 L 
s 
P 
p 
.002 w 
.78041 .2645 m .3569 .17104 L .35637 .20503 L p 
.799 .611 .648 r 
F P 
s 
P 
p 
.004 w 
.31299 .13298 m 
.35663 .18801 L 
s 
P 
p 
.002 w 
.35637 .20503 m .78117 .29646 L .78041 .2645 L p 
.799 .611 .648 r 
F P 
s 
P 
p 
.004 w 
.78079 .28046 m 
.91641 .26886 L 
s 
P 
p 
.004 w 
.84734 .2427 m 
.91641 .26886 L 
s 
P 
p 
.004 w 
.45861 .70565 m 
.44919 .76552 L 
s 
P 
p 
.004 w 
.91641 .26886 m 
.82245 .32203 L 
s 
P 
p 
.004 w 
.4035 .67389 m 
.44919 .76552 L 
s 
P 
p 
.004 w 
.81329 .26062 m 
.91641 .26886 L 
s 
P 
p 
.002 w 
.4675 .29493 m .48269 .29298 L .31046 .59572 L p 
.104 0 .262 r 
F P 
s 
P 
p 
.004 w 
.44939 .73646 m 
.45198 .34695 L 
s 
P 
p 
.002 w 
.1612 .51309 m .17805 .5268 L .21473 .54985 L p 
0 .403 .819 r 
F P 
s 
P 
p 
.1612 .51309 m .21473 .54985 L .16764 .5113 L 0 .403 .819 r 
F 
P 
p 
.002 w 
.20457 .52884 m .16764 .5113 L p 
.21473 .54985 L 0 .403 .819 r 
F P 
s 
P 
p 
.002 w 
.25322 .55595 m .20457 .52884 L p 
.21473 .54985 L 0 .403 .819 r 
F P 
s 
P 
p 
.002 w 
.29385 .58164 m .25322 .55595 L p 
.21473 .54985 L 0 .403 .819 r 
F P 
s 
P 
p 
.002 w 
.31046 .59572 m .29385 .58164 L p 
.21473 .54985 L 0 .403 .819 r 
F P 
s 
P 
p 
.002 w 
.2976 .59323 m .31046 .59572 L p 
.21473 .54985 L 0 .403 .819 r 
F P 
s 
P 
p 
.002 w 
.21473 .54985 m .26113 .57572 L .2976 .59323 L p 
0 .403 .819 r 
F P 
s 
P 
p 
.004 w 
.49644 .66826 m 
.44919 .76552 L 
s 
P 
p 
.004 w 
.44919 .76552 m 
.43702 .65968 L 
s 
P 
p 
.002 w 
.15884 .50643 m .32705 .21572 L .3274 .21614 L p 
.913 .856 .773 r 
F P 
s 
P 
p 
.002 w 
.34412 .206 m .33629 .20791 L .32705 .21572 L p 
0 0 .172 r 
F P 
s 
P 
p 
.32705 .21572 m .15866 .50694 L .34412 .206 L 0 0 .172 r 
F 
P 
p 
.002 w 
.32705 .21572 m .15884 .50643 L .15866 .50694 L p 
0 0 .172 r 
F P 
s 
P 
p 
.002 w 
.29385 .58164 m .31046 .59572 L .48269 .29298 L p 
.924 .876 .77 r 
F P 
s 
P 
p 
.002 w 
.48269 .29298 m .46882 .27471 L .29385 .58164 L p 
.924 .876 .77 r 
F P 
s 
P 
p 
.002 w 
.16764 .5113 m .15756 .51013 L .1612 .51309 L p 
0 .403 .819 r 
F P 
s 
P 
p 
.002 w 
.15866 .50694 m .15756 .51013 L p 
.34412 .206 L 0 0 .172 r 
F P 
s 
P 
p 
.002 w 
.15756 .51013 m .16764 .5113 L .34412 .206 L p 
0 0 .172 r 
F P 
s 
P 
p 
.002 w 
.25322 .55595 m .29385 .58164 L .46882 .27471 L p 
.799 .677 .73 r 
F P 
s 
P 
p 
.004 w 
.29452 .17668 m 
.31299 .13298 L 
s 
P 
p 
.004 w 
.39362 .1672 m 
.31299 .13298 L 
s 
P 
p 
.004 w 
.31299 .13298 m 
.34309 .22024 L 
s 
P 
p 
.004 w 
.33585 .12658 m 
.31299 .13298 L 
s 
P 
p 
.002 w 
.05095 .1088 m 
.87207 .02499 L 
s 
.87207 .02499 m 
.89225 .64214 L 
s 
.89225 .64214 m 
.02499 .69478 L 
s 
.02499 .69478 m 
.05095 .1088 L 
s 
.95385 .24565 m 
.87207 .02499 L 
s 
.87207 .02499 m 
.89225 .64214 L 
s 
.89225 .64214 m 
.97501 .78004 L 
s 
.97501 .78004 m 
.95385 .24565 L 
s 
P 
p 
p 
.002 w 
.95385 .24565 m 
.87207 .02499 L 
s 
P 
p 
.002 w 
.94944 .23375 m 
.94321 .2343 L 
s 
P 
[(0)] .96189 .23266 -1 .08765 Mshowa 
p 
.002 w 
.92611 .17081 m 
.91989 .17139 L 
s 
P 
[(0.5)] .93856 .16967 -1 .09198 Mshowa 
p 
.002 w 
.90045 .10156 m 
.89423 .10216 L 
s 
P 
[(1)] .91289 .10036 -1 .09676 Mshowa 
p 
.002 w 
.87207 .02499 m 
.86585 .02563 L 
s 
P 
[(1.5)] .8845 .02373 -1 .10206 Mshowa 
p 
.001 w 
.94495 .22163 m 
.94121 .22196 L 
s 
P 
p 
.001 w 
.94037 .20928 m 
.93663 .20961 L 
s 
P 
p 
.001 w 
.93571 .1967 m 
.93197 .19703 L 
s 
P 
p 
.001 w 
.93095 .18388 m 
.92722 .18422 L 
s 
P 
p 
.001 w 
.92118 .1575 m 
.91744 .15785 L 
s 
P 
p 
.001 w 
.91615 .14392 m 
.91241 .14427 L 
s 
P 
p 
.001 w 
.91102 .13008 m 
.90728 .13044 L 
s 
P 
p 
.001 w 
.90578 .11596 m 
.90205 .11632 L 
s 
P 
p 
.001 w 
.895 .08687 m 
.89127 .08724 L 
s 
P 
p 
.001 w 
.88944 .07188 m 
.88571 .07225 L 
s 
P 
p 
.001 w 
.88377 .05657 m 
.88004 .05695 L 
s 
P 
p 
.001 w 
.87798 .04095 m 
.87425 .04133 L 
s 
P 
p 
.001 w 
.95385 .24565 m 
.95012 .24598 L 
s 
P 
P 
p 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .31299 .13298 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .91641 .26886 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .44919 .76552 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(1)] .45224 .30855 1.3 1.3 Mshowa 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{304, 256},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004`000101000`40O003h00Oogoo<Goo003oOola
Ool00?mooc5oo`00ogoo<Goo003lOol50002Ool00`00Oomoo`02Ool00`00Oomoo`0UOol00?ioo`03
001oogoo00Ioo`03001oo`0002Ioo`00oWoo00<007ooOol027oo00<007ooOol097oo003nOol00`00
Oomoo`06Ool2000WOol00?ioo`03001oogoo00Ioo`03001oogoo02Ioo`00oGoo0P0027oo0`009Woo
0038Ool5001SOol00<Yoo`03001oogoo06=oo`00bWoo00<007ooOol0Hgoo003:Ool00`00Oomoo`0j
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00<Yoo`03001oogoo03aoo`03001oogoo00Io
o`03001oo`0001]oo`00bGoo0P00?Woo00<007ooOol027oo00<007ooOol06Goo002>Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`1UOol50004Ool00`00Oomoo`06Ool2000LOol008eoo`03
001oo`0000Moo`03001oo`0005aoo`X000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
01]oo`00SGoo00<007oo00002Goo00<007ooOol0DGoo2@000Woo00<007ooOol02Goo0P000Woo0P00
27oo0`006goo002=Ool00`00Ool00007Ool2001:Ool;000FOol2000ZOol008eoo`03001oo`0000Mo
o`03001oogoo03moo`X000Yoo`03001oogoo01Aoo`8002Yoo`00SWoo00<007ooOol01Woo0`00=Woo
2@0027oo00<007ooOol087oo0`00:Goo001MOol00`00Oomoo`1VOol:0006Ool00`00Oomoo`0[Ool0
0`00Ool0000YOol005aoo`03001oo`0005ioo`T000Eoo`03001oogoo03Ioo`04001oogoo000XOol0
05aoo`03001oo`0005Aoo`X000=oo`03001oogoo00Qoo`03001oogoo03Ioo`04001oogoo000XOol0
05aoo`03001oo`0004Yoo`X00003Ool007oo04ioo`04001oogoo000XOol005aoo`03001oo`00045o
o`X005Yoo`05001oo`00Ool0000WOol002Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo
02Yoo`03001oogoo03Ioo`X006Aoo`05001oogooOol0000WOol002Eoo`03001oo`0000Moo`03001o
o`0005]oo`T000Qoo`03001oogoo06=oo`05001oogooOol0000WOol0021oo`<0009oo`03001oo`00
00Uoo`03001oogoo04moo`X000Ioo`03001oogoo06ioo`03001oogoo009oo`03001oogoo02Aoo`00
9Goo00<007oo00001goo0P00B7oo2P001Goo00<007ooOol0NGoo00@007ooOomoo`8002Ioo`009Goo
00<007oo00001goo00<007ooOol0?Woo2@0017oo00<007ooOol0Q7oo00<007ooOol00goo00<007oo
Ool08goo000VOol00`00Oomoo`06Ool3000dOol:0003Ool00`00Oomoo`2?Ool00`00Oomoo`02Ool0
0`00Oomoo`0SOol005eoo`T0009oo`03001oogoo09Yoo`03001oogoo009oo`03001oogoo02=oo`00
Dgoo2`00Ygoo00@007ooOomoo`<002Aoo`00B7oo2`002Woo00<007ooOol0YGoo00<007ooOol00goo
00<007ooOol08Woo000mOol00`00Oomoo`09002lOol00`00Oomoo`03Ool00`00Oomoo`02Ool5000K
Ool003=oo`03001oogoo00X00<Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo01]oo`00
;Goo2@001goo00<007ooOol0aGoo00<007ooOol017oo00<007ooOol00goo00<007ooOol06goo000S
Ool:0006Ool00`00Oomoo`3?Ool00`00Oomoo`02Ool30005Ool00`00Oomoo`0KOol001Uoo`X000Eo
o`03001oogoo0=Yoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo01]oo`0057oo1@001Goo
00<007ooOol0i7oo00<007ooOol01Goo00@007ooOomoo`8001eoo`0057oo0P00kgoo00<007ooOol0
1Woo00<007ooOol07goo000DOol00`00Ool0003^Ool00`00Oomoo`05Ool2000QOol001Aoo`04001o
ogoo003]Ool00`00Oomoo`06Ool00`00Oomoo`0OOol001Aoo`05001oogooOol0003/Ool00`00Oomo
o`07Ool00`00Oomoo`0NOol001Aoo`03001oogoo009oo`03001oogoo04Yoo`8009eoo`03001oogoo
00Moo`03001oogoo01ioo`0057oo00<007ooOol00goo00<007ooOol0AGoo1000Wgoo00<007ooOol0
1Woo0P0087oo000DOol00`00Oomoo`04Ool00`00Oomoo`12Ool2002SOol00`00Oomoo`08Ool00`00
Oomoo`0MOol001Aoo`03001oogoo00Eoo`03001oogoo045oo`@00:5oo`03001oogoo00Qoo`03001o
ogoo01eoo`0057oo00<007ooOol01Woo00<007ooOol0?goo00D007oo000007oo008009moo`03001o
ogoo00Uoo`03001oogoo01aoo`0057oo00<007ooOol01goo00<007ooOol0?Woo00@007oo000000=o
o`<009aoo`03001oogoo00Qoo`8001ioo`004goo00<007ooOol02Goo00<007ooOol0?7oo00H007oo
Ool007oo0005Ool2002JOol00`00Oomoo`09Ool00`00Oomoo`0LOol001=oo`03001oogoo00Yoo`03
001oogoo03]oo`07001oogooOol007oo00001Woo0`00Ugoo00<007ooOol02Woo00<007ooOol06goo
000COol00`00Oomoo`0;Ool00`00Oomoo`0jOol01@00Oomoogoo00000Woo00<007ooOol01Woo0P00
UGoo00<007ooOol02Woo00<007ooOol06goo000COol00`00Oomoo`0<Ool00`00Oomoo`0hOol00`00
Oomoo`03Ool200000goo001oo`08Ool2002COol00`00Oomoo`09Ool2000MOol001=oo`03001oogoo
00aoo`03001oogoo03Qoo`03001oogoo00=oo`800003Ool007oo00Yoo`<0091oo`03001oogoo00]o
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`004goo00<007oo
Ool03Goo00<007ooOol0=goo00<007ooOol00Woo0P0000Aoo`00Ool000eoo`8008ioo`03001oogoo
00]oo`03001oogoo009oo`03001oo`0000Moo`03001oo`0000]oo`004goo00<007ooOol03Woo00<0
07ooOol0=Goo00<007ooOol01Goo00D007ooOomoo`0000ioo`8008aoo`03001oogoo00aoo`07001o
ogooOol007oo00002Goo00<007ooOol02Goo000COol00`00Oomoo`0?Ool00`00Oomoo`0dOol00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoogoo0`00UGoo00<007ooOol02Woo0`000goo00<007oo
00001goo0P0037oo000COol00`00Oomoo`0@Ool00`00Oomoo`0bOol00`00Oomoo`06Ool00`00Oomo
o`03Ool01000Oomoo`000VId1000TGoo00<007ooOol037oo00L007ooOomoo`00Ool00007Ool00`00
Oomoo`0;Ool001=oo`03001oogoo015oo`03001oogoo035oo`03001oogoo00Moo`03001oogoo00=o
o`03001oo`0000IVM0D008aoo`03001oogoo00eoo`05001oogooOol00008Ool3000;Ool001=oo`03
001oogoo019oo`03001oogoo03Yoo`03001oogoo00=oo`03001oo`0000]VM0D008Qoo`03001oogoo
00aoo`03001oogoo01Qoo`004goo00<007ooOol04goo00<007ooOol0>Goo00<007ooOol017oo0P00
46Id1000Q7oo00<007ooOol02goo0P006Woo000COol00`00Oomoo`0DOol00`00Oomoo`0iOol00`00
Oomoo`04Ool00`00IWAVM00BIW@5001oOol00`00Oomoo`0=Ool00`00Oomoo`0GOol001=oo`03001o
ogoo01Eoo`03001oogoo03Qoo`03001oogoo00Aoo`03001VM6Id01MVM0@007]oo`03001oogoo00eo
o`03001oogoo01Moo`004goo00<007ooOol05Woo00<007ooOol0=goo00<007ooOol017oo00<006Id
IW@06fId1@00MWoo00<007ooOol037oo0P006Goo000COol00`00Oomoo`0GOol00`00Oomoo`0gOol0
0`00Oomoo`03Ool00`00IWAVM00PIW@5001aOol00`00Oomoo`0>Ool00`00Oomoo`0FOol001=oo`03
001oogoo01Qoo`03001oogoo03Ioo`03001oogoo00=oo`03001VM6Id02EVM0@006eoo`03001oogoo
00ioo`03001oogoo01Ioo`004goo00<007ooOol06Goo00<007ooOol0=Woo0`000Woo0`00:FId1@00
J7oo00<007ooOol03goo00<007ooOol05Goo000COol00`00Oomoo`0JOol00`00Oomoo`0dOol20002
BK<400000dlo00000002000ZIW@4001TOol00`00Oomoo`0>Ool2000GOol001=oo`03001oogoo01]o
o`03001oogoo035oo`0400001@050005BK<20004Ccl5000YIW@5001OOol00`00Oomoo`0?Ool00`00
Oomoo`0EOol001=oo`03001oogoo01aoo`03001oogoo02moo`0600001@050019/`001DVc00<004lo
Ccl01dlo1@00:FId1000Fgoo00<007ooOol047oo00<007ooOol057oo000COol00`00Oomoo`0MOol0
0`00Oomoo`0]Ool01`0000D01@050019/`0000I9/`03001??dlo00]??`@002UVM0D005Ioo`03001o
ogoo011oo`03001oogoo01Aoo`004Woo00<007ooOol07goo00<007ooOol0;7oo00@0000500D000Y9
/`03001??dlo00i??`D002UVM0D0055oo`03001oogoo00moo`8000Ioo`03001oogoo00eoo`004Woo
00<007ooOol087oo00<007ooOol0:Woo00D0000500D01@0000]9/`03001??dlo019??`@002YVM0@0
04eoo`03001oogoo015oo`03001oogoo009oo`03001oo`0000ioo`004Woo00<007ooOol08Goo00<0
07ooOol0:Goo00@0000500D000a9/`03001??dlo01I??`D002UVM0D004Qoo`03001oogoo015oo`03
001oogoo009oo`03001oo`0000ioo`004Woo00<007ooOol08Woo00<007ooOol09goo00<0000500D0
0P003DVc00<004loCcl06Tlo1@00:FId1000A7oo00<007ooOol047oo0`000goo00<007oo00003Woo
000BOol00`00Oomoo`0SOol00`00Oomoo`0VOol0100000D01@003DVc00<005Xe000084lo1000:FId
1@00?goo00<007ooOol04Woo00L007ooOomoo`00Ool0000>Ool0019oo`03001oogoo02Aoo`03001o
ogoo02Aoo`0300001@05008000e9/`03001J=EXe00UJ=@8001A??`03Cci??dlo009??`D002UVM0D0
03Yoo`03001oogoo019oo`03001oogoo009oo`03001oogoo00eoo`004Woo00<007ooOol09Goo00<0
07ooOol08Woo00D0000500D01@0000e9/`03001J=EXe00aJ=@8001a??`@002YVM0@002eoo`8000Mo
o`03001oogoo01=oo`03001oogoo015oo`004Woo00<007ooOol09Woo00<007ooOol08Goo00<00005
00D00P0034Vc00<005XeFSD03eXe0P007Tlo1@00:FId1@00:Woo0`0017oo00<007ooOol03Woo1P00
4goo000BOol00`00Oomoo`0WOol00`00Oomoo`0OOol01@0000D01@0500003DVc00<005XeFSD045Xe
00=V]`0000008Dlo1000:VId1000:Goo0`0000=oo`00Ool00goo30001Goo00<007ooOol04Goo000B
Ool00`00Oomoo`0XOol00`00Oomoo`0NOol0100000D01@003DVc00<005XeFSD045Xe00D006JgI[MV
]`0002A??`D002UVM0D0029oo`/0015oo`03001oogoo015oo`004Woo00<007ooOol0:Goo00<007oo
Ool077oo00<0000500D00P003DVc00<005XeFSD03eXe00<006JgI[L00fJg00<004loCcl09Tlo1@00
:FId1@004Goo30001Woo10004Woo00<007ooOol04Goo000BOol00`00Oomoo`0YOol00`00Oomoo`0L
Ool0100000D01@003DVc00<005XeFSD045Xe00<006JgI[L016Jg0P00:dlo1000:VId10000Woo4P00
2goo00@007ooOomoo`<000moo`03001oogoo015oo`004Woo00<007ooOol0:Woo00<007ooOol06Woo
00<0000500D00P003DVc00<005XeFSD03eXe00<006JgI[L01fJg00<004loCcl0;4lo1@00:fId00<0
07ooOol03goo3`000goo0`0037oo00<007ooOol04Goo000BOol00`00Oomoo`0[Ool00`00Oomoo`0H
Ool01@0000D01@0500003DVc00<005XeFSD045Xe00<006JgI[L026Jg00<004loCcl0<4lo10009fId
00<007ooOol06Woo00@007ooOomoo`P000Yoo`03001oogoo015oo`004Woo00<007ooOol0;7oo00<0
07ooOol05goo00<0000500D00P0034Vc00<005XeFSD045Xe00<006JgI[L02VJg0P00=4lo1@008VId
00<007ooOol05goo3P002goo00<007ooOol04Goo000BOol00`00Oomoo`0]Ool00`00Oomoo`0EOol0
1@0000D01@0500003DVc00<005XeFSD03eXe00<006JgI[L00VJg1@001VJg00<004loCcl0=Tlo1@00
7FId00<007ooOol03Goo2P000goo00@007ooOomoo`D000eoo`03001oogoo015oo`004Woo00<007oo
Ool0;Woo00<007ooOol057oo00@0000500D000e9/`03001J=EXe011J=@03001V]fJg00AV]`03001V
]fJg00EV]`03001gV00003a??`@001UVM003001oogoo00=oo`X000eoo`@00003Ool0000000moo`03
001oogoo015oo`004Woo00<007ooOol0;goo00<007ooOol04Woo00<0000500D00P003DVc00<005Xe
FSD03eXe00<006JgI[L01FJg00<006JgI[L01FJg00<007NH0000@4lo1@0056Id1P0057oo10000goo
00<007ooOol01Woo0P001goo00<007ooOol04Goo000BOol00`00Oomoo`0`Ool00`00Oomoo`0@Ool0
1@0000D01@0500003DVc00<005XeFSD045Xe00<006JgI[L01FJg00<006JgI[L016Jg00D007NHMiQg
V00004A??`@0011VM003001oogoo01Aoo`<000Aoo`<000Yoo`03001oogoo00Eoo`03001oogoo015o
o`004Woo00<007ooOol0<Goo00<007ooOol03goo00<0000500D00P003DVc00<005XeFSD03eXe00<0
06JgI[L01VJg00<006JgI[L016Jg00<007NHMiP00WNH00<004loCcl0ADlo1@002fId00<007ooOol0
4Woo0P001Woo0P0037oo00<007ooOol01Goo00<007ooOol04Goo000BOol00`00Oomoo`0bOol00`00
Oomoo`0=Ool01@0000D01@0500003DVc00<005XeFSD045Xe00<006JgI[L01FJg0P001FJg00<007NH
MiP00gNH00<004loCcl0BTlo1@001VId00<007ooOol067oo0P0000=oo`00Ool02Woo00<007oo0000
1Woo00<007ooOol04Goo000AOol00`00Oomoo`0dOol00`00Oomoo`0<Ool0100000D01@003DVc00<0
05XeFSD045Xe00<006JgI[L03FJg00<007NHMiP017NH00<004loCcl0CTlo10000VId00<007ooOol0
5goo00D007ooOomoo`0000]oo`03001oo`0000Moo`03001oogoo011oo`004Goo00<007ooOol0=Goo
00<007ooOol02Woo00D0000500D01@0000e9/`03001J=EXe011J=@03001V]fJg00aV]`03001gV7NH
00EgV1e??`AF5C1??`L001Moo`8000Aoo`03001oogoo00Qoo`800003Ool0000000Ioo`03001oogoo
011oo`004Goo00<007ooOol0=Woo00<007ooOol02Goo00@0000500D000e9/`03001J=EXe011J=@03
001V]fJg00aV]`03001gV7NH00EgV003001??dlo049??`h001]oo`8000Ioo`03001oogoo01=oo`03
001oogoo011oo`004Goo00<007ooOol0=goo00<007ooOol017oo10000P050P003DVc00<005XeFSD0
3eXe00<006JgI[L03FJg00<007NHMiP01GNH>Dlo3P009Goo0P0027oo00<007ooOol04goo00<007oo
Ool047oo000AOol00`00Oomoo`0hOol60002Ool01@0000D01@0500003DVc00<005XeFSD045Xe00<0
06JgI[L036Jg00<007NHMiP01GNH00<004loCcl0:dlo3P00<7oo00<007ooOol027oo00<007ooOol0
4goo00<007ooOol047oo000AOol00`00Oomoo`0hOol00`00Oomoo`05Ool00`0000D01@02000=BK<0
0`00FSEJ=@0?FSD00`00I[MV]`0=I[L00`00MiQgV004MiP00`00Ccm??`0QCcl=000jOol2000;Ool0
0`00Oomoo`0COol00`00Oomoo`0@Ool0015oo`03001oogoo03Qoo`03001oogoo00Aoo`0500001@05
00D0000=BK<00`00FSEJ=@0@FSD00`00I[MV]`0<I[L00`00MiQgV005MiP00`00Ccm??`0ECcl=0014
Ool2000=Ool00`00Oomoo`0COol00`00Oomoo`0@Ool0015oo`03001oogoo03Qoo`03001oogoo00Ao
o`0400001@05000=BK<00`00FSEJ=@0@FSD00`00I[MV]`0=I[L00`00MiQgV004MiP00`00Ccm??`0:
Ccl=001>Ool2000?Ool00`00Oomoo`0COol00`00Oomoo`0@Ool0015oo`03001oogoo03Qoo`03001o
ogoo00=oo`0500001@0500D0000=BK<00`00FSEJ=@0@FSD00`00I[MV]`0<I[L00`00MiQgV004MiP0
0`00Ccl0000<001IOol00`00Oomoo`0?Ool00`00Oomoo`0COol00`00Oomoo`0@Ool0015oo`03001o
ogoo03Qoo`03001oogoo00=oo`0400001@05000=BK<00`00FSEJ=@0@FSD?I[L00`00MiQgV005MiP3
001gOol00`00Oomoo`0COol00`00Oomoo`0@Ool0015oo`03001oogoo03Qoo`03001oogoo009oo`03
00001@05008000e9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH00AgV003001oogoo07Qo
o`03001oogoo01=oo`03001oogoo011oo`004Goo00<007ooOol0>7oo00D007ooOomoo`0000<01@03
0019/dVc00]9/`03001J=EXe011J=@03001V]fJg00aV]`03001gV7NH00EgV003001oogoo07Qoo`03
001oogoo01=oo`03001oogoo011oo`004Goo00<007ooOol0<Goo00<007ooOol017oo00D007ooOomo
o`0000801@8000e9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH00AgV003001oogoo07Uo
o`03001oogoo01=oo`03001oogoo011oo`004Goo00<007ooOol0<7oo00<007oo000017oo0`0000=o
o`0000D00P0500<004VcBK<02dVc00<005XeFSD045Xe00<006JgI[L036Jg00<007NHMiP01GNH00<0
07ooOol0NGoo00<007ooOol04goo00<007ooOol047oo000AOol00`00Oomoo`0`Ool00`00Ool00005
Ool01000Oomoo`000P0500<004VcBK<02dVc00<005XeFSD045Xe00<006JgI[L03FJg00<007NHMiP0
17NH00<007ooOol0NWoo00<007ooOol04goo00<007ooOol047oo000AOol00`00Oomoo`0`Ool00`00
Ool00005Ool00`00Ool0000300D00`00BK=9/`0;BK<00`00FSEJ=@0@FSD00`00I[MV]`0<I[L00`00
MiQgV004MiP00`00Oomoo`1kOol00`00Oomoo`0COol00`00Oomoo`0@Ool0015oo`03001oogoo031o
o`03001oo`0000Eoo`03001oo`0000801@030019/dVc00]9/`03001J=EXe011J=@03001V]fJg00eV
]`03001gV7NH00AgV003001oogoo07]oo`03001oogoo01=oo`03001oogoo011oo`004Goo00<007oo
Ool0<Goo00<007ooOol017oo0P000P050P003DVc00<005XeFSD03eXe00<006JgI[L03FJg00<007NH
MiP017NH0P00OGoo00<007ooOol04goo00<007ooOol047oo000AOol00`00Oomoo`0hOol01@0000D0
1@0500003DVc00<005XeFSD045Xe00<006JgI[L036Jg00<007NHMiP01GNH0P00OGoo00<007ooOol0
4goo00<007ooOol047oo000AOol00`00Oomoo`0hOol0100000D01@003TVc00<005XeFSD03eXe00<0
06JgI[L03FJg00<007NHMiP017NH00<007oo0000OGoo00<007ooOol04goo00<007ooOol047oo000A
Ool00`00Oomoo`0gOol01@0000D01@0500003DVc00<005XeFSD045Xe00<006JgI[L036Jg00<007NH
MiP01GNH00<007oo0000OGoo00<007ooOol04goo00<007ooOol047oo000@Ool00`00Oomoo`0hOol0
100000D01@003DVc00<005XeFSD045Xe00<006JgI[L03FJg00<007NHMiP017NH00@007ooOol007eo
o`03001oogoo01=oo`03001oogoo011oo`0047oo00<007ooOol0=goo00<0000500D00P003DVc00<0
05XeFSD03eXe00<006JgI[L03FJg00<007NHMiP017NH00D007ooOomoo`0007eoo`03001oogoo01=o
o`03001oogoo011oo`0047oo00<007ooOol0=Woo00D0000500D01@0000e9/`03001J=EXe011J=@03
001V]fJg00eV]`03001gV7NH00AgV005001oogooOol0001mOol00`00Oomoo`0COol00`00Oomoo`0@
Ool0011oo`03001oogoo03Ioo`0300001@05008000e9/`03001J=EXe00mJ=@03001V]fJg00eV]`03
001gV7NH00AgV003001oogoo009oo`03001oogoo07]oo`03001oogoo01=oo`03001oogoo011oo`00
47oo00<007ooOol0=Goo00D0000500D01@0000e9/`03001J=EXe011J=@03001V]fJg00aV]`03001g
V7NH00EgV003001oogoo009oo`03001oogoo07]oo`03001oogoo01=oo`03001oogoo011oo`0047oo
00<007ooOol0=Goo00@0000500D000i9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH00Ag
V003001oogoo00=oo`03001oogoo07]oo`03001oogoo01Aoo`03001oogoo00moo`0047oo00<007oo
Ool0=7oo00D0000500D01@0000e9/`03001J=EXe011J=@03001V]fJg00aV]`03001gV7NH00EgV003
001oogoo00=oo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo00moo`0047oo00<007ooOol0
=7oo00@0000500D000e9/`03001J=EXe011J=@03001V]fJg00eV]`03001gV7NH00AgV003001oogoo
00Aoo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo00moo`0047oo00<007ooOol0<goo00<0
000500D00P003DVc00<005XeFSD03eXe00<006JgI[L03FJg00<007NHMiP01GNH00<007ooOol017oo
00<007ooOol0O7oo00<007ooOol04goo00<007ooOol03goo000@Ool00`00Oomoo`0bOol01@0000D0
1@0500003DVc00<005XeFSD045Xe00<006JgI[L03FJg00<007NHMiP017NH00<007ooOol01Goo00<0
07ooOol0O7oo00<007ooOol04goo00<007ooOol03goo000@Ool00`00Oomoo`0bOol00`0000D01@02
000=BK<00`00FSEJ=@0?FSD00`00I[MV]`0=I[L00`00MiQgV004MiP00`00Oomoo`06Ool00`00Oomo
o`1lOol00`00Oomoo`0COol00`00Oomoo`0?Ool0011oo`03001oogoo035oo`0500001@0500D0000=
BK<00`00FSEJ=@0@FSD00`00I[MV]`0<I[L00`00MiQgV005MiP00`00Oomoo`06Ool00`00Oomoo`1l
Ool00`00Oomoo`0COol00`00Oomoo`0?Ool0011oo`03001oogoo035oo`0400001@05000>BK<00`00
FSEJ=@0?FSD00`00I[MV]`0=I[L00`00MiQgV004MiP00`00Oomoo`07Ool00`00Oomoo`1lOol00`00
Oomoo`0COol00`00Oomoo`0?Ool0011oo`03001oogoo031oo`0500001@0500D0000=BK<00`00FSEJ
=@0?FSD00`00I[MV]`0=I[L00`00MiQgV005MiP00`00Oomoo`07Ool00`00Oomoo`1lOol00`00Oomo
o`0COol00`00Oomoo`0?Ool0011oo`03001oogoo031oo`0400001@05000=BK<00`00FSEJ=@0@FSD0
0`00I[MV]`0=I[L00`00MiQgV004MiP00`00Oomoo`08Ool00`00Oomoo`1lOol00`00Oomoo`0COol0
0`00Oomoo`0?Ool0011oo`03001oogoo02moo`0300001@05008000e9/`03001J=EXe00mJ=@03001V
]fJg00eV]`03001gV7NH00EgV003001oogoo00Qoo`03001oogoo07aoo`03001oogoo01=oo`03001o
ogoo00moo`0047oo00<007ooOol0;Woo00D0000500D01@0000e9/`03001J=EXe011J=@03001V]fJg
00eV]`03001gV7NH00AgV003001oogoo00Uoo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo
00moo`0047oo00<007ooOol0;Woo00@0000500D000i9/`03001J=EXe00mJ=@03001V]fJg00eV]`03
001gV7NH00AgV003001oogoo00Yoo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo00moo`00
47oo00<007ooOol0;Goo00D0000500D01@0000e9/`03001J=EXe011J=@03001V]fJg00aV]`03001g
V7NH00EgV003001oogoo00Yoo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo00moo`0047oo
00<007ooOol0;Goo00@0000500D000i9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH00Ag
V003001oogoo00]oo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo00moo`0047oo00<007oo
Ool0;7oo00D0000500D01@0000e9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH00EgV003
001oogoo00]oo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo00moo`0047oo00<007ooOol0
;7oo00@0000500D000e9/`03001J=EXe011J=@03001V]fJg00eV]`03001gV7NH00AgV003001oogoo
00aoo`03001oogoo07aoo`03001oogoo01=oo`03001oogoo00moo`003goo00<007ooOol0;7oo00<0
000500D00P003DVc00<005XeFSD03eXe00<006JgI[L03FJg00<007NHMiP01GNH00<007ooOol037oo
00<007ooOol0O7oo00<007ooOol04goo00<007ooOol03goo000?Ool00`00Oomoo`0[Ool01@0000D0
1@0500003DVc00<005XeFSD045Xe00<006JgI[L03FJg00<007NHMiP017NH00<007ooOol03Goo00<0
07ooOol0O7oo00<007ooOol04goo00<007ooOol03goo000?Ool00`00Oomoo`0[Ool0100000D01@00
3TVc00<005XeFSD03eXe00<006JgI[L03FJg00<007NHMiP017NH00<007ooOol03Woo00<007ooOol0
O7oo00<007ooOol04goo00<007ooOol03goo000?Ool00`00Oomoo`0ZOol01@0000D01@0500003DVc
00<005XeFSD03eXe00<006JgI[L03VJg00<007NHMiP017NH00<007ooOol03Woo00<007ooOol0O7oo
00<007ooOol04goo00<007ooOol03goo000?Ool00`00Oomoo`0ZOol0100000D01@003TVc00<005Xe
FSD03eXe00<006JgI[L03FJg00<007NHMiP017NH00<007ooOol03goo00<007ooOol0O7oo00<007oo
Ool04goo00<007ooOol03goo000?Ool00`00Oomoo`0YOol01@0000D01@0500003DVc00<005XeFSD0
3eXe00<006JgI[L03FJg00<007NHMiP01GNH00<007ooOol03goo00<007ooOol0O7oo00<007ooOol0
4goo00<007ooOol03goo000?Ool00`00Oomoo`0XOol01@0000D01@0500003DVc00<005XeFSD045Xe
00<006JgI[L03FJg00<007NHMiP017NH00<007ooOol047oo00<007ooOol0O7oo00<007ooOol04goo
00<007ooOol03goo000?Ool00`00Oomoo`0XOol00`0000D01@02000=BK<00`00FSEJ=@0?FSD00`00
I[MV]`0=I[L00`00MiQgV005MiP00`00Oomoo`0@Ool00`00Oomoo`1lOol00`00Oomoo`0COol00`00
Oomoo`0?Ool000moo`03001oogoo02Moo`0500001@0500D0000=BK<00`00FSEJ=@0@FSD00`00I[MV
]`0=I[L00`00MiQgV004MiP00`00Oomoo`0AOol00`00Oomoo`1lOol00`00Oomoo`0COol00`00Oomo
o`0?Ool000moo`03001oogoo02Moo`0400001@05000>BK<00`00FSEJ=@0?FSD00`00I[MV]`0=I[L0
0`00MiQgV004MiP00`00Oomoo`0BOol00`00Oomoo`1lOol00`00Oomoo`0DOol00`00Oomoo`0>Ool0
00moo`03001oogoo02Ioo`0500001@0500D0000=BK<00`00FSEJ=@0?FSD00`00I[MV]`0>I[L00`00
MiQgV004MiP00`00Oomoo`0BOol00`00Oomoo`1lOol00`00Oomoo`0DOol00`00Oomoo`0>Ool000mo
o`03001oogoo02Ioo`<01@030019/dVc00a9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH
00AgV003001oogoo01=oo`03001oogoo07aoo`03001oogoo01Aoo`03001oogoo00ioo`003goo00<0
07ooOol09Goo00D0000500D01@0000e9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH00Eg
V003001oogoo01=oo`03001oogoo07aoo`03001oogoo01Aoo`03001oogoo00ioo`003goo00<007oo
Ool097oo00D0000500D01@0000e9/`03001J=EXe011J=@03001V]fJg00eV]`03001gV7NH00AgV003
001oogoo01Aoo`03001oogoo07aoo`03001oogoo01Aoo`03001oogoo00ioo`003goo00<007ooOol0
97oo00@0000500D000i9/`03001J=EXe00mJ=@03001V]fJg00eV]`03001gV7NH00EgV003001oogoo
01Aoo`03001oogoo07eoo`03001oogoo01=oo`03001oogoo00ioo`003goo00<007ooOol08goo00D0
000500D01@0000e9/`03001J=EXe00mJ=@03001V]fJg00iV]`03001gV7NH00AgV003001oogoo01Eo
o`03001oogoo07eoo`03001oogoo01=oo`03001oogoo00ioo`003goo00<007ooOol08goo0`0500<0
04VcBK<034Vc00<005XeFSD03eXe00<006JgI[L03FJg00<007NHMiP017NH00<007ooOol05Woo00<0
07ooOol0OGoo00<007ooOol04goo00<007ooOol03Woo000?Ool00`00Oomoo`0ROol01@0000D01@05
00003DVc00<005XeFSD03eXe00<006JgI[L03VJg00<007NHMiP017NH00<007ooOol05Woo00<007oo
Ool0OGoo00<007ooOol04goo00<007ooOol03Woo000?Ool00`00Oomoo`0ROol300D00`00BK=9/`0<
BK<00`00FSEJ=@0?FSD00`00I[MV]`0=I[L00`00MiQgV004MiP00`00Oomoo`0GOol00`00Oomoo`1m
Ool00`00Oomoo`0COol00`00Oomoo`0>Ool000moo`03001oogoo025oo`0500001@0500D0000=BK<0
0`00FSEJ=@0?FSD00`00I[MV]`0=I[L00`00MiQgV005MiP00`00Oomoo`0GOol00`00Oomoo`1mOol0
0`00Oomoo`0COol00`00Oomoo`0>Ool000moo`03001oogoo025oo`@000e9/`03001J=EXe011J=@03
001V]fJg00eV]`03001gV7NH00AgV003001oogoo01Qoo`03001oogoo07eoo`03001oogoo01=oo`03
001oogoo00ioo`003Woo00<007ooOol08goo00<0006J0IX00P002dVc00<005XeFSD03eXe00<006Jg
I[L03FJg00<007NHMiP01GNH00<007ooOol067oo00<007ooOol0OGoo00<007ooOol04goo00<007oo
Ool03Woo000>Ool00`00Oomoo`0TOol010000IX1VP6J0P0024Vc00<005XeFSD03eXe00<006JgI[L0
3VJg00<007NHMiP017NH00<007ooOol06Goo00<007ooOol0OGoo00<007ooOol04goo00<007ooOol0
3Woo000>Ool00`00Oomoo`0UOol00`000IX1VP020IX20006BK<00`00FSEJ=@0?FSD00`00I[MV]`0=
I[L00`00MiQgV004MiP00`00Oomoo`0JOol00`00Oomoo`1mOol00`00Oomoo`0COol00`00Oomoo`0>
Ool000ioo`03001oogoo02Moo`030001VP6J0081VP8000=9/`03001J=EXe00mJ=@03001V]fJg00iV
]`03001gV7NH00AgV003001oogoo01Yoo`03001oogoo07eoo`03001oogoo01=oo`03001oogoo00io
o`003Woo00<007ooOol0:7oo00<0006J0IX00`6J0P0000=9/eXeFSD045Xe00<006JgI[L03FJg00<0
07NHMiP017NH00<007ooOol06goo00<007ooOol0OGoo00<007ooOol04goo00<007ooOol03Woo000>
Ool00`00Oomoo`0YOol200050IX00`00FSEJ=@0?FSD00`00I[MV]`0=I[L00`00MiQgV005MiP00`00
Oomoo`0KOol00`00Oomoo`1mOol00`00Oomoo`0COol00`00Oomoo`0>Ool000ioo`03001oogoo02]o
o`030001VP6J00<1VP8000iJ=@03001V]fJg00iV]`03001gV7NH00AgV003001oogoo01aoo`03001o
ogoo07eoo`03001oogoo01=oo`03001oogoo00ioo`003Woo00<007ooOol0;7oo0P001@6J0P0035Xe
00<006JgI[L03FJg00<007NHMiP01GNH00<007ooOol077oo00<007ooOol0OGoo00<007ooOol04goo
00<007ooOol03Woo000>Ool00`00Oomoo`0^Ool00`000IX1VP040IX20009FSD00`00I[MV]`0>I[L0
0`00MiQgV004MiP00`00Oomoo`0LOol00`00Oomoo`1nOol00`00Oomoo`0COol00`00Oomoo`0>Ool0
00ioo`03001oogoo031oo`030001VP6J00@1VP8000MJ=@03001V]fJg00eV]`03001gV7NH00EgV003
001oogoo01aoo`03001oogoo07ioo`03001oogoo01=oo`03001oogoo00ioo`003Woo00<007ooOol0
<Goo00<0006J0IX01@6J0P0015Xe00<006JgI[L03VJg00<007NHMiP017NH00<007ooOol07Goo00<0
07ooOol0OWoo00<007ooOol04goo00<007ooOol03Woo000>Ool00`00Oomoo`0cOol00`000IX1VP05
0IX20002FSD@I[L00`00MiQgV004MiP00`00Oomoo`0NOol00`00Oomoo`1nOol00`00Oomoo`0COol0
0`00Oomoo`0>Ool000ioo`03001oogoo03Aoo`8000P1VP03001V]fJg00iV]`03001gV7NH00AgV003
001oogoo01ioo`03001oogoo07ioo`03001oogoo01=oo`03001oogoo00ioo`003Woo00<007ooOol0
=Woo0P001`6J0P003FJg00<007NHMiP017NH00<007ooOol07goo00<007ooOol0OWoo00<007ooOol0
4goo00<007ooOol03Woo000>Ool00`00Oomoo`0hOol200070IX00`00I[MV]`09I[L00`00MiQgV005
MiP00`00Oomoo`0OOol00`00Oomoo`1nOol00`00Oomoo`0DOol00`00Oomoo`0=Ool000ioo`03001o
ogoo03Uoo`<000H1VP8000UV]`03001gV7NH00AgV003001oogoo021oo`03001oogoo07ioo`03001o
ogoo01Aoo`03001oogoo00eoo`003Woo00<007ooOol0>Goo00<007ooOol00P001P6J00<006JgI[L0
1FJg00<007NHMiP01GNH00<007ooOol087oo00<007ooOol0OWoo00<007ooOol057oo00<007ooOol0
3Goo000>Ool00`00Oomoo`0iOol00`00Oomoo`02Ool200050IX20005I[L00`00MiQgV004MiP00`00
Oomoo`0QOol00`00Oomoo`1nOol00`00Oomoo`0DOol00`00Oomoo`0=Ool000ioo`03001oogoo03Uo
o`03001oogoo00Aoo`8000D1VP05001V]fJgI[L00006MiP00`00Oomoo`0ROol00`00Oomoo`1nOol0
0`00Oomoo`0DOol00`00Oomoo`0=Ool000ioo`03001oogoo03Uoo`03001oogoo00Ioo`8000@1VP80
0003I[L007NH00EgV003001oogoo029oo`03001oogoo07ioo`03001oogoo01Aoo`03001oogoo00eo
o`003Woo00<007ooOol0>Goo00<007ooOol027oo0P00106J00<007NHMiP017NH00<007ooOol08goo
00<007ooOol0OWoo00<007ooOol057oo00<007ooOol03Goo000=Ool00`00Oomoo`0jOol00`00Oomo
o`0:Ool200030IX00`00MiQgV003MiP00`00Oomoo`0SOol00`00Oomoo`1nOol00`00Oomoo`0DOol0
0`00Oomoo`0=Ool000eoo`03001oogoo03Uoo`8000ioo`800081VP80009gV003001oogoo02Aoo`03
001oogoo07ioo`03001oogoo01Aoo`03001oogoo00eoo`003Goo00<007ooOol0>Woo00<007ooOol0
3Woo0`0000@1VP00MiP002Ioo`03001oogoo07moo`03001oogoo01=oo`03001oogoo00eoo`003Goo
00<007ooOol0>Woo00<007ooOol04Goo0`009goo00<007ooOol0Ogoo00<007ooOol04goo00<007oo
Ool03Goo000=Ool00`00Oomoo`0jOol00`00Oomoo`0kOol00`00Oomoo`1oOol00`00Oomoo`0COol0
0`00Oomoo`0=Ool000eoo`03001oogoo03Yoo`03001oogoo03]oo`03001oogoo07moo`03001oogoo
01=oo`03001oogoo00eoo`003Goo00<007ooOol0>Woo00<007ooOol0>goo00<007ooOol0Ogoo00<0
07ooOol04goo00<007ooOol03Goo000=Ool00`00Oomoo`0jOol00`00Oomoo`0kOol00`00Oomoo`1o
Ool00`00Oomoo`0COol00`00Oomoo`0=Ool000eoo`03001oogoo03Yoo`03001oogoo03]oo`03001o
ogoo07moo`03001oogoo01=oo`03001oogoo00eoo`003Goo00<007ooOol0>Woo00<007ooOol0>goo
00<007ooOol0Ogoo00<007ooOol04goo00<007ooOol03Goo000=Ool00`00Oomoo`0jOol00`00Oomo
o`0kOol00`00Oomoo`1oOol00`00Oomoo`0COol00`00Oomoo`0=Ool000eoo`03001oogoo03Uoo`80
03eoo`03001oogoo07moo`03001oogoo01=oo`03001oogoo00eoo`003Goo00<007ooOol0>Woo00<0
07ooOol0>goo00<007ooOol0Ogoo00<007ooOol04goo00<007ooOol03Goo000=Ool00`00Oomoo`0i
Ool00`00Oomoo`0lOol00`00Oomoo`1oOol00`00Oomoo`0COol00`00Oomoo`0=Ool000eoo`03001o
ogoo03Uoo`03001oogoo03aoo`03001oogoo07moo`03001oogoo01=oo`03001oogoo00eoo`003Goo
00<007ooOol0>Goo00<007ooOol0?7oo00<007ooOol0Ogoo00<007ooOol04goo00<007ooOol03Goo
000=Ool00`00Oomoo`0iOol00`00Oomoo`0lOol00`00Oomoo`1oOol00`00Oomoo`0COol00`00Oomo
o`0=Ool000eoo`03001oogoo03Uoo`03001oogoo03aoo`03001oogoo07Moo`T001Eoo`03001oogoo
00eoo`003Goo00<007ooOol0>Goo00<007ooOol0?7oo00<007ooOol0IWoo4@002Goo00<007ooOol0
4Woo00<007ooOol03Goo000=Ool00`00Oomoo`0`Ool50004Ool00`00Oomoo`0lOol00`00Oomoo`1E
OolA000JOol00`00Oomoo`0COol00`00Oomoo`0<Ool000eoo`03001oogoo039oo`03001oogoo00Ao
o`<003aoo`03001oogoo04Aooa4002aoo`03001oogoo019oo`03001oogoo00aoo`003Goo00<007oo
Ool0<Woo00<007ooOol017oo00<007ooOol0?7oo00<007ooOol0<goo4@00?Goo00<007ooOol04Woo
00<007ooOol037oo000<Ool00`00Oomoo`0cOol00`00Oomoo`04Ool00`00Oomoo`0iOol01000Oomo
o`0097oo4@00Cgoo00<007ooOol04Goo00<007ooOol037oo000<Ool00`00Oomoo`0cOol00`00Oomo
o`04Ool00`00Oomoo`0iOol01000Oomoo`004goo4@00HGoo00<007ooOol047oo00<007ooOol037oo
000<Ool00`00Oomoo`0bOol20006Ool00`00Oomoo`0iOol01000Oomoo`000goo4000LWoo00<007oo
Ool047oo00<007ooOol037oo000<Ool00`00Oomoo`0jOol00`00Oomoo`0_OolA000:Ool00`00Oomo
o`1fOol00`00Oomoo`0?Ool00`00Oomoo`0<Ool000aoo`03001oogoo03Yoo`03001oogoo01iooa80
00Uoo`04001oogoo000<Ool00`00Oomoo`1gOol00`00Oomoo`0?Ool00`00Oomoo`0<Ool000aoo`03
001oogoo03Yoo`03001oogoo00eooa40015oo`03001oogoo00Moo`04001oogoo000<Ool00`00Oomo
o`1hOol00`00Oomoo`0>Ool00`00Oomoo`0<Ool000aoo`03001oogoo03Uooa4002=oo`03001oogoo
00Moo`03001oo`0000]oo`03001oogoo07Yoo`03001oogoo00eoo`03001oogoo00aoo`0037oo00<0
07ooOol0:7oo4@0000=oo`000000<Goo00<007ooOol01goo00<007oo00002goo00<007ooOol0NWoo
00<007ooOol03Goo00<007ooOol037oo000<Ool00`00Oomoo`0GOolA000BOol00`00Oomoo`0aOol0
0`00Oomoo`06Ool00`00Ool0000:Ool00`00Oomoo`1lOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool0
00aoo`03001oogoo00Iooa4002=oo`03001oogoo035oo`03001oogoo00Ioo`03001oo`0000Yoo`03
001oogoo07aoo`03001oogoo00aoo`03001oogoo00aoo`0037oo2@00=7oo00<007ooOol0<Woo00<0
07ooOol01Goo00<007oo00002Goo00<007ooOol0OWoo00<007ooOol02goo00<007ooOol037oo000=
Ool2000jOol00`00Oomoo`0bOol00`00Oomoo`05Ool00`00Ool00009Ool00`00Oomoo`1oOol00`00
Oomoo`0:Ool00`00Oomoo`0<Ool000moo`8003Qoo`03001oogoo03=oo`03001oogoo00Aoo`03001o
o`0000Qoo`03001oogoo081oo`03001oogoo00Yoo`03001oogoo00aoo`004Goo00<007ooOol0=Goo
00<007ooOol0<goo00<007ooOol017oo00<007oo00000Woo00<007ooOol00goo00<007ooOol0PGoo
00<007ooOol02Goo00<007ooOol037oo000BOol2000eOol00`00Oomoo`0dOol00`00Oomoo`03Ool0
0`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`22Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool0
01Aoo`8003=oo`03001oogoo03Aoo`03001oogoo00=oo`03001oo`00009oo`03001oogoo009oo`03
001oogoo08=oo`03001oogoo00Qoo`03001oogoo00aoo`005Woo00<007ooOol0<7oo00<007ooOol0
=Goo00<007ooOol00goo0P0000=oo`00Ool00goo00<007ooOol0QGoo00<007ooOol01goo00<007oo
Ool037oo000GOol2000_Ool3000fOol00`00Oomoo`03Ool200000goo001oo`03Ool00`00Oomoo`25
Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool001Uoo`8002ioo`03001oogoo03Ioo`03001oogoo009o
o`800003Ool007oo009oo`03001oogoo08Moo`03001oogoo00Ioo`03001oogoo00aoo`006goo00<0
07ooOol0:goo00<007ooOol0=Woo00<007ooOol00Woo0P0000=oo`00Ool00Woo00<007ooOol0Qgoo
00<007ooOol01Woo00<007ooOol037oo000LOol2000[Ool00`00Oomoo`0gOol01000Oomoogoo0P00
00Eoo`00Oomoo`0008]oo`03001oogoo00Eoo`03001oogoo00aoo`007Woo0P00:Goo00<007ooOol0
=goo00@007ooOomoo`800005Ool007ooOol0002<Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool0021o
o`03001oogoo02Ioo`03001oogoo03Qoo`03001oogoo00<0009oo`03001oogoo08]oo`03001oogoo
00Aoo`03001oogoo00aoo`008Goo0P009Woo00<007ooOol0>7oo00<007ooOol00`000Woo00<007oo
Ool0S7oo00<007ooOol017oo00<007ooOol02goo000SOol2000TOol00`00Oomoo`0iOol00`00Ool0
000200000goo001oo`2>Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool002Eoo`03001oogoo025oo`03
001oogoo03Uoo`03001oo`0000800003Ool007oo08moo`03001oogoo00=oo`03001oogoo00]oo`00
9Woo0P008Goo00<007ooOol0>Woo00<007oo00000P00TWoo00<007ooOol00Woo00<007ooOol02goo
000XOol2000NOol2000lOol00`00Ool00002002BOol00`00Oomoo`02Ool00`00Oomoo`0;Ool002Yo
o`03001oogoo01]oo`03001oogoo03aoo`<009Aoo`05001oogooOol0000=Ool002]oo`8001]oo`03
001oogoo03aoo`<009Aoo`05001oogooOol0000=Ool002eoo`8001Uoo`03001oogoo03eoo`03001o
ogoo09Aoo`04001oogoo000=Ool002moo`03001oogoo01Ioo`03001oogoo03eoo`03001oogoo09Eo
o`03001oo`0000eoo`00<7oo0P005Woo00<007ooOol0eGoo00<007oo00003Goo000bOol2000DOol0
0`00Oomoo`3FOol2000=Ool003Aoo`03001oogoo015oo`03001oogoo0=Ioo`8000eoo`00=Goo0P00
4Goo00<007ooOol0cWoo2P003Goo000gOol2000?Ool2002kOolD000GOol003Uoo`03001oogoo00ao
o`03001oogoo03moo`@006=ooa@002]oo`00>Woo0P0037oo00<007ooOol0@7oo00<007oo0000Cgoo
5000?goo000lOol2000:Ool00`00Oomoo`0oOol00`00Ool0000lOolD001COol003ioo`03001oogoo
00Moo`03001oogoo03moo`@002Qooa<006Moo`00?goo0P001goo00<007ooOol0Egoo5000NWoo0011
Ool20005Ool00`00Oomoo`13OolD002>Ool004=oo`03001oogoo009oo`03001oogoo02mooa@00:9o
o`00A7oo0P000Woo00<007ooOol06goo5000]Woo000eOol50002Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool30009OolD003:Ool003Moo`03001oogoo00Ioo`03001oo`0000Eoo`X00=ioo`00=goo00<0
07ooOol027oo00<007ooOol0jgoo000gOol00`00Oomoo`06Ool2003^Ool003Moo`03001oogoo00Io
o`03001oogoo0>eoo`00=Woo0P0027oo0`00kGoo003oOolaOol00?mooc5oo`00ogoo<Goo0000\
\>"],
  ImageRangeCache->{{{0, 303}, {255, 0}} -> {-0.0429457, 0.0182995, 
  0.00341948, 0.00341948}}]
}, Open  ]],

Cell[TextData[
"The centroidal inertia properties of a cylinder in an axial reference frame \
can be found in an engineering manual. These properties have been determined \
and are given in the following example."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the inertia properties of the cylinder."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(rad = 0.25; height = 1.0; density = 10.0; \), 
    \(cylmass = \[Pi]\ rad\^2\ height\ density\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(1.96349540849362078`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cylcent = {0.5, \(-0.25\), \@3.0\/4}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        RowBox[{"-", 
          StyleBox["0.25`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", "0.433012701892219276`"}], "}"}]], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cylcentinertia
       = {1\/12\ \((3\ rad\^2 + height\^2)\), 
          1\/12\ \((3\ rad\^2 + height\^2)\), rad\^2\/2, 0, 0, 0}\ cylmass\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.194304233132181192`, 0.194304233132181192`, 0.0613592315154256517`, 
      0, 0, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can now be used to combine the inertia properties of the plate and the \
cylinder into one set of centroidal inertia properties. Note that the \
optional rotation argument is used for the cylinder since the reference frame \
in which its inertia properties were calculated was not aligned with the \
local reference frame. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the inertia properties of the combined thin plate and cylinder. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CompositeInertia[{cent, mass, centinertia}, {cylcent, cylmass, 
        cylcentinertia, {\[Pi]/6.0, {1, 0, 0}}}]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.466172726344032462`, \(-0.131604542204113483`\), 
        0.345126866911711172`}, 
      2.46349540849362069`, {0.43241104984356582`, 0.274637868491846592`, 
        0.296827867257816979`, 0.052633711850342788`, 0.158228877202385875`, 
        \(-0.0287605722426425991`\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2D Inertia Functions "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also provides two inertia transformation functions that parallel those in \
",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", although the calculations they perform are trivial by comparison."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ParallelAxis[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", mass, inertia",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the parallel axes theorem to transform the moment of inertia of a \
body into or out of a centroidal reference frame. Assuming that the given ",
  StyleBox["inertia",
    FontSlant->"Italic"],
  " is centroidal, ",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the moment of inertia with respect to a noncentroidal reference \
frame in which ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the vector from the origin of the noncentroidal frame to the centroid. \
Negative mass can be given to transform a noncentroidal moment of inertia \
into a centroidal reference frame.\n \n",
  StyleBox["CompositeInertia[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid1, mass1, inertia1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ..., ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroidn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["massn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["inertian",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid, mass, inertia",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of the centroidal inertia properties of a composite body made up of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " components. Given a local reference frame affixed to the composite body, \
each argument to ",
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the centroidal inertia properties of a component of the \
composite body with respect to the local reference frame. Negative ",
  StyleBox["massi",
    FontSlant->"Italic"],
  " can be specified for components that are voids."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Utilities for manipulating 2D inertia properties."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[Graphics3D[{LocalAxes[1,1.4], \n  Extrude[{{0,0,.05}, {1,0,.05}, \
{0,1,.05}, {0,0,.05}}, {0,0,-1}, .1], \n  Polygon[{{0,0,-.05}, {1,0,-.05}, \
{0,1,-.05} }], \n  Polygon[{{0,0, .05}, {1,0, .05}, {0,1, .05}}]}, \n  Axes\
\[Rule]True, AxesEdge\[Rule]{{1,-1},{1,-1},{-1,-1}}], \n  \
ViewPoint\[Rule]{4,1.7,1.2},  \n  \
PlotRange\[Rule]{{-.1,1.5},{-.1,1.5},{-.1,1.5}}]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[Graphics3D[{LocalAxes[1,1.4], \n  Extrude[{{0,0,.05}, {1,0,.05}, \
{0,1,.05}, {0,0,.05}}, {0,0,-1}, .1], \n  Polygon[{{0,0,-.05}, {1,0,-.05}, \
{0,1,-.05} }], \n  Polygon[{{0,0, .05}, {1,0, .05}, {0,1, .05} }], \n  \
Bar[Line[{.5,0,0},{.5,-.5,Sqrt[3.]/2}],.25, 10]}, \n  Axes\[Rule]True, \
AxesEdge\[Rule]{{1,-1},{1,-1},{-1,-1}}], \n  ViewPoint\[Rule]{4,1.0,1.3},  \n \
 PlotRange\[Rule]{{-.1,1.5},{-0.7,1.5},{-.1,1.5}}]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["8.2  Kinematic and Dynamic Solutions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section describes the function of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s inverse dynamics solution block. Inverse dynamics allows the dynamic \
reaction forces in a fully kinematically constrained model to be found. The \
motion of such a model is completely defined by the kinematics of the model, \
only the reaction forces that result from the constrained motion are found \
through inverse dynamics. To find the free response of a model with one or \
more degrees of dynamic freedom, consult Chapter 10."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Dynamics Options "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Once the kinematic constraints and the inertia properties of a body have \
been defined, the dynamic forces in a mechanism can be determined. The ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to tell ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " to calculate the generalized reaction forces in the model and to include \
the forces due to inertia."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the solution level sought.\n\n",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the location of each body, and the generalized reaction forces due \
to static loads. If any forces in the model depend on velocity terms, they \
will be set to zero. \n\n",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the location and velocity of each body, and the generalized \
reaction forces due to static or velocity-dependent loads.\n\n",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the location, velocity, and acceleration of each body, and the \
generalized reaction forces due to all loads, including inertial loads. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The purpose of the ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is to allow for velocity-dependent loading, such as damping, \
while still not including the dynamic loading. Note that using the ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting does not necessarily produce an error in a model that has \
velocity-dependent loading, because ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the velocities to zero. This condition ",
  StyleBox["may",
    FontSlant->"Italic"],
  " result in an incidental error, however, if the velocity-dependent terms \
happen to blow up at zero velocity. \n\nThe ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting calculates the mechanism accelerations and then adds the inertial \
loads due to the acceleration of each body to the model's applied load vector \
before calculating the generalized reaction forces. Note that the ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting must be used to include the centrifugal forces, even though they \
depend on velocity and not acceleration."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " example model is developed to demonstrate a simple gyroscopic inertial \
loading condition. The model is a flywheel with an angular velocity vector \
with a changing direction.\n\nThe model consists of only one moving body, the \
flywheel. The flywheel spins about an axis that is attached to the ground at \
one point. The axis of rotation of the flywheel is then rotated about another \
nonparallel axis affixed to the ground. Thus, the direction of the axis of \
rotation of the flywheel changes with time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the flywheel model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.06305  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.0129967 1.12209 0.0280521 1.12209 [ 
[ 0 0 0 0 ] 
[ 1 1.06305 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 1.06305 L 
0 1.06305 L 
closepath 
clip 
newpath 
p 
.002 w 
.34205 .44874 m 
.32194 1.035 L 
s 
.32194 1.035 m 
.97195 .99899 L 
s 
.97195 .99899 m 
.93187 .3792 L 
s 
.93187 .3792 m 
.34205 .44874 L 
s 
.0871 .14338 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.02805 .87345 L 
s 
.02805 .87345 m 
.0871 .14338 L 
s 
.34205 .44874 m 
.32194 1.035 L 
s 
.32194 1.035 m 
.02805 .87345 L 
s 
.02805 .87345 m 
.0871 .14338 L 
s 
.0871 .14338 m 
.34205 .44874 L 
s 
.93187 .3792 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.97195 .99899 L 
s 
.97195 .99899 m 
.93187 .3792 L 
s 
P 
p 
.75 0 0 r 
.01 w 
.47869 .49572 m 
.60614 .66731 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.60614 .66731 Mdot 
P 
p 
.75 0 0 r 
.01 w 
.78497 .56524 m 
.3223 .61183 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.3223 .61183 Mdot 
P 
p 
.75 0 0 r 
.004 w 
.54805 .58909 m 
.54805 .78455 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.54805 .58909 m 
.74869 .56889 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.48994 .51086 m 
.54805 .58909 L 
s 
P 
p 
.004 w 
.54805 .58909 m 
.54805 .94261 L 
s 
P 
p 
.004 w 
.54805 .58909 m 
.90789 .55286 L 
s 
P 
p 
.004 w 
.43872 .4419 m 
.54805 .58909 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.7121 .58042 m 
.74869 .56889 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.74869 .56889 m 
.70739 .55385 L 
s 
P 
p 
.004 w 
.83956 .57369 m 
.90789 .55286 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.54805 .78455 m 
.55351 .75064 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.74869 .56889 m 
.70839 .59227 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.70361 .56546 m 
.74869 .56889 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.52794 .74617 m 
.54805 .78455 L 
s 
P 
p 
.004 w 
.90789 .55286 m 
.83218 .52625 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.78497 .56524 Mdot 
P 
p 
.75 0 0 r 
.004 w 
.56824 .74276 m 
.54805 .78455 L 
s 
P 
p 
.004 w 
.54805 .94261 m 
.55783 .87804 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.54805 .78455 m 
.54249 .7382 L 
s 
P 
p 
.004 w 
.90789 .55286 m 
.83538 .59478 L 
s 
P 
p 
.004 w 
.82782 .5466 m 
.90789 .55286 L 
s 
P 
p 
.004 w 
.51192 .87127 m 
.54805 .94261 L 
s 
P 
p 
.004 w 
.58444 .86609 m 
.54805 .94261 L 
s 
P 
p 
.004 w 
.54805 .94261 m 
.53799 .85908 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.48994 .51086 m 
.50245 .50762 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.48154 .52975 m 
.48994 .51086 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.52316 .52527 m 
.48994 .51086 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.48994 .51086 m 
.50215 .54753 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.47869 .49572 Mdot 
P 
p 
.004 w 
.43872 .4419 m 
.46369 .43836 L 
s 
P 
p 
.004 w 
.42488 .47918 m 
.43872 .4419 L 
s 
P 
p 
.004 w 
.50178 .47045 m 
.43872 .4419 L 
s 
P 
p 
.004 w 
.43872 .4419 m 
.46266 .51175 L 
s 
P 
p 
.002 w 
.0871 .14338 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.02805 .87345 L 
s 
.02805 .87345 m 
.0871 .14338 L 
s 
.93187 .3792 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.97195 .99899 L 
s 
.97195 .99899 m 
.93187 .3792 L 
s 
P 
p 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .43872 .4419 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .90789 .55286 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .54805 .94261 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(1)] .54805 .58909 1.3 1.3 Mshowa 
P 
.75 0 0 r 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .48994 .51086 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .74869 .56889 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .54805 .78455 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(2)] .54805 .58909 1.3 1.3 Mshowa 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 299},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0001:a000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00
iWoo1000;goo003POol60003Ool00`00Oomoo`0]Ool00=Uoo`L000Uoo`8002ioo`00dgoo1P0047oo
0P00;Woo003<Ool7000FOol2000^Ool00<Ioo`H001eoo`8002ioo`00_goo1`008goo00<007oo0000
;Goo002iOol6000ZOol00`00Ool0000]Ool00;9oo`L0031oo`03001oo`0002eoo`00Zgoo1`00=goo
00<007oo0000;Goo002UOol6000oOol00`00Ool0000/Ool009ioo`L004Eoo`03001oo`0002aoo`00
V7oo1P00C7oo00<007oo0000;7oo002AOol7001BOol01000Oomoo`00:goo002;Ool6001IOol01000
Oomoo`00:goo0024Ool7001OOol01000Oomoo`00:goo001nOol6001VOol01000Oomoo`00:goo001g
Ool7001/Ool01@00Oomoogoo0000:Woo001aOol6001cOol01@00Oomoogoo0000:Woo001ZOol7001i
Ool01@00Oomoogoo0000:Woo001TOol60020Ool00`00Oomoo`02Ool00`00Oomoo`0WOol005eoo`L0
08Ioo`03001oogoo009oo`03001oogoo02Moo`00Egoo1P00SGoo00<007ooOol00Woo00<007ooOol0
9goo001@Ool7002COol00`00Oomoo`02Ool00`00Oomoo`0WOol004Uoo`L009Yoo`03001oogoo00=o
o`03001oogoo02Ioo`00@goo1P00XGoo00<007ooOol00goo00<007ooOol09Woo000lOol7002WOol0
0`00Oomoo`03Ool00`00Oomoo`0VOol003Ioo`H00:ioo`03001oogoo00=oo`03001oogoo02Ioo`00
;goo1`00]7oo00<007ooOol017oo00<007ooOol09Goo000YOol6002kOol00`00Oomoo`04Ool00`00
Oomoo`0UOol0029oo`L00<9oo`03001oogoo00=oo`03001oogoo02Eoo`0077oo1P00bGoo00<007oo
Ool017oo00<007ooOol097oo000HOol4003?Ool00`00Oomoo`04Ool00`00Oomoo`0TOol001Qoo`80
0=5oo`03001oogoo00Aoo`03001oogoo02Aoo`0067oo00<007oo0000d7oo00<007ooOol017oo00<0
07ooOol097oo000HOol01000Oomoo`00cgoo00<007ooOol01Goo00<007ooOol08goo000HOol01000
Oomoo`00cgoo00<007ooOol01Goo00<007ooOol08goo000HOol01@00Oomoogoo0000cWoo00<007oo
Ool01Goo00<007ooOol08goo000GOol00`00Oomoo`03Ool00`00Oomoo`3;Ool00`00Oomoo`05Ool0
0`00Oomoo`0SOol001Moo`03001oogoo00Aoo`03001oogoo0<Yoo`03001oogoo00Ioo`03001oogoo
029oo`005goo00<007ooOol01Goo00<007ooOol0bGoo00<007ooOol01Woo00<007ooOol08Woo000G
Ool00`00Oomoo`06Ool00`00Oomoo`38Ool00`00Oomoo`06Ool00`00Oomoo`0ROol001Moo`03001o
ogoo00Ioo`03001oogoo0<Qoo`03001oogoo00Moo`03001oogoo025oo`005goo00<007ooOol01goo
00<007ooOol0agoo00<007ooOol01goo00<007ooOol08Goo000GOol00`00Oomoo`08Ool00`00Oomo
o`36Ool00`00Oomoo`07Ool00`00Oomoo`0QOol001Moo`03001oogoo00Uoo`03001oogoo0<Eoo`03
001oogoo00Moo`03001oogoo025oo`005goo00<007ooOol02Woo00<007ooOol0a7oo00<007ooOol0
27oo00<007ooOol087oo000GOol00`00Oomoo`0;Ool00`00Oomoo`33Ool00`00Oomoo`08Ool00`00
Oomoo`0POol001Moo`03001oogoo00]oo`03001oogoo0<=oo`03001oogoo00Qoo`03001oogoo021o
o`005goo00<007ooOol037oo00<007ooOol0`Woo00<007ooOol027oo00<007ooOol087oo000FOol0
0`00Oomoo`0>Ool00`00Oomoo`32Ool00`00Oomoo`08Ool00`00Oomoo`0OOol001Ioo`03001oogoo
00moo`03001oogoo0<5oo`03001oogoo00Qoo`03001oogoo01moo`005Woo00<007ooOol047oo00<0
07ooOol0`7oo00<007ooOol027oo00<007ooOol07goo000FOol00`00Oomoo`0AOol00`00Oomoo`2o
Ool00`00Oomoo`09Ool00`00Oomoo`0NOol001Ioo`03001oogoo015oo`03001oogoo0;moo`03001o
ogoo00Uoo`03001oogoo01ioo`005Woo00<007ooOol04Woo00<007ooOol0_Woo00<007ooOol02Goo
00<007ooOol07Woo000FOol00`00Oomoo`0COol00`00Oomoo`2mOol00`00Oomoo`09Ool00`00Oomo
o`0NOol001Ioo`03001oogoo01Aoo`03001oogoo0;aoo`03001oogoo00Yoo`03001oogoo01eoo`00
5Woo00<007ooOol05Goo00<007ooOol0^goo00<007ooOol02Woo00<007ooOol07Goo000FOol00`00
Oomoo`0FOol00`00Oomoo`2jOol00`00Oomoo`0:Ool00`00Oomoo`0MOol001Ioo`03001oogoo01Io
o`03001oogoo0;Yoo`03001oogoo00]oo`03001oogoo01aoo`005Woo00<007ooOol05goo00<007oo
Ool0^Goo00<007ooOol02goo00<007ooOol077oo000EOol00`00Oomoo`0IOol00`00Oomoo`2hOol0
0`00Oomoo`0;Ool00`00Oomoo`0LOol001Eoo`03001oogoo01Yoo`03001oogoo0;Moo`03001oogoo
00]oo`03001oogoo01aoo`005Goo00<007ooOol06goo00<007ooOol0]Woo00<007ooOol037oo00<0
07ooOol06goo000EOol00`00Oomoo`0LOol00`00Oomoo`2eOol00`00Oomoo`0<Ool00`00Oomoo`0K
Ool001Eoo`03001oogoo01aoo`03001oogoo0;Eoo`03001oogoo00aoo`03001oogoo01]oo`005Goo
00<007ooOol07Goo00<007ooOol0]7oo00<007ooOol037oo00<007ooOol06goo000EOol00`00Oomo
o`0NOol00`00Oomoo`2cOol00`00Oomoo`0=Ool00`00Oomoo`0JOol001Eoo`03001oogoo01moo`03
001oogoo0;9oo`03001oogoo00eoo`03001oogoo01Yoo`005Goo00<007ooOol087oo00<007ooOol0
/Woo00<007ooOol037oo00<007ooOol06Woo000EOol00`00Oomoo`0QOol00`00Oomoo`2aOol00`00
Oomoo`0=Ool00`00Oomoo`0IOol001Eoo`03001oogoo025oo`03001oogoo0;5oo`03001oogoo00eo
o`03001oogoo01Uoo`005Goo00<007ooOol08Woo00<007ooOol0/7oo00<007ooOol03Goo00<007oo
Ool06Goo000DOol00`00Oomoo`0TOol00`00Oomoo`2_Ool00`00Oomoo`0=Ool00`00Oomoo`0IOol0
01Aoo`03001oogoo02Eoo`03001oogoo0:ioo`03001oogoo00ioo`03001oogoo01Qoo`0057oo00<0
07ooOol09Woo00<007ooOol0[Goo00<007ooOol03Woo00<007ooOol067oo000DOol00`00Oomoo`0W
Ool00`00Oomoo`2/Ool00`00Oomoo`0>Ool00`00Oomoo`0HOol001Aoo`03001oogoo02Moo`03001o
ogoo0:aoo`03001oogoo00ioo`03001oogoo01Qoo`0057oo00<007ooOol0:7oo00<007ooOol0Zgoo
00<007ooOol03goo00<007ooOol05goo000DOol00`00Oomoo`0YOol00`00Oomoo`2ZOol00`00Oomo
o`0?Ool00`00Oomoo`0GOol001Aoo`03001oogoo02Yoo`03001oogoo0:Uoo`03001oogoo00moo`03
001oogoo01Moo`0057oo00<007ooOol0:goo00<007ooOol0Z7oo00<007ooOol047oo00<007ooOol0
5Woo000DOol00`00Oomoo`0/Ool00`00Oomoo`2WOol00`00Oomoo`0@Ool00`00Oomoo`0FOol001Ao
o`03001oogoo02aoo`03001oogoo0:Moo`03001oogoo011oo`03001oogoo01Ioo`0057oo00<007oo
Ool0;Goo00<007ooOol0YWoo00<007ooOol047oo00<007ooOol05Woo000COol00`00Oomoo`0_Ool0
0`00Oomoo`2UOol00`00Oomoo`0AOol00`00Oomoo`0EOol001=oo`03001oogoo031oo`03001oogoo
0:Aoo`03001oogoo015oo`03001oogoo01Eoo`004goo00<007ooOol0<Goo00<007ooOol0Xgoo00<0
07ooOol04Goo00<007ooOol05Goo000COol00`00Oomoo`0bOol00`00Oomoo`2ROol00`00Oomoo`0B
Ool00`00Oomoo`0DOol001=oo`03001oogoo039oo`03001oogoo0:=oo`03001oogoo015oo`03001o
ogoo01Aoo`004goo00<007ooOol0<goo00<007ooOol0XWoo00<007ooOol04Goo00<007ooOol057oo
000COol00`00Oomoo`0dOol00`00Oomoo`2QOol00`00Oomoo`0AOol00`00Oomoo`0DOol001=oo`03
001oogoo03Eoo`03001oogoo0:1oo`03001oogoo019oo`03001oogoo01=oo`004goo00<007ooOol0
=Woo00<007ooOol0Wgoo00<007ooOol04Woo00<007ooOol04goo000COol00`00Oomoo`0gOol00`00
Oomoo`2NOol00`00Oomoo`0BOol00`00Oomoo`0COol001=oo`03001oogoo03Moo`03001oogoo09io
o`03001oogoo019oo`03001oogoo01=oo`004goo00<007ooOol0>7oo00<007ooOol0WGoo00<007oo
Ool04goo00<007ooOol04Woo000BOol00`00Oomoo`0jOol00`00Oomoo`2LOol00`00Oomoo`0?Ool5
000DOol0019oo`03001oogoo03]oo`03001oogoo09]oo`03001oogoo00Ioo`T000Aoo`03001oogoo
019oo`004Woo00<007ooOol0?7oo00<007ooOol0VWoo2@003Goo00<007ooOol04Woo000BOol00`00
Oomoo`0mOol00`00Oomoo`2AOol9000EOol00`00Oomoo`0BOol0019oo`03001oogoo03eoo`03001o
ogoo08Qoo`T000Qoo`03001oogoo01=oo`03001oogoo019oo`004Woo00<007ooOol0?Woo00<007oo
Ool0Ogoo20004Goo00<007ooOol04goo00<007ooOol04Woo000BOol00`00Oomoo`0oOol00`00Oomo
o`1eOol9000IOol00`00Oomoo`0COol00`00Oomoo`0BOol0019oo`03001oogoo041oo`03001oogoo
06]oo`T0029oo`03001oogoo01=oo`03001oogoo019oo`004Woo00<007ooOol0@Goo00<007ooOol0
HWoo2000:goo00<007ooOol057oo00<007ooOol04Goo000BOol00`00Oomoo`12Ool00`00Oomoo`1H
Ool9000cOol00`00Oomoo`0DOol00`00Oomoo`0AOol0019oo`03001oogoo049oo`03001oogoo04mo
o`T003aoo`03001oogoo01Aoo`03001oogoo015oo`004Woo00<007ooOol0@goo00<007ooOol0AWoo
2000AGoo00<007ooOol057oo00<007ooOol04Goo000AOol00`00Oomoo`15Ool00`00Oomoo`0lOol9
001>Ool00`00Oomoo`0COol00`00Oomoo`0AOol0015oo`03001oogoo04Ioo`03001oogoo039oo`T0
05Moo`03001oogoo01=oo`03001oogoo015oo`004Goo00<007ooOol0Agoo00<007ooOol0:Goo2000
H7oo00<007ooOol04goo00<007ooOol04Goo000AOol00`00Oomoo`18Ool00`00Oomoo`0OOol9001X
Ool00`00Oomoo`0COol00`00Oomoo`0AOol0015oo`03001oogoo04Qoo`03001oogoo01Ioo`d006eo
o`03001oogoo01=oo`03001oogoo015oo`004Goo00<007ooOol0BGoo00<007ooOol03Goo20001Goo
1000LGoo00<007ooOol04goo00<007ooOol04Goo000AOol00`00Oomoo`1:Ool00`00Oomoo`03Ool9
000=Ool4001aOol00`00Oomoo`0COol00`00Oomoo`0AOol0015oo`03001oogoo04]oo`D001Eoo`03
001oo`00009oo`8006moo`03001oogoo01=oo`03001oogoo015oo`004Goo00<007ooOol0Bgoo00<0
07ooOol05goo00@007oo000000=oo`8006eoo`03001oogoo01=oo`03001oogoo015oo`004Goo00<0
07ooOol0Bgoo00<007ooOol05goo00D007oo001oo`0000Aoo`<006Yoo`03001oogoo01=oo`03001o
ogoo015oo`004Goo00<007ooOol0Bgoo00<007ooOol05Woo00L007ooOomoo`00Ool00006Ool2001X
Ool00`00Oomoo`0DOol00`00Oomoo`0@Ool0015oo`03001oogoo04]oo`03001oogoo01Ioo`06001o
ogooOol007oo0P0017oo0e`00P00IWoo00<007ooOol057oo00<007ooOol047oo000@Ool00`00Oomo
o`1<Ool00`00Oomoo`0EOol00`00Oomoo`02Ool400000gooG01L0006G002001TOol00`00Oomoo`0D
Ool00`00Oomoo`0@Ool0011oo`03001oogoo04aoo`03001oogoo01Eoo`03001oogoo00=oo`8000aL
0080069oo`03001oogoo01Aoo`03001oogoo011oo`0047oo00<007ooOol0C7oo00<007ooOol05Goo
00<007ooOol00Woo0P0000=L0000G00035`0HWoo00<007ooOol057oo00<007ooOol047oo000@Ool0
0`00Oomoo`1<Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00G01L000>G01QOol00`00Oomoo`0D
Ool00`00Oomoo`0@Ool0011oo`03001oogoo04aoo`03001oogoo01Aoo`03001oogoo00Aoo`03G000
05`000iL065oo`03001oogoo01Aoo`03001oogoo011oo`0047oo00<007ooOol0C7oo00<007ooOol0
6Woo0U`000<005`0G0003U`0H7oo00<007ooOol057oo00<007ooOol047oo000@Ool00`00Oomoo`1<
Ool00`00Oomoo`0JOol3G0000`00G01L000=G01POol00`00Oomoo`0DOol00`00Oomoo`0@Ool0011o
o`03001oogoo04aoo`03001oogoo01Yoo`=L0003001L05`000eL065oo`03001oogoo01=oo`03001o
ogoo011oo`0047oo00<007ooOol0C7oo00<007ooOol06Goo15`000<005`0G0003U`0H7oo00<007oo
Ool04goo00<007ooOol047oo000@Ool00`00Oomoo`1<Ool00`00Oomoo`0IOol5G0000`00G01L000=
G01POol00`00Oomoo`0COol00`00Oomoo`0@Ool0011oo`03001oogoo04aoo`03001oogoo01Uoo`EL
0003001L05`000eL061oo`03001oogoo01=oo`03001oogoo011oo`0047oo00<007ooOol0C7oo00<0
07ooOol06Woo15`000<005`0G00035`0HGoo00<007ooOol04goo00<007ooOol047oo000?Ool00`00
Oomoo`1<Ool00`00Oomoo`0KOol5G0000`00G01L000;G01QOol00`00Oomoo`0COol00`00Oomoo`0@
Ool000moo`03001oogoo04aoo`03001oogoo01]oo`EL0003001L05`000]L065oo`03001oogoo01Ao
o`03001oogoo00moo`003goo00<007ooOol0C7oo00<007ooOol077oo4E`0HWoo00<007ooOol057oo
00<007ooOol03goo000?Ool00`00Oomoo`1<Ool00`00Oomoo`0LOolBG01QOol00`00Oomoo`0DOol0
0`00Oomoo`0?Ool000moo`03001oogoo04aoo`03001oogoo01eoo`mL009oo`9L05moo`03001oogoo
01Aoo`03001oogoo00moo`003goo00<007ooOol0C7oo00<007ooOol07Woo3E`000<005`0Ool00Woo
0U`0EWoo0P001Goo00<007ooOol057oo00<007ooOol03goo000?Ool00`00Oomoo`1<Ool00`00Oomo
o`0POol:G00017oo001L05`0G7oo0`000Woo00<007ooOol057oo00<007ooOol03goo000?Ool00`00
Oomoo`1<Ool00`00Oomoo`0SOol3G003Ool2G0000gooG01L001;Ool3G00AOol3000FOol00`00Oomo
o`0?Ool000moo`03001oogoo04aoo`03001oogoo02Yoo`9L0003Ool005`004Moo`UL011oo`@001=o
o`03001oogoo00moo`003goo00<007ooOol0C7oo00<007ooOol0:Woo0U`00Woo00<005`0Ool0@goo
3E`03Woo00@007ooOomoo`<0011oo`03001oogoo00moo`003goo00<007ooOol0C7oo00<007ooOol0
:Goo00ML07ooG01L07oo001L0013Ool?G00=Ool00`00Oomoo`04Ool3000=Ool00`00Oomoo`0?Ool0
00moo`03001oogoo04aoo`03001oogoo02]oo`06G01oogooOol005`0@Goo4E`00goo30001goo0`00
2Woo00<007ooOol03goo000>Ool00`00Oomoo`1=Ool00`00Oomoo`0`Ool00`00G01oo`0oOolAG00<
Ool00`00Oomoo`0<0008Ool00`00Oomoo`0?Ool000ioo`03001oogoo04eoo`03001oogoo035oo`80
00=L0003001oogoo02aoo`9L00Yooa=L00]oo`h000Uoo`03001oogoo00moo`003Woo00<007ooOol0
CGoo00<007ooOol0<Goo00@005`0G000039oo`=L00Mooa=L00=oo`T000Ioo`D000]oo`03001oogoo
00moo`003Woo00<007ooOol0CGoo00<007ooOol0<Woo00<005`0G000=Goo0U`01Goo4e`00`002Goo
00<007oo00000`0000=oo`0000003Woo00<007ooOol03Woo000>Ool00`00Oomoo`1=Ool00`00Oomo
o`0cOol00`00G01oo`0^Ool6G002Ool3G0000gooG01L000CG00:Ool30004Ool00`00Oomoo`05Ool2
0007Ool00`00Oomoo`0>Ool000ioo`03001oogoo04eoo`03001oogoo03=oo`03G00005`0031ooamL
00Moo`<00003Ool007oo009oo`8000Uoo`03001oogoo00Eoo`03001oogoo00ioo`003Woo00<007oo
Ool0CGoo00<007ooOol0<goo00<005`0G0009goo1E`02@006U`01Goo0P0017oo00@007oo000000]o
o`03001oogoo00Eoo`03001oogoo00ioo`003Woo00<007ooOol0CGoo00<007ooOol0=Goo00<005`0
Ool06goo1U`02@0015`00Woo15`000=ooe`0Ool00Woo4e`037oo0P0037oo00<007oo00001Woo00<0
07ooOol03Woo000>Ool00`00Oomoo`17Ool3G003Ool00`00Oomoo`0fOol00`00Oomoo`0@Ool6G00:
0004G009Ool2G003Ool2G004OolCG00;Ool2000=Ool00`00Ool00006Ool00`00Oomoo`0>Ool000io
o`03001oogoo04Aoo`UL0003001oogoo03Ioo`03G00007oo00Ioo`ML00T000AL01Ioo`9L00Iooa=L
00Uoo`800003Ool007oo00]oo`800003Ool0000000Eoo`03001oogoo00ioo`003Woo00<007ooOol0
@Woo3E`0=Woo0U`000<005`0G0000e`02@000e`07goo00=L07ooOol01goo4E`027oo0P000goo00<0
07ooOol057oo00<007ooOol03Woo000>Ool00`00Oomoo`11Ool?G00[Ool=G0050002G00WOol2G00:
OolAG006Ool20005Ool00`00Oomoo`0DOol00`00Oomoo`0>Ool000eoo`03001oogoo045ooa5L021o
oaAL00=oo`03001L07oo02Yoo`03G01oogoo00Yooa1L00Ioo`03001oogoo00Eoo`03001oogoo01Ao
o`03001oogoo00ioo`003Goo00<007ooOol0@Goo4E`05Woo55`03Goo00<005`0G000=goo00=L07oo
G00035`03goo00<007ooOol057oo00<007ooOol03Woo000=Ool00`00Oomoo`10OolCG00<OolCG00G
Ool01000OomL05`0=Goo0U`000=ooe`0G0002E`04Goo00<007ooOol057oo00<007ooOol03Woo000=
Ool00`00Oomoo`10OolCG002OolCG00QOol01000Oomooe`0?Goo0e`057oo00<007ooOol057oo00<0
07ooOol03Woo000=Ool00`00Oomoo`10OolOG00ZOol00`00Oomoo`02G01COol00`00Oomoo`0DOol0
0`00Oomoo`0>Ool000eoo`03001oogoo03mooaIL03Aoo`04001oogooOol2G01BOol00`00Oomoo`0E
Ool00`00Oomoo`0=Ool000eoo`03001oogoo03mooaEL03Eoo`03001oogoo009oo`9L055oo`03001o
ogoo01Eoo`03001oogoo00eoo`003Goo00<007ooOol0?goo5E`0=Goo00<007ooOol00goo00=L07oo
Ool0Cgoo00<007ooOol05Goo00<007ooOol03Goo000=Ool00`00Oomoo`10OolCG00fOol00`00Oomo
o`03Ool2G01@Ool00`00Oomoo`0EOol00`00Oomoo`0=Ool000eoo`03001oogoo041ooa=L03Ioo`03
001oogoo00Aoo`9L04moo`03001oogoo01Eoo`03001oogoo00eoo`003Goo00<007ooOol0@7oo4e`0
=Woo00<007ooOol01Goo00=L07ooOol0CGoo00<007ooOol05Goo00<007ooOol03Goo000=Ool00`00
Oomoo`11OolAG00gOol00`00Oomoo`05Ool2G005Ool3G017Ool00`00Oomoo`0DOol00`00Oomoo`0=
Ool000aoo`03001oogoo049ooa5L03Moo`03001oogoo00Ioo`9L0003OomL05`000ML04Aoo`03001o
ogoo01Aoo`03001oogoo00eoo`0037oo00<007ooOol0@goo3e`0>7oo00<007ooOol01goo3E`0@Woo
00<007ooOol057oo00<007ooOol03Goo000<Ool00`00Oomoo`14Ool=G00iOol00`00Oomoo`06Ool?
G011Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool000aoo`03001oogoo04Ioo`UL03]oo`03001oogoo
00Eooa5L041oo`03001oogoo01Aoo`03001oogoo00eoo`0037oo00<007ooOol0BGoo0e`00Woo00<0
07ooOol0>Goo00<007ooOol01Goo4E`0@7oo00<007ooOol057oo00<007ooOol03Goo000<Ool00`00
Oomoo`1>Ool00`00Oomoo`0iOol00`00Oomoo`04OolCG00oOol00`00Oomoo`0DOol00`00Oomoo`0=
Ool000aoo`03001oogoo04ioo`03001oogoo03Uoo`03001oogoo00Aooa=L03moo`03001oogoo01Ao
o`03001oogoo00eoo`0037oo00<007ooOol0CWoo00<007ooOol0>Goo00<007ooOol017oo4e`0?goo
00<007ooOol057oo00<007ooOol03Goo000<Ool00`00Oomoo`1>Ool00`00Oomoo`0iOol00`00Oomo
o`03OolEG00nOol00`00Oomoo`0EOol00`00Oomoo`0<Ool000aoo`03001oogoo04ioo`03001oogoo
03Uoo`03001oogoo00=ooaEL03ioo`03001oogoo01Eoo`03001oogoo00aoo`0037oo00<007ooOol0
CWoo00<007ooOol0>Goo00<007ooOol00goo5E`0?Woo00<007ooOol05Goo00<007ooOol037oo000<
Ool00`00Oomoo`1>Ool00`00Oomoo`0iOol00`00Oomoo`04OolCG00oOol00`00Oomoo`0EOol00`00
Oomoo`0<Ool000]oo`03001oogoo04moo`03001oogoo03Uoo`03001oogoo00Aooa=L03moo`03001o
ogoo01Eoo`03001oogoo00aoo`002goo00<007ooOol0Cgoo00<007ooOol0>Goo00<007ooOol017oo
4e`0?goo00<007ooOol05Goo00<007ooOol037oo000;Ool00`00Oomoo`1?Ool00`00Oomoo`0iOol0
0`00Oomoo`05OolAG010Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool000]oo`03001oogoo04moo`03
001oogoo03Uoo`03001oogoo00Eooa5L041oo`03001oogoo01Eoo`03001oogoo00aoo`002goo00<0
07ooOol0Cgoo00<007ooOol0>Goo00<007ooOol01Woo3e`0@Goo00<007ooOol05Goo00<007ooOol0
37oo000;Ool00`00Oomoo`1?Ool00`00Oomoo`0iOol00`00Oomoo`07Ool=G012Ool00`00Oomoo`0E
Ool00`00Oomoo`0<Ool000]oo`03001oogoo04moo`03001oogoo03Uoo`03001oogoo00Uoo`UL04Ao
o`03001oogoo01Eoo`03001oogoo00aoo`002goo00<007ooOol0Cgoo00<007ooOol0>Goo00<007oo
Ool037oo0e`0B7oo00<007ooOol057oo00<007ooOol037oo000;Ool00`00Oomoo`1?Ool00`00Oomo
o`0iOol00`00Oomoo`1GOol00`00Oomoo`0DOol00`00Oomoo`0<Ool000]oo`03001oogoo04moo`03
001oogoo03Uoo`03001oogoo05Moo`03001oogoo01Aoo`03001oogoo00aoo`002goo00<007ooOol0
Cgoo00<007ooOol0>Goo00<007ooOol0Egoo00<007ooOol05Goo00<007ooOol02goo000;Ool00`00
Oomoo`1?Ool00`00Oomoo`0iOol00`00Oomoo`1GOol00`00Oomoo`0EOol00`00Oomoo`0;Ool000Yo
o`03001oogoo051oo`03001oogoo03Uoo`03001oogoo05Moo`03001oogoo01Eoo`03001oogoo00]o
o`002Woo00<007ooOol0D7oo00<007ooOol0>Goo00<007ooOol0Egoo00<007ooOol05Goo00<007oo
Ool02goo000:Ool00`00Oomoo`1@Ool00`00Oomoo`0iOol00`00Oomoo`1GOol00`00Oomoo`0EOol0
0`00Oomoo`0;Ool000Yoo`03001oogoo051oo`03001oogoo03Uoo`03001oogoo05Moo`03001oogoo
01Eoo`03001oogoo00]oo`002Woo00<007ooOol0D7oo00<007ooOol0=goo00=L07oo0000FGoo00<0
07ooOol05Goo00<007ooOol02goo000:Ool00`00Oomoo`1?Ool00`00Oomoo`0hOol00e`0Ool0001I
Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool000Yoo`03001oogoo04moo`03001oogoo03Qoo`03G01o
o`0000Eoo`03G01oogoo055oo`03001oogoo01Eoo`03001oogoo00]oo`002Woo00<007ooOol0Cgoo
00<007ooOol0=7oo00ML07ooOomooe`0Ool00004Ool00e`0Oomoo`1BOol00`00Oomoo`0EOol00`00
Oomoo`0;Ool000Yoo`03001oogoo04moo`03001oogoo03Eoo`07G01oogooOomL0000G0000goo00=L
07ooOol0DWoo00<007ooOol05Goo00<007ooOol02goo000:Ool00`00Oomoo`1?Ool00`00Oomoo`0e
Ool01e`0OomoogooG00005`0009oo`03G01oogoo05=oo`03001oogoo01Eoo`03001oogoo00]oo`00
2Woo00<007ooOol0Cgoo00<007ooOol0=Woo00IL07ooOomL0000G002Ool00e`0Oomoo`1COol00`00
Oomoo`0EOol00`00Oomoo`0;Ool000Yoo`03001oogoo04moo`03001oogoo03Ioo`08G01oogooG000
05`0OomL05Ioo`03001oogoo01Eoo`03001oogoo00]oo`002Goo00<007ooOol0D7oo00<007ooOol0
=goo00ML07ooG00005`0OomL001FOol00`00Oomoo`0EOol00`00Oomoo`0;Ool000Uoo`03001oogoo
051oo`03001oogoo03Qoo`=L0003OomL07oo05Ioo`03001oogoo01Ioo`03001oogoo00Yoo`002Goo
00<007ooOol0D7oo00<007ooOol0>7oo00EL07ooG01ooe`005Moo`03001oogoo01Ioo`03001oogoo
00Yoo`002Goo00<007ooOol0D7oo00<007ooOol0>Goo0e`0FGoo00<007ooOol05Goo00<007ooOol0
2Woo0009Ool00`00Oomoo`1@Ool00`00Oomoo`0iOol3G01IOol00`00Oomoo`0EOol00`00Oomoo`0:
Ool000Uoo`03001oogoo051oo`03001oogoo03Yoo`03G01oogoo05Qoo`03001oogoo01Eoo`03001o
ogoo00Yoo`002Goo00<007ooOol0D7oo00<007ooOol0>Woo00<007ooOol0F7oo00<007ooOol05Goo
00<007ooOol02Woo0009Ool00`00Oomoo`1@Ool00`00Oomoo`0jOol00`00Oomoo`1HOol00`00Oomo
o`0EOol00`00Oomoo`0:Ool000Uoo`03001oogoo051oo`03001oogoo03Yoo`03001oogoo05Qoo`03
001oogoo01Eoo`03001oogoo00Yoo`002Goo00<007ooOol0D7oo00<007ooOol0>Woo00<007ooOol0
F7oo00<007ooOol05Goo00<007ooOol02Woo0009Ool00`00Oomoo`1@Ool00`00Oomoo`0jOol00`00
Oomoo`1HOol00`00Oomoo`0EOol00`00Oomoo`0:Ool000Uoo`03001oogoo051oo`03001oogoo03Yo
o`03001ooe`000=L05Eoo`03001oogoo01Eoo`03001oogoo00Yoo`0027oo00<007ooOol0DGoo00<0
07ooOol0>Woo00H007ooOomL07ooG01?Ool7000GOol00`00Oomoo`0:Ool000Qoo`03001oogoo055o
o`03001oogoo03Yoo`05001ooe`0OomL0013Ool=0007Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool0
00Qoo`03001oogoo055oo`03001oogoo03Yoo`03001ooe`000=L03Eoo`d001Aoo`03001oogoo01Ao
o`03001oogoo00Yoo`0027oo00<007ooOol0DGoo00<007ooOol0>Woo00<007ooOol0:Woo3P008Woo
00<007ooOol057oo00<007ooOol02Goo0008Ool00`00Oomoo`1AOol00`00Oomoo`0jOol00`00Oomo
o`0MOol=000`Ool00`00Oomoo`0DOol00`00Oomoo`09Ool000Qoo`03001oogoo055oo`03001oogoo
03Yoo`03001oogoo011oo`d003ioo`03001oogoo01=oo`03001oogoo00Uoo`0027oo00<007ooOol0
DGoo00<007ooOol0>Woo00<007ooOol00goo3@00Bgoo00<007ooOol04goo00<007ooOol02Goo0008
Ool00`00Oomoo`1AOol00`00Oomoo`0cOol=001IOol00`00Oomoo`0BOol00`00Oomoo`09Ool000Qo
o`03001oogoo055oo`03001oogoo02Ioo`d000Moo`03001oogoo05aoo`03001oogoo019oo`03001o
ogoo00Uoo`0027oo00<007ooOol0DGoo00<007ooOol067oo3P0057oo00<007ooOol0GGoo00<007oo
Ool04Goo00<007ooOol02Goo0008Ool00`00Oomoo`1AOol00`00Oomoo`0;Ool=000ROol00`00Oomo
o`1MOol00`00Oomoo`0AOol00`00Oomoo`09Ool000Qoo`03001oogoo055oo`h002moo`03001oogoo
05ioo`03001oogoo011oo`03001oogoo00Uoo`001goo00<007ooOol0AWoo3@00?7oo00<007ooOol0
GWoo00<007ooOol047oo00<007ooOol02Goo0007Ool00`00Oomoo`0iOol=000<Ool00`00Oomoo`0j
Ool00`00Oomoo`1OOol00`00Oomoo`0?Ool00`00Oomoo`09Ool000Moo`03001oogoo02aoo`d001Qo
o`03001oogoo03Qoo`04001oogoo001QOol00`00Oomoo`0?Ool00`00Oomoo`09Ool000Moo`03001o
ogoo01ioo`h002Eoo`03001oogoo03Qoo`04001oogoo001ROol00`00Oomoo`0>Ool00`00Oomoo`09
Ool000Moo`03001oogoo015oo`d003=oo`03001oogoo03Qoo`04001oogoo0009Ool00`00Oomoo`1F
Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool000Moo`03001oogoo00Aoo`d0041oo`03001oogoo03Qo
o`04001oogoo0009Ool00`00Oomoo`1GOol00`00Oomoo`0>Ool00`00Oomoo`08Ool000Moo`L004eo
o`03001oogoo035oo`03001oogoo00Aoo`04001oogoo0008Ool00`00Oomoo`1IOol00`00Oomoo`0=
Ool00`00Oomoo`08Ool000Qoo`80055oo`03001oogoo035oo`03001oogoo00Eoo`03001oo`0000Qo
o`03001oogoo05Uoo`03001oogoo00eoo`03001oogoo00Qoo`002Woo0P00Cgoo00<007ooOol0<Woo
00<007ooOol017oo00<007oo00000Woo00<007ooOol00Woo00<007ooOol0Fgoo00<007ooOol037oo
00<007ooOol027oo000<Ool2001=Ool00`00Oomoo`0bOol00`00Oomoo`04Ool00`00Ool00002Ool0
0`00Oomoo`02Ool00`00Oomoo`1KOol00`00Oomoo`0<Ool00`00Oomoo`08Ool000ioo`8004]oo`03
001oogoo03=oo`03001oogoo00=oo`03001oo`00009oo`05001oogooOol0001OOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool0011oo`8004Uoo`03001oogoo03=oo`03001oogoo00=oo`05001oo`00Ool0
0004Ool00`00Oomoo`1MOol00`00Oomoo`0;Ool00`00Oomoo`08Ool0019oo`03001oogoo04Ioo`03
001oogoo03Aoo`03001oogoo009oo`05001oo`00Ool00003Ool00`00Oomoo`1OOol00`00Oomoo`0:
Ool00`00Oomoo`08Ool001=oo`8004Ioo`03001oogoo03Aoo`03001oogoo009oo`05001oo`00Ool0
0003Ool00`00Oomoo`1OOol00`00Oomoo`0:Ool00`00Oomoo`08Ool001Eoo`8004Aoo`03001oogoo
03Eoo`09001oogooOol007oo001oo`00009oo`03001oogoo065oo`03001oogoo00Uoo`03001oogoo
00Qoo`005goo0P00@Woo00<007ooOol0=Goo00<007ooOol00Woo0P0000Eoo`00Oomoo`0006=oo`03
001oogoo00Uoo`03001oogoo00Qoo`006Goo0P00@7oo00<007ooOol0=Woo00@007ooOomoo`800005
Ool007ooOol0001TOol00`00Oomoo`08Ool00`00Oomoo`08Ool001]oo`8003ioo`03001oogoo03Io
o`04001oogooOol30002Ool00`00Oomoo`1SOol00`00Oomoo`08Ool00`00Oomoo`08Ool001eoo`80
03aoo`03001oogoo03Moo`03001oogoo00<0009oo`03001oogoo06Aoo`03001oogoo00Moo`03001o
ogoo00Qoo`007goo00<007ooOol0>Goo00<007ooOol0=goo00<007ooOol00`0000=oo`00Ool0IWoo
00<007ooOol01goo00<007ooOol027oo000POol2000iOol00`00Oomoo`0hOol00`00Ool000020000
0goo001oo`1WOol00`00Oomoo`07Ool00`00Oomoo`07Ool0029oo`8003Moo`03001oogoo03Qoo`03
001oo`0000<006Uoo`03001oogoo00Moo`03001oogoo00Moo`0097oo0P00=Goo00<007ooOol0>Goo
1@00JWoo00<007ooOol01Woo00<007ooOol01goo000VOol2000cOol00`00Oomoo`0iOol01000Ool0
0000Jgoo00<007ooOol01Woo00<007ooOol01goo000XOol2000aOol00`00Oomoo`0jOol3001/Ool0
0`00Oomoo`05Ool00`00Oomoo`07Ool002Yoo`03001oogoo02ioo`03001oogoo03Yoo`8006ioo`03
001oogoo00Aoo`03001oogoo00Moo`00:goo0P00;Woo00<007ooOol0>goo00<007ooOol0K7oo00<0
07ooOol017oo00<007ooOol01goo000]Ool2000/Ool00`00Oomoo`2[Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool002moo`8002Yoo`03001oogoo0:]oo`03001oogoo00=oo`03001oogoo00Moo`00<Goo
0P00:7oo00<007ooOol0[7oo00<007ooOol00Woo00<007ooOol01goo000cOol2000VOol00`00Oomo
o`2/Ool00`00Oomoo`02Ool00`00Oomoo`07Ool003Eoo`8002Aoo`03001oogoo03eoo`@006aoo`05
001oogooOol00009Ool003Moo`03001oogoo025oo`03001oogoo03ioo`03001oo`0006aoo`05001o
ogooOol00009Ool003Qoo`80025oo`03001oogoo03eoo`03001oo`0006ioo`04001oogoo0009Ool0
03Yoo`8001moo`03001oogoo03eoo`@006eoo`05001oogooOol00008Ool003aoo`8001aoo`03001o
ogoo0;1oo`04001oogoo0008Ool003ioo`8001Yoo`03001oogoo0;1oo`04001oogoo0008Ool0041o
o`8001Qoo`03001oogoo0;5oo`03001oo`0000Qoo`00@Woo00<007ooOol05Goo00<007ooOol0/Goo
00<007oo000027oo0013Ool2000EOol00`00Oomoo`2bOol20008Ool004Eoo`8001=oo`03001oogoo
0;9oo`8000Qoo`00Agoo0P004Goo00<007ooOol0ZWoo2P0027oo0019Ool2000?Ool00`00Oomoo`2H
OolB000BOol004]oo`8000eoo`03001oogoo08Iooa8002Aoo`00CGoo0P002goo00<007ooOol0M7oo
4P00=Woo001?Ool00`00Oomoo`08Ool00`00Oomoo`1ROolB0018Ool0051oo`8000Qoo`03001oogoo
04mooa<005Yoo`00DWoo0P001Woo00<007ooOol0?Goo4P00KGoo001DOol20004Ool00`00Oomoo`0[
OolB001oOol005Ioo`80009oo`03001oogoo01Uooa80095oo`00F7oo0`002Goo4P00Xgoo001JOol:
002eOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYo
o`00ogoo6Woo0000\
\>"],
  ImageRangeCache->{{{0, 280}, {298, 0}} -> {0.0115781, -0.0255552, 
  0.00318287, 0.00318287}}]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is given to ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " before building any other part of the flywheel model. This is done so \
that the angular velocity and angular acceleration of the flywheel is \
calculated directly, instead of being calculated in terms of derivatives of \
Euler parameters. Note that this is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " a necessary step to obtain the dynamic forces. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This causes angular velocities to be calculated directly so that it won't be \
necessary to convert the Euler parameters into angular velocity."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetSymbols[Method \[Rule] Angular]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Inertia "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The flywheel is modeled by four one-unit point masses, symmetrically \
placed about the axis of rotation. The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function can be used, trivially, to find the net inertia properties of \
the flywheel. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \({fcent, fmass, finertia} = 
      CompositeInertia[\n
        \t\t{{1, 0, 0}, 1, {0, 0, 0, 0, 0, 0}}, {{0, 1, 0}, 
          1, {0, 0, 0, 0, 0, 0}}, {{\(-1\), 0, 0}, 
          1, {0, 0, 0, 0, 0, 0}}, {{0, \(-1\), 0}, 1, {0, 0, 0, 0, 0, 0}}]\), 
  
    \(On[General::"\<spell1\>"]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0, 0}, 4, {2, 2, 4, 0, 0, 0}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"One body object is defined for the flywheel model. The ground body does not \
have a body object because it has no inertia or required point definitions. \
The body object for the flywheel contains the inertia properties and the \
locations of each of the four point masses. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(flywheel = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the body object for the flywheel."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      bd[flywheel] = 
        Body[flywheel, 
          PointList 
            \[Rule] {{1, 0, 0}, {0, 1, 0}, {\(-1\), 0, 0}, {0, \(-1\), 0}}, \n
          \t\t\tCentroid \[Rule] fcent, \n\t\t\tMass \[Rule] fmass, \n\t\t\t
          Inertia \[Rule] finertia]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Three constraints, two of which are functionally dependent on time, are \
required to model the flywheel mechanism. \n\nA ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint places the center of the flywheel at the global origin.\nA ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint forces the axis of rotation of the flywheel to be parallel \
with a specified vector on the ground body. The direction of the axis vector \
on the ground body is explicitly a function of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This constraint effectively causes the axis of rotation of the flywheel \
to change direction with time. \nA ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint rotates the flywheel about its axis. Note the choice of the \
vector that was used on the ground body. The vector in the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " direction on the ground body is always normal to the axis of rotation of \
the flywheel. If a vector in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction was chosen instead, the constraint would become singular at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.25. Note also that the flywheel is spinning 10 times more rapidly \
about its symmetry axis than its axis is rotating with respect to the \
ground."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the flywheel."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      cs[1] = Spherical3[1, Point[ground, 0], Point[flywheel, 0]], \n\t
      cs[2] = Parallel2[2, Vector[flywheel, {0, 0, 1}], 
          Vector[ground, {Sin[2\ N[\[Pi]]\ T], 0, Cos[2.0  \[Pi]\ T]}]], \n\t
      cs[3] = ProjectedAngle1[3, Vector[flywheel, {0, 1, 0}], 
          Vector[ground, {0, 1, 0}], Vector[flywheel, {0, 0, 1}], 
          20.0  \[Pi]\ T]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because of the presence of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the constraints, the model can be run through its intended range of \
motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.02. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.02]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.02`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Z2 \[Rule] 0.`\), ",", 
        \(Eo2 \[Rule] 0.807420584139025798`\), ",", 
        \(Ei2 \[Rule] 0.0369073413628481672`\), ",", 
        \(Ej2 \[Rule] 0.0507985973848783345`\), ",", 
        \(Ek2 \[Rule] 0.58662539236452984`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Here is the flywheel at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.02."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.06305  
MathPictureStart 
%% Graphics3D 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
-0.0129967 1.12209 0.0280521 1.12209 [ 
[ 0 0 0 0 ] 
[ 1 1.06305 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
0 0 m 
1 0 L 
1 1.06305 L 
0 1.06305 L 
closepath 
clip 
newpath 
p 
.002 w 
.34205 .44874 m 
.32194 1.035 L 
s 
.32194 1.035 m 
.97195 .99899 L 
s 
.97195 .99899 m 
.93187 .3792 L 
s 
.93187 .3792 m 
.34205 .44874 L 
s 
.0871 .14338 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.02805 .87345 L 
s 
.02805 .87345 m 
.0871 .14338 L 
s 
.34205 .44874 m 
.32194 1.035 L 
s 
.32194 1.035 m 
.02805 .87345 L 
s 
.02805 .87345 m 
.0871 .14338 L 
s 
.0871 .14338 m 
.34205 .44874 L 
s 
.93187 .3792 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.97195 .99899 L 
s 
.97195 .99899 m 
.93187 .3792 L 
s 
P 
p 
.75 0 0 r 
.01 w 
.6704 .68213 m 
.40683 .48172 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.6704 .68213 Mdot 
P 
p 
.75 0 0 r 
.004 w 
.6531 .66897 m 
.63338 .6365 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.61654 .65808 m 
.6531 .66897 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.6531 .66897 m 
.63274 .67111 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.64971 .64937 m 
.6531 .66897 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.54805 .58909 m 
.6531 .66897 L 
s 
P 
p 
.75 0 0 r 
.01 w 
.7588 .52932 m 
.35684 .64333 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.35684 .64333 Mdot 
P 
p 
.75 0 0 r 
.004 w 
.54805 .58909 m 
.54103 .77541 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.72583 .53867 m 
.54805 .58909 L 
s 
P 
p 
.004 w 
.54805 .58909 m 
.54805 .94261 L 
s 
P 
p 
.004 w 
.54805 .58909 m 
.90789 .55286 L 
s 
P 
p 
.004 w 
.43872 .4419 m 
.54805 .58909 L 
s 
P 
p 
.004 w 
.83956 .57369 m 
.90789 .55286 L 
s 
P 
p 
.004 w 
.90789 .55286 m 
.83218 .52625 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.55395 .74469 m 
.54103 .77541 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.69963 .55806 m 
.72583 .53867 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.54103 .77541 m 
.52497 .74126 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.72583 .53867 m 
.68917 .53084 L 
s 
P 
p 
.004 w 
.54805 .94261 m 
.55783 .87804 L 
s 
P 
p 
.004 w 
.90789 .55286 m 
.83538 .59478 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.54103 .77541 m 
.56014 .73254 L 
s 
P 
p 
.004 w 
.82782 .5466 m 
.90789 .55286 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.72583 .53867 m 
.68894 .56751 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.53086 .72904 m 
.54103 .77541 L 
s 
P 
p 
.75 0 0 r 
.004 w 
.67835 .54003 m 
.72583 .53867 L 
s 
P 
p 
.004 w 
.51192 .87127 m 
.54805 .94261 L 
s 
P 
p 
.004 w 
.58444 .86609 m 
.54805 .94261 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.7588 .52932 Mdot 
P 
p 
.004 w 
.54805 .94261 m 
.53799 .85908 L 
s 
P 
p 
.75 0 0 r 
.08 w 
.40683 .48172 Mdot 
P 
p 
.004 w 
.43872 .4419 m 
.46369 .43836 L 
s 
P 
p 
.004 w 
.42488 .47918 m 
.43872 .4419 L 
s 
P 
p 
.004 w 
.50178 .47045 m 
.43872 .4419 L 
s 
P 
p 
.004 w 
.43872 .4419 m 
.46266 .51175 L 
s 
P 
p 
.002 w 
.0871 .14338 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.02805 .87345 L 
s 
.02805 .87345 m 
.0871 .14338 L 
s 
.93187 .3792 m 
.83254 .02805 L 
s 
.83254 .02805 m 
.87238 .81008 L 
s 
.87238 .81008 m 
.97195 .99899 L 
s 
.97195 .99899 m 
.93187 .3792 L 
s 
P 
p 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .43872 .4419 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .90789 .55286 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .54805 .94261 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(1)] .54805 .58909 1.3 1.3 Mshowa 
P 
.75 0 0 r 
p 
/Courier findfont 10 scalefont setfont 
[(x)] .72583 .53867 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(y)] .6531 .66897 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(z)] .54103 .77541 -1.3 -1.3 Mshowa 
P 
p 
/Courier findfont 10 scalefont setfont 
[(2)] .54805 .58909 1.3 1.3 Mshowa 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 299},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0001:a000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00
iWoo1000;goo003POol60003Ool00`00Oomoo`0]Ool00=Uoo`L000Uoo`8002ioo`00dgoo1P0047oo
0P00;Woo003<Ool7000FOol2000^Ool00<Ioo`H001eoo`8002ioo`00_goo1`008goo00<007oo0000
;Goo002iOol6000ZOol00`00Ool0000]Ool00;9oo`L0031oo`03001oo`0002eoo`00Zgoo1`00=goo
00<007oo0000;Goo002UOol6000oOol00`00Ool0000/Ool009ioo`L004Eoo`03001oo`0002aoo`00
V7oo1P00C7oo00<007oo0000;7oo002AOol7001BOol01000Oomoo`00:goo002;Ool6001IOol01000
Oomoo`00:goo0024Ool7001OOol01000Oomoo`00:goo001nOol6001VOol01000Oomoo`00:goo001g
Ool7001/Ool01@00Oomoogoo0000:Woo001aOol6001cOol01@00Oomoogoo0000:Woo001ZOol7001i
Ool01@00Oomoogoo0000:Woo001TOol60020Ool00`00Oomoo`02Ool00`00Oomoo`0WOol005eoo`L0
08Ioo`03001oogoo009oo`03001oogoo02Moo`00Egoo1P00SGoo00<007ooOol00Woo00<007ooOol0
9goo001@Ool7002COol00`00Oomoo`02Ool00`00Oomoo`0WOol004Uoo`L009Yoo`03001oogoo00=o
o`03001oogoo02Ioo`00@goo1P00XGoo00<007ooOol00goo00<007ooOol09Woo000lOol7002WOol0
0`00Oomoo`03Ool00`00Oomoo`0VOol003Ioo`H00:ioo`03001oogoo00=oo`03001oogoo02Ioo`00
;goo1`00]7oo00<007ooOol017oo00<007ooOol09Goo000YOol6002kOol00`00Oomoo`04Ool00`00
Oomoo`0UOol0029oo`L00<9oo`03001oogoo00=oo`03001oogoo02Eoo`0077oo1P00bGoo00<007oo
Ool017oo00<007ooOol097oo000HOol4003?Ool00`00Oomoo`04Ool00`00Oomoo`0TOol001Qoo`80
0=5oo`03001oogoo00Aoo`03001oogoo02Aoo`0067oo00<007oo0000d7oo00<007ooOol017oo00<0
07ooOol097oo000HOol01000Oomoo`00cgoo00<007ooOol01Goo00<007ooOol08goo000HOol01000
Oomoo`00cgoo00<007ooOol01Goo00<007ooOol08goo000HOol01@00Oomoogoo0000cWoo00<007oo
Ool01Goo00<007ooOol08goo000GOol00`00Oomoo`03Ool00`00Oomoo`3;Ool00`00Oomoo`05Ool0
0`00Oomoo`0SOol001Moo`03001oogoo00Aoo`03001oogoo0<Yoo`03001oogoo00Ioo`03001oogoo
029oo`005goo00<007ooOol01Goo00<007ooOol0bGoo00<007ooOol01Woo00<007ooOol08Woo000G
Ool00`00Oomoo`06Ool00`00Oomoo`38Ool00`00Oomoo`06Ool00`00Oomoo`0ROol001Moo`03001o
ogoo00Ioo`03001oogoo0<Qoo`03001oogoo00Moo`03001oogoo025oo`005goo00<007ooOol01goo
00<007ooOol0agoo00<007ooOol01goo00<007ooOol08Goo000GOol00`00Oomoo`08Ool00`00Oomo
o`36Ool00`00Oomoo`07Ool00`00Oomoo`0QOol001Moo`03001oogoo00Uoo`03001oogoo0<Eoo`03
001oogoo00Moo`03001oogoo025oo`005goo00<007ooOol02Woo00<007ooOol0a7oo00<007ooOol0
27oo00<007ooOol087oo000GOol00`00Oomoo`0;Ool00`00Oomoo`33Ool00`00Oomoo`08Ool00`00
Oomoo`0POol001Moo`03001oogoo00]oo`03001oogoo0<=oo`03001oogoo00Qoo`03001oogoo021o
o`005goo00<007ooOol037oo00<007ooOol0`Woo00<007ooOol027oo00<007ooOol087oo000FOol0
0`00Oomoo`0>Ool00`00Oomoo`32Ool00`00Oomoo`08Ool00`00Oomoo`0OOol001Ioo`03001oogoo
00moo`03001oogoo0<5oo`03001oogoo00Qoo`03001oogoo01moo`005Woo00<007ooOol047oo00<0
07ooOol0`7oo00<007ooOol027oo00<007ooOol07goo000FOol00`00Oomoo`0AOol00`00Oomoo`2o
Ool00`00Oomoo`09Ool00`00Oomoo`0NOol001Ioo`03001oogoo015oo`03001oogoo0;moo`03001o
ogoo00Uoo`03001oogoo01ioo`005Woo00<007ooOol04Woo00<007ooOol0_Woo00<007ooOol02Goo
00<007ooOol07Woo000FOol00`00Oomoo`0COol00`00Oomoo`2mOol00`00Oomoo`09Ool00`00Oomo
o`0NOol001Ioo`03001oogoo01Aoo`03001oogoo0;aoo`03001oogoo00Yoo`03001oogoo01eoo`00
5Woo00<007ooOol05Goo00<007ooOol0^goo00<007ooOol02Woo00<007ooOol07Goo000FOol00`00
Oomoo`0FOol00`00Oomoo`2jOol00`00Oomoo`0:Ool00`00Oomoo`0MOol001Ioo`03001oogoo01Io
o`03001oogoo0;Yoo`03001oogoo00]oo`03001oogoo01aoo`005Woo00<007ooOol05goo00<007oo
Ool0^Goo00<007ooOol02goo00<007ooOol077oo000EOol00`00Oomoo`0IOol00`00Oomoo`2hOol0
0`00Oomoo`0;Ool00`00Oomoo`0LOol001Eoo`03001oogoo01Yoo`03001oogoo0;Moo`03001oogoo
00]oo`03001oogoo01aoo`005Goo00<007ooOol06goo00<007ooOol0]Woo00<007ooOol037oo00<0
07ooOol06goo000EOol00`00Oomoo`0LOol00`00Oomoo`2eOol00`00Oomoo`0<Ool00`00Oomoo`0K
Ool001Eoo`03001oogoo01aoo`03001oogoo0;Eoo`03001oogoo00aoo`03001oogoo01]oo`005Goo
00<007ooOol07Goo00<007ooOol0]7oo00<007ooOol037oo00<007ooOol06goo000EOol00`00Oomo
o`0NOol00`00Oomoo`2cOol00`00Oomoo`0=Ool00`00Oomoo`0JOol001Eoo`03001oogoo01moo`03
001oogoo0;9oo`03001oogoo00eoo`03001oogoo01Yoo`005Goo00<007ooOol087oo00<007ooOol0
/Woo00<007ooOol037oo00<007ooOol06Woo000EOol00`00Oomoo`0QOol00`00Oomoo`2aOol00`00
Oomoo`0=Ool00`00Oomoo`0IOol001Eoo`03001oogoo025oo`03001oogoo0;5oo`03001oogoo00eo
o`03001oogoo01Uoo`005Goo00<007ooOol08Woo00<007ooOol0/7oo00<007ooOol03Goo00<007oo
Ool06Goo000DOol00`00Oomoo`0TOol00`00Oomoo`2_Ool00`00Oomoo`0=Ool00`00Oomoo`0IOol0
01Aoo`03001oogoo02Eoo`03001oogoo0:ioo`03001oogoo00ioo`03001oogoo01Qoo`0057oo00<0
07ooOol09Woo00<007ooOol0[Goo00<007ooOol03Woo00<007ooOol067oo000DOol00`00Oomoo`0W
Ool00`00Oomoo`2/Ool00`00Oomoo`0>Ool00`00Oomoo`0HOol001Aoo`03001oogoo02Moo`03001o
ogoo0:aoo`03001oogoo00ioo`03001oogoo01Qoo`0057oo00<007ooOol0:7oo00<007ooOol0Zgoo
00<007ooOol03goo00<007ooOol05goo000DOol00`00Oomoo`0YOol00`00Oomoo`2ZOol00`00Oomo
o`0?Ool00`00Oomoo`0GOol001Aoo`03001oogoo02Yoo`03001oogoo0:Uoo`03001oogoo00moo`03
001oogoo01Moo`0057oo00<007ooOol0:goo00<007ooOol0Z7oo00<007ooOol047oo00<007ooOol0
5Woo000DOol00`00Oomoo`0/Ool00`00Oomoo`2WOol00`00Oomoo`0@Ool00`00Oomoo`0FOol001Ao
o`03001oogoo02aoo`03001oogoo0:Moo`03001oogoo011oo`03001oogoo01Ioo`0057oo00<007oo
Ool0;Goo00<007ooOol0YWoo00<007ooOol047oo00<007ooOol05Woo000COol00`00Oomoo`0_Ool0
0`00Oomoo`2UOol00`00Oomoo`0AOol00`00Oomoo`0EOol001=oo`03001oogoo031oo`03001oogoo
0:Aoo`03001oogoo015oo`03001oogoo01Eoo`004goo00<007ooOol0<Goo00<007ooOol0Xgoo00<0
07ooOol04Goo00<007ooOol05Goo000COol00`00Oomoo`0bOol00`00Oomoo`2ROol00`00Oomoo`0B
Ool00`00Oomoo`0DOol001=oo`03001oogoo039oo`03001oogoo0:=oo`03001oogoo015oo`03001o
ogoo01Aoo`004goo00<007ooOol0<goo00<007ooOol0XWoo00<007ooOol04Goo00<007ooOol057oo
000COol00`00Oomoo`0dOol00`00Oomoo`2QOol00`00Oomoo`0AOol00`00Oomoo`0DOol001=oo`03
001oogoo03Eoo`03001oogoo0:1oo`03001oogoo019oo`03001oogoo01=oo`004goo00<007ooOol0
=Woo00<007ooOol0Wgoo00<007ooOol04Woo00<007ooOol04goo000COol00`00Oomoo`0gOol00`00
Oomoo`2NOol00`00Oomoo`0BOol00`00Oomoo`0COol001=oo`03001oogoo03Moo`03001oogoo09io
o`03001oogoo019oo`03001oogoo01=oo`004goo00<007ooOol0>7oo00<007ooOol0WGoo00<007oo
Ool04goo00<007ooOol04Woo000BOol00`00Oomoo`0jOol00`00Oomoo`2LOol00`00Oomoo`0?Ool5
000DOol0019oo`03001oogoo03]oo`03001oogoo09]oo`03001oogoo00Ioo`T000Aoo`03001oogoo
019oo`004Woo00<007ooOol0?7oo00<007ooOol0VWoo2@003Goo00<007ooOol04Woo000BOol00`00
Oomoo`0mOol00`00Oomoo`2AOol9000EOol00`00Oomoo`0BOol0019oo`03001oogoo03eoo`03001o
ogoo08Qoo`T000Qoo`03001oogoo01=oo`03001oogoo019oo`004Woo00<007ooOol0?Woo00<007oo
Ool0Ogoo20004Goo00<007ooOol04goo00<007ooOol04Woo000BOol00`00Oomoo`0oOol00`00Oomo
o`1eOol9000IOol00`00Oomoo`0COol00`00Oomoo`0BOol0019oo`03001oogoo041oo`03001oogoo
06]oo`T0029oo`03001oogoo01=oo`03001oogoo019oo`004Woo00<007ooOol0@Goo00<007ooOol0
HWoo2000:goo00<007ooOol057oo00<007ooOol04Goo000BOol00`00Oomoo`12Ool00`00Oomoo`1H
Ool9000cOol00`00Oomoo`0DOol00`00Oomoo`0AOol0019oo`03001oogoo049oo`03001oogoo04mo
o`T003aoo`03001oogoo01Aoo`03001oogoo015oo`004Woo00<007ooOol0@goo00<007ooOol0AWoo
2000AGoo00<007ooOol057oo00<007ooOol04Goo000AOol00`00Oomoo`15Ool00`00Oomoo`0lOol9
001>Ool00`00Oomoo`0COol00`00Oomoo`0AOol0015oo`03001oogoo04Ioo`03001oogoo039oo`T0
05Moo`03001oogoo01=oo`03001oogoo015oo`004Goo00<007ooOol0Agoo00<007ooOol0:Goo2000
H7oo00<007ooOol04goo00<007ooOol04Goo000AOol00`00Oomoo`18Ool00`00Oomoo`0OOol9001X
Ool00`00Oomoo`0COol00`00Oomoo`0AOol0015oo`03001oogoo04Qoo`03001oogoo01Ioo`d006eo
o`03001oogoo01=oo`03001oogoo015oo`004Goo00<007ooOol0BGoo00<007ooOol03Goo20001Goo
1000LGoo00<007ooOol04goo00<007ooOol04Goo000AOol00`00Oomoo`1:Ool00`00Oomoo`03Ool9
000=Ool4001aOol00`00Oomoo`0COol00`00Oomoo`0AOol0015oo`03001oogoo04]oo`D000aoo`=L
00Ioo`03001oo`00009oo`8006moo`03001oogoo01=oo`03001oogoo015oo`004Goo00<007ooOol0
Bgoo00<007ooOol02goo2E`00goo00@007oo000000=oo`8006eoo`03001oogoo01=oo`03001oogoo
015oo`004Goo00<007ooOol0Bgoo00<007ooOol02Goo3E`000Ioo`00Ool007oo0004Ool3001ZOol0
0`00Oomoo`0COol00`00Oomoo`0AOol0015oo`03001oogoo04]oo`03001oogoo00Qoo`iL0007001o
ogooOol007oo00001Woo0P00J7oo00<007ooOol057oo00<007ooOol047oo000AOol00`00Oomoo`1;
Ool00`00Oomoo`07Ool?G0001P00G01oogoo001oo`8000Moo`8006Ioo`03001oogoo01Aoo`03001o
ogoo011oo`0047oo00<007ooOol0C7oo00<007ooOol01goo3U`000<005`0G0000Woo10002Goo0P00
I7oo00<007ooOol057oo00<007ooOol047oo000@Ool00`00Oomoo`1<Ool00`00Oomoo`06Ool?G000
1000G01L05`00Woo0P0000=oo`00Ool02Goo0P00HWoo00<007ooOol057oo00<007ooOol047oo000@
Ool00`00Oomoo`1<Ool00`00Oomoo`06Ool?G0001@00G01L05`0Ool00P0000Aoo`00Ool006eoo`03
001oogoo01Aoo`03001oogoo011oo`0047oo00<007ooOol0C7oo00<007ooOol01Woo3U`000<005`0
G0000U`00Woo00D007ooOomoo`0006eoo`03001oogoo01Aoo`03001oogoo011oo`0047oo00<007oo
Ool0C7oo00<007ooOol01Goo3e`000<005`0G0000e`00Woo00D007ooOomoo`0006aoo`03001oogoo
01Aoo`03001oogoo011oo`0047oo00<007ooOol0C7oo00<007ooOol01Goo5E`00Woo00<007ooOol0
0Woo00<007ooOol0JGoo00<007ooOol057oo00<007ooOol047oo000@Ool00`00Oomoo`1<Ool00`00
Oomoo`05OolEG003Ool00`00Oomoo`02Ool00`00Oomoo`1XOol00`00Oomoo`0DOol00`00Oomoo`0@
Ool0011oo`03001oogoo04aoo`03001oogoo00Iooa=L00Aoo`03001oogoo009oo`03001oogoo06Uo
o`03001oogoo01=oo`03001oogoo011oo`0047oo00<007ooOol0C7oo00<007ooOol01Woo4e`017oo
00<007ooOol00goo00<007ooOol0J7oo00<007ooOol04goo00<007ooOol047oo000@Ool00`00Oomo
o`1<Ool00`00Oomoo`06OolCG005Ool00`00Oomoo`03Ool00`00Oomoo`19Ool3G00KOol00`00Oomo
o`0COol00`00Oomoo`0@Ool0011oo`03001oogoo04aoo`03001oogoo00Mooa5L00Ioo`03001oogoo
00Aoo`03001oogoo04Eoo`UL01Qoo`03001oogoo01=oo`03001oogoo011oo`0047oo00<007ooOol0
C7oo00<007ooOol01goo4U`01Goo00<007ooOol017oo00<007ooOol0@goo3E`05Woo00<007ooOol0
4goo00<007ooOol047oo000?Ool00`00Oomoo`1<Ool00`00Oomoo`09OolCG004Ool00`00Oomoo`04
Ool00`00Oomoo`11Ool?G00EOol00`00Oomoo`0COol00`00Oomoo`0@Ool000moo`03001oogoo04ao
o`03001oogoo00Yoo`eL009oo`AL00=oo`03001oogoo00Eoo`03001oogoo03mooa5L01Aoo`03001o
ogoo01Aoo`03001oogoo00moo`003goo00<007ooOol0C7oo00<007ooOol037oo2E`01Woo0e`02Woo
00<007ooOol0?goo4E`057oo00<007ooOol057oo00<007ooOol03goo000?Ool00`00Oomoo`1<Ool0
0`00Oomoo`0?Ool3G00:Ool4G009Ool00`00Oomoo`0mOolCG00COol00`00Oomoo`0DOol00`00Oomo
o`0?Ool000moo`03001oogoo04aoo`03001oogoo01eoo`AL00Uoo`03001oogoo03aooa=L01=oo`03
001oogoo01Aoo`03001oogoo00moo`003goo00<007ooOol0C7oo00<007ooOol07goo0e`02Goo00<0
07ooOol0>goo4e`037oo0P001Goo00<007ooOol057oo00<007ooOol03goo000?Ool00`00Oomoo`1<
Ool00`00Oomoo`0POol4G007Ool00`00Oomoo`0aOol3G006OolEG00=Ool30002Ool00`00Oomoo`0D
Ool00`00Oomoo`0?Ool000moo`03001oogoo04aoo`03001oogoo025oo`AL00Moo`03001oogoo03=o
oa]L011oo`<001Ioo`03001oogoo00moo`003goo00<007ooOol0C7oo00<007ooOol08goo0e`01goo
00<007ooOol0=7oo6E`04Woo10004goo00<007ooOol03goo000?Ool00`00Oomoo`1<Ool00`00Oomo
o`0TOol3G007Ool00`00Oomoo`0[Ool8G0000gooG01L000EG00COol01000Oomoogoo0`0047oo00<0
07ooOol03goo000?Ool00`00Oomoo`1<Ool00`00Oomoo`0UOol4G005Ool00`00Oomoo`0aOolJG00C
Ool00`00Oomoo`04Ool3000=Ool00`00Oomoo`0?Ool000moo`03001oogoo04aoo`03001oogoo02Io
o`AL00Eoo`03001oogoo02aoo`ML0004OomL07ooOolCG00:Ool<0007Ool3000:Ool00`00Oomoo`0?
Ool000ioo`03001oogoo04eoo`03001oogoo02Qoo`=L00Eoo`03001oogoo02Qoo`ML00=oo`03G01o
ogoo009ooa5L01Aoo`03001oogoo00`000Qoo`03001oogoo00moo`003Woo00<007ooOol0CGoo00<0
07ooOol0:Goo15`017oo0P000e`000<007ooOol07Woo1e`01Goo0U`01Goo4E`057oo3P002Goo00<0
07ooOol03goo000>Ool00`00Oomoo`1=Ool00`00Oomoo`0ZOol4G003Ool01000OomL00007goo1e`0
1goo0U`01goo3e`03Goo2@001Woo1@002goo00<007ooOol03goo000>Ool00`00Oomoo`1=Ool00`00
Oomoo`0/Ool3G003Ool00`00OomL000KOol7G00:Ool2G009Ool=G004Ool:0009Ool00`00Ool00003
00000goo0000000>Ool00`00Oomoo`0>Ool000ioo`03001oogoo04eoo`03001oogoo02eoo`AL009o
o`03001L07oo01Moo`ML00aoo`03G01oogoo00Uoo`]L00H0019oo`<000Aoo`03001oogoo00Eoo`80
00Moo`03001oogoo00ioo`003Woo00<007ooOol0CGoo00<007ooOol0;Woo15`000Aooe`0001L01=o
o`ML00moo`03G01oogoo00Uoo`04G0000000G0020003G00HOol300000goo001oo`02Ool20009Ool0
0`00Oomoo`05Ool00`00Oomoo`0>Ool000ioo`03001oogoo04eoo`03001oogoo031oo`=L0003001L
07oo011oo`ML01Eoo`T001moo`8000Aoo`04001oo`00000;Ool00`00Oomoo`05Ool00`00Oomoo`0>
Ool000ioo`03001oogoo04eoo`03001oogoo035oo`AL0003001oogoo00Yoo`ML011oo`T002ioo`80
00aoo`03001oo`0000Ioo`03001oogoo00ioo`003Woo00<007ooOol0CGoo00<007ooOol0<Woo15`0
00<007ooOol01Woo1e`02Goo2P00=Woo0P003Goo00<007oo00001Woo00<007ooOol03Woo000>Ool0
0`00Oomoo`1=Ool00`00Oomoo`0dOol3G0001000Oomoogoo1e`017oo2@00?Woo0P0000=oo`00Ool0
2goo0P0000=oo`0000001Goo00<007ooOol03Woo000>Ool00`00Oomoo`1=Ool00`00Oomoo`0eOol2
G0000`00G01L0003G0090015Ool20003Ool00`00Oomoo`0DOol00`00Oomoo`0>Ool000ioo`03001o
ogoo04eoo`03001oogoo03Aoo`AL00D004aoo`8000Eoo`03001oogoo01Aoo`03001oogoo00ioo`00
3Goo00<007ooOol0CWoo00<007ooOol0<7oo1e`000Aoo`00G01L04eoo`03001oogoo00Eoo`03001o
ogoo01Aoo`03001oogoo00ioo`003Goo00<007ooOol0CWoo00<007ooOol0;Goo1e`017oo00<005`0
G0000U`0Dgoo00<007ooOol057oo00<007ooOol03Woo000=Ool00`00Oomoo`1>Ool00`00Oomoo`0Y
Ool7G008Ool00`00OomL0003G01BOol00`00Oomoo`0DOol00`00Oomoo`0>Ool000eoo`03001oogoo
04ioo`03001oogoo02Ioo`ML00]oo`04001oogooOol3G01AOol00`00Oomoo`0DOol00`00Oomoo`0>
Ool000eoo`03001oogoo04ioo`04001oogooOol3G00NOol7G00?Ool00`00Oomoo`02Ool4G01?Ool0
0`00Oomoo`0DOol00`00Oomoo`0>Ool000eoo`03001oogoo04ioo`03001L05`000ML01Qoo`ML019o
o`03001oogoo00=oo`AL04ioo`03001oogoo01Eoo`03001oogoo00eoo`003Goo00<007ooOol0CGoo
3E`04Woo1e`05Woo00<007ooOol01Goo0e`0CGoo00<007ooOol05Goo00<007ooOol03Goo000=Ool0
0`00Oomoo`1<Ool?G00>Ool7G00IOol00`00Oomoo`06Ool4G01;Ool00`00Oomoo`0EOol00`00Oomo
o`0=Ool000eoo`03001oogoo04]ooa5L00Uoo`ML01eoo`03001oogoo00Moo`AL04Yoo`03001oogoo
01Eoo`03001oogoo00eoo`003Goo00<007ooOol0Bgoo4E`01Woo1e`087oo00<007ooOol02Goo0e`0
BGoo00<007ooOol05Goo00<007ooOol03Goo000=Ool00`00Oomoo`1:OolCG0000gooG01L0005G00T
Ool00`00Oomoo`0:Ool3G018Ool00`00Oomoo`0EOol00`00Oomoo`0=Ool000eoo`03001oogoo04Yo
oaQL02Moo`03001oogoo00]oo`AL04Moo`03001oogoo01Aoo`03001oogoo00eoo`0037oo00<007oo
Ool0Bgoo55`0:Woo00=L0000Ool03Goo15`01Goo00=L07ooOol0?Woo00<007ooOol057oo00<007oo
Ool03Goo000<Ool00`00Oomoo`1:OolEG00ZOol00e`0001oo`0?Ool3G005Ool00e`0Oomoo`0mOol0
0`00Oomoo`0DOol00`00Oomoo`0=Ool000aoo`03001oogoo04YooaEL02Yoo`03G00007oo011oo`AL
00=oo`03G01oogoo03eoo`03001oogoo01Aoo`03001oogoo00eoo`0037oo00<007ooOol0BWoo5E`0
:Woo00=L0000Ool04Goo15`00goo00=L07ooG00017oo0e`0=Goo00<007ooOol057oo00<007ooOol0
3Goo000<Ool00`00Oomoo`1;OolCG00[Ool00e`0001oo`0COol3G002Ool015`0OomL07oo2E`0<Woo
00<007ooOol057oo00<007ooOol03Goo000<Ool00`00Oomoo`1;OolCG00[Ool00e`0001oo`0DOol4
G0000gooG01L000<G00`Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool000aoo`03001oogoo04]ooa=L
02]oo`03G00007oo015oo`9L009ooa=L02moo`03001oogoo01Aoo`03001oogoo00eoo`0037oo00<0
07ooOol0C7oo4E`0;7oo00=L0000Ool04goo0e`000=ooe`0G00045`0;Woo00<007ooOol057oo00<0
07ooOol03Goo000<Ool00`00Oomoo`1<OolAG00/Ool00e`0001oo`0FOolCG00^Ool00`00Oomoo`0E
Ool00`00Oomoo`0<Ool000aoo`03001oogoo04eoo`mL02eoo`03G00007oo01Mooa=L02eoo`03001o
ogoo01Eoo`03001oogoo00aoo`0037oo00<007ooOol0CWoo3E`0;Woo00=L0000Ool05Woo55`0;Goo
00<007ooOol05Goo00<007ooOol037oo000<Ool00`00Oomoo`1>Ool00`00OomL0008G00`Ool00e`0
001oo`0GOolCG00]Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool000]oo`03001oogoo04moo`03001o
ogoo009oo`=L03=oo`03G00007oo01IooaEL02aoo`03001oogoo01Eoo`03001oogoo00aoo`002goo
00<007ooOol0Cgoo00<007ooOol0>7oo00=L0000Ool05Woo5E`0;7oo00<007ooOol05Goo00<007oo
Ool037oo000;Ool00`00Oomoo`1?Ool00`00Oomoo`0hOol00e`0001oo`0FOolEG00/Ool00`00Oomo
o`0EOol00`00Oomoo`0<Ool000]oo`03001oogoo04moo`03001oogoo03Qoo`03G00007oo01Mooa=L
02eoo`03001oogoo01Eoo`03001oogoo00aoo`002goo00<007ooOol0Cgoo00<007ooOol0>7oo00=L
0000Ool05goo4e`0;Goo00<007ooOol05Goo00<007ooOol037oo000;Ool00`00Oomoo`1?Ool00`00
Oomoo`0hOol00e`0001oo`0GOolCG00]Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool000]oo`03001o
ogoo04moo`03001oogoo03Qoo`03G00007oo01Qooa5L02ioo`03001oogoo01Eoo`03001oogoo00ao
o`002goo00<007ooOol0Cgoo00<007ooOol0>7oo00=L0000Ool067oo4E`0;goo00<007ooOol057oo
00<007ooOol037oo000;Ool00`00Oomoo`1?Ool00`00Oomoo`0hOol00e`0001oo`0IOol?G00`Ool0
0`00Oomoo`0DOol00`00Oomoo`0<Ool000]oo`03001oogoo04moo`03001oogoo03Qoo`03G00007oo
01Yoo`eL035oo`03001oogoo01Aoo`03001oogoo00aoo`002goo00<007ooOol0Cgoo00<007ooOol0
>7oo00=L0000Ool077oo2E`0<goo00<007ooOol05Goo00<007ooOol02goo000;Ool00`00Oomoo`1?
Ool00`00Oomoo`0hOol00e`0001oo`0OOol3G00fOol00`00Oomoo`0EOol00`00Oomoo`0;Ool000Yo
o`03001oogoo051oo`03001oogoo03Qoo`03G00007oo05Qoo`03001oogoo01Eoo`03001oogoo00]o
o`002Woo00<007ooOol0D7oo00<007ooOol0>7oo00=L0000Ool0F7oo00<007ooOol05Goo00<007oo
Ool02goo000:Ool00`00Oomoo`1@Ool00`00Oomoo`0dOol01U`0Oomooe`0Ool005Uoo`03001oogoo
01Eoo`03001oogoo00]oo`002Woo00<007ooOol0D7oo00<007ooOol0=7oo00IL07ooOomL07oo0002
Ool00e`0Oomoo`1DOol00`00Oomoo`0EOol00`00Oomoo`0;Ool000Yoo`03001oogoo051oo`03001o
ogoo03Aoo`06G01oogooG01oo`000Woo00=L07ooOol0E7oo00<007ooOol05Goo00<007ooOol02goo
000:Ool00`00Oomoo`1?Ool00`00Oomoo`0cOol02U`0Oomooe`0OomL07oo001ooe`0Egoo00<007oo
Ool05Goo00<007ooOol02goo000:Ool00`00Oomoo`1?Ool00`00Oomoo`0cOol02U`0Oomooe`0OomL
07oo001ooe`0Egoo00<007ooOol05Goo00<007ooOol02goo000:Ool00`00Oomoo`1?Ool00`00Oomo
o`0dOol01e`0OomL07ooG01oo`00009L05Moo`03001oogoo01Eoo`03001oogoo00]oo`002Woo00<0
07ooOol0Cgoo00<007ooOol0=7oo00QL07ooG01ooe`0Ool005`0F7oo00<007ooOol05Goo00<007oo
Ool02goo000:Ool00`00Oomoo`1?Ool00`00Oomoo`0eOol01E`0OomL05`0Ool00U`0F7oo00<007oo
Ool05Goo00<007ooOol02goo000:Ool00`00Oomoo`1?Ool00`00Oomoo`0eOol01U`0OomL05`0OomL
05Uoo`03001oogoo01Eoo`03001oogoo00]oo`002Woo00<007ooOol0Cgoo00<007ooOol0=Woo0e`0
00=ooe`0Ool0F7oo00<007ooOol05Goo00<007ooOol02goo0009Ool00`00Oomoo`1@Ool00`00Oomo
o`0fOol4G0000`00Oomoo`1GOol00`00Oomoo`0EOol00`00Oomoo`0;Ool000Uoo`03001oogoo051o
o`03001oogoo03Moo`=L0003001oogoo05Moo`03001oogoo01Ioo`03001oogoo00Yoo`002Goo00<0
07ooOol0D7oo00<007ooOol0=goo0U`000=oo`00Ool0F7oo00<007ooOol05Woo00<007ooOol02Woo
0009Ool00`00Oomoo`1@Ool00`00Oomoo`0hOol00e`0Ool0001JOol00`00Oomoo`0EOol00`00Oomo
o`0:Ool000Uoo`03001oogoo051oo`03001oogoo03Yoo`03001oogoo05Qoo`03001oogoo01Eoo`03
001oogoo00Yoo`002Goo00<007ooOol0D7oo00<007ooOol0>Woo00<007ooOol0F7oo00<007ooOol0
5Goo00<007ooOol02Woo0009Ool00`00Oomoo`1@Ool00`00Oomoo`0jOol00`00Oomoo`1HOol00`00
Oomoo`0EOol00`00Oomoo`0:Ool000Uoo`03001oogoo051oo`03001oogoo03Yoo`03001oogoo05Qo
o`03001oogoo01Eoo`03001oogoo00Yoo`002Goo00<007ooOol0D7oo00<007ooOol0>Woo00<007oo
Ool0F7oo00<007ooOol05Goo00<007ooOol02Woo0009Ool00`00Oomoo`1@Ool00`00Oomoo`0jOol4
G01GOol00`00Oomoo`0EOol00`00Oomoo`0:Ool000Uoo`03001oogoo051oo`03001oogoo03Yoo`04
001L07ooG01GOol00`00Oomoo`0EOol00`00Oomoo`0:Ool000Uoo`03001oogoo051oo`03001oogoo
03Yoo`03G01ooe`005Qoo`03001oogoo01Eoo`03001oogoo00Yoo`0027oo00<007ooOol0DGoo00<0
07ooOol0>Woo15`0DGoo1`005goo00<007ooOol02Woo0008Ool00`00Oomoo`1AOol00`00Oomoo`0j
Ool00`00Oomoo`15Ool=0007Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool000Qoo`03001oogoo055o
o`03001oogoo03Yoo`03001oogoo03Qoo`d001Aoo`03001oogoo01Aoo`03001oogoo00Yoo`0027oo
00<007ooOol0DGoo00<007ooOol0>Woo00<007ooOol0:Woo3P008Woo00<007ooOol057oo00<007oo
Ool02Goo0008Ool00`00Oomoo`1AOol00`00Oomoo`0jOol00`00Oomoo`0MOol=000`Ool00`00Oomo
o`0DOol00`00Oomoo`09Ool000Qoo`03001oogoo055oo`03001oogoo03Yoo`03001oogoo011oo`d0
03ioo`03001oogoo01=oo`03001oogoo00Uoo`0027oo00<007ooOol0DGoo00<007ooOol0>Woo00<0
07ooOol00goo3@00Bgoo00<007ooOol04goo00<007ooOol02Goo0008Ool00`00Oomoo`1AOol00`00
Oomoo`0cOol=001IOol00`00Oomoo`0BOol00`00Oomoo`09Ool000Qoo`03001oogoo055oo`03001o
ogoo02Ioo`d000Moo`03001oogoo05aoo`03001oogoo019oo`03001oogoo00Uoo`0027oo00<007oo
Ool0DGoo00<007ooOol067oo3P0057oo00<007ooOol0GGoo00<007ooOol04Goo00<007ooOol02Goo
0008Ool00`00Oomoo`1AOol00`00Oomoo`0;Ool=000ROol00`00Oomoo`1MOol00`00Oomoo`0AOol0
0`00Oomoo`09Ool000Qoo`03001oogoo055oo`h002moo`03001oogoo05ioo`03001oogoo011oo`03
001oogoo00Uoo`001goo00<007ooOol0AWoo3@00?7oo00<007ooOol0GWoo00<007ooOol047oo00<0
07ooOol02Goo0007Ool00`00Oomoo`0iOol=000<Ool00`00Oomoo`0jOol00`00Oomoo`1OOol00`00
Oomoo`0?Ool00`00Oomoo`09Ool000Moo`03001oogoo02aoo`d001Qoo`03001oogoo03Qoo`04001o
ogoo001QOol00`00Oomoo`0?Ool00`00Oomoo`09Ool000Moo`03001oogoo01ioo`h002Eoo`03001o
ogoo03Qoo`04001oogoo001ROol00`00Oomoo`0>Ool00`00Oomoo`09Ool000Moo`03001oogoo015o
o`d003=oo`03001oogoo03Qoo`04001oogoo0009Ool00`00Oomoo`1FOol00`00Oomoo`0>Ool00`00
Oomoo`09Ool000Moo`03001oogoo00Aoo`d0041oo`03001oogoo03Qoo`04001oogoo0009Ool00`00
Oomoo`1GOol00`00Oomoo`0>Ool00`00Oomoo`08Ool000Moo`L004eoo`03001oogoo035oo`03001o
ogoo00Aoo`04001oogoo0008Ool00`00Oomoo`1IOol00`00Oomoo`0=Ool00`00Oomoo`08Ool000Qo
o`80055oo`03001oogoo035oo`03001oogoo00Eoo`03001oo`0000Qoo`03001oogoo05Uoo`03001o
ogoo00eoo`03001oogoo00Qoo`002Woo0P00Cgoo00<007ooOol0<Woo00<007ooOol017oo00<007oo
00000Woo00<007ooOol00Woo00<007ooOol0Fgoo00<007ooOol037oo00<007ooOol027oo000<Ool2
001=Ool00`00Oomoo`0bOol00`00Oomoo`04Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomo
o`1KOol00`00Oomoo`0<Ool00`00Oomoo`08Ool000ioo`8004]oo`03001oogoo03=oo`03001oogoo
00=oo`03001oo`00009oo`05001oogooOol0001OOol00`00Oomoo`0;Ool00`00Oomoo`08Ool0011o
o`8004Uoo`03001oogoo03=oo`03001oogoo00=oo`05001oo`00Ool00004Ool00`00Oomoo`1MOol0
0`00Oomoo`0;Ool00`00Oomoo`08Ool0019oo`03001oogoo04Ioo`03001oogoo03Aoo`03001oogoo
009oo`05001oo`00Ool00003Ool00`00Oomoo`1OOol00`00Oomoo`0:Ool00`00Oomoo`08Ool001=o
o`8004Ioo`03001oogoo03Aoo`03001oogoo009oo`05001oo`00Ool00003Ool00`00Oomoo`1OOol0
0`00Oomoo`0:Ool00`00Oomoo`08Ool001Eoo`8004Aoo`03001oogoo03Eoo`09001oogooOol007oo
001oo`00009oo`03001oogoo065oo`03001oogoo00Uoo`03001oogoo00Qoo`005goo0P00@Woo00<0
07ooOol0=Goo00<007ooOol00Woo0P0000Eoo`00Oomoo`0006=oo`03001oogoo00Uoo`03001oogoo
00Qoo`006Goo0P00@7oo00<007ooOol0=Woo00@007ooOomoo`800005Ool007ooOol0001TOol00`00
Oomoo`08Ool00`00Oomoo`08Ool001]oo`8003ioo`03001oogoo03Ioo`04001oogooOol30002Ool0
0`00Oomoo`1SOol00`00Oomoo`08Ool00`00Oomoo`08Ool001eoo`8003aoo`03001oogoo03Moo`03
001oogoo00<0009oo`03001oogoo06Aoo`03001oogoo00Moo`03001oogoo00Qoo`007goo00<007oo
Ool0>Goo00<007ooOol0=goo00<007ooOol00`0000=oo`00Ool0IWoo00<007ooOol01goo00<007oo
Ool027oo000POol2000iOol00`00Oomoo`0hOol00`00Ool0000200000goo001oo`1WOol00`00Oomo
o`07Ool00`00Oomoo`07Ool0029oo`8003Moo`03001oogoo03Qoo`03001oo`0000<006Uoo`03001o
ogoo00Moo`03001oogoo00Moo`0097oo0P00=Goo00<007ooOol0>Goo1@00JWoo00<007ooOol01Woo
00<007ooOol01goo000VOol2000cOol00`00Oomoo`0iOol01000Ool00000Jgoo00<007ooOol01Woo
00<007ooOol01goo000XOol2000aOol00`00Oomoo`0jOol3001/Ool00`00Oomoo`05Ool00`00Oomo
o`07Ool002Yoo`03001oogoo02ioo`03001oogoo03Yoo`8006ioo`03001oogoo00Aoo`03001oogoo
00Moo`00:goo0P00;Woo00<007ooOol0>goo00<007ooOol0K7oo00<007ooOol017oo00<007ooOol0
1goo000]Ool2000/Ool00`00Oomoo`2[Ool00`00Oomoo`03Ool00`00Oomoo`07Ool002moo`8002Yo
o`03001oogoo0:]oo`03001oogoo00=oo`03001oogoo00Moo`00<Goo0P00:7oo00<007ooOol0[7oo
00<007ooOol00Woo00<007ooOol01goo000cOol2000VOol00`00Oomoo`2/Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool003Eoo`8002Aoo`03001oogoo03eoo`@006aoo`05001oogooOol00009Ool003Mo
o`03001oogoo025oo`03001oogoo03ioo`03001oo`0006aoo`05001oogooOol00009Ool003Qoo`80
025oo`03001oogoo03eoo`03001oo`0006ioo`04001oogoo0009Ool003Yoo`8001moo`03001oogoo
03eoo`@006eoo`05001oogooOol00008Ool003aoo`8001aoo`03001oogoo0;1oo`04001oogoo0008
Ool003ioo`8001Yoo`03001oogoo0;1oo`04001oogoo0008Ool0041oo`8001Qoo`03001oogoo0;5o
o`03001oo`0000Qoo`00@Woo00<007ooOol05Goo00<007ooOol0/Goo00<007oo000027oo0013Ool2
000EOol00`00Oomoo`2bOol20008Ool004Eoo`8001=oo`03001oogoo0;9oo`8000Qoo`00Agoo0P00
4Goo00<007ooOol0ZWoo2P0027oo0019Ool2000?Ool00`00Oomoo`2HOolB000BOol004]oo`8000eo
o`03001oogoo08Iooa8002Aoo`00CGoo0P002goo00<007ooOol0M7oo4P00=Woo001?Ool00`00Oomo
o`08Ool00`00Oomoo`1ROolB0018Ool0051oo`8000Qoo`03001oogoo04mooa<005Yoo`00DWoo0P00
1Woo00<007ooOol0?Goo4P00KGoo001DOol20004Ool00`00Oomoo`0[OolB001oOol005Ioo`80009o
o`03001oogoo01Uooa80095oo`00F7oo0`002Goo4P00Xgoo001JOol:002eOol00?mooaYoo`00ogoo
6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo0000\
\>"],
  ImageRangeCache->{{{0, 280}, {298, 0}} -> {0.0115781, -0.0255552, 
  0.00318287, 0.00318287}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Inertial Loading "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "No forces are applied to the model with ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because only the inertial loading of the flywheel is being considered. \
All of the inertia properties have already been defined, so all that must be \
done to find the dynamic solution is to request it of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the solution option. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The dynamic solution at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.0, Solution \[Rule] Dynamic] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 0, Y2 \[Rule] 0, Z2 \[Rule] 0, 
      Eo2 \[Rule] 1.00000000000049449`, Ei2 \[Rule] 0, Ej2 \[Rule] 0, 
      Ek2 \[Rule] 0, X2d \[Rule] 0, Y2d \[Rule] 0, Z2d \[Rule] 0, 
      Wx2 \[Rule] 0, Wy2 \[Rule] 6.28318530717958623`, 
      Wz2 \[Rule] 62.8318530717958623`, X2dd \[Rule] 0, Y2dd \[Rule] 0, 
      Z2dd \[Rule] 0, Wx2d \[Rule] 394.784176043574408`, Wy2d \[Rule] 0, 
      Wz2d \[Rule] 0, Lmb1 \[Rule] 0, Lmb2 \[Rule] 0, Lmb3 \[Rule] 0, 
      Lmb4 \[Rule] 4.02279430743526411`*^-9, 
      Lmb5 \[Rule] 1579.13670417331353`, Lmb6 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The angular velocity and acceleration of the flywheel can be read directly \
from the solution rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " output functions can be used. Note that the angular acceleration is \
orthogonal to the angular velocity. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the angular velocity and acceleration of the flywheel."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Chop[{Omega[flywheel], Alpha[flywheel]} /. LastSolve[]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 6.28318530717958623`, 62.8318530717958623`}, {
        394.784176043574408`, 0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"The moment that is applied to the flywheel to enforce the specified rotation \
is the reaction force to constraint 2, the constraint that controls the \
direction of the axis of the flywheel.\n\nNote that the reaction to \
constraint 3 is zero. No moment is required to spin the flywheel about its \
primary axis, only to change the direction of the axis. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the moments that are applied to the flywheel by the constraints. "],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[2, flywheel] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0, 0}, {1579.13670417643681`, 2.54672624300638528`*^-9, 0.`}}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[3, flywheel] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0, 0}, {\(-1.73052625299783695`*^-33\), 0, 
        \(-5.3651968505955061`*^-21\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"As the position of the flywheel is advanced in time, the components of the \
angular velocity change, and the components of the angular acceleration and \
the applied moment follow."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This calculates the dynamic solution at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.01. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SolveMech[0.01, Solution \[Rule] Dynamic]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the angular velocity and acceleration. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({Omega[flywheel], Alpha[flywheel]} /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{3.94524469736798355`, 6.28318530717958445`, 62.7078687623371777`}, {
        394.005159652023184`, 1.14968229676268274`*^-13, 
        \(-24.7887035163615365`\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the applied moment."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[2, Point[flywheel, 1]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0, 0}, {1576.02063901031108`, \(-3.54801159119233489`*^-7\), 
        \(-99.1548140882181705`\)}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph = Graphics3D[{\n(*Ground*)\n   {LocalAxes[1,1.5]},\n(*Mass-Bar*)\n   \
{RGBColor[.75,0,0],PointSize[.08], \n    Vertex[flywheel, {1,2,3,4}], \n    \
LocalAxes[flywheel, .85],\n    Thickness[.01], \n    \
Edge[flywheel,{2,4}],Edge[flywheel,{1,3}]}},\n\
PlotRange\[Rule]{{-1.5,1.5},{-1.5,1.5},{-1.5,1.5}},\n\
ViewPoint\[Rule]{3.035,0.830,1.246}]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[graph/.LastSolve[]];  "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["8.3  Friction and Damping"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section demonstrates various techniques of applying friction and \
damping forces to a mechanism model with ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Types of Friction"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Loads that can be applied to a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model fall into four basic categories with considerable overlap between \
them.\n\nAn applied load is a load in which the magnitude and/or direction \
depends on the configuration of the model, on time, or is constant. Applied \
loads may or may not be conservative. Loads of this type are discussed \
throughout Chapter 7. \n\nA damping load is a nonconservative load in which \
the magnitude and/or direction depends on the velocity of the model. These \
loads are modeled by giving an expression for the load magnitude or direction \
that is functionally dependent on velocity terms, and then using the ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option settings for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nA frictional load is a nonconservative load in which the magnitude \
and/or direction depends on the reaction forces applied by the constraints. \
These loads are modeled by giving an expression for the load magnitude or \
direction that is functionally dependent on the Lagrange multipliers, usually \
by using the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to find the reaction force at a constraint. \n\nAn inertial load \
is a load in which the magnitude and/or direction depends on the linear and \
angular acceleration and angular velocity of bodies in the model. Inertial \
loads are applied to the model automatically by specifying inertia properties \
for each body, and then using the ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option setting for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", as discussed in Section 8.2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Damping"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Damping loads are usually applied to a model in a relatively simple manner. \
To apply linear damping to a point on a moving body, a force is applied to \
the body that is inversely proportional to the velocity of the point. The \
magnitude of the force is proportional to the magnitude of the velocity of \
the point (relative to whatever the point is in contact with) and the \
direction vector of the force is opposite the velocity vector of the point."],
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global velocity vector, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dX/dt, dY/dt, dZ/dt",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The velocity of a point."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The following example shows how damping with a damping constant of 4.0 would \
be applied to a point at local coordinates {1,0,0} on body 2 in a 3D model."],
   "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is an example of an applied damping load. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ld[1] = 
      Force[2, Axis[Point[2, {1, 0, 0}], \(-Velocity[Point[2, {1, 0, 0}]]\)], 
        4.0, Magnitude \[Rule] Relative]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Force", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The line of action of the force passes through ",
  StyleBox["Point[2, {1,0,0}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is not dependent on velocity, and points in the direction of the \
velocity of the point. The negation of the velocity vector causes the applied \
force to oppose the motion of the point, and the ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting causes the magnitude of the force to be 4.0 times the magnitude \
of the velocity vector, instead of a constant magnitude of 4.0.\n\nTo model \
point damping that occurs at an interface between two moving bodies, the \
velocity of the point to which damping is applied must be known relative to \
the body that the point is in contact with. The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["RelativeVelocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function returns this vector quantity."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeVelocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bn",
    FontSlant->"Italic"],
  StyleBox["um, p",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["oint",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dX/dt, dY/dt, dZ/dt",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the global velocity vector of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The velocity of a point relative to another body."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The following example shows how damping that exists between body 2 and body \
3, with a damping constant of 4.0, would be applied to body 2 at local \
coordinates {0,1,0} in a 3D model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a load object that models point damping between two bodies."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ld[1] = 
      Force[2, Axis[Point[2, {0, 1, 0}], 
          \(-RelativeVelocity[3, Point[2, {0, 1, 0}]]\)], 4.0, 
        Magnitude \[Rule] Relative]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Force", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that the preceding example only applies the frictional force to body 2. \
An equal and opposite force should also be applied to body 3."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Friction"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A Coulombic friction load is functionally dependent on reaction forces in \
the model. Such a load is usually applied by making the magnitude of the load \
a function of reaction forces by using the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction force and moment that constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " applies to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", calculated about the specified point."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The reaction load from a constraint."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Coulombic friction forces may also be dependent on velocity terms to \
establish the direction of the frictional force.\n\nThe following example \
shows how the friction of a point sliding on a plane might be modeled. The \
model uses a ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint to place a point on body 2 in contact with a plane on body 3, \
and a coefficient of friction between the point and the plane is 0.3. The \
frictional force would be modeled in the general case by using the velocity \
vector of the point, relative to the plane, to define the direction of the \
force, and the reaction to the constraint times the coefficient of friction \
to define the magnitude. \n\nThe second constraint in the following ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " call is just a dummy constraint to fill out the needed 12 degrees of \
freedom."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a dummy ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " call with a ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      PointOnPlane1[1, Point[2, {1, 0, 0}], 
        Plane[3, {0, 0, 0}, {1, 0, 0}, {1, 1, 1}]], \n\t
      Constraint[2, Table[X2 == 0, {11}]]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The optional second argument of ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used here to apply a force to body 2 and an equal and opposite force \
to body 3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a general method for modeling Coulombic friction on a ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint. The coefficient of friction is 0.3. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Force[2, 3, 
      Axis[Point[2, {1, 0, 0}], 
        \(-RelativeVelocity[3, Point[2, {0, 1, 0}]]\)], 
      0.3\ Magnitude[
          \(Reaction[1, Point[2, {1, 0, 0}]]\)\[LeftDoubleBracket]1
            \[RightDoubleBracket]]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({SysLoad["Force", "<>"], SysLoad["Force", "<>"]}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Damping Example "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the application of damping to a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model, a 2D model of a simple four-bar linkage is developed. The model \
consists of three moving bodies: the drive bar, the driven bar, and the \
center bar. The kinematic input to the model is the rotation of the drive \
bar.\n\nDamping is first applied to the model at a point on the center bar \
that traces out an eccentric path in the 2D plane. Coulombic friction is then \
applied to the rotational axis of the drive bar. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the four-bar mechanism, with a moving point locus. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.20833  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.5 0.208333 0.333333 0.208333 [ 
[(-2)] .08333 0 0 2 Msboxa 
[(-1)] .29167 0 0 2 Msboxa 
[(0)] .5 0 0 2 Msboxa 
[(1)] .70833 0 0 2 Msboxa 
[(2)] .91667 0 0 2 Msboxa 
[(-1)] -0.0125 .125 1 0 Msboxa 
[(0)] -0.0125 .33333 1 0 Msboxa 
[(1)] -0.0125 .54167 1 0 Msboxa 
[(2)] -0.0125 .75 1 0 Msboxa 
[(3)] -0.0125 .95833 1 0 Msboxa 
[(4)] -0.0125 1.16667 1 0 Msboxa 
[ -0.001 -0.001 0 0 ] 
[ 1.001 1.20933 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.08333 0 m 
.08333 .00625 L 
s 
P 
[(-2)] .08333 0 0 2 Mshowa 
p 
.002 w 
.29167 0 m 
.29167 .00625 L 
s 
P 
[(-1)] .29167 0 0 2 Mshowa 
p 
.002 w 
.5 0 m 
.5 .00625 L 
s 
P 
[(0)] .5 0 0 2 Mshowa 
p 
.002 w 
.70833 0 m 
.70833 .00625 L 
s 
P 
[(1)] .70833 0 0 2 Mshowa 
p 
.002 w 
.91667 0 m 
.91667 .00625 L 
s 
P 
[(2)] .91667 0 0 2 Mshowa 
p 
.001 w 
.125 0 m 
.125 .00375 L 
s 
P 
p 
.001 w 
.16667 0 m 
.16667 .00375 L 
s 
P 
p 
.001 w 
.20833 0 m 
.20833 .00375 L 
s 
P 
p 
.001 w 
.25 0 m 
.25 .00375 L 
s 
P 
p 
.001 w 
.33333 0 m 
.33333 .00375 L 
s 
P 
p 
.001 w 
.375 0 m 
.375 .00375 L 
s 
P 
p 
.001 w 
.41667 0 m 
.41667 .00375 L 
s 
P 
p 
.001 w 
.45833 0 m 
.45833 .00375 L 
s 
P 
p 
.001 w 
.54167 0 m 
.54167 .00375 L 
s 
P 
p 
.001 w 
.58333 0 m 
.58333 .00375 L 
s 
P 
p 
.001 w 
.625 0 m 
.625 .00375 L 
s 
P 
p 
.001 w 
.66667 0 m 
.66667 .00375 L 
s 
P 
p 
.001 w 
.75 0 m 
.75 .00375 L 
s 
P 
p 
.001 w 
.79167 0 m 
.79167 .00375 L 
s 
P 
p 
.001 w 
.83333 0 m 
.83333 .00375 L 
s 
P 
p 
.001 w 
.875 0 m 
.875 .00375 L 
s 
P 
p 
.001 w 
.04167 0 m 
.04167 .00375 L 
s 
P 
p 
.001 w 
.95833 0 m 
.95833 .00375 L 
s 
P 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 .125 m 
.00625 .125 L 
s 
P 
[(-1)] -0.0125 .125 1 0 Mshowa 
p 
.002 w 
0 .33333 m 
.00625 .33333 L 
s 
P 
[(0)] -0.0125 .33333 1 0 Mshowa 
p 
.002 w 
0 .54167 m 
.00625 .54167 L 
s 
P 
[(1)] -0.0125 .54167 1 0 Mshowa 
p 
.002 w 
0 .75 m 
.00625 .75 L 
s 
P 
[(2)] -0.0125 .75 1 0 Mshowa 
p 
.002 w 
0 .95833 m 
.00625 .95833 L 
s 
P 
[(3)] -0.0125 .95833 1 0 Mshowa 
p 
.002 w 
0 1.16667 m 
.00625 1.16667 L 
s 
P 
[(4)] -0.0125 1.16667 1 0 Mshowa 
p 
.001 w 
0 .16667 m 
.00375 .16667 L 
s 
P 
p 
.001 w 
0 .20833 m 
.00375 .20833 L 
s 
P 
p 
.001 w 
0 .25 m 
.00375 .25 L 
s 
P 
p 
.001 w 
0 .29167 m 
.00375 .29167 L 
s 
P 
p 
.001 w 
0 .375 m 
.00375 .375 L 
s 
P 
p 
.001 w 
0 .41667 m 
.00375 .41667 L 
s 
P 
p 
.001 w 
0 .45833 m 
.00375 .45833 L 
s 
P 
p 
.001 w 
0 .5 m 
.00375 .5 L 
s 
P 
p 
.001 w 
0 .58333 m 
.00375 .58333 L 
s 
P 
p 
.001 w 
0 .625 m 
.00375 .625 L 
s 
P 
p 
.001 w 
0 .66667 m 
.00375 .66667 L 
s 
P 
p 
.001 w 
0 .70833 m 
.00375 .70833 L 
s 
P 
p 
.001 w 
0 .79167 m 
.00375 .79167 L 
s 
P 
p 
.001 w 
0 .83333 m 
.00375 .83333 L 
s 
P 
p 
.001 w 
0 .875 m 
.00375 .875 L 
s 
P 
p 
.001 w 
0 .91667 m 
.00375 .91667 L 
s 
P 
p 
.001 w 
0 1 m 
.00375 1 L 
s 
P 
p 
.001 w 
0 1.04167 m 
.00375 1.04167 L 
s 
P 
p 
.001 w 
0 1.08333 m 
.00375 1.08333 L 
s 
P 
p 
.001 w 
0 1.125 m 
.00375 1.125 L 
s 
P 
p 
.001 w 
0 .08333 m 
.00375 .08333 L 
s 
P 
p 
.001 w 
0 .04167 m 
.00375 .04167 L 
s 
P 
p 
.001 w 
0 0 m 
.00375 0 L 
s 
P 
p 
.001 w 
0 1.20833 m 
.00375 1.20833 L 
s 
P 
p 
.002 w 
0 0 m 
0 1.20833 L 
s 
P 
P 
p 
p 
.002 w 
.08333 1.20208 m 
.08333 1.20833 L 
s 
P 
p 
.002 w 
.29167 1.20208 m 
.29167 1.20833 L 
s 
P 
p 
.002 w 
.5 1.20208 m 
.5 1.20833 L 
s 
P 
p 
.002 w 
.70833 1.20208 m 
.70833 1.20833 L 
s 
P 
p 
.002 w 
.91667 1.20208 m 
.91667 1.20833 L 
s 
P 
p 
.001 w 
.125 1.20458 m 
.125 1.20833 L 
s 
P 
p 
.001 w 
.16667 1.20458 m 
.16667 1.20833 L 
s 
P 
p 
.001 w 
.20833 1.20458 m 
.20833 1.20833 L 
s 
P 
p 
.001 w 
.25 1.20458 m 
.25 1.20833 L 
s 
P 
p 
.001 w 
.33333 1.20458 m 
.33333 1.20833 L 
s 
P 
p 
.001 w 
.375 1.20458 m 
.375 1.20833 L 
s 
P 
p 
.001 w 
.41667 1.20458 m 
.41667 1.20833 L 
s 
P 
p 
.001 w 
.45833 1.20458 m 
.45833 1.20833 L 
s 
P 
p 
.001 w 
.54167 1.20458 m 
.54167 1.20833 L 
s 
P 
p 
.001 w 
.58333 1.20458 m 
.58333 1.20833 L 
s 
P 
p 
.001 w 
.625 1.20458 m 
.625 1.20833 L 
s 
P 
p 
.001 w 
.66667 1.20458 m 
.66667 1.20833 L 
s 
P 
p 
.001 w 
.75 1.20458 m 
.75 1.20833 L 
s 
P 
p 
.001 w 
.79167 1.20458 m 
.79167 1.20833 L 
s 
P 
p 
.001 w 
.83333 1.20458 m 
.83333 1.20833 L 
s 
P 
p 
.001 w 
.875 1.20458 m 
.875 1.20833 L 
s 
P 
p 
.001 w 
.04167 1.20458 m 
.04167 1.20833 L 
s 
P 
p 
.001 w 
.95833 1.20458 m 
.95833 1.20833 L 
s 
P 
p 
.002 w 
0 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
.99375 .125 m 
1 .125 L 
s 
P 
p 
.002 w 
.99375 .33333 m 
1 .33333 L 
s 
P 
p 
.002 w 
.99375 .54167 m 
1 .54167 L 
s 
P 
p 
.002 w 
.99375 .75 m 
1 .75 L 
s 
P 
p 
.002 w 
.99375 .95833 m 
1 .95833 L 
s 
P 
p 
.002 w 
.99375 1.16667 m 
1 1.16667 L 
s 
P 
p 
.001 w 
.99625 .16667 m 
1 .16667 L 
s 
P 
p 
.001 w 
.99625 .20833 m 
1 .20833 L 
s 
P 
p 
.001 w 
.99625 .25 m 
1 .25 L 
s 
P 
p 
.001 w 
.99625 .29167 m 
1 .29167 L 
s 
P 
p 
.001 w 
.99625 .375 m 
1 .375 L 
s 
P 
p 
.001 w 
.99625 .41667 m 
1 .41667 L 
s 
P 
p 
.001 w 
.99625 .45833 m 
1 .45833 L 
s 
P 
p 
.001 w 
.99625 .5 m 
1 .5 L 
s 
P 
p 
.001 w 
.99625 .58333 m 
1 .58333 L 
s 
P 
p 
.001 w 
.99625 .625 m 
1 .625 L 
s 
P 
p 
.001 w 
.99625 .66667 m 
1 .66667 L 
s 
P 
p 
.001 w 
.99625 .70833 m 
1 .70833 L 
s 
P 
p 
.001 w 
.99625 .79167 m 
1 .79167 L 
s 
P 
p 
.001 w 
.99625 .83333 m 
1 .83333 L 
s 
P 
p 
.001 w 
.99625 .875 m 
1 .875 L 
s 
P 
p 
.001 w 
.99625 .91667 m 
1 .91667 L 
s 
P 
p 
.001 w 
.99625 1 m 
1 1 L 
s 
P 
p 
.001 w 
.99625 1.04167 m 
1 1.04167 L 
s 
P 
p 
.001 w 
.99625 1.08333 m 
1 1.08333 L 
s 
P 
p 
.001 w 
.99625 1.125 m 
1 1.125 L 
s 
P 
p 
.001 w 
.99625 .08333 m 
1 .08333 L 
s 
P 
p 
.001 w 
.99625 .04167 m 
1 .04167 L 
s 
P 
p 
.001 w 
.99625 0 m 
1 0 L 
s 
P 
p 
.001 w 
.99625 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
1 0 m 
1 1.20833 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 1.20833 L 
0 1.20833 L 
closepath 
clip 
newpath 
p 
p 
p 
.025 w 
.08333 .95833 Mdot 
.015 w 
.29167 .02083 m 
.5 .33333 L 
.70833 .02083 L 
.08333 .02083 L 
.08333 .95833 L 
s 
P 
p 
1 0 0 r 
p 
.015 w 
.55208 .24312 m 
.70833 .33333 L 
s 
.70833 .33333 m 
.55208 .42354 L 
s 
P 
.015 w 
newpath 
.5 .33333 .10417 0 365.73 arc 
s 
P 
p 
0 0 1 r 
p 
.015 w 
.08333 .95833 m 
.70833 .95833 L 
s 
P 
P 
p 
p 
.025 w 
.70833 .33333 Mdot 
.70833 .95833 Mdot 
.91667 .75 Mdot 
P 
0 1 0 r 
p 
.70833 .33333 m 
.70833 .95833 L 
.91667 .75 L 
F 
P 
P 
P 
.004 w 
.91667 .75 m 
.91104 .81206 L 
.8952 .86278 L 
.87212 .89517 L 
.84594 .9026 L 
.82031 .87992 L 
.79638 .8262 L 
.77265 .74866 L 
.7489 .66256 L 
.72906 .58351 L 
.7183 .5204 L 
.71923 .47588 L 
.73138 .44978 L 
.75254 .44118 L 
.77988 .44904 L 
.81056 .47222 L 
.84186 .50939 L 
.871 .55879 L 
.89504 .61796 L 
.91104 .68331 L 
.91667 .75 L 
s 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{220, 266},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L00012Q000`40O003h00Og7oo003LOol00=ao
o`00g7oo000OOol3000WOol5000UOol00`00Oomoo`0UOol5000WOol3000BOol001moo`03001oogoo
02Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001oogoo02Moo`03001oogoo019oo`006Woo0`00
0goo00<007ooOol08Woo0`000goo00<007ooOol097oo00<007oo0000:7oo00<007ooOol0:7oo00<0
07ooOol04Goo000POol00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Ool0000XOol00`00Oomoo`0X
Ool00`00Oomoo`0AOol001moo`03001oo`0002Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001o
ogoo02Moo`03001oo`00019oo`0087oo00<007ooOol09goo0P009goo00<007ooOol09Woo0P00:Woo
00<007ooOol04Goo003LOol00=aoo`00g7oo003LOol00=aoo`00g7oo003LOol00=aoo`003Gooc@00
0Woo000=Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool10001
Ool1Ool000eoo`03001oogoo00ioo`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo02Qoo`03
001oogoo02Moo`03001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=
Ool00`00Oomoo`0=Oon3000iOol10001Ool1Ool000eoo`03001oogoo00eooh<003Uoo`40005oo`5o
o`003Goo00<007ooOol03GooP`00>Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000YOol4001>
Ool4000jOol10001Ool1Ool000eoo`03001oogoo00eoo`<002Yoo`<004ioo`<003]oo`40005oo`5o
o`003Goo0P003Woo0`00:Woo1000C7oo1000>goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000[
Ool4001:Ool4000lOol10001Ool1Ool000eoo`03001oogoo00eoo`<002aoo`<004Yoo`<003eoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00;7oo1000B7oo1000?Goo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3000]Ool40016Ool4000nOol10001Ool1Ool000eoo`03001oogoo00eoo`<002ioo`<0
04Ioo`<003moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00;Woo1000A7oo1000?goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3000_Ool40012Ool40010Ool10001Ool1Ool000eoo`03001oogoo
00eoo`<0031oo`<0049oo`<0045oo`40005oo`5oo`003Goo0P003Woo0`00<7oo1000@7oo1000@Goo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000aOol4000nOol40012Ool10001Ool1Ool000eoo`03
001oogoo00eoo`<0039oo`<003ioo`<004=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00<Woo
1000?7oo1000@goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000cOol3000kOol40014Ool10001
Ool1Ool000eoo`03001oogoo00eoo`<003=oo`@003Yoo`<004Eoo`40005oo`5oo`001Woo1@000Woo
00<007ooOol03Goo0`00=7oo1000>7oo1000AGoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool3000eOol3000gOol40016Ool10001Ool1Ool0009oo`<000=oo`03001oogoo009oo`80
00ioo`<003Eoo`@003Ioo`<004Ioo`80009oo`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00
=Woo1000=7oo1000Agoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3000gOol3
000cOol40018Ool10001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<003Moo`@0039oo`<004Uo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00>7oo1000<7oo1000BGoo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3000iOol3000_Ool4001:Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003Uo
o`@002ioo`<004]oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00>Woo1000;7oo1000Bgoo0@00
0Goo0Goo000=Ool00`00Oomoo`0=Ool3000kOol3000[Ool4001<Ool10001Ool1Ool000eoo`8000io
o`<003]oo`@002Yoo`<004eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?7oo1000:7oo1000
CGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000mOol3000WOol4001>Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<003eoo`@002Eoo`@004moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
?Woo100097oo0`00D7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol3000SOol4001@Ool1
0001Ool1Ool000eoo`03001oogoo00eoo`<003moo`@0025oo`@0055oo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00@7oo100087oo0`00DWoo0@000Goo0Goo000=Ool2000>Ool30011Ool3000OOol4
001BOol10001Ool1Ool000eoo`03001oogoo00eoo`<0045oo`@001eoo`@005=oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00@Woo100077oo0`00E7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0013Ool30009Ool8O00:Ool4001DOol10001Ool1Ool000eoo`03001oogoo00eoo`<004=oo`@000=o
oa5l00Eoo`@005Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00A7oo100000=oog`0O0004W`0
0goo0`00EWoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30015Ool20009O006Ool:O003001FOol1
0001Ool1Ool000eoo`03001oogoo00eoo`<004Eoo`03001l07`000Al00ioo`Ml0003001oogoo05Eo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00AGoo1W`04Goo1g`0EWoo0@000Goo0Goo000=Ool2
000>Ool30014Ool5O0000`00Oomoo`0AOol00`00O01l0005O01DOol10001Ool1Ool000eoo`03001o
ogoo00eoo`<004=oo`Al00@0015oo`<000Ql059oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
@Woo17`00Woo0`004Goo0`0000=oog`0O0001W`0DGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0011Ool4O003Ool4000?Ool40002Ool9O01?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0041o
o`Al00Eoo`@000eoo`@000Aoo`Yl04eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?goo17`0
1goo0`003Goo0`001Woo2W`0C7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol4O007Ool4
000;Ool40007Ool4O0000gooO01l0004O01:Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003mo
o`=l00Uoo`@000Uoo`@000Uoo`Al009oo`Il04Qoo`40005oo`5oo`003Goo0P003Woo0`00?Woo17`0
2Woo0`002Goo0`002goo0g`00goo1W`0Agoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000nOol3
O00;Ool40007Ool4000;Ool4O004Ool6O015Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003io
o`=l00aoo`@000Eoo`@000eoo`=l00Ioo`Il04=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
?Woo0g`03Goo0`001Goo0`003Woo0g`01goo1W`0@Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
000mOol4O00=Ool40003Ool4000>Ool3O009Ool6O010Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<003eoo`=l00moo`@00003Ool00000008000moo`=l00]oo`Il03ioo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00?Goo0g`047oo0`0000Aoo`000000011oo`=l00aoo`Ml03aoo`40005oo`5oo`00
27oo00<007ooOol00Woo00<007ooOol03Goo0`00?Goo0g`047oo1`0047oo0g`03Woo1W`0>goo0@00
0Goo0Goo0007Ool00`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00AOol5000AOol3O00@Ool3
O00200000g`0Oomoo`0gOol10001Ool1Ool000Moo`03001oo`0000=oo`8000ioo`<003eoo`=l019o
o`<0019oo`=l015oo`03O0000000008003Qoo`80009oo`001goo00<007oo00000goo00<007ooOol0
3Goo0`00?Goo0g`04Woo0`004Woo0g`047oo0W`00P0000<3h000Ool0>7oo0@000Goo0Goo0007Ool0
0`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00WOol3O00>Ool5O0000`000n1oo`0iOol10001
Ool1Ool000Qoo`03001oogoo009oo`03001oogoo00eoo`<003eoo`=l02Moo`=l00aoo`Il009oo`83
h3Uoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?Goo17`09Woo0g`02Woo1g`00goo0P?P>Goo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000nOol3O00VOol3O008Ool7O005Ool30n0hOol10001
Ool1Ool000eoo`03001oogoo00eoo`<003ioo`=l02Ioo`=l00Moo`Il00Moo`<3h3Qoo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00?Woo0g`09Goo17`01Goo1W`02Goo10?P=goo0@000Goo0Goo000=
Ool2000>Ool3000nOol4O00TOol3O004Ool6O00;Ool40n0gOol10001Ool1Ool000eoo`03001oogoo
00eoo`<003moo`=l02=oo`Al009oo`Ml00aoo`D3h3Ioo`40005oo`5oo`003Goo00<007ooOol03Goo
0`00?goo17`08Woo0g`00Woo1W`03Woo1@?P=Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000o
Ool4O00QOol:O00@Ool60n0eOol10001Ool1Ool000eoo`03001oogoo00eoo`<0041oo`Al01ioo`Yl
019oo`H3h3Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@Goo1G`077oo2G`04goo1`?P=7oo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30012Ool4O00JOol9O00EOol70n0dOol10001Ool1Ool0
00eoo`03001oogoo00eoo`<004=oo`Al01Qoo`Ql01Moo`P3h3=oo`40005oo`5oo`003Goo00<007oo
Ool03Goo0`00A7oo1G`05Goo1g`06Goo20?P<goo0@000Goo0Goo000=Ool2000>Ool30014Ool7O00B
Ool6O00KOol90n0bOol10001Ool1Ool000eoo`03001oogoo00eoo`<004Ioo`Il00ioo`Ql01aoo`T3
h39oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00B7oo27`027oo27`07Woo2P?P<Goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool30019OolFO00OOol:0n0aOol10001Ool1Ool000eoo`03001oogoo
00eoo`<004Yooa5l02=oo`/3h31oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Cgoo2W`09Goo
1`?P1@00;goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol40n0300050n03000/Ool10001
Ool1Ool000eoo`03001oogoo00eoo`<007ioo`@3h0030003h0?P00D3h0=oo`8002Yoo`40005oo`5o
o`003Goo0P003Woo0`00OWoo0`?P00<000?P0n001`?P17oo00<007ooOol09goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001nOol30n000`000n03h0070n05Ool00`00Oomoo`0VOol10001Ool1Ool0
00eoo`03001oogoo00eoo`<007ioo`<3h0030003h0?P00P3h0Eoo`8002Ioo`40005oo`5oo`003Goo
00<007ooOol03Goo0`00OWoo0P?P00<000?P0n002@?P1goo00<007ooOol08goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00:0n07Ool00`00Oomoo`0ROol10001Ool1Ool0
00eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00X3h0Moo`03001oogoo029oo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00OWoo0P?P00<000?P0n002`?P1goo00<007ooOol08Goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00;0n08Ool00`00Oomoo`0POol10001
Ool1Ool000eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00`3h0Qoo`03001oogoo01moo`40
005oo`5oo`003Goo0P003Woo0`00OWoo0P?P00<000?P0n0030?P27oo00<007ooOol07goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00=0n08Ool00`00Oomoo`0NOol10001
Ool1Ool000eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00d3h0Uoo`03001oogoo01eoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo0P?P00<000?P0n003P?P2Goo00<007ooOol077oo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol20n000`000n03h00>0n09Ool00`00Oomoo`0L
Ool10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`83h0030003h0?P00l3h0Uoo`03001oogoo
01]oo`40005oo`5oo`001Woo1@000Woo00<007ooOol03Goo0`00OWoo0P?P00<000?P0n003`?P2Goo
00<007ooOol06goo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3001nOol20n00
0`000n03h00@0n09Ool00`00Oomoo`0JOol10001Ool1Ool000Qoo`03001oogoo009oo`8000ioo`<0
07ioo`<3h0030003h0?P00l3h0Yoo`03001oogoo01Qoo`80009oo`0027oo00<007ooOol00Woo00<0
07ooOol03Goo0`00OWoo0`?P00<000?P0n0040?P2Goo00<007ooOol06Goo0@000Goo0Goo0008Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool3001nOol30n000`000n03h00@0n0:Ool00`00Oomoo`0HOol1
0001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<007ioo`<3h0030003h0?P0143h0Uoo`03001o
ogoo01Qoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo0`?P00<000?P0n004@?P2Woo00<0
07ooOol05goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol30n000`000n03h00B0n09Ool0
0`00Oomoo`0GOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`@3h0030003h0?P0143h0Yo
o`03001oogoo01Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo10?P00<000?P0n004P?P
2Goo00<007ooOol05Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol40n000`000n03h00B
0n0:Ool00`00Oomoo`0EOol10001Ool1Ool000eoo`8000ioo`<007ioo`@3h0030003h0?P01<3h0Uo
o`03001oogoo01Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo10?P00<000?P0n004`?P
2Goo00<007ooOol05Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol40n000`000n03h00D
0n09Ool00`00Oomoo`0DOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`D3h0030003h0?P
01<3h0Uoo`03001oogoo01Aoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo1@?P00<000?P
0n0050?P2Goo00<007ooOol04goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol50n000`00
0n03h00D0n09Ool00`00Oomoo`0COol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`D3h003
0003h0?P01D3h0Uoo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo1P?P
00<000?P0n0050?P2Goo00<007ooOol04Woo0@000Goo0Goo000=Ool2000>Ool3001nOol60n000`00
0n03h00E0n08Ool00`00Oomoo`0BOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`H3h003
0003h0?P01D3h0Qoo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo1P?P
00<000?P0n005P?P27oo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001nOol7
0n000`000n03h00E0n08Ool00`00Oomoo`0AOol10001Ool1Ool000eoo`03001oogoo00eoo`<007io
o`L3h0030003h0?P01H3h0Moo`03001oogoo015oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
OWoo1`?P00<000?P0n005P?P1goo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
001nOol70n000`000n03h00G0n07Ool00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<007ioo`P3h0030003h0?P01H3h0Moo`03001oogoo011oo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo20?P00<000?P0n005`?P1Woo00<007ooOol047oo0@000Goo0Goo000=Ool2000>Ool3
001nOol80n000`000n03h00G0n06Ool00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<007ioo`T3h0030003h0?P01L3h0Ioo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo2@?P00<000?P0n005`?P1Woo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001nOol90n000`000n03h00H0n05Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001o
ogoo00eoo`<007ioo`T3h0030003h0?P01P3h0Eoo`03001oogoo00moo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00OWoo2P?P00<000?P0n0060?P17oo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001nOol:0n000`000n03h00H0n04Ool00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<007ioo`X3h0030003h0?P01T3h0=oo`03001oogoo00moo`40005oo`5oo`00
3Goo0P003Woo0`00OWoo2`?P00<000?P0n0060?P0goo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001nOol;0n000`000n03h00I0n02Ool00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<007ioo`/3h0030003h0?P01T3h09oo`03001oogoo00moo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo30?P00<000?P0n006@?P0Woo00<007ooOol03Woo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOol<0n000`000n03h00I0n02Ool00`00Oomoo`0>Ool10001Ool1
Ool000eoo`03001oogoo00eoo`<007ioo``3h0030003h0?P01X3h003Ool007oo00moo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00OWoo30?P00<000?P0n006P?P00=oo`00Ool03goo0@000Goo0Goo
0007Ool30003Ool00`00Oomoo`0=Ool3001nOol=0n000`000n03h00J0n000`00Oomoo`0>Ool10001
Ool1Ool000Moo`03001oogoo00=oo`03001oogoo00eoo`<007ioo`d3h0030003h0?P01X3h003001o
ogoo00ioo`40005oo`5oo`0027oo00<007ooOol00Woo0P003Woo0`00OWoo3@?P00<000?P0n006P?P
0P003Woo0P000Woo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3001nOol>0n000`000n03h00H
0n03000?Ool10001Ool1Ool000Moo`03001oo`0000=oo`03001oogoo00eoo`<007ioo`h3h0030003
h0?P01L3h003Ool00000011oo`40005oo`5oo`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00
OWoo3P?P00<000?P0n005P?P0goo00<007ooOol03Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
001nOol?0n000`000n03h00D0n04Ool00`00Oomoo`0>Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<007ioo`l3h0030003h0?P01<3h0Eoo`03001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo3`?P00<000?P0n004P?P1Goo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001nOol?0n000`000n03h00A0n06Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`8000io
o`<007iooa03h0030003h0?P00l3h0Moo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00OWoo40?P00<000?P0n003P?P27oo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001nOol@0n000`000n03h00=0n09Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001o
ogoo00eoo`<007iooa43h0030003h0?P00/3h0Yoo`03001oogoo00moo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00OWoo4@?P00<000?P0n002P?P2goo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001nOolA0n000`000n03h0090n0<Ool00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<007iooa83h0030003h0?P00L3h0aoo`03001oogoo011oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo4P?P00<000?P0n001P?P3Goo00<007ooOol047oo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOolB0n000`000n03h0050n0>Ool00`00Oomoo`0@Ool10001Ool1
Ool000eoo`8000ioo`<007iooa<3h0030003h0?P00<3h0moo`03001oogoo011oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo4`?P00<000?P0n000P?P3goo00<007ooOol04Goo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOolD0n000`000n03h00@Ool00`00Oomoo`0AOol10001Ool1Ool0
00eoo`03001oogoo00eoo`<007iooa@3h0030003h7oo011oo`03001oogoo015oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo5@?P00<007ooOol03goo00<007ooOol04Goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001nOolD0n000goo001oo`0?Ool00`00Oomoo`0BOol10001Ool1Ool000eo
o`03001oogoo00eoo`<007iooa<3h0=oo`03001oogoo00eoo`03001oogoo019oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo4P?P17oo00<007ooOol037oo00<007ooOol04goo0@000Goo0Goo
000=Ool2000>Ool3001nOolA0n06Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol10001Ool1Ool000eo
o`03001oogoo00eoo`<007iooa03h0Moo`03001oogoo00Uoo`03001oogoo01Eoo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo3`?P2Goo00<007ooOol027oo00<007ooOol05Goo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001nOol>0n0;Ool00`00Oomoo`06Ool00`00Oomoo`0FOol10001Ool1
Ool000eoo`03001oogoo00eoo`<007ioo`d3h0eoo`03001oogoo00=oo`8001Uoo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00OWoo30?P3goo00<007ooOol00P006goo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3001nOol;0n0AOol2000MOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`X3
h35oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00OWoo2@?P<Woo0@000Goo0Goo000=Ool2000>
Ool3001nOol80n0cOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`L3h3Aoo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00OWoo1P?P=Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001n
Ool50n0fOol10001Ool1Ool000eoo`03001oogoo00eoo`<007ioo`@3h3Moo`40005oo`5oo`003Goo
00<007ooOol03Goo0`00OWoo0`?P>7oo0@000Goo0Goo0007Ool20004Ool00`00Oomoo`0=Ool3001n
Ool20n0iOol10001Ool1Ool000Uoo`05001oogooOol0000?Oon001l00`000n007`0iOol10001Ool1
Ool000Qoo`03001oogoo009oo`8000eoo`0300007`0O07d07`@003Qoo`80009oo`002Goo00D007oo
Oomoo`0000ioo`0300007`0O07d07`@003Uoo`40005oo`5oo`001goo00<007oo00000goo00<007oo
Ool03Goo0P00OWoo0P00>Woo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`39Ool10001
Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=
Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007oo
Ool0bGoo0@000Goo0Goo000=Ool2003:Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5o
o`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03
001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39
Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo0P00bWoo0@000Goo0Goo000=
Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007oo
Ool0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40
005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool0
00eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo0P00bWoo0@000Goo0Goo000=Ool00`00Oomoo`39
Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo
0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo
00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`800<Yoo`40
005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool0
00eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00
Oomoo`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`0027oo0`000Woo00<007oo
Ool0bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo0007Ool40002Ool20039
Ool20002Ool000Moo`03001oo`0000=oo`03001oogoo0<Uoo`40005oo`5oo`0027oo0P000goo00<0
07ooOol0bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo000=Ool00`00Oomo
o`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@00
0Goo0Goo000=Ool00`00Oomoo`0>Ool00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0XOol0
0`00Oomoo`0WOol00`00Oomoo`0>Ool10001Ool1Ool000eoold0009oo`00\
\>"],
  ImageRangeCache->{{{0, 219}, {265, 0}} -> {-2.71851, -2.02306, 0.0235014, 
  0.0235014}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Four body objects are required for the four-bar model. Each bar is \
attached to another bar at its local origin and at a point at the other end \
of the bar on the local ",
  StyleBox["X",
    FontSlant->"Italic"],
  " or ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axis."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(drivebar = 2; \)\), 
    \(\(drivenbar = 3; \)\), 
    \(\(centerbar = 4; \)\), 
    \(On[General::"\<spell1\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the body objects for the four-bar model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(bd[ground] = Body[ground, PointList \[Rule] {{\(-2\), 3}}]; \)\), 
    \(\(bd[drivebar] = Body[drivebar, PointList \[Rule] {{1, 0}}]; \)\), 
    \(\(bd[drivenbar] = 
      Body[drivenbar, PointList \[Rule] {{3, 0}}, 
        InitialGuess \[Rule] {{\(-2\), 3}, 0}]; \)\), 
    \(\(bd[centerbar] = 
      Body[centerbar, \n\t\tPointList \[Rule] {{0, 3}, {1, 2}}, 
        InitialGuess \[Rule] {{1, 0}, 0}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The body properties are incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[drivebar], bd[drivenbar], bd[centerbar]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Five constraints, one of which is a driving constraint, are required to \
model the four-bar mechanism. A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used as a driving constraint to rotate the drive bar. Four \
",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints model the four pivot points in the four-bar mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the four-bar."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(cs[1] = RotationLock1[1, drivebar, 2.0  \[Pi]\ T]; \n
    cs[2] = Revolute2[2, \n\t\tPoint[drivebar, 0], Point[ground, 0]]; \n
    cs[3] = Revolute2[3, \n\t\tPoint[drivenbar, 0], Point[ground, 1]]; \n
    cs[4] = Revolute2[4, \n\t\tPoint[drivebar, 1], Point[centerbar, 0]]; \n
    cs[5] = Revolute2[5, \n\t\tPoint[drivenbar, 1], Point[centerbar, 1]]; \)],
   "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The constraints are incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs[1], cs[2], cs[3], cs[4], cs[5]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Damping Load "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A damping force is applied to point 2 on the center bar relative to the \
ground. The direction of the frictional force opposes the global velocity of \
point 2, and the coefficient of damping is 5.0."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a damping load."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ld[1] = 
      Force[centerbar, 
        Axis[Point[centerbar, 2], \(-Velocity[centerbar, 2]\)], 5.0, 
        Magnitude \[Rule] Relative]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The load is incorporated into the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because of the presence of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the driving constraint ",
  StyleBox["cs[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the model can be run through its intended range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the angle of rotation of the drive bar in revolutions. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.3]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.3`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 1.88495559215387586`\), ",", 
        \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
        \(Th3 \[Rule] 0.231291243186026607`\), ",", 
        \(X4 \[Rule] \(-0.309016994374947362`\)\), ",", 
        \(Y4 \[Rule] 0.951056516295153642`\), ",", 
        \(Th4 \[Rule] \(-0.422136359279569184`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the four-bar model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: 1.20833  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.5 0.208333 0.333333 0.208333 [ 
[(-2)] .08333 0 0 2 Msboxa 
[(-1)] .29167 0 0 2 Msboxa 
[(0)] .5 0 0 2 Msboxa 
[(1)] .70833 0 0 2 Msboxa 
[(2)] .91667 0 0 2 Msboxa 
[(-1)] -0.0125 .125 1 0 Msboxa 
[(0)] -0.0125 .33333 1 0 Msboxa 
[(1)] -0.0125 .54167 1 0 Msboxa 
[(2)] -0.0125 .75 1 0 Msboxa 
[(3)] -0.0125 .95833 1 0 Msboxa 
[(4)] -0.0125 1.16667 1 0 Msboxa 
[ -0.001 -0.001 0 0 ] 
[ 1.001 1.20933 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.08333 0 m 
.08333 .00625 L 
s 
P 
[(-2)] .08333 0 0 2 Mshowa 
p 
.002 w 
.29167 0 m 
.29167 .00625 L 
s 
P 
[(-1)] .29167 0 0 2 Mshowa 
p 
.002 w 
.5 0 m 
.5 .00625 L 
s 
P 
[(0)] .5 0 0 2 Mshowa 
p 
.002 w 
.70833 0 m 
.70833 .00625 L 
s 
P 
[(1)] .70833 0 0 2 Mshowa 
p 
.002 w 
.91667 0 m 
.91667 .00625 L 
s 
P 
[(2)] .91667 0 0 2 Mshowa 
p 
.001 w 
.125 0 m 
.125 .00375 L 
s 
P 
p 
.001 w 
.16667 0 m 
.16667 .00375 L 
s 
P 
p 
.001 w 
.20833 0 m 
.20833 .00375 L 
s 
P 
p 
.001 w 
.25 0 m 
.25 .00375 L 
s 
P 
p 
.001 w 
.33333 0 m 
.33333 .00375 L 
s 
P 
p 
.001 w 
.375 0 m 
.375 .00375 L 
s 
P 
p 
.001 w 
.41667 0 m 
.41667 .00375 L 
s 
P 
p 
.001 w 
.45833 0 m 
.45833 .00375 L 
s 
P 
p 
.001 w 
.54167 0 m 
.54167 .00375 L 
s 
P 
p 
.001 w 
.58333 0 m 
.58333 .00375 L 
s 
P 
p 
.001 w 
.625 0 m 
.625 .00375 L 
s 
P 
p 
.001 w 
.66667 0 m 
.66667 .00375 L 
s 
P 
p 
.001 w 
.75 0 m 
.75 .00375 L 
s 
P 
p 
.001 w 
.79167 0 m 
.79167 .00375 L 
s 
P 
p 
.001 w 
.83333 0 m 
.83333 .00375 L 
s 
P 
p 
.001 w 
.875 0 m 
.875 .00375 L 
s 
P 
p 
.001 w 
.04167 0 m 
.04167 .00375 L 
s 
P 
p 
.001 w 
.95833 0 m 
.95833 .00375 L 
s 
P 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 .125 m 
.00625 .125 L 
s 
P 
[(-1)] -0.0125 .125 1 0 Mshowa 
p 
.002 w 
0 .33333 m 
.00625 .33333 L 
s 
P 
[(0)] -0.0125 .33333 1 0 Mshowa 
p 
.002 w 
0 .54167 m 
.00625 .54167 L 
s 
P 
[(1)] -0.0125 .54167 1 0 Mshowa 
p 
.002 w 
0 .75 m 
.00625 .75 L 
s 
P 
[(2)] -0.0125 .75 1 0 Mshowa 
p 
.002 w 
0 .95833 m 
.00625 .95833 L 
s 
P 
[(3)] -0.0125 .95833 1 0 Mshowa 
p 
.002 w 
0 1.16667 m 
.00625 1.16667 L 
s 
P 
[(4)] -0.0125 1.16667 1 0 Mshowa 
p 
.001 w 
0 .16667 m 
.00375 .16667 L 
s 
P 
p 
.001 w 
0 .20833 m 
.00375 .20833 L 
s 
P 
p 
.001 w 
0 .25 m 
.00375 .25 L 
s 
P 
p 
.001 w 
0 .29167 m 
.00375 .29167 L 
s 
P 
p 
.001 w 
0 .375 m 
.00375 .375 L 
s 
P 
p 
.001 w 
0 .41667 m 
.00375 .41667 L 
s 
P 
p 
.001 w 
0 .45833 m 
.00375 .45833 L 
s 
P 
p 
.001 w 
0 .5 m 
.00375 .5 L 
s 
P 
p 
.001 w 
0 .58333 m 
.00375 .58333 L 
s 
P 
p 
.001 w 
0 .625 m 
.00375 .625 L 
s 
P 
p 
.001 w 
0 .66667 m 
.00375 .66667 L 
s 
P 
p 
.001 w 
0 .70833 m 
.00375 .70833 L 
s 
P 
p 
.001 w 
0 .79167 m 
.00375 .79167 L 
s 
P 
p 
.001 w 
0 .83333 m 
.00375 .83333 L 
s 
P 
p 
.001 w 
0 .875 m 
.00375 .875 L 
s 
P 
p 
.001 w 
0 .91667 m 
.00375 .91667 L 
s 
P 
p 
.001 w 
0 1 m 
.00375 1 L 
s 
P 
p 
.001 w 
0 1.04167 m 
.00375 1.04167 L 
s 
P 
p 
.001 w 
0 1.08333 m 
.00375 1.08333 L 
s 
P 
p 
.001 w 
0 1.125 m 
.00375 1.125 L 
s 
P 
p 
.001 w 
0 .08333 m 
.00375 .08333 L 
s 
P 
p 
.001 w 
0 .04167 m 
.00375 .04167 L 
s 
P 
p 
.001 w 
0 0 m 
.00375 0 L 
s 
P 
p 
.001 w 
0 1.20833 m 
.00375 1.20833 L 
s 
P 
p 
.002 w 
0 0 m 
0 1.20833 L 
s 
P 
P 
p 
p 
.002 w 
.08333 1.20208 m 
.08333 1.20833 L 
s 
P 
p 
.002 w 
.29167 1.20208 m 
.29167 1.20833 L 
s 
P 
p 
.002 w 
.5 1.20208 m 
.5 1.20833 L 
s 
P 
p 
.002 w 
.70833 1.20208 m 
.70833 1.20833 L 
s 
P 
p 
.002 w 
.91667 1.20208 m 
.91667 1.20833 L 
s 
P 
p 
.001 w 
.125 1.20458 m 
.125 1.20833 L 
s 
P 
p 
.001 w 
.16667 1.20458 m 
.16667 1.20833 L 
s 
P 
p 
.001 w 
.20833 1.20458 m 
.20833 1.20833 L 
s 
P 
p 
.001 w 
.25 1.20458 m 
.25 1.20833 L 
s 
P 
p 
.001 w 
.33333 1.20458 m 
.33333 1.20833 L 
s 
P 
p 
.001 w 
.375 1.20458 m 
.375 1.20833 L 
s 
P 
p 
.001 w 
.41667 1.20458 m 
.41667 1.20833 L 
s 
P 
p 
.001 w 
.45833 1.20458 m 
.45833 1.20833 L 
s 
P 
p 
.001 w 
.54167 1.20458 m 
.54167 1.20833 L 
s 
P 
p 
.001 w 
.58333 1.20458 m 
.58333 1.20833 L 
s 
P 
p 
.001 w 
.625 1.20458 m 
.625 1.20833 L 
s 
P 
p 
.001 w 
.66667 1.20458 m 
.66667 1.20833 L 
s 
P 
p 
.001 w 
.75 1.20458 m 
.75 1.20833 L 
s 
P 
p 
.001 w 
.79167 1.20458 m 
.79167 1.20833 L 
s 
P 
p 
.001 w 
.83333 1.20458 m 
.83333 1.20833 L 
s 
P 
p 
.001 w 
.875 1.20458 m 
.875 1.20833 L 
s 
P 
p 
.001 w 
.04167 1.20458 m 
.04167 1.20833 L 
s 
P 
p 
.001 w 
.95833 1.20458 m 
.95833 1.20833 L 
s 
P 
p 
.002 w 
0 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
.99375 .125 m 
1 .125 L 
s 
P 
p 
.002 w 
.99375 .33333 m 
1 .33333 L 
s 
P 
p 
.002 w 
.99375 .54167 m 
1 .54167 L 
s 
P 
p 
.002 w 
.99375 .75 m 
1 .75 L 
s 
P 
p 
.002 w 
.99375 .95833 m 
1 .95833 L 
s 
P 
p 
.002 w 
.99375 1.16667 m 
1 1.16667 L 
s 
P 
p 
.001 w 
.99625 .16667 m 
1 .16667 L 
s 
P 
p 
.001 w 
.99625 .20833 m 
1 .20833 L 
s 
P 
p 
.001 w 
.99625 .25 m 
1 .25 L 
s 
P 
p 
.001 w 
.99625 .29167 m 
1 .29167 L 
s 
P 
p 
.001 w 
.99625 .375 m 
1 .375 L 
s 
P 
p 
.001 w 
.99625 .41667 m 
1 .41667 L 
s 
P 
p 
.001 w 
.99625 .45833 m 
1 .45833 L 
s 
P 
p 
.001 w 
.99625 .5 m 
1 .5 L 
s 
P 
p 
.001 w 
.99625 .58333 m 
1 .58333 L 
s 
P 
p 
.001 w 
.99625 .625 m 
1 .625 L 
s 
P 
p 
.001 w 
.99625 .66667 m 
1 .66667 L 
s 
P 
p 
.001 w 
.99625 .70833 m 
1 .70833 L 
s 
P 
p 
.001 w 
.99625 .79167 m 
1 .79167 L 
s 
P 
p 
.001 w 
.99625 .83333 m 
1 .83333 L 
s 
P 
p 
.001 w 
.99625 .875 m 
1 .875 L 
s 
P 
p 
.001 w 
.99625 .91667 m 
1 .91667 L 
s 
P 
p 
.001 w 
.99625 1 m 
1 1 L 
s 
P 
p 
.001 w 
.99625 1.04167 m 
1 1.04167 L 
s 
P 
p 
.001 w 
.99625 1.08333 m 
1 1.08333 L 
s 
P 
p 
.001 w 
.99625 1.125 m 
1 1.125 L 
s 
P 
p 
.001 w 
.99625 .08333 m 
1 .08333 L 
s 
P 
p 
.001 w 
.99625 .04167 m 
1 .04167 L 
s 
P 
p 
.001 w 
.99625 0 m 
1 0 L 
s 
P 
p 
.001 w 
.99625 1.20833 m 
1 1.20833 L 
s 
P 
p 
.002 w 
1 0 m 
1 1.20833 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 1.20833 L 
0 1.20833 L 
closepath 
clip 
newpath 
p 
p 
p 
.025 w 
.08333 .95833 Mdot 
.015 w 
.29167 .02083 m 
.5 .33333 L 
.70833 .02083 L 
.08333 .02083 L 
.08333 .95833 L 
s 
P 
p 
1 0 0 r 
p 
.015 w 
.5697 .41074 m 
.43562 .53147 L 
s 
.43562 .53147 m 
.39811 .35499 L 
s 
P 
.015 w 
newpath 
.5 .33333 .10417 0 365.73 arc 
s 
P 
p 
0 0 1 r 
p 
.015 w 
.08333 .95833 m 
.69169 1.1016 L 
s 
P 
P 
p 
p 
.025 w 
.43562 .53147 Mdot 
.69169 1.1016 Mdot 
.79638 .8262 Mdot 
P 
0 1 0 r 
p 
.43562 .53147 m 
.69169 1.1016 L 
.79638 .8262 L 
F 
P 
P 
P 
.004 w 
.91667 .75 m 
.91104 .81206 L 
.8952 .86278 L 
.87212 .89517 L 
.84594 .9026 L 
.82031 .87992 L 
.79638 .8262 L 
.77265 .74866 L 
.7489 .66256 L 
.72906 .58351 L 
.7183 .5204 L 
.71923 .47588 L 
.73138 .44978 L 
.75254 .44118 L 
.77988 .44904 L 
.81056 .47222 L 
.84186 .50939 L 
.871 .55879 L 
.89504 .61796 L 
.91104 .68331 L 
.91667 .75 L 
s 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{220, 266},
  ImageMargins->{{100, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003L00012Q000`40O003h00Og7oo003LOol00=ao
o`00g7oo000OOol3000WOol5000UOol00`00Oomoo`0UOol5000WOol3000BOol001moo`03001oogoo
02Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001oogoo02Moo`03001oogoo019oo`006Woo0`00
0goo00<007ooOol08Woo0`000goo00<007ooOol097oo00<007oo0000:7oo00<007ooOol0:7oo00<0
07ooOol04Goo000POol00`00Oomoo`0XOol00`00Oomoo`0TOol00`00Ool0000XOol00`00Oomoo`0X
Ool00`00Oomoo`0AOol001moo`03001oo`0002Uoo`03001oogoo02Aoo`03001oo`0002Qoo`03001o
ogoo02Moo`03001oo`00019oo`0087oo00<007ooOol09goo0P009goo00<007ooOol09Woo0P00:Woo
00<007ooOol04Goo003LOol00=aoo`00g7oo003LOol00=aoo`00g7oo003LOol00=aoo`003Gooc@00
0Woo000=Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool10001
Ool1Ool000eoo`03001oogoo00ioo`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo02Qoo`03
001oogoo02Moo`03001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=
Ool00`00Oomoo`0=Oon3000iOol10001Ool1Ool000eoo`03001oogoo00eooh<003Uoo`40005oo`5o
o`003Goo00<007ooOol03GooP`00>Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000YOol4001>
Ool4000jOol10001Ool1Ool000eoo`03001oogoo00eoo`<002Yoo`<004ioo`<003]oo`40005oo`5o
o`003Goo0P003Woo0`00:Woo1000C7oo1000>goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000[
Ool4001:Ool4000lOol10001Ool1Ool000eoo`03001oogoo00eoo`<002aoo`<004Yoo`<003eoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00;7oo1000B7oo1000?Goo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3000]Ool40016Ool4000nOol10001Ool1Ool000eoo`03001oogoo00eoo`<002ioo`<0
04Ioo`<003moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00;Woo1000A7oo1000?goo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3000_Ool40012Ool40010Ool10001Ool1Ool000eoo`03001oogoo
00eoo`<0031oo`<0049oo`<0045oo`40005oo`5oo`003Goo0P003Woo0`00<7oo1000@7oo1000@Goo
0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000aOol4000nOol40012Ool10001Ool1Ool000eoo`03
001oogoo00eoo`<0039oo`<003ioo`<004=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00<Woo
1000?7oo1000@goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000cOol3000kOol40014Ool10001
Ool1Ool000eoo`03001oogoo00eoo`<003=oo`@003Yoo`<004Eoo`40005oo`5oo`001Woo1@000Woo
00<007ooOol03Goo0`00=7oo1000>7oo1000AGoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00
Oomoo`0=Ool3000eOol3000gOol40016Ool10001Ool1Ool0009oo`<000=oo`03001oogoo009oo`80
00ioo`<003Eoo`@003Ioo`<004Ioo`80009oo`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00
=Woo1000=7oo1000Agoo0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool3000gOol3
000cOol40018Ool10001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<003Moo`@0039oo`<004Uo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00>7oo1000<7oo1000BGoo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3000iOol3000_Ool4001:Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003Uo
o`@002ioo`<004]oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00>Woo1000;7oo1000Bgoo0@00
0Goo0Goo000=Ool00`00Oomoo`0=Ool3000kOol3000[Ool4001<Ool10001Ool1Ool000eoo`8000io
o`<003]oo`@002Yoo`<004eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?7oo1000:7oo1000
CGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000mOol3000WOol4001>Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<003eoo`@002Eoo`@004moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
?Woo100097oo0`00D7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol3000SOol4001@Ool1
0001Ool1Ool000eoo`03001oogoo00eoo`<003moo`@0025oo`@0055oo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00@7oo100087oo0`00DWoo0@000Goo0Goo000=Ool2000>Ool30011Ool3000OOol4
001BOol10001Ool1Ool000eoo`03001oogoo00eoo`<0045oo`@001eoo`@005=oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00@Woo100077oo0`00E7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0013Ool30009Ool8O00:Ool4001DOol10001Ool1Ool000eoo`03001oogoo00eoo`<004=oo`@000=o
oa5l00Eoo`@005Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00A7oo100000=oog`0O0004W`0
0goo0`00EWoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30015Ool20009O006Ool9O004001FOol1
0001Ool1Ool000eoo`03001oogoo00eoo`<004Eoo`03001l07`000Al00ioo`Ml0003001oogoo05Eo
o`40005oo`5oo`003Goo00<007ooOol03Goo0`00AGoo1W`04Goo1G`0F7oo0@000Goo0Goo000=Ool2
000>Ool30014Ool5O0000`00Oomoo`0AOol00`00O01l0002O01GOol10001Ool1Ool000eoo`03001o
ogoo00eoo`<004=oo`Al00@0015oo`<000Al05Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
@Woo17`00Woo0`004Goo0`0000=oog`0O0000W`0EGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
0011Ool4O003Ool4000?Ool40002Ool4O01DOol10001Ool1Ool000eoo`03001oogoo00eoo`<0041o
o`Al00Eoo`@000eoo`@000Aoo`Al05=oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?goo17`0
1goo0`003Goo0`001Woo1G`0DGoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000oOol4O007Ool4
000;Ool40007Ool4O01AOol10001Ool1Ool000eoo`03001oogoo00eoo`<003moo`=l00Uoo`@000Uo
o`@000Uoo`Al051oo`40005oo`5oo`003Goo0P003Woo0`00?Woo17`02Woo0`002Goo0`002goo0g`0
D7oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000nOol3O00;Ool40007Ool4000;Ool4O01?Ool1
0001Ool1Ool000eoo`03001oogoo00eoo`<003ioo`=l00aoo`@000Eoo`@000eoo`=l04moo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00?Woo0g`03Goo0`001Goo0`003Woo0g`0Cgoo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3000mOol4O00=Ool40003Ool4000>Ool3O01?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<003eoo`=l00moo`@00003Ool00000008000moo`=l04moo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00?Goo0g`047oo0`0000Aoo`000000011oo`=l04moo`40005oo`5oo`00
27oo00<007ooOol00Woo00<007ooOol03Goo0`00?Goo0g`047oo1`0047oo0g`0Cgoo0@000Goo0Goo
0007Ool00`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00AOol5000AOol3O01?Ool10001Ool1
Ool000Moo`03001oo`0000=oo`8000ioo`<003eoo`=l019oo`<0019oo`=l04ioo`80009oo`001goo
00<007oo00000goo00<007ooOol03Goo0`00?Goo0g`04Woo0`004Woo0g`0Cgoo0@000Goo0Goo0007
Ool00`00Ool00003Ool00`00Oomoo`0=Ool3000mOol3O00WOol3O01?Ool10001Ool1Ool000Qoo`03
001oogoo009oo`03001oogoo00eoo`<003eoo`=l02Moo`=l04moo`40005oo`5oo`003Goo00<007oo
Ool03Goo0`00?Goo17`09Woo0g`0Cgoo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3000mOol4O00V
Ool3O01?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003eoo`Al02Ioo`=l04moo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00?Woo0g`09Goo17`0Cgoo0@000Goo0Goo000=Ool2000>Ool3000n
Ool4O00TOol3O01@Ool10001Ool1Ool000eoo`03001oogoo00eoo`<003ioo`Al02=oo`Al051oo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00?Woo1G`08Woo0g`0DGoo0@000Goo0Goo000=Ool00`00
Oomoo`0=Ool3000nOol5O00QOol4O01AOol10001Ool1Ool000eoo`03001oogoo00eoo`<003moo`El
01ioo`El059oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00?goo1g`077oo1G`0DWoo0@000Goo
0Goo000=Ool00`00Oomoo`0=Ool3000oOol7O00JOol5O01DOol10001Ool1Ool000eoo`03001oogoo
00eoo`<003moo`Ql01Qoo`El05Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@7oo0g`000=o
og`0O0000g`05Goo1W`0EGoo0@000Goo0Goo000=Ool2000>Ool30010Ool3O0000gooO01l0005O00B
Ool5O01GOol10001Ool1Ool000eoo`03001oogoo00eoo`<0041oo`=l00=oo`Il00ioo`Il05Uoo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00@7oo0g`01Goo27`027oo1g`0FWoo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool30010Ool4O005OolFO01JOol10001Ool1Ool000eoo`03001oogoo00eoo`<0
045oo`=l00Iooa=l05aoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@Goo0g`02goo3G`0:Goo
1@00;goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30011Ool3O00COol4O00WOol30005Ool3000/
Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0045oo`Al015oo`Al02Qoo`03001oogoo00Qoo`80
02Yoo`40005oo`5oo`003Goo0P003Woo0`00@Woo0g`047oo17`0:7oo00<007ooOol02goo00<007oo
Ool09goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30012Ool3O00?Ool4O00YOol00`00Oomoo`0<
Ool00`00Oomoo`0VOol10001Ool1Ool000eoo`03001oogoo00eoo`<0049oo`=l00eoo`El02Yoo`03
001oogoo00eoo`8002Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00@Woo0g`037oo1G`0:Woo
00<007ooOol047oo00<007ooOol08goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30012Ool4O00:
Ool4O00/Ool00`00Oomoo`0AOol00`00Oomoo`0ROol10001Ool1Ool000eoo`03001oogoo00eoo`<0
04=oo`=l00Uoo`Al02eoo`03001oogoo015oo`03001oogoo029oo`40005oo`5oo`003Goo00<007oo
Ool03Goo0`00@goo0g`027oo17`0;Woo00<007ooOol04Woo00<007ooOol08Goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool30013Ool3O007Ool4O00_Ool00`00Oomoo`0COol00`00Oomoo`0POol10001
Ool1Ool000eoo`03001oogoo00eoo`<004=oo`Al00Eoo`Al031oo`03001oogoo01Aoo`03001oogoo
01moo`40005oo`5oo`003Goo0P003Woo0`00A7oo0g`017oo17`0<Goo00<007ooOol057oo00<007oo
Ool07goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool30014Ool3O003Ool4O00bOol00`00Oomoo`0E
Ool00`00Oomoo`0NOol10001Ool1Ool000eoo`03001oogoo00eoo`<004Aoo`=l009oo`Al03=oo`03
001oogoo01Ioo`03001oogoo01eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00A7oo0g`000=o
og`0O0000W`0=7oo00<007ooOol05goo00<007ooOol077oo0@000Goo0Goo000=Ool00`00Oomoo`0=
Ool30014Ool7O00eOol00`00Oomoo`0GOol00`00Oomoo`0LOol10001Ool1Ool000eoo`03001oogoo
00eoo`<004Eoo`8000=l03Ioo`03001oogoo01Qoo`03001oogoo01]oo`40005oo`5oo`001Woo1@00
0Woo00<007ooOol03Goo0`00A7oo100000=l07ooOol0=Goo00<007ooOol067oo00<007ooOol06goo
0@000Goo0Goo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool30014Ool300000`?POomoo`0fOol0
0`00Oomoo`0IOol00`00Oomoo`0JOol10001Ool1Ool000Qoo`03001oogoo009oo`8000ioo`<004Eo
o`800083h3Qoo`03001oogoo01Uoo`03001oogoo01Qoo`80009oo`0027oo00<007ooOol00Woo00<0
07ooOol03Goo0`00B7oo0P?P=goo00<007ooOol06Goo00<007ooOol06Goo0@000Goo0Goo0008Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool30018Ool30n0fOol00`00Oomoo`0JOol00`00Oomoo`0HOol1
0001Ool1Ool000Moo`8000Aoo`03001oogoo00eoo`<004Uoo`@3h3Aoo`03001oogoo01Yoo`03001o
ogoo01Qoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00BGoo1@?P<goo00<007ooOol06goo00<0
07ooOol05goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001:Ool50n0bOol00`00Oomoo`0KOol0
0`00Oomoo`0GOol10001Ool1Ool000eoo`03001oogoo00eoo`<004Yoo`H3h39oo`03001oogoo01]o
o`03001oogoo01Ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Bgoo1`?P<7oo00<007ooOol0
6goo00<007ooOol05Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001;Ool80n0_Ool00`00Oomo
o`0LOol00`00Oomoo`0EOol10001Ool1Ool000eoo`8000ioo`<004]oo`T3h2ioo`03001oogoo01ao
o`03001oogoo01Eoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00C7oo2@?P;Goo00<007ooOol0
77oo00<007ooOol05Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001<Ool;0n0[Ool00`00Oomo
o`0MOol00`00Oomoo`0DOol10001Ool1Ool000eoo`03001oogoo00eoo`<004eoo`/3h2]oo`03001o
ogoo01aoo`03001oogoo01Aoo`40005oo`5oo`003Goo00<007ooOol03Goo0`00CGoo30?P:Woo00<0
07ooOol07Goo00<007ooOol04goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001>Ool<0n0YOol0
0`00Oomoo`0MOol00`00Oomoo`0COol10001Ool1Ool000eoo`03001oogoo00eoo`<004ioo`d3h2Qo
o`03001oogoo01ioo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Cgoo3P?P
9goo00<007ooOol07Goo00<007ooOol04Woo0@000Goo0Goo000=Ool2000>Ool3001?Ool?0n0VOol0
0`00Oomoo`0MOol00`00Oomoo`0BOol10001Ool1Ool000eoo`03001oogoo00eoo`<004mooa03h2Eo
o`03001oogoo01eoo`03001oogoo019oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00D7oo40?P
97oo00<007ooOol07Woo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001@OolB
0n0SOol00`00Oomoo`0MOol00`00Oomoo`0AOol10001Ool1Ool000eoo`03001oogoo00eoo`<0055o
oa83h29oo`03001oogoo01eoo`03001oogoo015oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00
DGoo4`?P8Goo00<007ooOol07Goo00<007ooOol04Goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3
001BOolC0n0POol00`00Oomoo`0NOol00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<0059ooaD3h1moo`03001oogoo01eoo`03001oogoo011oo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00Dgoo5@?P7Woo00<007ooOol07Goo00<007ooOol047oo0@000Goo0Goo000=Ool2000>Ool3
001COolF0n0MOol00`00Oomoo`0MOol00`00Oomoo`0@Ool10001Ool1Ool000eoo`03001oogoo00eo
o`<005=ooaL3h1eoo`03001oogoo01eoo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol0
3Goo0`00E7oo5`?P77oo00<007ooOol07Goo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomo
o`0=Ool3001DOolI0n0JOol00`00Oomoo`0MOol00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001o
ogoo00eoo`<005EooaT3h1Uoo`03001oogoo01eoo`03001oogoo00moo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00EGoo6P?P6Goo00<007ooOol077oo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001FOolJ0n0HOol00`00Oomoo`0LOol00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<005Iooa`3h1Ioo`03001oogoo01aoo`03001oogoo00moo`40005oo`5oo`00
3Goo0P003Woo0`00Egoo70?P5Woo00<007ooOol06goo00<007ooOol03goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001GOolM0n0EOol00`00Oomoo`0KOol00`00Oomoo`0?Ool10001Ool1Ool000eo
o`03001oogoo00eoo`<005Qooad3h1Aoo`03001oogoo01]oo`03001oogoo00moo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00F7oo7`?P4goo00<007ooOol06goo00<007ooOol03Woo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001HOolP0n0BOol00`00Oomoo`0KOol00`00Oomoo`0>Ool10001Ool1
Ool000eoo`03001oogoo00eoo`<005Uoob03h15oo`03001oogoo01]oo`03001oogoo00ioo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00FGoo8@?P47oo00<007ooOol06goo00<007ooOol03Woo0@00
0Goo0Goo0007Ool30003Ool00`00Oomoo`0=Ool3001JOolR0n0?Ool00`00Oomoo`0JOol00`00Oomo
o`0>Ool10001Ool1Ool000Moo`03001oogoo00=oo`03001oogoo00eoo`<005Yoob<3h0ioo`03001o
ogoo01Yoo`03001oogoo00ioo`40005oo`5oo`0027oo00<007ooOol00Woo0P003Woo0`00Fgoo8`?P
3Goo00<007ooOol06Woo00<007ooOol03Goo0P000Woo0008Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool3001KOolT0n0=Ool00`00Oomoo`0IOol00`00Oomoo`0>Ool10001Ool1Ool000Moo`03001oo`00
00=oo`03001oogoo00eoo`<005aoob@3h0aoo`03001oogoo01Uoo`03001oogoo00ioo`40005oo`5o
o`0027oo00<007ooOol00Woo00<007ooOol03Goo0`00G7oo9P?P2Woo00<007ooOol06Goo00<007oo
Ool03Woo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001LOolW0n0:Ool00`00Oomoo`0HOol00`00
Oomoo`0>Ool10001Ool1Ool000eoo`03001oogoo00eoo`<005eoobL3h0Uoo`03001oogoo01Qoo`03
001oogoo00ioo`40005oo`5oo`003Goo00<007ooOol03Goo0`00GGoo:0?P27oo00<007ooOol05goo
00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001NOolY0n06Ool00`00Oomoo`0G
Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`8000ioo`<005ioobX3h0Ioo`03001oogoo01Ioo`03
001oogoo00moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00Ggoo:P?P1Goo00<007ooOol05Woo
00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001OOol[0n04Ool00`00Oomoo`0F
Ool00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0061oob`3h0=oo`03001oogoo
01Eoo`03001oogoo00moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00H7oo;@?P0Woo00<007oo
Ool05Goo00<007ooOol03goo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001POol^0n000goo001o
o`0FOol00`00Oomoo`0?Ool10001Ool1Ool000eoo`03001oogoo00eoo`<0065oobh3h08001Eoo`03
001oogoo011oo`40005oo`5oo`003Goo00<007ooOol03Goo0`00HGoo;`?P0P0057oo00<007ooOol0
47oo0@000Goo0Goo000=Ool00`00Oomoo`0=Ool3001ROol^0n02000DOol00`00Oomoo`0@Ool10001
Ool1Ool000eoo`8000ioo`<0069oobh3h08001Aoo`03001oogoo011oo`40005oo`5oo`003Goo00<0
07ooOol03Goo0`00Hgoo;0?P0Woo00<007ooOol04Goo00<007ooOol04Goo0@000Goo0Goo000=Ool0
0`00Oomoo`0=Ool3001SOol/0n03Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol10001Ool1Ool000eo
o`03001oogoo00eoo`<006Aoob/3h0=oo`03001oogoo011oo`03001oogoo015oo`40005oo`5oo`00
3Goo00<007ooOol03Goo0`00I7oo:P?P1Goo00<007ooOol03goo00<007ooOol04Goo0@000Goo0Goo
000=Ool00`00Oomoo`0=Ool3001UOolY0n05Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol10001Ool1
Ool000eoo`03001oogoo00eoo`<006EoobP3h0Moo`03001oogoo00eoo`03001oogoo019oo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00IGoo:0?P1goo00<007ooOol037oo00<007ooOol04goo0@00
0Goo0Goo000=Ool2000>Ool3001VOolW0n08Ool00`00Oomoo`0:Ool00`00Oomoo`0DOol10001Ool1
Ool000eoo`03001oogoo00eoo`<006IoobH3h0Uoo`03001oogoo00Uoo`03001oogoo01Eoo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00Igoo9@?P2Woo00<007ooOol027oo00<007ooOol05Goo0@00
0Goo0Goo000=Ool00`00Oomoo`0=Ool3001WOolT0n0<Ool00`00Oomoo`06Ool00`00Oomoo`0FOol1
0001Ool1Ool000eoo`03001oogoo00eoo`<006Qoob<3h0eoo`03001oogoo00=oo`8001Uoo`40005o
o`5oo`003Goo00<007ooOol03Goo0`00J7oo8`?P3Woo00<007ooOol00P006goo0@000Goo0Goo000=
Ool00`00Oomoo`0=Ool3001YOolQ0n0@Ool2000MOol10001Ool1Ool000eoo`03001oogoo00eoo`<0
06Uoob43h2moo`40005oo`5oo`003Goo00<007ooOol03Goo0`00JGoo80?P<7oo0@000Goo0Goo000=
Ool2000>Ool3001ZOolO0n0`Ool10001Ool1Ool000eoo`03001oogoo00eoo`<006Yooal3h31oo`40
005oo`5oo`003Goo00<007ooOol03Goo0`00Jgoo7@?P<Goo0@000Goo0Goo000=Ool00`00Oomoo`0=
Ool3001[OolM0n0aOol10001Ool1Ool000eoo`03001oogoo00eoo`<006aooa/3h39oo`40005oo`5o
o`003Goo00<007ooOol03Goo0`00K7oo6`?P<Woo0@000Goo0Goo0007Ool20004Ool00`00Oomoo`0=
Ool3001]OolJ0n0bOol10001Ool1Ool000Uoo`05001oogooOol0000?Ool401m/OolI0n0cOol10001
Ool1Ool000Qoo`03001oogoo009oo`8000eoo`0300007`0O00H07fQooaT3h39oo`80009oo`002Goo
00D007ooOomoo`0000ioo`0300007`0O00X07fEooaL3h3Aoo`40005oo`5oo`001goo00<007oo0000
0goo00<007ooOol03Goo0P000Woo300OHGoo5`?P=7oo0@000Goo0Goo0008Ool00`00Oomoo`02Ool0
0`00Oomoo`0EOol=01mMOolF0n0dOol10001Ool1Ool000eoo`03001oogoo01Uoo`d07eUooaD3h3Eo
o`40005oo`5oo`003Goo00<007ooOol07Goo3@0OEWoo50?P=Goo0@000Goo0Goo000=Ool00`00Oomo
o`0ROol=01mAOolD0n0eOol10001Ool1Ool000eoo`03001oogoo02Ioo`d07diooa83h3Ioo`40005o
o`5oo`003Goo00<007ooOol0:Woo3@0OBWoo4P?P=Woo0@000Goo0Goo000=Ool2000`Ool<01m7Ool@
0n0gOol10001Ool1Ool000eoo`03001oogoo03=oo`d07d9ooa03h3Moo`40005oo`5oo`003Goo00<0
07ooOol0=goo3@0O?Woo40?P=goo0@000Goo0Goo000=Ool00`00Oomoo`0kOol=01lkOol>0n0hOol1
0001Ool1Ool000eoo`03001oogoo041oo``07cMoo`h3h3Qoo`40005oo`5oo`003Goo00<007ooOol0
A7oo3@0O<goo30?P>Goo0@000Goo0Goo000=Ool00`00Oomoo`18Ool=01l_Ool<0n0iOol10001Ool1
Ool000eoo`03001oogoo04aoo`d07baoo`/3h3Uoo`40005oo`5oo`003Goo0P00DWoo3@0O9goo2P?P
>Woo0@000Goo0Goo000=Ool00`00Oomoo`1EOol=01lTOol90n0jOol10001Ool1Ool000eoo`03001o
ogoo05Uoo`d07b1oo`P3h3]oo`40005oo`5oo`003Goo00<007ooOol0GWoo300O77oo20?P>goo0@00
0Goo0Goo000=Ool00`00Oomoo`1ROol=01lHOol70n0kOol10001Ool1Ool000eoo`03001oogoo06Io
o`d07aAoo`H3h3aoo`40005oo`5oo`003Goo00<007ooOol0JWoo3@0O4Goo1@?P?7oo0@000Goo0Goo
000=Ool00`00Oomoo`1_Ool=01l<Ool40n0mOol10001Ool1Ool000eoo`03001oogoo07=oo`d07`Uo
o`<3h3eoo`40005oo`5oo`003Goo0P00N7oo3@0O1Goo0`?P?Goo0@000Goo0Goo000=Ool00`00Oomo
o`1lOol<01l2Ool00`?POomoo`0lOol10001Ool1Ool000eoo`03001oogoo081oo`T07`030003h00O
03eoo`40005oo`5oo`003Goo00<007ooOol0Q7oo100O1000?Goo0@000Goo0Goo000=Ool00`00Oomo
o`28Ool4000mOol10001Ool1Ool000eoo`03001oogoo08Uoo`8003ioo`40005oo`5oo`003Goo00<0
07ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eoo`800<Yoo`40005o
o`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomoo`39Ool10001Ool1Ool000eo
o`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo0Goo000=Ool00`00Oomo
o`39Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`0027oo0`000Woo00<007ooOol0
bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo0007Ool40002Ool20039Ool2
0002Ool000Moo`03001oo`0000=oo`03001oogoo0<Uoo`40005oo`5oo`0027oo0P000goo00<007oo
Ool0bGoo0@000Goo0Goo0009Ool01@00Oomoogoo0000bgoo0@000Goo0Goo000=Ool00`00Oomoo`39
Ool10001Ool1Ool000eoo`03001oogoo0<Uoo`40005oo`5oo`003Goo00<007ooOol0bGoo0@000Goo
0Goo000=Ool00`00Oomoo`0>Ool00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`0XOol00`00
Oomoo`0WOol00`00Oomoo`0>Ool10001Ool1Ool000eoold0009oo`00\
\>"],
  ImageRangeCache->{{{0, 219}, {265, 0}} -> {-2.71851, -2.02306, 0.0235014, 
  0.0235014}}]
}, Open  ]],

Cell[TextData[{
  "Because the loading in this model is dependent on velocity terms, the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option must be used with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to solve for the reaction forces. If ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " were used, ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would assume that all velocities were zero, thus, the applied damping \
would have zero magnitude and zero reactions would result. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the solution, including the generalized reaction forces. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.4, Solution \[Rule] Kinematic]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.4`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0.`\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 2.51327412287183449`\), ",", 
        \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
        \(Th3 \[Rule] \(-0.00631962658203875982`\)\), ",", 
        \(X4 \[Rule] \(-0.809016994374947273`\)\), ",", 
        \(Y4 \[Rule] 0.58778525229247327`\), ",", 
        \(Th4 \[Rule] \(-0.647238475478386199`\)\), ",", \(X2d \[Rule] 0.`\), 
        ",", \(Y2d \[Rule] 0.`\), ",", \(Th2d \[Rule] 6.28318530717958623`\), 
        ",", \(X3d \[Rule] 0.`\), ",", \(Y3d \[Rule] 0.`\), ",", 
        \(Th3d \[Rule] \(-2.61247446744095768`\)\), ",", 
        \(X4d \[Rule] \(-3.69316366098091375`\)\), ",", 
        \(Y4d \[Rule] \(-5.08320369231525948`\)\), ",", 
        \(Th4d \[Rule] \(-1.52245911440018755`\)\), ",", 
        \(Lmb1 \[Rule] \(-56.4364137785567976`\)\), ",", 
        \(Lmb2 \[Rule] 40.2949461451892698`\), ",", 
        \(Lmb3 \[Rule] 40.4832517984362816`\), ",", 
        \(Lmb4 \[Rule] \(-29.384470501144877`\)\), ",", 
        \(Lmb5 \[Rule] 0.18570135304516409`\), ",", 
        \(Lmb6 \[Rule] \(-40.2949461451892698`\)\), ",", 
        \(Lmb7 \[Rule] \(-40.4832517984362816`\)\), ",", 
        \(Lmb8 \[Rule] 29.384470501144877`\), ",", 
        \(Lmb9 \[Rule] \(-0.18570135304516409`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The reaction moment at the rotational driver is the moment required to \
rotate the drive bar. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[1, drivebar] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, 56.4364137785567976`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the reaction force at the drive bar axis. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[2, drivebar] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(-40.2949461451892698`\), \(-40.4832517984362816`\)}, 0}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Plots "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To generate a plot of the torque required to turn the drive bar, the \
four-bar model is run from ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 to ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 1 in 21 steps, a full turn of the drive bar, while requesting that ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " interpolate the results. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This generates an interpolated solution set and returns one part of the \
solution. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((irules = 
          SolveMech[{0, 1}, 21, Solution \[Rule] Kinematic, 
            Interpolation \[Rule] True])\)\[LeftDoubleBracket]10
      \[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"Lmb1", "\[Rule]", 
      RowBox[{
        TagBox[\(InterpolatingFunction[{{0, 1.`}}, "<>"]\),
          False,
          Editable->False], "[", "T", "]"}]}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is an explicit expression for the drive torque. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(drivetorque = 
      \(Reaction[1, drivebar]\)\[LeftDoubleBracket]2\[RightDoubleBracket]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(-Lmb1\)\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of the drive torque as a function of time."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[drivetorque /. irules], {T, 0, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.00998946 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11461 -12 -4.5 ]
[.01131 .11461 0 4.5 ]
[.01131 .2145 -12 -4.5 ]
[.01131 .2145 0 4.5 ]
[.01131 .3144 -12 -4.5 ]
[.01131 .3144 0 4.5 ]
[.01131 .41429 -12 -4.5 ]
[.01131 .41429 0 4.5 ]
[.01131 .51419 -12 -4.5 ]
[.01131 .51419 0 4.5 ]
[.01131 .61408 -12 -4.5 ]
[.01131 .61408 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11461 m
.03006 .11461 L
s
[(10)] .01131 .11461 1 0 Mshowa
.02381 .2145 m
.03006 .2145 L
s
[(20)] .01131 .2145 1 0 Mshowa
.02381 .3144 m
.03006 .3144 L
s
[(30)] .01131 .3144 1 0 Mshowa
.02381 .41429 m
.03006 .41429 L
s
[(40)] .01131 .41429 1 0 Mshowa
.02381 .51419 m
.03006 .51419 L
s
[(50)] .01131 .51419 1 0 Mshowa
.02381 .61408 m
.03006 .61408 L
s
[(60)] .01131 .61408 1 0 Mshowa
.125 Mabswid
.02381 .03469 m
.02756 .03469 L
s
.02381 .05467 m
.02756 .05467 L
s
.02381 .07465 m
.02756 .07465 L
s
.02381 .09463 m
.02756 .09463 L
s
.02381 .13459 m
.02756 .13459 L
s
.02381 .15457 m
.02756 .15457 L
s
.02381 .17455 m
.02756 .17455 L
s
.02381 .19453 m
.02756 .19453 L
s
.02381 .23448 m
.02756 .23448 L
s
.02381 .25446 m
.02756 .25446 L
s
.02381 .27444 m
.02756 .27444 L
s
.02381 .29442 m
.02756 .29442 L
s
.02381 .33438 m
.02756 .33438 L
s
.02381 .35436 m
.02756 .35436 L
s
.02381 .37434 m
.02756 .37434 L
s
.02381 .39431 m
.02756 .39431 L
s
.02381 .43427 m
.02756 .43427 L
s
.02381 .45425 m
.02756 .45425 L
s
.02381 .47423 m
.02756 .47423 L
s
.02381 .49421 m
.02756 .49421 L
s
.02381 .53417 m
.02756 .53417 L
s
.02381 .55415 m
.02756 .55415 L
s
.02381 .57412 m
.02756 .57412 L
s
.02381 .5941 m
.02756 .5941 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .32854 m
.04262 .30903 L
.06244 .28097 L
.10458 .20574 L
.14264 .13239 L
.16385 .09784 L
.17388 .08482 L
.18314 .07542 L
.18781 .07183 L
.19276 .06894 L
.19532 .06784 L
.19772 .06707 L
.1991 .06674 L
.20036 .06652 L
.20105 .06643 L
.20181 .06636 L
.20252 .06631 L
.20319 .06629 L
.20438 .06631 L
.20567 .0664 L
.20688 .06657 L
.208 .06679 L
.20901 .06704 L
.21012 .06738 L
.21236 .06826 L
.21364 .06888 L
.2148 .06964 L
.21742 .07196 L
.22214 .0771 L
.23205 .09185 L
.24122 .11026 L
.25193 .13753 L
.26198 .16884 L
.28065 .24964 L
.30125 .34968 L
.31973 .43987 L
.3302 .48752 L
.33994 .52745 L
.35044 .56405 L
.35501 .57747 L
.35626 .58082 L
.35743 .58363 L
.35864 .58579 L
.35998 .58801 L
.36271 .59207 L
.36522 .59524 L
.36777 .59791 L
.37018 .59995 L
.37149 .60085 L
.37292 .60167 L
Mistroke
.37424 .60228 L
.37543 .60271 L
.37611 .60291 L
.37685 .60308 L
.37763 .60321 L
.37836 .60328 L
.37905 .60332 L
.37978 .60331 L
.38108 .6032 L
.3823 .60297 L
.38299 .60279 L
.38363 .60259 L
.38605 .60154 L
.38825 .60019 L
.39058 .59836 L
.39542 .59325 L
.40075 .58559 L
.40531 .57721 L
.41022 .56492 L
.4191 .5389 L
.46029 .38116 L
.48086 .30007 L
.49997 .22966 L
.51961 .17186 L
.53813 .12754 L
.54797 .10818 L
.55863 .09142 L
.56824 .07913 L
.57723 .06995 L
.58672 .06254 L
.59175 .05952 L
.59714 .05695 L
.59985 .05592 L
.60279 .05499 L
.60539 .05432 L
.60815 .05378 L
.61063 .05343 L
.61204 .05328 L
.61269 .05323 L
.61337 .05318 L
.61458 .05313 L
.61569 .0531 L
.61689 .0531 L
.6182 .05313 L
.61951 .05319 L
.62073 .05328 L
.62206 .05341 L
.62347 .05358 L
.62585 .05396 L
.62846 .05449 L
Mistroke
.63327 .05579 L
.63779 .05737 L
.64788 .06201 L
.65873 .06862 L
.67988 .08591 L
.69997 .10678 L
.73818 .15504 L
.77885 .2132 L
.818 .26858 L
.83799 .29399 L
.8596 .31761 L
.86976 .32699 L
.88048 .33551 L
.89053 .34187 L
.89969 .34638 L
.90423 .34815 L
.90918 .34971 L
.91189 .3504 L
.9144 .35093 L
.91695 .35137 L
.91934 .35168 L
.92138 .35187 L
.92252 .35194 L
.92357 .35199 L
.92466 .35202 L
.92584 .35203 L
.92708 .35202 L
.92824 .35198 L
.92947 .35192 L
.93063 .35183 L
.9328 .35161 L
.93514 .35127 L
.93768 .3508 L
.94229 .34963 L
.94659 .34819 L
.95639 .34361 L
.96594 .33734 L
.97619 .32854 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo0010Ool0
0`00Oomoo`02Ool01000Oomoogoo0`009Goo00<007ooOol00Woo00<007ooOol00Woo0`009Goo00<0
07ooOol00Woo00@007ooOomoo`8002Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Mo
o`D000]oo`00?goo00<007oo00001goo00<007ooOol097oo00<007oo00002Goo00<007ooOol08goo
00<007oo00001goo00<007oo000097oo00<007oo00001goo00<007oo0000:Woo00<007ooOol02goo
000oOol00`00Ool00008Ool00`00Oomoo`0SOol00`00Ool00007Ool4000TOol00`00Ool00007Ool0
0`00Ool0000TOol00`00Ool00007Ool00`00Ool0000ZOol00`00Oomoo`0;Ool003moo`03001oo`00
00Qoo`03001oogoo02=oo`03001oo`0000Moo`03001oo`0002Eoo`03001oo`0000Moo`8002Eoo`03
001oo`0000Qoo`03001oogoo02Uoo`03001oogoo00]oo`00?goo00<007oo00001goo00<007oo0000
97oo00<007oo000027oo0P009Goo00<007oo00001goo00<007ooOol097oo00<007oo00001goo00<0
07oo0000:Woo00<007ooOol02goo0010Ool00`00Oomoo`07Ool00`00Oomoo`0TOol00`00Oomoo`08
Ool00`00Oomoo`0TOol00`00Oomoo`07Ool2000UOol00`00Oomoo`07Ool00`00Oomoo`0XOol2000=
Ool00?mooaUoo`00ogoo6Goo000DOol00`00Oomoo`3oOol2Ool001Aoo`03001oogoo0?moo`9oo`00
57oo00<007ooOol0ogoo0Woo000DOol00`00Oomoo`3oOol2Ool000ioool000D000Ioo`0057oo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo000DOol00`00Oomoo`3oOol2Ool001Aoo`03001oogoo0?moo`9oo`0057oo00<007oo
Ool0ogoo0Woo000DOol2003oOol3Ool001Aoo`03001oogoo0?moo`9oo`0057oo00<007ooOol0ogoo
0Woo000DOol00`00Oomoo`3oOol2Ool001Aoo`03001oogoo0?moo`9oo`0057oo0P00Tgoo2P00IGoo
000DOol00`00Oomoo`2@Ool30009Ool2001SOol001Aoo`03001oogoo08moo`03001oogoo00aoo`80
065oo`0057oo00<007ooOol0:Woo1000H7oo00<007ooOol03goo0P00Ggoo000DOol00`00Oomoo`0Y
Ool00`00Oomoo`02Ool2001MOol00`00Oomoo`0BOol00`00Oomoo`1LOol001Aoo`8002Moo`<000Io
o`03001oogoo05Uoo`8001Ioo`03001oogoo05]oo`0057oo00<007ooOol09Goo00<007ooOol027oo
0P00F7oo00<007ooOol05goo0P00Fgoo000DOol00`00Oomoo`0UOol00`00Oomoo`09Ool00`00Oomo
o`1EOol00`00Oomoo`0JOol00`00Oomoo`1HOol001Aoo`03001oogoo02Aoo`03001oogoo00]oo`03
001oogoo05Aoo`03001oogoo01]oo`03001oogoo05Moo`0057oo00<007ooOol08goo00<007ooOol0
37oo00<007ooOol0Dgoo00<007ooOol07Goo00<007ooOol0EWoo000DOol2000SOol00`00Oomoo`0>
Ool00`00Oomoo`1BOol00`00Oomoo`0NOol00`00Oomoo`1EOol001Aoo`03001oogoo025oo`03001o
ogoo011oo`03001oogoo051oo`03001oogoo01moo`03001oogoo05Eoo`0057oo00<007ooOol087oo
00<007ooOol04Goo00<007ooOol0Cgoo00<007ooOol08Goo00<007ooOol0E7oo000DOol00`00Oomo
o`0POol00`00Oomoo`0BOol00`00Oomoo`1>Ool00`00Oomoo`0ROol00`00Oomoo`1COol000Moo`D0
009oo`03001oogoo00=oo`03001oogoo01moo`03001oogoo01Aoo`03001oogoo04aoo`03001oogoo
02Aoo`03001oogoo059oo`002Goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0OOol00`00Oomo
o`0DOol00`00Oomoo`1;Ool00`00Oomoo`0VOol00`00Oomoo`1AOol000Uoo`07001oogooOol007oo
000017oo0`007Woo00<007ooOol05Goo00<007ooOol0Bgoo00<007ooOol09goo00<007ooOol0D7oo
0009Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo01ioo`03001oogoo01Ioo`03001oogoo04Uo
o`03001oogoo02Qoo`03001oogoo051oo`002Goo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0M
Ool00`00Oomoo`0GOol00`00Oomoo`19Ool00`00Oomoo`0YOol00`00Oomoo`1?Ool000Qoo`8000Ao
o`03001oogoo00=oo`03001oogoo01eoo`03001oogoo01Moo`03001oogoo04Qoo`03001oogoo02]o
o`03001oogoo04ioo`0057oo00<007ooOol077oo00<007ooOol067oo00<007ooOol0B7oo00<007oo
Ool0;7oo00<007ooOol0CGoo000DOol2000LOol00`00Oomoo`0JOol00`00Oomoo`16Ool00`00Oomo
o`0^Ool00`00Oomoo`1<Ool001Aoo`03001oogoo01]oo`03001oogoo01Yoo`03001oogoo04Ioo`03
001oogoo02moo`03001oogoo04]oo`0057oo00<007ooOol06Woo00<007ooOol06goo00<007ooOol0
AWoo00<007ooOol0;goo00<007ooOol0Bgoo000DOol00`00Oomoo`0JOol00`00Oomoo`0LOol00`00
Oomoo`14Ool00`00Oomoo`0aOol00`00Oomoo`1:Ool001Aoo`03001oogoo01Uoo`03001oogoo01eo
o`03001oogoo04Aoo`03001oogoo039oo`03001oogoo04Uoo`0057oo0P006Woo00<007ooOol07Goo
00<007ooOol0@goo00<007ooOol0=7oo00<007ooOol0B7oo000DOol00`00Oomoo`0HOol00`00Oomo
o`0OOol00`00Oomoo`12Ool00`00Oomoo`0eOol00`00Oomoo`17Ool001Aoo`03001oogoo01Qoo`03
001oogoo01moo`03001oogoo049oo`03001oogoo03Eoo`03001oogoo04Moo`0057oo00<007ooOol0
5goo00<007ooOol08Goo00<007ooOol0@7oo00<007ooOol0=goo00<007ooOol0AWoo000DOol00`00
Oomoo`0GOol00`00Oomoo`0QOol00`00Oomoo`10Ool00`00Oomoo`0hOol00`00Oomoo`15Ool001Ao
o`8001Moo`03001oogoo029oo`03001oogoo041oo`03001oogoo03Uoo`03001oogoo04Aoo`0057oo
00<007ooOol05Woo00<007ooOol08Woo00<007ooOol0?goo00<007ooOol0>Woo00<007ooOol0A7oo
000DOol00`00Oomoo`0EOol00`00Oomoo`0TOol00`00Oomoo`0nOol00`00Oomoo`0kOol00`00Oomo
o`13Ool001Aoo`03001oogoo01Eoo`03001oogoo02Aoo`03001oogoo03ioo`03001oogoo03aoo`03
001oogoo049oo`0057oo00<007ooOol057oo00<007ooOol09Goo00<007ooOol0?Goo00<007ooOol0
?Woo00<007ooOol0@Goo000DOol2000EOol00`00Oomoo`0UOol00`00Oomoo`0mOol00`00Oomoo`0n
Ool00`00Oomoo`11Ool001Aoo`03001oogoo01=oo`03001oogoo02Moo`03001oogoo03aoo`03001o
ogoo03moo`03001oogoo041oo`0057oo00<007ooOol04goo00<007ooOol09goo00<007ooOol0>goo
00<007ooOol0@Goo00<007ooOol0?goo0008Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`0BOol0
0`00Oomoo`0XOol00`00Oomoo`0kOol00`00Oomoo`12Ool00`00Oomoo`0nOol000Qoo`03001oogoo
009oo`03001oo`0000Aoo`03001oogoo015oo`03001oogoo02Uoo`03001oogoo03]oo`03001oogoo
049oo`03001oogoo03ioo`002Goo00L007ooOomoo`00Ool00004Ool3000AOol00`00Oomoo`0ZOol0
0`00Oomoo`0iOol00`00Oomoo`14Ool00`00Oomoo`0mOol000Uoo`07001oogooOol007oo000017oo
00<007ooOol047oo00<007ooOol0:goo00<007ooOol0>Goo00<007ooOol0AGoo00<007ooOol0?7oo
0008Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`0@Ool00`00Oomoo`0[Ool00`00Oomo
o`0iOol00`00Oomoo`15Ool00`00Oomoo`0lOol000Uoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00moo`03001oogoo02aoo`03001oogoo03Qoo`03001oogoo04Moo`03001oogoo03]oo`00
57oo00<007ooOol03goo00<007ooOol0;Goo00<007ooOol0=goo00<007ooOol0B7oo00<007ooOol0
>Woo000DOol00`00Oomoo`0>Ool00`00Oomoo`0^Ool00`00Oomoo`0gOol00`00Oomoo`19Ool00`00
Oomoo`0iOol001Aoo`8000moo`03001oogoo02ioo`03001oogoo03Ioo`03001oogoo04Yoo`03001o
ogoo03Uoo`0057oo00<007ooOol03Goo00<007ooOol0;goo00<007ooOol0=Woo00<007ooOol0Bgoo
00<007ooOol0>7oo000DOol00`00Oomoo`0<Ool00`00Oomoo`0aOol00`00Oomoo`0eOol00`00Oomo
o`1<Ool00`00Oomoo`0gOol001Aoo`03001oogoo00aoo`03001oogoo035oo`03001oogoo03Eoo`03
001oogoo04aoo`03001oogoo03Moo`0057oo00<007ooOol02goo00<007ooOol0<Woo00<007ooOol0
=7oo00<007ooOol0CWoo00<007ooOol0=Woo000DOol2000<Ool00`00Oomoo`0bOol00`00Oomoo`0d
Ool00`00Oomoo`1?Ool00`00Oomoo`0eOol001Aoo`03001oogoo00Yoo`03001oogoo03=oo`03001o
ogoo03Aoo`03001oogoo051oo`03001oogoo03Aoo`0057oo00<007ooOol02Woo00<007ooOol0=7oo
00<007ooOol0<goo00<007ooOol0D7oo00<007ooOol0=7oo000DOol00`00Oomoo`09Ool00`00Oomo
o`0eOol00`00Oomoo`0bOol00`00Oomoo`1BOol00`00Oomoo`0cOol001Aoo`03001oogoo00Uoo`03
001oogoo03Eoo`03001oogoo039oo`03001oogoo05=oo`03001oogoo039oo`0057oo0P002Goo00<0
07ooOol0=Woo00<007ooOol0<Woo00<007ooOol0Dgoo00<007ooOol0<Woo000DOol00`00Oomoo`08
Ool00`00Oomoo`0fOol00`00Oomoo`0bOol00`00Oomoo`1DOol00`00Oomoo`0aOol001Aoo`03001o
ogoo00Moo`03001oogoo03Qoo`03001oogoo031oo`03001oogoo05Ioo`03001oogoo031oo`0057oo
00<007ooOol01Woo00<007ooOol0>Goo00<007ooOol0<7oo00<007ooOol0Egoo00<007ooOol0;goo
000DOol00`00Oomoo`06Ool00`00Oomoo`0iOol00`00Oomoo`0`Ool00`00Oomoo`1GOol00`00Oomo
o`0_Ool001Aoo`8000Ioo`03001oogoo03Yoo`03001oogoo031oo`03001oogoo05Qoo`03001oogoo
02ioo`0057oo00<007ooOol017oo00<007ooOol0>goo00<007ooOol0;goo00<007ooOol0FWoo00<0
07ooOol0;Goo000DOol00`00Oomoo`03Ool00`00Oomoo`0lOol00`00Oomoo`0_Ool00`00Oomoo`1K
Ool00`00Oomoo`0/Ool000Qoo`8000Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo03eo
o`03001oogoo02ioo`03001oogoo05aoo`03001oogoo02]oo`002Woo00H007ooOol007oo0004Ool0
0`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`0]Ool00`00Oomoo`1NOol00`00Oomoo`0ZOol0
00Uoo`07001oogooOol007oo000017oo0`0000=oo`00Ool0@7oo00<007ooOol0;Goo00<007ooOol0
Ggoo00<007ooOol0:Goo000:Ool01P00Oomoo`00Ool000Aoo`04001oogoo0012Ool00`00Oomoo`0]
Ool00`00Oomoo`1POol00`00Oomoo`0XOol000Qoo`03001oo`00009oo`03001oo`0000Aoo`03001o
o`0004=oo`03001oogoo02eoo`03001oogoo065oo`03001oogoo02Moo`002Goo00<007ooOol00Woo
00<007ooOol00goo0P00AGoo00<007ooOol0:goo00<007ooOol0HWoo00<007ooOol09goo000DOol0
0`00Oomoo`14Ool00`00Oomoo`0[Ool00`00Oomoo`1SOol00`00Oomoo`0IOol00`00Oomoo`0:Ool0
01Aoo`03001oogoo04Aoo`03001oogoo02]oo`03001oogoo06Aoo`8001Moo`8000eoo`0057oo0P00
AGoo00<007ooOol0:Woo00<007ooOol0Igoo0P0057oo00<007ooOol03Goo000DOol00`00Oomoo`14
Ool00`00Oomoo`0ZOol00`00Oomoo`1YOol2000AOol00`00Oomoo`0>Ool001Aoo`03001oogoo04Eo
o`03001oogoo02Uoo`03001oogoo06]oo`03001oogoo00aoo`80015oo`0057oo00<007ooOol0AGoo
00<007ooOol0:Goo00<007ooOol0K7oo0P002Goo0`004goo000DOol00`00Oomoo`15Ool00`00Oomo
o`0XOol00`00Oomoo`1_Ool9000FOol001Aoo`8004Ioo`03001oogoo02Qoo`03001oogoo08ioo`00
57oo00<007ooOol0AGoo00<007ooOol0:7oo00<007ooOol0SWoo000DOol00`00Oomoo`16Ool00`00
Oomoo`0VOol00`00Oomoo`2?Ool001Aoo`03001oogoo04Ioo`03001oogoo02Ioo`03001oogoo08mo
o`0057oo00<007ooOol0AWoo00<007ooOol09Woo00<007ooOol0Sgoo000DOol20017Ool00`00Oomo
o`0VOol00`00Oomoo`2?Ool001Aoo`03001oogoo04Moo`03001oogoo02Aoo`03001oogoo091oo`00
57oo00<007ooOol0Agoo00<007ooOol097oo00<007ooOol0T7oo000DOol00`00Oomoo`17Ool00`00
Oomoo`0TOol00`00Oomoo`2@Ool001Aoo`03001oogoo04Moo`03001oogoo02Aoo`03001oogoo091o
o`0057oo0P00B7oo00<007ooOol08goo00<007ooOol0TGoo000DOol00`00Oomoo`18Ool00`00Oomo
o`0ROol00`00Oomoo`2AOol001Aoo`03001oogoo04Qoo`03001oogoo029oo`03001oogoo095oo`00
2Goo0`000Woo00<007ooOol00goo00<007ooOol0B7oo00<007ooOol08Woo00<007ooOol0TGoo000:
Ool01P00Oomoo`00Ool000Aoo`03001oogoo04Qoo`03001oogoo025oo`03001oogoo099oo`0027oo
100000Aoo`00Ool000Aoo`<004Qoo`03001oogoo025oo`03001oogoo099oo`0027oo00<007oo0000
0Woo00<007oo000017oo00<007ooOol0BGoo00<007ooOol087oo00<007ooOol0TWoo0009Ool20002
Ool00`00Ool00004Ool00`00Oomoo`19Ool00`00Oomoo`0POol00`00Oomoo`2BOol000Yoo`05001o
ogooOol00005Ool00`00Oomoo`19Ool00`00Oomoo`0OOol00`00Oomoo`2COol001Aoo`03001oogoo
04Uoo`03001oogoo01moo`03001oogoo09=oo`0057oo0P00Bgoo00<007ooOol07Woo00<007ooOol0
Tgoo000DOol00`00Oomoo`1:Ool00`00Oomoo`0NOol00`00Oomoo`2COol001Aoo`03001oogoo04Yo
o`03001oogoo01eoo`03001oogoo09Aoo`0057oo00<007ooOol0BWoo00<007ooOol07Goo00<007oo
Ool0U7oo000DOol00`00Oomoo`1:Ool00`00Oomoo`0MOol00`00Oomoo`2DOol001Aoo`03001oogoo
04]oo`03001oogoo01aoo`03001oogoo09Aoo`0057oo0P00C7oo00<007ooOol06goo00<007ooOol0
UGoo000DOol00`00Oomoo`1;Ool00`00Oomoo`0KOol00`00Oomoo`2EOol001Aoo`03001oogoo04]o
o`03001oogoo01]oo`03001oogoo09Eoo`0057oo00<007ooOol0C7oo00<007ooOol06Woo00<007oo
Ool0UGoo000DOol00`00Oomoo`1<Ool00`00Oomoo`0IOol00`00Oomoo`2FOol001Aoo`8004eoo`03
001oogoo01Uoo`03001oogoo09Ioo`0057oo00<007ooOol0C7oo00<007ooOol06Goo00<007ooOol0
UWoo000DOol00`00Oomoo`1=Ool00`00Oomoo`0HOol00`00Oomoo`2FOol001Aoo`03001oogoo04eo
o`03001oogoo01Moo`03001oogoo09Moo`0057oo00<007ooOol0CGoo00<007ooOol05goo00<007oo
Ool0Ugoo000DOol2001>Ool00`00Oomoo`0GOol00`00Oomoo`2GOol001Aoo`03001oogoo04ioo`03
001oogoo01Ioo`03001oogoo09Moo`0057oo00<007ooOol0CWoo00<007ooOol05Goo00<007ooOol0
V7oo0009Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1>Ool00`00Oomoo`0EOol00`00
Oomoo`2HOol000Qoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo04ioo`03001oogoo01Eo
o`03001oogoo09Qoo`002Woo00H007ooOol007oo0004Ool3001>Ool00`00Oomoo`0EOol00`00Oomo
o`2HOol000Qoo`8000=oo`03001oo`0000Aoo`03001oogoo04ioo`03001oogoo01Aoo`03001oogoo
09Uoo`0027oo00<007ooOol00Woo00<007oo000017oo00<007ooOol0Cgoo00<007ooOol04goo00<0
07ooOol0VGoo0008Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`1?Ool00`00Oomoo`0COol00`00
Oomoo`2IOol001Aoo`03001oogoo04moo`03001oogoo01=oo`03001oogoo09Uoo`0057oo0P00D7oo
00<007ooOol04Woo00<007ooOol0VWoo000DOol00`00Oomoo`1@Ool00`00Oomoo`0AOol00`00Oomo
o`2JOol001Aoo`03001oogoo051oo`03001oogoo015oo`03001oogoo09Yoo`0057oo00<007ooOol0
D7oo00<007ooOol047oo00<007ooOol0Vgoo000DOol00`00Oomoo`1AOol00`00Oomoo`0?Ool00`00
Oomoo`2KOol001Aoo`80059oo`03001oogoo00ioo`03001oogoo09aoo`0057oo00<007ooOol0DGoo
00<007ooOol03Woo00<007ooOol0W7oo000DOol00`00Oomoo`1BOol00`00Oomoo`0<Ool00`00Oomo
o`2MOol001Aoo`03001oogoo059oo`03001oogoo00aoo`03001oogoo09eoo`0057oo00<007ooOol0
DWoo00<007ooOol037oo00<007ooOol0WGoo000DOol00`00Oomoo`1BOol00`00Oomoo`0;Ool00`00
Oomoo`2NOol001Aoo`8005Aoo`03001oogoo00Yoo`03001oogoo09ioo`0057oo00<007ooOol0Dgoo
00<007ooOol02Woo00<007ooOol0WWoo000DOol00`00Oomoo`1DOol00`00Oomoo`08Ool00`00Oomo
o`2OOol001Aoo`03001oogoo05Aoo`03001oogoo00Qoo`03001oogoo09moo`0057oo00<007ooOol0
EGoo00<007ooOol01Woo00<007ooOol0X7oo000DOol2001GOol00`00Oomoo`04Ool00`00Oomoo`2Q
Ool001Aoo`03001oogoo05Ioo`8000Aoo`03001oogoo0:9oo`0057oo00<007ooOol0Egoo1@00YGoo
0008Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`3oOol2Ool000Qoo`03001oo`00009oo`03001o
o`0000Aoo`03001oogoo0?moo`9oo`0027oo00<007oo00000Woo00<007oo000017oo0`00ogoo0Woo
0008Ool20003Ool00`00Ool00004Ool00`00Oomoo`3oOol2Ool000Qoo`03001oogoo009oo`03001o
o`000?moo`Uoo`002Goo0P000goo00<007ooOol0ogoo27oo003oOolIOol00001\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0838278, -4.72912, 0.00405337,
   0.386443}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "A parametric plot of the ",
  StyleBox["x-y",
    FontSlant->"Italic"],
  " reaction at the axis of the drive bar can be easily created. The plot \
ranges only from ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 to ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.95 so the start and end points are apparent. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the drive arm axis reaction vector. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(axisreact = 
      \(Reaction[2, drivebar]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-Lmb2\), \(-Lmb3\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a parametric plot of the drive arm axis reaction vector."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[Evaluate[axisreact /. irules], {T, 0, .95}]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.715565 0.0170051 0.3583 0.00779918 [
[.03536 .3458 -9 -9 ]
[.03536 .3458 9 0 ]
[.20541 .3458 -9 -9 ]
[.20541 .3458 9 0 ]
[.37546 .3458 -9 -9 ]
[.37546 .3458 9 0 ]
[.54551 .3458 -9 -9 ]
[.54551 .3458 9 0 ]
[.88562 .3458 -6 -9 ]
[.88562 .3458 6 0 ]
[.70307 .04633 -18 -4.5 ]
[.70307 .04633 0 4.5 ]
[.70307 .12432 -18 -4.5 ]
[.70307 .12432 0 4.5 ]
[.70307 .20232 -18 -4.5 ]
[.70307 .20232 0 4.5 ]
[.70307 .28031 -18 -4.5 ]
[.70307 .28031 0 4.5 ]
[.70307 .43629 -12 -4.5 ]
[.70307 .43629 0 4.5 ]
[.70307 .51428 -12 -4.5 ]
[.70307 .51428 0 4.5 ]
[.70307 .59228 -12 -4.5 ]
[.70307 .59228 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03536 .3583 m
.03536 .36455 L
s
[(-40)] .03536 .3458 0 1 Mshowa
.20541 .3583 m
.20541 .36455 L
s
[(-30)] .20541 .3458 0 1 Mshowa
.37546 .3583 m
.37546 .36455 L
s
[(-20)] .37546 .3458 0 1 Mshowa
.54551 .3583 m
.54551 .36455 L
s
[(-10)] .54551 .3458 0 1 Mshowa
.88562 .3583 m
.88562 .36455 L
s
[(10)] .88562 .3458 0 1 Mshowa
.125 Mabswid
.06937 .3583 m
.06937 .36205 L
s
.10338 .3583 m
.10338 .36205 L
s
.13739 .3583 m
.13739 .36205 L
s
.1714 .3583 m
.1714 .36205 L
s
.23942 .3583 m
.23942 .36205 L
s
.27343 .3583 m
.27343 .36205 L
s
.30744 .3583 m
.30744 .36205 L
s
.34145 .3583 m
.34145 .36205 L
s
.40947 .3583 m
.40947 .36205 L
s
.44348 .3583 m
.44348 .36205 L
s
.47749 .3583 m
.47749 .36205 L
s
.5115 .3583 m
.5115 .36205 L
s
.57952 .3583 m
.57952 .36205 L
s
.61353 .3583 m
.61353 .36205 L
s
.64754 .3583 m
.64754 .36205 L
s
.68155 .3583 m
.68155 .36205 L
s
.74958 .3583 m
.74958 .36205 L
s
.78359 .3583 m
.78359 .36205 L
s
.8176 .3583 m
.8176 .36205 L
s
.85161 .3583 m
.85161 .36205 L
s
.00135 .3583 m
.00135 .36205 L
s
.91963 .3583 m
.91963 .36205 L
s
.95364 .3583 m
.95364 .36205 L
s
.98765 .3583 m
.98765 .36205 L
s
.25 Mabswid
0 .3583 m
1 .3583 L
s
.71557 .04633 m
.72182 .04633 L
s
[(-40)] .70307 .04633 1 0 Mshowa
.71557 .12432 m
.72182 .12432 L
s
[(-30)] .70307 .12432 1 0 Mshowa
.71557 .20232 m
.72182 .20232 L
s
[(-20)] .70307 .20232 1 0 Mshowa
.71557 .28031 m
.72182 .28031 L
s
[(-10)] .70307 .28031 1 0 Mshowa
.71557 .43629 m
.72182 .43629 L
s
[(10)] .70307 .43629 1 0 Mshowa
.71557 .51428 m
.72182 .51428 L
s
[(20)] .70307 .51428 1 0 Mshowa
.71557 .59228 m
.72182 .59228 L
s
[(30)] .70307 .59228 1 0 Mshowa
.125 Mabswid
.71557 .06193 m
.71932 .06193 L
s
.71557 .07753 m
.71932 .07753 L
s
.71557 .09313 m
.71932 .09313 L
s
.71557 .10873 m
.71932 .10873 L
s
.71557 .13992 m
.71932 .13992 L
s
.71557 .15552 m
.71932 .15552 L
s
.71557 .17112 m
.71932 .17112 L
s
.71557 .18672 m
.71932 .18672 L
s
.71557 .21792 m
.71932 .21792 L
s
.71557 .23351 m
.71932 .23351 L
s
.71557 .24911 m
.71932 .24911 L
s
.71557 .26471 m
.71932 .26471 L
s
.71557 .29591 m
.71932 .29591 L
s
.71557 .31151 m
.71932 .31151 L
s
.71557 .3271 m
.71932 .3271 L
s
.71557 .3427 m
.71932 .3427 L
s
.71557 .3739 m
.71932 .3739 L
s
.71557 .3895 m
.71932 .3895 L
s
.71557 .4051 m
.71932 .4051 L
s
.71557 .42069 m
.71932 .42069 L
s
.71557 .45189 m
.71932 .45189 L
s
.71557 .46749 m
.71932 .46749 L
s
.71557 .48309 m
.71932 .48309 L
s
.71557 .49869 m
.71932 .49869 L
s
.71557 .52988 m
.71932 .52988 L
s
.71557 .54548 m
.71932 .54548 L
s
.71557 .56108 m
.71932 .56108 L
s
.71557 .57668 m
.71932 .57668 L
s
.71557 .03073 m
.71932 .03073 L
s
.71557 .01514 m
.71932 .01514 L
s
.71557 .60787 m
.71932 .60787 L
s
.25 Mabswid
.71557 0 m
.71557 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.89364 .60332 m
.88551 .60143 L
.87638 .59865 L
.85713 .59055 L
.83434 .57733 L
.81125 .56045 L
.76125 .5138 L
.69501 .44066 L
.60905 .3463 L
.49298 .23726 L
.42014 .18115 L
.33016 .12258 L
.243 .07444 L
.16545 .04301 L
.13063 .03143 L
.09642 .02193 L
.07969 .01816 L
.07212 .0167 L
.06562 .01559 L
.06259 .01516 L
.0598 .01496 L
.05725 .01483 L
.05499 .01475 L
.05267 .01472 L
.05139 .01472 L
.05022 .01473 L
.04794 .01481 L
.04671 .01487 L
.04561 .01495 L
.04373 .01511 L
.04205 .01531 L
.04014 .01559 L
.03848 .01589 L
.03537 .01665 L
.03242 .01766 L
.03037 .01861 L
.02843 .0198 L
.02677 .0212 L
.02556 .02264 L
.025 .02352 L
.02452 .02452 L
.02434 .025 L
.02418 .02552 L
.02396 .02647 L
.02384 .02741 L
.02381 .02833 L
.02386 .02936 L
.02401 .03051 L
.02415 .03115 L
.0243 .03176 L
Mistroke
.02474 .03318 L
.02591 .03588 L
.02738 .03846 L
.02938 .04133 L
.03231 .04429 L
.03626 .04755 L
.04448 .05367 L
.06808 .06876 L
.12599 .09933 L
.26982 .15806 L
.43786 .21668 L
.58588 .26725 L
.71534 .31642 L
.81124 .36106 L
.87921 .40214 L
.90549 .42227 L
.92887 .44396 L
.94626 .46414 L
.95832 .48201 L
.96727 .49977 L
.97065 .50875 L
.97327 .51792 L
.97419 .52205 L
.97491 .52588 L
.97523 .52797 L
.97553 .53022 L
.97574 .53207 L
.97592 .53409 L
.97598 .535 L
.97604 .53597 L
.97609 .53681 L
.97613 .53772 L
.97616 .53874 L
.97618 .5397 L
.97619 .54063 L
.97619 .54149 L
.97618 .54228 L
.97617 .54302 L
.97614 .54382 L
.97611 .54469 L
.97601 .54644 L
.97589 .54803 L
.97572 .54982 L
.97552 .55144 L
.97497 .55499 L
.97431 .55819 L
.97359 .56114 L
.97156 .56747 L
.96871 .57388 L
.96568 .57908 L
Mistroke
.96179 .58434 L
.95716 .58926 L
.9523 .59333 L
.94743 .59656 L
.94243 .59919 L
.93763 .60116 L
.93208 .60289 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oagoo00<007ooOol0
CWoo0037Ool00`00Oomoo`1>Ool00<Moo`03001oogoo04ioo`00agoo00<007ooOol0CWoo0037Ool0
0`00Oomoo`1>Ool000Uoo``00;9oo`8004moo`001goo0P0037oo1000[Woo00<007ooOol0CWoo0007
Ool00`00Oomoo`0?Ool5002YOol00`00Oomoo`1>Ool000Ioo`8001Ioo`@00:Eoo`03001oogoo04io
o`001Woo0P006Woo1000XGoo0P00Cgoo0007Ool00`00Oomoo`0LOol3002NOol00`00Oomoo`1>Ool0
00Moo`03001oogoo01moo`@008moo`<0009oo`03001oogoo00=oo`03001oogoo04ioo`0027oo00<0
07ooOol08Woo0`00SGoo00H007ooOol007oo0004Ool00`00Oomoo`1>Ool000Uoo`03001oogoo02Ao
o`8008Aoo`<0009oo`@00004Ool007oo0004Ool3001>Ool000Yoo`03001oogoo02Eoo`8008Moo`03
001oo`00009oo`03001oo`0000Aoo`03001oogoo04ioo`002goo0P009goo0`00QGoo0P000Woo00<0
07oo000017oo00<007ooOol0CWoo000=Ool2000XOol20024Ool01@00Oomoogoo00001Goo00<007oo
Ool0CWoo000?Ool00`00Oomoo`0WOol2002<Ool00`00Oomoo`1>Ool0011oo`03001oogoo02Qoo`<0
08Uoo`8004moo`004Goo0P00:goo0P00Qgoo00<007ooOol0CWoo000COol00`00Oomoo`0ZOol20025
Ool00`00Oomoo`1>Ool001Aoo`8002aoo`8008=oo`03001oogoo04ioo`005Woo0P00;7oo0P00PGoo
0P00Cgoo000HOol2000/Ool2001oOol00`00Oomoo`1>Ool001Yoo`8002aoo`8007eoo`03001oogoo
04ioo`0077oo0P00;7oo0P00Ngoo00<007ooOol0CWoo000NOol2000/Ool00`00Oomoo`1hOol2001?
Ool0021oo`8002]oo`8007Qoo`03001oogoo04ioo`008Woo0`00:Woo0P00MWoo00<007ooOol0CWoo
000UOol2000ZOol2001dOol00`00Oomoo`1>Ool002Moo`<002Uoo`03001oogoo075oo`03001oogoo
04ioo`00:Woo0P00:7oo0P00LGoo0P00Cgoo000/Ool3000WOol2001_Ool00`00Oomoo`1>Ool002mo
o`8002Moo`80065oo`8000Aoo`03001oogoo00=oo`03001oogoo04ioo`00<Goo0`009Woo0P00HGoo
00H007ooOol007oo0004Ool00`00Oomoo`1>Ool003Aoo`8002Ioo`03001oogoo05Moo`<000=oo`07
001oogooOol007oo000017oo0`00CWoo000fOol3000TOol2001NOol01P00Oomoo`00Ool000Aoo`03
001oogoo04ioo`00>Goo0P0097oo00<007ooOol0FGoo00<007oo00000Woo00<007oo000017oo00<0
07ooOol0CWoo000kOol3000ROol2001JOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1>
Ool003ioo`80029oo`8006=oo`8004moo`00@7oo0`008Goo00<007ooOol0H7oo00<007ooOol0CWoo
0013Ool2000POol2001POol00`00Oomoo`1>Ool004Eoo`<001moo`03001oogoo05eoo`03001oogoo
04ioo`00B7oo0P007Woo0P00GGoo00<007ooOol0CWoo001:Ool3000MOol00`00Oomoo`1JOol2001?
Ool004eoo`<001]oo`8005Yoo`03001oogoo04ioo`00D7oo0P006goo00<007ooOol0Egoo00<007oo
Ool0CWoo001BOol3000IOol2001GOol00`00Oomoo`1>Ool005Eoo`<001Qoo`8005Eoo`8004moo`00
F7oo0`005goo00<007ooOol0DWoo00<007ooOol0CWoo001KOol2000FOol2001BOol00`00Oomoo`1>
Ool005eoo`<001Eoo`03001oogoo04moo`03001oogoo04ioo`00H7oo0`004goo00<007ooOol0CWoo
0P00Cgoo001SOol3000AOol2001>Ool00`00Oomoo`1>Ool006Ioo`<0011oo`03001oogoo04]oo`03
001oogoo04ioo`00JGoo0P003goo00<007ooOol0?Woo0`000goo00<007ooOol00goo00<007ooOol0
CWoo001[Ool3000=Ool00`00Oomoo`0mOol00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`1>
Ool006ioo`<000]oo`8003Qoo`<000=oo`07001oogooOol007oo000017oo0`00CWoo001aOol3000:
Ool00`00Oomoo`0kOol01`00Oomoogoo001oo`0000Aoo`03001oogoo04ioo`00M7oo0P002Goo00<0
07ooOol0>Goo00<007oo00000Woo00<007oo000017oo00<007ooOol0CWoo001fOol30007Ool00`00
Oomoo`0iOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`1>Ool007Uoo`<000Eoo`8004Ao
o`8004moo`00O7oo0`0017oo00<007ooOol0@Goo00<007ooOol0CWoo001oOol30002Ool00`00Oomo
o`10Ool00`00Oomoo`1>Ool0089oo`@0045oo`03001oogoo04ioo`00QGoo0`00?goo0P00Cgoo0028
Ool3000lOol00`00Oomoo`1>Ool008Uoo`03001oo`00008003Uoo`03001oogoo04ioo`00RWoo00@0
07ooOomoo`8003Moo`03001oogoo04ioo`00Rgoo00<007ooOol00Woo0`00=7oo00<007ooOol0CWoo
002<Ool00`00Oomoo`04Ool3000aOol2001?Ool008eoo`03001oogoo00Ioo`<002ioo`03001oogoo
04ioo`00SWoo00<007ooOol027oo0`00:goo00<007ooOol0CWoo002?Ool00`00Oomoo`0:Ool3000X
Ool00`00Oomoo`1>Ool0091oo`03001oogoo00aoo`<002Eoo`8004moo`00TGoo0P003goo0`008Woo
00<007ooOol0CWoo002COol00`00Oomoo`0?Ool2000POol00`00Oomoo`1>Ool009Aoo`03001oogoo
011oo`<0011oo`D0009oo`03001oogoo00=oo`03001oogoo04ioo`00UGoo00<007ooOol04Woo0P00
47oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1>Ool009Ioo`03001oogoo01=oo`<000Moo`<0
00=oo`07001oogooOol007oo000017oo0`00CWoo002GOol00`00Oomoo`0EOol3000:Ool01`00Oomo
ogoo001oo`0000Aoo`03001oogoo04ioo`00V7oo00<007ooOol05goo0P0027oo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`1>Ool009Uoo`03001oogoo01Qoo`<000Aoo`8000Aoo`03001oogoo00=o
o`03001oogoo04ioo`00VWoo00<007ooOol06Woo0P003Woo0P00Cgoo002KOol00`00Oomoo`0KOol3
000;Ool00`00Oomoo`1>Ool009aoo`03001oogoo01eoo`8000Uoo`03001oogoo04ioo`00WGoo00<0
07ooOol07Woo0`001Woo00<007ooOol0CWoo002NOol00`00Oomoo`0POol30003Ool2001?Ool009mo
o`03001oogoo029oo`800003Ool007oo04moo`002Goo0`000Woo00<007ooOol09goo0P0017oo00<0
07ooOol09Woo0`000goo00<007ooOol09Goo1@000Woo00D007ooOomoo`0002Eoo`<002Qoo`D0009o
o`03001oogoo01eoo`002Woo00H007ooOol007oo000ZOol01P00Oomoo`00Ool002Moo`03001oogoo
009oo`03001oo`0002Qoo`07001oogooOol007oo00000goo0P0097oo00@007oo000002Qoo`07001o
ogooOol007oo00007Woo0003Ool30002Ool4000017oo001oo`008goo0`000goo00L007ooOomoo`00
Ool0000ROol30003Ool01`00Oomoogoo001oo`00029oo`<000=oo`07001oogooOol007oo00001Goo
00<007ooOol08Goo00@007ooOomoo`8002Ioo`07001oogooOol007oo00007Woo0008Ool00`00Ool0
0002Ool00`00Ool0000ZOol01P00Oomoo`00Ool002Qoo`07001oogooOol007oo0000:7oo00L007oo
Oomoo`00Ool00006Ool00`00Oomoo`0POol20004Ool2000TOol01`00Oomoogoo001oo`0001ioo`00
2Goo0P000Woo00<007oo0000:7oo00<007oo00000Woo00<007oo00009goo00<007oo00000Woo00<0
07oo0000:7oo00L007ooOomoo`00Ool00007Ool00`00Oomoo`0OOol00`00Oomoo`05Ool3000QOol0
1`00Oomoogoo001oo`0001ioo`002Woo00D007ooOomoo`0002Yoo`03001oogoo009oo`03001oogoo
02Moo`03001oogoo009oo`03001oogoo02Ioo`8000Aoo`03001oogoo00Moo`03001oogoo01ioo`03
001oogoo00Qoo`8001ioo`8000Aoo`03001oogoo01eoo`00Ygoo00<007ooOol07Goo00<007ooOol0
2Woo0P00@Woo002XOol00`00Oomoo`0LOol2000=Ool20010Ool00:Uoo`03001oogoo01]oo`03001o
ogoo00ioo`<003eoo`00ZWoo00<007ooOol06Woo00<007ooOol04Goo0P00>goo002[Ool00`00Oomo
o`0IOol00`00Oomoo`0COol2000iOol00?l001P0005oo`0000<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo
00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo
00<007ooOol01goo00<007oo00001Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol017oo0`002Goo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01goo00<007ooOol00Woo000:Ool00`00Oomoo`0/Ool00`00Oomoo`0/Ool0
0`00Oomoo`0]Ool00`00Oomoo`0COol00`00Oomoo`0FOol00`00Oomoo`0IOol2000AOol00`00Oomo
o`0OOol00:moo`03001oogoo01Eoo`03001oogoo01]oo`80035oo`00[goo00<007ooOol05Goo00<0
07ooOol07Goo0P00;goo002`Ool00`00Oomoo`0DOol2000POol00`00Oomoo`0/Ool00;5oo`03001o
ogoo01=oo`03001oogoo021oo`8002aoo`00/Woo00<007ooOol04Woo00<007ooOol08Woo0P00:Woo
002cOol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00Oomoo`0WOol00;Aoo`03001oogoo011oo`80
02Ioo`8002Moo`00]Goo00<007ooOol03goo00<007ooOol09goo0P009Goo002fOol00`00Oomoo`0>
Ool00`00Oomoo`0YOol2000SOol00;Moo`03001oogoo00eoo`03001oogoo02]oo`03001oogoo021o
o`00^7oo00<007ooOol037oo0P00;Goo00<007ooOol07goo002iOol00`00Oomoo`0;Ool00`00Oomo
o`0]Ool00`00Oomoo`0NOol00;Yoo`03001oogoo00Yoo`03001oogoo02ioo`8001ioo`00^goo00<0
07ooOol02Goo00<007ooOol0<7oo00<007ooOol06goo002kOol00`00Oomoo`09Ool00`00Oomoo`0a
Ool00`00Oomoo`0JOol00;aoo`03001oogoo00Qoo`8003=oo`03001oogoo01Uoo`00_Goo00<007oo
Ool01goo00<007ooOol0<goo00<007ooOol067oo002jOol50002Ool00`00Oomoo`03Ool00`00Oomo
o`0dOol00`00Oomoo`0GOol00;aoo`03001oogoo00800003Ool007oo00=oo`03001oogoo03Eoo`03
001oogoo01Ioo`00_7oo00L007ooOomoo`00Ool00004Ool3000fOol00`00Oomoo`0EOol00;aoo`04
001oogooOol30004Ool00`00Oomoo`0gOol00`00Oomoo`0DOol00;aoo`07001oogooOol007oo0000
17oo00<007ooOol0>7oo00<007ooOol04goo002kOol20004Ool00`00Ool00003Ool00`00Oomoo`0i
Ool00`00Oomoo`0BOol00<Aoo`03001oogoo008003]oo`03001oogoo015oo`00aGoo00<007oo0000
?7oo00<007ooOol04Goo0036Ool2000mOol00`00Oomoo`0@Ool00<Moo`03001oogoo03aoo`03001o
ogoo00moo`00agoo0P00?Woo00<007ooOol03Woo0037Ool3000nOol00`00Oomoo`0=Ool00<Moo`04
001oogoo000nOol00`00Oomoo`0<Ool00<Moo`04001oogoo000nOol00`00Oomoo`0<Ool00<Moo`05
001oogooOol0000nOol00`00Oomoo`0;Ool00<Moo`8000=oo`03001oogoo03aoo`03001oogoo00Yo
o`00agoo00<007ooOol00goo00<007ooOol0>goo00<007ooOol02Woo0037Ool00`00Oomoo`04Ool0
0`00Oomoo`0kOol00`00Oomoo`09Ool00<Moo`03001oogoo00Eoo`03001oogoo03Yoo`03001oogoo
00Uoo`00agoo0P001goo00<007ooOol0>Woo00<007ooOol027oo0037Ool00`00Oomoo`07Ool00`00
Oomoo`0iOol00`00Oomoo`08Ool00<Moo`03001oogoo00Qoo`03001oogoo03Qoo`03001oogoo00Qo
o`00^goo0`000goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol01goo
002kOol00`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`0:Ool00`00Oomoo`0gOol00`00Oomo
o`07Ool00;aoo`07001oogooOol007oo000017oo0`002goo00<007ooOol0=goo00<007ooOol01Woo
002lOol01`00Oomoogoo001oo`0000Aoo`03001oogoo00aoo`03001oogoo03Ioo`03001oogoo00Io
o`00^goo00<007oo00000Woo00<007oo000017oo00<007ooOol03Goo00<007ooOol0=Goo00<007oo
Ool01Woo002lOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`0dOol0
0`00Oomoo`06Ool00<Moo`80011oo`03001oogoo03=oo`03001oogoo00Ioo`00agoo00<007ooOol0
47oo00<007ooOol0<Woo00<007ooOol01Woo0037Ool00`00Oomoo`0AOol2000bOol20007Ool00<Mo
o`03001oogoo01=oo`03001oogoo031oo`03001oogoo00Eoo`00agoo0P005Goo00<007ooOol0;goo
00<007ooOol01Goo0037Ool00`00Oomoo`0EOol00`00Oomoo`0]Ool00`00Oomoo`06Ool00<Moo`03
001oogoo01Ioo`03001oogoo02aoo`03001oogoo00Ioo`00agoo00<007ooOol05goo00<007ooOol0
:goo00<007ooOol01Woo0037Ool00`00Oomoo`0HOol00`00Oomoo`0ZOol00`00Oomoo`06Ool00<Mo
o`8001Yoo`03001oogoo02Uoo`03001oogoo00Ioo`00agoo00<007ooOol06Woo00<007ooOol09goo
00<007ooOol01goo0037Ool00`00Oomoo`0KOol2000VOol00`00Oomoo`08Ool00<Moo`03001oogoo
01eoo`03001oogoo02=oo`03001oogoo00Qoo`00agoo0P007goo00<007ooOol08Woo00<007ooOol0
27oo0037Ool00`00Oomoo`0OOol2000ROol00`00Oomoo`08Ool00;]oo`8000Aoo`03001oogoo00=o
o`03001oogoo025oo`03001oogoo01ioo`03001oogoo00Uoo`00_Goo00H007ooOol007oo0004Ool0
0`00Oomoo`0ROol2000LOol2000<Ool00;aoo`07001oogooOol007oo000017oo0`0097oo0P006Goo
00<007ooOol037oo002mOol01P00Oomoo`00Ool000Aoo`03001oogoo02Ioo`<001Ioo`03001oogoo
00aoo`00^goo00<007oo00000Woo00<007oo000017oo00<007ooOol0:Goo0P004Goo0`003goo002l
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0[Ool50009Ool3000BOol00<Moo`03001o
ogoo04ioo`00agoo0P00Cgoo0037Ool00`00Oomoo`1>Ool00<Moo`03001oogoo04ioo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-42.1533, -45.9411, 0.211303, 
  0.460719}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Friction Load "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A very simple Coulombic friction load is applied to the rotational axis of \
the drive bar, with respect to the ground. The load is a pure moment \
resisting the direction of motion, the magnitude of which is proportional to \
the magnitude of the reaction vector at the drive bar axis. A coefficient of \
friction of 0.5 is assumed and is applied to a journal bearing with radius \
0.4. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a simple Coulombic friction load. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ld[2] = 
      Moment[drivebar, 
        \(-0.5\)\ 0.4\ 
          Magnitude[
            \(Reaction[2, drivebar]\)\[LeftDoubleBracket]1
              \[RightDoubleBracket]]]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The load is added to the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1], ld[2]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[" More Plots "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This generates another interpolated solution set."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(irules = 
      SolveMech[{0, 1}, 21, Solution \[Rule] Kinematic, 
        Interpolation \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The drive torque function that was developed earlier can be plotted again \
with the new solution rules. Note that the required drive torque is slightly \
higher. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a plot of the drive torque with friction at the ",
  StyleBox["drivebar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " axis. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[drivetorque /. irules], {T, 0, 1}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.00831514 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .09787 -12 -4.5 ]
[.01131 .09787 0 4.5 ]
[.01131 .18102 -12 -4.5 ]
[.01131 .18102 0 4.5 ]
[.01131 .26417 -12 -4.5 ]
[.01131 .26417 0 4.5 ]
[.01131 .34732 -12 -4.5 ]
[.01131 .34732 0 4.5 ]
[.01131 .43047 -12 -4.5 ]
[.01131 .43047 0 4.5 ]
[.01131 .51362 -12 -4.5 ]
[.01131 .51362 0 4.5 ]
[.01131 .59677 -12 -4.5 ]
[.01131 .59677 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .09787 m
.03006 .09787 L
s
[(10)] .01131 .09787 1 0 Mshowa
.02381 .18102 m
.03006 .18102 L
s
[(20)] .01131 .18102 1 0 Mshowa
.02381 .26417 m
.03006 .26417 L
s
[(30)] .01131 .26417 1 0 Mshowa
.02381 .34732 m
.03006 .34732 L
s
[(40)] .01131 .34732 1 0 Mshowa
.02381 .43047 m
.03006 .43047 L
s
[(50)] .01131 .43047 1 0 Mshowa
.02381 .51362 m
.03006 .51362 L
s
[(60)] .01131 .51362 1 0 Mshowa
.02381 .59677 m
.03006 .59677 L
s
[(70)] .01131 .59677 1 0 Mshowa
.125 Mabswid
.02381 .03135 m
.02756 .03135 L
s
.02381 .04798 m
.02756 .04798 L
s
.02381 .06461 m
.02756 .06461 L
s
.02381 .08124 m
.02756 .08124 L
s
.02381 .1145 m
.02756 .1145 L
s
.02381 .13113 m
.02756 .13113 L
s
.02381 .14776 m
.02756 .14776 L
s
.02381 .16439 m
.02756 .16439 L
s
.02381 .19765 m
.02756 .19765 L
s
.02381 .21428 m
.02756 .21428 L
s
.02381 .23091 m
.02756 .23091 L
s
.02381 .24754 m
.02756 .24754 L
s
.02381 .2808 m
.02756 .2808 L
s
.02381 .29743 m
.02756 .29743 L
s
.02381 .31406 m
.02756 .31406 L
s
.02381 .33069 m
.02756 .33069 L
s
.02381 .36395 m
.02756 .36395 L
s
.02381 .38058 m
.02756 .38058 L
s
.02381 .39721 m
.02756 .39721 L
s
.02381 .41384 m
.02756 .41384 L
s
.02381 .4471 m
.02756 .4471 L
s
.02381 .46373 m
.02756 .46373 L
s
.02381 .48036 m
.02756 .48036 L
s
.02381 .49699 m
.02756 .49699 L
s
.02381 .53025 m
.02756 .53025 L
s
.02381 .54688 m
.02756 .54688 L
s
.02381 .56351 m
.02756 .56351 L
s
.02381 .58014 m
.02756 .58014 L
s
.02381 .61341 m
.02756 .61341 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33101 m
.04262 .31324 L
.06244 .28751 L
.10458 .21685 L
.14264 .1436 L
.16385 .10712 L
.17388 .09226 L
.18314 .08091 L
.18772 .07647 L
.19276 .0726 L
.19537 .07104 L
.19782 .06989 L
.19915 .06939 L
.20041 .06899 L
.2011 .06881 L
.20186 .06864 L
.2025 .06853 L
.20319 .06843 L
.20447 .06831 L
.20568 .06828 L
.20686 .06833 L
.20795 .06845 L
.20912 .06866 L
.21041 .06898 L
.21176 .06943 L
.21302 .06995 L
.2142 .07053 L
.21532 .07164 L
.21742 .07401 L
.22214 .08034 L
.23179 .09752 L
.24205 .12167 L
.26047 .17903 L
.27994 .26257 L
.29822 .34947 L
.31669 .43687 L
.33691 .52202 L
.34659 .55563 L
.35192 .57147 L
.35453 .57847 L
.35695 .58446 L
.35828 .58683 L
.35969 .58904 L
.36267 .59318 L
.36536 .59629 L
.36788 .59868 L
.37021 .60045 L
.37272 .60188 L
.37415 .60247 L
.37485 .60271 L
Mistroke
.3755 .60289 L
.37672 .60315 L
.37736 .60324 L
.37805 .6033 L
.37929 .60332 L
.38 .60328 L
.38066 .60321 L
.38136 .60309 L
.38199 .60296 L
.38342 .60255 L
.38464 .60208 L
.38596 .60145 L
.38836 .59998 L
.39117 .59773 L
.39415 .59472 L
.3995 .58776 L
.40445 .57955 L
.4091 .56891 L
.41968 .53964 L
.45842 .39811 L
.49961 .24466 L
.52018 .18366 L
.53929 .13674 L
.55775 .10119 L
.56801 .08575 L
.57745 .07416 L
.58772 .06444 L
.59312 .06053 L
.59584 .05894 L
.59883 .05766 L
.60142 .05676 L
.60386 .05607 L
.60521 .05576 L
.60668 .05547 L
.60791 .05528 L
.60926 .05511 L
.61052 .05499 L
.61171 .05491 L
.61296 .05487 L
.61367 .05487 L
.61432 .05487 L
.6154 .0549 L
.6166 .05496 L
.61784 .05507 L
.619 .05519 L
.62162 .05559 L
.62404 .0561 L
.6295 .05769 L
.63432 .05959 L
.63943 .06209 L
Mistroke
.65801 .0745 L
.67756 .09256 L
.69587 .11267 L
.73466 .16102 L
.7759 .21754 L
.81563 .27069 L
.85384 .3139 L
.87353 .331 L
.88446 .3385 L
.89451 .34394 L
.9048 .34808 L
.91022 .34966 L
.91298 .3503 L
.91594 .35085 L
.91854 .35124 L
.92091 .35149 L
.92206 .35159 L
.9233 .35167 L
.92447 .35172 L
.92556 .35175 L
.92681 .35176 L
.92799 .35174 L
.92928 .3517 L
.93001 .35167 L
.93068 .35163 L
.93194 .35154 L
.93332 .35141 L
.93611 .35105 L
.93862 .35062 L
.94134 .35003 L
.94627 .34865 L
.95107 .3469 L
.95549 .34493 L
.96555 .33916 L
.97619 .33101 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo000nOol0
0`00Oomoo`02Ool01000Oomoogoo0`009goo00<007ooOol00Woo00<007ooOol00Woo0`009Goo00<0
07ooOol00Woo00@007ooOomoo`8002Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Qo
o`D000Qoo`00?Goo00<007oo00001goo00<007ooOol09Woo00<007oo00002Goo00<007ooOol08goo
00<007oo00001goo00<007oo00009Woo00<007oo00001goo00<007oo0000:goo00<007ooOol027oo
000mOol00`00Ool00008Ool00`00Oomoo`0UOol00`00Ool00007Ool4000TOol00`00Ool00007Ool0
0`00Ool0000VOol00`00Ool00007Ool00`00Ool0000[Ool00`00Oomoo`08Ool003eoo`03001oo`00
00Qoo`03001oogoo02Eoo`03001oo`0000Moo`03001oo`0002Eoo`03001oo`0000Moo`8002Moo`03
001oo`0000Qoo`03001oogoo02Yoo`03001oogoo00Qoo`00?Goo00<007oo00001goo00<007oo0000
9Woo00<007oo000027oo0P009Goo00<007oo00001goo00<007ooOol09Woo00<007oo00001goo00<0
07oo0000:goo00<007ooOol027oo000nOol00`00Oomoo`07Ool00`00Oomoo`0VOol00`00Oomoo`08
Ool00`00Oomoo`0TOol00`00Oomoo`07Ool2000WOol00`00Oomoo`07Ool00`00Oomoo`0YOol2000:
Ool00?mooaUoo`00ogoo6Goo000AOol00`00Oomoo`3oOol5Ool0015oo`03001oogoo0?moo`Eoo`00
4Goo00<007ooOol0ogoo1Goo000AOol00`00Oomoo`3oOol5Ool000]oool000/000=oo`004Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol01goo000AOol00`00Oomoo`3oOol5Ool0015oo`03001oogoo0?moo`Eoo`004Goo0P00ogoo
1Woo000AOol00`00Oomoo`3oOol5Ool0015oo`03001oogoo0?moo`Eoo`004Goo00<007ooOol0ogoo
1Goo000AOol00`00Oomoo`3oOol5Ool0015oo`800?moo`Ioo`004Goo00<007ooOol0V7oo1000J7oo
000AOol00`00Oomoo`2FOol30002Ool4001UOol0015oo`03001oogoo09Aoo`8000Uoo`8006=oo`00
4Goo0P00U7oo00<007ooOol02goo00<007ooOol0H7oo000AOol00`00Oomoo`0/Ool5001QOol00`00
Oomoo`0=Ool2001POol0015oo`03001oogoo02Yoo`8000Aoo`03001oogoo05ioo`03001oogoo011o
o`03001oogoo05eoo`004Goo00<007ooOol0:Goo00<007ooOol01Goo00<007ooOol0G7oo00<007oo
Ool04Woo00<007ooOol0G7oo000AOol2000YOol00`00Oomoo`07Ool00`00Oomoo`1JOol00`00Oomo
o`0DOol2001LOol0015oo`03001oogoo02Moo`03001oogoo00Uoo`03001oogoo05Uoo`03001oogoo
01Ioo`03001oogoo05Uoo`004Goo00<007ooOol09Woo00<007ooOol02Woo00<007ooOol0F7oo00<0
07ooOol067oo0P00FGoo0004Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`0UOol00`00Oomoo`0<
Ool00`00Oomoo`1FOol00`00Oomoo`0KOol00`00Oomoo`1FOol000Ioo`07001oogooOol007oo0000
17oo00<007ooOol097oo00<007ooOol03Goo00<007ooOol0EGoo00<007ooOol07Goo00<007ooOol0
EGoo0006Ool01`00Oomoogoo001oo`0000Aoo`<002Aoo`03001oogoo00ioo`03001oogoo05Aoo`03
001oogoo01eoo`03001oogoo05Eoo`001Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`0SOol0
0`00Oomoo`0?Ool00`00Oomoo`1COol00`00Oomoo`0OOol00`00Oomoo`1DOol000Ioo`07001oogoo
Ool007oo000017oo00<007ooOol08goo00<007ooOol047oo00<007ooOol0DGoo00<007ooOol08Goo
00<007ooOol0Dgoo0005Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`0ROol00`00Oomoo`0AOol0
0`00Oomoo`1AOol00`00Oomoo`0QOol00`00Oomoo`1COol0015oo`8002=oo`03001oogoo015oo`03
001oogoo051oo`03001oogoo02=oo`03001oogoo059oo`004Goo00<007ooOol08Goo00<007ooOol0
4goo00<007ooOol0Cgoo00<007ooOol097oo00<007ooOol0DGoo000AOol00`00Oomoo`0QOol00`00
Oomoo`0COol00`00Oomoo`1>Ool00`00Oomoo`0VOol00`00Oomoo`1@Ool0015oo`03001oogoo021o
o`03001oogoo01Aoo`03001oogoo04ioo`03001oogoo02Moo`03001oogoo04moo`004Goo00<007oo
Ool07goo00<007ooOol05Woo00<007ooOol0C7oo00<007ooOol0:7oo00<007ooOol0Cgoo000AOol2
000POol00`00Oomoo`0FOol00`00Oomoo`1<Ool00`00Oomoo`0YOol00`00Oomoo`1>Ool0015oo`03
001oogoo01ioo`03001oogoo01Moo`03001oogoo04]oo`03001oogoo02]oo`03001oogoo04eoo`00
4Goo00<007ooOol07Woo00<007ooOol067oo00<007ooOol0BWoo00<007ooOol0;7oo00<007ooOol0
C7oo000AOol00`00Oomoo`0MOol00`00Oomoo`0IOol00`00Oomoo`19Ool00`00Oomoo`0^Ool00`00
Oomoo`1;Ool0015oo`8001eoo`03001oogoo01Yoo`03001oogoo04Uoo`03001oogoo02moo`03001o
ogoo04Yoo`004Goo00<007ooOol077oo00<007ooOol06goo00<007ooOol0Agoo00<007ooOol0<7oo
00<007ooOol0BWoo000AOol00`00Oomoo`0KOol00`00Oomoo`0LOol00`00Oomoo`17Ool00`00Oomo
o`0aOol00`00Oomoo`19Ool0015oo`03001oogoo01]oo`03001oogoo01aoo`03001oogoo04Moo`03
001oogoo039oo`03001oogoo04Qoo`004Goo0P006goo00<007ooOol07Woo00<007ooOol0AGoo00<0
07ooOol0=7oo00<007ooOol0Agoo000AOol00`00Oomoo`0JOol00`00Oomoo`0NOol00`00Oomoo`15
Ool00`00Oomoo`0eOol00`00Oomoo`16Ool0015oo`03001oogoo01Uoo`03001oogoo01moo`03001o
ogoo04Eoo`03001oogoo03Ioo`03001oogoo04Eoo`001Goo0`000goo00<007ooOol00goo00<007oo
Ool06Goo00<007ooOol087oo00<007ooOol0@goo00<007ooOol0=goo00<007ooOol0AGoo0005Ool0
0`00Oomoo`02Ool00`00Ool00004Ool00`00Oomoo`0HOol00`00Oomoo`0QOol00`00Oomoo`13Ool0
0`00Oomoo`0hOol00`00Oomoo`14Ool000Ioo`07001oogooOol007oo000017oo0`0067oo00<007oo
Ool08Goo00<007ooOol0@Woo00<007ooOol0>Woo00<007ooOol0@goo0006Ool01`00Oomoogoo001o
o`0000Aoo`03001oogoo01Moo`03001oogoo029oo`03001oogoo049oo`03001oogoo03]oo`03001o
ogoo049oo`001Goo00<007oo00000Woo00<007oo000017oo00<007ooOol05goo00<007ooOol08goo
00<007ooOol0@Goo00<007ooOol0>goo00<007ooOol0@Woo0006Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0FOol00`00Oomoo`0TOol00`00Oomoo`10Ool00`00Oomoo`0mOol00`00Oomo
o`11Ool0015oo`8001Moo`03001oogoo02Aoo`03001oogoo041oo`03001oogoo03ioo`03001oogoo
041oo`004Goo00<007ooOol05Goo00<007ooOol09Goo00<007ooOol0?goo00<007ooOol0@7oo00<0
07ooOol0?goo000AOol00`00Oomoo`0EOol00`00Oomoo`0VOol00`00Oomoo`0nOol00`00Oomoo`11
Ool00`00Oomoo`0nOol0015oo`03001oogoo01Aoo`03001oogoo02Moo`03001oogoo03ioo`03001o
ogoo045oo`03001oogoo03ioo`004Goo00<007ooOol057oo00<007ooOol09goo00<007ooOol0?Goo
00<007ooOol0@goo00<007ooOol0?Goo000AOol2000DOol00`00Oomoo`0XOol00`00Oomoo`0mOol0
0`00Oomoo`14Ool00`00Oomoo`0lOol0015oo`03001oogoo019oo`03001oogoo02Uoo`03001oogoo
03eoo`03001oogoo04Eoo`03001oogoo03]oo`004Goo00<007ooOol04Woo00<007ooOol0:Woo00<0
07ooOol0>goo00<007ooOol0AWoo00<007ooOol0>goo000AOol00`00Oomoo`0AOol00`00Oomoo`0[
Ool00`00Oomoo`0kOol00`00Oomoo`17Ool00`00Oomoo`0jOol0015oo`80019oo`03001oogoo02]o
o`03001oogoo03Yoo`03001oogoo04Uoo`03001oogoo03Uoo`004Goo00<007ooOol047oo00<007oo
Ool0;7oo00<007ooOol0>Woo00<007ooOol0BGoo00<007ooOol0>Goo000AOol00`00Oomoo`0@Ool0
0`00Oomoo`0]Ool00`00Oomoo`0iOol00`00Oomoo`1:Ool00`00Oomoo`0hOol0015oo`03001oogoo
00moo`03001oogoo02ioo`03001oogoo03Qoo`03001oogoo04aoo`03001oogoo03Moo`004Goo0P00
3goo00<007ooOol0;goo00<007ooOol0>7oo00<007ooOol0C7oo00<007ooOol0=goo000AOol00`00
Oomoo`0>Ool00`00Oomoo`0_Ool00`00Oomoo`0hOol00`00Oomoo`1=Ool00`00Oomoo`0fOol0015o
o`03001oogoo00eoo`03001oogoo035oo`03001oogoo03Ioo`03001oogoo04moo`03001oogoo03Eo
o`001Goo0P0017oo00<007ooOol00goo00<007ooOol03Goo00<007ooOol0<Goo00<007ooOol0=Woo
00<007ooOol0Cgoo00<007ooOol0=Goo0007Ool01P00Oomoo`00Ool000Aoo`03001oogoo00aoo`03
001oogoo039oo`03001oogoo03Ioo`03001oogoo051oo`03001oogoo03Aoo`001Woo00L007ooOomo
o`00Ool00004Ool3000;Ool00`00Oomoo`0cOol00`00Oomoo`0fOol00`00Oomoo`1AOol00`00Oomo
o`0cOol000Moo`06001oogoo001oo`0017oo00<007ooOol02goo00<007ooOol0<goo00<007ooOol0
=Goo00<007ooOol0DWoo00<007ooOol0<goo0005Ool00`00Ool00002Ool00`00Ool00004Ool00`00
Oomoo`0:Ool00`00Oomoo`0eOol00`00Oomoo`0dOol00`00Oomoo`1COol00`00Oomoo`0bOol000Io
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo03Eoo`03001oogoo03Ao
o`03001oogoo05Aoo`03001oogoo035oo`004Goo0P002Woo00<007ooOol0=Woo00<007ooOol0=7oo
00<007ooOol0EGoo00<007ooOol0<7oo000AOol00`00Oomoo`09Ool00`00Oomoo`0fOol00`00Oomo
o`0cOol00`00Oomoo`1GOol00`00Oomoo`0_Ool0015oo`03001oogoo00Qoo`03001oogoo03Qoo`03
001oogoo039oo`03001oogoo05Qoo`03001oogoo02ioo`004Goo00<007ooOol01goo00<007ooOol0
>Goo00<007ooOol0<Woo00<007ooOol0FGoo00<007ooOol0;Goo000AOol00`00Oomoo`06Ool00`00
Oomoo`0jOol00`00Oomoo`0aOol00`00Oomoo`1JOol00`00Oomoo`0]Ool0015oo`8000Ioo`03001o
ogoo03]oo`03001oogoo035oo`03001oogoo05]oo`03001oogoo02aoo`004Goo00<007ooOol01Goo
00<007ooOol0>goo00<007ooOol0<Goo00<007ooOol0G7oo00<007ooOol0:goo000AOol00`00Oomo
o`04Ool00`00Oomoo`0mOol00`00Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0ZOol0015oo`03
001oogoo00=oo`03001oogoo03ioo`03001oogoo02moo`03001oogoo05moo`03001oogoo02Uoo`00
4Goo0P000goo00<007ooOol0?goo00<007ooOol0;goo00<007ooOol0H7oo00<007ooOol0:7oo000A
Ool01@00Oomoogoo0000@Woo00<007ooOol0;goo00<007ooOol0HGoo00<007ooOol09goo000AOol0
1000Oomoo`00@goo00<007ooOol0;Woo00<007ooOol0Hgoo00<007ooOol09Woo000AOol00`00Ool0
0015Ool00`00Oomoo`0]Ool00`00Oomoo`1TOol00`00Oomoo`0UOol0015oo`8004Ioo`03001oogoo
02eoo`03001oogoo06Eoo`03001oogoo02Aoo`004Goo00<007ooOol0AGoo00<007ooOol0;Goo00<0
07ooOol0IWoo00<007ooOol06Goo00<007ooOol01goo000AOol00`00Oomoo`15Ool00`00Oomoo`0/
Ool00`00Oomoo`1XOol2000GOol2000:Ool000Ioo`<0009oo`03001oogoo00=oo`03001oogoo04Io
o`03001oogoo02]oo`03001oogoo06Yoo`8001=oo`8000aoo`001goo00H007ooOol007oo0004Ool0
0`00Oomoo`16Ool00`00Oomoo`0[Ool00`00Oomoo`1/Ool3000>Ool2000>Ool000Eoo`@00004Ool0
07oo0004Ool30016Ool00`00Oomoo`0[Ool00`00Oomoo`1_Ool30009Ool2000@Ool000Eoo`03001o
o`00009oo`03001oo`0000Aoo`03001oogoo04Ioo`03001oogoo02Yoo`03001oogoo07=oo`T0019o
o`001Woo0P000Woo00<007oo000017oo00<007ooOol0AWoo00<007ooOol0:Woo00<007ooOol0SWoo
0007Ool01@00Oomoogoo00001Goo00<007ooOol0Agoo00<007ooOol0:Goo00<007ooOol0SWoo000A
Ool20018Ool00`00Oomoo`0XOol00`00Oomoo`2?Ool0015oo`03001oogoo04Moo`03001oogoo02Qo
o`03001oogoo08moo`004Goo00<007ooOol0Agoo00<007ooOol0:7oo00<007ooOol0Sgoo000AOol0
0`00Oomoo`17Ool00`00Oomoo`0XOol00`00Oomoo`2?Ool0015oo`03001oogoo04Qoo`03001oogoo
02Ioo`03001oogoo091oo`004Goo0P00BGoo00<007ooOol09Woo00<007ooOol0T7oo000AOol00`00
Oomoo`18Ool00`00Oomoo`0VOol00`00Oomoo`2@Ool0015oo`03001oogoo04Qoo`03001oogoo02Io
o`03001oogoo091oo`004Goo00<007ooOol0B7oo00<007ooOol09Goo00<007ooOol0TGoo000AOol2
001:Ool00`00Oomoo`0TOol00`00Oomoo`2AOol0015oo`03001oogoo04Uoo`03001oogoo02Aoo`03
001oogoo095oo`004Goo00<007ooOol0BGoo00<007ooOol08goo00<007ooOol0TWoo000AOol00`00
Oomoo`19Ool00`00Oomoo`0SOol00`00Oomoo`2BOol0015oo`8004]oo`03001oogoo029oo`03001o
ogoo099oo`004Goo00<007ooOol0BWoo00<007ooOol08Woo00<007ooOol0TWoo000AOol00`00Oomo
o`1:Ool00`00Oomoo`0QOol00`00Oomoo`2COol000Ioo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo04Yoo`03001oogoo025oo`03001oogoo09=oo`001Goo00<007oo00000Woo00<007oo0000
17oo00<007ooOol0BWoo00<007ooOol08Goo00<007ooOol0Tgoo0007Ool01P00Oomoo`00Ool000Ao
o`<004]oo`03001oogoo021oo`03001oogoo09=oo`001Goo0P000goo00<007oo000017oo00<007oo
Ool0Bgoo00<007ooOol07goo00<007ooOol0U7oo0005Ool00`00Oomoo`02Ool00`00Ool00004Ool0
0`00Oomoo`1;Ool00`00Oomoo`0OOol00`00Oomoo`2DOol000Eoo`<000=oo`03001oogoo00=oo`03
001oogoo04]oo`03001oogoo01moo`03001oogoo09Aoo`004Goo0P00C7oo00<007ooOol07goo00<0
07ooOol0U7oo000AOol00`00Oomoo`1<Ool00`00Oomoo`0MOol00`00Oomoo`2EOol0015oo`03001o
ogoo04aoo`03001oogoo01eoo`03001oogoo09Eoo`004Goo00<007ooOol0C7oo00<007ooOol07Goo
00<007ooOol0UGoo000AOol00`00Oomoo`1<Ool00`00Oomoo`0MOol00`00Oomoo`2EOol0015oo`80
04ioo`03001oogoo01]oo`03001oogoo09Ioo`004Goo00<007ooOol0CGoo00<007ooOol06goo00<0
07ooOol0UWoo000AOol00`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`2FOol0015oo`03001o
ogoo04eoo`03001oogoo01Yoo`03001oogoo09Moo`004Goo0P00CWoo00<007ooOol06Woo00<007oo
Ool0Ugoo000AOol00`00Oomoo`1>Ool00`00Oomoo`0IOol00`00Oomoo`2GOol0015oo`03001oogoo
04ioo`03001oogoo01Uoo`03001oogoo09Moo`004Goo00<007ooOol0CWoo00<007ooOol067oo00<0
07ooOol0V7oo000AOol2001?Ool00`00Oomoo`0HOol00`00Oomoo`2HOol0015oo`03001oogoo04mo
o`03001oogoo01Moo`03001oogoo09Qoo`004Goo00<007ooOol0Cgoo00<007ooOol05goo00<007oo
Ool0V7oo0005Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`1?Ool00`00Oomoo`0FOol00`00Oomo
o`2IOol000Eoo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo04moo`03001oogoo01Ioo`03
001oogoo09Uoo`001Goo00<007oo00000Woo00<007oo000017oo0`00D7oo00<007ooOol05Goo00<0
07ooOol0VGoo0005Ool20003Ool00`00Ool00004Ool00`00Oomoo`1@Ool00`00Oomoo`0EOol00`00
Oomoo`2IOol000Eoo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo051oo`03001oogoo01Ao
o`03001oogoo09Yoo`001Woo0P000goo00<007ooOol00goo00<007ooOol0D7oo00<007ooOol057oo
00<007ooOol0VWoo000AOol2001BOol00`00Oomoo`0COol00`00Oomoo`2JOol0015oo`03001oogoo
055oo`03001oogoo01=oo`03001oogoo09Yoo`004Goo00<007ooOol0DGoo00<007ooOol04Woo00<0
07ooOol0Vgoo000AOol00`00Oomoo`1BOol00`00Oomoo`0AOol00`00Oomoo`2KOol0015oo`03001o
ogoo059oo`03001oogoo015oo`03001oogoo09]oo`004Goo0P00Dgoo00<007ooOol047oo00<007oo
Ool0W7oo000AOol00`00Oomoo`1COol00`00Oomoo`0?Ool00`00Oomoo`2LOol0015oo`03001oogoo
05=oo`03001oogoo00ioo`03001oogoo09eoo`004Goo00<007ooOol0Dgoo00<007ooOol03Woo00<0
07ooOol0WGoo000AOol2001DOol00`00Oomoo`0=Ool00`00Oomoo`2NOol0015oo`03001oogoo05Ao
o`03001oogoo00aoo`03001oogoo09ioo`004Goo00<007ooOol0E7oo00<007ooOol037oo00<007oo
Ool0WWoo000AOol00`00Oomoo`1DOol00`00Oomoo`0;Ool00`00Oomoo`2OOol0015oo`8005Ioo`03
001oogoo00Yoo`03001oogoo09moo`004Goo00<007ooOol0EGoo00<007ooOol02Goo00<007ooOol0
X7oo000AOol00`00Oomoo`1FOol00`00Oomoo`08Ool00`00Oomoo`2POol000Ioo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo05Ioo`03001oogoo00Moo`03001oogoo0:5oo`001Woo00L007oo
Oomoo`00Ool00004Ool00`00Oomoo`1GOol00`00Oomoo`05Ool00`00Oomoo`2ROol000Ioo`07001o
ogooOol007oo000017oo0`00F7oo0P001Goo00<007ooOol0XWoo0007Ool01P00Oomoo`00Ool000Ao
o`03001oogoo05Uoo`<00003Ool000000:Eoo`001Goo00<007oo00000Woo00<007oo000017oo00<0
07ooOol0Fgoo0P00Ygoo0005Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`3oOol5Ool0015oo`80
0?moo`Ioo`004Goo00<007ooOol0ogoo1Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0712482, -5.59224, 0.00396691,
   0.454354}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Friction Example "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the application of Coulombic friction to a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " mechanism model, a 2D model of a slider on an inclined ramp is developed. \
The model consists of one moving body, the slider.\n\nAs the slider is pushed \
along its track on the ground body, it travels along the initial horizontal \
part of the track until the tip of the slider encounters the upward turn of \
the track. The tip then progresses up the inclined ramp while the heel of the \
slider stays on the horizontal section. Coulombic friction is modeled at the \
two sliding interfaces at the tip and the heel of the slider. The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to switch between the different friction forces as the \
tip of the slider passes from one section of the ramp to the next. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the 2D slider-ramp model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
  
%%Creator: Mathematica 
  
%%AspectRatio: .58824   
  
MathPictureStart 
  
%% Graphics 
  
/Courier findfont 10  scalefont  setfont 
  
% Scaling calculations 
  
0.0588235 0.235294 0.117647 0.235294 [ 
  
[(0)] .05882  0 0 2 Msboxa 
  
[(1)] .29412  0 0 2 Msboxa 
  
[(2)] .52941  0 0 2 Msboxa 
  
[(3)] .76471  0 0 2 Msboxa 
  
[(4)] 1 0 0 2 Msboxa 
  
[(-0.5)] -0.0125 0 1 0 Msboxa 
  
[(0)] -0.0125 .11765  1 0 Msboxa 
  
[(0.5)] -0.0125 .23529  1 0 Msboxa 
  
[(1)] -0.0125 .35294  1 0 Msboxa 
  
[(1.5)] -0.0125 .47059  1 0 Msboxa 
  
[(2)] -0.0125 .58824  1 0 Msboxa 
  
[ -0.001 -0.001 0 0 ] 
  
[ 1.001 .58924  0 0 ] 
  
] MathScale 
  
% Start of Graphics 
  
1 setlinecap 
  
1 setlinejoin 
  
newpath 
  
[ ] 0 setdash 
  
0 g 
  
p 
  
p 
  
.002  w 
  
.05882  0 m 
  
.05882  .00625  L 
  
s 
  
P 
  
[(0)] .05882  0 0 2 Mshowa 
  
p 
  
.002  w 
  
.29412  0 m 
  
.29412  .00625  L 
  
s 
  
P 
  
[(1)] .29412  0 0 2 Mshowa 
  
p 
  
.002  w 
  
.52941  0 m 
  
.52941  .00625  L 
  
s 
  
P 
  
[(2)] .52941  0 0 2 Mshowa 
  
p 
  
.002  w 
  
.76471  0 m 
  
.76471  .00625  L 
  
s 
  
P 
  
[(3)] .76471  0 0 2 Mshowa 
  
p 
  
.002  w 
  
1 0 m 
  
1 .00625  L 
  
s 
  
P 
  
[(4)] 1 0 0 2 Mshowa 
  
p 
  
.001  w 
  
.10588  0 m 
  
.10588  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.15294  0 m 
  
.15294  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.2  0 m 
  
.2  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.24706  0 m 
  
.24706  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.34118  0 m 
  
.34118  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.38824  0 m 
  
.38824  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.43529  0 m 
  
.43529  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.48235  0 m 
  
.48235  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.57647  0 m 
  
.57647  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.62353  0 m 
  
.62353  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.67059  0 m 
  
.67059  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.71765  0 m 
  
.71765  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.81176  0 m 
  
.81176  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.85882  0 m 
  
.85882  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.90588  0 m 
  
.90588  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.95294  0 m 
  
.95294  .00375  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.01176  0 m 
  
.01176  .00375  L 
  
s 
  
P 
  
p 
  
.002  w 
  
0 0 m 
  
1 0 L 
  
s 
  
P 
  
p 
  
.002  w 
  
0 0 m 
  
.00625  0 L 
  
s 
  
P 
  
[(-0.5)] -0.0125 0 1 0 Mshowa 
  
p 
  
.002  w 
  
0 .11765  m 
  
.00625  .11765  L 
  
s 
  
P 
  
[(0)] -0.0125 .11765  1 0 Mshowa 
  
p 
  
.002  w 
  
0 .23529  m 
  
.00625  .23529  L 
  
s 
  
P 
  
[(0.5)] -0.0125 .23529  1 0 Mshowa 
  
p 
  
.002  w 
  
0 .35294  m 
  
.00625  .35294  L 
  
s 
  
P 
  
[(1)] -0.0125 .35294  1 0 Mshowa 
  
p 
  
.002  w 
  
0 .47059  m 
  
.00625  .47059  L 
  
s 
  
P 
  
[(1.5)] -0.0125 .47059  1 0 Mshowa 
  
p 
  
.002  w 
  
0 .58824  m 
  
.00625  .58824  L 
  
s 
  
P 
  
[(2)] -0.0125 .58824  1 0 Mshowa 
  
p 
  
.001  w 
  
0 .02353  m 
  
.00375  .02353  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .04706  m 
  
.00375  .04706  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .07059  m 
  
.00375  .07059  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .09412  m 
  
.00375  .09412  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .14118  m 
  
.00375  .14118  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .16471  m 
  
.00375  .16471  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .18824  m 
  
.00375  .18824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .21176  m 
  
.00375  .21176  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .25882  m 
  
.00375  .25882  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .28235  m 
  
.00375  .28235  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .30588  m 
  
.00375  .30588  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .32941  m 
  
.00375  .32941  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .37647  m 
  
.00375  .37647  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .4  m 
  
.00375  .4  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .42353  m 
  
.00375  .42353  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .44706  m 
  
.00375  .44706  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .49412  m 
  
.00375  .49412  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .51765  m 
  
.00375  .51765  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .54118  m 
  
.00375  .54118  L 
  
s 
  
P 
  
p 
  
.001  w 
  
0 .56471  m 
  
.00375  .56471  L 
  
s 
  
P 
  
p 
  
.002  w 
  
0 0 m 
  
0 .58824  L 
  
s 
  
P 
  
P 
  
p 
  
p 
  
.002  w 
  
.05882  .58199  m 
  
.05882  .58824  L 
  
s 
  
P 
  
p 
  
.002  w 
  
.29412  .58199  m 
  
.29412  .58824  L 
  
s 
  
P 
  
p 
  
.002  w 
  
.52941  .58199  m 
  
.52941  .58824  L 
  
s 
  
P 
  
p 
  
.002  w 
  
.76471  .58199  m 
  
.76471  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.10588  .58449  m 
  
.10588  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.15294  .58449  m 
  
.15294  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.2  .58449  m 
  
.2  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.24706  .58449  m 
  
.24706  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.34118  .58449  m 
  
.34118  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.38824  .58449  m 
  
.38824  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.43529  .58449  m 
  
.43529  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.48235  .58449  m 
  
.48235  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.57647  .58449  m 
  
.57647  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.62353  .58449  m 
  
.62353  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.67059  .58449  m 
  
.67059  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.71765  .58449  m 
  
.71765  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.81176  .58449  m 
  
.81176  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.85882  .58449  m 
  
.85882  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.90588  .58449  m 
  
.90588  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.95294  .58449  m 
  
.95294  .58824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.01176  .58449  m 
  
.01176  .58824  L 
  
s 
  
P 
  
p 
  
.002  w 
  
0 .58824  m 
  
1 .58824  L 
  
s 
  
P 
  
p 
  
.002  w 
  
.99375  0 m 
  
1 0 L 
  
s 
  
P 
  
p 
  
.002  w 
  
.99375  .11765  m 
  
1 .11765  L 
  
s 
  
P 
  
p 
  
.002  w 
  
.99375  .23529  m 
  
1 .23529  L 
  
s 
  
P 
  
p 
  
.002  w 
  
.99375  .35294  m 
  
1 .35294  L 
  
s 
  
P 
  
p 
  
.002  w 
  
.99375  .47059  m 
  
1 .47059  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .02353  m 
  
1 .02353  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .04706  m 
  
1 .04706  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .07059  m 
  
1 .07059  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .09412  m 
  
1 .09412  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .14118  m 
  
1 .14118  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .16471  m 
  
1 .16471  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .18824  m 
  
1 .18824  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .21176  m 
  
1 .21176  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .25882  m 
  
1 .25882  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .28235  m 
  
1 .28235  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .30588  m 
  
1 .30588  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .32941  m 
  
1 .32941  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .37647  m 
  
1 .37647  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .4  m 
  
1 .4  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .42353  m 
  
1 .42353  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .44706  m 
  
1 .44706  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .49412  m 
  
1 .49412  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .51765  m 
  
1 .51765  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .54118  m 
  
1 .54118  L 
  
s 
  
P 
  
p 
  
.001  w 
  
.99625  .56471  m 
  
1 .56471  L 
  
s 
  
P 
  
p 
  
.002  w 
  
1 0 m 
  
1 .58824  L 
  
s 
  
P 
  
P 
  
p 
  
P 
  
0 0 m 
  
1 0 L 
  
1 .58824  L 
  
0 .58824  L 
  
closepath 
  
clip 
  
newpath 
  
p 
  
p 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(x)] .35346  .19122  -1.24641 -1.02992 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(y)] .24576  .26943  -1.24641 -1.02992 Mshowa 
  
P 
  
p 
  
/Courier findfont 8 scalefont setfont 
  
[(2)] .2605  .17647  -1.24641 -1.02992 Mshowa 
  
P 
  
.004  w 
  
.35346  .19122  m 
  
.2605  .17647  L 
  
.24576  .26943  L 
  
s 
  
.33634  .17897  m 
  
.35346  .19122  L 
  
.33339  .19757  L 
  
s 
  
.23941  .24936  m 
  
.24576  .26943  L 
  
.258  .25231  L 
  
s 
  
P 
  
p 
  
.007  w 
  
.05882  .11765  m 
  
.52941  .11765  L 
  
s 
  
.6126  .15211  m 
  
.94536  .48486  L 
  
s 
  
newpath 
  
.52941  .23529  .11765  -90 -45 arc 
  
s 
  
P 
  
p 
  
p 
  
.04  w 
  
.43479  .20412  Mdot 
  
P 
  
1 0 0 r 
  
.007  w 
  
newpath 
  
.2605  .17647  .05882  0 365.73 arc 
  
s 
  
.25129  .23457  m 
  
.26972  .11837  L 
  
.6183  .17368  L 
  
.59987  .28988  L 
  
.25129  .23457  L 
  
s 
  
newpath 
  
.60908  .23178  .05882  0 365.73 arc 
  
s 
  
P 
  
P 
  
% End of Graphics 
  
MathPictureEnd 
  
  \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{402, 236},
  ImageMargins->{{42, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006B0000k1000`40O003h00OogooTgoo003oOonC
Ool00?mooi=oo`00ogooTgoo000dOol00`00Oomoo`1@Ool5001@Ool3001AOol2001DOol30009Ool0
03=oo`03001oo`0005=oo`03001oogoo051oo`03001oogoo05=oo`03001oogoo059oo`03001oogoo
00Qoo`00<goo00<007oo0000Dgoo00<007ooOol0DGoo00<007ooOol0DGoo00<007ooOol0DGoo1000
2Goo000cOol00`00Ool0001COol00`00Oomoo`1AOol00`00Oomoo`1BOol00`00Oomoo`1@Ool00`00
Ool0000:Ool003=oo`03001oo`0005=oo`03001oogoo051oo`03001oo`00055oo`03001oo`0005=o
o`8000Yoo`00=7oo00<007ooOol0DGoo0P00Dgoo00<007ooOol0DGoo00<007ooOol0Dgoo00<007oo
Ool027oo003oOonCOol00?mooi=oo`00ogooTgoo003oOonCOol00?mooi=oo`00ogooTgoo000>Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3oOomhOol000eoo`03001oo`0000Moo`03001o
o`000?moogUoo`0027oo0`000Woo00<007oo00002Goo00<007ooOol017ooo`00J0002goo000=Ool0
0`00Ool00007Ool20007Ool01@00Oomoogoo000047oo00<007ooOol03Woo00<007ooOol03Woo00<0
07ooOol03Goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<0
07ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<0
07ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<0
07ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol02Goo000=Ool00`00Ool00007
Ool00`00Oomoo`06Ool01@00Oomoogoo000047oo00<007ooOol03Woo00<007ooOol03Woo00<007oo
Ool03Goo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007ooOol03Woo00<007oo
Ool03Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol02Goo000>Ool00`00Oomoo`06Ool3
0006Ool00`00Oomoo`0BOol00`00Oomoo`1AOol00`00Oomoo`1BOol00`00Oomoo`1AOol00`00Oomo
o`1AOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007oo
Ool0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03
001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000P
Ool2003oOomTOol2000;Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007oo
Ool0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03
001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000P
Ool00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uo
o`0087oo0P00ogooI7oo0P002goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03
001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000P
Ool00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uo
o`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomo
o`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo0P00ogooI7oo0P002goo000P
Ool00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uo
o`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomo
o`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo00<0
07ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`800?moofAoo`8000]o
o`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomo
o`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo00<0
07ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAo
o`03001oogoo00Uoo`0067oo00<007ooOol01Goo00<007ooOol0ogooI7oo00<007ooOol02Goo000G
Ool00`00Ool00006Ool00`00Oomoo`1EOol00g`0Oomoo`04Ool2O002Ool00g`0Oomoo`1NOol00`00
Oomoo`2OOol00`00Oomoo`09Ool001Moo`03001oo`0000Ioo`<0015ood80015l06000003Ool007oo
09Yoo`<000]oo`005goo00<007oo00001Woo00<007ooOol04Goo@0006G`0GP0000=oo`00Ool0V7oo
00<007ooOol02Goo000GOol00`00Ool00006Ool00`00Oomoo`1@Ool4O008Ool2O004Ool>O01BOol:
002GOol00`00Oomoo`09Ool001Qoo`03001oogoo00Eoo`03001oogoo04ioo`Al00Yoo`9l00Ioo`Al
009oo`el04moo`P009Eoo`03001oogoo00Uoo`0087oo00<007ooOol0C7oo1G`02goo0W`027oo0g`0
1goo3G`0CWoo1000U7oo00<007ooOol02Goo000POol00`00Oomoo`1;Ool4O00=Ool2O009Ool3O00=
Ool<O01:Ool4002BOol00`00Oomoo`09Ool0021oo`03001oogoo04Yoo`=l00moo`9l00Yoo`=l019o
o`al04Eoo`D0091oo`03001oogoo00Uoo`0087oo00<007ooOol0BGoo0g`03goo0W`037oo0g`05goo
3G`0@7oo1@00SWoo00<007ooOol02Goo000POol20019Ool3O00@Ool2O00=Ool3O00LOol=O00lOol4
002<Ool2000;Ool0021oo`03001oogoo04Qoo`9l015oo`9l00ioo`=l029oo`al03Qoo`<008aoo`03
001oogoo00Uoo`0087oo00<007ooOol0B7oo00=l07ooOol047oo0W`03goo0W`0:7oo37`0<goo0`00
Rgoo00<007ooOol02Goo000POol00`00Oomoo`17Ool2O00BOol2O00@Ool00g`0Oomoo`0/Ool<O00^
Ool3002:Ool00`00Oomoo`09Ool0021oo`03001oogoo04Moo`03O01oogoo015oo`9l011oo`9l03=o
o`el02Qoo`<008Uoo`03001oogoo00Uoo`0087oo00<007ooOol0AWoo0W`04goo0W`047oo0W`0>Goo
3G`08goo0`00R7oo00<007ooOol02Goo000POol00`00Oomoo`15Ool2O00COol2O00AOol2O010Ool<
O00NOol30027Ool00`00Oomoo`09Ool0021oo`03001oogoo04Eoo`9l01=oo`9l015oo`9l04Ioo`al
01Uoo`<008Ioo`03001oogoo00Uoo`0087oo00<007ooOol0AGoo0W`04goo0W`04Goo0g`0Bgoo3G`0
4goo0`00QGoo00<007ooOol02Goo000POol20016Ool2O00COol2O00BOol2O01AOol=O00>Ool30023
Ool2000;Ool0021oo`03001oogoo04Aoo`9l01Aoo`9l019oo`9l05Qoo`al00Uoo`<008=oo`03001o
ogoo00Uoo`0087oo00<007ooOol0A7oo0W`057oo0W`04Woo0W`0GWoo37`00goo00Al00000000089o
o`03001oogoo00Uoo`0087oo00<007ooOol0A7oo0W`057oo0W`04Woo0W`0GWoo00=l07ooO0003g`0
0P00PGoo00<007ooOol02Goo000POol00`00Oomoo`14Ool2O00COol2O003000@Ool2O01MOolEO000
0`00Oomoo`1nOol00`00Oomoo`09Ool0021oo`03001oogoo04Aoo`9l01=oo`9l00=oo`H000Yoo`9l
00Eoo`03001oogoo05Aoo`El00Qoo`9l00Aoo`El07moo`03001oogoo00Uoo`0087oo00<007ooOol0
A7oo0W`04goo0W`02Goo1`000goo0W`01Woo0P00Dgoo0g`02goo0W`01Woo17`0OWoo00<007ooOol0
2Goo000POol00`00Oomoo`14Ool2O00COol2O00017oo0000000037oo0`000W`00P001Woo00<007oo
Ool0CWoo17`037oo0W`027oo0g`0OGoo00<007ooOol02Goo000POol20015Ool3O00BOol2O0000goo
0000000@Ool2O002Ool600000goo0000000LOol3000^Ool4O00=Ool2O009Ool3O01kOol2000;Ool0
021oo`03001oogoo04Eoo`9l019oo`9l00=oo`03001oogoo00eoo`9l00Qoo`@001Uoo`L002]oo`=l
00moo`9l00Yoo`=l07]oo`03001oogoo00Uoo`0087oo00<007ooOol0AGoo0W`04Woo0W`00goo00<0
07ooOol037oo0W`01goo10006Woo2@00:Goo0g`03goo0W`037oo0g`0NWoo00<007ooOol02Goo000P
Ool00`00Oomoo`15Ool2O00BOol2O00017oo000000003Woo0W`01Goo0P007Goo2`009goo0g`047oo
0W`03Goo0g`0NGoo00<007ooOol02Goo000POol00`00Oomoo`15Ool3O00@Ool2O00COol2O00=Ool2
00000goo001oo`0BOol;000WOol2O00AOol2O00>Ool3O01hOol00`00Oomoo`09Ool0021oo`03001o
ogoo04Moo`03O01oogoo00ioo`9l01=oo`9l00moo`03001oogoo015oo`d002Eoo`=l015oo`9l00mo
o`9l0003001oogoo07Eoo`03001oogoo00Uoo`0087oo00<007ooOol0Agoo0W`03goo0W`04goo00=l
07ooOol03Goo00<007oo00004Woo3@0097oo0g`04Woo0W`03goo0g`000<007ooOol0M7oo00<007oo
Ool02Goo000POol00`00Oomoo`18Ool00g`0Oomoo`0=Ool2O00BOol2O00TOol=000TOol2O00COol2
O00@Ool3O0000`00Oomoo`1cOol00`00Oomoo`09Ool0021oo`8004Uoo`9l00ioo`9l011oo`Al02Eo
o`/002Aoo`9l01Aoo`9l011oo`9l00<007=oo`8000]oo`0087oo00<007ooOol0B7oo17`037oo0W`0
3goo17`09Woo2`0097oo0W`04goo0W`04Goo0W`000Aoo`00000007=oo`03001oogoo00Uoo`0087oo
00<007ooOol0BGoo17`02goo0W`03goo0W`0:Goo2@009Goo0W`04goo0W`04Goo0g`000Aoo`000000
079oo`03001oogoo00Uoo`0087oo00<007ooOol0Bgoo0W`02Woo0W`03Woo17`0:Woo1`009Woo0W`0
4goo0W`04Woo0W`00Woo0`00LGoo00<007ooOol02Goo000POol00`00Oomoo`1;Ool4O008Ool2O00=
Ool4O00]Ool3000WOol2O00DOol2O00BOol2O003Ool3001`Ool00`00Oomoo`09Ool0021oo`03001o
ogoo04aoo`El00Ioo`9l00eoo`9l05Uoo`9l01Aoo`9l019oo`9l00Aoo`<006moo`03001oogoo00Uo
o`0087oo00<007ooOol0CWoo17`01Goo0W`02Goo00=l07ooO0000g`0FGoo0W`057oo0W`04Woo0W`0
1Goo0`00KWoo00<007ooOol02Goo000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`1@Ool4O0000gooO01oo`02O007Ool7O01JOol2O00DOol2O00BOol2O006Ool3001]
Ool00`00Oomoo`09Ool000eoo`03001oo`0000Moo`03001oo`0000Ioo`03001oogoo055oo`Ql00Eo
o`Ml05aoo`9l01=oo`9l01=oo`9l00Moo`<006aoo`03001oogoo00Uoo`003Goo00<007oo00002Goo
00<007ooOol017oo0`00DWoo3g`0H7oo0W`04goo0W`04goo0W`027oo0`00JGoo0`002goo000=Ool0
0`00Ool00007Ool20007Ool00`00Oomoo`1FOol?O01LOol2O00COol2O00COol2O009Ool3001ZOol0
0`00Oomoo`09Ool000eoo`03001oo`0000Moo`03001oogoo00Ioo`03001oogoo05Moo`03001oogoo
00Aoo`el05Ioo`9l01=oo`9l01=oo`9l00Yoo`<006Uoo`03001oogoo00Uoo`003Woo00<007ooOol0
1Woo0`001Woo00<007ooOol0EWoo00<007ooOol037oo3G`0Cgoo0g`04Woo0W`04goo0W`02goo0`00
J7oo00<007ooOol02Goo000POol00`00Oomoo`1FOol00`00Oomoo`0BOol=O01:Ool2O00BOol2O00C
Ool2O00<Ool3001WOol00`00Oomoo`09Ool0021oo`03001oogoo05=oo`04001oogoo000KOol=O013
Ool2O00BOol2O00BOol2O00>Ool3001VOol00`00Oomoo`09Ool0021oo`03001oogoo05=oo`04001o
ogoo0002Ool00`00Oomoo`0LOol>O00lOol2O00AOol2O00COol2O00?Ool3001UOol00`00Oomoo`09
Ool0021oo`03001oogoo05Aoo`05001oo`00Ool0000VOol=O00fOol3O00@Ool2O00COol2O00@Ool3
001TOol00`00Oomoo`09Ool0021oo`8005Eoo`05001oo`00Ool0000]Ool=O00aOol00g`0Oomoo`0>
Ool2O00COol2O00AOol3001ROol2000;Ool0021oo`03001oogoo05Aoo`800003Ool007oo03=oo`el
02]oo`9l00moo`9l01=oo`03O01oogoo015oo`<0069oo`03001oogoo00Uoo`0087oo00<007ooOol0
E7oo0`00?7oo3G`097oo0g`03Woo0W`04Woo0W`057oo0`00HGoo00<007ooOol02Goo000POol00`00
Oomoo`1EOol20012Ool=O00OOol3O00=Ool2O00@Ool4O00EOol3001POol00`00Oomoo`09Ool0021o
o`03001oogoo05Eoo`03001oogoo04Qoo`el01Uoo`=l00aoo`9l00moo`Al01Moo`<005moo`03001o
ogoo00Uoo`0087oo00<007ooOol0EWoo0P00CWoo3W`04goo0g`02Woo0W`047oo0W`06Woo0`00GWoo
00<007ooOol02Goo000POol00`00Oomoo`1GOol00`00Oomoo`1COol=O00>Ool3O009Ool2O00>Ool4
O00KOol3001MOol00`00Oomoo`09Ool0021oo`03001oogoo05Moo`03001oogoo05Yoo`el00Qoo`=l
00Qoo`9l00eoo`Al01eoo`<005aoo`03001oogoo00Uoo`0087oo00<007ooOol0EWoo00<007oo0000
HGoo3G`00goo17`01Woo0W`02goo17`087oo0`00Fgoo00<007ooOol02Goo000POol2001GOol01000
Ool00000Igoo3W`01Goo0W`02Goo1G`08Woo0`00FGoo0P002goo000POol00`00Oomoo`37Ool?O005
Ool00g`0Ooml0004O00UOol3001IOol00`00Oomoo`09Ool0021oo`03001oogoo0<ioo`Ql00=oo`Ml
02Qoo`<005Qoo`03001oogoo00Uoo`0087oo00<007ooOol0cgoo3g`0:goo0`00Egoo00<007ooOol0
2Goo000POol00`00Oomoo`3COol7O00`Ool3001FOol00`00Oomoo`09Ool0021oo`03001oogoo0?mo
o`aoo`<005Eoo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo3Goo0`00E7oo00<007ooOol02Goo
000POol00`00Oomoo`3oOol>Ool3001COol00`00Oomoo`09Ool0021oo`800?mooa1oo`<0055oo`80
00]oo`0087oo00<007ooOol0ogoo47oo0`00DGoo00<007ooOol02Goo000POol00`00Oomoo`3oOolA
Ool3001@Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mooa9oo`<004moo`03001oogoo00Uoo`00
87oo00<007ooOol0ogoo4goo1000CGoo00<007ooOol02Goo000POol00`00Oomoo`3oOolDOol4001<
Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mooaIoo`<004]oo`03001oogoo00Uoo`0087oo00<0
07ooOol0ogoo5goo0`00BWoo00<007ooOol02Goo000POol00`00Oomoo`3oOolHOol30019Ool00`00
Oomoo`09Ool0021oo`800?mooaYoo`<004Moo`8000]oo`0087oo00<007ooOol0ogoo6Woo0`00Agoo
00<007ooOol02Goo000POol00`00Oomoo`3oOolKOol30016Ool00`00Oomoo`09Ool0021oo`03001o
ogoo0?mooaaoo`<004Eoo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo7Goo0`00A7oo00<007oo
Ool02Goo000POol00`00Oomoo`3oOolNOol30013Ool00`00Oomoo`09Ool001Ioo`D000Eoo`03001o
ogoo0?mooamoo`<0049oo`03001oogoo00Uoo`0067oo00<007ooOol01Goo00<007ooOol0ogoo87oo
0`00@Goo00<007ooOol02Goo000HOol00`00Oomoo`05Ool3003oOolQOol3000nOol3000;Ool001Qo
o`03001oogoo00Eoo`03001oogoo0?moob9oo`<003moo`03001oogoo00Uoo`0067oo00<007ooOol0
1Goo00<007ooOol0ogoo8goo0`00?Woo00<007ooOol02Goo000GOol20007Ool00`00Oomoo`3oOolT
Ool3000mOol00`00Oomoo`09Ool0021oo`03001oogoo0?moobEoo`<003aoo`03001oogoo00Uoo`00
87oo00<007ooOol0ogoo9Woo0`00>goo00<007ooOol02Goo000POol00`00Oomoo`3oOolWOol3000j
Ool00`00Oomoo`09Ool0021oo`03001oogoo0?moobQoo`<003Uoo`03001oogoo00Uoo`0087oo00<0
07ooOol0ogoo:Goo0`00>7oo00<007ooOol02Goo000POol2003oOol[Ool3000fOol2000;Ool0021o
o`03001oogoo0?moob]oo`<003Ioo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo;7oo0`00=Goo
00<007ooOol02Goo000POol00`00Oomoo`3oOol]Ool3000dOol00`00Oomoo`09Ool0021oo`03001o
ogoo0?moobioo`<003=oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo;goo0`00<Woo00<007oo
Ool02Goo000POol00`00Oomoo`3oOol`Ool3000aOol00`00Oomoo`09Ool0021oo`03001oogoo0?mo
oc5oo`<0031oo`03001oogoo00Uoo`0087oo0P00ogoo<goo0`00;Woo0P002goo000POol00`00Oomo
o`3oOolcOol3000^Ool00`00Oomoo`09Ool0021oo`03001oogoo0?moocAoo`<002eoo`03001oogoo
00Uoo`0087oo00<007ooOol0ogoo=Goo0`00;7oo00<007ooOol02Goo000POol00`00Oomoo`3oOolf
Ool3000[Ool00`00Oomoo`09Ool0021oo`03001oogoo0?moocMoo`<002Yoo`03001oogoo00Uoo`00
87oo00<007ooOol0ogoo>7oo0`00:Goo00<007ooOol02Goo000POol00`00Oomoo`3oOoliOol3000X
Ool00`00Oomoo`09Ool0021oo`800?mooc]oo`<002Ioo`8000]oo`0087oo00<007ooOol0ogoo>goo
0`009Woo00<007ooOol02Goo000POol00`00Oomoo`3oOollOol3000UOol00`00Oomoo`09Ool0021o
o`03001oogoo0?mooceoo`<002Aoo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo?Woo0`008goo
00<007ooOol02Goo000POol00`00Oomoo`3oOoloOol3000ROol00`00Oomoo`09Ool0021oo`03001o
ogoo0?mood1oo`<0025oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo@Goo0`0087oo00<007oo
Ool02Goo000POol00`00Oomoo`3oOom2Ool3000OOol00`00Oomoo`09Ool0021oo`800?moodAoo`<0
01eoo`8000]oo`0087oo00<007ooOol0ogooA7oo0`007Goo00<007ooOol02Goo000POol00`00Oomo
o`3oOom5Ool3000LOol00`00Oomoo`09Ool0021oo`03001oogoo0?moodIoo`<001]oo`03001oogoo
00Uoo`0087oo00<007ooOol0ogooAgoo0`006Woo00<007ooOol02Goo000POol00`00Oomoo`3oOom8
Ool3000IOol00`00Oomoo`09Ool000aoo`D0009oo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo0?moodUoo`<001Qoo`03001oogoo00Uoo`003Woo00<007ooOol01Woo00<007oo00001Woo00<0
07ooOol0ogooBWoo0`005goo00<007ooOol02Goo000>Ool00`00Oomoo`08Ool00`00Oomoo`04Ool3
003oOom;Ool3000DOol3000;Ool000ioo`03001oogoo00Ioo`8000Moo`03001oogoo0?moodaoo`<0
01Eoo`03001oogoo00Uoo`003Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol0ogooCGoo
0`0057oo00<007ooOol02Goo000=Ool20008Ool30006Ool00`00Oomoo`3oOom>Ool3000COol00`00
Oomoo`09Ool0021oo`03001oogoo0?moodmoo`<0019oo`03001oogoo00Uoo`0087oo00<007ooOol0
ogooD7oo0`004Goo00<007ooOol02Goo000POol00`00Oomoo`3oOomAOol00`00Oomoo`0@Ool00`00
Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo
00<007ooOol02Goo000POol2003oOomTOol2000;Ool0021oo`03001oogoo0?moofAoo`03001oogoo
00Uoo`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00
Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo
00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?mo
ofAoo`03001oogoo00Uoo`0087oo0P00ogooI7oo0P002goo000POol00`00Oomoo`3oOomTOol00`00
Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo
00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?mo
ofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomo
o`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo0P00
ogooI7oo0P002goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?mo
ofAoo`03001oogoo00Uoo`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomo
o`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<0
07ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool0021o
o`800?moofAoo`8000]oo`0087oo00<007ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomo
o`3oOomTOol00`00Oomoo`09Ool0021oo`03001oogoo0?moofAoo`03001oogoo00Uoo`0087oo00<0
07ooOol0ogooI7oo00<007ooOol02Goo000POol00`00Oomoo`3oOomTOol00`00Oomoo`09Ool001Mo
o`<000Ioo`03001oogoo019oo`03001oogoo055oo`03001oogoo059oo`03001oogoo055oo`03001o
ogoo055oo`03001oogoo00Uoo`005goo00<007ooOol01Woo00D007ooOomoo`00011oo`03001oogoo
00ioo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo
00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo
00ioo`03001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo
00Uoo`0067oo00<007ooOol01Gooo`00J0002goo000HOol00`00Oomoo`3oOomhOol001Moo`03001o
o`000?moogUoo`0067oo00<007ooOol0ogooN7oo003oOonCOol00?mooi=oo`00ogooTgoo0000\
\>"],
  ImageRangeCache->{{{0, 401}, {235, 0}} -> {-0.630873, -0.713287, 0.0118486, 
  0.0118486}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two body objects are defined for the slider-ramp model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ramp (body 1) requires five point definitions.\nP1 is the origin of the \
ramp.\nP2 is a point directly to the right of the origin to define the lower \
flat of the ramp.\nP3 is the center point of the curved section of the ramp.\n\
P4 and P5 are two points that define the upper flat of the ramp."], "Special1",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider (body 2) requires two local point definitions.\nP1 is the center \
of the heel of the slider, which is the local origin.\nP2 is the center of \
the tip of the slider."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that points 3, 4, and 5 on the ramp are defined as functions of two \
user-defined variables ",
  StyleBox["radius",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["incline",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", so that the radius at the curve of the ramp and the angle of the incline \
can be changed easily.\n\nBecause a gravitational force will be applied to \
the slider, the mass and centroid location are defined in the slider's body \
object."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the bodies in the model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ramp = 1; \)\), 
    \(\(slider = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the body objects for the slider-ramp."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(radius =. \), 
    \(incline =. \)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[ramp] = Body[ramp, PointList\[Rule]{\n  (*P1*) {0, 0},\n  (*P2*) {2, 0},\n\
  (*P3*) {2, radius},\n  (*P4*) { 2 + radius*Sin[incline],\n           radius \
- radius*Cos[incline] },\n  (*P5*) {      2 + radius*Sin[incline],\n          \
 radius - radius*Cos[incline] } +\n             PolarToXY[{2, incline}]} ];"],
   "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[slider] = Body[slider, PointList\[Rule]\n  {(*P1*) {0   , 0 },\n   (*P2*) \
{1.5 , 0 }},\n  InitialGuess\[Rule]{{.5,.25},0},\n  Mass\[Rule]1.0, \n  \
Centroid\[Rule]{.75, 0}];"], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The body properties are added to the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ramp], bd[slider]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three constraints, one of which is a driving constraint, are required to \
model the slider-ramp mechanism."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the horizontal position of the heel of the slider. \
This constraint is a driving constraint because it is functionally dependent \
on the time variable ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint keeps the heel of the slider in contact with the ramp."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint keeps the tip of the slider in contact with the ramp. The ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has three stages:"
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "1. A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint keeps the tip of the slider in contact with the horizontal \
section of the ramp.\n2. A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint keeps the tip of the slider in contact with the curved section \
of the ramp.\n3. A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint keeps the tip of the slider in contact with the inclined \
section of the ramp."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The value of the initial switch time determined by inspection is 0.5. \
However, the value of the second switchtime is more difficult to determine \
analytically, so it is left as the symbol ",
  StyleBox["swtime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and the ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to find a numeric value."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the slider-ramp model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(swtime =. \), 
    \(\(cs[1] = RelativeX1[1, Point[slider, 0], T]; \)\), 
    \(\(cs[2] = RelativeY1[2, Point[slider, 0], .25]; \)\), 
    \(\(cs[3] = 
      TimeSwitch[3, \n\t\t
        PointOnLine1[1, \n\t\t\tPoint[slider, 2], Line[ramp, 1, 2], .25], \n
        \t\t0.50, \n\t\t
        RelativeDistance1[2, \n\t\t\tPoint[ramp, 3], Point[slider, 2], .25], 
        \n\t\tswtime, \n\t\t
        PointOnLine1[3, \n\t\t\tPoint[slider, 2], Line[ramp, 4, 5], .25]]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here, the constraints are added to the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs[1], cs[2], cs[3]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Before the model can be run the undefined symbols, ",
  StyleBox["incline",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["radius",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["swtime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", must be defined. ",
  StyleBox["$MechVariables",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the names of any symbols that have been recognized as being part \
of the current model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " utility. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \($MechVariables\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({"incline", "radius", "swtime"}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The embedded symbols are explicitly defined. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(incline = 45.0  \[Degree]; \nradius = 0.5; \n\(swtime = 0.7; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.65."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.65]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.65`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] 0.65`\), ",", 
        RowBox[{"Y2", "\[Rule]", 
          StyleBox["0.25`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", 
        \(Th2 \[Rule] 0.0329342910972761959`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the slider-ramp model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.65. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .58824  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.0588235 0.235294 0.117647 0.235294 [ 
[(0)] .05882 0 0 2 Msboxa 
[(1)] .29412 0 0 2 Msboxa 
[(2)] .52941 0 0 2 Msboxa 
[(3)] .76471 0 0 2 Msboxa 
[(4)] 1 0 0 2 Msboxa 
[(-0.5)] -0.0125 0 1 0 Msboxa 
[(0)] -0.0125 .11765 1 0 Msboxa 
[(0.5)] -0.0125 .23529 1 0 Msboxa 
[(1)] -0.0125 .35294 1 0 Msboxa 
[(1.5)] -0.0125 .47059 1 0 Msboxa 
[(2)] -0.0125 .58824 1 0 Msboxa 
[ -0.001 -0.001 0 0 ] 
[ 1.001 .58924 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.05882 0 m 
.05882 .00625 L 
s 
P 
[(0)] .05882 0 0 2 Mshowa 
p 
.002 w 
.29412 0 m 
.29412 .00625 L 
s 
P 
[(1)] .29412 0 0 2 Mshowa 
p 
.002 w 
.52941 0 m 
.52941 .00625 L 
s 
P 
[(2)] .52941 0 0 2 Mshowa 
p 
.002 w 
.76471 0 m 
.76471 .00625 L 
s 
P 
[(3)] .76471 0 0 2 Mshowa 
p 
.002 w 
1 0 m 
1 .00625 L 
s 
P 
[(4)] 1 0 0 2 Mshowa 
p 
.001 w 
.10588 0 m 
.10588 .00375 L 
s 
P 
p 
.001 w 
.15294 0 m 
.15294 .00375 L 
s 
P 
p 
.001 w 
.2 0 m 
.2 .00375 L 
s 
P 
p 
.001 w 
.24706 0 m 
.24706 .00375 L 
s 
P 
p 
.001 w 
.34118 0 m 
.34118 .00375 L 
s 
P 
p 
.001 w 
.38824 0 m 
.38824 .00375 L 
s 
P 
p 
.001 w 
.43529 0 m 
.43529 .00375 L 
s 
P 
p 
.001 w 
.48235 0 m 
.48235 .00375 L 
s 
P 
p 
.001 w 
.57647 0 m 
.57647 .00375 L 
s 
P 
p 
.001 w 
.62353 0 m 
.62353 .00375 L 
s 
P 
p 
.001 w 
.67059 0 m 
.67059 .00375 L 
s 
P 
p 
.001 w 
.71765 0 m 
.71765 .00375 L 
s 
P 
p 
.001 w 
.81176 0 m 
.81176 .00375 L 
s 
P 
p 
.001 w 
.85882 0 m 
.85882 .00375 L 
s 
P 
p 
.001 w 
.90588 0 m 
.90588 .00375 L 
s 
P 
p 
.001 w 
.95294 0 m 
.95294 .00375 L 
s 
P 
p 
.001 w 
.01176 0 m 
.01176 .00375 L 
s 
P 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 0 m 
.00625 0 L 
s 
P 
[(-0.5)] -0.0125 0 1 0 Mshowa 
p 
.002 w 
0 .11765 m 
.00625 .11765 L 
s 
P 
[(0)] -0.0125 .11765 1 0 Mshowa 
p 
.002 w 
0 .23529 m 
.00625 .23529 L 
s 
P 
[(0.5)] -0.0125 .23529 1 0 Mshowa 
p 
.002 w 
0 .35294 m 
.00625 .35294 L 
s 
P 
[(1)] -0.0125 .35294 1 0 Mshowa 
p 
.002 w 
0 .47059 m 
.00625 .47059 L 
s 
P 
[(1.5)] -0.0125 .47059 1 0 Mshowa 
p 
.002 w 
0 .58824 m 
.00625 .58824 L 
s 
P 
[(2)] -0.0125 .58824 1 0 Mshowa 
p 
.001 w 
0 .02353 m 
.00375 .02353 L 
s 
P 
p 
.001 w 
0 .04706 m 
.00375 .04706 L 
s 
P 
p 
.001 w 
0 .07059 m 
.00375 .07059 L 
s 
P 
p 
.001 w 
0 .09412 m 
.00375 .09412 L 
s 
P 
p 
.001 w 
0 .14118 m 
.00375 .14118 L 
s 
P 
p 
.001 w 
0 .16471 m 
.00375 .16471 L 
s 
P 
p 
.001 w 
0 .18824 m 
.00375 .18824 L 
s 
P 
p 
.001 w 
0 .21176 m 
.00375 .21176 L 
s 
P 
p 
.001 w 
0 .25882 m 
.00375 .25882 L 
s 
P 
p 
.001 w 
0 .28235 m 
.00375 .28235 L 
s 
P 
p 
.001 w 
0 .30588 m 
.00375 .30588 L 
s 
P 
p 
.001 w 
0 .32941 m 
.00375 .32941 L 
s 
P 
p 
.001 w 
0 .37647 m 
.00375 .37647 L 
s 
P 
p 
.001 w 
0 .4 m 
.00375 .4 L 
s 
P 
p 
.001 w 
0 .42353 m 
.00375 .42353 L 
s 
P 
p 
.001 w 
0 .44706 m 
.00375 .44706 L 
s 
P 
p 
.001 w 
0 .49412 m 
.00375 .49412 L 
s 
P 
p 
.001 w 
0 .51765 m 
.00375 .51765 L 
s 
P 
p 
.001 w 
0 .54118 m 
.00375 .54118 L 
s 
P 
p 
.001 w 
0 .56471 m 
.00375 .56471 L 
s 
P 
p 
.002 w 
0 0 m 
0 .58824 L 
s 
P 
P 
p 
p 
.002 w 
.05882 .58199 m 
.05882 .58824 L 
s 
P 
p 
.002 w 
.29412 .58199 m 
.29412 .58824 L 
s 
P 
p 
.002 w 
.52941 .58199 m 
.52941 .58824 L 
s 
P 
p 
.002 w 
.76471 .58199 m 
.76471 .58824 L 
s 
P 
p 
.002 w 
1 .58199 m 
1 .58824 L 
s 
P 
p 
.001 w 
.10588 .58449 m 
.10588 .58824 L 
s 
P 
p 
.001 w 
.15294 .58449 m 
.15294 .58824 L 
s 
P 
p 
.001 w 
.2 .58449 m 
.2 .58824 L 
s 
P 
p 
.001 w 
.24706 .58449 m 
.24706 .58824 L 
s 
P 
p 
.001 w 
.34118 .58449 m 
.34118 .58824 L 
s 
P 
p 
.001 w 
.38824 .58449 m 
.38824 .58824 L 
s 
P 
p 
.001 w 
.43529 .58449 m 
.43529 .58824 L 
s 
P 
p 
.001 w 
.48235 .58449 m 
.48235 .58824 L 
s 
P 
p 
.001 w 
.57647 .58449 m 
.57647 .58824 L 
s 
P 
p 
.001 w 
.62353 .58449 m 
.62353 .58824 L 
s 
P 
p 
.001 w 
.67059 .58449 m 
.67059 .58824 L 
s 
P 
p 
.001 w 
.71765 .58449 m 
.71765 .58824 L 
s 
P 
p 
.001 w 
.81176 .58449 m 
.81176 .58824 L 
s 
P 
p 
.001 w 
.85882 .58449 m 
.85882 .58824 L 
s 
P 
p 
.001 w 
.90588 .58449 m 
.90588 .58824 L 
s 
P 
p 
.001 w 
.95294 .58449 m 
.95294 .58824 L 
s 
P 
p 
.001 w 
.01176 .58449 m 
.01176 .58824 L 
s 
P 
p 
.002 w 
0 .58824 m 
1 .58824 L 
s 
P 
p 
.002 w 
.99375 0 m 
1 0 L 
s 
P 
p 
.002 w 
.99375 .11765 m 
1 .11765 L 
s 
P 
p 
.002 w 
.99375 .23529 m 
1 .23529 L 
s 
P 
p 
.002 w 
.99375 .35294 m 
1 .35294 L 
s 
P 
p 
.002 w 
.99375 .47059 m 
1 .47059 L 
s 
P 
p 
.002 w 
.99375 .58824 m 
1 .58824 L 
s 
P 
p 
.001 w 
.99625 .02353 m 
1 .02353 L 
s 
P 
p 
.001 w 
.99625 .04706 m 
1 .04706 L 
s 
P 
p 
.001 w 
.99625 .07059 m 
1 .07059 L 
s 
P 
p 
.001 w 
.99625 .09412 m 
1 .09412 L 
s 
P 
p 
.001 w 
.99625 .14118 m 
1 .14118 L 
s 
P 
p 
.001 w 
.99625 .16471 m 
1 .16471 L 
s 
P 
p 
.001 w 
.99625 .18824 m 
1 .18824 L 
s 
P 
p 
.001 w 
.99625 .21176 m 
1 .21176 L 
s 
P 
p 
.001 w 
.99625 .25882 m 
1 .25882 L 
s 
P 
p 
.001 w 
.99625 .28235 m 
1 .28235 L 
s 
P 
p 
.001 w 
.99625 .30588 m 
1 .30588 L 
s 
P 
p 
.001 w 
.99625 .32941 m 
1 .32941 L 
s 
P 
p 
.001 w 
.99625 .37647 m 
1 .37647 L 
s 
P 
p 
.001 w 
.99625 .4 m 
1 .4 L 
s 
P 
p 
.001 w 
.99625 .42353 m 
1 .42353 L 
s 
P 
p 
.001 w 
.99625 .44706 m 
1 .44706 L 
s 
P 
p 
.001 w 
.99625 .49412 m 
1 .49412 L 
s 
P 
p 
.001 w 
.99625 .51765 m 
1 .51765 L 
s 
P 
p 
.001 w 
.99625 .54118 m 
1 .54118 L 
s 
P 
p 
.001 w 
.99625 .56471 m 
1 .56471 L 
s 
P 
p 
.002 w 
1 0 m 
1 .58824 L 
s 
P 
P 
p 
P 
0 0 m 
1 0 L 
1 .58824 L 
0 .58824 L 
closepath 
clip 
newpath 
p 
p 
p 
p 
/Courier findfont 8 scalefont setfont 
[(x)] .30583 .17957 -1.44979 -0.92915 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(y)] .20867 .27054 -1.44979 -0.92915 Mshowa 
P 
p 
/Courier findfont 8 scalefont setfont 
[(2)] .21176 .17647 -1.44979 -0.92915 Mshowa 
P 
.004 w 
.30583 .17957 m 
.21176 .17647 L 
.20867 .27054 L 
s 
.28733 .16954 m 
.30583 .17957 L 
.28671 .18836 L 
s 
.19988 .25141 m 
.20867 .27054 L 
.21869 .25203 L 
s 
P 
p 
p 
.007 w 
.05882 .11765 m 
.52941 .11765 L 
s 
P 
p 
.007 w 
.6126 .15211 m 
.94536 .48486 L 
s 
P 
.007 w 
newpath 
.52941 .23529 .11765 -90 -45 arc 
s 
P 
p 
.04 w 
.38814 .18228 Mdot 
1 0 0 r 
.007 w 
newpath 
.21176 .17647 .05882 91.887 271.887 arc 
s 
p 
.2137 .11768 m 
.56645 .1293 L 
s 
.56258 .24688 m 
.20983 .23526 L 
s 
P 
newpath 
.56451 .18809 .05882 -88.113 91.887 arc 
s 
P 
P 
P 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{350, 205},
  ImageMargins->{{61, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005N0000cA000`40O003h00OogooGgoo003oOomO
Ool00?mooemoo`00ogooGgoo000aOol00`00Oomoo`13Ool50014Ool30015Ool20017Ool3000:Ool0
031oo`03001oo`0004Ioo`03001oogoo04Aoo`03001oogoo04Moo`03001oogoo04Eoo`03001oogoo
00Uoo`00<7oo00<007oo0000AWoo00<007ooOol0AGoo00<007ooOol0AGoo00<007ooOol0A7oo1000
2Woo000`Ool00`00Ool00016Ool00`00Oomoo`15Ool00`00Oomoo`16Ool00`00Oomoo`13Ool00`00
Ool0000;Ool0031oo`03001oo`0004Ioo`03001oogoo04Aoo`03001oo`0004Eoo`03001oo`0004Io
o`8000]oo`00<Goo00<007ooOol0A7oo0P00Agoo00<007ooOol0AGoo00<007ooOol0AWoo00<007oo
Ool02Goo003oOomOOol00?mooemoo`00ogooGgoo003oOomOOol00?mooemoo`00ogooGgoo000?Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3oOom3Ool000ioo`03001oo`0000Moo`03001o
o`000?moodAoo`002Goo0`000Woo00<007oo00002Goo00<007ooOol00gooo`00=0002goo000>Ool0
0`00Ool00007Ool20006Ool01000Oomoo`003Woo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007oo
Ool037oo00<007ooOol02goo00<007ooOol037oo00<007ooOol02Goo000>Ool00`00Ool00007Ool0
0`00Oomoo`05Ool01000Oomoo`003Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02Goo000?Ool00`00Oomoo`06Ool30005Ool0
0`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`00
87oo00<007ooOol0ogoo<7oo00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09
Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo0P00ogoo<7oo0P002goo000POol0
0`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`00
87oo00<007ooOol0ogoo<7oo00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09
Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo00<007oo
Ool02Goo000POol2003oOol`Ool2000;Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`00
87oo00<007ooOol0ogoo<7oo00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09
Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo00<007oo
Ool02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`800?mooc1oo`8000]oo`00
87oo00<007ooOol0ogoo<7oo00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09
Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo00<007oo
Ool02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mooc1oo`03
001oogoo00Uoo`0087oo0P00ogoo<7oo0P002goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09
Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo00<007oo
Ool02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09Ool001Uoo`03001oogoo00Aoo`03001o
ogoo0?mooc1oo`03001oogoo00Uoo`0067oo00<007oo00001Goo00<007ooOol0Wgoo00<007ooOol0
SGoo00<007ooOol02Goo000HOol00`00Ool00005Ool3000>Ool[00000g`00000001U0005Ool00`00
Oomoo`24Ool3000;Ool001Qoo`03001oo`0000Eoo`03001oogoo00ioobP002al04H00003Ool007oo
08Aoo`03001oogoo00Uoo`0067oo00<007oo00001Goo00<007ooOol0=7ooDg`067oo3P00PWoo00<0
07ooOol02Goo000IOol00`00Oomoo`04Ool00`00Oomoo`0bOol6O00ZOom9O0001000O0000000P7oo
00<007ooOol02Goo000POol00`00Oomoo`0aOol4O01BOolWO0000`00O000001nOol00`00Oomoo`09
Ool0021oo`03001oogoo031oo`=l07Ioo`Yl07aoo`03001oogoo00Uoo`0087oo00<007ooOol0<7oo
0W`0NWoo2G`0NWoo00<007ooOol02Goo000POol00`00Oomoo`0_Ool2O01oOol6O01iOol00`00Oomo
o`09Ool0021oo`8002moo`=l089oo`04001l07`0O01gOol2000;Ool0021oo`03001oogoo02eoo`=l
08Aoo`04001l07`0O01gOol00`00Oomoo`09Ool0021oo`03001oogoo02eoo`9l08Moo`=l07Ioo`03
001oogoo00Uoo`0087oo00<007ooOol0;Goo00=l07ooOol0Qgoo0W`000<007ooOol0Lgoo00<007oo
Ool02Goo000POol00`00Oomoo`0/Ool2O02:Ool2O0000`00Oomoo`1bOol00`00Oomoo`09Ool0021o
o`03001oogoo02]oo`9l08]oo`=l0003001oogoo075oo`03001oogoo00Uoo`0087oo00<007ooOol0
:goo0W`0S7oo0g`000<007ooOol0L7oo00<007ooOol02Goo000POol2000/Ool2O02<Ool2O003001`
Ool2000;Ool0021oo`03001oogoo02]oo`9l02Qoo`03001oogoo01]oo`03001oogoo04=oo`=l00<0
071oo`03001oogoo00Uoo`0087oo00<007ooOol0:goo0W`0:Goo0P0067oo1P00@goo17`00`00Kgoo
00<007ooOol02Goo000POol00`00Oomoo`0[Ool00g`0Oomoo`0?Ool?000<Ool2000EOol90012Ool2
O002Ool3001^Ool00`00Oomoo`09Ool0021oo`03001oogoo02]oo`9l011oo`03001oogoo00aoo`l0
01Aoo`T0049oo`9l00=oo`<006eoo`03001oogoo00Uoo`0087oo00<007ooOol0:goo0W`047oo00<0
07ooOol067oo0P005Goo2@00@Woo0W`017oo0`00K7oo00<007ooOol02Goo000POol00`00Oomoo`0[
Ool2O00@Ool00`00Oomoo`03000COol2000FOol;0011Ool2O005Ool3001[Ool00`00Oomoo`09Ool0
021oo`8002aoo`9l011oo`03001oogoo0080019oo`8000Eoo`800003Ool007oo00moo`T0049oo`9l
00Ioo`<006Uoo`8000]oo`0087oo00<007ooOol0:goo0W`047oo00<007ooOol00Woo00<007ooOol0
67oo00<007ooOol03goo2@00@Woo0W`01goo0`00JGoo00<007ooOol02Goo000POol00`00Oomoo`0[
Ool3O00?Ool00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Ool0000@Ool90012Ool2O008Ool3001X
Ool00`00Oomoo`09Ool0021oo`03001oogoo02aoo`9l00moo`03001oogoo00<002eoo`H004Aoo`9l
00Uoo`<006Moo`03001oogoo00Uoo`0087oo00<007ooOol0;7oo0W`03goo00<007ooOol0<goo00<0
07ooOol0A7oo0W`02Woo0`00IWoo00<007ooOol02Goo000POol00`00Oomoo`0/Ool3O00>Ool00`00
Oomoo`1jOol2O00;Ool3001UOol00`00Oomoo`09Ool0021oo`03001oogoo02ioo`03O01oogoo00ao
o`03001oogoo07Uoo`9l00eoo`<006Aoo`03001oogoo00Uoo`0087oo0P00;goo0W`03Goo00<007oo
Ool0NGoo0W`03Woo0`00HWoo0P002goo000POol00`00Oomoo`0_Ool2O00<Ool00`00Oomoo`1iOol2
O00?Ool3001ROol00`00Oomoo`09Ool0021oo`03001oogoo02moo`=l00]oo`03001oogoo07Uoo`03
O01oogoo00moo`<0065oo`03001oogoo00Uoo`0087oo00<007ooOol0<7oo17`02Goo00<007ooOol0
N7oo0W`04Woo0`00H7oo00<007ooOol02Goo000POol00`00Oomoo`0aOol4O008Ool00`00Oomoo`1g
Ool3O00COol3001OOol00`00Oomoo`09Ool000moo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03=oo`Al00Ioo`03001oogoo07Ioo`=l01Eoo`<005ioo`03001oogoo00Uo
o`003Woo00<007oo00001goo00<007oo00001Goo00<007ooOol0=7oo1G`00goo0W`0MWoo17`05goo
0`00GGoo00<007ooOol02Goo000>Ool00`00Ool00009Ool00`00Oomoo`03Ool3000fOolSO01JOol4
O00IOol3001JOol3000;Ool000ioo`03001oo`0000Moo`8000Ioo`03001oogoo03Moocal03ioo`Al
01aoo`<005]oo`03001oogoo00Uoo`003Woo00<007oo00001goo00<007ooOol01Goo00<007ooOol0
?Goo00<007ooOol06Goo=G`087oo00=l07ooO0000g`07Woo0`00FWoo00<007ooOol02Goo000?Ool0
0`00Oomoo`06Ool30005Ool00`00Oomoo`0mOol00`00Oomoo`0cOolfO003Ool6O00QOol3001IOol0
0`00Oomoo`09Ool0021oo`03001oogoo03eoo`03001oogoo04ioob=l02=oo`<005Qoo`03001oogoo
00Uoo`0087oo00<007ooOol0>Woo00@007ooOol006Yoo`El02Qoo`<005Moo`03001oogoo00Uoo`00
87oo00<007ooOol0>Woo00@007ooOol0009oo`03001oogoo09=oo`<005Ioo`03001oogoo00Uoo`00
87oo00<007ooOol0>goo00D007oo001oo`0009Moo`<005Eoo`03001oogoo00Uoo`0087oo0P00?7oo
00D007oo001oo`0009Qoo`<005=oo`8000]oo`0087oo00<007ooOol0?7oo0`00VWoo0`00Dgoo00<0
07ooOol02Goo000POol00`00Oomoo`0lOol3002KOol3001BOol00`00Oomoo`09Ool0021oo`03001o
ogoo03eoo`03001oogoo09]oo`<0055oo`03001oogoo00Uoo`0087oo00<007ooOol0?goo0P00Vgoo
0`00D7oo00<007ooOol02Goo000POol00`00Oomoo`10Ool00`00Oomoo`2JOol3001?Ool00`00Oomo
o`09Ool0021oo`03001oogoo041oo`03001oogoo09]oo`<004ioo`03001oogoo00Uoo`0087oo0P00
@7oo00<007oo0000WGoo0`00C7oo0P002goo000POol00`00Oomoo`0oOol01000Ool00000WGoo0`00
C7oo00<007ooOol02Goo000POol00`00Oomoo`3QOol3001;Ool00`00Oomoo`09Ool0021oo`03001o
ogoo0>9oo`<004Yoo`03001oogoo00Uoo`0087oo00<007ooOol0hgoo0`00BGoo00<007ooOol02Goo
000POol00`00Oomoo`3TOol30018Ool00`00Oomoo`09Ool0021oo`03001oogoo0>Eoo`<004Moo`03
001oogoo00Uoo`0087oo0P00igoo0`00AGoo0P002goo000POol00`00Oomoo`3WOol30015Ool00`00
Oomoo`09Ool0021oo`03001oogoo0>Qoo`<004Aoo`03001oogoo00Uoo`0087oo00<007ooOol0jGoo
0`00@goo00<007ooOol02Goo000POol00`00Oomoo`3ZOol30012Ool00`00Oomoo`09Ool0021oo`03
001oogoo0>]oo`<0045oo`03001oogoo00Uoo`0087oo00<007ooOol0k7oo0`00@7oo00<007ooOol0
2Goo000POol2003^Ool3000nOol2000;Ool0021oo`03001oogoo0>ioo`<003ioo`03001oogoo00Uo
o`0087oo00<007ooOol0kgoo0`00?Goo00<007ooOol02Goo000POol00`00Oomoo`3`Ool3000lOol0
0`00Oomoo`09Ool0021oo`03001oogoo0?5oo`<003]oo`03001oogoo00Uoo`005goo1@0017oo00<0
07ooOol0lWoo0`00>Woo00<007ooOol02Goo000IOol00`00Oomoo`04Ool00`00Oomoo`3cOol3000i
Ool00`00Oomoo`09Ool001Uoo`03001oogoo00Aoo`<00?Aoo`<003Ioo`<000]oo`006Goo00<007oo
Ool017oo00<007ooOol0mGoo0`00=goo00<007ooOol02Goo000IOol00`00Oomoo`04Ool00`00Oomo
o`3fOol3000fOol00`00Oomoo`09Ool001Qoo`8000Ioo`03001oogoo0?Moo`<003Eoo`03001oogoo
00Uoo`0087oo00<007ooOol0n7oo0`00=7oo00<007ooOol02Goo000POol00`00Oomoo`3iOol3000c
Ool00`00Oomoo`09Ool0021oo`03001oogoo0?Yoo`<0039oo`03001oogoo00Uoo`0087oo00<007oo
Ool0ngoo0`00<Goo00<007ooOol02Goo000POol2003mOol3000_Ool2000;Ool0021oo`03001oogoo
0?eoo`<002moo`03001oogoo00Uoo`0087oo00<007ooOol0oWoo0`00;Woo00<007ooOol02Goo000P
Ool00`00Oomoo`3oOol3000]Ool00`00Oomoo`09Ool0021oo`03001oogoo0?moo`5oo`<002aoo`03
001oogoo00Uoo`0087oo00<007ooOol0ogoo0Woo0`00:goo00<007ooOol02Goo000POol00`00Oomo
o`3oOol3Ool3000ZOol00`00Oomoo`09Ool0021oo`800?moo`Eoo`<002Qoo`8000]oo`0087oo00<0
07ooOol0ogoo1Goo0`00:7oo00<007ooOol02Goo000POol00`00Oomoo`3oOol6Ool3000WOol00`00
Oomoo`09Ool0021oo`03001oogoo0?moo`Moo`<002Ioo`03001oogoo00Uoo`0087oo00<007ooOol0
ogoo27oo0`009Goo00<007ooOol02Goo000POol00`00Oomoo`3oOol9Ool3000TOol00`00Oomoo`09
Ool0021oo`03001oogoo0?moo`Yoo`<002=oo`03001oogoo00Uoo`0087oo0P00ogoo37oo0`008Goo
0P002goo000POol00`00Oomoo`3oOol<Ool3000QOol00`00Oomoo`09Ool0021oo`03001oogoo0?mo
o`eoo`<0021oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo3Woo0`007goo00<007ooOol02Goo
000POol00`00Oomoo`3oOol?Ool3000NOol00`00Oomoo`09Ool0021oo`03001oogoo0?mooa1oo`<0
01eoo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo4Goo0`0077oo00<007ooOol02Goo000POol2
003oOolCOol3000JOol2000;Ool0021oo`03001oogoo0?mooa=oo`<001Yoo`03001oogoo00Uoo`00
87oo00<007ooOol0ogoo57oo0`006Goo00<007ooOol02Goo000POol00`00Oomoo`3oOolEOol3000H
Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mooaIoo`<001Moo`03001oogoo00Uoo`003Goo1@00
0Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogoo5goo0`005Woo00<007ooOol02Goo
000?Ool00`00Oomoo`06Ool00`00Ool00005Ool00`00Oomoo`3oOolHOol3000EOol00`00Oomoo`09
Ool000moo`03001oogoo00Qoo`03001oogoo00=oo`<00?mooaUoo`<0019oo`<000]oo`003goo00<0
07ooOol01Woo0P001Woo00<007ooOol0ogoo6Woo0`004goo00<007ooOol02Goo000?Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`3oOolKOol3000BOol00`00Oomoo`09Ool000ioo`8000Qo
o`<000Eoo`03001oogoo0?mooaaoo`<0015oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo7Goo
0`0047oo00<007ooOol02Goo000POol00`00Oomoo`3oOolNOol3000?Ool00`00Oomoo`09Ool0021o
o`03001oogoo0?mooamoo`03001oogoo00ioo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo
00<007ooOol02Goo000POol2003oOol`Ool2000;Ool0021oo`03001oogoo0?mooc1oo`03001oogoo
00Uoo`0087oo00<007ooOol0ogoo<7oo00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00
Oomoo`09Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo
00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`800?mooc1oo`80
00]oo`0087oo00<007ooOol0ogoo<7oo00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00
Oomoo`09Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo
00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mo
oc1oo`03001oogoo00Uoo`0087oo0P00ogoo<7oo0P002goo000POol00`00Oomoo`3oOol`Ool00`00
Oomoo`09Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo
00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mo
oc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo00<007ooOol02Goo000POol2003oOol`
Ool2000;Ool0021oo`03001oogoo0?mooc1oo`03001oogoo00Uoo`0087oo00<007ooOol0ogoo<7oo
00<007ooOol02Goo000POol00`00Oomoo`3oOol`Ool00`00Oomoo`09Ool0021oo`03001oogoo0?mo
oc1oo`03001oogoo00Uoo`0067oo0`001Goo00<007ooOol0ogoo<7oo00<007ooOol02Goo000HOol0
0`00Oomoo`05Ool01000Oomoo`003Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo
00<007ooOol02goo00<007ooOol037oo00<007ooOol02Goo000IOol00`00Oomoo`04Oooo000d000;
Ool001Uoo`03001oogoo0?mood=oo`0067oo00<007oo0000ogooA7oo000IOol00`00Oomoo`3oOom3
Ool00?mooemoo`00ogooGgoo003oOomOOol00001\
\>"],
  ImageRangeCache->{{{0, 349}, {204, 0}} -> {-0.696747, -0.750017, 0.0138891, 
  0.0138891}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Switch Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Now the exact value of ",
  StyleBox["swtime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be found with ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Because the slider passes tangentially from the curved section of the \
ramp onto the inclined section (which implies that there is no discontinuity \
in the velocity of the slider at the transition) the ",
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option must be used with ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This option tells ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to look for the point of velocity equality instead of just location \
equality."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Find switch time 2 in constraint 3."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(swtime = T /. FindSwitchTime[3, 2, TangentConstraint \[Rule] True]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.678564978733080437`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Loads"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The goal of this example is to determine the force required to push the \
slider around the curved section of the ramp and up the incline, with gravity \
pulling down on the slider, and friction between the slider and the ramp at \
both ends.\n\nFirst, gravity is applied without any friction forces. A plot \
of the force required to push the slider is made from a list of solutions \
returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a gravitational load. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1] = Gravity[{0, \(-1\)}, 9.81]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The model is run from ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.0 to 1.8. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((stattab = SolveMech[{0, 1.8}, 30, Solution \[Rule] Static])
        \)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(T \[Rule] 0\), ",", \(X2 \[Rule] 0.`\), ",", 
        RowBox[{"Y2", "\[Rule]", 
          StyleBox["0.25`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", 
        \(Th2 \[Rule] 1.95654243132469005`*^-14\), ",", \(Lmb1 \[Rule] 0.`\), 
        ",", \(Lmb2 \[Rule] \(-4.90500000000000024`\)\), ",", 
        \(Lmb3 \[Rule] \(-2.45250000000000012`\)\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a plot of the driving force."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{T, 
          \(Reaction[1, slider]\)\[LeftDoubleBracket]1, 1
            \[RightDoubleBracket]} /. stattab, Frame \[Rule] True, 
      PlotJoined \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.529101 0.0147151 0.126186 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -12 -9 ]
[.15608 -0.0125 12 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -12 -9 ]
[.42063 -0.0125 12 0 ]
[.55291 -0.0125 -3 -9 ]
[.55291 -0.0125 3 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .1409 -6 -4.5 ]
[-0.0125 .1409 0 4.5 ]
[-0.0125 .26709 -6 -4.5 ]
[-0.0125 .26709 0 4.5 ]
[-0.0125 .39327 -6 -4.5 ]
[-0.0125 .39327 0 4.5 ]
[-0.0125 .51946 -6 -4.5 ]
[-0.0125 .51946 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(0.25)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(0.5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(0.75)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(1)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(1.25)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(1.5)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(1.75)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .1409 m
.00625 .1409 L
s
[(1)] -0.0125 .1409 1 0 Mshowa
0 .26709 m
.00625 .26709 L
s
[(2)] -0.0125 .26709 1 0 Mshowa
0 .39327 m
.00625 .39327 L
s
[(3)] -0.0125 .39327 1 0 Mshowa
0 .51946 m
.00625 .51946 L
s
[(4)] -0.0125 .51946 1 0 Mshowa
.125 Mabswid
0 .03995 m
.00375 .03995 L
s
0 .06519 m
.00375 .06519 L
s
0 .09043 m
.00375 .09043 L
s
0 .11566 m
.00375 .11566 L
s
0 .16614 m
.00375 .16614 L
s
0 .19138 m
.00375 .19138 L
s
0 .21661 m
.00375 .21661 L
s
0 .24185 m
.00375 .24185 L
s
0 .29233 m
.00375 .29233 L
s
0 .31756 m
.00375 .31756 L
s
0 .3428 m
.00375 .3428 L
s
0 .36804 m
.00375 .36804 L
s
0 .41851 m
.00375 .41851 L
s
0 .44375 m
.00375 .44375 L
s
0 .46899 m
.00375 .46899 L
s
0 .49422 m
.00375 .49422 L
s
0 .5447 m
.00375 .5447 L
s
0 .56993 m
.00375 .56993 L
s
0 .59517 m
.00375 .59517 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .1409 m
1 .1409 L
s
.99375 .26709 m
1 .26709 L
s
.99375 .39327 m
1 .39327 L
s
.99375 .51946 m
1 .51946 L
s
.125 Mabswid
.99625 .03995 m
1 .03995 L
s
.99625 .06519 m
1 .06519 L
s
.99625 .09043 m
1 .09043 L
s
.99625 .11566 m
1 .11566 L
s
.99625 .16614 m
1 .16614 L
s
.99625 .19138 m
1 .19138 L
s
.99625 .21661 m
1 .21661 L
s
.99625 .24185 m
1 .24185 L
s
.99625 .29233 m
1 .29233 L
s
.99625 .31756 m
1 .31756 L
s
.99625 .3428 m
1 .3428 L
s
.99625 .36804 m
1 .36804 L
s
.99625 .41851 m
1 .41851 L
s
.99625 .44375 m
1 .44375 L
s
.99625 .46899 m
1 .46899 L
s
.99625 .49422 m
1 .49422 L
s
.99625 .5447 m
1 .5447 L
s
.99625 .56993 m
1 .56993 L
s
.99625 .59517 m
1 .59517 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.05665 .01472 L
.08949 .01472 L
.12233 .01472 L
.15517 .01472 L
.18801 .01472 L
.22085 .01472 L
.25369 .01472 L
.28654 .01472 L
.31938 .1638 L
.35222 .35093 L
.38506 .60332 L
.4179 .5823 L
.45074 .5632 L
.48358 .54567 L
.51642 .52945 L
.54926 .51432 L
.5821 .50012 L
.61494 .48671 L
.64778 .47399 L
.68062 .46185 L
.71346 .45022 L
.74631 .43903 L
.77915 .42822 L
.81199 .41775 L
.84483 .40756 L
.87767 .39762 L
.91051 .38789 L
.94335 .37834 L
.97619 .36893 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo000DOol0
0`00Oomoo`0HOol00`00Oomoo`02Ool01000Oomoogoo0`000goo00<007ooOol04Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol04goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol05Woo1@005Goo1@000Woo00@007ooOomoo`<000=oo`03001oogoo015oo`D0009o
o`03001oogoo009oo`03001oogoo015oo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Yoo`004goo00<007oo000067oo00<007oo00001goo00<007ooOol00Woo00<007oo00004Woo
00<007oo00001goo00<007oo00004goo00<007oo000027oo00L007ooOomoo`00Ool0000IOol00`00
Oomoo`0GOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool0000DOol00`00Oomoo`06Ool00`00
Ool0000DOol00`00Oomoo`07Ool01`00Oomoogoo001oo`0000]oo`004goo00<007oo000067oo00<0
07oo000027oo00<007ooOol00goo00<007ooOol047oo00<007oo00002Goo00<007ooOol04Goo00<0
07oo000027oo00<007ooOol00goo00<007ooOol05goo00<007ooOol05goo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol04Woo00<007ooOol027oo00<007ooOol04Woo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol02Goo000COol00`00Ool0000HOol00`00Ool00008Ool01000Oomoogoo
0P004goo00<007oo00001goo0P0057oo00<007oo00002Goo00<007ooOol00P006Woo00<007ooOol0
5goo00<007ooOol01goo00@007ooOomoo`8001Eoo`03001oogoo00Ioo`8001Eoo`03001oogoo00Qo
o`03001oogoo008000aoo`004goo00<007oo000067oo00<007oo00001goo00<007oo00000Woo00<0
07ooOol04Woo00<007oo00001goo00<007ooOol04goo00<007oo00001goo00<007oo00000Woo00<0
07ooOol06Goo00<007ooOol05goo00<007ooOol01Woo00<007oo00000Woo00<007ooOol057oo00<0
07ooOol01Woo00<007ooOol057oo00<007ooOol01Woo00<007oo00000Woo00<007ooOol02goo000D
Ool00`00Oomoo`0HOol00`00Oomoo`07Ool01000Oomoogoo0`004goo00<007ooOol01Woo0`0057oo
00<007ooOol01Woo0`000Woo0`0067oo0P0067oo0P002Goo00@007ooOomoo`<001=oo`8000Qoo`<0
01=oo`8000Qoo`<0009oo`<000]oo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`003Wooo`001@001Woo000>Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool000Qoo`03001oogoo00=oo`03001oogoo0?moo`5oo`03001oogoo00Ao
o`001goo00<007oo000017oo00<007ooOol0ogoo0Goo00<007ooOol017oo0007Ool00`00Ool00004
Ool30003Oom5002fOol30006Ool000Moo`03001oo`0000Aoo`03001oogoo04Moo`03001oogoo0;Io
o`03001oogoo00Aoo`001goo00<007oo000017oo00<007ooOol0Agoo00<007ooOol0]Woo00<007oo
Ool017oo0008Ool00`00Oomoo`03Ool00`00Oomoo`18Ool00`00Oomoo`2eOol00`00Oomoo`04Ool0
00ioo`03001oogoo04Qoo`03001oogoo0;Eoo`03001oogoo00Aoo`003Woo00<007ooOol0B7oo00<0
07ooOol0]Goo00<007ooOol017oo000>Ool20019Ool00`00Oomoo`2dOol20006Ool000ioo`03001o
ogoo04Uoo`03001oogoo0;Aoo`03001oogoo00Aoo`003Woo00<007ooOol0BGoo00<007ooOol0]7oo
00<007ooOol017oo000>Ool00`00Oomoo`19Ool00`00Oomoo`2dOol00`00Oomoo`04Ool000ioo`03
001oogoo04Uoo`03001oogoo0;Aoo`03001oogoo00Aoo`003Woo00<007ooOol0BWoo00<007ooOol0
/goo00<007ooOol017oo000>Ool00`00Oomoo`1:Ool00`00Oomoo`2cOol00`00Oomoo`04Ool000io
o`8004]oo`03001oogoo0;9oo`8000Ioo`003Woo00<007ooOol0BWoo00<007ooOol0/goo00<007oo
Ool017oo000>Ool00`00Oomoo`1;Ool00`00Oomoo`2bOol00`00Oomoo`04Ool000ioo`03001oogoo
04]oo`03001oogoo0;9oo`03001oogoo00Aoo`003Woo00<007ooOol0Bgoo00<007ooOol0/Woo00<0
07ooOol017oo000>Ool00`00Oomoo`1;Ool00`00Oomoo`2bOol00`00Oomoo`04Ool000ioo`8004ao
o`03001oogoo0;5oo`8000Ioo`003Woo00<007ooOol0C7oo00<007ooOol0/Goo00<007ooOol017oo
000>Ool00`00Oomoo`1<Ool00`00Oomoo`2aOol00`00Oomoo`04Ool000ioo`03001oogoo04aoo`03
001oogoo0;5oo`03001oogoo00Aoo`003Woo00<007ooOol0C7oo00<007ooOol0/Goo00<007ooOol0
17oo000>Ool00`00Oomoo`1=Ool00`00Oomoo`2`Ool00`00Oomoo`04Ool000ioo`03001oogoo04eo
o`03001oogoo0;1oo`03001oogoo00Aoo`003Woo0P00CWoo00<007ooOol0[goo0P001Woo000>Ool0
0`00Oomoo`1=Ool00`00Oomoo`2`Ool00`00Oomoo`04Ool000ioo`03001oogoo04ioo`03001oogoo
0:moo`03001oogoo00Aoo`003Woo00<007ooOol0CWoo00<007ooOol0[goo00<007ooOol017oo0006
Ool50003Ool00`00Oomoo`1>Ool00`00Oomoo`2_Ool00`00Oomoo`04Ool000Qoo`03001oogoo00=o
o`03001oogoo04ioo`03001oogoo0:moo`03001oogoo00Aoo`0027oo00<007ooOol00goo0`00Cgoo
00<007ooOol0[7oo0`001Woo0008Ool00`00Oomoo`03Ool00`00Oomoo`1?Ool00`00Oomoo`2^Ool0
0`00Oomoo`04Ool000Qoo`03001oogoo00=oo`03001oogoo04moo`03001oogoo0:ioo`03001oogoo
00Aoo`001goo0P001Goo00<007ooOol0Cgoo00<007ooOol0[Woo00<007ooOol017oo000>Ool00`00
Oomoo`1@Ool00`00Oomoo`2]Ool00`00Oomoo`04Ool000ioo`03001oogoo051oo`03001oogoo0:eo
o`03001oogoo00Aoo`003Woo00<007ooOol0D7oo00<007ooOol0[Goo00<007ooOol017oo000>Ool2
001AOol00`00Oomoo`2/Ool20006Ool000ioo`03001oogoo051oo`03001oogoo0:eoo`03001oogoo
00Aoo`003Woo00<007ooOol0D7oo00<007ooOol0[Goo00<007ooOol017oo000>Ool00`00Oomoo`1A
Ool00`00Oomoo`2/Ool00`00Oomoo`04Ool000ioo`03001oogoo055oo`03001oogoo0:aoo`03001o
ogoo00Aoo`003Woo00<007ooOol0DGoo00<007ooOol0[7oo00<007ooOol017oo000>Ool2001BOol0
0`00Oomoo`2[Ool20006Ool000ioo`03001oogoo055oo`03001oogoo0:aoo`03001oogoo00Aoo`00
3Woo00<007ooOol0DGoo00<007ooOol0[7oo00<007ooOol017oo000>Ool00`00Oomoo`1BOol00`00
Oomoo`2[Ool00`00Oomoo`04Ool000ioo`03001oogoo059oo`03001oogoo0:]oo`03001oogoo00Ao
o`003Woo00<007ooOol0DWoo00<007ooOol0Zgoo00<007ooOol017oo000>Ool00`00Oomoo`1BOol0
0`00Oomoo`2[Ool00`00Oomoo`04Ool000ioo`8005=oo`03001oogoo0:Yoo`8000Ioo`003Woo00<0
07ooOol0DWoo00<007ooOol0Zgoo00<007ooOol017oo000>Ool00`00Oomoo`1COol00`00Oomoo`2Z
Ool00`00Oomoo`04Ool000ioo`03001oogoo05=oo`03001oogoo0:Yoo`03001oogoo00Aoo`003Woo
00<007ooOol0Dgoo00<007ooOol0ZWoo00<007ooOol017oo000>Ool00`00Oomoo`1COol00`00Oomo
o`2ZOol00`00Oomoo`04Ool000ioo`8005Aoo`03001oogoo0:Uoo`8000Ioo`003Woo00<007ooOol0
Dgoo00<007ooOol0ZWoo00<007ooOol017oo000>Ool00`00Oomoo`1DOol00`00Oomoo`2YOol00`00
Oomoo`04Ool000ioo`03001oogoo05Aoo`03001oogoo0:Uoo`03001oogoo00Aoo`003Woo00<007oo
Ool0E7oo00<007ooOol0ZGoo00<007ooOol017oo0007Ool30004Ool00`00Oomoo`1DOol00`00Oomo
o`2YOol00`00Oomoo`04Ool000Moo`03001oogoo00Aoo`03001oogoo05Aoo`03001oogoo0:Uoo`03
001oogoo00Aoo`0027oo00<007ooOol00goo0`00E7oo00<007ooOol0Ygoo0`001Woo0008Ool00`00
Oomoo`03Ool00`00Oomoo`1EOol00`00Oomoo`2XOol00`00Oomoo`04Ool000Moo`03001oo`0000Ao
o`03001oogoo05Eoo`03001oogoo0:Qoo`03001oogoo00Aoo`0027oo00<007ooOol00goo00<007oo
Ool0EGoo00<007ooOol0Z7oo00<007ooOol017oo000>Ool00`00Oomoo`1EOol00`00Oomoo`2XOol0
0`00Oomoo`04Ool000ioo`03001oogoo05Eoo`03001oogoo0:Qoo`03001oogoo00Aoo`003Woo0P00
EWoo00<007ooOol0Ygoo0P001Woo000>Ool00`00Oomoo`1FOol00`00Oomoo`2WOol00`00Oomoo`04
Ool000ioo`03001oogoo05Ioo`03001oogoo0:Moo`03001oogoo00Aoo`003Woo00<007ooOol0EWoo
00<007ooOol0Ygoo00<007ooOol017oo000>Ool00`00Oomoo`1FOol00`00Oomoo`2WOol00`00Oomo
o`04Ool000ioo`03001oogoo05Ioo`03001oogoo0:Moo`03001oogoo00Aoo`003Woo00<007ooOol0
EWoo00<007ooOol0Ygoo00<007ooOol017oo000>Ool2001HOol00`00Oomoo`2UOol20006Ool000io
o`03001oogoo05Moo`03001oogoo0:Ioo`03001oogoo00Aoo`003Woo00<007ooOol0Egoo00<007oo
Ool0YWoo00<007ooOol017oo000>Ool00`00Oomoo`1GOol00`00Oomoo`2VOol00`00Oomoo`04Ool0
00ioo`03001oogoo05Moo`03001oogoo0:Ioo`03001oogoo00Aoo`003Woo00<007ooOol0Egoo00<0
07ooOol0YWoo00<007ooOol017oo000>Ool2001IOol00`00Oomoo`2TOol20006Ool000ioo`03001o
ogoo05Qoo`03001oogoo0:Eoo`03001oogoo00Aoo`003Woo00<007ooOol0F7oo00<007ooOol0YGoo
00<007ooOol017oo000>Ool00`00Oomoo`1HOol00`00Oomoo`2UOol00`00Oomoo`04Ool000ioo`03
001oogoo05Qoo`03001oogoo0:Eoo`03001oogoo00Aoo`003Woo00<007ooOol0F7oo00<007ooOol0
YGoo00<007ooOol017oo000>Ool00`00Oomoo`1IOol00`00Oomoo`2TOol00`00Oomoo`04Ool000io
o`8005Yoo`03001oogoo09eoo`8000Aoo`8000Ioo`003Woo00<007ooOol0FGoo00<007ooOol0VWoo
0`001goo00<007ooOol017oo000>Ool00`00Oomoo`1IOol00`00Oomoo`2GOol3000:Ool00`00Oomo
o`04Ool000ioo`03001oogoo05Uoo`03001oogoo09Aoo`<000eoo`03001oogoo00Aoo`001goo0P00
1Goo00<007ooOol0FGoo00<007ooOol0T7oo100047oo00<007ooOol017oo0009Ool00`00Oomoo`02
Ool00`00Oomoo`1IOol00`00Oomoo`2<Ool4000DOol00`00Oomoo`04Ool000Qoo`03001oogoo00=o
o`<005Uoo`03001oogoo08Uoo`<001Ioo`<000Ioo`002Goo00<007ooOol00Woo00<007ooOol0FWoo
00<007ooOol0QGoo0`006goo00<007ooOol017oo0007Ool00`00Ool00004Ool00`00Oomoo`1JOol0
0`00Oomoo`22Ool3000NOol00`00Oomoo`04Ool000Qoo`03001oogoo00=oo`03001oogoo05Yoo`03
001oogoo07ioo`@0025oo`03001oogoo00Aoo`003Woo00<007ooOol0FWoo00<007ooOol0NWoo1000
9Goo00<007ooOol017oo000>Ool00`00Oomoo`1JOol00`00Oomoo`1gOol3000YOol00`00Oomoo`04
Ool000ioo`03001oogoo05Yoo`03001oogoo07Aoo`<002aoo`03001oogoo00Aoo`003Woo0P00Fgoo
00<007ooOol0LGoo0`00;Woo0P001Woo000>Ool00`00Oomoo`1KOol00`00Oomoo`1/Ool4000bOol0
0`00Oomoo`04Ool000ioo`03001oogoo05]oo`03001oogoo06Qoo`@003Ioo`03001oogoo00Aoo`00
3Woo00<007ooOol0Fgoo00<007ooOol0IGoo0`00>Woo00<007ooOol017oo000>Ool00`00Oomoo`1K
Ool00`00Oomoo`1ROol3000mOol00`00Oomoo`04Ool000ioo`03001oogoo05]oo`03001oogoo05mo
o`<0041oo`03001oogoo00Aoo`003Woo0P00G7oo00<007ooOol0GGoo0P00@Woo0P001Woo000>Ool0
0`00Oomoo`1KOol00`00Oomoo`1JOol30015Ool00`00Oomoo`04Ool000ioo`03001oogoo05aoo`03
001oogoo05Ioo`<004Qoo`03001oogoo00Aoo`003Woo00<007ooOol0G7oo00<007ooOol0Dgoo0`00
Bgoo00<007ooOol017oo000>Ool00`00Oomoo`1LOol00`00Oomoo`1@Ool3001>Ool00`00Oomoo`04
Ool000ioo`03001oogoo05aoo`03001oogoo04eoo`<0055oo`03001oogoo00Aoo`003Woo00<007oo
Ool0G7oo00<007ooOol0Bgoo0P00E7oo00<007ooOol017oo000>Ool2001MOol00`00Oomoo`18Ool3
001EOol20006Ool000ioo`03001oogoo05aoo`03001oogoo04Eoo`<005Uoo`03001oogoo00Aoo`00
3Woo00<007ooOol0G7oo00<007ooOol0@goo0P00G7oo00<007ooOol017oo000>Ool00`00Oomoo`1M
Ool00`00Oomoo`10Ool2001NOol00`00Oomoo`04Ool000ioo`03001oogoo05eoo`03001oogoo03io
o`80061oo`03001oogoo00Aoo`003Woo00<007ooOol0GGoo00<007ooOol0>goo0`00HWoo00<007oo
Ool017oo000>Ool2001NOol00`00Oomoo`0iOol2001TOol20006Ool000ioo`03001oogoo05eoo`03
001oogoo03Ioo`<006Moo`03001oogoo00Aoo`003Woo00<007ooOol0GGoo00<007ooOol0<goo0`00
JWoo00<007ooOol017oo000>Ool00`00Oomoo`1MOol00`00Oomoo`0aOol2001]Ool00`00Oomoo`04
Ool000ioo`03001oogoo05ioo`03001oogoo02ioo`8006moo`03001oogoo00Aoo`0027oo0`000goo
00<007ooOol0GWoo00<007ooOol0;7oo0P00LGoo00<007ooOol017oo0009Ool00`00Oomoo`02Ool0
0`00Oomoo`1NOol00`00Oomoo`0ZOol2001cOol00`00Oomoo`04Ool000Moo`@000=oo`<005ioo`03
001oogoo02Qoo`8007=oo`<000Ioo`001goo00<007oo000017oo00<007ooOol0GWoo00<007ooOol0
9Woo0P00Mgoo00<007ooOol017oo0008Ool20004Ool00`00Oomoo`1NOol00`00Oomoo`0TOol2001i
Ool00`00Oomoo`04Ool000Uoo`03001oogoo009oo`03001oogoo05ioo`03001oogoo025oo`<007]o
o`03001oogoo00Aoo`003Woo00<007ooOol0Ggoo00<007ooOol07Woo0P00OWoo00<007ooOol017oo
000>Ool00`00Oomoo`1OOol00`00Oomoo`0LOol20020Ool00`00Oomoo`04Ool000ioo`03001oogoo
05moo`03001oogoo01Yoo`80089oo`03001oogoo00Aoo`003Woo0P00H7oo00<007ooOol067oo0P00
Pgoo0P001Woo000>Ool00`00Oomoo`1OOol00`00Oomoo`0FOol20026Ool00`00Oomoo`04Ool000io
o`03001oogoo05moo`03001oogoo01Aoo`8008Qoo`03001oogoo00Aoo`003Woo00<007ooOol0Ggoo
00<007ooOol04Woo0P00RWoo00<007ooOol017oo000>Ool00`00Oomoo`1OOol00`00Oomoo`0@Ool2
002<Ool00`00Oomoo`04Ool000ioo`03001oogoo061oo`03001oogoo00eoo`8008ioo`03001oogoo
00Aoo`003Woo0P00HGoo00<007ooOol02goo0P00Sgoo0P001Woo000>Ool00`00Oomoo`1POol00`00
Oomoo`09Ool2002BOol00`00Oomoo`04Ool000ioo`03001oogoo061oo`03001oogoo00Moo`8009Ao
o`03001oogoo00Aoo`003Woo00<007ooOol0H7oo00<007ooOol01Woo00<007ooOol0U7oo00<007oo
Ool017oo000>Ool00`00Oomoo`1POol00`00Oomoo`05Ool00`00Oomoo`2EOol00`00Oomoo`04Ool0
00ioo`03001oogoo061oo`03001oogoo00=oo`8009Qoo`03001oogoo00Aoo`003Woo00<007ooOol0
HGoo00D007ooOomoo`0009Yoo`03001oogoo00Aoo`003Woo0P00HWoo00@007ooOol009Yoo`8000Io
o`003Woo00<007ooOol0HGoo0`00W7oo00<007ooOol017oo000>Ool00`00Oomoo`1QOol00`00Oomo
o`2LOol00`00Oomoo`04Ool000ioo`03001oogoo0?moo`5oo`03001oogoo00Aoo`003Woo00<007oo
Ool00goo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol087oo00<007ooOol07goo00<007ooOol02Woo00<007ooOol017oo000>Oooo
00050006Ool00001\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.153191, -0.491601, 0.00731112,
   0.0306557}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Now a friction force is added to the left end of the slider. This is \
fairly straightforward, as the line of action of the force is constant \
throughout the motion of the slider. The force is applied to the slider and \
the line of action is along the surface of the ramp. The magnitude of the \
force is equal to the coefficient of friction times the normal force at the \
left end of the slider, which is the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " reaction to constraint 2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the left end friction load. The symbol ",
  StyleBox["cf",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the coefficient of friction."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cf = 0.4; \)\), 
    \(\(ld[2] = 
      Force[slider, Line[ramp, 2, 1], 
        cf\ \(Reaction[2, slider]\)\[LeftDoubleBracket]1, 2
            \[RightDoubleBracket]]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Now a friction force is added to the right end of the slider. This is \
rather complicated, as the line of action of the friction force changes as \
the slider passes from one section of the ramp to another.\n\nThe friction \
force is applied to the slider, but the line of action is along the surface \
of the ramp. On the two flat sections of the ramp, the friction force is \
applied in the same manner as the force on the left end of the slider. \
However, the line of action of the force around the curve on the ramp has to \
be developed directly with vector algebra.\n\nAlthough the line of action \
changes as the slider moves through the different stages of the ramp, the \
magnitude of the normal force is always equal to the coefficient of friction \
times the magnitude of the reaction force of constraint 3, even though \
constraint 3 is changing from one constraint type to another. \n\n",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to switch between the forces in exactly the same manner as it is \
used to switch constraints, without the constraint number argument. Since the \
forcing functions switch at the same times as the constraints, the same \
switch times can be used."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the right end friction load "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(rightnormal = 
      Magnitude[
        \(Reaction[3, slider]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]; 
    \)\), 
    \(\(ld[3] = 
      TimeSwitch[\n\t\tForce[slider, Line[ramp, 2, 1], cf\ rightnormal], \n
        \t\t0.50, \n\t\t
        Force[slider, 
          Axis[Location[ramp, 3] + radius\ Unit[ramp, 3, slider, 2], 
            RMatrix.Direction[slider, 2, ramp, 3]], cf\ rightnormal], \n\t\t
        swtime, \n\t\tForce[slider, Line[ramp, 5, 4], cf\ rightnormal]]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"All of the defined loads are added here to the current model. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1], ld[2], ld[3]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called with intermediate times in between the beginning and end times \
that are explicitly included in the points in time that are solved for. This \
ensures that a data point is included exactly at the peak of the force plot. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The model is now run through a range of 30 points in time, including the two \
switch times. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((stattab = 
          SolveMech[{0, 0.5, swtime, 1.8}, 30, Solution \[Rule] Static])
        \)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 0.`, Y2 \[Rule] 0.25`, 
      Th2 \[Rule] \(-2.03455989035428164`*^-11\), 
      Lmb1 \[Rule] \(-3.9240000000000009`\), 
      Lmb2 \[Rule] \(-4.25099999999999944`\), 
      Lmb3 \[Rule] \(-2.77950000000000052`\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a plot of the driving force. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{T, 
          \(Reaction[1, slider]\)\[LeftDoubleBracket]1, 1
            \[RightDoubleBracket]} /. stattab, Frame \[Rule] True, 
      PlotJoined \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.529101 -0.205202 0.0560442 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.15608 -0.0125 -12 -9 ]
[.15608 -0.0125 12 0 ]
[.28836 -0.0125 -9 -9 ]
[.28836 -0.0125 9 0 ]
[.42063 -0.0125 -12 -9 ]
[.42063 -0.0125 12 0 ]
[.55291 -0.0125 -3 -9 ]
[.55291 -0.0125 3 0 ]
[.68519 -0.0125 -12 -9 ]
[.68519 -0.0125 12 0 ]
[.81746 -0.0125 -9 -9 ]
[.81746 -0.0125 9 0 ]
[.94974 -0.0125 -12 -9 ]
[.94974 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01897 -6 -4.5 ]
[-0.0125 .01897 0 4.5 ]
[-0.0125 .13106 -6 -4.5 ]
[-0.0125 .13106 0 4.5 ]
[-0.0125 .24315 -6 -4.5 ]
[-0.0125 .24315 0 4.5 ]
[-0.0125 .35524 -12 -4.5 ]
[-0.0125 .35524 0 4.5 ]
[-0.0125 .46733 -12 -4.5 ]
[-0.0125 .46733 0 4.5 ]
[-0.0125 .57942 -12 -4.5 ]
[-0.0125 .57942 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.15608 0 m
.15608 .00625 L
s
[(0.25)] .15608 -0.0125 0 1 Mshowa
.28836 0 m
.28836 .00625 L
s
[(0.5)] .28836 -0.0125 0 1 Mshowa
.42063 0 m
.42063 .00625 L
s
[(0.75)] .42063 -0.0125 0 1 Mshowa
.55291 0 m
.55291 .00625 L
s
[(1)] .55291 -0.0125 0 1 Mshowa
.68519 0 m
.68519 .00625 L
s
[(1.25)] .68519 -0.0125 0 1 Mshowa
.81746 0 m
.81746 .00625 L
s
[(1.5)] .81746 -0.0125 0 1 Mshowa
.94974 0 m
.94974 .00625 L
s
[(1.75)] .94974 -0.0125 0 1 Mshowa
.125 Mabswid
.05026 0 m
.05026 .00375 L
s
.07672 0 m
.07672 .00375 L
s
.10317 0 m
.10317 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.20899 0 m
.20899 .00375 L
s
.23545 0 m
.23545 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.31481 0 m
.31481 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.36772 0 m
.36772 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.44709 0 m
.44709 .00375 L
s
.47354 0 m
.47354 .00375 L
s
.5 0 m
.5 .00375 L
s
.52646 0 m
.52646 .00375 L
s
.57937 0 m
.57937 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.63228 0 m
.63228 .00375 L
s
.65873 0 m
.65873 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.79101 0 m
.79101 .00375 L
s
.84392 0 m
.84392 .00375 L
s
.87037 0 m
.87037 .00375 L
s
.89683 0 m
.89683 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01897 m
.00625 .01897 L
s
[(4)] -0.0125 .01897 1 0 Mshowa
0 .13106 m
.00625 .13106 L
s
[(6)] -0.0125 .13106 1 0 Mshowa
0 .24315 m
.00625 .24315 L
s
[(8)] -0.0125 .24315 1 0 Mshowa
0 .35524 m
.00625 .35524 L
s
[(10)] -0.0125 .35524 1 0 Mshowa
0 .46733 m
.00625 .46733 L
s
[(12)] -0.0125 .46733 1 0 Mshowa
0 .57942 m
.00625 .57942 L
s
[(14)] -0.0125 .57942 1 0 Mshowa
.125 Mabswid
0 .047 m
.00375 .047 L
s
0 .07502 m
.00375 .07502 L
s
0 .10304 m
.00375 .10304 L
s
0 .15908 m
.00375 .15908 L
s
0 .18711 m
.00375 .18711 L
s
0 .21513 m
.00375 .21513 L
s
0 .27117 m
.00375 .27117 L
s
0 .2992 m
.00375 .2992 L
s
0 .32722 m
.00375 .32722 L
s
0 .38326 m
.00375 .38326 L
s
0 .41128 m
.00375 .41128 L
s
0 .43931 m
.00375 .43931 L
s
0 .49535 m
.00375 .49535 L
s
0 .52337 m
.00375 .52337 L
s
0 .55139 m
.00375 .55139 L
s
0 .60744 m
.00375 .60744 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.15608 .61178 m
.15608 .61803 L
s
.28836 .61178 m
.28836 .61803 L
s
.42063 .61178 m
.42063 .61803 L
s
.55291 .61178 m
.55291 .61803 L
s
.68519 .61178 m
.68519 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.94974 .61178 m
.94974 .61803 L
s
.125 Mabswid
.05026 .61428 m
.05026 .61803 L
s
.07672 .61428 m
.07672 .61803 L
s
.10317 .61428 m
.10317 .61803 L
s
.12963 .61428 m
.12963 .61803 L
s
.18254 .61428 m
.18254 .61803 L
s
.20899 .61428 m
.20899 .61803 L
s
.23545 .61428 m
.23545 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.31481 .61428 m
.31481 .61803 L
s
.34127 .61428 m
.34127 .61803 L
s
.36772 .61428 m
.36772 .61803 L
s
.39418 .61428 m
.39418 .61803 L
s
.44709 .61428 m
.44709 .61803 L
s
.47354 .61428 m
.47354 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.52646 .61428 m
.52646 .61803 L
s
.57937 .61428 m
.57937 .61803 L
s
.60582 .61428 m
.60582 .61803 L
s
.63228 .61428 m
.63228 .61803 L
s
.65873 .61428 m
.65873 .61803 L
s
.71164 .61428 m
.71164 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.76455 .61428 m
.76455 .61803 L
s
.79101 .61428 m
.79101 .61803 L
s
.84392 .61428 m
.84392 .61803 L
s
.87037 .61428 m
.87037 .61803 L
s
.89683 .61428 m
.89683 .61803 L
s
.92328 .61428 m
.92328 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01897 m
1 .01897 L
s
.99375 .13106 m
1 .13106 L
s
.99375 .24315 m
1 .24315 L
s
.99375 .35524 m
1 .35524 L
s
.99375 .46733 m
1 .46733 L
s
.99375 .57942 m
1 .57942 L
s
.125 Mabswid
.99625 .047 m
1 .047 L
s
.99625 .07502 m
1 .07502 L
s
.99625 .10304 m
1 .10304 L
s
.99625 .15908 m
1 .15908 L
s
.99625 .18711 m
1 .18711 L
s
.99625 .21513 m
1 .21513 L
s
.99625 .27117 m
1 .27117 L
s
.99625 .2992 m
1 .2992 L
s
.99625 .32722 m
1 .32722 L
s
.99625 .38326 m
1 .38326 L
s
.99625 .41128 m
1 .41128 L
s
.99625 .43931 m
1 .43931 L
s
.99625 .49535 m
1 .49535 L
s
.99625 .52337 m
1 .52337 L
s
.99625 .55139 m
1 .55139 L
s
.99625 .60744 m
1 .60744 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.05688 .01472 L
.08995 .01472 L
.12302 .01472 L
.15608 .01472 L
.18915 .01472 L
.22222 .01472 L
.25529 .01472 L
.28836 .01472 L
.31985 .1135 L
.35135 .26499 L
.38284 .60332 L
.4158 .55537 L
.44877 .51575 L
.48173 .48232 L
.51469 .45359 L
.54766 .42854 L
.58062 .40643 L
.61359 .38668 L
.64655 .3689 L
.67951 .35273 L
.71248 .33793 L
.74544 .3243 L
.77841 .31165 L
.81137 .29986 L
.84433 .28882 L
.8773 .27842 L
.91026 .26858 L
.94323 .25925 L
.97619 .25035 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo000GOol0
0`00Oomoo`0HOol00`00Oomoo`02Ool01000Oomoogoo0`000goo00<007ooOol04Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol04goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol05Woo1@005Goo1@000Woo00@007ooOomoo`<000=oo`03001oogoo015oo`D0009o
o`03001oogoo009oo`03001oogoo015oo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Moo`005Woo00<007oo000067oo00<007oo00001goo00<007ooOol00Woo00<007oo00004Woo
00<007oo00001goo00<007oo00004goo00<007oo000027oo00L007ooOomoo`00Ool0000IOol00`00
Oomoo`0GOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool0000DOol00`00Oomoo`06Ool00`00
Ool0000DOol00`00Oomoo`07Ool01`00Oomoogoo001oo`0000Qoo`005Woo00<007oo000067oo00<0
07oo000027oo00<007ooOol00goo00<007ooOol047oo00<007oo00002Goo00<007ooOol04Goo00<0
07oo000027oo00<007ooOol00goo00<007ooOol05goo00<007ooOol05goo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol04Woo00<007ooOol027oo00<007ooOol04Woo00<007ooOol01goo00<0
07ooOol00goo00<007ooOol01Woo000FOol00`00Ool0000HOol00`00Ool00008Ool01000Oomoogoo
0P004goo00<007oo00001goo0P0057oo00<007oo00002Goo00<007ooOol00P006Woo00<007ooOol0
5goo00<007ooOol01goo00@007ooOomoo`8001Eoo`03001oogoo00Ioo`8001Eoo`03001oogoo00Qo
o`03001oogoo008000Uoo`005Woo00<007oo000067oo00<007oo00001goo00<007oo00000Woo00<0
07ooOol04Woo00<007oo00001goo00<007ooOol04goo00<007oo00001goo00<007oo00000Woo00<0
07ooOol06Goo00<007ooOol05goo00<007ooOol01Woo00<007oo00000Woo00<007ooOol057oo00<0
07ooOol01Woo00<007ooOol057oo00<007ooOol01Woo00<007oo00000Woo00<007ooOol027oo000G
Ool00`00Oomoo`0HOol00`00Oomoo`07Ool01000Oomoogoo0`004goo00<007ooOol01Woo0`0057oo
00<007ooOol01Woo0`000Woo0`0067oo0P0067oo0P002Goo00@007ooOomoo`<001=oo`8000Qoo`<0
01=oo`8000Qoo`<0009oo`<000Qoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool00?mooaUoo`004Gooo`001@000goo000AOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`01Ool0015oo`03001oogoo0?moo`5oo`03001oogoo005oo`002goo0`000goo
00<007ooOol0ogoo0Goo00<007ooOol00Goo000<Ool00`00Oomoo`02Ool00`00Oomoo`03Oom6002g
Ool00`00Oomoo`01Ool000Yoo`@000=oo`<004Qoo`03001oogoo0;=oo`<000=oo`002Woo00<007oo
000017oo00<007ooOol0BGoo00<007ooOol0]7oo00<007ooOol00Goo000;Ool20004Ool00`00Oomo
o`19Ool00`00Oomoo`2dOol00`00Oomoo`01Ool000aoo`03001oogoo009oo`03001oogoo04Uoo`03
001oogoo0;Aoo`03001oogoo005oo`004Goo00<007ooOol0BWoo00<007ooOol0/goo00<007ooOol0
0Goo000AOol00`00Oomoo`1:Ool00`00Oomoo`2cOol00`00Oomoo`01Ool0015oo`03001oogoo04Yo
o`03001oogoo0;=oo`03001oogoo005oo`004Goo0P00C7oo00<007ooOol0/Goo0P000goo000AOol0
0`00Oomoo`1;Ool00`00Oomoo`2bOol00`00Oomoo`01Ool0015oo`03001oogoo04]oo`03001oogoo
0;9oo`03001oogoo005oo`004Goo00<007ooOol0C7oo00<007ooOol0/Goo00<007ooOol00Goo000A
Ool00`00Oomoo`1<Ool00`00Oomoo`2aOol00`00Oomoo`01Ool0015oo`03001oogoo04aoo`03001o
ogoo0;5oo`03001oogoo005oo`004Goo00<007ooOol0C7oo00<007ooOol0/Goo00<007ooOol00Goo
000AOol2001>Ool00`00Oomoo`2_Ool20003Ool0015oo`03001oogoo04eoo`03001oogoo0;1oo`03
001oogoo005oo`004Goo00<007ooOol0CGoo00<007ooOol0/7oo00<007ooOol00Goo000AOol00`00
Oomoo`1>Ool00`00Oomoo`2_Ool00`00Oomoo`01Ool0015oo`03001oogoo04ioo`03001oogoo0:mo
o`03001oogoo005oo`004Goo00<007ooOol0CWoo00<007ooOol0[goo00<007ooOol00Goo000AOol0
0`00Oomoo`1?Ool00`00Oomoo`2^Ool00`00Oomoo`01Ool0015oo`80051oo`03001oogoo0:eoo`80
00=oo`004Goo00<007ooOol0Cgoo00<007ooOol0[Woo00<007ooOol00Goo000AOol00`00Oomoo`1@
Ool00`00Oomoo`2]Ool00`00Oomoo`01Ool0015oo`03001oogoo051oo`03001oogoo0:eoo`03001o
ogoo005oo`004Goo00<007ooOol0D7oo00<007ooOol0[Goo00<007ooOol00Goo000AOol00`00Oomo
o`1@Ool00`00Oomoo`2]Ool00`00Oomoo`01Ool000Yoo`8000Eoo`03001oogoo055oo`03001oogoo
0:aoo`03001oogoo005oo`002Woo00<007oo000017oo00<007ooOol0DGoo00<007ooOol0[7oo00<0
07ooOol00Goo000:Ool00`00Ool00004Ool3001AOol00`00Oomoo`2ZOol30003Ool000Yoo`8000Eo
o`03001oogoo055oo`03001oogoo0:aoo`03001oogoo005oo`002Woo00<007ooOol017oo00<007oo
Ool0DGoo00<007ooOol0[7oo00<007ooOol00Goo000;Ool20004Ool00`00Oomoo`1BOol00`00Oomo
o`2[Ool00`00Oomoo`01Ool0015oo`03001oogoo059oo`03001oogoo0:]oo`03001oogoo005oo`00
4Goo00<007ooOol0DWoo00<007ooOol0Zgoo00<007ooOol00Goo000AOol00`00Oomoo`1BOol00`00
Oomoo`2[Ool00`00Oomoo`01Ool0015oo`8005=oo`03001oogoo0:Yoo`8000=oo`004Goo00<007oo
Ool0Dgoo00<007ooOol0ZWoo00<007ooOol00Goo000AOol00`00Oomoo`1COol00`00Oomoo`2ZOol0
0`00Oomoo`01Ool0015oo`03001oogoo05=oo`03001oogoo0:Yoo`03001oogoo005oo`004Goo00<0
07ooOol0Dgoo00<007ooOol0ZWoo00<007ooOol00Goo000AOol00`00Oomoo`1COol00`00Oomoo`2Z
Ool00`00Oomoo`01Ool0015oo`03001oogoo05Aoo`03001oogoo0:Uoo`03001oogoo005oo`004Goo
0P00EGoo00<007ooOol0Z7oo0P000goo000AOol00`00Oomoo`1DOol00`00Oomoo`2YOol00`00Oomo
o`01Ool0015oo`03001oogoo05Aoo`03001oogoo0:Uoo`03001oogoo005oo`004Goo00<007ooOol0
EGoo00<007ooOol0Z7oo00<007ooOol00Goo000AOol00`00Oomoo`1EOol00`00Oomoo`2XOol00`00
Oomoo`01Ool0015oo`03001oogoo05Eoo`03001oogoo0:Qoo`03001oogoo005oo`004Goo00<007oo
Ool0EGoo00<007ooOol0Z7oo00<007ooOol00Goo000AOol2001FOol00`00Oomoo`2WOol20003Ool0
015oo`03001oogoo05Ioo`03001oogoo0:Moo`03001oogoo005oo`004Goo00<007ooOol0EWoo00<0
07ooOol0Ygoo00<007ooOol00Goo000AOol00`00Oomoo`1FOol00`00Oomoo`2WOol00`00Oomoo`01
Ool0015oo`03001oogoo05Ioo`03001oogoo0:Moo`03001oogoo005oo`004Goo00<007ooOol0EWoo
00<007ooOol0Ygoo00<007ooOol00Goo000;Ool00`00Oomoo`03Ool00`00Oomoo`1GOol00`00Oomo
o`2VOol00`00Oomoo`01Ool000Yoo`03001oo`0000Aoo`03001oogoo05Moo`03001oogoo0:Ioo`03
001oogoo005oo`002Woo00<007oo000017oo0`00Egoo00<007ooOol0Y7oo0`000goo000;Ool00`00
Oomoo`03Ool00`00Oomoo`1GOol00`00Oomoo`2OOol20005Ool00`00Oomoo`01Ool000Yoo`03001o
o`0000Aoo`03001oogoo05Moo`03001oogoo09aoo`<000Moo`03001oogoo005oo`002goo00<007oo
Ool00goo00<007ooOol0F7oo00<007ooOol0V7oo0`002Woo00<007ooOol00Goo000AOol00`00Oomo
o`1HOol00`00Oomoo`2EOol3000=Ool00`00Oomoo`01Ool0015oo`03001oogoo05Qoo`03001oogoo
095oo`@0011oo`03001oogoo005oo`004Goo00<007ooOol0F7oo00<007ooOol0SGoo100057oo00<0
07ooOol00Goo000AOol2001IOol00`00Oomoo`2:Ool3000GOol20003Ool0015oo`03001oogoo05Qo
o`03001oogoo08Moo`<001]oo`03001oogoo005oo`004Goo00<007ooOol0F7oo00<007ooOol0Q7oo
0`007Woo00<007ooOol00Goo000AOol00`00Oomoo`1HOol00`00Oomoo`20Ool4000QOol00`00Oomo
o`01Ool0015oo`03001oogoo05Uoo`03001oogoo07]oo`@002Eoo`03001oogoo005oo`004Goo00<0
07ooOol0FGoo00<007ooOol0N7oo0`00:Goo00<007ooOol00Goo000AOol00`00Oomoo`1IOol00`00
Oomoo`1eOol3000/Ool00`00Oomoo`01Ool0015oo`8005Yoo`03001oogoo079oo`<002ioo`8000=o
o`004Goo00<007ooOol0FGoo00<007ooOol0L7oo0P00<Woo00<007ooOol00Goo000AOol00`00Oomo
o`1IOol00`00Oomoo`1]Ool3000dOol00`00Oomoo`01Ool0015oo`03001oogoo05Uoo`03001oogoo
06Yoo`<003Moo`03001oogoo005oo`004Goo00<007ooOol0FGoo00<007ooOol0J7oo0P00>Woo00<0
07ooOol00Goo000AOol00`00Oomoo`1IOol00`00Oomoo`1VOol2000lOol00`00Oomoo`01Ool0015o
o`03001oogoo05Uoo`03001oogoo06Aoo`8003ioo`03001oogoo005oo`004Goo0P00FWoo00<007oo
Ool0HGoo0`00?goo0P000goo000AOol00`00Oomoo`1JOol00`00Oomoo`1MOol30013Ool00`00Oomo
o`01Ool0015oo`03001oogoo05Yoo`03001oogoo05Yoo`<004Ioo`03001oogoo005oo`004Goo00<0
07ooOol0FWoo00<007ooOol0F7oo0P00BGoo00<007ooOol00Goo000AOol00`00Oomoo`1JOol00`00
Oomoo`1FOol2001;Ool00`00Oomoo`01Ool0015oo`03001oogoo05Yoo`03001oogoo05Aoo`8004eo
o`03001oogoo005oo`0017oo1@000Woo00<007ooOol00goo00<007ooOol0FWoo00<007ooOol0DWoo
0P00Cgoo00<007ooOol00Goo0006Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo05Yoo`03001o
ogoo04moo`<0055oo`03001oogoo005oo`001Woo00L007ooOomoo`00Ool00004Ool3001JOol00`00
Oomoo`1=Ool2001BOol30003Ool000Ioo`07001oogooOol007oo000017oo00<007ooOol0FWoo00<0
07ooOol0Bgoo0P00EWoo00<007ooOol00Goo0006Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo
05Yoo`03001oogoo04Uoo`8005Qoo`03001oogoo005oo`001Goo0P0017oo00<007ooOol00goo00<0
07ooOol0FWoo00<007ooOol0Agoo0P00FWoo00<007ooOol00Goo000AOol00`00Oomoo`1KOol00`00
Oomoo`14Ool2001LOol00`00Oomoo`01Ool0015oo`03001oogoo05]oo`03001oogoo04=oo`03001o
ogoo05aoo`03001oogoo005oo`004Goo00<007ooOol0Fgoo00<007ooOol0@Goo0P00Ggoo00<007oo
Ool00Goo000AOol2001LOol00`00Oomoo`0oOol2001POol20003Ool0015oo`03001oogoo05]oo`03
001oogoo03ioo`03001oogoo065oo`03001oogoo005oo`004Goo00<007ooOol0Fgoo00<007ooOol0
?7oo0P00I7oo00<007ooOol00Goo000AOol00`00Oomoo`1KOol00`00Oomoo`0jOol2001VOol00`00
Oomoo`01Ool0015oo`03001oogoo05]oo`03001oogoo03Qoo`8006Qoo`03001oogoo005oo`004Goo
00<007ooOol0Fgoo00<007ooOol0=Woo0P00JWoo00<007ooOol00Goo000AOol00`00Oomoo`1KOol0
0`00Oomoo`0eOol00`00Oomoo`1ZOol00`00Oomoo`01Ool0015oo`8005aoo`03001oogoo03Aoo`03
001oogoo06Yoo`8000=oo`004Goo00<007ooOol0G7oo00<007ooOol0<Goo0P00KWoo00<007ooOol0
0Goo000AOol00`00Oomoo`1LOol00`00Oomoo`0`Ool00`00Oomoo`1^Ool00`00Oomoo`01Ool0015o
o`03001oogoo05aoo`03001oogoo02moo`03001oogoo06moo`03001oogoo005oo`004Goo00<007oo
Ool0G7oo00<007ooOol0;Goo0P00LWoo00<007ooOol00Goo000AOol00`00Oomoo`1LOol00`00Oomo
o`0/Ool00`00Oomoo`1bOol00`00Oomoo`01Ool0015oo`03001oogoo05aoo`03001oogoo02Yoo`80
07Eoo`03001oogoo005oo`004Goo0P00GGoo00<007ooOol0:Goo00<007ooOol0M7oo0P000goo000A
Ool00`00Oomoo`1LOol00`00Oomoo`0WOol2001hOol00`00Oomoo`01Ool0015oo`03001oogoo05ao
o`03001oogoo02Ioo`03001oogoo07Qoo`03001oogoo005oo`004Goo00<007ooOol0G7oo00<007oo
Ool097oo0P00Ngoo00<007ooOol00Goo000AOol00`00Oomoo`1LOol00`00Oomoo`0SOol00`00Oomo
o`1kOol00`00Oomoo`01Ool0015oo`03001oogoo05eoo`03001oogoo025oo`03001oogoo07aoo`03
001oogoo005oo`0017oo1@0000Aoo`00000000Aoo`03001oogoo05eoo`03001oogoo021oo`03001o
ogoo07eoo`03001oogoo005oo`001Woo00D007ooOomoo`0000Ioo`03001oogoo05eoo`03001oogoo
01moo`03001oogoo07ioo`03001oogoo005oo`001Woo00<007ooOol00Woo00<007ooOol00goo0`00
GGoo00<007ooOol07Goo0P00Ogoo0`000goo0006Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00
Oomoo`1MOol00`00Oomoo`0LOol00`00Oomoo`21Ool00`00Oomoo`01Ool000Ioo`07001oogooOol0
07oo000017oo00<007ooOol0GGoo00<007ooOol06goo00<007ooOol0PWoo00<007ooOol00Goo0005
Ool20004Ool00`00Oomoo`03Ool00`00Oomoo`1MOol00`00Oomoo`0JOol00`00Oomoo`23Ool00`00
Oomoo`01Ool0015oo`03001oogoo05eoo`03001oogoo01Uoo`03001oogoo08Aoo`03001oogoo005o
o`004Goo00<007ooOol0GGoo00<007ooOol067oo00<007ooOol0QGoo00<007ooOol00Goo000AOol0
0`00Oomoo`1MOol00`00Oomoo`0GOol00`00Oomoo`26Ool00`00Oomoo`01Ool0015oo`8005ioo`03
001oogoo01Ioo`03001oogoo08Ioo`8000=oo`004Goo00<007ooOol0GWoo00<007ooOol057oo00<0
07ooOol0R7oo00<007ooOol00Goo000AOol00`00Oomoo`1NOol00`00Oomoo`0COol00`00Oomoo`29
Ool00`00Oomoo`01Ool0015oo`03001oogoo05ioo`03001oogoo019oo`03001oogoo08Yoo`03001o
ogoo005oo`004Goo00<007ooOol0GWoo00<007ooOol04Goo00<007ooOol0Rgoo00<007ooOol00Goo
000AOol00`00Oomoo`1NOol00`00Oomoo`0@Ool00`00Oomoo`2<Ool00`00Oomoo`01Ool0015oo`03
001oogoo05ioo`03001oogoo00moo`03001oogoo08eoo`03001oogoo005oo`004Goo0P00Ggoo00<0
07ooOol03Woo00<007ooOol0SGoo0P000goo000AOol00`00Oomoo`1NOol00`00Oomoo`0>Ool00`00
Oomoo`2>Ool00`00Oomoo`01Ool0015oo`03001oogoo05ioo`03001oogoo00eoo`03001oogoo08mo
o`03001oogoo005oo`004Goo00<007ooOol0GWoo00<007ooOol037oo00<007ooOol0T7oo00<007oo
Ool00Goo000AOol00`00Oomoo`1NOol00`00Oomoo`0;Ool00`00Oomoo`2AOol00`00Oomoo`01Ool0
015oo`03001oogoo05moo`03001oogoo00Uoo`03001oogoo099oo`03001oogoo005oo`004Goo00<0
07ooOol0Ggoo00<007ooOol02Goo00<007ooOol0TWoo00<007ooOol00Goo000AOol2001POol00`00
Oomoo`08Ool00`00Oomoo`2BOol20003Ool0015oo`03001oogoo05moo`03001oogoo00Moo`03001o
ogoo09Aoo`03001oogoo005oo`004Goo00<007ooOol0Ggoo00<007ooOol01Woo00<007ooOol0UGoo
00<007ooOol00Goo000AOol00`00Oomoo`1OOol00`00Oomoo`06Ool00`00Oomoo`2EOol00`00Oomo
o`01Ool0015oo`03001oogoo05moo`03001oogoo00Eoo`03001oogoo09Ioo`03001oogoo005oo`00
4Goo00<007ooOol0Ggoo00<007ooOol017oo00<007ooOol0Ugoo00<007ooOol00Goo0004Ool50002
Ool30003Ool00`00Oomoo`1OOol00`00Oomoo`04Ool00`00Oomoo`2GOol00`00Oomoo`01Ool000Io
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo05moo`03001oogoo00=oo`03001oogoo09Qo
o`03001oogoo005oo`001Woo00@007ooOomoo`@000=oo`<005moo`03001oogoo009oo`03001oogoo
09Moo`<000=oo`001Woo00L007ooOomoo`00Ool00004Ool00`00Oomoo`1POol01000Oomoo`00W7oo
00<007ooOol00Goo0006Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`1POol01000Oomoo`00W7oo
00<007ooOol00Goo0005Ool20005Ool00`00Oomoo`02Ool00`00Oomoo`1POol00`00Ool0002MOol0
0`00Oomoo`01Ool0015oo`03001oogoo061oo`8009ioo`03001oogoo005oo`004Goo00<007ooOol0
H7oo0P00WWoo00<007ooOol00Goo000AOol00`00Oomoo`1POol00`00Oomoo`2MOol00`00Oomoo`01
Ool0015oo`800?moo`5oo`8000=oo`004Goo00<007ooOol00goo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol02Woo00<007ooOol00Goo000AOooo00050003Ool00001\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.175124, 2.81713, 0.00731112, 
  0.0690227}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Four-Bar "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["postab = SolveMech[{0,1},21]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
graph = Graphics[{Thickness[.015],PointSize[.025],
(* Ground    *) {Point[{-2,3}], 
  Line[{{-1,-1.5},{0,0},{1,-1.5},{-2,-1.5},{-2,3}}]},
(* Drive Bar *) {RGBColor[1,0,0],
  Tangent[{0,0}, .5, Point[drivebar, 1], 0],
  Circle[Location[drivebar,0],.5] },
(* Driven Bar*) {RGBColor[0,0,1],Edge[drivenbar, {0, 1}] },
(* Center Bar*) {Vertex[centerbar, {0,1,2}],
                 RGBColor[0,1,0],Facet[centerbar, {0,1,2}]}},
  Frame->True,PlotRange->{{-2.4,2.4},{-1.6,4.2}}, 
  AspectRatio->Automatic]; \
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{graph/.LastSolve[], \n  \
Graphics[LocusPlot[Point[centerbar,2],postab]]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Slider-Ramp "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph = Graphics[{LocalAxes[slider,0.4],Thickness[.007],\n              \
PointSize[.04],\n(*Ramp   *)  {Edge[ramp, {1,2}],Edge[ramp, {4,5}],\n         \
     Circle[PointList[ramp,3],.5,\n                \
{Angle[ramp,3,2],Angle[ramp,3,4]}]},\n(*Slider *)  \
{Point[Location[Centroid[slider]]],RGBColor[1,0,0],\n              \
Circle[Location[slider,0],.25,\n                     \
Angle[slider]+{1,3}*N[Pi]/2],\n              Tangent[Point[slider, 1], .25,\n \
                     Point[slider, 2], .25],\n              \
Circle[Location[slider,2],.25,\n                     \
Angle[slider]+{-1,1}*N[Pi]/2]}},\n  \
Frame->True,PlotRange->{{-.25,4},{-.5,2}},\n  AspectRatio->Automatic];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[{graph/.LastSolve[]}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 700},
WindowMargins->{{34, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 85, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1841, 57, 78, 2, 47, "Subsection"],
Cell[1922, 61, 872, 17, 166, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2831, 83, 124, 3, 33, "Section",
  PageBreakAbove->True],
Cell[2958, 88, 496, 13, 92, "Text"],

Cell[CellGroupData[{
Cell[3479, 105, 92, 2, 47, "Subsection"],
Cell[3574, 109, 342, 11, 53, "Text"],

Cell[CellGroupData[{
Cell[3941, 124, 550, 20, 55, "Special3"],
Cell[4494, 146, 127, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[4636, 152, 598, 20, 74, "Text"],

Cell[CellGroupData[{
Cell[5259, 176, 80, 2, 23, "Special5"],
Cell[5342, 180, 1734, 58, 223, "Special3"],
Cell[7079, 240, 219, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[7335, 254, 80, 2, 23, "Special5"],
Cell[7418, 258, 3524, 139, 303, "Special3"],
Cell[10945, 399, 219, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[11179, 411, 527, 19, 73, "Text"],

Cell[CellGroupData[{
Cell[11731, 434, 649, 25, 55, "Special3"],
Cell[12383, 461, 139, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12571, 470, 88, 2, 31, "Subsection"],
Cell[12662, 474, 476, 13, 73, "Text"],

Cell[CellGroupData[{
Cell[13163, 491, 188, 8, 24, "SmallText"],
Cell[13354, 501, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13475, 508, 135, 3, 24, "SmallText"],
Cell[13613, 513, 135, 4, 65, "Input"]
}, Open  ]],
Cell[13763, 520, 445, 8, 128, "Text"],

Cell[CellGroupData[{
Cell[14233, 532, 154, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[14412, 540, 203, 5, 45, "Input"],
Cell[14618, 547, 50, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14717, 554, 140, 3, 24, "SmallText"],
Cell[14860, 559, 82, 2, 25, "Input"]
}, Open  ]],
Cell[14957, 564, 547, 15, 91, "Text"],

Cell[CellGroupData[{
Cell[15529, 583, 123, 2, 24, "SmallText"],
Cell[15655, 587, 109, 2, 25, "Input"]
}, Open  ]],
Cell[15779, 592, 268, 8, 53, "Text"],

Cell[CellGroupData[{
Cell[16072, 604, 972, 39, 117, "Special3"],
Cell[17047, 645, 130, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[17192, 651, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[17331, 657, 75, 2, 25, "Input"],
Cell[17409, 661, 36, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17482, 667, 293, 12, 24, "SmallText"],
Cell[17778, 681, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[17896, 689, 107, 2, 31, "Subsection"],
Cell[18006, 693, 1023, 19, 243, "Text"],

Cell[CellGroupData[{
Cell[19054, 716, 5541, 198, 398, "Special3"],
Cell[24598, 916, 152, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[24787, 924, 1639, 76, 88, "Special3"],
Cell[26429, 1002, 207, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[26673, 1016, 106, 2, 43, "Subsubsection"],
Cell[26782, 1020, 314, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[27121, 1030, 96, 2, 24, "SmallText"],
Cell[27220, 1034, 30118, 1016, 281, 8001, 738, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[57353, 2053, 225, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[57603, 2062, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[57759, 2069, 186, 5, 39, "Input"],
Cell[57948, 2076, 39, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58024, 2082, 177, 7, 24, "SmallText"],
Cell[58204, 2091, 74, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58315, 2098, 195, 5, 39, "Input"],
Cell[58513, 2105, 38, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58588, 2111, 191, 5, 39, "Input"],
Cell[58782, 2118, 48, 1, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58867, 2124, 283, 11, 24, "SmallText"],
Cell[59153, 2137, 82, 2, 25, "Input"]
}, Open  ]]
}, Open  ]],
Cell[59262, 2143, 269, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[59556, 2152, 119, 2, 24, "SmallText"],
Cell[59678, 2156, 76, 2, 37, "Input"],

Cell[CellGroupData[{
Cell[59779, 2162, 202, 5, 43, "Input"],
Cell[59984, 2169, 49, 1, 42, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[60082, 2176, 188, 8, 24, "SmallText"],
Cell[60273, 2186, 84, 2, 25, "Input"]
}, Open  ]],
Cell[60372, 2191, 1018, 26, 187, "Text"],

Cell[CellGroupData[{
Cell[61415, 2221, 136, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[61576, 2228, 144, 4, 45, "Input"],
Cell[61723, 2234, 68, 1, 42, "Output"]
}, Open  ]]
}, Open  ]],
Cell[61818, 2239, 420, 10, 72, "Text"],

Cell[CellGroupData[{
Cell[62263, 2253, 135, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[62423, 2260, 98, 2, 25, "Input"],
Cell[62524, 2264, 141, 3, 80, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[62714, 2273, 149, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[62888, 2281, 214, 4, 45, "Input"],
Cell[63105, 2287, 79, 1, 42, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[63245, 2295, 99, 2, 29, "Subsubsection"],
Cell[63347, 2299, 790, 19, 129, "Text"],

Cell[CellGroupData[{
Cell[64162, 2322, 96, 2, 24, "SmallText"],
Cell[64261, 2326, 46469, 1777, 264, 17521, 1415, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[110745, 4106, 271, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[111041, 4115, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[111193, 4121, 154, 3, 45, "Input"],
Cell[111350, 4126, 54, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111441, 4132, 95, 2, 42, "Input"],
Cell[111539, 4136, 318, 10, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111894, 4151, 198, 5, 95, "Input"],
Cell[112095, 4158, 120, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[112242, 4164, 487, 11, 91, "Text"],

Cell[CellGroupData[{
Cell[112754, 4179, 156, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[112935, 4187, 171, 3, 45, "Input"],
Cell[113109, 4192, 311, 5, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[113469, 4203, 191, 8, 24, "SmallText"],
Cell[113663, 4213, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[113781, 4221, 104, 2, 29, "Subsubsection"],
Cell[113888, 4225, 376, 12, 53, "Text"],

Cell[CellGroupData[{
Cell[114289, 4241, 2725, 91, 225, "Special3"],
Cell[117017, 4334, 152, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[117230, 4344, 91, 2, 31, "Subsection"],
Cell[117324, 4348, 448, 8, 151, "Input"],
Cell[117775, 4358, 503, 8, 169, "Input"],
Cell[118281, 4368, 77, 2, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[118407, 4376, 137, 3, 33, "Section",
  PageBreakAbove->True],
Cell[118547, 4381, 607, 12, 128, "Text"],

Cell[CellGroupData[{
Cell[119179, 4397, 97, 2, 47, "Subsection"],
Cell[119279, 4401, 570, 17, 91, "Text"],

Cell[CellGroupData[{
Cell[119874, 4422, 1269, 39, 193, "Special3"],
Cell[121146, 4463, 206, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[121367, 4475, 1296, 33, 209, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[122700, 4513, 100, 2, 31, "Subsection"],
Cell[122803, 4517, 671, 14, 148, "Text"],

Cell[CellGroupData[{
Cell[123499, 4535, 189, 8, 24, "SmallText"],
Cell[123691, 4545, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[123812, 4552, 119, 2, 24, "SmallText"],
Cell[123934, 4556, 26936, 658, 307, 4041, 370, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[150885, 5217, 712, 22, 91, "Text"],

Cell[CellGroupData[{
Cell[151622, 5243, 226, 5, 40, "SmallText"],
Cell[151851, 5250, 93, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151981, 5257, 91, 2, 43, "Subsubsection"],
Cell[152075, 5261, 447, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[152547, 5279, 378, 9, 145, "Input"],
Cell[152928, 5290, 68, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[153045, 5297, 89, 2, 29, "Subsubsection"],
Cell[153137, 5301, 350, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[153512, 5311, 143, 4, 24, "SmallText"],
Cell[153658, 5317, 106, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153801, 5325, 120, 2, 24, "SmallText"],
Cell[153924, 5329, 333, 8, 125, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[154306, 5343, 94, 2, 29, "Subsubsection"],
Cell[154403, 5347, 1550, 38, 285, "Text"],

Cell[CellGroupData[{
Cell[155978, 5389, 129, 3, 24, "SmallText"],
Cell[156110, 5394, 442, 8, 165, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[156601, 5408, 91, 2, 29, "Subsubsection"],
Cell[156695, 5412, 457, 17, 54, "Text"],

Cell[CellGroupData[{
Cell[157177, 5433, 189, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[157391, 5445, 74, 2, 25, "Input"],
Cell[157468, 5449, 496, 11, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[157991, 5464, 191, 8, 24, "SmallText"],
Cell[158185, 5474, 27471, 664, 307, 4034, 370, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[185705, 6144, 97, 2, 31, "Subsection"],
Cell[185805, 6148, 517, 14, 92, "Text"],

Cell[CellGroupData[{
Cell[186347, 6166, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[186560, 6178, 107, 2, 25, "Input"],
Cell[186670, 6182, 605, 9, 105, "Output"]
}, Open  ]]
}, Open  ]],
Cell[187302, 6195, 466, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[187793, 6213, 146, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[187964, 6221, 114, 2, 25, "Input"],
Cell[188081, 6225, 122, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[188230, 6231, 431, 7, 109, "Text"],

Cell[CellGroupData[{
Cell[188686, 6242, 157, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[188868, 6250, 95, 2, 25, "Input"],
Cell[188966, 6254, 103, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[189106, 6261, 95, 2, 25, "Input"],
Cell[189204, 6265, 122, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[189353, 6271, 256, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[189634, 6280, 208, 8, 24, "SmallText"],
Cell[189845, 6290, 106, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[189988, 6297, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[190140, 6303, 108, 2, 25, "Input"],
Cell[190251, 6307, 198, 3, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[190498, 6316, 106, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[190629, 6322, 105, 2, 25, "Input"],
Cell[190737, 6326, 136, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[190922, 6334, 191, 8, 24, "SmallText"],
Cell[191116, 6344, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[191234, 6352, 91, 2, 31, "Subsection"],
Cell[191328, 6356, 425, 8, 205, "Input"],
Cell[191756, 6366, 102, 2, 25, "Input"],
Cell[191861, 6370, 85, 2, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[191995, 6378, 126, 3, 33, "Section",
  PageBreakAbove->True],
Cell[192124, 6383, 259, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[192408, 6395, 97, 2, 47, "Subsection"],
Cell[192508, 6399, 1998, 46, 437, "Text"],

Cell[CellGroupData[{
Cell[194531, 6449, 90, 2, 43, "Subsubsection"],
Cell[194624, 6453, 533, 9, 128, "Text"],

Cell[CellGroupData[{
Cell[195182, 6466, 189, 8, 24, "SmallText"],
Cell[195374, 6476, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[195495, 6483, 570, 24, 40, "Special3"],
Cell[196068, 6509, 127, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[196210, 6515, 232, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[196467, 6524, 126, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[196618, 6530, 187, 4, 65, "Input"],
Cell[196808, 6536, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[196891, 6541, 1127, 29, 207, "Text"],

Cell[CellGroupData[{
Cell[198043, 6574, 760, 32, 55, "Special3"],
Cell[198806, 6608, 152, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[198973, 6614, 260, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[199258, 6623, 150, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[199433, 6631, 209, 5, 65, "Input"],
Cell[199645, 6638, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[199728, 6643, 215, 4, 52, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[199980, 6652, 91, 2, 29, "Subsubsection"],
Cell[200074, 6656, 423, 13, 72, "Text"],

Cell[CellGroupData[{
Cell[200522, 6673, 663, 25, 55, "Special3"],
Cell[201188, 6700, 139, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[201342, 6706, 1023, 21, 244, "Text"],

Cell[CellGroupData[{
Cell[202390, 6731, 300, 12, 24, "SmallText"],
Cell[202693, 6745, 223, 5, 85, "Input"]
}, Open  ]],
Cell[202931, 6753, 275, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[203231, 6766, 282, 8, 40, "SmallText"],

Cell[CellGroupData[{
Cell[203538, 6778, 287, 7, 65, "Input"],
Cell[203828, 6787, 82, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[203959, 6794, 191, 8, 24, "SmallText"],
Cell[204153, 6804, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[204283, 6813, 96, 2, 31, "Subsection"],
Cell[204382, 6817, 608, 12, 166, "Text"],

Cell[CellGroupData[{
Cell[205015, 6833, 189, 8, 24, "SmallText"],
Cell[205207, 6843, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[205328, 6850, 139, 3, 24, "SmallText"],
Cell[205470, 6855, 24853, 1019, 274, 7022, 794, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230360, 7879, 89, 2, 43, "Subsubsection"],
Cell[230452, 7883, 357, 12, 52, "Text"],

Cell[CellGroupData[{
Cell[230834, 7899, 143, 4, 24, "SmallText"],
Cell[230980, 7905, 239, 7, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231256, 7917, 129, 3, 24, "SmallText"],
Cell[231388, 7922, 470, 9, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231895, 7936, 140, 3, 24, "SmallText"],
Cell[232038, 7941, 127, 3, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[232214, 7950, 94, 2, 29, "Subsubsection"],
Cell[232311, 7954, 497, 14, 92, "Text"],

Cell[CellGroupData[{
Cell[232833, 7972, 129, 3, 24, "SmallText"],
Cell[232965, 7977, 413, 7, 185, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[233415, 7989, 136, 3, 24, "SmallText"],
Cell[233554, 7994, 108, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[233711, 8002, 96, 2, 29, "Subsubsection"],
Cell[233810, 8006, 275, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[234110, 8015, 102, 2, 24, "SmallText"],
Cell[234215, 8019, 203, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[234455, 8029, 127, 2, 24, "SmallText"],
Cell[234585, 8033, 74, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[234708, 8041, 91, 2, 29, "Subsubsection"],
Cell[234802, 8045, 705, 24, 93, "Text"],

Cell[CellGroupData[{
Cell[235532, 8073, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[235745, 8085, 73, 2, 25, "Input"],
Cell[235821, 8089, 584, 12, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[236454, 8107, 196, 8, 24, "SmallText"],
Cell[236653, 8117, 25176, 1023, 274, 7025, 794, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[261844, 9143, 863, 29, 112, "Text"],

Cell[CellGroupData[{
Cell[262732, 9176, 148, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[262905, 9184, 101, 2, 25, "Input"],
Cell[263009, 9188, 1486, 27, 162, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[264544, 9221, 175, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[264744, 9229, 95, 2, 25, "Input"],
Cell[264842, 9233, 64, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[264955, 9240, 130, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[265110, 9247, 95, 2, 25, "Input"],
Cell[265208, 9251, 93, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[265362, 9259, 89, 2, 29, "Subsubsection"],
Cell[265454, 9263, 512, 17, 73, "Text"],

Cell[CellGroupData[{
Cell[265991, 9284, 164, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[266180, 9292, 225, 5, 65, "Input"],
Cell[266408, 9299, 195, 5, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[266652, 9310, 133, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[266810, 9317, 150, 4, 25, "Input"],
Cell[266963, 9323, 43, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[267055, 9330, 137, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[267217, 9337, 113, 2, 25, "Input"],
Cell[267333, 9341, 18337, 536, 181, 5433, 371, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[285697, 9881, 451, 16, 53, "Text"],

Cell[CellGroupData[{
Cell[286173, 9901, 123, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[286321, 9907, 148, 4, 25, "Input"],
Cell[286472, 9913, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[286577, 9920, 147, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[286749, 9928, 126, 3, 45, "Input"],
Cell[286878, 9933, 15800, 526, 181, 5565, 394, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[302739, 10466, 97, 2, 29, "Subsubsection"],
Cell[302839, 10470, 463, 8, 109, "Text"],

Cell[CellGroupData[{
Cell[303327, 10482, 121, 2, 24, "SmallText"],
Cell[303451, 10486, 239, 7, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[303727, 10498, 118, 2, 24, "SmallText"],
Cell[303848, 10502, 81, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[303978, 10510, 95, 2, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[304098, 10516, 129, 3, 24, "SmallText"],
Cell[304230, 10521, 167, 4, 45, "Input"]
}, Open  ]],
Cell[304412, 10528, 238, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[304675, 10537, 229, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[304929, 10549, 113, 2, 25, "Input"],
Cell[305045, 10553, 18872, 558, 181, 5668, 389, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[323966, 11117, 191, 8, 24, "SmallText"],
Cell[324160, 11127, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[324290, 11136, 97, 2, 31, "Subsection"],
Cell[324390, 11140, 1032, 22, 224, "Text"],

Cell[CellGroupData[{
Cell[325447, 11166, 189, 8, 24, "SmallText"],
Cell[325639, 11176, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325760, 11183, 125, 2, 24, "SmallText"],
Cell[325888, 11187, 24578, 1604, 244, 9079, 1408, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350503, 12796, 89, 2, 43, "Subsubsection"],
Cell[350595, 12800, 130, 3, 33, "Text"],
Cell[350728, 12805, 382, 7, 93, "Special1"],
Cell[351113, 12814, 256, 5, 59, "Special1"],
Cell[351372, 12821, 581, 16, 129, "Text"],

Cell[CellGroupData[{
Cell[351978, 12841, 135, 3, 24, "SmallText"],
Cell[352116, 12846, 102, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[352255, 12854, 125, 2, 24, "SmallText"],
Cell[352383, 12858, 93, 3, 45, "Input"],
Cell[352479, 12863, 371, 6, 169, "Input"],
Cell[352853, 12871, 232, 4, 115, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[353122, 12880, 131, 3, 24, "SmallText"],
Cell[353256, 12885, 90, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[353395, 12893, 94, 2, 29, "Subsubsection"],
Cell[353492, 12897, 182, 4, 52, "Text"],
Cell[353677, 12903, 418, 14, 44, "Special1"],
Cell[354098, 12919, 235, 8, 26, "Special1"],
Cell[354336, 12929, 340, 12, 44, "Special1"],
Cell[354679, 12943, 636, 19, 113, "Special2"],
Cell[355318, 12964, 488, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[355831, 12982, 138, 3, 24, "SmallText"],
Cell[355972, 12987, 531, 12, 245, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[356540, 13004, 133, 3, 24, "SmallText"],
Cell[356676, 13009, 94, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[356819, 13017, 91, 2, 29, "Subsubsection"],
Cell[356913, 13021, 580, 21, 73, "Text"],

Cell[CellGroupData[{
Cell[357518, 13046, 156, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[357699, 13057, 73, 2, 25, "Input"],
Cell[357775, 13061, 65, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[357889, 13068, 124, 2, 24, "SmallText"],
Cell[358016, 13072, 125, 3, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358178, 13080, 191, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[358394, 13092, 74, 2, 25, "Input"],
Cell[358471, 13096, 420, 11, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[358940, 13113, 201, 8, 24, "SmallText"],
Cell[359144, 13123, 18918, 882, 213, 6614, 725, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[378111, 14011, 94, 2, 29, "Subsubsection"],
Cell[378208, 14015, 884, 27, 131, "Text"],

Cell[CellGroupData[{
Cell[379117, 14046, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[379256, 14052, 128, 3, 45, "Input"],
Cell[379387, 14057, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[379503, 14065, 88, 2, 29, "Subsubsection"],
Cell[379594, 14069, 561, 13, 129, "Text"],

Cell[CellGroupData[{
Cell[380180, 14086, 109, 2, 24, "SmallText"],
Cell[380292, 14090, 103, 2, 25, "Input"]
}, Open  ]],
Cell[380410, 14095, 196, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[380631, 14107, 174, 3, 25, "Input"],
Cell[380808, 14112, 447, 9, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[381292, 14126, 115, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[381432, 14132, 235, 5, 45, "Input"],
Cell[381670, 14139, 18081, 652, 181, 6034, 497, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[399778, 14795, 567, 12, 109, "Text"],

Cell[CellGroupData[{
Cell[400370, 14811, 239, 8, 24, "SmallText"],
Cell[400612, 14821, 234, 6, 65, "Input"]
}, Open  ]],
Cell[400861, 14830, 1319, 22, 338, "Text"],

Cell[CellGroupData[{
Cell[402205, 14856, 115, 2, 24, "SmallText"],
Cell[402323, 14860, 551, 13, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[402911, 14878, 144, 4, 24, "SmallText"],
Cell[403058, 14884, 88, 2, 25, "Input"]
}, Open  ]],
Cell[403161, 14889, 390, 10, 72, "Text"],
Cell[403554, 14901, 173, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[403752, 14909, 198, 4, 65, "Input"],
Cell[403953, 14915, 272, 5, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[404262, 14925, 116, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[404403, 14931, 235, 5, 45, "Input"],
Cell[404641, 14938, 18909, 653, 181, 6010, 488, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[423611, 15598, 189, 8, 22, "SmallText"],
Cell[423803, 15608, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[423921, 15616, 91, 2, 31, "Subsection"],
Cell[424015, 15620, 92, 2, 43, "Subsubsection"],
Cell[424110, 15624, 105, 2, 25, "Input"],
Cell[424218, 15628, 572, 14, 241, "Input"],
Cell[424793, 15644, 157, 4, 43, "Input"],
Cell[424953, 15650, 95, 2, 43, "Subsubsection"],
Cell[425051, 15654, 768, 14, 277, "Input"],
Cell[425822, 15670, 102, 2, 25, "Input"],
Cell[425927, 15674, 85, 2, 25, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

