(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    214763,       8288]*)
(*NotebookOutlinePosition[    215705,       8320]*)
(*  CellTagsIndexPosition[    215661,       8316]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["9.  Parametric Design", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Overview"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers the use of ",
  StyleBox["Mechanical Systems'",
    FontSlant->"Italic"],
  "s parametric design synthesis functions, ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These functions allow the user to specify one or more geometric \
conditions that are to be satisfied, along with the names of parameters that \
are to be varied in an attempt to satisfy them. Coupled systems can be used \
to satisfy several geometric conditions that are specified at different \
configurations of the model, or conditions that are dependent on velocity, \
acceleration, or constraint reactions.\n\nThe ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions find the linearized sensitivity of all of the dependent \
variables in a model to variations in specified parameters. These functions \
are used to perform a linearized tolerance analysis on a multibody system. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["9.1  Coupled Models", "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "The simplest invocation of the ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions is to allow a model parameter or parameters to be varied in an \
attempt to satisfy some geometric condition at one point in time. In this \
section a planar model of a four-bar mechanism is developed, and the lengths \
of the links in the four-bar mechanism are adjusted to achieve various \
desired geometric design goals."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The following subsection develops a planar model of a classic four-bar \
mechanism. The driving input to the model is to specify the rotation of bar \
2, the drive bar. Because the drive bar is the shortest link in the model, \
the driven bar and center bar simply oscillate as the drive bar progresses \
through each full turn. Driven in this manner the model has no singular \
configurations."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(Off[General::"\<spell1\>"]\), 
    \(Off[General::"\<spell\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the four-bar model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.52632 
MathPictureStart
%% Graphics
/Times findfont 10  scalefont  setfont
% Scaling calculations
0.631579 0.263158 0.421053 0.263158 [
[(-2)] .10526 0 0 2 Msboxa
[(-1.5)] .23684 0 0 2 Msboxa
[(-1)] .36842 0 0 2 Msboxa
[(-0.5)] .5 0 0 2 Msboxa
[(0)] .63158 0 0 2 Msboxa
[(0.5)] .76316 0 0 2 Msboxa
[(1)] .89474 0 0 2 Msboxa
[(-1)] -0.0125 .15789 1 0 Msboxa
[(0)] -0.0125 .42105 1 0 Msboxa
[(1)] -0.0125 .68421 1 0 Msboxa
[(2)] -0.0125 .94737 1 0 Msboxa
[(3)] -0.0125 1.21053 1 0 Msboxa
[(4)] -0.0125 1.47368 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.52732 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.10526 0 m
.10526 .00625 L
s
P
[(-2)] .10526 0 0 2 Mshowa
p
.002 w
.23684 0 m
.23684 .00625 L
s
P
[(-1.5)] .23684 0 0 2 Mshowa
p
.002 w
.36842 0 m
.36842 .00625 L
s
P
[(-1)] .36842 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(-0.5)] .5 0 0 2 Mshowa
p
.002 w
.63158 0 m
.63158 .00625 L
s
P
[(0)] .63158 0 0 2 Mshowa
p
.002 w
.76316 0 m
.76316 .00625 L
s
P
[(0.5)] .76316 0 0 2 Mshowa
p
.002 w
.89474 0 m
.89474 .00625 L
s
P
[(1)] .89474 0 0 2 Mshowa
p
.001 w
.13158 0 m
.13158 .00375 L
s
P
p
.001 w
.15789 0 m
.15789 .00375 L
s
P
p
.001 w
.18421 0 m
.18421 .00375 L
s
P
p
.001 w
.21053 0 m
.21053 .00375 L
s
P
p
.001 w
.26316 0 m
.26316 .00375 L
s
P
p
.001 w
.28947 0 m
.28947 .00375 L
s
P
p
.001 w
.31579 0 m
.31579 .00375 L
s
P
p
.001 w
.34211 0 m
.34211 .00375 L
s
P
p
.001 w
.39474 0 m
.39474 .00375 L
s
P
p
.001 w
.42105 0 m
.42105 .00375 L
s
P
p
.001 w
.44737 0 m
.44737 .00375 L
s
P
p
.001 w
.47368 0 m
.47368 .00375 L
s
P
p
.001 w
.52632 0 m
.52632 .00375 L
s
P
p
.001 w
.55263 0 m
.55263 .00375 L
s
P
p
.001 w
.57895 0 m
.57895 .00375 L
s
P
p
.001 w
.60526 0 m
.60526 .00375 L
s
P
p
.001 w
.65789 0 m
.65789 .00375 L
s
P
p
.001 w
.68421 0 m
.68421 .00375 L
s
P
p
.001 w
.71053 0 m
.71053 .00375 L
s
P
p
.001 w
.73684 0 m
.73684 .00375 L
s
P
p
.001 w
.78947 0 m
.78947 .00375 L
s
P
p
.001 w
.81579 0 m
.81579 .00375 L
s
P
p
.001 w
.84211 0 m
.84211 .00375 L
s
P
p
.001 w
.86842 0 m
.86842 .00375 L
s
P
p
.001 w
.07895 0 m
.07895 .00375 L
s
P
p
.001 w
.05263 0 m
.05263 .00375 L
s
P
p
.001 w
.02632 0 m
.02632 .00375 L
s
P
p
.001 w
.92105 0 m
.92105 .00375 L
s
P
p
.001 w
.94737 0 m
.94737 .00375 L
s
P
p
.001 w
.97368 0 m
.97368 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .15789 m
.00625 .15789 L
s
P
[(-1)] -0.0125 .15789 1 0 Mshowa
p
.002 w
0 .42105 m
.00625 .42105 L
s
P
[(0)] -0.0125 .42105 1 0 Mshowa
p
.002 w
0 .68421 m
.00625 .68421 L
s
P
[(1)] -0.0125 .68421 1 0 Mshowa
p
.002 w
0 .94737 m
.00625 .94737 L
s
P
[(2)] -0.0125 .94737 1 0 Mshowa
p
.002 w
0 1.21053 m
.00625 1.21053 L
s
P
[(3)] -0.0125 1.21053 1 0 Mshowa
p
.002 w
0 1.47368 m
.00625 1.47368 L
s
P
[(4)] -0.0125 1.47368 1 0 Mshowa
p
.001 w
0 .21053 m
.00375 .21053 L
s
P
p
.001 w
0 .26316 m
.00375 .26316 L
s
P
p
.001 w
0 .31579 m
.00375 .31579 L
s
P
p
.001 w
0 .36842 m
.00375 .36842 L
s
P
p
.001 w
0 .47368 m
.00375 .47368 L
s
P
p
.001 w
0 .52632 m
.00375 .52632 L
s
P
p
.001 w
0 .57895 m
.00375 .57895 L
s
P
p
.001 w
0 .63158 m
.00375 .63158 L
s
P
p
.001 w
0 .73684 m
.00375 .73684 L
s
P
p
.001 w
0 .78947 m
.00375 .78947 L
s
P
p
.001 w
0 .84211 m
.00375 .84211 L
s
P
p
.001 w
0 .89474 m
.00375 .89474 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.05263 m
.00375 1.05263 L
s
P
p
.001 w
0 1.10526 m
.00375 1.10526 L
s
P
p
.001 w
0 1.15789 m
.00375 1.15789 L
s
P
p
.001 w
0 1.26316 m
.00375 1.26316 L
s
P
p
.001 w
0 1.31579 m
.00375 1.31579 L
s
P
p
.001 w
0 1.36842 m
.00375 1.36842 L
s
P
p
.001 w
0 1.42105 m
.00375 1.42105 L
s
P
p
.001 w
0 .10526 m
.00375 .10526 L
s
P
p
.001 w
0 .05263 m
.00375 .05263 L
s
P
p
.001 w
0 0 m
.00375 0 L
s
P
p
.002 w
0 0 m
0 1.52632 L
s
P
P
p
p
.002 w
.10526 1.52007 m
.10526 1.52632 L
s
P
p
.002 w
.23684 1.52007 m
.23684 1.52632 L
s
P
p
.002 w
.36842 1.52007 m
.36842 1.52632 L
s
P
p
.002 w
.5 1.52007 m
.5 1.52632 L
s
P
p
.002 w
.63158 1.52007 m
.63158 1.52632 L
s
P
p
.002 w
.76316 1.52007 m
.76316 1.52632 L
s
P
p
.002 w
.89474 1.52007 m
.89474 1.52632 L
s
P
p
.001 w
.13158 1.52257 m
.13158 1.52632 L
s
P
p
.001 w
.15789 1.52257 m
.15789 1.52632 L
s
P
p
.001 w
.18421 1.52257 m
.18421 1.52632 L
s
P
p
.001 w
.21053 1.52257 m
.21053 1.52632 L
s
P
p
.001 w
.26316 1.52257 m
.26316 1.52632 L
s
P
p
.001 w
.28947 1.52257 m
.28947 1.52632 L
s
P
p
.001 w
.31579 1.52257 m
.31579 1.52632 L
s
P
p
.001 w
.34211 1.52257 m
.34211 1.52632 L
s
P
p
.001 w
.39474 1.52257 m
.39474 1.52632 L
s
P
p
.001 w
.42105 1.52257 m
.42105 1.52632 L
s
P
p
.001 w
.44737 1.52257 m
.44737 1.52632 L
s
P
p
.001 w
.47368 1.52257 m
.47368 1.52632 L
s
P
p
.001 w
.52632 1.52257 m
.52632 1.52632 L
s
P
p
.001 w
.55263 1.52257 m
.55263 1.52632 L
s
P
p
.001 w
.57895 1.52257 m
.57895 1.52632 L
s
P
p
.001 w
.60526 1.52257 m
.60526 1.52632 L
s
P
p
.001 w
.65789 1.52257 m
.65789 1.52632 L
s
P
p
.001 w
.68421 1.52257 m
.68421 1.52632 L
s
P
p
.001 w
.71053 1.52257 m
.71053 1.52632 L
s
P
p
.001 w
.73684 1.52257 m
.73684 1.52632 L
s
P
p
.001 w
.78947 1.52257 m
.78947 1.52632 L
s
P
p
.001 w
.81579 1.52257 m
.81579 1.52632 L
s
P
p
.001 w
.84211 1.52257 m
.84211 1.52632 L
s
P
p
.001 w
.86842 1.52257 m
.86842 1.52632 L
s
P
p
.001 w
.07895 1.52257 m
.07895 1.52632 L
s
P
p
.001 w
.05263 1.52257 m
.05263 1.52632 L
s
P
p
.001 w
.02632 1.52257 m
.02632 1.52632 L
s
P
p
.001 w
.92105 1.52257 m
.92105 1.52632 L
s
P
p
.001 w
.94737 1.52257 m
.94737 1.52632 L
s
P
p
.001 w
.97368 1.52257 m
.97368 1.52632 L
s
P
p
.002 w
0 1.52632 m
1 1.52632 L
s
P
p
.002 w
.99375 .15789 m
1 .15789 L
s
P
p
.002 w
.99375 .42105 m
1 .42105 L
s
P
p
.002 w
.99375 .68421 m
1 .68421 L
s
P
p
.002 w
.99375 .94737 m
1 .94737 L
s
P
p
.002 w
.99375 1.21053 m
1 1.21053 L
s
P
p
.002 w
.99375 1.47368 m
1 1.47368 L
s
P
p
.001 w
.99625 .21053 m
1 .21053 L
s
P
p
.001 w
.99625 .26316 m
1 .26316 L
s
P
p
.001 w
.99625 .31579 m
1 .31579 L
s
P
p
.001 w
.99625 .36842 m
1 .36842 L
s
P
p
.001 w
.99625 .47368 m
1 .47368 L
s
P
p
.001 w
.99625 .52632 m
1 .52632 L
s
P
p
.001 w
.99625 .57895 m
1 .57895 L
s
P
p
.001 w
.99625 .63158 m
1 .63158 L
s
P
p
.001 w
.99625 .73684 m
1 .73684 L
s
P
p
.001 w
.99625 .78947 m
1 .78947 L
s
P
p
.001 w
.99625 .84211 m
1 .84211 L
s
P
p
.001 w
.99625 .89474 m
1 .89474 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.05263 m
1 1.05263 L
s
P
p
.001 w
.99625 1.10526 m
1 1.10526 L
s
P
p
.001 w
.99625 1.15789 m
1 1.15789 L
s
P
p
.001 w
.99625 1.26316 m
1 1.26316 L
s
P
p
.001 w
.99625 1.31579 m
1 1.31579 L
s
P
p
.001 w
.99625 1.36842 m
1 1.36842 L
s
P
p
.001 w
.99625 1.42105 m
1 1.42105 L
s
P
p
.001 w
.99625 .10526 m
1 .10526 L
s
P
p
.001 w
.99625 .05263 m
1 .05263 L
s
P
p
.001 w
.99625 0 m
1 0 L
s
P
p
.002 w
1 0 m
1 1.52632 L
s
P
P
p
P
0 0 m
1 0 L
1 1.52632 L
0 1.52632 L
closepath
clip
newpath
p
p
.02 w
.36842 .02632 m
.63158 .42105 L
.89474 .02632 L
.10526 .02632 L
.10526 1.21053 L
s
P
p
1 0 0 r
p
.02 w
.63158 .42105 m
.88186 .50237 L
s
P
.02 w
newpath
.63158 .42105 .13158 0 365.73 arc
s
P
p
0 0 1 r
p
.02 w
.10526 1.21053 m
.89054 1.2918 L
s
P
P
p
p
.035 w
.88186 .50237 Mdot
.89054 1.2918 Mdot
.88765 1.02866 Mdot
P
0 1 0 r
p
.02 w
.88186 .50237 m
.89054 1.2918 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{188, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002l00017a000`40O003h00O_7oo002lOol00;ao
o`0077oo100047oo0`000Woo10004Woo0`004Goo0P000goo100047oo0P004Goo0P000goo10004Woo
0`004goo000MOol00`00Ool0000AOol00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool0
1000Oomoo`001Woo00<007ooOol037oo00@007ooOol000moo`04001oogoo0006Ool00`00Oomoo`0@
Ool00`00Oomoo`0BOol001Uoo`8000=oo`03001oogoo00]oo`8000=oo`03001oogoo00Eoo`03001o
ogoo00]oo`8000=oo`03001oogoo00aoo`800005Ool007ooOol00006Ool00`00Oomoo`0<Ool01000
Oomoo`003goo00@007ooOol000Ioo`03001oogoo011oo`03001oogoo019oo`007goo00<007ooOol0
3goo00<007ooOol01Goo00<007ooOol047oo00<007ooOol03goo00@007ooOol000Ioo`03001oogoo
00aoo`04001oogoo000?Ool01000Oomoo`001Woo00<007ooOol047oo00<007ooOol04Woo000OOol0
0`00Oomoo`0?Ool00`00Oomoo`03Ool2000COol00`00Oomoo`0?Ool01000Oomoo`0017oo0P003goo
00@007ooOol000moo`04001oogoo0004Ool2000COol00`00Oomoo`0BOol001aoo`04001oogoo000A
Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool01000Oomoo`0017oo00<007ooOol0
3Woo00@007ooOol000moo`04001oogoo0004Ool00`00Oomoo`0BOol00`00Oomoo`0BOol001eoo`80
015oo`8000Ioo`80015oo`80019oo`8000Ioo`8000moo`80015oo`8000Ioo`80015oo`8001Aoo`00
_7oo002lOol00;aoo`00_7oo002lOol00;aoo`00_7oo002lOol000Yook40005oo`002Woo00<007oo
Ool00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05
001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool10001Ool000Yoo`03001oogoo011o
o`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Ao
o`03001oogoo01Aoo`03001oogoo011oo`40005oo`002Woo00<007ooOol0[Goo0@000Goo000:Ool0
0`00Oomoo`0?Oon=000AOol10001Ool000Yoo`03001oogoo00moohd0015oo`40005oo`002Woo00<0
07ooOol03gooS@004Goo0@000Goo000:Ool00`00Oomoo`0?Ool3000/Ool4001EOol4000BOol10001
Ool000Yoo`03001oogoo00moo`<002eoo`<005Eoo`<001=oo`40005oo`002Woo00<007ooOol03goo
0`00;Goo1000Dgoo10004goo0@000Goo000:Ool2000@Ool3000^Ool4001AOol4000COol20001Ool0
00Yoo`03001oogoo00moo`<002moo`<0055oo`<001Eoo`40005oo`002Woo00<007ooOol03goo0`00
;goo1000Cgoo10005Goo0@000Goo000:Ool00`00Oomoo`0?Ool3000`Ool4001=Ool4000FOol10001
Ool000Yoo`03001oogoo00moo`<0035oo`<004eoo`<001Moo`40005oo`002Woo00<007ooOol03goo
0`00<Goo1000Bgoo10005goo0@000Goo000:Ool00`00Oomoo`0?Ool3000bOol40019Ool4000HOol1
0001Ool000Yoo`03001oogoo00moo`<003=oo`<004Uoo`<001Uoo`40005oo`002Woo00<007ooOol0
3goo0`00<goo1000Agoo10006Goo0@000Goo000:Ool2000@Ool3000dOol40015Ool4000IOol20001
Ool000Yoo`03001oogoo00moo`<003Eoo`<004Eoo`<001]oo`40005oo`002Woo00<007ooOol03goo
0`00=Goo1000@goo10006goo0@000Goo000:Ool00`00Oomoo`0?Ool3000fOol40011Ool4000LOol1
0001Ool000Yoo`03001oogoo00moo`<003Moo`<0045oo`<001eoo`40005oo`002Woo00<007ooOol0
3goo0`00=goo1000?goo10007Goo0@000Goo0004Ool30003Ool00`00Oomoo`0?Ool3000hOol4000m
Ool4000NOol10001Ool000Eoo`03001oogoo009oo`03001oogoo00moo`<003Uoo`<003eoo`<001mo
o`40005oo`000P000goo00<007ooOol00Woo00<007ooOol03goo0`00>Goo1000>goo10007goo0@00
0Goo0005Ool00`00Oomoo`02Ool2000@Ool3000jOol4000iOol4000OOol20001Ool000Eoo`03001o
ogoo009oo`03001oogoo00moo`<003]oo`<003Uoo`<0025oo`40005oo`001Goo00<007ooOol00Woo
00<007ooOol03goo0`00>goo1000=goo10008Goo0@000Goo0004Ool20004Ool00`00Oomoo`0?Ool3
000lOol4000eOol4000ROol10001Ool000Yoo`03001oogoo00moo`<003eoo`<003Eoo`<002=oo`40
005oo`002Woo00<007ooOol03goo0`00?Goo1000<goo10008goo0@000Goo000:Ool00`00Oomoo`0?
Ool3000nOol4000aOol4000TOol10001Ool000Yoo`03001oogoo00moo`<003moo`<0035oo`<002Eo
o`40005oo`002Woo00<007ooOol03goo0`00?goo1000;goo10009Goo0@000Goo000:Ool2000@Ool3
0010Ool4000]Ool4000UOol20001Ool000Yoo`03001oogoo00moo`<0045oo`<002eoo`<002Moo`40
005oo`002Woo00<007ooOol03goo0`00@Goo1000:goo10009goo0@000Goo000:Ool00`00Oomoo`0?
Ool30012Ool4000YOol4000XOol10001Ool000Yoo`03001oogoo00moo`<004=oo`<002Uoo`<002Uo
o`40005oo`002Woo00<007ooOol03goo0`00@goo10009goo1000:Goo0@000Goo000:Ool00`00Oomo
o`0?Ool30014Ool4000UOol4000ZOol10001Ool000Yoo`03001oogoo00moo`<004Eoo`<002Eoo`<0
02]oo`40005oo`002Woo00<007ooOol03goo0`00AGoo10008goo1000:goo0@000Goo000:Ool00`00
Oomoo`0?Ool30016Ool4000QOol4000/Ool10001Ool000Yoo`80011oo`<004Moo`<0025oo`<002ao
o`80005oo`002Woo00<007ooOol03goo0`00Agoo10007goo1000;Goo0@000Goo000:Ool00`00Oomo
o`0?Ool30018Ool4000MOol4000^Ool10001Ool000Yoo`03001oogoo00moo`<004Uoo`<000Yoo`Ql
00]oo`<002moo`40005oo`002Woo00<007ooOol03goo0`00BGoo10001Goo47`01Woo1000;goo0@00
0Goo000:Ool00`00Oomoo`0?Ool3001:Ool400000gooO01l000DO002Ool4000`Ool10001Ool000Yo
o`03001oogoo00moo`<004]oo`<000Ul00Ioo`Yl00<0035oo`40005oo`002Woo00<007ooOol03goo
0`00Bgoo0P001W`03Woo27`000<007ooOol0;goo0@000Goo000:Ool00`00Oomoo`0?Ool3001;Ool6
O00COol5O00bOol10001Ool000Yoo`80011oo`<004Yoo`El0003001oogoo01=oo`03001l07`0009l
031oo`80005oo`002Woo00<007ooOol03goo0`00BGoo1W`00P004goo0`0017`0<7oo0@000Goo000:
Ool00`00Oomoo`0?Ool30018Ool5O0000goo00000002000AOol400000gooO01l0002O00_Ool10001
Ool000Yoo`03001oogoo00moo`<004Moo`Al00Aoo`<0015oo`<000=oo`Al02ioo`40005oo`002Woo
00<007ooOol03goo0`00AWoo17`01Goo10003goo100017oo1G`0;7oo0@000Goo000:Ool00`00Oomo
o`0?Ool30015Ool4O007Ool4000=Ool40006Ool4O00/Ool10001Ool000Yoo`03001oogoo00moo`<0
04Aoo`Al00Uoo`<000eoo`<000Qoo`Al02]oo`40005oo`002Woo00<007ooOol03goo0`00A7oo17`0
2Goo10002goo10002Goo0g`0:goo0@000Goo000:Ool00`00Oomoo`0?Ool30014Ool3O00;Ool40009
Ool4000:Ool4O00ZOol10001Ool000Yoo`80011oo`<004=oo`Al00aoo`<000Uoo`<000aoo`=l02Uo
o`80005oo`002Woo00<007ooOol03goo0`00@goo0g`03Goo10001goo100037oo0g`0:Woo0@000Goo
000:Ool00`00Oomoo`0?Ool30013Ool3O00>Ool40005Ool4000=Ool4O00YOol10001Ool000Yoo`03
001oogoo00moo`<004=oo`=l00moo`<000Eoo`<000moo`=l02Uoo`40005oo`002Woo00<007ooOol0
3goo0`00@goo0g`03goo10000goo10003goo17`0:7oo0@000Goo000:Ool00`00Oomoo`0?Ool30012
Ool4O00@Ool400000goo00000002000AOol3O00XOol10001Ool000Aoo`8000Aoo`03001oogoo00mo
o`<0049oo`=l019oo`<00004Ool00000000BOol3O00XOol10001Ool000=oo`04001oogoo0003Ool0
0`00Oomoo`0?Ool30012Ool3O00BOol7000BOol3O00XOol10001Ool000=oo`04001oogoo0003Ool0
0`00Oomoo`0?Ool30012Ool3O00COol01@00O01l07`000004goo0g`0:7oo0@000Goo0003Ool01000
Oomoo`000goo0P0047oo0`00@Woo0g`057oo1W`04Goo0g`09goo0P000Goo0003Ool01000Oomoo`00
0goo00<007ooOol03goo0`00@Woo0g`057oo2G`03Woo0g`0:7oo0@000Goo0003Ool01000Oomoo`00
0goo00<007ooOol03goo0`00@Woo0g`05Woo2W`02goo0g`0:7oo0@000Goo0004Ool20004Ool00`00
Oomoo`0?Ool30012Ool3O00IOol:O008Ool3O00XOol10001Ool000Yoo`03001oogoo00moo`<0049o
o`=l01aoo`Yl00Eoo`=l02Qoo`40005oo`002Woo00<007ooOol03goo0`00@Woo17`07Woo2W`00Woo
0g`0:7oo0@000Goo000:Ool00`00Oomoo`0?Ool30013Ool3O00QOol<O00XOol10001Ool000Yoo`03
001oogoo00moo`<004=oo`=l02Aoo`Yl02Moo`40005oo`002Woo00<007ooOol03goo0`00@goo0g`0
9goo2W`097oo0@000Goo000:Ool00`00Oomoo`0?Ool30013Ool4O00WOol<O00QOol10001Ool000Yo
o`80011oo`<004Aoo`=l02Ioo`Al009oo`Yl01eoo`80005oo`002Woo00<007ooOol03goo0`00A7oo
17`09Goo0g`01Woo2W`06goo0@000Goo000:Ool00`00Oomoo`0?Ool30014Ool4O00TOol4O009Ool:
O00HOol10001Ool000Yoo`03001oogoo00moo`<004Eoo`El029oo`=l00eoo`Ul0003001oogoo01=o
o`40005oo`002Woo00<007ooOol03goo0`00AWoo17`08Goo17`047oo1G`000@000?P0n03h1=oo`40
005oo`002Woo00<007ooOol03goo0`00Agoo17`07goo17`057oo00=l000000000`?P4goo0@000Goo
000:Ool00`00Oomoo`0?Ool30017Ool4O00NOol5O00FOol010000n03h0?P4goo0@000Goo000:Ool0
0`00Oomoo`0?Ool30018Ool5O00JOol5O00IOol30n0COol10001Ool000Yoo`03001oogoo00moo`<0
04Uoo`Il01Qoo`El01Uoo`<3h1=oo`40005oo`002Woo0P0047oo0`00BWoo1g`05Goo17`06goo0`?P
4Woo0P000Goo000:Ool00`00Oomoo`0?Ool3001;Ool8O00AOol5O00LOol30n0COol10001Ool000Yo
o`03001oogoo00moo`<004ioo`Ml00aoo`Ql01aoo`<3h1=oo`40005oo`002Woo00<007ooOol03goo
0`00D7oo5g`07Woo0`?P4goo0@000Goo000:Ool00`00Oomoo`0?Ool3001BOolCO00POol30n0COol1
0001Ool000Yoo`03001oogoo00moo`<005Aoo`il02=oo`<3h1=oo`40005oo`002Woo00<007ooOol0
3goo0`00QGoo0`?P4goo0@000Goo000:Ool00`00Oomoo`0?Ool30025Ool30n0COol10001Ool000Yo
o`03001oogoo00moo`<008Eoo`<3h1=oo`40005oo`002Woo0P0047oo0`00QGoo0`?P4Woo0P000Goo
000:Ool00`00Oomoo`0?Ool30025Ool30n0COol10001Ool000Yoo`03001oogoo00moo`<008Eoo`<3
h1=oo`40005oo`002Woo00<007ooOol03goo0`00QGoo0`?P4goo0@000Goo000:Ool00`00Oomoo`0?
Ool30025Ool30n0COol10001Ool000Yoo`03001oogoo00moo`<008Eoo`<3h1=oo`40005oo`002Woo
00<007ooOol03goo0`00QGoo0`?P4goo0@000Goo000:Ool00`00Oomoo`0?Ool30025Ool30n0COol1
0001Ool000Yoo`03001oogoo00moo`<008Eoo`<3h1=oo`40005oo`002Woo0P0047oo0`00QGoo0`?P
4Woo0P000Goo000:Ool00`00Oomoo`0?Ool30025Ool30n0COol10001Ool000Yoo`03001oogoo00mo
o`<008Eoo`<3h1=oo`40005oo`002Woo00<007ooOol03goo0`00QGoo0`?P4goo0@000Goo000:Ool0
0`00Oomoo`0?Ool30025Ool30n0COol10001Ool000Yoo`03001oogoo00moo`<008Eoo`<3h1=oo`40
005oo`002Woo00<007ooOol03goo0`00QGoo0`?P4goo0@000Goo0004Ool30003Ool00`00Oomoo`0?
Ool30025Ool30n0COol10001Ool000Eoo`03001oogoo009oo`03001oogoo00moo`<008Eoo`<3h1=o
o`40005oo`001Goo00<007ooOol00Woo00<007ooOol03goo0`00QGoo0`?P4goo0@000Goo0005Ool0
0`00Oomoo`02Ool2000@Ool30025Ool30n0BOol20001Ool000Eoo`03001oogoo009oo`03001oogoo
00moo`<008Eoo`<3h1=oo`40005oo`001Goo00<007ooOol00Woo00<007ooOol03goo0`00QWoo0`?P
4Woo0@000Goo0004Ool20004Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001o
ogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo
000:Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001oogoo00moo`<008Ioo`<3
h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool2000@Ool30026
Ool30n0AOol20001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo00<007oo
Ool03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool0
00Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P
4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001oogoo00mo
o`<008Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool2
000@Ool30026Ool30n0AOol20001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`00
2Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0B
Ool10001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo
0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool000Yoo`03
001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@00
0Goo000:Ool2000@Ool30026Ool30n0AOol20001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19o
o`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool3
0026Ool30n0BOol10001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo00<0
07ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001
Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo
0`?P4Woo0@000Goo000:Ool2000@Ool30026Ool30n0AOol20001Ool000Yoo`03001oogoo00moo`<0
08Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00
Oomoo`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005o
o`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool3
0n0BOol10001Ool000=oo`@000=oo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`0017oo00<0
07oo00000goo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo0005Ool00`00Oomoo`02Ool00`00
Oomoo`0?Ool30026Ool30n0BOol10001Ool000Ioo`04001oogooOol2000@Ool30026Ool30n0AOol2
0001Ool000Ioo`05001oogooOol0000AOol30026Ool30n0BOol10001Ool000=oo`04001oogoo0003
Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool000Aoo`8000Aoo`03001oogoo00moo`<008Io
o`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomo
o`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`00
2Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0B
Ool10001Ool000Yoo`80011oo`<008Ioo`<3h15oo`80005oo`002Woo00<007ooOol03goo0`00QWoo
0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001oogoo
00moo`<008Ioo`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:
Ool00`00Oomoo`0?Ool30025Ool010000n03h0?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30024
Ool200030n0BOol10001Ool000Yoo`03001oogoo00moo`<008Eoo`040003h0?P0n0BOol10001Ool0
00Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo0P0047oo0`00QWoo0`?P4Goo0P00
0Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001oogoo00moo`<008Io
o`<3h19oo`40005oo`002Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomo
o`0?Ool30026Ool30n0BOol10001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`00
2Woo00<007ooOol03goo0`00QWoo0`?P4Woo0@000Goo000:Ool00`00Oomoo`0?Ool30026Ool30n0B
Ool10001Ool000Yoo`03001oogoo00moo`<008Ioo`<3h19oo`40005oo`002Woo0P0047oo0`00Qgoo
0`?P47oo0P000Goo000:Ool00`00Oomoo`0?Ool30027Ool30n0AOol10001Ool000Yoo`03001oogoo
00moo`<008Moo`<3h15oo`40005oo`002Woo00<007ooOol03goo0`00Qgoo0`?P4Goo0@000Goo000:
Ool00`00Oomoo`0?Ool30027Ool30n0AOol10001Ool000Yoo`03001oogoo00moo`<008Moo`<3h15o
o`40005oo`002Woo00<007ooOol03goo0`00Qgoo0`?P4Goo0@000Goo000:Ool00`00Oomoo`0?Ool3
0027Ool30n0AOol10001Ool000Yoo`03001oogoo00moo`<008Moo`<3h15oo`40005oo`002Woo00<0
07ooOol03goo0`00Qgoo0`?P4Goo0@000Goo000:Ool2000@Ool30027Ool30n0@Ool20001Ool000Yo
o`03001oogoo00moo`<008Moo`<3h15oo`40005oo`002Woo00<007ooOol03goo0`00Qgoo0`?P4Goo
0@000Goo000:Ool00`00Oomoo`0?Ool30027Ool30n0AOol10001Ool000Yoo`03001oogoo00moo`<0
08Moo`<3h15oo`40005oo`002Woo00<007ooOol03goo0`00Qgoo0`?P4Goo0@000Goo0003Ool30004
Ool00`00Oomoo`0?Ool30027Ool30n0AOol10001Ool000Ioo`05001oogooOol0000AOol30027Ool3
0n0AOol10001Ool000Ioo`05001oogooOol0000AOol601n4Ool30n0AOol10001Ool000Aoo`8000Ao
o`80011ooa007gYoo`<3h11oo`80005oo`001Goo00<007ooOol00Woo00<007ooOol03goo6P0OL7oo
0`?P4Goo0@000Goo0006Ool01@00Oomoogoo00005goo7P0OIWoo0`?P4Goo0@000Goo0003Ool30004
Ool00`00Oomoo`0OOolN01mLOol30n0AOol10001Ool000Yoo`03001oogoo02Uooah07e9oo`<3h15o
o`40005oo`002Woo00<007ooOol0<goo7P0OB7oo0`?P4Goo0@000Goo000:Ool00`00Oomoo`0mOolM
01loOol30n0AOol10001Ool000Yoo`03001oogoo04Mooad07cEoo`<3h15oo`40005oo`002Woo00<0
07ooOol0DGoo7@0O:goo0`?P4Goo0@000Goo000:Ool2001KOolN01lQOol30n0@Ool20001Ool000Yo
o`03001oogoo06Aooah07aMoo`<3h15oo`40005oo`002Woo00<007ooOol0KWoo7P0O3Goo0`?P4Goo
0@000Goo000:Ool00`00Oomoo`1hOolN01l3Ool30n0AOol10001Ool000Yoo`03001oogoo089ooaL0
7`<3h15oo`40005oo`002Woo00<007ooOol0S7oo300O00@000?P0n03h15oo`40005oo`002Woo00<0
07ooOol0UWoo00<07`0000000`?P4Goo0@000Goo000:Ool00`00Oomoo`2HOol3000BOol10001Ool0
00Yoo`03001oogoo09Uoo`03001oogoo015oo`40005oo`002Woo0P00[Goo0P000Goo000:Ool00`00
Oomoo`2]Ool10001Ool000Yoo`03001oogoo0:eoo`40005oo`002Woo00<007ooOol0[Goo0@000Goo
000:Ool00`00Oomoo`2]Ool10001Ool000Yoo`03001oogoo0:eoo`40005oo`002Woo00<007ooOol0
[Goo0@000Goo000:Ool00`00Oomoo`2]Ool10001Ool000Yoo`03001oogoo0:eoo`40005oo`002Woo
00<007ooOol0[Goo0@000Goo000:Ool2002]Ool20001Ool000Yoo`03001oogoo0:eoo`40005oo`00
2Woo00<007ooOol0[Goo0@000Goo000:Ool00`00Oomoo`2]Ool10001Ool000Yoo`03001oogoo0:eo
o`40005oo`002Woo00<007ooOol0[Goo0@000Goo000:Ool00`00Oomoo`2]Ool10001Ool000Yoo`03
001oogoo0:eoo`40005oo`002Woo00<007ooOol0[Goo0@000Goo000:Ool2002]Ool20001Ool000Yo
o`03001oogoo0:eoo`40005oo`002Woo00<007ooOol0[Goo0@000Goo000:Ool00`00Oomoo`2]Ool1
0001Ool000Yoo`03001oogoo0:eoo`40005oo`002Woo00<007ooOol0[Goo0@000Goo0005Ool00`00
Oomoo`02Ool00`00Oomoo`2]Ool10001Ool000Eoo`03001oogoo009oo`03001oogoo0:eoo`40005o
o`000goo10000goo00<007ooOol0[Goo0@000Goo0003Ool00`00Ool00004Ool2002]Ool20001Ool0
00Aoo`8000Aoo`03001oogoo0:eoo`40005oo`0017oo0P0017oo00<007ooOol0[Goo0@000Goo0005
Ool00`00Oomoo`02Ool00`00Oomoo`2]Ool10001Ool000Yoo`03001oogoo0:eoo`40005oo`002Woo
00<007ooOol0[Goo0@000Goo000:Ool00`00Oomoo`2]Ool10001Ool000Yoo`03001oogoo0:eoo`40
005oo`002Woo00<007ooOol047oo00<007ooOol057oo00<007ooOol057oo00<007ooOol057oo00<0
07ooOol057oo00<007ooOol057oo00<007ooOol057oo00<007ooOol047oo0@000Goo000:Oona0001
Ool00001\
\>"],
  ImageRangeCache->{{{0, 187}, {286, 0}} -> {-2.63333, -1.98984, 0.0216562, 
  0.0216562}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Four body objects are defined for the four-bar mechanism model. Each body \
in the model is simply a two-ended bar, so only two local points are defined \
on each body. Each body is attached to one neighboring body at its local \
origin and another neighboring body at an offset point on the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " or ",
  StyleBox["y",
    FontSlant->"Italic"],
  " axis. Body 4, the center bar, has a third point defined that is used only \
as a point of reference to measure the motion of the model.\n\nThe body \
objects are defined such that the length of each bar is a symbolic parameter \
that can be changed at a later time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(drivebar = 2; \)\), 
    \(\(drivenbar = 3; \)\), 
    \(\(centerbar = 4; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the four body objects for the four-bar model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[bar2, bar3, bar4]\nbd[ground] = Body[ground, PointList\[Rule]{ \n  \
(*P1*) { 0, 0},  \n  (*P2*) {-2, 3}}];  "], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[drivebar] = Body[drivebar, PointList\[Rule]{ \n  (*P1*) {   0, 0},  \n  \
(*P2*) {bar2, 0}},  \n  InitialGuess->{{0,0},0}];  "], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[drivenbar] = Body[drivenbar, PointList\[Rule]{\n  (*P1*) {   0, 0},  \n  \
(*P2*) {bar3, 0}},  \n  InitialGuess->{{-2,3},0}];"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"bd[centerbar] = Body[centerbar, PointList\[Rule]{ \n  (*P1*) {0, 0   },  \n  \
(*P2*) {0, bar4},  \n  (*P3*) {0, 2   }},  \n  InitialGuess->{{1,0},0}];"], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The body objects are incorporated into the current model with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[drivebar], bd[drivenbar], bd[centerbar]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Five constraints, one of which is a driving constraint with explicit \
dependence on time, are used to model the four-bar mechanism. A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint controls the rotation of the drive bar as a function of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Four ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints model the revolute joints at each end of the four bars."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here are the five constraint objects for the four-bar model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(cs[1] = RotationLock1[1, drivebar, ground, 2.0  \[Pi]\ T]; \n
    \(cs[2] = Revolute2[2, Point[drivebar, 1], Point[ground, 1]]; \)\), 
    \(cs[3] = Revolute2[3, \n\t\tPoint[drivenbar, 1], Point[ground, 2]]; \n
    cs[4] = Revolute2[4, \n\t\tPoint[drivebar, 2], Point[centerbar, 1]]; \n
    cs[5] = Revolute2[5, \n\t\tPoint[drivenbar, 2], Point[centerbar, 2]]; 
    \)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The constraint objects are incorporated into the current model with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 5]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Before the model can be run, the symbols ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["bar4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that determine the length of the each bar must be defined. The ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to make the symbols formal parameters so that they are \
recognized by ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["The symbolic lengths of each bar are defined."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetParameters[bar2 \[Rule] 1, bar3 \[Rule] 3, bar4 \[Rule] 3]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({bar2 \[Rule] 1, bar3 \[Rule] 3, bar4 \[Rule] 3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.05."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05, Solution \[Rule] Velocity]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(bar2 \[Rule] 1\), ",", 
        \(bar3 \[Rule] 3\), ",", \(bar4 \[Rule] 3\), ",", \(X2 \[Rule] 0.`\), 
        ",", \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.314159265358979311`\), 
        ",", \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
        \(Th3 \[Rule] 0.103127849139853311`\), ",", 
        \(X4 \[Rule] 0.951056516295153464`\), ",", 
        \(Y4 \[Rule] 0.309016994374947406`\), ",", 
        \(Th4 \[Rule] \(-0.0110017511491135966`\)\), ",", \(X2d \[Rule] 0.`\),
         ",", \(Y2d \[Rule] 0.`\), ",", \(Th2d \[Rule] 6.28318530717958623`\),
         ",", \(X3d \[Rule] 0.`\), ",", \(Y3d \[Rule] 0.`\), ",", 
        \(Th3d \[Rule] 1.99764343513096953`\), ",", 
        \(X4d \[Rule] \(-1.94161103872546636`\)\), ",", 
        \(Y4d \[Rule] 5.9756643294831111`\), ",", 
        \(Th4d \[Rule] \(-0.441582708205192542`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Here is a plot of the four-bar mechanism with the locus of a point on the \
center bar."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.52632 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.631579 0.263158 0.421053 0.263158 [
[(-2)] .10526 0 0 2 Msboxa
[(-1.5)] .23684 0 0 2 Msboxa
[(-1)] .36842 0 0 2 Msboxa
[(-0.5)] .5 0 0 2 Msboxa
[(0)] .63158 0 0 2 Msboxa
[(0.5)] .76316 0 0 2 Msboxa
[(1)] .89474 0 0 2 Msboxa
[(-1)] -0.0125 .15789 1 0 Msboxa
[(0)] -0.0125 .42105 1 0 Msboxa
[(1)] -0.0125 .68421 1 0 Msboxa
[(2)] -0.0125 .94737 1 0 Msboxa
[(3)] -0.0125 1.21053 1 0 Msboxa
[(4)] -0.0125 1.47368 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.52732 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.10526 0 m
.10526 .00625 L
s
P
[(-2)] .10526 0 0 2 Mshowa
p
.002 w
.23684 0 m
.23684 .00625 L
s
P
[(-1.5)] .23684 0 0 2 Mshowa
p
.002 w
.36842 0 m
.36842 .00625 L
s
P
[(-1)] .36842 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(-0.5)] .5 0 0 2 Mshowa
p
.002 w
.63158 0 m
.63158 .00625 L
s
P
[(0)] .63158 0 0 2 Mshowa
p
.002 w
.76316 0 m
.76316 .00625 L
s
P
[(0.5)] .76316 0 0 2 Mshowa
p
.002 w
.89474 0 m
.89474 .00625 L
s
P
[(1)] .89474 0 0 2 Mshowa
p
.001 w
.13158 0 m
.13158 .00375 L
s
P
p
.001 w
.15789 0 m
.15789 .00375 L
s
P
p
.001 w
.18421 0 m
.18421 .00375 L
s
P
p
.001 w
.21053 0 m
.21053 .00375 L
s
P
p
.001 w
.26316 0 m
.26316 .00375 L
s
P
p
.001 w
.28947 0 m
.28947 .00375 L
s
P
p
.001 w
.31579 0 m
.31579 .00375 L
s
P
p
.001 w
.34211 0 m
.34211 .00375 L
s
P
p
.001 w
.39474 0 m
.39474 .00375 L
s
P
p
.001 w
.42105 0 m
.42105 .00375 L
s
P
p
.001 w
.44737 0 m
.44737 .00375 L
s
P
p
.001 w
.47368 0 m
.47368 .00375 L
s
P
p
.001 w
.52632 0 m
.52632 .00375 L
s
P
p
.001 w
.55263 0 m
.55263 .00375 L
s
P
p
.001 w
.57895 0 m
.57895 .00375 L
s
P
p
.001 w
.60526 0 m
.60526 .00375 L
s
P
p
.001 w
.65789 0 m
.65789 .00375 L
s
P
p
.001 w
.68421 0 m
.68421 .00375 L
s
P
p
.001 w
.71053 0 m
.71053 .00375 L
s
P
p
.001 w
.73684 0 m
.73684 .00375 L
s
P
p
.001 w
.78947 0 m
.78947 .00375 L
s
P
p
.001 w
.81579 0 m
.81579 .00375 L
s
P
p
.001 w
.84211 0 m
.84211 .00375 L
s
P
p
.001 w
.86842 0 m
.86842 .00375 L
s
P
p
.001 w
.07895 0 m
.07895 .00375 L
s
P
p
.001 w
.05263 0 m
.05263 .00375 L
s
P
p
.001 w
.02632 0 m
.02632 .00375 L
s
P
p
.001 w
.92105 0 m
.92105 .00375 L
s
P
p
.001 w
.94737 0 m
.94737 .00375 L
s
P
p
.001 w
.97368 0 m
.97368 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .15789 m
.00625 .15789 L
s
P
[(-1)] -0.0125 .15789 1 0 Mshowa
p
.002 w
0 .42105 m
.00625 .42105 L
s
P
[(0)] -0.0125 .42105 1 0 Mshowa
p
.002 w
0 .68421 m
.00625 .68421 L
s
P
[(1)] -0.0125 .68421 1 0 Mshowa
p
.002 w
0 .94737 m
.00625 .94737 L
s
P
[(2)] -0.0125 .94737 1 0 Mshowa
p
.002 w
0 1.21053 m
.00625 1.21053 L
s
P
[(3)] -0.0125 1.21053 1 0 Mshowa
p
.002 w
0 1.47368 m
.00625 1.47368 L
s
P
[(4)] -0.0125 1.47368 1 0 Mshowa
p
.001 w
0 .21053 m
.00375 .21053 L
s
P
p
.001 w
0 .26316 m
.00375 .26316 L
s
P
p
.001 w
0 .31579 m
.00375 .31579 L
s
P
p
.001 w
0 .36842 m
.00375 .36842 L
s
P
p
.001 w
0 .47368 m
.00375 .47368 L
s
P
p
.001 w
0 .52632 m
.00375 .52632 L
s
P
p
.001 w
0 .57895 m
.00375 .57895 L
s
P
p
.001 w
0 .63158 m
.00375 .63158 L
s
P
p
.001 w
0 .73684 m
.00375 .73684 L
s
P
p
.001 w
0 .78947 m
.00375 .78947 L
s
P
p
.001 w
0 .84211 m
.00375 .84211 L
s
P
p
.001 w
0 .89474 m
.00375 .89474 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.05263 m
.00375 1.05263 L
s
P
p
.001 w
0 1.10526 m
.00375 1.10526 L
s
P
p
.001 w
0 1.15789 m
.00375 1.15789 L
s
P
p
.001 w
0 1.26316 m
.00375 1.26316 L
s
P
p
.001 w
0 1.31579 m
.00375 1.31579 L
s
P
p
.001 w
0 1.36842 m
.00375 1.36842 L
s
P
p
.001 w
0 1.42105 m
.00375 1.42105 L
s
P
p
.001 w
0 .10526 m
.00375 .10526 L
s
P
p
.001 w
0 .05263 m
.00375 .05263 L
s
P
p
.001 w
0 0 m
.00375 0 L
s
P
p
.002 w
0 0 m
0 1.52632 L
s
P
P
p
p
.002 w
.10526 1.52007 m
.10526 1.52632 L
s
P
p
.002 w
.23684 1.52007 m
.23684 1.52632 L
s
P
p
.002 w
.36842 1.52007 m
.36842 1.52632 L
s
P
p
.002 w
.5 1.52007 m
.5 1.52632 L
s
P
p
.002 w
.63158 1.52007 m
.63158 1.52632 L
s
P
p
.002 w
.76316 1.52007 m
.76316 1.52632 L
s
P
p
.002 w
.89474 1.52007 m
.89474 1.52632 L
s
P
p
.001 w
.13158 1.52257 m
.13158 1.52632 L
s
P
p
.001 w
.15789 1.52257 m
.15789 1.52632 L
s
P
p
.001 w
.18421 1.52257 m
.18421 1.52632 L
s
P
p
.001 w
.21053 1.52257 m
.21053 1.52632 L
s
P
p
.001 w
.26316 1.52257 m
.26316 1.52632 L
s
P
p
.001 w
.28947 1.52257 m
.28947 1.52632 L
s
P
p
.001 w
.31579 1.52257 m
.31579 1.52632 L
s
P
p
.001 w
.34211 1.52257 m
.34211 1.52632 L
s
P
p
.001 w
.39474 1.52257 m
.39474 1.52632 L
s
P
p
.001 w
.42105 1.52257 m
.42105 1.52632 L
s
P
p
.001 w
.44737 1.52257 m
.44737 1.52632 L
s
P
p
.001 w
.47368 1.52257 m
.47368 1.52632 L
s
P
p
.001 w
.52632 1.52257 m
.52632 1.52632 L
s
P
p
.001 w
.55263 1.52257 m
.55263 1.52632 L
s
P
p
.001 w
.57895 1.52257 m
.57895 1.52632 L
s
P
p
.001 w
.60526 1.52257 m
.60526 1.52632 L
s
P
p
.001 w
.65789 1.52257 m
.65789 1.52632 L
s
P
p
.001 w
.68421 1.52257 m
.68421 1.52632 L
s
P
p
.001 w
.71053 1.52257 m
.71053 1.52632 L
s
P
p
.001 w
.73684 1.52257 m
.73684 1.52632 L
s
P
p
.001 w
.78947 1.52257 m
.78947 1.52632 L
s
P
p
.001 w
.81579 1.52257 m
.81579 1.52632 L
s
P
p
.001 w
.84211 1.52257 m
.84211 1.52632 L
s
P
p
.001 w
.86842 1.52257 m
.86842 1.52632 L
s
P
p
.001 w
.07895 1.52257 m
.07895 1.52632 L
s
P
p
.001 w
.05263 1.52257 m
.05263 1.52632 L
s
P
p
.001 w
.02632 1.52257 m
.02632 1.52632 L
s
P
p
.001 w
.92105 1.52257 m
.92105 1.52632 L
s
P
p
.001 w
.94737 1.52257 m
.94737 1.52632 L
s
P
p
.001 w
.97368 1.52257 m
.97368 1.52632 L
s
P
p
.002 w
0 1.52632 m
1 1.52632 L
s
P
p
.002 w
.99375 .15789 m
1 .15789 L
s
P
p
.002 w
.99375 .42105 m
1 .42105 L
s
P
p
.002 w
.99375 .68421 m
1 .68421 L
s
P
p
.002 w
.99375 .94737 m
1 .94737 L
s
P
p
.002 w
.99375 1.21053 m
1 1.21053 L
s
P
p
.002 w
.99375 1.47368 m
1 1.47368 L
s
P
p
.001 w
.99625 .21053 m
1 .21053 L
s
P
p
.001 w
.99625 .26316 m
1 .26316 L
s
P
p
.001 w
.99625 .31579 m
1 .31579 L
s
P
p
.001 w
.99625 .36842 m
1 .36842 L
s
P
p
.001 w
.99625 .47368 m
1 .47368 L
s
P
p
.001 w
.99625 .52632 m
1 .52632 L
s
P
p
.001 w
.99625 .57895 m
1 .57895 L
s
P
p
.001 w
.99625 .63158 m
1 .63158 L
s
P
p
.001 w
.99625 .73684 m
1 .73684 L
s
P
p
.001 w
.99625 .78947 m
1 .78947 L
s
P
p
.001 w
.99625 .84211 m
1 .84211 L
s
P
p
.001 w
.99625 .89474 m
1 .89474 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.05263 m
1 1.05263 L
s
P
p
.001 w
.99625 1.10526 m
1 1.10526 L
s
P
p
.001 w
.99625 1.15789 m
1 1.15789 L
s
P
p
.001 w
.99625 1.26316 m
1 1.26316 L
s
P
p
.001 w
.99625 1.31579 m
1 1.31579 L
s
P
p
.001 w
.99625 1.36842 m
1 1.36842 L
s
P
p
.001 w
.99625 1.42105 m
1 1.42105 L
s
P
p
.001 w
.99625 .10526 m
1 .10526 L
s
P
p
.001 w
.99625 .05263 m
1 .05263 L
s
P
p
.001 w
.99625 0 m
1 0 L
s
P
p
.002 w
1 0 m
1 1.52632 L
s
P
P
p
P
0 0 m
1 0 L
1 1.52632 L
0 1.52632 L
closepath
clip
newpath
p
p
p
.02 w
.36842 .02632 m
.63158 .42105 L
.89474 .02632 L
.10526 .02632 L
.10526 1.21053 L
s
P
p
1 0 0 r
p
.02 w
.63158 .42105 m
.5 .64895 L
s
P
.02 w
newpath
.63158 .42105 .13158 0 365.73 arc
s
P
p
0 0 1 r
p
.02 w
.10526 1.21053 m
.88428 1.33859 L
s
P
P
p
p
.035 w
.5 .64895 Mdot
.88428 1.33859 Mdot
.75619 1.10871 Mdot
P
0 1 0 r
p
.02 w
.5 .64895 m
.88428 1.33859 L
s
P
P
P
.004 w
.89474 .94737 m
.88231 1.0543 L
.84974 1.14125 L
.8099 1.18863 L
.77745 1.17971 L
.75619 1.10871 L
.73604 .9956 L
.71384 .8778 L
.69963 .77996 L
.70211 .70986 L
.72304 .66987 L
.75924 .66226 L
.80424 .6891 L
.84889 .75019 L
.88228 .84023 L
.89474 .94737 L
s
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{188, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002l00017a000`40O003h00O_7oo002lOol00;ao
o`00_7oo002lOol001moo`<000ioo`D0009oo`03001oogoo009oo`03001oogoo00eoo`D000moo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00eoo`D0019oo`007goo00<007ooOol047oo00<007ooOol01Woo00<0
07oo000047oo00<007ooOol03Woo00<007oo00001goo00<007oo000037oo00<007oo00003goo00<0
07oo00001goo00<007oo000047oo00<007ooOol04Woo000JOol30003Ool00`00Oomoo`09Ool30003
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool30003Ool00`00Oomoo`09Ool30002Ool00`00Ool00009
Ool00`00Oomoo`0:Ool00`00Ool0000?Ool00`00Ool00009Ool00`00Oomoo`0>Ool00`00Oomoo`0B
Ool0021oo`03001oogoo00moo`03001oogoo00Ioo`80015oo`03001oogoo00ioo`03001oo`0000Mo
o`8000eoo`03001oo`0000moo`03001oo`0000Moo`80015oo`03001oogoo019oo`007goo00<007oo
000047oo00<007ooOol01Woo00<007ooOol047oo00<007ooOol03Woo00<007oo00001goo00<007oo
Ool037oo00<007oo00003goo00<007oo00001goo00<007ooOol047oo00<007ooOol04Woo000POol0
0`00Oomoo`0>Ool20008Ool3000?Ool2000AOol00`00Oomoo`06Ool3000=Ool00`00Oomoo`0?Ool0
0`00Oomoo`06Ool3000?Ool2000DOol00;aoo`00_7oo002lOol00;aoo`00_7oo002lOol00;aoo`00
_7oo000<Oon_0001Ool000aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo0000
17oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00001Ool0
00aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`0>
Oon=000@Ool10001Ool000aoo`03001oogoo00ioohd0011oo`40005oo`0037oo00<007ooOol03Woo
S@0047oo0@000Goo000<Ool00`00Oomoo`0>Ool3000/Ool4001EOol4000AOol10001Ool000aoo`03
001oogoo00ioo`<002eoo`<005Eoo`<0019oo`40005oo`0037oo00<007ooOol03Woo0`00;Goo1000
Dgoo10004Woo0@000Goo000<Ool00`00Oomoo`0>Ool3000^Ool4001AOol4000COol10001Ool000ao
o`03001oogoo00ioo`<002moo`<0055oo`<001Aoo`40005oo`0037oo00<007ooOol03Woo0`00;goo
1000Cgoo100057oo0@000Goo000<Ool00`00Oomoo`0>Ool3000`Ool4001=Ool4000EOol10001Ool0
00aoo`03001oogoo00ioo`<0035oo`<004eoo`<001Ioo`40005oo`0037oo00<007ooOol03Woo0`00
<Goo1000Bgoo10005Woo0@000Goo000<Ool00`00Oomoo`0>Ool3000bOol40019Ool4000GOol10001
Ool000aoo`03001oogoo00ioo`<003=oo`<004Uoo`<001Qoo`40005oo`0037oo00<007ooOol03Woo
0`00<goo1000Agoo100067oo0@000Goo000<Ool00`00Oomoo`0>Ool3000dOol40015Ool4000IOol1
0001Ool000aoo`03001oogoo00ioo`<003Eoo`<004Eoo`<001Yoo`40005oo`0037oo00<007ooOol0
3Woo0`00=Goo1000@goo10006Woo0@000Goo000<Ool00`00Oomoo`0>Ool3000fOol40011Ool4000K
Ool10001Ool000aoo`03001oogoo00ioo`<003Moo`<0045oo`<001aoo`40005oo`0037oo00<007oo
Ool03Woo0`00=goo1000?goo100077oo0@000Goo000<Ool00`00Oomoo`0>Ool3000hOol4000mOol4
000MOol10001Ool000Eoo`D0009oo`03001oogoo00ioo`<003Uoo`<003eoo`<001ioo`40005oo`00
1goo00<007ooOol00Woo00<007ooOol03Woo0`00>Goo1000>goo10007Woo0@000Goo000017oo0000
00000goo00<007ooOol00Woo0P003goo0`00>Woo1000>Goo10007Woo0P000Goo0007Ool00`00Oomo
o`02Ool00`00Oomoo`0>Ool3000kOol3000iOol3000POol10001Ool000Moo`03001oogoo009oo`03
001oogoo00ioo`<003]oo`@003Moo`@0021oo`40005oo`001Woo0P0017oo00<007ooOol03Woo0`00
?7oo1000=Goo10008Goo0@000Goo000<Ool00`00Oomoo`0>Ool3000mOol3000eOol3000ROol10001
Ool000aoo`03001oogoo00ioo`<003eoo`@003=oo`@0029oo`40005oo`0037oo00<007ooOol03Woo
0`00?Woo1000<Goo10008goo0@000Goo000<Ool00`00Oomoo`0>Ool3000oOol3000aOol3000TOol1
0001Ool000aoo`03001oogoo00ioo`<003moo`@002moo`@002Aoo`40005oo`0037oo00<007ooOol0
3Woo0`00@7oo1000;Goo10009Goo0@000Goo000<Ool00`00Oomoo`0>Ool30011Ool3000]Ool3000V
Ool10001Ool000aoo`03001oogoo00ioo`<0045oo`@002]oo`@002Ioo`40005oo`0037oo00<007oo
Ool03Woo0`00@Woo1000:Goo10009goo0@000Goo000<Ool00`00Oomoo`0>Ool30013Ool3000YOol3
000XOol10001Ool000aoo`03001oogoo00ioo`<004=oo`@002Moo`@002Qoo`40005oo`0037oo00<0
07ooOol03Woo0`00A7oo10009Goo1000:Goo0@000Goo000<Ool00`00Oomoo`0>Ool30015Ool3000U
Ool3000ZOol10001Ool000aoo`03001oogoo00ioo`<004Eoo`@002=oo`@002Yoo`40005oo`0037oo
00<007ooOol03Woo0`00AWoo10008Goo1000:goo0@000Goo000<Ool00`00Oomoo`0>Ool30017Ool3
000QOol3000/Ool10001Ool000aoo`03001oogoo00ioo`<004Moo`@001moo`@002aoo`40005oo`00
37oo00<007ooOol03Woo0`00B7oo10007Goo1000;Goo0@000Goo000<Ool00`00Oomoo`0>Ool30019
Ool30008Ool<O009Ool3000^Ool10001Ool000aoo`03001oogoo00ioo`<004Uoo`@000Eooa9l00Ao
o`@002ioo`40005oo`0037oo00<007ooOol03Woo0`00BWoo100067`000=oo`0000000P00;goo0@00
0Goo000<Ool00`00Oomoo`0>Ool3001;Ool20008O00:Ool9O002000`Ool10001Ool000aoo`03001o
ogoo00ioo`<004]oo`Ql011oo`El0080031oo`40005oo`0037oo00<007ooOol03Woo0`00BWoo1W`0
5Goo1G`0<7oo0@000Goo000<Ool00`00Oomoo`0>Ool30019Ool6O0000`00Oomoo`0COol00`00O01l
0004O00^Ool10001Ool000aoo`03001oogoo00ioo`<004Qoo`El00@001=oo`<000El02ioo`40005o
o`0037oo00<007ooOol03Woo0`00Agoo17`00goo10004Goo100000=oog`0O00017`0;7oo0@000Goo
000<Ool00`00Oomoo`0>Ool30017Ool4O004Ool3000AOol30004Ool4O00/Ool10001Ool000aoo`03
001oogoo00ioo`<004Ioo`Al00Eoo`@000moo`@000Eoo`Al02]oo`40005oo`0037oo00<007ooOol0
3Woo0`00AGoo1G`01Woo10003Goo10001goo0g`0:goo0@000Goo000<Ool00`00Oomoo`0>Ool30014
Ool4O009Ool3000=Ool30008Ool4O00ZOol10001Ool000aoo`03001oogoo00ioo`<004Aoo`Al00Uo
o`@000]oo`@000Uoo`=l02Yoo`40005oo`0037oo00<007ooOol03Woo0`00A7oo0g`02goo10002Goo
10002Woo17`0:Goo0@000Goo000<Ool00`00Oomoo`0>Ool30013Ool4O00<Ool30009Ool3000<Ool3
O00YOol10001Ool000aoo`03001oogoo00ioo`<004=oo`=l00eoo`@000Moo`@000aoo`Al02Qoo`40
005oo`0037oo00<007ooOol03Woo0`00@goo0g`03Woo10001Goo10003Woo0g`0:7oo0@000Goo000<
Ool00`00Oomoo`0>Ool30013Ool3O00?Ool30005Ool3000?Ool4O00WOol10001Ool000aoo`03001o
ogoo00ioo`<0049oo`Al00moo`@000=oo`@0011oo`=l02Moo`40005oo`0037oo00<007ooOol03Woo
0`00@Woo0g`04Goo100000=oo`0000000P004Goo0g`09goo0@000Goo000<Ool00`00Oomoo`0>Ool3
0012Ool3O00BOol3000017oo000000004Woo0g`09goo0@000Goo0007Ool00`00Oomoo`02Ool00`00
Oomoo`0>Ool30012Ool3O00BOol7000BOol3O00WOol10001Ool000Ioo`03001oo`0000=oo`03001o
ogoo00ioo`<0049oo`=l01=oo`05001l07`0O000000COol3O00WOol10001Ool000Ioo`03001oo`00
00=oo`8000moo`<0049oo`=l01Aoo`=l01Aoo`=l02Ioo`80005oo`001Woo00<007oo00000goo00<0
07ooOol03Woo0`00@Woo0g`04goo17`057oo0g`09goo0@000Goo0006Ool00`00Ool00003Ool00`00
Oomoo`0>Ool30012Ool3O00COol3O00EOol3O00WOol10001Ool000Moo`03001oogoo009oo`03001o
ogoo00ioo`<0049oo`=l019oo`Al01Eoo`=l02Moo`40005oo`0037oo00<007ooOol03Woo0`00@Woo
17`047oo17`05Woo0g`09goo0@000Goo000<Ool00`00Oomoo`0>Ool30013Ool3O00@Ool3O00FOol4
O00WOol10001Ool000aoo`03001oogoo00ioo`<004=oo`=l00moo`Al01Ioo`=l02Qoo`40005oo`00
37oo00<007ooOol03Woo0`00@goo0g`03goo0g`05Woo17`0:7oo0@000Goo000<Ool00`00Oomoo`0>
Ool30013Ool3O00>Ool4O00FOol3O00YOol10001Ool000aoo`03001oogoo00ioo`<004=oo`Al00ao
o`Al01Moo`=l02Uoo`40005oo`0037oo00<007ooOol03Woo0`00A7oo0g`037oo0g`05goo17`0:Goo
0@000Goo000<Ool00`00Oomoo`0>Ool30014Ool4O00:Ool4O00GOol3O00ZOol10001Ool000aoo`03
001oogoo00ioo`<004Aoo`Al00Yoo`=l01Moo`Al02Yoo`40005oo`0037oo00<007ooOol03Woo0`00
AGoo17`027oo17`05Woo17`0:goo0@000Goo000<Ool00`00Oomoo`0>Ool30016Ool4O006Ool4O00F
Ool5O00[Ool10001Ool000aoo`03001oogoo00ioo`<004Moo`Al00Eoo`=l01Ioo`Al02eoo`40005o
o`0037oo00<007ooOol03Woo0`00B7oo1G`00Woo17`05Goo17`0;Woo0@000Goo000<Ool00`00Oomo
o`0>Ool30019Ool9O00EOol4O00_Ool10001Ool000aoo`03001oogoo00ioo`<004Yoo`Ql01=oo`El
031oo`40005oo`0037oo00<007ooOol03Woo0`00Bgoo1W`04Woo1g`0<7oo0@000Goo000<Ool00`00
Oomoo`0>Ool3001=Ool8O00<Ool7O00bOol10001Ool000aoo`03001oogoo00ioo`<004aoo`el00Ao
o`Ul03Aoo`40005oo`0037oo00<007ooOol03Woo0`00C7oo67`0=Woo0@000Goo000<Ool00`00Oomo
o`0>Ool3001;Ool4O005Ool>O00hOol10001Ool000aoo`03001oogoo00ioo`<004]oo`=l00Yoo`Il
03aoo`40005oo`0037oo00<007ooOol03Woo0`00BWoo17`0C7oo0@000Goo000<Ool00`00Oomoo`0>
Ool30019Ool4O01=Ool10001Ool000aoo`03001oogoo00ioo`<004Uoo`=l04ioo`40005oo`0037oo
00<007ooOol03Woo0`00B7oo17`0CWoo0@000Goo000<Ool00`00Oomoo`0>Ool30018Ool3O01?Ool1
0001Ool000aoo`03001oogoo00ioo`<004Moo`Al04moo`40005oo`0037oo00<007ooOol03Woo0`00
AWoo17`0D7oo0@000Goo000<Ool00`00Oomoo`0>Ool30016Ool3O01AOol10001Ool000aoo`03001o
ogoo00ioo`<004Eoo`Al055oo`40005oo`0037oo00<007ooOol03Woo0`00AGoo0g`0DWoo0@000Goo
000<Ool00`00Oomoo`0>Ool30014Ool4O01BOol10001Ool000aoo`03001oogoo00ioo`<004=oo`Al
05=oo`40005oo`0037oo00<007ooOol03Woo0`00@goo0g`0E7oo0@000Goo000<Ool00`00Oomoo`0>
Ool30012Ool30n000g`0Oomoo`1BOol10001Ool000aoo`03001oogoo00ioo`<0049oo`<3h5Eoo`40
005oo`0037oo00<007ooOol03Woo0`00@Goo00<000?P0n000P?PE7oo0@000Goo000<Ool00`00Oomo
o`0>Ool30012Ool010000n03h0?PE7oo0@000Goo000<Ool00`00Oomoo`0>Ool30013Ool40n0WOol3
000YOol10001Ool000aoo`03001oogoo00ioo`<004Aoo`<3h2=oo`@000=oo`8002Moo`40005oo`00
1Goo1@000Woo00<007ooOol03Woo0`00A7oo10?P8Goo00<007ooOol01goo0P009Goo0@000Goo0007
Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool30015Ool40n0POol00`00Oomoo`09Ool2000SOol10001
Ool000Moo`03001oogoo009oo`8000moo`<004Ioo`<3h1moo`03001oogoo00aoo`80021oo`80005o
o`001goo00<007ooOol00Woo00<007ooOol03Woo0`00AWoo10?P7Woo00<007ooOol03Woo00<007oo
Ool07Woo0@000Goo0007Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool30017Ool30n0MOol00`00Oomo
o`0?Ool00`00Oomoo`0NOol10001Ool000Ioo`8000Aoo`03001oogoo00ioo`<004Moo`@3h1aoo`03
001oogoo011oo`03001oogoo01eoo`40005oo`0037oo00<007ooOol03Woo0`00B7oo0`?P6goo00<0
07ooOol04Woo00<007ooOol077oo0@000Goo000<Ool00`00Oomoo`0>Ool30018Ool40n0JOol00`00
Oomoo`0COol00`00Oomoo`0KOol10001Ool000aoo`03001oogoo00ioo`<004Uoo`<3h1Yoo`03001o
ogoo01=oo`03001oogoo01]oo`40005oo`0037oo00<007ooOol03Woo0`00BGoo10?P6Goo00<007oo
Ool057oo00<007ooOol06Woo0@000Goo000<Ool00`00Oomoo`0>Ool3001:Ool40n0HOol00`00Oomo
o`0EOol00`00Oomoo`0IOol10001Ool000aoo`03001oogoo00ioo`<004]oo`<3h1Qoo`03001oogoo
01Ioo`03001oogoo01Qoo`40005oo`0037oo00<007ooOol03Woo0`00Bgoo10?P5goo00<007ooOol0
5Woo00<007ooOol067oo0@000Goo000<Ool00`00Oomoo`0>Ool3001<Ool30n0GOol00`00Oomoo`0G
Ool00`00Oomoo`0GOol10001Ool000aoo`03001oogoo00ioo`<004aoo`@3h1Ioo`03001oogoo01Mo
o`03001oogoo01Moo`40005oo`0037oo00<007ooOol03Woo0`00CGoo0`?P5Woo00<007ooOol067oo
00<007ooOol05Woo0@000Goo000<Ool00`00Oomoo`0>Ool3001=Ool40n0EOol00`00Oomoo`0HOol0
0`00Oomoo`0FOol10001Ool000aoo`03001oogoo00ioo`<004ioo`<3h1Eoo`03001oogoo01Qoo`03
001oogoo01Ioo`40005oo`0037oo00<007ooOol03Woo0`00CWoo10?P57oo00<007ooOol06Goo00<0
07ooOol05Goo0@000Goo000<Ool00`00Oomoo`0>Ool3001?Ool40n0COol00`00Oomoo`0IOol00`00
Oomoo`0EOol10001Ool000aoo`03001oogoo00ioo`<0051oo`<3h1=oo`03001oogoo01Yoo`03001o
ogoo01Aoo`40005oo`0037oo00<007ooOol03Woo0`00D7oo10?P4Woo00<007ooOol06Woo00<007oo
Ool057oo0@000Goo000<Ool00`00Oomoo`0>Ool3001AOol30n0BOol00`00Oomoo`0JOol00`00Oomo
o`0DOol10001Ool000aoo`03001oogoo00ioo`<0055oo`@3h19oo`03001oogoo01Yoo`03001oogoo
01=oo`40005oo`0037oo00<007ooOol03Woo0`00DWoo0`?P4Woo00<007ooOol06Woo00<007ooOol0
4goo0@000Goo000<Ool00`00Oomoo`0>Ool3001BOol40n0AOol00`00Oomoo`0JOol00`00Oomoo`0C
Ool10001Ool000aoo`03001oogoo00ioo`<005=oo`<3h15oo`03001oogoo01]oo`03001oogoo019o
o`40005oo`0037oo00<007ooOol03Woo0`00Dgoo10?P47oo00<007ooOol06goo00<007ooOol04Woo
0@000Goo000<Ool00`00Oomoo`0>Ool3001DOol40n0?Ool00`00Oomoo`0LOol00`00Oomoo`0AOol1
0001Ool000aoo`03001oogoo00ioo`<005Eoo`<3h0moo`03001oogoo01aoo`03001oogoo015oo`40
005oo`0037oo00<007ooOol03Woo0`00EGoo10?P3Woo00<007ooOol077oo00<007ooOol04Goo0@00
0Goo000<Ool00`00Oomoo`0>Ool3001FOol30n0?Ool00`00Oomoo`0KOol00`00Oomoo`0AOol10001
Ool000aoo`03001oogoo00ioo`<005Ioo`@3h0ioo`03001oogoo01]oo`03001oogoo015oo`40005o
o`0037oo00<007ooOol03Woo0`00Egoo0`?P3Woo00<007ooOol06goo00<007ooOol04Goo0@000Goo
000<Ool00`00Oomoo`0>Ool3001GOol40n0=Ool00`00Oomoo`0LOol00`00Oomoo`0@Ool10001Ool0
00aoo`03001oogoo00ioo`<005Qoo`<3h0eoo`03001oogoo01aoo`03001oogoo011oo`40005oo`00
37oo00<007ooOol03Woo0`00F7oo10?P37oo00<007ooOol077oo00<007ooOol047oo0@000Goo000<
Ool00`00Oomoo`0>Ool3001IOol40n0;Ool00`00Oomoo`0LOol00`00Oomoo`0@Ool10001Ool000ao
o`03001oogoo00ioo`<005Yoo`<3h0aoo`03001oogoo01]oo`03001oogoo011oo`40005oo`0037oo
00<007ooOol03Woo0`00FWoo10?P2goo00<007ooOol06goo00<007ooOol047oo0@000Goo000<Ool0
0`00Oomoo`0>Ool3001KOol30n0;Ool00`00Oomoo`0KOol00`00Oomoo`0@Ool10001Ool000aoo`03
001oogoo00ioo`<005]oo`@3h0Yoo`03001oogoo01]oo`03001oogoo011oo`40005oo`0037oo00<0
07ooOol03Woo0`00G7oo0`?P2Woo00<007ooOol06goo00<007ooOol047oo0@000Goo000<Ool00`00
Oomoo`0>Ool3001LOol40n0:Ool00`00Oomoo`0JOol00`00Oomoo`0@Ool10001Ool000aoo`03001o
ogoo00ioo`<005eoo`<3h0Yoo`03001oogoo01]oo`03001oogoo00moo`40005oo`0037oo00<007oo
Ool03Woo0`00GGoo10?P2Goo00<007ooOol06goo00<007ooOol03goo0@000Goo0006Ool30003Ool0
0`00Oomoo`0>Ool3001NOol40n08Ool00`00Oomoo`0KOol00`00Oomoo`0?Ool10001Ool000Ioo`03
001oogoo00=oo`03001oogoo00ioo`<005moo`<3h0Qoo`03001oogoo01]oo`03001oogoo00moo`40
005oo`001goo00<007ooOol00Woo0P003goo0`00Ggoo10?P1goo00<007ooOol06goo00<007ooOol0
3Woo0P000Goo0007Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool3001POol30n08Ool00`00Oomoo`0J
Ool00`00Oomoo`0?Ool10001Ool000Ioo`03001oo`0000=oo`03001oogoo00ioo`<0061oo`@3h0Mo
o`03001oogoo01Yoo`03001oogoo00moo`40005oo`001goo00<007ooOol00Woo00<007ooOol03Woo
0`00HGoo0`?P1goo00<007ooOol06Woo00<007ooOol03goo0@000Goo000<Ool00`00Oomoo`0>Ool3
001QOol40n06Ool00`00Oomoo`0JOol00`00Oomoo`0?Ool10001Ool000aoo`03001oogoo00ioo`<0
069oo`<3h0Ioo`03001oogoo01Uoo`03001oogoo011oo`40005oo`0037oo00<007ooOol03Woo0`00
HWoo10?P1Woo00<007ooOol067oo00<007ooOol047oo0@000Goo000<Ool00`00Oomoo`0>Ool3001S
Ool30n06Ool00`00Oomoo`0HOol00`00Oomoo`0@Ool10001Ool000aoo`03001oogoo00ioo`<006=o
o`@3h0Eoo`03001oogoo01Qoo`03001oogoo011oo`40005oo`0037oo00<007ooOol03Woo0`00I7oo
10?P17oo00<007ooOol067oo00<007ooOol047oo0@000Goo000<Ool00`00Oomoo`0>Ool3001UOol3
0n04Ool00`00Oomoo`0HOol00`00Oomoo`0@Ool10001Ool000aoo`03001oogoo00ioo`<006Eoo`@3
h0Aoo`03001oogoo01Moo`03001oogoo011oo`40005oo`0037oo00<007ooOol03Woo0`00IWoo0`?P
17oo00<007ooOol05goo00<007ooOol047oo0@000Goo000<Ool00`00Oomoo`0>Ool3001VOol40n03
Ool00`00Oomoo`0GOol00`00Oomoo`0@Ool10001Ool000aoo`03001oogoo00ioo`<006Moo`<3h0=o
o`03001oogoo01Ioo`03001oogoo015oo`40005oo`0037oo00<007ooOol03Woo0`00Igoo10?P0Woo
00<007ooOol05Woo00<007ooOol04Goo0@000Goo000<Ool00`00Oomoo`0>Ool3001XOol30n03Ool0
0`00Oomoo`0EOol00`00Oomoo`0AOol10001Ool000aoo`03001oogoo00ioo`<006Qoo`@3h09oo`03
001oogoo01Eoo`03001oogoo015oo`40005oo`0037oo00<007ooOol03Woo0`00JGoo10?P00=oo`00
Ool05Woo00<007ooOol04Goo0@000Goo000<Ool00`00Oomoo`0>Ool3001ZOol30n000goo001oo`0F
Ool00`00Oomoo`0AOol10001Ool000aoo`03001oogoo00ioo`<006Yoo`@3h003001oogoo01Aoo`03
001oogoo019oo`40005oo`0037oo00<007ooOol03Woo0`00Jgoo0`?P00=oo`00Ool057oo00<007oo
Ool04Woo0@000Goo000<Ool00`00Oomoo`0>Ool3001[Ool40n000`00Oomoo`0BOol00`00Oomoo`0C
Ool10001Ool000aoo`03001oogoo00ioo`<006aoo`<3h003001oogoo019oo`03001oogoo01=oo`40
005oo`0037oo00<007ooOol03Woo0`00K7oo0`?P00<007ooOol04Woo00<007ooOol04goo0@000Goo
000<Ool00`00Oomoo`0>Ool3001]Ool20n000`00Oomoo`0AOol00`00Oomoo`0DOol10001Ool000ao
o`03001oogoo00ioo`<006eoo`<3h003001oogoo011oo`03001oogoo01Aoo`40005oo`0037oo00<0
07ooOol03Woo0`00KWoo0P?P00<000?POol03goo00<007ooOol05Goo0@000Goo000<Ool00`00Oomo
o`0>Ool3001]Ool200000`?P0003h00@Ool00`00Oomoo`0EOol10001Ool000aoo`03001oogoo00io
o`<006ioo`030003h0000083h0moo`03001oogoo01Eoo`40005oo`0037oo00<007ooOol03Woo0`00
Kgoo0P000P?P3Woo00<007ooOol05Woo0@000Goo000<Ool00`00Oomoo`0>Ool3001`Ool010?P0003
h0?P3Goo00<007ooOol05Woo0@000Goo000<Ool00`00Oomoo`0>Ool3001aOol00`000n03h00<Ool0
0`00Oomoo`0GOol10001Ool000aoo`03001oogoo00ioo`<0075oo`040003h0?P0n0;Ool00`00Oomo
o`0GOol10001Ool000aoo`03001oogoo00ioo`<0075oo`040003h0?P0n0:Ool00`00Oomoo`0HOol1
0001Ool000aoo`03001oogoo00ioo`<0079oo`040003h0?P0n08Ool00`00Oomoo`0IOol10001Ool0
00aoo`03001oogoo00ioo`<0079oo`030003h0?P0083h0Moo`03001oogoo01Uoo`40005oo`0037oo
00<007ooOol03Woo0`00LWoo00<007oo0n000P?P1Woo00<007ooOol06Woo0@000Goo000<Ool00`00
Oomoo`0>Ool3001bOol00`00Ool3h0030n04Ool00`00Oomoo`0KOol10001Ool000aoo`03001oogoo
00ioo`<007=oo`03001oo`?P0083h0=oo`03001oogoo01aoo`40005oo`0037oo00<007ooOol03Woo
0`00Lgoo0P0010?P0Woo00<007ooOol077oo0@000Goo000<Ool00`00Oomoo`0>Ool3001eOol30000
0`?POol0000OOol10001Ool000aoo`03001oogoo00ioo`<007Ioo`83h080021oo`40005oo`0037oo
00<007ooOol03Woo0`00Mgoo0`?P87oo0@000Goo0006Ool20004Ool00`00Oomoo`0>Ool3001gOol4
0n0OOol10001Ool000Qoo`05001oogooOol0000@Ool501mfOol40n0NOol10001Ool000Moo`03001o
ogoo009oo`8000moo`/07g5oo`<3h1eoo`80005oo`0027oo00D007ooOomoo`00011ooa407f]oo`@3
h1eoo`40005oo`001Woo00<007oo00000goo00<007ooOol04goo4P0OIWoo0`?P7Goo0@000Goo0007
Ool00`00Oomoo`02Ool00`00Oomoo`0IOolB01mPOol40n0LOol10001Ool000aoo`03001oogoo01mo
oa<07eYoo`<3h1aoo`40005oo`0037oo00<007ooOol09Goo4`0OE7oo10?P6goo0@000Goo000<Ool0
0`00Oomoo`0[OolC01m?Ool30n0KOol10001Ool000aoo`03001oogoo039ooa807dUoo`@3h1Yoo`40
005oo`0037oo00<007ooOol0>7oo4P0OA7oo10?P6Goo0@000Goo000<Ool00`00Oomoo`0nOolB01lo
Ool30n0IOol10001Ool000aoo`03001oogoo04Aooa<07cQoo`@3h1Qoo`40005oo`0037oo00<007oo
Ool0BWoo4`0O<goo0`?P67oo0@000Goo000<Ool00`00Oomoo`1@OolC01l]Ool40n0GOol10001Ool0
00aoo`03001oogoo05Mooa807bQoo`<3h1Moo`40005oo`0037oo00<007ooOol0GGoo4P0O8Woo10?P
5Woo0@000Goo000<Ool00`00Oomoo`1SOolB01lMOol30n0FOol10001Ool000aoo`03001oogoo06Uo
oa<07aIoo`@3h1Eoo`40005oo`0037oo00<007ooOol0Kgoo4`0O4Goo10?P57oo0@000Goo000<Ool0
0`00Oomoo`1eOolC01l<Ool30n0DOol10001Ool000aoo`03001oogoo07aooa807`Ioo`@3h1=oo`40
005oo`0037oo00<007ooOol0PWoo4P0O00Aoo`?P0n03h1=oo`40005oo`0037oo00<007ooOol0R7oo
3@0O10?P4Woo0@000Goo000<Ool00`00Oomoo`2>Ool701l01@000n03h0?P00004Goo0@000Goo000<
Ool00`00Oomoo`2DOol201l30n0BOol10001Ool000aoo`03001oogoo09Moo`03001oogoo015oo`40
005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001o
ogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool0
00aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`2[
Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool0
0`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@00
0Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007oo
Ool0Zgoo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`00
1goo0`000Woo00<007ooOol0Zgoo0@000Goo0008Ool01@00Oomoogoo0000[Goo0@000Goo0006Ool4
0002Ool2002[Ool20001Ool000Ioo`03001oo`0000=oo`03001oogoo0:]oo`40005oo`001goo0P00
0goo00<007ooOol0Zgoo0@000Goo0008Ool01@00Oomoogoo0000[Goo0@000Goo000<Ool00`00Oomo
o`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<
Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00D007ooOomoo`00005oo`0037oo[`000Goo0000\
\>"],
  ImageRangeCache->{{{0, 187}, {286, 0}} -> {-2.66511, -2.00546, 0.021759, 
  0.021759}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Solving for One Parameter"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetCouple[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbol, equation",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that seeks the value of ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " that satisfies the ",
  StyleBox["equation",
    FontSlant->"Italic"],
  " and all of the constraints in the current model. All required initial \
guesses and the value of time are taken from the current initial guess ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["SolveCouple[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cpsys",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attempts to solve the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object ",
  StyleBox["cpsys",
    FontSlant->"Italic"],
  " and returns a list of rules representing the solution. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The coupled system building and solving functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions are now used to adjust the length of the drive bar ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In the four-bar's current configuration, the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 on the center bar is 0.898 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1. The following example uses a coupled system to find the length of \
the drive bar which causes the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 to be 0.8 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the current ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 on the center bar."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetGuess[]; \)\), 
    \(\(Location[centerbar, 3]\)\[LeftDoubleBracket]1\[RightDoubleBracket] /. 
      SolveMech[0.1]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.89796979282778615`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " basically adds a degree of freedom to the mechanism model by allowing a \
parameter to become a dependent variable, and also adds an equation to \
constrain the new degree of freedom. The following command essentially says \
\"adjust the value of ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " such that the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 on the center bar is equal to 0.8 at the current \
default time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1\".\n\nThe current default initial guesses obtained from ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are used as the initial guesses for the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", unless otherwise specified. The current value of the parameter ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used for its initial guess."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cpsys = 
      SetCouple[bar2, 
        \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
            \[RightDoubleBracket] == 0.8]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CoupleSystem[{bar2}, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that is solved with ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object contains a new set of constraint equations that include all of the \
constraints in the current model, plus one. The list of rules returned by ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is of the same form as the rules returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object and finds a new value of ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveCouple[cpsys]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(bar2 \[Rule] 0.52056957875206935`\), 
        ",", \(bar3 \[Rule] 3\), ",", \(bar4 \[Rule] 3\), ",", 
        \(X2 \[Rule] 0.`\), ",", \(Y2 \[Rule] 0.`\), ",", 
        \(Th2 \[Rule] 0.628318530717958623`\), ",", \(X3 \[Rule] \(-2.`\)\), 
        ",", \(Y3 \[Rule] 3.`\), ",", \(Th3 \[Rule] 0.0839882389683893038`\), 
        ",", \(X4 \[Rule] 0.42114963596503161`\), ",", 
        \(Y4 \[Rule] 0.305983121182571515`\), ",", 
        \(Th4 \[Rule] \(-0.190576696573565129`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The new value of the parameters ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is added to the current parameters list."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetParameters[%\[LeftDoubleBracket]{2, 3, 4}\[RightDoubleBracket]]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({bar2 \[Rule] 0.52056957875206935`, bar3 \[Rule] 3, bar4 \[Rule] 3}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This shows that the desired condition is satisfied."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Location[centerbar, 3]\)\[LeftDoubleBracket]1\[RightDoubleBracket] /. 
      SolveMech[0.1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.799999999999998756`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that sets a new value of time at which the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is solved. ",
  StyleBox["InitialCondition->Time->",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["t",
    FontSlant->"Italic"],
  " specifies the new value of time ",
  StyleBox["t",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies that the values in the current parameters list should be \
updated with the new values found by ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also accepts all of the standard Newton's method options.\n\nHere are the \
default option settings for ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n",
  StyleBox[
  "DampingFactor    -> 1\nInitialCondition -> Automatic\nMaxIterations    -> \
15\nSetParameters    -> False\nZeroTest         -> (Abs[#]<10^(-9)&)",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Options for ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Without building a new ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, ",
  StyleBox["cpsys",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be re-solved at a new value of time by using the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. Note that the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option expects a setting of the form ",
  StyleBox["Time->",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", not ",
  StyleBox["T->",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["t",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is solved again with a new value of time."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveCouple[cpsys, InitialCondition \[Rule] \(Time \[Rule] 0.11\), 
      SetParameters \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.110000000000000008`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(bar2 \[Rule] 0.559534334699471358`\),
         ",", \(bar3 \[Rule] 3\), ",", \(bar4 \[Rule] 3\), ",", 
        \(X2 \[Rule] 0.`\), ",", \(Y2 \[Rule] 0.`\), ",", 
        \(Th2 \[Rule] 0.691150383789754485`\), ",", \(X3 \[Rule] \(-2.`\)\), 
        ",", \(Y3 \[Rule] 3.`\), ",", \(Th3 \[Rule] 0.101907749810763337`\), 
        ",", \(X4 \[Rule] 0.431128614673683507`\), ",", 
        \(Y4 \[Rule] 0.35666060802551569`\), ",", 
        \(Th4 \[Rule] \(-0.185497674119480304`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The contents of the current parameters list are updated."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Parameters[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({bar2 \[Rule] 0.559534334699471358`, bar3 \[Rule] 3, bar4 \[Rule] 3}\)],
   "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Solving for Multiple Parameters"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetCouple[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, ..., symn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eq1, ..., eqn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that seeks the values of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " ",
  StyleBox["symi",
    FontSlant->"Italic"],
  " that satisfy ",
  StyleBox["n",
    FontSlant->"Italic"],
  " ",
  StyleBox["eqi",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Building coupled systems with multiple parameters."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Multiple parameter values are solved for by supplying an equal number of \
geometric conditions to be satisfied. A coupled system is used here to find \
the values of ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that simultaneously cause the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 on the center bar to be 0.8 and the distance from \
the global origin to point 2 on the center bar to be 3.5, both at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This finds the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 and the distance from the origin to point 2 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(Location[centerbar, 3]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
        Distance[Point[ground, 1], Point[centerbar, 2]]} /. SolveMech[.1]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.808767852085123983`, 3.42614194425346774`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cpsys = 
      SetCouple[{bar2, bar3}, {
          \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
              \[RightDoubleBracket] == 0.8, 
          Distance[Point[ground, 1], Point[centerbar, 2]] == 3.5}]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(CoupleSystem[{bar2, bar3}, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object and finds new values for ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SolveCouple[cpsys, SetParameters \[Rule] True]\)\[LeftDoubleBracket]{
        2, 3, 4}\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({bar2 \[Rule] 0.679022949296830446`, bar3 \[Rule] 2.94932644888197259`, 
      bar4 \[Rule] 3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This shows that the desired conditions have been satisfied."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({First[Location[centerbar, 3]], 
        Distance[Point[ground, 1], Point[centerbar, 2]]} /. SolveMech[0.1]\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.800000000000463984`, 3.49999999999412336`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "In all the preceding examples, the value of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at which the coupled model has been solved has been taken from the \
default initial guess list. The ",
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to explicitly set the value of time in the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, or to specify that time is a dependent variable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the value of time at which the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is to be solved or to cause time to be treated as an unknown. \n\n",
  StyleBox["Time->",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["t",
    FontSlant->"Italic"],
  " is used to set the value of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = ",
  StyleBox["t",
    FontSlant->"Italic"],
  " at which the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is solved. \n\n",
  StyleBox["Time->None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to set time to the current value of time from the default initial \
guesses, ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", if the model has any time dependency.\n\n",
  StyleBox["Time->Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to omit the time specification so that time becomes a dependent \
variable to be solved for. If ",
  StyleBox["Time->Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " requires that one extra equation be given to constrain the resulting \
extra degree of freedom."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Instead of fixing time at 0.1, time can be a dependent variable to be \
solved for. The following example seeks the values of ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that satisfy the same pair of conditions that were used in the previous \
example."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The parameter ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is reset to its original value before building the new ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[bar3 \[Rule] 3]; \)\), 
    \(cpsys = 
      SetCouple[{bar2}, {
          \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
              \[RightDoubleBracket] == 0.8, 
          Distance[Point[ground, 1], Point[centerbar, 2]] == 3.5}, 
        Time \[Rule] Free]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CoupleSystem[{bar2}, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the solution for ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((sol = SolveCouple[cpsys])\)\[LeftDoubleBracket]{1, 2, 3, 4}
        \[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0.118480358767163895`, bar2 \[Rule] 0.602986370869984611`, 
      bar3 \[Rule] 3, bar4 \[Rule] 3}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The desired conditions are satisfied."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(Location[centerbar, 3]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
        Distance[Point[ground, 1], Point[centerbar, 2]]} /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.8`, 3.5`}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph = Graphics[{Thickness[.02],PointSize[.035],\n(* Ground *)\n  \
{Line[{{-1,-1.5},{0,0},{1,-1.5},{-2,-1.5},{-2,3}}]},\n(* Drive Bar *) \
{RGBColor[1,0,0],\n  Edge[drivebar, {1, 2}],\n  \
Circle[Location[drivebar,1],.5] }, \n(* Driven Bar*) \
{RGBColor[0,0,1],Edge[drivenbar, {1, 2}] },\n(* Center Bar*) \
{Vertex[centerbar, {1,2,3}],\n                 \
RGBColor[0,1,0],Edge[centerbar, {1, 2}]}},\n  \
Frame->True,PlotRange->{{-2.4,1.4},{-1.6,4.2}},\n  AspectRatio->Automatic];"],
   "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[graph/.LastSolve[]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["SetGuess[];\npostab = SolveMech[{0,1},16];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"locus3:=Graphics[LocusPlot[ Point[centerbar,3], postab ]]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"SetGuess[];\nShow[{graph/.SolveMech[{0.1, 0.397}],locus3}];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["9.2  Multiple Configuration Couples"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions can be used to find the values of several parameters that \
simultaneously satisfy several geometric conditions at different \
configurations of the model, at different points in time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Solving for Two Parameters"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetCouple[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, ..., symn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eqs1, ",
    FontSlant->"Italic"],
  StyleBox["options1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eqs2, ",
    FontSlant->"Italic"],
  StyleBox["options2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" ..., options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that seeks the values of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " ",
  StyleBox["symi",
    FontSlant->"Italic"],
  " that satisfy the ",
  StyleBox["eqsi",
    FontSlant->"Italic"],
  " at several different points in time, or different configurations of the \
mechanism. Each ",
  StyleBox["eqsi",
    FontSlant->"Italic"],
  " must be an equation or list of equations, and the total number of \
equations must be equal to ",
  StyleBox["n",
    FontSlant->"Italic"],
  " plus the number of occurrences of ",
  StyleBox["Time->Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the",
  StyleBox[" optionsi",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes the constraint equations to be compiled. The default setting \
is ",
  StyleBox["Compiled->False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"],
  "\n\n",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify initial guesses for each different mechanism \
configuration. The default setting for ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is ",
    FontFamily->"Times"],
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the value of time at each different \
configuration. The default setting, ",
  StyleBox["Time->None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", takes the value of time from the current default initial guess list."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Building coupled systems across multiple configurations."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options are used somewhat differently than standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " option usage because one specification for time and one set of initial \
guesses must be given for each separate mechanism configuration. The ",
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option must be specified for a multiple configuration ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because the default setting sets the value of time to be the same for all \
configurations, making all configurations identical. Since the ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option applies to the entire ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", it can appear in any part of the ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command.\n\nThe following example uses the four-bar model that was \
developed in the preceding section. A coupled system is used to adjust the \
lengths of both the drive and driven bars so as to meet two geometric \
conditions that are satisfied at two different points in time. The ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 on the center bar is set to 0.8 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1, and the distance from the global origin to point 2 on the center \
bar is set to 3.8 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3.\n\nBecause the coupled system is simultaneously solved in two \
different mechanism configurations, the same initial guess for both \
configurations may not be acceptable. Therefore, the ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to explicitly specify initial guesses for each \
configuration."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are two initial guesses for the two configurations."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SetGuess[]; \)\), 
    \(\(guess1 = SolveMech[0.1]; \)\), 
    \(\(guess2 = SolveMech[0.3]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are parts of the two conditions at the two initial configurations."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(Location[centerbar, 3]\)\[LeftDoubleBracket]1
          \[RightDoubleBracket] /. guess1, 
      Distance[Point[ground, 1], Point[centerbar, 2]] /. guess2}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.834639986623104945`, 3.53916681000478261`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cpsys = 
      SetCouple[{bar2, bar3}, {
          \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
              \[RightDoubleBracket] == 0.8, Time \[Rule] 0.1, 
          InitialGuess \[Rule] guess1}, {
          Distance[Point[ground, 1], Point[centerbar, 2]] == 3.8, 
          Time \[Rule] 0.3, InitialGuess \[Rule] guess2}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "A ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that spans multiple configurations has a unique solution at each \
configuration. Thus, ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a nested list of solution rules with each list corresponding to \
one configuration of the mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object and finds new values for ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = SolveCouple[cpsys]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 0.965873549088972893`\), ",", 
            \(bar3 \[Rule] 2.86606168716793163`\), ",", \(bar4 \[Rule] 3\), 
            ",", \(X2 \[Rule] 0.`\), ",", \(Y2 \[Rule] 0.`\), ",", 
            \(Th2 \[Rule] 0.628318530717958623`\), ",", 
            \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
            \(Th3 \[Rule] 0.199358532805639203`\), ",", 
            \(X4 \[Rule] 0.781408115630224031`\), ",", 
            \(Y4 \[Rule] 0.567726227733888233`\), ",", 
            \(Th4 \[Rule] \(-0.00929607607419090165`\)\)}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.3`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 0.965873549088972893`\), ",", 
            \(bar3 \[Rule] 2.86606168716793163`\), ",", \(bar4 \[Rule] 3\), 
            ",", \(X2 \[Rule] 0.`\), ",", \(Y2 \[Rule] 0.`\), ",", 
            \(Th2 \[Rule] 1.88495559215387586`\), ",", 
            \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
            \(Th3 \[Rule] 0.254053494448249139`\), ",", 
            \(X4 \[Rule] \(-0.298471341085737549`\)\), ",", 
            \(Y4 \[Rule] 0.918600332778194506`\), ",", 
            \(Th4 \[Rule] \(-0.365602841187449101`\)\)}], "}"}]}], "}"}]], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This shows that the desired condition is satisfied."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(Location[centerbar, 3]\)\[LeftDoubleBracket]1
          \[RightDoubleBracket] /. 
        sol\[LeftDoubleBracket]1\[RightDoubleBracket], 
      Distance[Point[ground, 1], Point[centerbar, 2]] /. 
        sol\[LeftDoubleBracket]2\[RightDoubleBracket]}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.8`, 3.79999999999999937`}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving for Multiple Parameters", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "It is possible to specify any number of geometric conditions to be \
satisfied at any number of different mechanism configurations, however, it is \
certainly not possible to satisfy any arbitrary set of conditions. A ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " built by ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may have no solution, or it may have stiff singularities at points very \
close to a valid solution, making it difficult to converge the model. The \
following example demonstrates a useful technique for slowly coaxing a model \
towards a desired solution with ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nIn the following example, a coupled system is used to find the values \
of ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["bar4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that satisfy four different geometric conditions at two different points \
in time. The ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinates of point 3 on the center bar are specified at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1, and the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinates of point 3 on the center bar are specified at an arbitrary \
time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " > 0.1, effectively specifying that point 3 on the center bar must pass \
through a given point in the global reference frame."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Here is the current location of point 3 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1 and ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[bar2 \[Rule] 1, bar3 \[Rule] 3, bar4 \[Rule] 3]; \)\), 
    \(Location[centerbar, 3] /. \((guess1 = SolveMech[0.1])\)\), 
    \(Location[centerbar, 3] /. \((guess2 = SolveMech[0.3])\)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.897969792826290635`, 2.58580612296616951`}\)], "Output"],

Cell[BoxData[
    \({0.51040341979773256`, 2.77548798522926354`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "First, a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is built that has very unambitious goals. This system simply tries to \
satisfy a set of conditions that are already approximately satisfied. Then, \
the coordinate goa",
  StyleBox["ls, ",
    FontFamily->"Times"],
  StyleBox["k1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["k2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["k3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", and ",
    FontFamily->"Times"],
  StyleBox["k4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" are",
    FontFamily->"Times"],
  " changed, slowly pulling the solution of the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " away from its original configuration."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The new parameters, ",
  StyleBox["k1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to ",
  StyleBox["k4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", are added to the parameters list."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SetParameters[k1 \[Rule] 0.90, k2 \[Rule] 2.59, k3 \[Rule] 0.51, 
      k4 \[Rule] 2.78]; \)\), 
    \(\(cpsys = 
      SetCouple[{bar2, bar3, bar4}, \n
        \t\t{{\(Location[centerbar, 3]\)\[LeftDoubleBracket]1
                \[RightDoubleBracket] == k1, 
            \(Location[centerbar, 3]\)\[LeftDoubleBracket]2
                \[RightDoubleBracket] == k2}, Time \[Rule] 0.1, 
          InitialGuess \[Rule] guess1}, {{
            \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
                \[RightDoubleBracket] == k3, 
            \(Location[centerbar, 3]\)\[LeftDoubleBracket]2
                \[RightDoubleBracket] == k4}, Time \[Rule] Free, 
          InitialGuess \[Rule] guess2}]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Note that the parameters ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["bar4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are approximately equal to their original values."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SolveCouple[cpsys]\)\[LeftDoubleBracket]{1, 2}, {1, 2, 3, 4}
        \[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 1.00687298217983256`\), ",", 
            \(bar3 \[Rule] 3.00045920610394523`\), ",", 
            \(bar4 \[Rule] 2.99732183709086932`\)}], "}"}], ",", 
        \({T \[Rule] 0.300267762156487094`, 
          bar2 \[Rule] 1.00687298217983256`, 
          bar3 \[Rule] 3.00045920610394523`, 
          bar4 \[Rule] 2.99732183709086932`}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "When ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called with a symbol that evaluates to a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object as its first argument, ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " updates the initial guesses contained within the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to the new values found to be the solution of the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Therefore, independent parameters can be slightly tweaked between \
successive runs of ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", with each run nudging the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " slightly closer to the desired solution."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The parameters are repeatedly changed and the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is re-solved."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[k1 \[Rule] 0.8]; \)\), 
    \(\(SolveCouple[cpsys]\)\[LeftDoubleBracket]{1, 2}, {1, 2, 3, 4}
        \[RightDoubleBracket]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 1.00383038951378478`\), ",", 
            \(bar3 \[Rule] 2.80731631794733349`\), ",", 
            \(bar4 \[Rule] 2.66193378591937701`\)}], "}"}], ",", 
        \({T \[Rule] 0.299737067651004363`, 
          bar2 \[Rule] 1.00383038951378478`, 
          bar3 \[Rule] 2.80731631794733349`, 
          bar4 \[Rule] 2.66193378591937701`}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[k2 \[Rule] 2.5]; \)\), 
    \(\(SolveCouple[cpsys]\)\[LeftDoubleBracket]{1, 2}, {1, 2, 3, 4}
        \[RightDoubleBracket]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 0.855597678998739752`\), ",", 
            \(bar3 \[Rule] 2.91249005860050669`\), ",", 
            \(bar4 \[Rule] 3.06524045510697584`\)}], "}"}], ",", 
        \({T \[Rule] 0.256045845737691957`, 
          bar2 \[Rule] 0.855597678998739752`, 
          bar3 \[Rule] 2.91249005860050669`, 
          bar4 \[Rule] 3.06524045510697584`}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[k3 \[Rule] 0.4]; \)\), 
    \(\(SolveCouple[cpsys]\)\[LeftDoubleBracket]{1, 2}, {1, 2, 3, 4}
        \[RightDoubleBracket]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 0.855597678998739752`\), ",", 
            \(bar3 \[Rule] 3.05297039690722771`\), ",", 
            \(bar4 \[Rule] 3.51108638873723144`\)}], "}"}], ",", 
        \({T \[Rule] 0.271638729081413821`, 
          bar2 \[Rule] 0.855597678998739752`, 
          bar3 \[Rule] 3.05297039690722771`, 
          bar4 \[Rule] 3.51108638873723144`}\)}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[k4 \[Rule] 2.2]; \)\), 
    \(\(SolveCouple[cpsys, SetParameters \[Rule] True]\)\[LeftDoubleBracket]{
        1, 2}, {1, 2, 3, 4}\[RightDoubleBracket]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 0.85559767899873993`\), ",", 
            \(bar3 \[Rule] 2.87040230787139414`\), ",", 
            \(bar4 \[Rule] 2.86848998476354744`\)}], "}"}], ",", 
        \({T \[Rule] 0.396612426697125197`, 
          bar2 \[Rule] 0.85559767899873993`, 
          bar3 \[Rule] 2.87040230787139414`, 
          bar4 \[Rule] 2.86848998476354744`}\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the four-bar mechanism at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1 and ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.396, with the locus of point 3 on the center bar."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.52632 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.631579 0.263158 0.421053 0.263158 [
[(-2)] .10526 0 0 2 Msboxa
[(-1.5)] .23684 0 0 2 Msboxa
[(-1)] .36842 0 0 2 Msboxa
[(-0.5)] .5 0 0 2 Msboxa
[(0)] .63158 0 0 2 Msboxa
[(0.5)] .76316 0 0 2 Msboxa
[(1)] .89474 0 0 2 Msboxa
[(-1)] -0.0125 .15789 1 0 Msboxa
[(0)] -0.0125 .42105 1 0 Msboxa
[(1)] -0.0125 .68421 1 0 Msboxa
[(2)] -0.0125 .94737 1 0 Msboxa
[(3)] -0.0125 1.21053 1 0 Msboxa
[(4)] -0.0125 1.47368 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.52732 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.10526 0 m
.10526 .00625 L
s
P
[(-2)] .10526 0 0 2 Mshowa
p
.002 w
.23684 0 m
.23684 .00625 L
s
P
[(-1.5)] .23684 0 0 2 Mshowa
p
.002 w
.36842 0 m
.36842 .00625 L
s
P
[(-1)] .36842 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(-0.5)] .5 0 0 2 Mshowa
p
.002 w
.63158 0 m
.63158 .00625 L
s
P
[(0)] .63158 0 0 2 Mshowa
p
.002 w
.76316 0 m
.76316 .00625 L
s
P
[(0.5)] .76316 0 0 2 Mshowa
p
.002 w
.89474 0 m
.89474 .00625 L
s
P
[(1)] .89474 0 0 2 Mshowa
p
.001 w
.13158 0 m
.13158 .00375 L
s
P
p
.001 w
.15789 0 m
.15789 .00375 L
s
P
p
.001 w
.18421 0 m
.18421 .00375 L
s
P
p
.001 w
.21053 0 m
.21053 .00375 L
s
P
p
.001 w
.26316 0 m
.26316 .00375 L
s
P
p
.001 w
.28947 0 m
.28947 .00375 L
s
P
p
.001 w
.31579 0 m
.31579 .00375 L
s
P
p
.001 w
.34211 0 m
.34211 .00375 L
s
P
p
.001 w
.39474 0 m
.39474 .00375 L
s
P
p
.001 w
.42105 0 m
.42105 .00375 L
s
P
p
.001 w
.44737 0 m
.44737 .00375 L
s
P
p
.001 w
.47368 0 m
.47368 .00375 L
s
P
p
.001 w
.52632 0 m
.52632 .00375 L
s
P
p
.001 w
.55263 0 m
.55263 .00375 L
s
P
p
.001 w
.57895 0 m
.57895 .00375 L
s
P
p
.001 w
.60526 0 m
.60526 .00375 L
s
P
p
.001 w
.65789 0 m
.65789 .00375 L
s
P
p
.001 w
.68421 0 m
.68421 .00375 L
s
P
p
.001 w
.71053 0 m
.71053 .00375 L
s
P
p
.001 w
.73684 0 m
.73684 .00375 L
s
P
p
.001 w
.78947 0 m
.78947 .00375 L
s
P
p
.001 w
.81579 0 m
.81579 .00375 L
s
P
p
.001 w
.84211 0 m
.84211 .00375 L
s
P
p
.001 w
.86842 0 m
.86842 .00375 L
s
P
p
.001 w
.07895 0 m
.07895 .00375 L
s
P
p
.001 w
.05263 0 m
.05263 .00375 L
s
P
p
.001 w
.02632 0 m
.02632 .00375 L
s
P
p
.001 w
.92105 0 m
.92105 .00375 L
s
P
p
.001 w
.94737 0 m
.94737 .00375 L
s
P
p
.001 w
.97368 0 m
.97368 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .15789 m
.00625 .15789 L
s
P
[(-1)] -0.0125 .15789 1 0 Mshowa
p
.002 w
0 .42105 m
.00625 .42105 L
s
P
[(0)] -0.0125 .42105 1 0 Mshowa
p
.002 w
0 .68421 m
.00625 .68421 L
s
P
[(1)] -0.0125 .68421 1 0 Mshowa
p
.002 w
0 .94737 m
.00625 .94737 L
s
P
[(2)] -0.0125 .94737 1 0 Mshowa
p
.002 w
0 1.21053 m
.00625 1.21053 L
s
P
[(3)] -0.0125 1.21053 1 0 Mshowa
p
.002 w
0 1.47368 m
.00625 1.47368 L
s
P
[(4)] -0.0125 1.47368 1 0 Mshowa
p
.001 w
0 .21053 m
.00375 .21053 L
s
P
p
.001 w
0 .26316 m
.00375 .26316 L
s
P
p
.001 w
0 .31579 m
.00375 .31579 L
s
P
p
.001 w
0 .36842 m
.00375 .36842 L
s
P
p
.001 w
0 .47368 m
.00375 .47368 L
s
P
p
.001 w
0 .52632 m
.00375 .52632 L
s
P
p
.001 w
0 .57895 m
.00375 .57895 L
s
P
p
.001 w
0 .63158 m
.00375 .63158 L
s
P
p
.001 w
0 .73684 m
.00375 .73684 L
s
P
p
.001 w
0 .78947 m
.00375 .78947 L
s
P
p
.001 w
0 .84211 m
.00375 .84211 L
s
P
p
.001 w
0 .89474 m
.00375 .89474 L
s
P
p
.001 w
0 1 m
.00375 1 L
s
P
p
.001 w
0 1.05263 m
.00375 1.05263 L
s
P
p
.001 w
0 1.10526 m
.00375 1.10526 L
s
P
p
.001 w
0 1.15789 m
.00375 1.15789 L
s
P
p
.001 w
0 1.26316 m
.00375 1.26316 L
s
P
p
.001 w
0 1.31579 m
.00375 1.31579 L
s
P
p
.001 w
0 1.36842 m
.00375 1.36842 L
s
P
p
.001 w
0 1.42105 m
.00375 1.42105 L
s
P
p
.001 w
0 .10526 m
.00375 .10526 L
s
P
p
.001 w
0 .05263 m
.00375 .05263 L
s
P
p
.001 w
0 0 m
.00375 0 L
s
P
p
.002 w
0 0 m
0 1.52632 L
s
P
P
p
p
.002 w
.10526 1.52007 m
.10526 1.52632 L
s
P
p
.002 w
.23684 1.52007 m
.23684 1.52632 L
s
P
p
.002 w
.36842 1.52007 m
.36842 1.52632 L
s
P
p
.002 w
.5 1.52007 m
.5 1.52632 L
s
P
p
.002 w
.63158 1.52007 m
.63158 1.52632 L
s
P
p
.002 w
.76316 1.52007 m
.76316 1.52632 L
s
P
p
.002 w
.89474 1.52007 m
.89474 1.52632 L
s
P
p
.001 w
.13158 1.52257 m
.13158 1.52632 L
s
P
p
.001 w
.15789 1.52257 m
.15789 1.52632 L
s
P
p
.001 w
.18421 1.52257 m
.18421 1.52632 L
s
P
p
.001 w
.21053 1.52257 m
.21053 1.52632 L
s
P
p
.001 w
.26316 1.52257 m
.26316 1.52632 L
s
P
p
.001 w
.28947 1.52257 m
.28947 1.52632 L
s
P
p
.001 w
.31579 1.52257 m
.31579 1.52632 L
s
P
p
.001 w
.34211 1.52257 m
.34211 1.52632 L
s
P
p
.001 w
.39474 1.52257 m
.39474 1.52632 L
s
P
p
.001 w
.42105 1.52257 m
.42105 1.52632 L
s
P
p
.001 w
.44737 1.52257 m
.44737 1.52632 L
s
P
p
.001 w
.47368 1.52257 m
.47368 1.52632 L
s
P
p
.001 w
.52632 1.52257 m
.52632 1.52632 L
s
P
p
.001 w
.55263 1.52257 m
.55263 1.52632 L
s
P
p
.001 w
.57895 1.52257 m
.57895 1.52632 L
s
P
p
.001 w
.60526 1.52257 m
.60526 1.52632 L
s
P
p
.001 w
.65789 1.52257 m
.65789 1.52632 L
s
P
p
.001 w
.68421 1.52257 m
.68421 1.52632 L
s
P
p
.001 w
.71053 1.52257 m
.71053 1.52632 L
s
P
p
.001 w
.73684 1.52257 m
.73684 1.52632 L
s
P
p
.001 w
.78947 1.52257 m
.78947 1.52632 L
s
P
p
.001 w
.81579 1.52257 m
.81579 1.52632 L
s
P
p
.001 w
.84211 1.52257 m
.84211 1.52632 L
s
P
p
.001 w
.86842 1.52257 m
.86842 1.52632 L
s
P
p
.001 w
.07895 1.52257 m
.07895 1.52632 L
s
P
p
.001 w
.05263 1.52257 m
.05263 1.52632 L
s
P
p
.001 w
.02632 1.52257 m
.02632 1.52632 L
s
P
p
.001 w
.92105 1.52257 m
.92105 1.52632 L
s
P
p
.001 w
.94737 1.52257 m
.94737 1.52632 L
s
P
p
.001 w
.97368 1.52257 m
.97368 1.52632 L
s
P
p
.002 w
0 1.52632 m
1 1.52632 L
s
P
p
.002 w
.99375 .15789 m
1 .15789 L
s
P
p
.002 w
.99375 .42105 m
1 .42105 L
s
P
p
.002 w
.99375 .68421 m
1 .68421 L
s
P
p
.002 w
.99375 .94737 m
1 .94737 L
s
P
p
.002 w
.99375 1.21053 m
1 1.21053 L
s
P
p
.002 w
.99375 1.47368 m
1 1.47368 L
s
P
p
.001 w
.99625 .21053 m
1 .21053 L
s
P
p
.001 w
.99625 .26316 m
1 .26316 L
s
P
p
.001 w
.99625 .31579 m
1 .31579 L
s
P
p
.001 w
.99625 .36842 m
1 .36842 L
s
P
p
.001 w
.99625 .47368 m
1 .47368 L
s
P
p
.001 w
.99625 .52632 m
1 .52632 L
s
P
p
.001 w
.99625 .57895 m
1 .57895 L
s
P
p
.001 w
.99625 .63158 m
1 .63158 L
s
P
p
.001 w
.99625 .73684 m
1 .73684 L
s
P
p
.001 w
.99625 .78947 m
1 .78947 L
s
P
p
.001 w
.99625 .84211 m
1 .84211 L
s
P
p
.001 w
.99625 .89474 m
1 .89474 L
s
P
p
.001 w
.99625 1 m
1 1 L
s
P
p
.001 w
.99625 1.05263 m
1 1.05263 L
s
P
p
.001 w
.99625 1.10526 m
1 1.10526 L
s
P
p
.001 w
.99625 1.15789 m
1 1.15789 L
s
P
p
.001 w
.99625 1.26316 m
1 1.26316 L
s
P
p
.001 w
.99625 1.31579 m
1 1.31579 L
s
P
p
.001 w
.99625 1.36842 m
1 1.36842 L
s
P
p
.001 w
.99625 1.42105 m
1 1.42105 L
s
P
p
.001 w
.99625 .10526 m
1 .10526 L
s
P
p
.001 w
.99625 .05263 m
1 .05263 L
s
P
p
.001 w
.99625 0 m
1 0 L
s
P
p
.002 w
1 0 m
1 1.52632 L
s
P
P
p
P
0 0 m
1 0 L
1 1.52632 L
0 1.52632 L
closepath
clip
newpath
p
p
p
.02 w
.36842 .02632 m
.63158 .42105 L
.89474 .02632 L
.10526 .02632 L
.10526 1.21053 L
s
P
p
1 0 0 r
p
.02 w
.63158 .42105 m
.81374 .5534 L
s
P
.02 w
newpath
.63158 .42105 .13158 0 365.73 arc
s
P
p
0 0 1 r
p
.02 w
.10526 1.21053 m
.85442 1.30717 L
s
P
P
p
p
.035 w
.81374 .5534 Mdot
.85442 1.30717 Mdot
.84211 1.07895 Mdot
P
0 1 0 r
p
.02 w
.81374 .5534 m
.85442 1.30717 L
s
P
P
P
p
p
.02 w
.36842 .02632 m
.63158 .42105 L
.89474 .02632 L
.10526 .02632 L
.10526 1.21053 L
s
P
p
1 0 0 r
p
.02 w
.63158 .42105 m
.45195 .55681 L
s
P
.02 w
newpath
.63158 .42105 .13158 0 365.73 arc
s
P
p
0 0 1 r
p
.02 w
.10526 1.21053 m
.8604 1.19162 L
s
P
P
p
p
.035 w
.45195 .55681 Mdot
.8604 1.19162 Mdot
.73673 .99942 Mdot
P
0 1 0 r
p
.02 w
.45195 .55681 m
.8604 1.19162 L
s
P
P
P
.004 w
.8589 .94736 m
.85207 1.03874 L
.82907 1.1126 L
.79943 1.15225 L
.77352 1.1446 L
.75417 1.0869 L
.73587 .99494 L
.71697 .89635 L
.70405 .81165 L
.70372 .74952 L
.71808 .71327 L
.74533 .70522 L
.78082 .72717 L
.8174 .77887 L
.84615 .85571 L
.8589 .94736 L
s
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{188, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002l00017a000`40O003h00O_7oo002lOol00;ao
o`00_7oo002lOol001moo`<000ioo`D0009oo`03001oogoo009oo`03001oogoo00eoo`D000moo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00eoo`D0019oo`007goo00<007ooOol047oo00<007ooOol01Woo00<0
07oo000047oo00<007ooOol03Woo00<007oo00001goo00<007oo000037oo00<007oo00003goo00<0
07oo00001goo00<007oo000047oo00<007ooOol04Woo000JOol30003Ool00`00Oomoo`09Ool30003
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool30003Ool00`00Oomoo`09Ool30002Ool00`00Ool00009
Ool00`00Oomoo`0:Ool00`00Ool0000?Ool00`00Ool00009Ool00`00Oomoo`0>Ool00`00Oomoo`0B
Ool0021oo`03001oogoo00moo`03001oogoo00Ioo`80015oo`03001oogoo00ioo`03001oo`0000Mo
o`8000eoo`03001oo`0000moo`03001oo`0000Moo`80015oo`03001oogoo019oo`007goo00<007oo
000047oo00<007ooOol01Woo00<007ooOol047oo00<007ooOol03Woo00<007oo00001goo00<007oo
Ool037oo00<007oo00003goo00<007oo00001goo00<007ooOol047oo00<007ooOol04Woo000POol0
0`00Oomoo`0>Ool20008Ool3000?Ool2000AOol00`00Oomoo`06Ool3000=Ool00`00Oomoo`0?Ool0
0`00Oomoo`06Ool3000?Ool2000DOol00;aoo`00_7oo002lOol00;aoo`00_7oo002lOol00;aoo`00
_7oo000<Oon_0001Ool000aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo0000
17oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool0
1@00Oomoogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00001Ool0
00aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`0>
Oon=000@Ool10001Ool000aoo`03001oogoo00ioohd0011oo`40005oo`0037oo00<007ooOol03Woo
S@0047oo0@000Goo000<Ool00`00Oomoo`0>Ool3000/Ool4001EOol4000AOol10001Ool000aoo`03
001oogoo00ioo`<002eoo`<005Eoo`<0019oo`40005oo`0037oo00<007ooOol03Woo0`00;Goo1000
Dgoo10004Woo0@000Goo000<Ool00`00Oomoo`0>Ool3000^Ool4001AOol4000COol10001Ool000ao
o`03001oogoo00ioo`<002moo`<0055oo`<001Aoo`40005oo`0037oo00<007ooOol03Woo0`00;goo
1000Cgoo100057oo0@000Goo000<Ool00`00Oomoo`0>Ool3000`Ool4001=Ool4000EOol10001Ool0
00aoo`03001oogoo00ioo`<0035oo`<004eoo`<001Ioo`40005oo`0037oo00<007ooOol03Woo0`00
<Goo1000Bgoo10005Woo0@000Goo000<Ool00`00Oomoo`0>Ool3000bOol40019Ool4000GOol10001
Ool000aoo`03001oogoo00ioo`<003=oo`<004Uoo`<001Qoo`40005oo`0037oo00<007ooOol03Woo
0`00<goo1000Agoo100067oo0@000Goo000<Ool00`00Oomoo`0>Ool3000dOol40015Ool4000IOol1
0001Ool000aoo`03001oogoo00ioo`<003Eoo`<004Eoo`<001Yoo`40005oo`0037oo00<007ooOol0
3Woo0`00=Goo1000@goo10006Woo0@000Goo000<Ool00`00Oomoo`0>Ool3000fOol40011Ool4000K
Ool10001Ool000aoo`03001oogoo00ioo`<003Moo`<0045oo`<001aoo`40005oo`0037oo00<007oo
Ool03Woo0`00=goo1000?goo100077oo0@000Goo000<Ool00`00Oomoo`0>Ool3000hOol4000mOol4
000MOol10001Ool000Eoo`D0009oo`03001oogoo00ioo`<003Uoo`<003eoo`<001ioo`40005oo`00
1goo00<007ooOol00Woo00<007ooOol03Woo0`00>Goo1000>goo10007Woo0@000Goo000017oo0000
00000goo00<007ooOol00Woo0P003goo0`00>Woo1000>Goo10007Woo0P000Goo0007Ool00`00Oomo
o`02Ool00`00Oomoo`0>Ool3000kOol3000iOol3000POol10001Ool000Moo`03001oogoo009oo`03
001oogoo00ioo`<003]oo`@003Moo`@0021oo`40005oo`001Woo0P0017oo00<007ooOol03Woo0`00
?7oo1000=Goo10008Goo0@000Goo000<Ool00`00Oomoo`0>Ool3000mOol3000eOol3000ROol10001
Ool000aoo`03001oogoo00ioo`<003eoo`@003=oo`@0029oo`40005oo`0037oo00<007ooOol03Woo
0`00?Woo1000<Goo10008goo0@000Goo000<Ool00`00Oomoo`0>Ool3000oOol3000aOol3000TOol1
0001Ool000aoo`03001oogoo00ioo`<003moo`@002moo`@002Aoo`40005oo`0037oo00<007ooOol0
3Woo0`00@7oo1000;Goo10009Goo0@000Goo000<Ool00`00Oomoo`0>Ool30011Ool3000]Ool3000V
Ool10001Ool000aoo`03001oogoo00ioo`<0045oo`@002]oo`@002Ioo`40005oo`0037oo00<007oo
Ool03Woo0`00@Woo1000:Goo10009goo0@000Goo000<Ool00`00Oomoo`0>Ool30013Ool3000YOol3
000XOol10001Ool000aoo`03001oogoo00ioo`<004=oo`@002Moo`@002Qoo`40005oo`0037oo00<0
07ooOol03Woo0`00A7oo10009Goo1000:Goo0@000Goo000<Ool00`00Oomoo`0>Ool30015Ool3000U
Ool3000ZOol10001Ool000aoo`03001oogoo00ioo`<004Eoo`@002=oo`@002Yoo`40005oo`0037oo
00<007ooOol03Woo0`00AWoo10008Goo1000:goo0@000Goo000<Ool00`00Oomoo`0>Ool30017Ool3
000QOol3000/Ool10001Ool000aoo`03001oogoo00ioo`<004Moo`@001moo`@002aoo`40005oo`00
37oo00<007ooOol03Woo0`00B7oo10007Goo1000;Goo0@000Goo000<Ool00`00Oomoo`0>Ool30019
Ool30008Ool<O009Ool3000^Ool10001Ool000aoo`03001oogoo00ioo`<004Uoo`@000Eooa9l00Ao
o`@002ioo`40005oo`0037oo00<007ooOol03Woo0`00BWoo100067`000=oo`0000000P00;goo0@00
0Goo000<Ool00`00Oomoo`0>Ool3001;Ool20008O00:Ool9O002000`Ool10001Ool000aoo`03001o
ogoo00ioo`<004]oo`Ql011oo`El0080031oo`40005oo`0037oo00<007ooOol03Woo0`00BWoo1W`0
5Goo1G`0<7oo0@000Goo000<Ool00`00Oomoo`0>Ool30019Ool6O0000`00Oomoo`0COol00`00O01l
0004O00^Ool10001Ool000aoo`03001oogoo00ioo`<004Qoo`El00@001=oo`<000El02ioo`40005o
o`0037oo00<007ooOol03Woo0`00Agoo17`00goo10004Goo100000=oog`0O00017`0;7oo0@000Goo
000<Ool00`00Oomoo`0>Ool30017Ool4O004Ool3000AOol30004Ool4O00/Ool10001Ool000aoo`03
001oogoo00ioo`<004Ioo`Al00Eoo`@000moo`@000Eoo`Al02]oo`40005oo`0037oo00<007ooOol0
3Woo0`00AGoo1G`01Woo10003Goo10001goo0g`0:goo0@000Goo000<Ool00`00Oomoo`0>Ool30014
Ool4O009Ool3000=Ool30008Ool4O00ZOol10001Ool000aoo`03001oogoo00ioo`<004Aoo`Al00Uo
o`@000]oo`@000Uoo`=l02Yoo`40005oo`0037oo00<007ooOol03Woo0`00A7oo0g`02goo10002Goo
10002Woo17`0:Goo0@000Goo000<Ool00`00Oomoo`0>Ool30013Ool4O00<Ool30009Ool3000<Ool3
O00YOol10001Ool000aoo`03001oogoo00ioo`<004=oo`=l00eoo`@000Moo`@000aoo`Al02Qoo`40
005oo`0037oo00<007ooOol03Woo0`00@goo0g`03Woo10001Goo10003Woo0g`0:7oo0@000Goo000<
Ool00`00Oomoo`0>Ool30013Ool3O00?Ool30005Ool3000?Ool4O00WOol10001Ool000aoo`03001o
ogoo00ioo`<0049oo`Al00moo`@000=oo`@0011oo`=l02Moo`40005oo`0037oo00<007ooOol03Woo
0`00@Woo0g`04Goo100000=oo`0000000P004Goo0g`09goo0@000Goo000<Ool00`00Oomoo`0>Ool3
0012Ool3O00BOol3000017oo000000004Woo0g`09goo0@000Goo0007Ool00`00Oomoo`02Ool00`00
Oomoo`0>Ool30012Ool3O00BOol7000BOol3O00WOol10001Ool000Ioo`03001oo`0000=oo`03001o
ogoo00ioo`<0049oo`=l01=oo`05001l07`0O000000COol3O00WOol10001Ool000Ioo`03001oo`00
00=oo`8000moo`<0049oo`=l01=oo`El01=oo`=l02Ioo`80005oo`001Woo00<007oo00000goo00<0
07ooOol03Woo0`00@Woo0g`04Woo1g`04Woo0g`09goo0@000Goo0006Ool00`00Ool00003Ool00`00
Oomoo`0>Ool30012Ool3O00@Ool5O0000gooO01l0003O00@Ool3O00WOol10001Ool000Moo`03001o
ogoo009oo`03001oogoo00ioo`<0049oo`=l00moo`El00=oo`El00moo`=l02Moo`40005oo`0037oo
00<007ooOol03Woo0`00@Woo17`03Goo1G`01Goo1W`03Goo0g`09goo0@000Goo000<Ool00`00Oomo
o`0>Ool30013Ool3O00;Ool5O009Ool5O00;Ool4O00WOol10001Ool000aoo`03001oogoo00ioo`<0
04=oo`=l00Yoo`El00]oo`El00Yoo`=l02Qoo`40005oo`0037oo00<007ooOol03Woo0`00@goo0g`0
2Goo1G`03Woo1G`01goo17`0:7oo0@000Goo000<Ool00`00Oomoo`0>Ool30013Ool3O007Ool5O00A
Ool5O006Ool3O00YOol10001Ool000aoo`03001oogoo00ioo`<004=oo`Al00Eoo`El01=oo`Il00Ao
o`=l02Uoo`40005oo`0037oo00<007ooOol03Woo0`00A7oo0g`00goo1W`05Woo1G`00Woo17`0:Goo
0@000Goo000<Ool00`00Oomoo`0>Ool30014Ool4O0000gooO01l0003O00IOol5O00017ooO01l07`0
:Woo0@000Goo000<Ool00`00Oomoo`0>Ool30014Ool9O00LOol7O00ZOol10001Ool000aoo`03001o
ogoo00ioo`<004Eoo`Il01moo`El02]oo`40005oo`0037oo00<007ooOol03Woo0`00AGoo1G`087oo
1g`0:Goo0@000Goo000<Ool00`00Oomoo`0>Ool30014Ool7O00NOol9O00XOol10001Ool000aoo`03
001oogoo00ioo`<0049oo`El0003Ooml07`000=l01]oo`Al009oo`El02Moo`40005oo`0037oo00<0
07ooOol03Woo0`00@Goo1G`00goo1W`067oo17`01Goo1G`09Goo0@000Goo000<Ool00`00Oomoo`0>
Ool30010Ool5O005Ool5O00FOol5O007Ool5O00TOol10001Ool000aoo`03001oogoo00ioo`<003io
o`El00Qoo`El01=oo`Ml00Qoo`El02=oo`40005oo`0037oo00<007ooOol03Woo0`00?Goo1G`02goo
27`037oo1g`037oo1G`08Goo0@000Goo000<Ool00`00Oomoo`0>Ool3000lOol5O00<Ool<O004Ool9
O00?Ool4O0000`00Oomoo`0NOol10001Ool000aoo`03001oogoo00ioo`<003Yoo`<3h09l011ooaEl
019oo`9l00040003h0?P0n0NOol10001Ool000aoo`03001oogoo00ioo`<003Uoo`050003h0?P0n1l
000FOol>O00EOol200030n0NOol10001Ool000aoo`03001oogoo00ioo`<003Qoo`8000@3h1Yoo`Il
01Yoo`040003h0?P0n0NOol10001Ool000aoo`03001oogoo00ioo`<003Uoo`8000@3h3Yoo`<3h1io
o`40005oo`0037oo00<007ooOol03Woo0`00>Woo00<007oo0n000P?P>Woo0`?P7Woo0@000Goo000<
Ool00`00Oomoo`0>Ool3000lOol40n0iOol30n0NOol10001Ool000aoo`03001oogoo00ioo`<003eo
o`@3h3Qoo`<3h1ioo`40005oo`0037oo00<007ooOol03Woo0`00?Woo0`?P>7oo0`?P7Woo0@000Goo
000<Ool00`00Oomoo`0>Ool3000nOol40n0gOol30n0NOol10001Ool000aoo`03001oogoo00ioo`<0
03moo`<3h3Moo`<3h1ioo`40005oo`0037oo00<007ooOol03Woo0`00?goo10?P=Woo0`?P7Woo0@00
0Goo000<Ool00`00Oomoo`0>Ool30010Ool40n0fOol30n0MOol10001Ool000aoo`03001oogoo00io
o`<0045oo`<3h3Ioo`<3h1eoo`40005oo`0037oo00<007ooOol03Woo0`00@Goo10?P=Goo0`?P7Goo
0@000Goo000<Ool00`00Oomoo`0>Ool30012Ool40n0dOol30n0MOol10001Ool000aoo`03001oogoo
00ioo`<004=oo`<3h3Aoo`<3h1eoo`40005oo`0037oo00<007ooOol03Woo0`00@goo10?P<goo0`?P
7Goo0@000Goo000<Ool00`00Oomoo`0>Ool30014Ool40n0bOol30n0MOol10001Ool000aoo`03001o
ogoo00ioo`<004Eoo`<3h39oo`<3h1eoo`40005oo`0037oo00<007ooOol03Woo0`00AGoo10?P<Goo
0`?P7Goo0@000Goo000<Ool00`00Oomoo`0>Ool30016Ool30n0aOol30n0MOol10001Ool000aoo`03
001oogoo00ioo`<004Ioo`@3h31oo`<3h1eoo`40005oo`001Goo1@000Woo00<007ooOol03Woo0`00
Agoo10?P;goo0`?P7Goo0@000Goo0007Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool30018Ool30n0_
Ool30n0MOol10001Ool000Moo`03001oogoo009oo`8000moo`<004Qoo`@3h2ioo`<3h1aoo`80005o
o`001goo00<007ooOol00Woo00<007ooOol03Woo0`00BGoo10?P;Goo0`?P7Goo0@000Goo0007Ool0
0`00Oomoo`02Ool00`00Oomoo`0>Ool3001:Ool30n0]Ool30n0MOol10001Ool000Ioo`8000Aoo`03
001oogoo00ioo`<004Yoo`@3h1moo`8000]oo`<3h1eoo`40005oo`0037oo00<007ooOol03Woo0`00
Bgoo10?P77oo0P000Woo0P002Goo0`?P7Goo0@000Goo000<Ool00`00Oomoo`0>Ool3001<Ool30n0J
Ool20006Ool00`00Oomoo`07Ool30n0LOol10001Ool000aoo`03001oogoo00ioo`<004aoo`@3h1Uo
o`03001oogoo00Ioo`8000Moo`<3h1aoo`40005oo`0037oo00<007ooOol03Woo0`00CGoo10?P5goo
00<007ooOol02Goo00<007ooOol017oo0`?P77oo0@000Goo000<Ool00`00Oomoo`0>Ool3001>Ool3
0n0GOol00`00Oomoo`0:Ool00`00Oomoo`03Ool30n0LOol10001Ool000aoo`03001oogoo00ioo`<0
04ioo`@3h1Ioo`03001oogoo00Yoo`03001oogoo00=oo`<3h1aoo`40005oo`0037oo00<007ooOol0
3Woo0`00Cgoo0`?P5Goo00<007ooOol037oo00<007ooOol00Woo0`?P77oo0@000Goo000<Ool00`00
Oomoo`0>Ool3001?Ool40n0DOol00`00Oomoo`0=Ool01000Oomoogoo0`?P77oo0@000Goo000<Ool0
0`00Oomoo`0>Ool3001@Ool40n0COol00`00Oomoo`0=Ool01000Oomoogoo0`?P77oo0@000Goo000<
Ool00`00Oomoo`0>Ool3001AOol30n0COol00`00Oomoo`0>Ool00`00Oomoo`030n0LOol10001Ool0
00aoo`03001oogoo00ioo`<0055oo`@3h19oo`03001oogoo00moo`03001oo`?P0083h1aoo`40005o
o`0037oo00<007ooOol03Woo0`00DWoo10?P4Goo00<007ooOol03goo00<007oo0n000P?P77oo0@00
0Goo000<Ool00`00Oomoo`0>Ool3001COol30n0AOol00`00Oomoo`0@Ool010000n03h0?P77oo0@00
0Goo000<Ool00`00Oomoo`0>Ool3001COol40n0@Ool00`00Oomoo`0@Ool010000n03h0?P77oo0@00
0Goo000<Ool00`00Oomoo`0>Ool3001DOol40n0?Ool00`00Oomoo`0AOol00`000n03h00LOol10001
Ool000aoo`03001oogoo00ioo`<005Eoo`<3h0moo`03001oogoo015oo`030003h0?P01aoo`40005o
o`0037oo00<007ooOol03Woo0`00EGoo10?P3Woo00<007ooOol04Goo00<000?P0n0077oo0@000Goo
000<Ool00`00Oomoo`0>Ool3001FOol30n0>Ool00`00Oomoo`0AOol00`?P0003h00LOol10001Ool0
00aoo`03001oogoo00ioo`<005Ioo`@3h0eoo`03001oogoo015oo`030n0000?P01aoo`40005oo`00
37oo00<007ooOol03Woo0`00Egoo10?P37oo00<007ooOol04Goo00<3h0000n0077oo0@000Goo000<
Ool00`00Oomoo`0>Ool3001HOol30n0<Ool00`00Oomoo`0BOol00`?P0003h00KOol10001Ool000ao
o`03001oogoo00ioo`<005Qoo`@3h0]oo`03001oogoo019oo`030n0000?P01]oo`40005oo`0037oo
00<007ooOol03Woo0`00FGoo10?P2goo00<007ooOol04Goo0P?P00<007ooOol06Goo0@000Goo000<
Ool00`00Oomoo`0>Ool3001JOol30n0;Ool00`00Oomoo`0AOol20n000`00Oomoo`0IOol10001Ool0
00aoo`03001oogoo00ioo`<005Yoo`@3h0Yoo`03001oogoo015oo`83h003001oogoo01Uoo`40005o
o`0037oo00<007ooOol03Woo0`00Fgoo10?P2Goo00<007ooOol04Goo0`?P00<007ooOol067oo0@00
0Goo000<Ool00`00Oomoo`0>Ool3001LOol30n09Ool00`00Oomoo`0AOol30n000`00Oomoo`0HOol1
0001Ool000aoo`03001oogoo00ioo`<005aoo`@3h0Qoo`03001oogoo015oo`<3h003001oogoo01Qo
o`40005oo`0037oo00<007ooOol03Woo0`00GGoo0`?P27oo00<007ooOol04Goo0`?P00<007ooOol0
67oo0@000Goo000<Ool00`00Oomoo`0>Ool3001MOol40n07Ool00`00Oomoo`0AOol30n000goo001o
o`0HOol10001Ool000aoo`03001oogoo00ioo`<005ioo`@3h0Moo`03001oogoo011oo`<3h003Ool0
07oo01Qoo`40005oo`0037oo00<007ooOol03Woo0`00Ggoo0`?P1goo00<007ooOol047oo0`?P00=o
o`00Ool067oo0@000Goo000<Ool00`00Oomoo`0>Ool3001OOol40n06Ool00`00Oomoo`0@Ool30n00
0goo001oo`0HOol10001Ool000aoo`03001oogoo00ioo`<0061oo`@3h0Eoo`03001oogoo011oo`<3
h003Ool007oo01Qoo`40005oo`0037oo00<007ooOol03Woo0`00HGoo0`?P1Goo00<007ooOol047oo
0`?P00=oo`00Ool067oo0@000Goo000<Ool00`00Oomoo`0>Ool3001QOol40n04Ool00`00Oomoo`0@
Ool30n02Ool00`00Oomoo`0FOol10001Ool000aoo`03001oogoo00ioo`<0069oo`@3h0Aoo`03001o
ogoo00moo`<3h09oo`03001oogoo01Ioo`40005oo`0037oo00<007ooOol03Woo0`00Hgoo0`?P17oo
00<007ooOol03goo0`?P0Woo00<007ooOol05Woo0@000Goo000<Ool00`00Oomoo`0>Ool3001SOol4
0n03Ool00`00Oomoo`0?Ool30n02Ool00`00Oomoo`0FOol10001Ool000aoo`03001oogoo00ioo`<0
06Aoo`@3h09oo`03001oogoo011oo`<3h003Ool007oo01Moo`40005oo`001Woo0`000goo00<007oo
Ool03Woo0`00IGoo0`?P0Woo00<007ooOol047oo0`?P0Woo00<007ooOol05Goo0@000Goo0006Ool0
0`00Oomoo`03Ool00`00Oomoo`0>Ool3001UOol40n000goo001oo`0AOol30n02Ool00`00Oomoo`0E
Ool10001Ool000Moo`03001oogoo009oo`8000moo`<006Ioo`<3h09oo`03001oogoo00moo`<3h09o
o`03001oogoo01Aoo`80005oo`001goo00<007ooOol00Woo00<007ooOol03Woo0`00IWoo10?P00=o
o`00Ool047oo0`?P0Woo00<007ooOol05Goo0@000Goo0006Ool00`00Ool00003Ool00`00Oomoo`0>
Ool3001WOol40n000`00Oomoo`0?Ool30n02Ool00`00Oomoo`0EOol10001Ool000Moo`03001oogoo
009oo`03001oogoo00ioo`<006Qoo`<3h003001oogoo00moo`<3h09oo`03001oogoo01Eoo`40005o
o`0037oo00<007ooOol03Woo0`00J7oo0`?P00<007ooOol03goo0`?P00=oo`00Ool05goo0@000Goo
000<Ool00`00Oomoo`0>Ool3001YOol20n000`000n1oo`0?Ool30n000goo001oo`0GOol10001Ool0
00aoo`03001oogoo00ioo`<006Yoo`83h003001oogoo00ioo`<3h003Ool007oo01Moo`40005oo`00
37oo00<007ooOol03Woo0`00JWoo0P?P00<000?POol03Woo0`?P00=oo`00Ool05goo0@000Goo000<
Ool00`00Oomoo`0>Ool3001[Ool010?P0003h0?P3Woo0`?P00=oo`00Ool05goo0@000Goo000<Ool0
0`00Oomoo`0>Ool3001ZOol300020n0>Ool30n000goo001oo`0GOol10001Ool000aoo`03001oogoo
00ioo`<006]oo`8000<3h0eoo`<3h003Ool007oo01Moo`40005oo`0037oo00<007ooOol03Woo0`00
K7oo0P000P?P3Goo0`?P00=oo`00Ool05goo0@000Goo000<Ool00`00Oomoo`0>Ool3001]Ool01000
0n03h0?P37oo0`?P00<007ooOol05goo0@000Goo000<Ool00`00Oomoo`0>Ool3001]Ool00`000n03
h0020n0;Ool30n000`00Oomoo`0GOol10001Ool000aoo`03001oogoo00ioo`<006eoo`03001oo`?P
0083h0]oo`<3h003001oogoo01Moo`40005oo`0037oo00<007ooOol03Woo0`00KGoo00<007oo0n00
0`?P2Woo0`?P00<007ooOol05goo0@000Goo000<Ool00`00Oomoo`0>Ool3001]Ool00`00Oomoo`04
0n0:Ool20n000`00Oomoo`0GOol10001Ool000aoo`03001oogoo00ioo`<006ioo`03001oogoo00<3
h0Yoo`83h003001oogoo01Moo`40005oo`0037oo00<007ooOol03Woo0`00KWoo00<007ooOol010?P
2Goo00<3h0000n006Goo0@000Goo000<Ool00`00Oomoo`0>Ool3001^Ool01000Oomoogoo10?P27oo
00<3h0000n006Goo0@000Goo000<Ool00`00Oomoo`0>Ool3001^Ool00`00Oomoo`02Ool30n08Ool0
0`?P0003h00IOol10001Ool000aoo`03001oogoo00ioo`<006ioo`03001oogoo009oo`@3h0Moo`03
0003h0?P01Uoo`40005oo`0037oo00<007ooOol03Woo0`00Kgoo00<007ooOol00Woo10?P1Goo0P00
0P?P6Goo0@000Goo000<Ool00`00Oomoo`0>Ool3001_Ool00`00Oomoo`03Ool30n04Ool300020n0I
Ool10001Ool000aoo`03001oogoo00ioo`<006moo`03001oogoo00=oo`@3h0Aoo`040003h0?P0n0I
Ool10001Ool000aoo`03001oogoo00ioo`<006moo`03001oogoo00Aoo`<3h0Aoo`040003h0?P0n0I
Ool10001Ool000aoo`03001oogoo00ioo`<0071oo`03001oogoo00=oo`@3h0=oo`040003h0?P0n0I
Ool10001Ool000aoo`03001oogoo00ioo`<0071oo`03001oogoo00Aoo`@3h003Ool007oo00<3h1Uo
o`40005oo`0037oo00<007ooOol03Woo0`00LGoo00<007ooOol017oo0`?P00=oo`00Ool00`?P6Goo
0@000Goo000<Ool00`00Oomoo`0>Ool3001aOol00`00Oomoo`04Ool30n000`00Oomoo`030n0IOol1
0001Ool000aoo`03001oogoo00ioo`<0075oo`03001oogoo00Eoo`83h0030003h7oo00<3h1Uoo`40
005oo`0037oo00<007ooOol03Woo0`00LWoo00<007ooOol01Goo00@000?P0n1oo`<3h1Uoo`40005o
o`0037oo00<007ooOol03Woo0`00LWoo00<007ooOol017oo00<000?P0n001@?P6Goo0@000Goo000<
Ool00`00Oomoo`0>Ool3001cOol00`00Oomoo`02Ool00`00Oomoo`060n0IOol10001Ool000aoo`03
001oogoo00ioo`<007=oo`8000=oo`04001oogooOol50n0IOol10001Ool000aoo`03001oogoo00io
o`<007Eoo`<000Aoo`H3h1Qoo`40005oo`0037oo00<007ooOol03Woo0`00OGoo1@?P67oo0@000Goo
000<Ool00`00Oomoo`0>Ool3001mOol50n0HOol10001Ool000aoo`03001oogoo00ioo`<007ioo`@3
h1Qoo`40005oo`0037oo00<007ooOol03Woo0`00Ogoo0`?P67oo0@000Goo000<Ool00`00Oomoo`0>
Ool3001oOol40n0GOol10001Ool000aoo`03001oogoo00ioo`<0079oo`h07`@3h1Ioo`40005oo`00
37oo00<007ooOol03Woo0`00DGoo;`0O00@000?P0n03h1Ioo`40005oo`0037oo00<007ooOol03Woo
0`00<7ooC`0O0P000`?P5Woo0@000Goo0006Ool20004Ool00`00Oomoo`0>Ool3000?OomS01l=Ool0
10?P000000005goo0@000Goo0008Ool01@00Oomoogoo000047ooE00O;Woo0P?P00<007ooOol05Woo
0@000Goo0007Ool00`00Oomoo`02Ool2000?Oolc01m?Ool30n0GOol20001Ool000Qoo`05001oogoo
Ool0000@OolF01m/Ool30n0HOol10001Ool000Ioo`03001oo`0000=oo`03001oogoo01AooaP07fAo
o`<3h1Qoo`40005oo`001goo00<007ooOol00Woo00<007ooOol077oo600OG7oo0`?P67oo0@000Goo
000<Ool00`00Oomoo`0TOolI01mCOol30n0HOol10001Ool000aoo`03001oogoo02aooaT07d]oo`<3
h1Qoo`40005oo`0037oo00<007ooOol0=7oo6@0O@goo0`?P67oo0@000Goo000<Ool00`00Oomoo`0m
OolH01llOol30n0GOol10001Ool000aoo`03001oogoo04EooaP07cAoo`<3h1Moo`40005oo`0037oo
00<007ooOol0CGoo600O;7oo0`?P5goo0@000Goo000<Ool00`00Oomoo`1EOolI01lSOol30n0GOol1
0001Ool000aoo`03001oogoo05eooaT07a]oo`<3h1Moo`40005oo`0037oo00<007ooOol0IGoo6@0O
4goo0`?P5goo0@000Goo000<Ool00`00Oomoo`1^OolH01l;Ool30n0GOol10001Ool000aoo`03001o
ogoo07IooaP07`=oo`<3h1Moo`40005oo`0037oo00<007ooOol0OWoo4`0O0`?P5goo0@000Goo000<
Ool00`00Oomoo`26Ool:01l010000n03h0?P5goo0@000Goo000<Ool00`00Oomoo`2>Ool00`0O0000
00030n0GOol10001Ool000aoo`03001oogoo091oo`<001Qoo`40005oo`0037oo00<007ooOol0TGoo
00<007ooOol05goo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40
005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001o
ogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool0
00aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`2[
Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@000Goo000<Ool0
0`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo0@00
0Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007oo
Ool0Zgoo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`00
37oo00<007ooOol0Zgoo0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]o
o`40005oo`001goo0`000Woo00<007ooOol0Zgoo0@000Goo0008Ool01@00Oomoogoo0000[Goo0@00
0Goo0006Ool40002Ool2002[Ool20001Ool000Ioo`03001oo`0000=oo`03001oogoo0:]oo`40005o
o`001goo0P000goo00<007ooOol0Zgoo0@000Goo0008Ool01@00Oomoogoo0000[Goo0@000Goo000<
Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00<007ooOol0Zgoo
0@000Goo000<Ool00`00Oomoo`2[Ool10001Ool000aoo`03001oogoo0:]oo`40005oo`0037oo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00D007ooOomoo`00005oo`0037oo[`000Goo0000\
\>"],
  ImageRangeCache->{{{0, 187}, {286, 0}} -> {-2.66511, -2.00546, 0.021759, 
  0.021759}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["k1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "-",
  StyleBox["k4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " parameters are removed from the parameters list."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ClearParameters[k1, k2, k3, k4]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["9.3  Velocity and Acceleration Couples"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Coupled systems are not limited to geometric conditions that involve only \
mechanism body location and orientation. Velocity and acceleration terms may \
be included in the conditions to be satisfied. However, the parameters that \
are varied in attempting to satisfy the conditions are assumed to be \
constant. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " parameters never have nonzero derivatives."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Solving for Two Parameters"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of coupled systems to satisfy higher-order \
conditions, the four-bar model developed in Section 9.1 is used again. In the \
following example, the lengths of the drive bar and the driven bar are \
adjusted to satisfy two geometric conditions that are specified in two \
different mechanism configurations. One of the conditions is a first-order \
expression, specifying a component of the velocity of a point.\n\nIn the \
following example, ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are adjusted so that the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 on the center bar is 0.4 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3, and the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " velocity of point 3 on the center bar is 6.0 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1. Initial guesses are specified for each configuration, and the \
initial guess for configuration 1, which contains the velocity condition, \
includes velocity terms."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are two initial guesses for the two configurations."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SetParameters[bar2 \[Rule] 1, bar3 \[Rule] 2, bar4 \[Rule] 3]; \)\), 
    \(\(SetGuess[]; \)\), 
    \(\(guess1 = SolveMech[0.1, Solution \[Rule] Velocity]; \)\), 
    \(\(guess2 = SolveMech[0.3]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cpsys = 
      SetCouple[{bar2, bar3}, {
          \(Velocity[centerbar, 3]\)\[LeftDoubleBracket]2
              \[RightDoubleBracket] == 6.0, Time \[Rule] .1, 
          InitialGuess \[Rule] guess1}, {
          \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
              \[RightDoubleBracket] == 0.4, Time \[Rule] .3, 
          InitialGuess \[Rule] guess2}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveCouple[cpsys, SetParameters \[Rule] True]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.1`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 1.16689990798376941`\), ",", 
            \(bar3 \[Rule] 2.91756364884587036`\), ",", \(bar4 \[Rule] 3\), 
            ",", \(X2 \[Rule] 0.`\), ",", \(Y2 \[Rule] 0.`\), ",", 
            \(Th2 \[Rule] 0.628318530717958623`\), ",", 
            \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
            \(Th3 \[Rule] 0.236627058349667418`\), ",", 
            \(X4 \[Rule] 0.944041856293431713`\), ",", 
            \(Y4 \[Rule] 0.685886556814303549`\), ",", 
            \(Th4 \[Rule] 0.0359338786293027023`\), ",", \(X2d \[Rule] 0.`\), 
            ",", \(Y2d \[Rule] 0.`\), ",", 
            \(Th2d \[Rule] 6.28318530717958623`\), ",", \(X3d \[Rule] 0.`\), 
            ",", \(Y3d \[Rule] 0.`\), ",", 
            \(Th3d \[Rule] 2.12751925649586093`\), ",", 
            \(X4d \[Rule] \(-4.30955233616762889`\)\), ",", 
            \(Y4d \[Rule] 5.93158992082543345`\), ",", 
            \(Th4d \[Rule] \(-0.952093210626273567`\)\)}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{"T", "\[Rule]", 
              StyleBox["0.3`",
                StyleBoxAutoDelete->True,
                PrintPrecision->1]}], ",", 
            \(bar2 \[Rule] 1.16689990798376941`\), ",", 
            \(bar3 \[Rule] 2.91756364884587036`\), ",", \(bar4 \[Rule] 3\), 
            ",", \(X2 \[Rule] 0.`\), ",", \(Y2 \[Rule] 0.`\), ",", 
            \(Th2 \[Rule] 1.88495559215387586`\), ",", 
            \(X3 \[Rule] \(-2.`\)\), ",", \(Y3 \[Rule] 3.`\), ",", 
            \(Th3 \[Rule] 0.307968738739501368`\), ",", 
            \(X4 \[Rule] \(-0.360591902301547051`\)\), ",", 
            \(Y4 \[Rule] 1.10978776135217915`\), ",", 
            \(Th4 \[Rule] \(-0.390116269373865129`\)\)}], "}"}]}], "}"}]], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The nested list of rules returned by ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has one complete solution for each of the two mechanism configurations. \
Note that ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatically determined that a velocity solution was needed for the \
first configuration by the presence of first-order terms in the geometric \
condition."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This shows that the desired goal has been achieved."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(Velocity[centerbar, 3]\)\[LeftDoubleBracket]2
          \[RightDoubleBracket] /. SolveMech[0.1, Solution \[Rule] Velocity], 
      \(Location[centerbar, 3]\)\[LeftDoubleBracket]1\[RightDoubleBracket] /. 
        SolveMech[0.3]}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({6.00000000001536015`, 0.399999999993015631`}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Solving for Multiple Parameters"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This last example of the use of coupled systems with velocity dependence \
uses two geometric conditions that are satisfied in one configuration, and \
one condition that is satisfied in another configuration. One of the \
conditions is an expression involving velocity.\n\n",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["bar3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["bar4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are adjusted so that the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of point 3 on the center bar is 0.4 at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.3, the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " velocity of point 3 is 5.5, at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1, and the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of point 2 on the center bar is 3.7, also at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the current values of the coordinates that are to be specified."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(Velocity[centerbar, 3]\)\[LeftDoubleBracket]2
          \[RightDoubleBracket] /. guess1, 
      \(Location[centerbar, 2]\)\[LeftDoubleBracket]2\[RightDoubleBracket] /. 
        guess1, \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
          \[RightDoubleBracket] /. guess2}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({5.54843502269815047`, 3.46101435060405471`, \(-0.263120515583556446`\)}
      \)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(cpsys = 
      SetCouple[{bar2, bar3, 
          bar4}, {{
            \(Velocity[centerbar, 3]\)\[LeftDoubleBracket]2
                \[RightDoubleBracket] == 5.5, 
            \(Location[centerbar, 2]\)\[LeftDoubleBracket]2
                \[RightDoubleBracket] == 3.7}, Time \[Rule] .1, 
          InitialGuess \[Rule] guess1}, {
          \(Location[centerbar, 3]\)\[LeftDoubleBracket]1
              \[RightDoubleBracket] == 0.4, Time \[Rule] .3, 
          InitialGuess \[Rule] guess2}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(SolveCouple[cpsys, SetParameters \[Rule] True]
        \)\[LeftDoubleBracket]1, {2, 3, 4}\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({bar2 \[Rule] 1.07852118599532298`, bar3 \[Rule] 2.92589963303014055`, 
      bar4 \[Rule] 3.06622410268389655`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"This shows that the conditions are now satisfied."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({\(Velocity[centerbar, 3]\)\[LeftDoubleBracket]2
          \[RightDoubleBracket] /. SolveMech[0.1, Solution \[Rule] Velocity], 
      \(Location[centerbar, 2]\)\[LeftDoubleBracket]2\[RightDoubleBracket] /. 
        LastSolve[], 
      \(Location[centerbar, 3]\)\[LeftDoubleBracket]1\[RightDoubleBracket] /. 
        SolveMech[0.3]}\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({5.50000000002974243`, 3.69999999999937134`, 0.399999999999484412`}\)], 
  "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["9.4  Load-Dependent Couples"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Coupled systems may be built with mathematical conditions that depend on \
reaction forces in the mechanism, instead of geometric conditions that depend \
on body locations and velocities. Such expressions contain the Lagrange \
multiplier terms (",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...) that are used to resolve static and dynamic reaction forces in a \
model. The four-bar mechanism is used to demonstrate this, after adding \
applied forces and gravity to the model so that the joint reactions are \
nonzero."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Loads on the Four-Bar Model"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The four-bar mechanism defined in Section 9.1 now has a constant moment \
applied to the driven bar and gravitational force applied to all bodies. "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This sets nonzero masses for each body. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\tBody[drivebar, Mass \[Rule] 0.05], 
      Body[drivenbar, Mass \[Rule] 0.10, Centroid \[Rule] {0.50, 0}], 
      Body[centerbar, Mass \[Rule] 0.05, Centroid \[Rule] {0, 0.25}]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a clockwise moment applied to the driven bar, and gravity applied to \
all bodies."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[Moment[drivenbar, \(-10\)], Gravity[{0, \(-1\)}, 9.81]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Solving for a Parameter"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A coupled system is used to find the length of the drive bar that causes \
the reaction moment at the driving constraint to be equal to 0.5. The driving \
constraint, constraint 1, is a ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraining the rotation of the drive bar. Since this constraint only \
controls the rotation of the drive bar it can support no forces, only a \
moment. Thus, the reaction force at the constraint is exactly zero. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the reaction force and moment that the driving constraint applies to \
the drive arm. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[bar2 \[Rule] 1, bar3 \[Rule] 3, bar4 \[Rule] 3]; \)\), 
    \(Reaction[1, drivebar] /. SolveMech[0.2, Solution \[Rule] Static]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, 0.652542278500145922`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "At ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.2, the driving constraint must apply a 0.65 unit moment to the drive \
bar to counteract the gravitational forces and the moment applied to the \
driven bar. A ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built that seeks the value of ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that results in a reaction moment of 0.5 units at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.2."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cpsys = 
      SetCouple[bar2, 
        \(Reaction[1, drivebar]\)\[LeftDoubleBracket]2
            \[RightDoubleBracket] == 0.5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CoupleSystem[{bar2}, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(bar2 /. SolveCouple[cpsys]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.893655035739183745`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"As with the examples given in the previous section, coupled systems can be \
built that couple multiple mechanism configurations. The conditions to be \
satisfied in such a system can be a mix of geometric conditions and algebraic \
conditions based on reaction forces."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Dynamic Solutions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the solution level used in each configuration of the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to pick a solution level that is sufficient to solve for the terms \
appearing in the equations given to ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Valid settings are ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "In all of the preceding examples, ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has been called with the default setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["Solution->Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontFamily->"Times"],
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" automatically upgrades the ",
    FontFamily->"Times"],
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" setting to ",
    FontFamily->"Times"],
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " when first-order terms are encountered in the equations, or to ",
    FontFamily->"Times"],
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" when second-order terms are encountered. ",
    FontFamily->"Times"],
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" chooses the ",
    FontFamily->"Times"],
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " setting if Lagrange multipliers are encountered due to reaction forces in \
the equations.\n\nHowever, ",
    FontFamily->"Times"],
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" does not automatically choose the ",
    FontFamily->"Times"],
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" or ",
    FontFamily->"Times"],
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" settings for ",
    FontFamily->"Times"],
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" unless first- or second-order terms ",
    FontFamily->"Times"],
  StyleBox["and",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " Lagrange multiplier terms appear in the equations, even though a dynamic \
solution (that includes inertial forces) may be desired. In the following \
example a ",
    FontFamily->"Times"],
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " is built with exactly the same inputs as in the previous example, but the \
",
    FontFamily->"Times"],
  StyleBox["Solution->Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " option causes inertial forces to be included, resulting in a different \
solution.",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the reaction that the driving constraint applies to the drive arm, \
including dynamic forces. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[bar2 \[Rule] 1, bar3 \[Rule] 3, bar4 \[Rule] 3]; \)\), 
    \(Reaction[1, drivebar] /. SolveMech[0.2, Solution \[Rule] Dynamic]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, 0.483505000920502503`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "With dynamic forces included, the reaction moment at the drive bar is \
reduced to only 0.48 units at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.2. A new ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built that seeks the value of ",
  StyleBox["bar2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that results in a reaction moment of 0.5 units at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.2, the same reaction moment that was sought in the previous example."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object with a dynamic formulation."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cpsys = 
      SetCouple[bar2, 
        \(Reaction[1, drivebar]\)\[LeftDoubleBracket]2
            \[RightDoubleBracket] == 0.5, Solution \[Rule] Dynamic]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CoupleSystem[{bar2}, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that the resulting length of the drive bar is quite different than was \
calculated using only static forces."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(bar2 /. SolveCouple[cpsys]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(1.01542400056271331`\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Dependent Time"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FindTime[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["equation",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks a solution to the current model that satisfies ",
  StyleBox["equation",
    FontSlant->"Italic"],
  " with time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " treated as a dependent variable. ",
  StyleBox["equation",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["Equal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify what level of solution is needed. ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also accepts the standard Newton's method options. \n\nHere are the \
default option settings for ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["\n",
    FontFamily->"Times"],
  StyleBox[
  "DampingFactor    -> 1\nMaxIterations    -> 15\nSolution         -> \
Automatic\nZeroTest         -> (Abs[#]<10^(-9)&)",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A combined form of ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is essentially a special combined form of the ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function that accepts only one condition to be satisfied, and considers \
time to be the only new dependent variable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This seeks the time at which the reaction on the drive bar is equal to 8."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(FindTime[
      \(Reaction[1, drivebar]\)\[LeftDoubleBracket]2\[RightDoubleBracket] == 
        1]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0.189728164329518129`, bar2 \[Rule] 1, bar3 \[Rule] 3, 
      bar4 \[Rule] 3, X2 \[Rule] 0.`, Y2 \[Rule] 0.`, 
      Th2 \[Rule] 1.19209721447338235`, X3 \[Rule] \(-2.`\), Y3 \[Rule] 3.`, 
      Th3 \[Rule] 0.300459734271376532`, X4 \[Rule] 0.369712067515925557`, 
      Y4 \[Rule] 0.929146375515238176`, 
      Th4 \[Rule] \(-0.166058644276352413`\), Lmb1 \[Rule] \(-1.`\), 
      Lmb2 \[Rule] \(-0.653041637292742827`\), 
      Lmb3 \[Rule] \(-4.83650709992208938`\), 
      Lmb4 \[Rule] 0.653041637292742827`, Lmb5 \[Rule] 2.87450709992208928`, 
      Lmb6 \[Rule] 0.653041637292742827`, Lmb7 \[Rule] 4.34600709992208944`, 
      Lmb8 \[Rule] \(-0.653041637292742827`\), 
      Lmb9 \[Rule] \(-3.8555070999220895`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatically pulls its initial guesses from the current default initial \
guess list ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and it updates the initial guess list with the new solution that it \
finds."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This shows that the specified condition has been met."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[1, drivebar] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, 1.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["9.5  Sensitivity"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  "'s sensitivity analysis functions are used to perform linearized tolerance \
analysis on multibody mechanisms. Similar to the ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions covered in the previous sections, ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are used as a pair to build and solve ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects. A planar example mechanism is developed in the following \
subsection that is used to demonstrate the use of these functions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The quick-return mechanism model that was developed in Section 3.1 is used \
here to demonstrate the use of sensitivity systems. The model is redefined as \
follows in abbreviated form."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the entire quick-return model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(drivearm = 3; \)\), 
    \(\(slider = 4; \)\), 
    \(Clear[crankarm, drivex, drivey]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Revolute2[1, Point[ground, {0, 5}], Point[crank, 0]], 
      RotationLock1[2, crank, 2\ N[\[Pi]]\ T], \n\t
      Revolute2[3, \n\t\tPoint[ground, {drivex, drivey}], 
        Point[drivearm, 0]], \n\t
      PointOnLine1[4, Point[crank, {crankarm, 0}], 
        Line[drivearm, 0, {0, 9}]], \n\t
      RelativeDistance1[5, \n\t\tPoint[drivearm, {0, 9}], Point[slider, 0], 
        5.0], \n\t
      Translate2[6, Line[ground, {\(-5\), 10}, {12, 10}], 
        Line[slider, 0, {3, 0}]]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetGuess[Y2 \[Rule] 5, Th3 \[Rule] \(-0.5\), X4 \[Rule] 9, 
      Y4 \[Rule] 10]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Note that three parameters were added to the model that are used in the \
following sensitivity analysis: ",
  StyleBox["crankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " coordinate of the crankpin on the crank, ",
  StyleBox["drivex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["drivey",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which are the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinates of the attachment point of the drive arm to the ground, \
respectively."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a graphic of the quick-return mechanism."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
p
p
.008 w
.28571 .04762 Mdot
p
.01 w
.04762 .52381 m
.85714 .52381 L
.85714 .04762 L
.04762 .04762 L
.04762 .52381 L
.04762 .42857 L
.28571 .28571 L
.04762 .14286 L
s
P
P
p
p
1 .5 .5 r
.01 w
.28571 .28571 m
.28571 .28571 .19048 0 365.73 arc
F
P
p
1 0 0 r
.01 w
.36968 .40129 m
.36968 .40129 .02857 0 365.73 arc
F
.28571 .28571 m
.28571 .28571 .02857 0 365.73 arc
F
P
p
p
.02 w
.28571 .28571 Mdot
.36968 .40129 Mdot
P
P
P
p
p
0 1 0 r
.004 w
.28571 .04762 m
.28571 .04762 .02857 0 365.73 arc
F
.38472 .4646 m
.38472 .4646 .02857 0 365.73 arc
F
.27181 .05092 m
.29961 .04432 L
.39861 .4613 L
.37082 .4679 L
F
P
p
.02 w
.28571 .04762 Mdot
.38472 .4646 Mdot
P
p
.01 w
.30771 .14028 m
.37372 .41827 L
s
P
P
p
0 0 1 r
.004 w
.61533 .52381 m
.61533 .52381 .01905 0 365.73 arc
F
.61533 .57143 m
.61533 .52381 L
.75819 .52381 L
.75819 .57143 L
F
P
p
.018 w
.38472 .4646 m
.61533 .52381 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo001<Ool70n36Ool004Yoo`/3
h<Aoo`00BGoo3@?P`goo0018Ool?0n32Ool004Qoo`l3h<9oo`00B7oo40?P`Goo0018Ool60n020008
0n31Ool000aooc`000D3h0@000L3h9P002Uoo`0037oo?0001@?P10001P?PV@00:Goo000<Ool2000j
Ool60n0200070n2GOol2000YOol000aoo`8003Yoo`l3h9Moo`8002Uoo`0037oo0P00>goo3P?PUgoo
0P00:Goo000<Ool2000lOol<0n2HOol2000YOol000aoo`8003eoo`/3h9Qoo`8002Uoo`0037oo0P00
?Woo2P?PV7oo0P00:Goo000<Ool20010Ool90n2GOol2000YOol000aoo`80041oo`T3h9Moo`8002Uo
o`0037oo0P00@Goo20?PUgoo0P00:Goo000<Ool20011Ool80n2GOol2000YOol000aoo`80045oo`T3
h9Ioo`8002Uoo`0037oo0P00@Goo2@?PUWoo0P00:Goo000<Ool2000kOol7ONl80n2FOol2000YOol0
00aoo`8003=oo`mmk`P3h0Imki1oo`8002Uoo`0037oo0P00<Goo4Gg_20?P2Gg_SGoo0P00:Goo000<
Ool2000^OolDONl90n0:ONn;Ool2000YOol000aoo`8002aooaImk`T3h0emkhQoo`8002Uoo`0037oo
0P00:Goo6Wg_20?P3gg_QWoo0P00:Goo000<Ool2000WOolLONl80n0AONn4Ool2000YOol000aoo`80
02Iooaemk`T3h19mkh9oo`8002Uoo`0037oo0P009Goo7Wg_2@?P4gg_PGoo0P00:Goo000<Ool2000S
OolQONl80n0EONmoOol2000YOol000aoo`80029oob9mk`P3h1Imkgioo`8002Uoo`0037oo0P0087oo
97g_10?P00<000?P0n000P?P5Wg_OGoo0P00:Goo000<Ool4000LOolVONl30n0300030n0HONmkOol2
000YOol000aoo`D001YoobQmk`<3h08000<3h1UmkgYoo`8002Uoo`0037oo0P0000=oo`0000000P00
5goo:Gg_0`?P0P000`?P6Wg_NGoo0P00:Goo000<Ool20002Ool5000EOolYONl30n0200030n0KONmh
Ool2000YOol000aoo`8000Aoo`@001=oobYmk`<3h0<000<3h1]mkgMoo`8002Uoo`0037oo0P001Woo
100047oo:gg_10?P0P000`?P77g_MWoo0P00:Goo000<Ool20007Ool5000=Ool]ONl30n0200030n0L
ONmfOol2000YOol000aoo`8000Uoo`@000]oobimk`<3h08000<3h1emkgEoo`8002Uoo`0037oo0P00
2goo100027oo;gg_0`?P0P0010?P7Gg_M7oo0P00:Goo000<Ool2000<Ool50006Ool_ONl30n030003
0n0NONmcOol2000YOol000aoo`8000ioo`@000Aooc5mk`<3h08000<3h1mmkg9oo`8002Uoo`0037oo
0P0047oo10000Woo<Gg_0`?P0P000`?P87g_LGoo0P00:Goo000<Ool2000AOol4000bONl30n020004
0n0OONmaOol2000YOol000aoo`8001=oo`03001mkgg_035mk`<3h0<000<3h1mmkg5oo`8002Uoo`00
37oo0P0057oo=7g_0`?P0P000`?P87g_L7oo0P00:Goo000<Ool2000COoleONl30n0200030n0PONm`
Ool2000YOol000aoo`8001=oocEmk`<3h08000@3h21mkfmoo`8002Uoo`0037oo0P004Woo=Wg_0`?P
0`000`?P8Gg_KWoo0P00:Goo000<Ool2000BOolgONl30n0200030n0RONm]Ool2000YOol000aoo`80
019oocMmk`<3h08000<3h29mkfeoo`8002Uoo`0037oo0P004Goo>7g_0`?P0P000`?P8Wg_KGoo0P00
:Goo000<Ool2000AOolhONl30n0300030n0RONm/Ool2000YOol000aoo`80011oocUmk`@3h08000<3
h29mkfaoo`8002Uoo`0037oo0P0047oo>Wg_0`?P0P000`?P8Wg_K7oo0P00:Goo000<Ool2000@Oolj
ONl30n0200030n0RONm/Ool2000YOol000aoo`8000mooc]mk`<3h08000@3h25mkfaoo`8002Uoo`00
37oo0P003goo>gg_0`?P0`000`?P8Wg_Jgoo0P00:Goo000<Ool2000>OolmONl30n0200030n0RONm[
Ool2000YOol000aoo`8000ioocemk`<3h08000<3h2=mkfYoo`8002Uoo`0037oo0P003Woo?Gg_0`?P
0P0010?P8Wg_JWoo0P00:Goo000<Ool2000=OolnONl30n0300030n0RONmZOol2000YOol000aoo`80
00eoocmmk`<3h08000<3h29mkfYoo`8002Uoo`0037oo0P003Goo?gg_0`?P0P000`?P8Wg_JWoo0P00
:Goo000<Ool2000=OolbONl5O008ONl30n0200030n0SONmYOol2000YOol000aoo`8000eoobmmk`]l
00Emk`<3h0<000<3h29mkfUoo`8002Uoo`0037oo0P003Goo;gg_37`017g_10?P0P000`?P8Wg_JGoo
0P00:Goo000<Ool2000=Ool^ONl>O004ONl30n0200030n0RONmYOol2000YOol000aoo`8000eoobem
k`ml00Amk`<3h08000<3h29mkfUoo`8002Uoo`0037oo0P0037oo;Wg_3g`017g_0`?P0P0010?P8Gg_
JGoo0P00:Goo000<Ool2000<Ool^ONl@O003ONl30n0300030n0QONmYOol2000YOol000aoo`8000ao
obimk`Il008000Ql00Amk`<3h08000<3h25mkfUoo`8002Uoo`0037oo0P0037oo;Wg_1G`010001g`0
17g_0`?P0P000`?P8Gg_JGoo0P00:Goo000<Ool2000<Ool^ONl5O0040006O005ONl30n0200040n0P
ONmYOol2000YOol000aoo`8000aoobimk`Il008000Ml00Emk`<3h0<000<3h21mkfUoo`8002Uoo`00
37oo0P003Goo;Wg_3W`01Wg_0`?P0P000`?P87g_JGoo0P00:Goo000<Ool2000=Ool_ONl<O007ONl3
0n0200030n0PONmYOol2000YOol000aoo`8000eoobmmk`]l00Qmk`<3h08000<3h21mkfUoo`8002Uo
o`0037oo0P003Goo<7g_2G`02Gg_0`?P0`000`?P7gg_JGoo0P00:Goo000<Ool2000=OolaONl7O00:
ONl40n0200030n0NONmZOol2000YOol000aoo`8000eood=mk`<3h08000<3h1imkfYoo`8002Uoo`00
37oo0P003Goo@gg_0`?P0P000`?P7Wg_JWoo0P00:Goo000<Ool2000=Oom3ONl30n0300030n0MONmZ
Ool2000YOol000aoo`8000iood9mk`@3h08000<3h1emkfYoo`8002Uoo`0037oo0P003Woo@gg_0`?P
0P000`?P77g_Jgoo0P00:Goo000<Ool2000?Oom2ONl30n0200030n0LONm[Ool2000YOol000aoo`80
00mood9mk`<3h08000@3h1]mkf]oo`8002Uoo`0037oo0P003goo@Wg_0`?P0`000`?P6Wg_K7oo0P00
:Goo000<Ool2000@Oom2ONl30n0200030n0JONm/Ool2000YOol000aoo`80011ood9mk`<3h08000<3
h1Ymkfaoo`8002Uoo`0037oo0P0047oo@Wg_0`?P0P0010?P6Gg_K7oo0P00:Goo000<Ool2000AOom1
ONl30n0300030n0IONm/Ool2000YOol000aoo`80015ood9mk`<3h08000<3h1Qmkfeoo`8002Uoo`00
37oo0P004Woo@Gg_0`?P0P000`?P67g_KGoo0P00:Goo000<Ool2000BOom1ONl30n0200030n0GONm^
Ool2000YOol000aoo`8001=ood1mk`<3h0<000<3h1Imkfioo`8002Uoo`0037oo0P004goo@7g_10?P
0P000`?P5Gg_Kgoo0P00:Goo000<Ool2000COom1ONl30n0200030n000g`0ONmmk`0AONm`Ool2000Y
Ool000aoo`8001=oo`03001mkgg_03imk`<3h08000<3h09l019mkg1oo`8002Uoo`0037oo0P004Goo
0`00?gg_00Al00?P0n03h0<000<3h09l011mkg5oo`8002Uoo`0037oo0P0047oo100000=oogg_ONl0
>gg_0W`010?P0P000`?P0g`03gg_LGoo0P00:Goo000<Ool2000>Ool40004OollONl3O0030n020003
0n04O00=ONmbOol2000YOol000aoo`8000aoo`D000IoocYmk`Al00<3h08000<3h0Al00amkg=oo`80
02Uoo`0037oo0P002goo100027oo>Wg_17`00`?P0P0010?P0g`02gg_M7oo0P00:Goo000<Ool20009
Ool4000;OoliONl4O0030n0300030n03O00;ONmdOol2000YOol000aoo`8000Moo`D000eoocQmk`El
00<3h08000<3h0=l00YmkgEoo`8002Uoo`0037oo0P001Woo10003goo>Gg_17`00`?P0P000`?P0g`0
2Gg_MWoo0P00:Goo000<Ool20004Ool4000BOoliONl3O0030n0200030n02O00:ONmfOol2000YOol0
00aoo`80009oo`D001AoocQmk`=l00<3h0<000<3h003O01mkgg_00MmkgMoo`8002Uoo`0037oo0P00
00=oo`0000000P005goo=gg_0g`010?P00<000?P0n000P?P27g_NGoo0P00:Goo000<Ool5000JOolh
ONl2O0080n07ONmjOol2000YOol000aoo`@001aoocQmk`03O003h0?P00H3h0Imkg]oo`8002Uoo`00
37oo0P007goo>7g_2@?P17g_O7oo0P00:Goo000<Ool2000POolgONl90n03ONmmOol2000YOol000ao
o`80029oocImk`P3h09mkgioo`8002Uoo`0037oo0P008goo=Gg_2P?POWoo0P00:Goo000<Ool2000U
OolcONl;0n1mOol2000YOol000aoo`8002Mooc1mk`d3h7aoo`8002Uoo`0037oo0P00:7oo;Wg_3`?P
Ngoo0P00:Goo000<Ool2000YOol]ONl50n0500050n1kOol2000YOol000aoo`8002aoobYmk`D3h0T0
00030n1oogoo07Uoo`8002Uoo`0037oo0P00;Woo9gg_1P?P3@00N7oo0P00:Goo000<Ool2000aOolR
ONl2Ool60n0@001eOol2000YOol000aoo`8003=ooaemk`Eoo`H3h1@0075oo`8002Uoo`0037oo0P00
>7oo4gg_2goo1P?P0P0000<3h00000004P00KGoo0P00:Goo000<Ool20010Ool3ONlDOol<0n0D001Y
Ool2000YOol000aoo`8005Moo`d3h0=ooa@006Eoo`8002Uoo`0037oo0P00Egoo30?P1goo5000HWoo
0P00:Goo000<Ool2001IOol90n0<OolD001NOol2000YOol000aoo`8005Yoo`H3h19ooa@005Yoo`80
02Uoo`0037oo0P00MWoo5000EWoo0P00:Goo000<Ool2001jOolD001BOol2000YOol000aoo`8007eo
oaD004ioo`8002Uoo`0037oo0P00PGoo5000Bgoo0P00:Goo000<Ool20025OolD00000goo01l07`06
01lnOol2000YOol000aoo`8008Uooa@000H07ceoo`8002Uoo`0037oo0P00SGoo50000P0O?Goo0P00
:Goo000<Ool2002AOol@000201lmOol2000YOol000aooj<000807cl002Uoo`0037ooX`009@0O7000
:Goo002WOol301l5000U01m5Ool00:Qoob`07dEoo`00Z7oo;00OAGoo002ZOolZ01m5Ool00:aoobP0
7dEoo`00[7oo:00OAGoo002/OolX01m5Ool00:aoobP07dEoo`00[7oo:00OAGoo002/OolX01m5Ool0
0:aoobP07dEoo`00[7oo:00OAGoo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYo
o`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003o
OolJOol00001\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-6.02038, -1.00006, 0.0751456, 
  0.0751456}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Sensitivity to Parameter Variations"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The quick-return model contains three undefined parameters: ",
  StyleBox["crankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["drivex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["drivey",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". We wish to find the sensitivity of the location of each body in the \
mechanism to small changes in these parameters, about some operating point. \
The sensitivities are not constant, they change as the mechanism moves \
through a complete cycle. Thus, the maximum sensitivity at any point in a \
cycle is of interest."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The values of the parameters are set and the body locations are found at the \
initial operating point."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetParameters[crankarm \[Rule] 3, drivex \[Rule] 0, 
      drivey \[Rule] 0]; \)\), 
    \(SolveMech[0] // Chop\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, crankarm \[Rule] 3, drivex \[Rule] 0, drivey \[Rule] 0, 
      X2 \[Rule] 0, Y2 \[Rule] 5.`, Th2 \[Rule] 0, X3 \[Rule] 0, 
      Y3 \[Rule] 0, Th3 \[Rule] \(-0.540419500270584141`\), 
      X4 \[Rule] 9.07904619162365378`, Y4 \[Rule] 10.`, Th4 \[Rule] 0}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetSensitivity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SetSensitivity[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbols...",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the equations necessary to find the sensitivity of the current \
mechanism to changes in the ",
  StyleBox["symbol(s)",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.\n\n",
  StyleBox["SolveSensitivity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sensys",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solves the ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object ",
  StyleBox["sensys",
    FontSlant->"Italic"],
  " and return a list of rules representing the sensitivities to variations \
in ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " as velocities. \n\n",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the operating point about which the sensitivities are \
calculated. If ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is unspecified, the operating point is taken from the current initial \
guess list, ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The sensitivity functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "First, the sensitivity to variations in the ",
  StyleBox["crankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " parameter are found."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sensys = SetSensitivity[crankarm]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SensitivitySystem[{crankarm}, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = SolveSensitivity[sensys] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, crankarm \[Rule] 3, drivex \[Rule] 0, drivey \[Rule] 0, 
      X2 \[Rule] 0, Y2 \[Rule] 5.`, Th2 \[Rule] 0, X3 \[Rule] 0, 
      Y3 \[Rule] 0, Th3 \[Rule] \(-0.540419500270584141`\), 
      X4 \[Rule] 9.07904619162365378`, Y4 \[Rule] 10.`, Th4 \[Rule] 0, 
      X2d \[Rule] 0, Y2d \[Rule] 0, Th2d \[Rule] 0, X3d \[Rule] 0, 
      Y3d \[Rule] 0, Th3d \[Rule] \(-0.147058823529411775`\), 
      X4d \[Rule] 0.785522289633989601`, Y4d \[Rule] 0, Th4d \[Rule] 0}\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The solution returned by ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is identical in form to the solution returned by ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["time",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Solution->Velocity]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The difference is that the velocity terms ",
  StyleBox["X2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Th3d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on, do not represent ",
  StyleBox["dX2/dT",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["dTh3/dT",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; they represent ",
  StyleBox["dX2/dcrankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["dTh3/dcrankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Because the results from ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are returned in this form, it is possible to use any of the ",
  StyleBox["Mechanical Systems ",
    FontSlant->"Italic"],
  "output functions, differentiated once, to find the sensitivity of more \
complicated quantities to changes in the parameter."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Here is the sensitivity of the distance from the crank center to the \
slider origin to changes in ",
  StyleBox["crankarm",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Dt[Magnitude[crank, 0, slider, 0], T]\), 
    \(% /. sol\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(2\ \((\(-X2\) + X4)\)\ \((\(-X2d\) + X4d)\) + 
        2\ \((\(-Y2\) + Y4)\)\ \((\(-Y2d\) + Y4d)\)\)\/\(2\ 
        \@\(\((\(-X2\) + X4)\)\^2 + \((\(-Y2\) + Y4)\)\^2\)\)\)], "Output"],

Cell[BoxData[
    \(0.688078219413977798`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Multiple Parameters"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If multiple symbols are passed to ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a nested list of solutions, one for each symbol."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Here is a ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with three parameters."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(sensys = SetSensitivity[{crankarm, drivex, drivey}]; \)\), 
    \(\(sol = SolveSensitivity[sensys]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Here is the sensitivity of the slider location to variations in each of the \
parameters."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dt[\(Location[slider, 0]\)\[LeftDoubleBracket]1\[RightDoubleBracket], T]
         /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.785522289633989601`, 0.214477710366010443`, 0.984412253570956252`}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "To plot the sensitivity of the slider location to changes in these three \
parameters, a set of solutions at several operating points is generated and \
used as initial conditions for ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This resets the initial guesses and seeks 25 solution points through a full \
turn of the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SetGuess[Y2 \[Rule] 5, Th2 \[Rule] 0, Th3 \[Rule] \(-0.5\), 
      X4 \[Rule] 9, Y4 \[Rule] 10]; \)\), 
    \(\(postab = SolveMech[{0, 1}, 25]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is applied with each of the position solutions serving as an initial \
condition."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(senstab = 
      Transpose[
        \((SolveSensitivity[sensys, InitialCondition \[Rule] #1]&)\)/@
          postab]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a plot of the sensitivities."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[Graphics[\((Line[{T, X4d} /. #1]&)\)/@senstab], 
      Frame \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.395369 0.108758 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -9 -9 ]
[.21429 -0.0125 9 0 ]
[.40476 -0.0125 -9 -9 ]
[.40476 -0.0125 9 0 ]
[.59524 -0.0125 -9 -9 ]
[.59524 -0.0125 9 0 ]
[.78571 -0.0125 -9 -9 ]
[.78571 -0.0125 9 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06909 -12 -4.5 ]
[-0.0125 .06909 0 4.5 ]
[-0.0125 .17785 -12 -4.5 ]
[-0.0125 .17785 0 4.5 ]
[-0.0125 .28661 -12 -4.5 ]
[-0.0125 .28661 0 4.5 ]
[-0.0125 .39537 -6 -4.5 ]
[-0.0125 .39537 0 4.5 ]
[-0.0125 .50413 -6 -4.5 ]
[-0.0125 .50413 0 4.5 ]
[-0.0125 .61289 -6 -4.5 ]
[-0.0125 .61289 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(0.2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(0.4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(0.6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(0.8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(1)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06909 m
.00625 .06909 L
s
[(-3)] -0.0125 .06909 1 0 Mshowa
0 .17785 m
.00625 .17785 L
s
[(-2)] -0.0125 .17785 1 0 Mshowa
0 .28661 m
.00625 .28661 L
s
[(-1)] -0.0125 .28661 1 0 Mshowa
0 .39537 m
.00625 .39537 L
s
[(0)] -0.0125 .39537 1 0 Mshowa
0 .50413 m
.00625 .50413 L
s
[(1)] -0.0125 .50413 1 0 Mshowa
0 .61289 m
.00625 .61289 L
s
[(2)] -0.0125 .61289 1 0 Mshowa
.125 Mabswid
0 .09085 m
.00375 .09085 L
s
0 .1126 m
.00375 .1126 L
s
0 .13435 m
.00375 .13435 L
s
0 .1561 m
.00375 .1561 L
s
0 .1996 m
.00375 .1996 L
s
0 .22136 m
.00375 .22136 L
s
0 .24311 m
.00375 .24311 L
s
0 .26486 m
.00375 .26486 L
s
0 .30836 m
.00375 .30836 L
s
0 .33011 m
.00375 .33011 L
s
0 .35187 m
.00375 .35187 L
s
0 .37362 m
.00375 .37362 L
s
0 .41712 m
.00375 .41712 L
s
0 .43887 m
.00375 .43887 L
s
0 .46062 m
.00375 .46062 L
s
0 .48238 m
.00375 .48238 L
s
0 .52588 m
.00375 .52588 L
s
0 .54763 m
.00375 .54763 L
s
0 .56938 m
.00375 .56938 L
s
0 .59113 m
.00375 .59113 L
s
0 .04734 m
.00375 .04734 L
s
0 .02559 m
.00375 .02559 L
s
0 .00384 m
.00375 .00384 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06909 m
1 .06909 L
s
.99375 .17785 m
1 .17785 L
s
.99375 .28661 m
1 .28661 L
s
.99375 .39537 m
1 .39537 L
s
.99375 .50413 m
1 .50413 L
s
.99375 .61289 m
1 .61289 L
s
.125 Mabswid
.99625 .09085 m
1 .09085 L
s
.99625 .1126 m
1 .1126 L
s
.99625 .13435 m
1 .13435 L
s
.99625 .1561 m
1 .1561 L
s
.99625 .1996 m
1 .1996 L
s
.99625 .22136 m
1 .22136 L
s
.99625 .24311 m
1 .24311 L
s
.99625 .26486 m
1 .26486 L
s
.99625 .30836 m
1 .30836 L
s
.99625 .33011 m
1 .33011 L
s
.99625 .35187 m
1 .35187 L
s
.99625 .37362 m
1 .37362 L
s
.99625 .41712 m
1 .41712 L
s
.99625 .43887 m
1 .43887 L
s
.99625 .46062 m
1 .46062 L
s
.99625 .48238 m
1 .48238 L
s
.99625 .52588 m
1 .52588 L
s
.99625 .54763 m
1 .54763 L
s
.99625 .56938 m
1 .56938 L
s
.99625 .59113 m
1 .59113 L
s
.99625 .04734 m
1 .04734 L
s
.99625 .02559 m
1 .02559 L
s
.99625 .00384 m
1 .00384 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4808 m
.06349 .47498 L
.10317 .46452 L
.14286 .45032 L
.18254 .43349 L
.22222 .41497 L
.2619 .39537 L
.30159 .37493 L
.34127 .35344 L
.38095 .33018 L
.42063 .30388 L
.46032 .27263 L
.5 .23394 L
.53968 .18542 L
.57937 .12761 L
.61905 .0715 L
.65873 .04971 L
.69841 .13013 L
.7381 .39537 L
.77778 .60332 L
.81746 .56736 L
.85714 .50725 L
.89683 .48585 L
.93651 .48258 L
.97619 .4808 L
s
.02381 .4187 m
.06349 .40891 L
.10317 .40032 L
.14286 .39344 L
.18254 .38826 L
.22222 .38453 L
.2619 .38177 L
.30159 .3794 L
.34127 .3767 L
.38095 .37283 L
.42063 .36679 L
.46032 .35732 L
.5 .3427 L
.53968 .32052 L
.57937 .2877 L
.61905 .24043 L
.65873 .17203 L
.69841 .07325 L
.7381 .01472 L
.77778 .16632 L
.81746 .33889 L
.85714 .41303 L
.89683 .43099 L
.93651 .42786 L
.97619 .4187 L
s
.02381 .50243 m
.06349 .48935 L
.10317 .4747 L
.14286 .45944 L
.18254 .44443 L
.22222 .43033 L
.2619 .41757 L
.30159 .40631 L
.34127 .3964 L
.38095 .38735 L
.42063 .37831 L
.46032 .36794 L
.5 .35431 L
.53968 .33487 L
.57937 .30722 L
.61905 .27285 L
.65873 .2464 L
.69841 .27188 L
.7381 .41757 L
.77778 .55579 L
.81746 .55699 L
.85714 .5343 L
.89683 .52216 L
.93651 .51317 L
.97619 .50243 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo000IOol0
0`00Oomoo`0YOol00`00Oomoo`02Ool01000Oomoogoo0`0097oo00<007ooOol00Woo00<007ooOol0
0Woo0`008goo00<007ooOol00Woo00@007ooOomoo`8002Eoo`03001oogoo009oo`03001oogoo009o
o`03001oogoo02Moo`D000Yoo`0067oo00<007oo0000:Goo00<007oo00001goo00<007ooOol08goo
00<007oo00002Goo00<007ooOol08Goo00<007oo00001goo00<007oo00008goo00<007oo00001goo
00<007oo0000:Woo00<007ooOol02Woo000HOol00`00Ool0000YOol00`00Ool00008Ool00`00Oomo
o`0ROol00`00Ool00007Ool4000ROol00`00Ool00007Ool00`00Ool0000SOol00`00Ool00007Ool0
0`00Ool0000ZOol00`00Oomoo`0:Ool001Qoo`03001oo`0002Uoo`03001oo`0000Qoo`03001oogoo
029oo`03001oo`0000Moo`03001oo`0002=oo`03001oo`0000Moo`8002Aoo`03001oo`0000Qoo`03
001oogoo02Uoo`03001oogoo00Yoo`0067oo00<007oo0000:Goo00<007oo00001goo00<007oo0000
8goo00<007oo000027oo0P008goo00<007oo00001goo00<007ooOol08goo00<007oo00001goo00<0
07oo0000:Woo00<007ooOol02Woo000IOol00`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`0S
Ool00`00Oomoo`08Ool00`00Oomoo`0ROol00`00Oomoo`07Ool2000TOol00`00Oomoo`07Ool00`00
Oomoo`0XOol2000<Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolI
Ool001Aoooh000Ioo`0057oo0P0017oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol00Woo0P001Woo000DOol00`00Oomoo`3jOol0
0`00Oomoo`04Ool001Aoo`03001oogoo0;Qoo`03001oogoo03moo`03001oogoo00Aoo`0057oo00<0
07ooOol0]goo0P00@Goo00<007ooOol017oo000DOol00`00Oomoo`2gOol00`00Ool00010Ool00`00
Oomoo`04Ool001Aoo`800;Moo`04001oogoo000oOol20006Ool001Aoo`03001oogoo0;Eoo`05001o
ogooOol00010Ool00`00Oomoo`04Ool001Aoo`03001oogoo0;Eoo`05001oogooOol00010Ool00`00
Oomoo`04Ool001Aoo`03001oogoo0;Aoo`03001oogoo00=oo`03001oogoo03eoo`03001oogoo00Ao
o`0057oo00<007ooOol0/goo00<007ooOol017oo00<007ooOol0?Goo00<007ooOol017oo000DOol0
0`00Oomoo`2cOol00`00Oomoo`04Ool00`00Oomoo`0mOol00`00Oomoo`04Ool001Aoo`800:Eoo`03
001oogoo00]oo`03001oogoo00Eoo`03001oogoo03aoo`8000Ioo`0057oo00<007ooOol0XWoo0`00
37oo00<007ooOol01goo00<007ooOol0?7oo00<007ooOol017oo000DOol00`00Oomoo`2POol20003
Ool00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`0lOol00`00Oomoo`04Ool000eoo`8000Eo
o`03001oogoo09moo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo03ao
o`03001oogoo00Aoo`003goo00<007ooOol00Woo00<007ooOol0WGoo0P001goo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol0?7oo00<007ooOol017oo0008Ool30003Ool00`00Oomoo`03Ool2
002LOol20009Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0jOol20006Ool000moo`03
001oogoo009oo`03001oogoo09Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03
001oogoo03]oo`03001oogoo00Aoo`003Goo00<007oo000017oo00<007ooOol0VGoo00<007ooOol0
2goo00<007ooOol017oo00<007ooOol02goo00<007ooOol0>goo00<007ooOol017oo000>Ool00`00
Oomoo`03Ool00`00Oomoo`2IOol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`0kOol00`00Oomoo`04Ool001Aoo`03001oogoo09Qoo`03001oogoo00eoo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo03Yoo`03001oogoo00Aoo`0057oo00<007ooOol0Ugoo00<007oo
Ool03goo00@007ooOol0011oo`03001oogoo03Yoo`03001oogoo00Aoo`0057oo0P00Ugoo00<007oo
Ool047oo00@007ooOol0011oo`03001oogoo03Uoo`8000Ioo`0057oo00<007ooOol0UWoo00<007oo
Ool04Goo00<007oo000047oo00<007ooOol0>Woo00<007ooOol017oo000DOol00`00Oomoo`2EOol0
0`00Oomoo`0BOol2000BOol00`00Oomoo`0iOol00`00Oomoo`04Ool001Aoo`03001oogoo09Aoo`03
001oogoo01Aoo`03001oogoo011oo`03001oogoo03Uoo`03001oogoo00Aoo`0057oo00<007ooOol0
U7oo00<007ooOol04goo0P004Woo00<007ooOol0>Goo00<007ooOol017oo000DOol2002DOol00`00
Oomoo`0DOol00`00Ool0000AOol00`00Oomoo`0hOol20006Ool001Aoo`03001oogoo099oo`03001o
ogoo01Eoo`03001oo`00019oo`03001oogoo03Qoo`03001oogoo00Aoo`0057oo00<007ooOol0TGoo
00<007ooOol05Goo00D007ooOomoo`00015oo`03001oogoo03Qoo`03001oogoo00Aoo`0057oo00<0
07ooOol0TGoo00<007ooOol05Goo00D007ooOomoo`00015oo`03001oogoo03Qoo`03001oogoo00Ao
o`0057oo00<007ooOol0T7oo00<007ooOol05Goo00<007ooOol00goo00<007ooOol03Woo00<007oo
Ool0>7oo00<007ooOol017oo000DOol00`00Oomoo`2?Ool00`00Oomoo`0FOol00`00Oomoo`03Ool0
0`00Oomoo`0?Ool00`00Oomoo`0gOol00`00Oomoo`04Ool001Aoo`80091oo`03001oogoo01Ioo`03
001oogoo00=oo`03001oogoo00moo`03001oogoo03Ioo`8000Ioo`0057oo00<007ooOol0SWoo00<0
07ooOol05Woo00<007ooOol017oo00<007ooOol03goo00<007ooOol0=goo00<007ooOol017oo000D
Ool00`00Oomoo`2=Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`0g
Ool00`00Oomoo`04Ool001Aoo`03001oogoo08eoo`03001oogoo01Ioo`03001oogoo00Ioo`03001o
ogoo00moo`03001oogoo03Ioo`03001oogoo00Aoo`0057oo00<007ooOol0S7oo00<007ooOol05goo
00<007ooOol01Woo00<007ooOol03goo00<007ooOol0=Woo00<007ooOol017oo000DOol2002<Ool0
0`00Oomoo`0HOol00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol20006Ool001Aoo`03
001oogoo08]oo`03001oogoo01Moo`03001oogoo00Moo`03001oogoo00moo`03001oogoo03Ioo`03
001oogoo00Aoo`0057oo00<007ooOol0RWoo00<007ooOol067oo00<007ooOol01goo00<007ooOol0
47oo00<007ooOol0=Goo00<007ooOol017oo000DOol00`00Oomoo`29Ool00`00Oomoo`0HOol00`00
Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`0eOol00`00Oomoo`04Ool000eoo`<000Aoo`03001o
ogoo08Uoo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo011oo`03001oogoo03Eoo`03001o
ogoo00Aoo`003Goo00<007ooOol017oo00<007ooOol0R7oo00<007ooOol067oo00<007ooOol02Woo
00<007ooOol03goo00<007ooOol0=Goo00<007ooOol017oo0008Ool30003Ool00`00Oomoo`03Ool2
0028Ool00`00Oomoo`0IOol00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`0cOol20006Ool0
00ioo`03001oogoo00=oo`03001oogoo08Moo`03001oogoo01Qoo`03001oogoo00]oo`03001oogoo
011oo`03001oogoo03Aoo`03001oogoo00Aoo`003Goo00<007oo000017oo00<007ooOol0QWoo00<0
07ooOol06Goo00<007ooOol02goo00<007ooOol047oo00<007ooOol0=7oo00<007ooOol017oo000>
Ool00`00Oomoo`03Ool00`00Oomoo`25Ool00`00Oomoo`0IOol00`00Oomoo`0<Ool00`00Oomoo`0@
Ool00`00Oomoo`0dOol00`00Oomoo`04Ool001Aoo`03001oogoo08Aoo`03001oogoo01Yoo`03001o
ogoo00aoo`03001oogoo015oo`03001oogoo03=oo`03001oogoo00Aoo`0057oo0P00Q7oo00<007oo
Ool06Woo00<007ooOol03Woo00<007ooOol047oo00<007ooOol0<Woo0P001Woo000DOol00`00Oomo
o`23Ool00`00Oomoo`0JOol00`00Oomoo`0>Ool00`00Oomoo`0@Ool00`00Oomoo`0cOol00`00Oomo
o`04Ool001Aoo`03001oogoo089oo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo011oo`03
001oogoo03=oo`03001oogoo00Aoo`0057oo00<007ooOol0PGoo00<007ooOol06Woo00<007ooOol0
47oo00<007ooOol047oo00<007ooOol0<goo00<007ooOol017oo000DOol00`00Oomoo`20Ool00`00
Oomoo`0KOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0bOol00`00Oomoo`04Ool001Ao
o`03001oogoo07moo`03001oogoo01]oo`03001oogoo015oo`03001oogoo015oo`03001oogoo039o
o`03001oogoo00Aoo`0057oo0P00Ogoo00<007ooOol077oo00<007ooOol04Goo00<007ooOol04Goo
00<007ooOol0<Goo0P001Woo000DOol00`00Oomoo`1nOol00`00Oomoo`0KOol00`00Oomoo`0COol0
0`00Oomoo`0@Ool00`00Oomoo`0bOol00`00Oomoo`04Ool001Aoo`03001oogoo07eoo`03001oogoo
01aoo`03001oogoo01=oo`03001oogoo015oo`03001oogoo035oo`03001oogoo00Aoo`0057oo00<0
07ooOol0O7oo00<007ooOol077oo00<007ooOol057oo00<007ooOol04Goo00<007ooOol0<Goo00<0
07ooOol017oo000DOol00`00Oomoo`1kOol00`00Oomoo`0MOol00`00Oomoo`0DOol00`00Oomoo`0A
Ool00`00Oomoo`0aOol00`00Oomoo`04Ool001Aoo`8007]oo`03001oogoo01eoo`03001oogoo01Eo
o`03001oogoo015oo`03001oogoo031oo`8000Ioo`0057oo00<007ooOol0NGoo00<007ooOol07Goo
00<007ooOol027oo00<007ooOol02goo00<007ooOol04Woo00<007ooOol0<7oo00<007ooOol017oo
000DOol00`00Oomoo`1hOol00`00Oomoo`0MOol00`00Oomoo`07Ool200000goo0000000;Ool00`00
Oomoo`0BOol00`00Oomoo`0`Ool00`00Oomoo`04Ool001Aoo`03001oogoo07Ioo`8001moo`03001o
ogoo00Moo`03001oogoo00=oo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo031oo`03001o
ogoo00Aoo`0057oo00<007ooOol0MGoo00<007ooOol07goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol027oo00<007ooOol04Goo00<007ooOol0<7oo00<007ooOol017oo000DOol00`00Oomo
o`1dOol00`00Oomoo`0OOol00`00Oomoo`05Ool20009Ool20008Ool00`00Oomoo`0AOol00`00Oomo
o`0`Ool00`00Oomoo`04Ool001Aoo`8007Aoo`03001oogoo01moo`03001oogoo00Eoo`03001oogoo
00]oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo02ioo`8000Ioo`0057oo00<007ooOol0
LWoo00<007ooOol07goo00<007ooOol017oo0P003goo0P001Goo00<007ooOol04Woo00<007ooOol0
;goo00<007ooOol017oo000DOol00`00Oomoo`1aOol00`00Oomoo`0OOol00`00Oomoo`04Ool00`00
Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0_Ool00`00Oomoo`04Ool000ao
o`D000=oo`03001oogoo071oo`03001oogoo01moo`03001oogoo00Aoo`03001oogoo019oo`03001o
ogoo00=oo`03001oogoo015oo`03001oogoo02moo`03001oogoo00Aoo`003Woo00<007ooOol00goo
00<007ooOol0KWoo0P008Woo00<007ooOol00goo00<007ooOol057oo00<007ooOol00Woo00<007oo
Ool04Woo00<007ooOol0;Woo00<007ooOol017oo0008Ool30003Ool00`00Oomoo`03Ool2001^Ool0
0`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Oomoo`0BOol0
0`00Oomoo`0]Ool20006Ool000ioo`03001oogoo00=oo`03001oogoo06aoo`03001oogoo025oo`03
001oogoo00=oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo019oo`03001oogoo02ioo`03
001oogoo00Aoo`003Woo00<007ooOol00goo00<007ooOol0Jgoo00<007ooOol08Goo00<007ooOol0
0Woo0P006Goo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol0;Woo00<007ooOol017oo000=
Ool20005Ool00`00Oomoo`1YOol2000ROol20004Ool00`00Oomoo`0JOol01@00Oomoogoo000057oo
00<007ooOol0;Woo00<007ooOol017oo000DOol00`00Oomoo`1XOol00`00Oomoo`0QOol00`00Oomo
o`03Ool00`00Oomoo`0KOol01@00Oomoogoo00005Goo00<007ooOol0;Goo00<007ooOol017oo000D
Ool00`00Oomoo`1WOol00`00Oomoo`0QOol00`00Oomoo`03Ool00`00Oomoo`0LOol00`00Oomoo`02
Ool00`00Oomoo`0BOol00`00Oomoo`0]Ool00`00Oomoo`04Ool001Aoo`8006Ioo`8002=oo`03001o
ogoo00=oo`03001oogoo01eoo`03001oogoo009oo`03001oogoo019oo`03001oogoo02aoo`8000Io
o`0057oo00<007ooOol0Hgoo0P008goo0P0017oo0P008Goo00D007ooOomoo`0001Aoo`03001oogoo
02eoo`03001oogoo00Aoo`0057oo00<007ooOol0HWoo00<007ooOol08Woo00<007ooOol00goo00<0
07ooOol08Goo00D007ooOomoo`0001Eoo`03001oogoo02aoo`03001oogoo00Aoo`0057oo00<007oo
Ool0H7oo0P0097oo00<007ooOol00goo00<007ooOol08Woo00D007ooOomoo`0001Eoo`03001oogoo
02aoo`03001oogoo00Aoo`0057oo00<007ooOol0GWoo0P0097oo0P0017oo0P009Woo00@007ooOol0
01Eoo`03001oogoo02aoo`03001oogoo00Aoo`0057oo0P00GWoo00<007ooOol08Woo0P001Goo00<0
07ooOol09Woo00@007ooOol001Eoo`03001oogoo02]oo`8000Ioo`0057oo00<007ooOol0Fgoo0P00
97oo00<007ooOol00goo0P00:Goo00D007ooOomoo`0001Eoo`03001oogoo02]oo`03001oogoo00Ao
o`0057oo00<007ooOol0FGoo0P0097oo0P0017oo0P00:goo00D007ooOomoo`0001Eoo`03001oogoo
02]oo`03001oogoo00Aoo`0057oo00<007ooOol0F7oo00<007ooOol08Woo0P0017oo0P00;Woo00@0
07ooOol001Eoo`03001oogoo02]oo`03001oogoo00Aoo`0057oo00<007ooOol0EWoo0P008goo0P00
0goo0`00<7oo00@007ooOol001Ioo`03001oogoo02Yoo`03001oogoo00Aoo`0057oo00<007ooOol0
E7oo0P008Goo10000goo0P00<goo00@007ooOol001Ioo`03001oogoo02Yoo`03001oogoo00Aoo`00
57oo0P00E7oo00<007ooOol07Goo100017oo0`00=Woo00<007oo00005goo00<007ooOol0:7oo0P00
1Woo000DOol00`00Oomoo`1AOol2000MOol30005Ool3000iOol01000Oomoo`005Woo00<007ooOol0
:Goo00<007ooOol017oo000DOol00`00Oomoo`1?Ool2000LOol30006Ool2000lOol01000Oomoo`00
5goo00<007ooOol0:7oo00<007ooOol017oo000DOol00`00Oomoo`1>Ool00`00Oomoo`0HOol40006
Ool3000nOol01000Oomoo`005goo00<007ooOol0:7oo00<007ooOol017oo000DOol00`00Oomoo`1<
Ool2000EOol60007Ool30012Ool00`00Ool0000HOol00`00Oomoo`0WOol00`00Oomoo`04Ool001Ao
o`8004]oo`8000eoo`X000Yoo`<004Eoo`03001oo`0001Qoo`03001oogoo02Ioo`8000Ioo`0057oo
00<007ooOol0BGoo00<007ooOol00goo2P0047oo1000B7oo00<007oo00006Goo00<007ooOol09Woo
00<007ooOol017oo000DOol00`00Oomoo`0kOolD000FOol4001<Ool00`00Ool0000JOol00`00Oomo
o`0UOol00`00Oomoo`04Ool001Aoo`03001oogoo035oo`X000Yoo`8001Uoo`D0055oo`03001oo`00
01Uoo`03001oogoo02Eoo`03001oogoo00Aoo`003Woo00<007ooOol00goo00<007ooOol09goo2P00
4Woo0P005Woo1@00EWoo00<007oo00006Woo00<007ooOol097oo00<007ooOol017oo000=Ool00`00
Ool00004Ool00`00Oomoo`0OOol8000JOol2000COol5001KOol00`00Ool0000JOol00`00Oomoo`0T
Ool00`00Oomoo`04Ool000eoo`03001oo`0000Aoo`8001]oo`D0021oo`80015oo`@0065oo`8001]o
o`03001oogoo029oo`8000Ioo`003Goo00<007oo000017oo00<007ooOol05Goo1@008goo0P0047oo
0`00IGoo0P006goo00<007ooOol08goo00<007ooOol017oo000=Ool00`00Ool00004Ool00`00Oomo
o`0@Ool5000VOol2000>Ool4001XOol2000LOol00`00Oomoo`0ROol00`00Oomoo`04Ool000ioo`03
001oogoo00=oo`03001oogoo00aoo`@002Uoo`8000aoo`@006aoo`03001oo`0001]oo`03001oogoo
029oo`03001oogoo00Aoo`0057oo00<007ooOol02Goo0`00:goo0P002Goo1@00LGoo0P0077oo00<0
07ooOol08Goo00<007ooOol017oo000DOol20006Ool4000/Ool20007Ool4001fOol2000MOol2000P
Ool20006Ool001Aoo`03001oogoo00=oo`8002ioo`8000Moo`8007Yoo`8001moo`8001Moo`<000Eo
o`03001oogoo00Aoo`0057oo00<007ooOol0<Goo0P001Woo0`00OGoo00<007ooOol07goo0P0047oo
1@0027oo00<007ooOol017oo000DOol00`00Oomoo`0_Ool20006Ool20020Ool2000ROol20007Ool7
000=Ool00`00Oomoo`04Ool001Aoo`03001oogoo02eoo`8000Eoo`<0089oo`8002Aoo`L001Aoo`03
001oogoo00Aoo`0057oo00<007ooOol0:Woo0`0017oo0`00QGoo0P00?goo00<007ooOol017oo000D
Ool2000YOol20003Ool40029Ool00`00Oomoo`0lOol20006Ool001Aoo`03001oogoo02Eoo`<0009o
o`<008eoo`03001oogoo03eoo`03001oogoo00Aoo`0057oo00<007ooOol08goo0P000goo0P00T7oo
00<007ooOol0?Goo00<007ooOol017oo000DOol00`00Oomoo`0POol30002Ool3002BOol2000nOol0
0`00Oomoo`04Ool001Aoo`03001oogoo01eoo`<000=oo`8009Ioo`03001oogoo03aoo`03001oogoo
00Aoo`0057oo0P006Woo10000goo0`00V7oo00<007ooOol0>goo0P001Woo000DOol00`00Oomoo`0F
Ool30005Ool2002KOol00`00Oomoo`0lOol00`00Oomoo`04Ool001Aoo`03001oogoo01=oo`<000Eo
o`<009eoo`8003eoo`03001oogoo00Aoo`0057oo00<007ooOol03goo10001Woo0P00XGoo00<007oo
Ool0>goo00<007ooOol017oo000DOol00`00Oomoo`0;Ool40007Ool3002SOol00`00Oomoo`0kOol0
0`00Oomoo`04Ool001Aoo`03001oogoo00Ioo`D000Uoo`800:Ioo`03001oogoo03]oo`03001oogoo
00Aoo`0057oo0P0017oo0`002goo0`00Z7oo0P00:7oo3`0017oo0P001Woo000DOol00`00Oomoo`0?
Ool2002[Ool2000ROol6000DOol00`00Oomoo`04Ool001Aoo`03001oogoo00aoo`<00:ioo`03001o
ogoo01ioo`8001Yoo`03001oogoo00Aoo`0037oo1@000goo00<007ooOol02Goo0`00/Goo0P007Goo
0P0077oo00<007ooOol017oo000>Ool00`00Oomoo`03Ool00`00Oomoo`05Ool4002dOol2000KOol2
000NOol00`00Oomoo`04Ool000ioo`03001oogoo00=oo`8000Aoo`800;Qoo`8001Uoo`8001Uoo`80
00Aoo`8000Ioo`003Woo00<007ooOol00goo00<007ooOol0_Goo0P005goo0P0067oo0`001goo00<0
07ooOol017oo000>Ool00`00Oomoo`03Ool00`00Oomoo`2mOol00`00Ool0000EOol00`00Oomoo`0D
Ool4000:Ool00`00Oomoo`04Ool000eoo`8000Eoo`03001oogoo0;ioo`8001Eoo`03001oogoo011o
o`@000ioo`03001oogoo00Aoo`0057oo00<007ooOol0_Woo0P0057oo00<007ooOol037oo1@004Woo
00<007ooOol017oo000DOol00`00Oomoo`2nOol2000COol00`00Oomoo`09Ool4000GOol00`00Oomo
o`04Ool001Aoo`800;moo`03001oo`00019oo`03001oogoo00Ioo`<001Yoo`8000Ioo`0057oo00<0
07ooOol0_Woo00<007oo00004Goo00<007ooOol00goo10007Woo00<007ooOol017oo000DOol00`00
Oomoo`2oOol2000@Ool00`00Oomoo`02Ool2000ROol00`00Oomoo`04Ool001Aoo`03001oogoo0;mo
o`03001oo`0000moo`03001oogoo008002Aoo`03001oogoo00Aoo`0057oo00<007ooOol0_goo00<0
07oo00003Woo00@007oo000002Ioo`03001oogoo00Aoo`0057oo0P00`7oo00<007oo00003Goo00<0
07oo00009goo0P001Woo000DOol00`00Oomoo`2oOol00`00Ool0000=Ool2000YOol00`00Oomoo`04
Ool001Aoo`03001oogoo0<1oo`03001oo`0000Yoo`8002]oo`03001oogoo00Aoo`0057oo00<007oo
Ool0`7oo00<007oo00002`00;7oo00<007ooOol017oo000DOol00`00Oomoo`30Ool00`00Oomoo`0:
Ool00`00Oomoo`0ZOol00`00Oomoo`04Ool001Aoo`03001oogoo0<1oo`03001oogoo00Uoo`03001o
ogoo02]oo`03001oogoo00Aoo`0057oo0P00`Goo00<007ooOol027oo00<007ooOol0:goo0P001Woo
000DOol00`00Oomoo`30Ool00`00Oomoo`07Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool001Aoo`03
001oogoo0<5oo`03001oogoo00Eoo`03001oogoo02ioo`03001oogoo00Aoo`0057oo00<007ooOol0
`Goo00<007ooOol017oo00<007ooOol0;goo00<007ooOol017oo000DOol00`00Oomoo`31Ool00`00
Oomoo`03Ool00`00Oomoo`0`Ool00`00Oomoo`04Ool001Aoo`800<9oo`03001oogoo009oo`03001o
ogoo031oo`8000Ioo`0057oo00<007ooOol0`Goo00D007ooOomoo`0003Aoo`03001oogoo00Aoo`00
57oo00<007ooOol0`Woo00<007oo0000=Goo00<007ooOol017oo000DOol00`00Oomoo`32Ool2000f
Ool00`00Oomoo`04Ool000eoo`<000Aoo`03001oogoo0<9oo`03001oogoo03Eoo`03001oogoo00Ao
o`003Goo00<007ooOol017oo00<007ooOol0nWoo00<007ooOol017oo000>Ool00`00Oomoo`03Ool2
0004Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`02Ool20006Ool000ioo`03001oogoo00=oooh000Ioo`003Goo00<007oo0000
ogoo2Goo000>Ool00`00Oomoo`3oOol8Ool00?mooaUoo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.109111, -4.07679, 0.004143, 
  0.0362798}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that the sensitivities are rather large near 3/4 turn of the crank. \
This is to be expected with a quick-return mechanism because of the high \
leverage ratio between the crank and the slider during the return stoke. The \
largest negative sensitivity is the sensitivity to the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the drive arm rotational a",
  StyleBox["xis ",
    FontFamily->"Times"],
  StyleBox["drivex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", when ",
    FontFamily->"Times"],
  "the crank is at 3/4 turn."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the quick-return mechanism at 3/4 turn of the crank. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61905 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.285714 0.047619 0.047619 0.047619 [
[ 0 0 0 0 ]
[ 1 .61905 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .61905 L
0 .61905 L
closepath
clip
newpath
p
p
.008 w
.28571 .04762 Mdot
p
.01 w
.04762 .52381 m
.85714 .52381 L
.85714 .04762 L
.04762 .04762 L
.04762 .52381 L
.04762 .42857 L
.28571 .28571 L
.04762 .14286 L
s
P
P
p
p
1 .5 .5 r
.01 w
.28571 .28571 m
.28571 .28571 .19048 0 365.73 arc
F
P
p
1 0 0 r
.01 w
.28571 .14286 m
.28571 .14286 .02857 0 365.73 arc
F
.28571 .28571 m
.28571 .28571 .02857 0 365.73 arc
F
P
p
p
.02 w
.28571 .28571 Mdot
.28571 .14286 Mdot
P
P
P
p
p
0 1 0 r
.004 w
.28571 .04762 m
.28571 .04762 .02857 0 365.73 arc
F
.28571 .47619 m
.28571 .47619 .02857 0 365.73 arc
F
.27143 .04762 m
.3 .04762 L
.3 .47619 L
.27143 .47619 L
F
P
p
.02 w
.28571 .04762 Mdot
.28571 .47619 Mdot
P
p
.01 w
.28571 .14286 m
.28571 .42857 L
s
P
P
p
0 0 1 r
.004 w
.519 .52381 m
.519 .52381 .01905 0 365.73 arc
F
.519 .57143 m
.519 .52381 L
.66186 .52381 L
.66186 .57143 L
F
P
p
.018 w
.28571 .47619 m
.519 .52381 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo003oOolJ
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo001<Ool70n36Ool004Yoo`/3
h<Aoo`00BGoo3@?P`goo0018Ool?0n32Ool004Qoo`l3h<9oo`00B7oo40?P`Goo0018Ool60n020008
0n31Ool000aooc`000D3h0@000L3h9P002Uoo`0037oo?0001@?P10001P?PV@00:Goo000<Ool2000j
Ool60n0200070n2GOol2000YOol000aoo`8003Yoo`l3h9Moo`8002Uoo`0037oo0P00>goo3P?PUgoo
0P00:Goo000<Ool2000lOol<0n2HOol2000YOol000aoo`8003eoo`X3h9Uoo`8002Uoo`0037oo0P00
?Woo20?PVWoo0P00:Goo000<Ool2000nOol80n2JOol2000YOol000aoo`8003ioo`P3h9Yoo`8002Uo
o`0037oo0P00?Woo20?PVWoo0P00:Goo000<Ool2000nOol80n2JOol2000YOol000aoo`8003ioo`P3
h9Yoo`8002Uoo`0037oo0P00?Woo20?PVWoo0P00:Goo000<Ool2000kOol3ONl80n02ONnHOol2000Y
Ool000aoo`8003=oo`]mk`P3h0Ymki1oo`8002Uoo`0037oo0P00<Goo3Gg_20?P3Gg_SGoo0P00:Goo
000<Ool2000^Ool@ONl80n0?ONn;Ool2000YOol000aoo`8002aooa9mk`P3h19mkhQoo`8002Uoo`00
37oo0P00:Goo5Gg_20?P57g_QWoo0P00:Goo000<Ool2000WOolEONl2O0080n000g`0ONmmk`0CONn4
Ool2000YOol000aoo`8002IooaImk`9l00P3h09l01Imkh9oo`8002Uoo`0037oo0P009Goo5Wg_0g`0
20?P0g`05Wg_PGoo0P00:Goo000<Ool2000SOolGONl4O0080n03O00HONmoOol2000YOol000aoo`80
029ooaQmk`Al00P3h0=l01Umkgioo`8002Uoo`0037oo0P0087oo6Wg_17`020?P17`06Gg_OGoo0P00
:Goo000<Ool4000LOolLONl4O0030n0200030n04O00KONmkOol2000YOol000aoo`D001Yooaemk`Al
00<3h08000<3h0Al01amkgYoo`8002Uoo`0037oo0P0000=oo`0000000P005goo7Wg_17`00`?P0P00
0`?P0g`07Wg_NGoo0P00:Goo000<Ool20002Ool5000EOolNONl4O0030n0200030n03O00OONmhOol2
000YOol000aoo`8000Aoo`@001=oob1mk`=l00<3h08000<3h0=l021mkgMoo`8002Uoo`0037oo0P00
1Woo100047oo8Wg_0W`00`?P0P000`?P0W`08Wg_MWoo0P00:Goo000<Ool20007Ool5000=OolSONl2
O0030n0200030n000g`0ONmmk`0QONmfOol2000YOol000aoo`8000Uoo`@000]oobEmk`04O003h0?P
0n0200030n0UONmeOol2000YOol000aoo`8000]oo`@000QoobMmk`<3h08000<3h2ImkgAoo`8002Uo
o`0037oo0P0037oo1@001Woo9gg_0`?P0P000`?P9gg_Lgoo0P00:Goo000<Ool2000>Ool40004OolX
ONl30n0200030n0XONmbOol2000YOol000aoo`80011oo`@0009oobQmk`<3h08000<3h2Umkg5oo`80
02Uoo`0037oo0P004Goo1000:Gg_0`?P0P000`?P:Gg_LGoo0P00:Goo000<Ool2000COol00`00ONmm
k`0XONl30n0200030n0YONmaOol2000YOol000aoo`8001AoobYmk`<3h08000<3h2Ymkg1oo`8002Uo
o`0037oo0P004goo:gg_0`?P0P000`?P:Wg_L7oo0P00:Goo000<Ool2000COol[ONl30n0200030n0[
ONm_Ool2000YOol000aoo`80019oobamk`<3h08000<3h2amkfioo`8002Uoo`0037oo0P004Woo;7g_
0`?P0P000`?P;Gg_KGoo0P00:Goo000<Ool2000BOol/ONl30n0200030n0]ONm]Ool2000YOol000ao
o`80015oobemk`<3h08000<3h2emkfeoo`8002Uoo`0037oo0P004Goo;Gg_0`?P0P000`?P;Wg_K7oo
0P00:Goo000<Ool2000@Ool^ONl30n0200030n0^ONm/Ool2000YOol000aoo`80011oobimk`<3h080
00<3h2imkfaoo`8002Uoo`0037oo0P0047oo;Wg_0`?P0P000`?P;Wg_K7oo0P00:Goo000<Ool2000?
Ool_ONl30n0200030n0^ONm/Ool2000YOol000aoo`8000moobmmk`<3h08000<3h2mmkf]oo`8002Uo
o`0037oo0P003Woo<7g_0`?P0P000`?P;gg_Jgoo0P00:Goo000<Ool2000>Ool`ONl30n0200030n0`
ONmZOol2000YOol000aoo`8000iooc1mk`<3h08000<3h31mkfYoo`8002Uoo`0037oo0P003Goo<Gg_
0`?P0P000`?P<7g_JWoo0P00:Goo000<Ool2000=OolaONl30n0200030n0`ONmZOol2000YOol000ao
o`8000eooc5mk`<3h08000<3h31mkfYoo`8002Uoo`0037oo0P003Goo<Gg_0`?P0P000`?P<Gg_JGoo
0P00:Goo000<Ool2000=Ool_ONl2O0030n0200030n000g`0ONmmk`0^ONmYOol2000YOol000aoo`80
00eoobmmk`9l00<3h08000<3h09l02mmkfUoo`8002Uoo`0037oo0P003Goo;Wg_0g`00`?P0P000`?P
0g`0;Wg_JGoo0P00:Goo000<Ool2000=Ool]ONl4O0030n0200030n03O00^ONmYOol2000YOol000ao
o`8000aoobimk`Al00<3h08000<3h0=l02imkfUoo`8002Uoo`0037oo0P0037oo;Wg_17`00`?P0P00
0`?P17`0;Gg_JGoo0P00:Goo000<Ool2000<Ool^ONl4O0030n0200030n04O00]ONmYOol2000YOol0
00aoo`8000aoobimk`Al00<3h08000<3h0Al02emkfUoo`8002Uoo`0037oo0P0037oo;Wg_17`00`?P
0P000`?P0g`0;Wg_JGoo0P00:Goo000<Ool2000<Ool^ONl4O0030n0200030n03O00^ONmYOol2000Y
Ool000aoo`8000eoobimk`=l00<3h08000<3h0=l02imkfUoo`8002Uoo`0037oo0P003Goo;gg_0W`0
0`?P0P000`?P0W`0;gg_JGoo0P00:Goo000<Ool2000=Ool_ONl2O0030n0200030n000g`0ONmmk`0^
ONmYOol2000YOol000aoo`8000eooc1mk`04O003h0?P0n0200030n0aONmYOol2000YOol000aoo`80
00eooc5mk`<3h08000<3h31mkfYoo`8002Uoo`0037oo0P003Goo<Gg_0`?P0P000`?P<7g_JWoo0P00
:Goo000<Ool2000=OolaONl30n0200030n0`ONmZOol2000YOol000aoo`8000eooc5mk`<3h08000<3
h31mkfYoo`8002Uoo`0037oo0P003Woo<7g_0`?P0P000`?P<7g_JWoo0P00:Goo000<Ool2000>Ool`
ONl30n0200030n0_ONm[Ool2000YOol000aoo`8000moobmmk`<3h08000<3h2mmkf]oo`8002Uoo`00
37oo0P003goo;gg_0`?P0P000`?P;gg_Jgoo0P00:Goo000<Ool2000?Ool_ONl30n0200030n0^ONm/
Ool2000YOol000aoo`80011oobimk`<3h08000<3h2imkfaoo`8002Uoo`0037oo0P0047oo;Wg_0`?P
0P000`?P;Wg_K7oo0P00:Goo000<Ool2000@Ool^ONl30n0200030n0^ONm/Ool2000YOol000aoo`80
015oobemk`<3h08000<3h2imkfaoo`8002Uoo`0037oo0P004Goo;Gg_0`?P0P000`?P;Gg_KGoo0P00
:Goo000<Ool2000BOol/ONl30n0200030n0]ONm]Ool2000YOol000aoo`80019oobamk`<3h08000<3
h2amkfioo`8002Uoo`0037oo0P004goo:gg_0`?P0P000`?P;7g_KWoo0P00:Goo000<Ool2000COol[
ONl30n0200030n0[ONm_Ool2000YOol000aoo`8001=oob]mk`<3h08000<3h2Ymkg1oo`8002Uoo`00
37oo0P004goo00<007g_ONl0:7g_0`?P0P000`?P:Wg_L7oo0P00:Goo000<Ool2000AOol3000ZONl3
0n0200030n0YONmaOol2000YOol000aoo`80011oo`@00003Oommkgg_02Mmk`<3h08000<3h2Umkg5o
o`8002Uoo`0037oo0P003Woo100017oo:7g_0`?P0P000`?P:7g_LWoo0P00:Goo000<Ool2000<Ool5
0006OolWONl30n0200030n0WONmcOol2000YOol000aoo`8000]oo`@000QoobMmk`<3h08000<3h2Im
kgAoo`8002Uoo`0037oo0P002Goo10002goo9Wg_0`?P0P000`?P9Wg_M7oo0P00:Goo000<Ool20007
Ool5000=OolUONl30n0200030n0UONmeOol2000YOol000aoo`8000Ioo`@000moobEmk`<3h08000<3
h2AmkgIoo`8002Uoo`0037oo0P0017oo10004Woo97g_0`?P0P000`?P97g_MWoo0P00:Goo000<Ool2
0002Ool5000DOolSONl30n0200030n0SONmgOol2000YOol000aoo`800003Ool00000008001Moob9m
k`<3h08000<3h25mkgUoo`8002Uoo`0037oo1@006Woo8Gg_0`?P0P000`?P87g_NWoo0P00:Goo000<
Ool4000LOolPONl30n0200030n0OONmkOol2000YOol000aoo`8001mooammk`<3h08000<3h1imkgao
o`8002Uoo`0037oo0P0087oo7Wg_20?P7Gg_OGoo0P00:Goo000<Ool2000ROolLONl80n0LONmnOol2
000YOol000aoo`8002=ooa]mk`P3h1]mkgmoo`8002Uoo`0037oo0P009Goo6Gg_20?P67g_PWoo0P00
:Goo000<Ool2000WOolGONl80n0FONn4Ool2000YOol000aoo`8002QooaImk`T3h1AmkhEoo`8002Uo
o`0037oo0P00:Goo4gg_30?P4Wg_QWoo0P00:Goo000<Ool2000/Ool?ONl>0n0?ONn8Ool2000YOol0
00aoo`8002ioo`amk`l3h0amkh]oo`8002Uoo`0037oo0P00<Goo2Gg_3`?P2Wg_SGoo0P00:Goo000<
Ool2000cOol7ONl60n0600040n06ONn@Ool2000YOol000aoo`8003Qoo`9mk`H3h0/009Eoo`8002Uo
o`0037oo0P00>Woo1@?P4@00T7oo0P00:Goo000<Ool2000jOol50n0F002;Ool2000YOol000aoo`80
03Yoo`H3h1X008Ioo`8002Uoo`0037oo0P00>goo2P?P6P00PGoo0P00:Goo000<Ool2000lOol<0n02
OolI001mOol2000YOol000aoo`8003aoo`/3h0QooaT007Qoo`8002Uoo`0037oo0P00?Goo2@?P3Woo
6@00Lgoo0P00:Goo000<Ool2000nOol70n0DOolI001^Ool2000YOol000aoo`8005iooaT006Uoo`80
02Uoo`0037oo0P00HWoo6P000goo200OFGoo0P00:Goo000<Ool2001WOolJ000701mHOol2000YOol0
00aoo`8006aooaX000807eQoo`8002Uoo`0037oo0P00LGoo5@000P0OF7oo0P00:Goo000<Oon80002
01mJ000YOol000aoohP002D07cL002Uoo`00S7oo0P0O1P009@0OH7oo002=Ool/01mPOol008eoob`0
7f1oo`00Sgoo:P0OH7oo002AOolX01mPOol0095oobP07f1oo`00TGoo:00OH7oo002AOolX01mPOol0
095oobP07f1oo`00TGoo:00OH7oo002AOolX01mPOol0095oobP07f1oo`00ogoo6Woo003oOolJOol0
0?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`00ogoo
6Woo003oOolJOol00?mooaYoo`00ogoo6Woo0000\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-6.02038, -1.00006, 0.0751456, 
  0.0751456}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 700},
WindowMargins->{{17, Automatic}, {Automatic, 10}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 86, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1842, 57, 88, 2, 47, "Subsection"],
Cell[1933, 61, 1214, 30, 207, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3184, 96, 110, 3, 33, "Section",
  PageBreakAbove->True],
Cell[3297, 101, 617, 16, 110, "Text"],

Cell[CellGroupData[{
Cell[3939, 121, 100, 2, 47, "Subsection"],
Cell[4042, 125, 469, 8, 109, "Text"],

Cell[CellGroupData[{
Cell[4536, 137, 189, 8, 24, "SmallText"],
Cell[4728, 147, 159, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4924, 156, 119, 2, 24, "SmallText"],
Cell[5046, 160, 23015, 1124, 295, 7262, 924, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28098, 1289, 89, 2, 43, "Subsubsection"],
Cell[28190, 1293, 744, 16, 166, "Text"],

Cell[CellGroupData[{
Cell[28959, 1313, 143, 4, 24, "SmallText"],
Cell[29105, 1319, 166, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29308, 1329, 135, 3, 24, "SmallText"],
Cell[29446, 1334, 169, 3, 79, "Input"],
Cell[29618, 1339, 182, 3, 79, "Input"],
Cell[29803, 1344, 182, 3, 79, "Input"],
Cell[29988, 1349, 208, 4, 97, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30233, 1358, 230, 8, 24, "SmallText"],
Cell[30466, 1368, 127, 3, 45, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[30642, 1377, 94, 2, 29, "Subsubsection"],
Cell[30739, 1381, 600, 17, 92, "Text"],
Cell[31342, 1400, 140, 3, 24, "SmallText"],
Cell[31485, 1405, 427, 7, 165, "Input"],

Cell[CellGroupData[{
Cell[31937, 1416, 241, 8, 24, "SmallText"],
Cell[32181, 1426, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[32317, 1434, 91, 2, 29, "Subsubsection"],
Cell[32411, 1438, 682, 25, 74, "Text"],

Cell[CellGroupData[{
Cell[33118, 1467, 124, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[33267, 1473, 123, 3, 25, "Input"],
Cell[33393, 1478, 82, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33524, 1485, 191, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[33740, 1497, 101, 2, 25, "Input"],
Cell[33844, 1501, 1052, 19, 124, "Output"]
}, Open  ]]
}, Open  ]],
Cell[34923, 1524, 167, 4, 24, "SmallText"],
Cell[35093, 1530, 26320, 1181, 295, 7524, 944, "GraphicsData", 
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[61462, 2717, 105, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[61592, 2723, 1222, 44, 133, "Special3"],
Cell[62817, 2769, 154, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[62986, 2776, 932, 33, 94, "Text"],

Cell[CellGroupData[{
Cell[63943, 2813, 194, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[64162, 2824, 181, 4, 45, "Input"],
Cell[64346, 2830, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[64427, 2835, 1151, 34, 192, "Text"],

Cell[CellGroupData[{
Cell[65603, 2873, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[65822, 2885, 188, 5, 25, "Input"],
Cell[66013, 2892, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[66100, 2897, 854, 29, 94, "Text"],

Cell[CellGroupData[{
Cell[66979, 2930, 297, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[67301, 2946, 77, 2, 25, "Input"],
Cell[67381, 2950, 683, 13, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[68113, 2969, 235, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[68373, 2981, 128, 3, 25, "Input"],
Cell[68504, 2986, 104, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[68657, 2994, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[68813, 3001, 152, 3, 25, "Input"],
Cell[68968, 3006, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[69072, 3013, 1523, 52, 260, "Special3"],
Cell[70598, 3067, 206, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[70819, 3079, 828, 34, 74, "Text"],

Cell[CellGroupData[{
Cell[71672, 3117, 216, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[71913, 3129, 160, 3, 45, "Input"],
Cell[72076, 3134, 700, 13, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[72825, 3153, 136, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[72986, 3160, 71, 2, 25, "Input"],
Cell[73060, 3164, 105, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[73226, 3173, 111, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[73362, 3179, 1029, 45, 55, "Special3"],
Cell[74394, 3226, 154, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[74563, 3233, 707, 22, 93, "Text"],

Cell[CellGroupData[{
Cell[75295, 3259, 299, 11, 24, "SmallText"],

Cell[CellGroupData[{
Cell[75619, 3274, 207, 4, 65, "Input"],
Cell[75829, 3280, 79, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[75957, 3287, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[76176, 3299, 271, 7, 85, "Input"],
Cell[76450, 3308, 66, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[76565, 3315, 379, 16, 24, "SmallText"],

Cell[CellGroupData[{
Cell[76969, 3335, 168, 3, 25, "Input"],
Cell[77140, 3340, 128, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[77317, 3348, 139, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[77481, 3355, 169, 4, 65, "Input"],
Cell[77653, 3361, 79, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[77759, 3366, 583, 17, 93, "Text"],

Cell[CellGroupData[{
Cell[78367, 3387, 1625, 56, 196, "Special3"],
Cell[79995, 3445, 206, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[80216, 3457, 445, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[80686, 3475, 318, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[81029, 3491, 339, 8, 105, "Input"],
Cell[81371, 3501, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81480, 3508, 267, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[81772, 3524, 151, 3, 25, "Input"],
Cell[81926, 3529, 142, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[82117, 3537, 116, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[82258, 3543, 194, 3, 65, "Input"],
Cell[82455, 3548, 46, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[82562, 3556, 91, 2, 31, "Subsection"],
Cell[82656, 3560, 560, 11, 241, "Input"],
Cell[83219, 3573, 100, 2, 25, "Input"],
Cell[83322, 3577, 117, 2, 43, "Input"],
Cell[83442, 3581, 133, 3, 25, "Input"],
Cell[83578, 3586, 135, 3, 43, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[83762, 3595, 136, 3, 33, "Section",
  PageBreakAbove->True],
Cell[83901, 3600, 450, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[84376, 3618, 106, 2, 47, "Subsection"],

Cell[CellGroupData[{
Cell[84507, 3624, 3175, 120, 274, "Special3"],
Cell[87685, 3746, 160, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[87860, 3753, 2170, 59, 364, "Text"],

Cell[CellGroupData[{
Cell[90055, 3816, 136, 3, 24, "SmallText"],
Cell[90194, 3821, 157, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90388, 3830, 154, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[90567, 3838, 216, 4, 65, "Input"],
Cell[90786, 3844, 79, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[90914, 3851, 187, 8, 24, "SmallText"],
Cell[91104, 3861, 393, 8, 105, "Input"]
}, Open  ]],
Cell[91512, 3872, 450, 14, 73, "Text"],

Cell[CellGroupData[{
Cell[91987, 3890, 379, 16, 24, "SmallText"],

Cell[CellGroupData[{
Cell[92391, 3910, 83, 2, 25, "Input"],
Cell[92477, 3914, 1595, 33, 143, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[94121, 3953, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[94277, 3960, 312, 6, 65, "Input"],
Cell[94592, 3968, 62, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[94715, 3976, 101, 2, 31, "Subsection"],
Cell[94819, 3980, 1935, 61, 267, "Text"],
Cell[96757, 4043, 294, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[97076, 4059, 260, 4, 65, "Input"],
Cell[97339, 4065, 79, 1, 29, "Output"],
Cell[97421, 4068, 78, 1, 29, "Output"]
}, Open  ]],
Cell[97514, 4072, 1016, 37, 92, "Text"],

Cell[CellGroupData[{
Cell[98555, 4113, 294, 12, 24, "SmallText"],
Cell[98852, 4127, 767, 15, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99656, 4147, 399, 16, 24, "SmallText"],

Cell[CellGroupData[{
Cell[100080, 4167, 151, 3, 25, "Input"],
Cell[100234, 4172, 626, 15, 67, "Output"]
}, Open  ]]
}, Open  ]],
Cell[100887, 4191, 1012, 33, 133, "Text"],

Cell[CellGroupData[{
Cell[101924, 4228, 230, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[102179, 4240, 199, 4, 45, "Input"],
Cell[102381, 4246, 626, 15, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103044, 4266, 199, 4, 45, "Input"],
Cell[103246, 4272, 628, 15, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103911, 4292, 199, 4, 45, "Input"],
Cell[104113, 4298, 628, 15, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104778, 4318, 227, 4, 65, "Input"],
Cell[105008, 4324, 626, 15, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[105683, 4345, 332, 12, 24, "SmallText"],
Cell[106018, 4359, 26967, 1232, 295, 7916, 992, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133022, 5596, 289, 12, 24, "SmallText"],
Cell[133314, 5610, 96, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[133471, 5619, 139, 3, 33, "Section",
  PageBreakAbove->True],
Cell[133613, 5624, 488, 11, 90, "Text"],

Cell[CellGroupData[{
Cell[134126, 5639, 106, 2, 47, "Subsection"],
Cell[134235, 5643, 1262, 34, 206, "Text"],

Cell[CellGroupData[{
Cell[135522, 5681, 136, 3, 24, "SmallText"],
Cell[135661, 5686, 262, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[135960, 5696, 194, 8, 24, "SmallText"],
Cell[136157, 5706, 427, 9, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136621, 5720, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[136833, 5732, 105, 2, 25, "Input"],
Cell[136941, 5736, 2010, 40, 181, "Output"]
}, Open  ]]
}, Open  ]],
Cell[138978, 5780, 528, 15, 92, "Text"],

Cell[CellGroupData[{
Cell[139531, 5799, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[139687, 5806, 289, 5, 65, "Input"],
Cell[139979, 5813, 79, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[140119, 5821, 111, 2, 31, "Subsection"],
Cell[140233, 5825, 1160, 40, 150, "Text"],

Cell[CellGroupData[{
Cell[141418, 5869, 155, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[141598, 5877, 337, 6, 65, "Input"],
Cell[141938, 5885, 113, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[142100, 5893, 194, 8, 24, "SmallText"],
Cell[142297, 5903, 557, 12, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142891, 5920, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[143103, 5932, 171, 3, 25, "Input"],
Cell[143277, 5937, 146, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[143450, 5943, 129, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[143604, 5950, 390, 7, 85, "Input"],
Cell[143997, 5959, 104, 2, 29, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[144162, 5968, 128, 3, 33, "Section",
  PageBreakAbove->True],
Cell[144293, 5973, 713, 18, 129, "Text"],

Cell[CellGroupData[{
Cell[145031, 5995, 107, 2, 47, "Subsection"],
Cell[145141, 5999, 225, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[145391, 6008, 119, 2, 24, "SmallText"],
Cell[145513, 6012, 252, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145802, 6022, 170, 4, 24, "SmallText"],
Cell[145975, 6028, 126, 3, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[146150, 6037, 103, 2, 31, "Subsection"],
Cell[146256, 6041, 568, 12, 111, "Text"],

Cell[CellGroupData[{
Cell[146849, 6057, 174, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[147048, 6065, 206, 4, 45, "Input"],
Cell[147257, 6071, 65, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[147349, 6076, 657, 22, 94, "Text"],

Cell[CellGroupData[{
Cell[148031, 6102, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[148250, 6114, 187, 5, 25, "Input"],
Cell[148440, 6121, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148549, 6128, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[148761, 6140, 85, 2, 25, "Input"],
Cell[148849, 6144, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[148931, 6149, 344, 6, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[149312, 6160, 97, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[149434, 6166, 1403, 56, 104, "Special3"],
Cell[150840, 6224, 206, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[151061, 6236, 2675, 92, 270, "Text"],

Cell[CellGroupData[{
Cell[153761, 6332, 183, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[153969, 6340, 207, 4, 65, "Input"],
Cell[154179, 6346, 65, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[154271, 6351, 671, 21, 92, "Text"],

Cell[CellGroupData[{
Cell[154967, 6376, 221, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[155213, 6388, 216, 6, 45, "Input"],
Cell[155432, 6396, 60, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[155519, 6401, 189, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[155733, 6409, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[155945, 6421, 85, 2, 25, "Input"],
Cell[156033, 6425, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[156148, 6433, 94, 2, 31, "Subsection"],
Cell[156245, 6437, 1381, 50, 182, "Special3"],
Cell[157629, 6489, 300, 13, 18, "Special4",
  PageBreakAbove->False],
Cell[157932, 6504, 491, 16, 72, "Text"],

Cell[CellGroupData[{
Cell[158448, 6524, 156, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[158629, 6532, 157, 4, 25, "Input"],
Cell[158789, 6538, 764, 12, 124, "Output"]
}, Open  ]]
}, Open  ]],
Cell[159580, 6554, 403, 13, 54, "Text"],

Cell[CellGroupData[{
Cell[160008, 6571, 133, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[160166, 6578, 95, 2, 25, "Input"],
Cell[160264, 6582, 47, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[160360, 6589, 191, 8, 24, "SmallText"],
Cell[160554, 6599, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[160684, 6608, 117, 3, 33, "Section",
  PageBreakAbove->True],
Cell[160804, 6613, 926, 28, 131, "Text"],

Cell[CellGroupData[{
Cell[161755, 6645, 97, 2, 47, "Subsection"],
Cell[161855, 6649, 260, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[162140, 6658, 117, 2, 24, "SmallText"],
Cell[162260, 6662, 237, 7, 125, "Input"],
Cell[162500, 6671, 555, 11, 225, "Input"],
Cell[163058, 6684, 145, 3, 25, "Input"]
}, Open  ]],
Cell[163218, 6690, 742, 27, 92, "Text"],

Cell[CellGroupData[{
Cell[163985, 6721, 127, 2, 24, "SmallText"],
Cell[164115, 6725, 8500, 214, 182, 1329, 120, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[172664, 6945, 115, 2, 31, "Subsection"],
Cell[172782, 6949, 707, 20, 111, "Text"],
Cell[173492, 6971, 183, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[173700, 6979, 174, 4, 45, "Input"],
Cell[173877, 6985, 305, 5, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174219, 6995, 2148, 80, 196, "Special3"],
Cell[176370, 7077, 129, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[176514, 7083, 226, 8, 34, "Text"],

Cell[CellGroupData[{
Cell[176765, 7095, 192, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[176982, 7107, 92, 2, 25, "Input"],
Cell[177077, 7111, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[177195, 7118, 192, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[177412, 7130, 97, 2, 25, "Input"],
Cell[177512, 7134, 509, 8, 105, "Output"]
}, Open  ]]
}, Open  ]],
Cell[178048, 7146, 1421, 50, 152, "Text"],
Cell[179472, 7198, 266, 9, 24, "SmallText"],

Cell[CellGroupData[{
Cell[179763, 7211, 117, 3, 45, "Input"],
Cell[179883, 7216, 205, 3, 47, "Output"],
Cell[180091, 7221, 55, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[180195, 7228, 99, 2, 31, "Subsection"],
Cell[180297, 7232, 349, 12, 53, "Text"],
Cell[180649, 7246, 208, 8, 24, "SmallText"],
Cell[180860, 7256, 165, 3, 45, "Input"],
Cell[181028, 7261, 169, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[181222, 7269, 147, 3, 25, "Input"],
Cell[181372, 7274, 110, 2, 29, "Output"]
}, Open  ]],
Cell[181497, 7279, 355, 10, 73, "Text"],

Cell[CellGroupData[{
Cell[181877, 7293, 176, 4, 24, "SmallText"],
Cell[182056, 7299, 209, 4, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182302, 7308, 260, 9, 24, "SmallText"],
Cell[182565, 7319, 181, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182783, 7329, 115, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[182923, 7335, 144, 3, 45, "Input"],
Cell[183070, 7340, 22058, 680, 181, 5932, 475, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[205155, 8024, 650, 18, 91, "Text"],

Cell[CellGroupData[{
Cell[205830, 8046, 143, 4, 24, "SmallText"],
Cell[205976, 8052, 8435, 213, 182, 1317, 120, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214448, 8270, 191, 8, 24, "SmallText"],
Cell[214642, 8280, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

