(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    576780,      22954]*)
(*NotebookOutlinePosition[    577469,      22978]*)
(*  CellTagsIndexPosition[    577425,      22974]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Reference Guide", "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  "A. Modified ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Built-in Symbols"
}], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "New definitions are made for the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " symbols ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Jacobian",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (options for ",
  StyleBox["Limit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", respectively). The new functional definitions that are made for these \
symbols by ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " do not interfere with their standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " usages as option names.\n\nDefinitions are made by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " for the derivative functions of ",
  StyleBox["Abs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Sign",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mod",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Round",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Floor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Ceiling",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The new definitions disregard the discontinuous nature of these \
functions and they are not valid for complex numbers in general."
}], "Special2"],

Cell[BoxData[GridBox[{
        {\(D[Abs[a], a]\), "\[LongRightArrow]", \(Sign[a]\)},
        {\(D[Sign[a], a]\), "\[LongRightArrow]", "0"},
        {\(D[Mod[a, b], a]\), "\[LongRightArrow]", "1"},
        {\(D[Round[a], a]\), "\[LongRightArrow]", "0"},
        {\(D[Floor[a], a]\), "\[LongRightArrow]", "0"},
        {\(D[Ceiling[a], a]\), "\[LongRightArrow]", "0"}
        }]], "Input"],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " makes extensive use of a few built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " symbols, such as ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and many standard option names. No new definitions are made for these \
symbols, they are simply used to carry their arguments or specify options as \
they are in standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Special2"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "B. ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " Objects and Functions"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Absolute",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Magnitude\[Rule]Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied load to be equal to the magnitude \
specified in the ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Magnitude\[Rule]Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied load to be equal to the specified \
magnitude times the length of the vector used to specify the direction of the \
load. "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Acceleration\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for certain ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. Setting ",
  StyleBox["Solution\[Rule]Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes such functions to seek a solution for the location, velocity, and \
acceleration of the current mechanism. \n",
  StyleBox["Acceleration[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global acceleration vector, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ddX, ddY",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ddX, ddY ,ddZ",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of the specified ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Acceleration[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bn",
    FontSlant->"Italic"],
  StyleBox["um, lp",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["nt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Acceleration[Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bn",
    FontSlant->"Italic"],
  StyleBox["um, lp",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["nt",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Acceleration[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Acceleration[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ...",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the acceleration and angular acceleration coordinates of the \
specified bodies.  \[FilledSmallSquare]  ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts other argument types of the same form as ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["AccelerationTerms\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["AccelerationTerms[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the part of the right-hand term of the current acceleration \
constraint expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Jacobian[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox[".",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["Acceleration[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["+",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["AccelerationTerms[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire acceleration constraint expression associated with \
constraint cnum.  \[FilledSmallSquare]  See also: ",
  StyleBox["VelocityTerms",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["AddLoads\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["AddLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether the supplied loads are to replace the existing \
load vector or be added to the existing load vector. The default setting is ",
  
  StyleBox["AddLoads\[Rule]False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Specifying ",
  StyleBox["AddLoads\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to add the specified loads to the loads that are currently set.  \
\[FilledSmallSquare]  Errant load settings can be induced with ",
  StyleBox["AddLoads\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by accidentally running ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " more than once with the same loads, thereby multiplying their magnitude.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Alpha\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Alpha[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angular acceleration of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the angular acceleration is a vector of the form: {",
  StyleBox["Ax, Ay, Az",
    FontSlant->"Italic"],
  "}.  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a scalar.  \[FilledSmallSquare]  If the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method was specified with ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angular acceleration in terms of Euler parameters and their \
second derivatives.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. The default setting is ",
  StyleBox["Coordinates\[Rule]Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Omega",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Angle\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics functions that specifies the range of the revolution angle of \
revolved objects. ",
  StyleBox["Angle\[Rule]{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["a",
    FontSlant->"Italic"],
  ", ",
  StyleBox["b",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " revolves the object from ",
  StyleBox["a",
    FontSlant->"Italic"],
  " to ",
  StyleBox["b",
    FontSlant->"Italic"],
  " radians. The default setting is ",
  StyleBox["Angle\[Rule]{0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["Pi}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Angle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the direction angle of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " relative to the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Angle\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["number",
    FontSlant->"Italic"],
  " is equivalent to ",
  StyleBox["Angle\[Rule]{0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", number",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Angle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Angle[Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  Other ",
  StyleBox["Angle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are interpreted as ",
  StyleBox["Angle[Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Angular\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes all subsequently built models to represent angular velocity \
and acceleration explicitly in their coordinates."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The alternative to the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  If the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is specified, the orientation of a 2D body is represented by a \
single quantity; its angular coordinate ",
  StyleBox["theta",
    FontSlant->"Italic"],
  " (",
  StyleBox["Th",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  "), and the body's angular velocity and acceleration are also specified by \
the single quantities ",
  StyleBox["omega",
    FontSlant->"Italic"],
  " and ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["Th",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Th",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ").  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the angular orientation of a body is always specified by four Euler \
parameters, but with the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method the angular velocity and acceleration are specified by \
the angular velocity and acceleration vectors, ",
  StyleBox["omega",
    FontSlant->"Italic"],
  " and ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Applied\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the default setting for the ",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Specifying \n",
  StyleBox["Type\[Rule]Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return the total external load applied to a body."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The alternatives to the ",
  StyleBox["Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting are ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ArcLength\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ArcLength[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["spline",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a one-dimensional cubic ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object approximately representing the arc length of the given ",
  StyleBox["spline",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["spline",
    FontSlant->"Italic"],
  " must be a 2D or 3D ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object such as is returned by ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The ",
    FontFamily->"Times"],
  StyleBox["spline",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" must be a single 2D or 3D ",
    FontFamily->"Times"],
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", not a list of 1D ",
    FontFamily->"Times"],
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" objects.  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  StyleBox["ArcLength",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["NIntegrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to approximate the arc length of each segment of the spline.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Arrow\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Arrow[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis",
    FontSlant->"Italic"],
  ", ",
  StyleBox["len",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a graphics object representing an arrow of length ",
  StyleBox["len",
    FontSlant->"Italic"],
  " emanating from the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and pointing in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". \n",
  StyleBox["Reverse\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the arrow to terminate at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and point in the opposite direction. ",
  StyleBox["HeadSize\[Rule]number",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the width of the arrowhead. ",
  StyleBox["Magnitude\[Rule]Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the length of the arrow to be equal to ",
  StyleBox["len",
    FontSlant->"Italic"],
  " times the length of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Arrow",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.  \
\[FilledSmallSquare]  The default option  ",
  StyleBox["HeadSize\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " makes the width of the head of the arrow 1/5 ",
  StyleBox["len",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LocalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Axis\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " data object that specifies an axis by origin and direction. The axis \
originates at ",
  StyleBox["point",
    FontSlant->"Italic"],
  " and points in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". ",
  StyleBox["point",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["Mec",
    FontSlant->"Italic"],
  StyleBox["h",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" point o",
    FontFamily->"Times"],
  "bject and ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector object, which may have the head ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt1, lpnt2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Axis[Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt1",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt2",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be vectors, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or point numbers (positive integers) referencing coordinates that were \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", if ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " is specified with a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, the direction of the plane's normal is used.  \
\[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",  ",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, vector1, vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " to explicitly specify the rotational reference vector of the axis (",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " must be nonparallel to ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ").  \[FilledSmallSquare]  ",
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt1, lpnt2, lpnt3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Axis[Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["],",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["],",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt3",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Bar\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, c",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a 2D rectangular bar of width ",
  StyleBox["2c",
    FontSlant->"Italic"],
  " spanning from the origin to the end of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, facets",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a 3D bar of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " spanning the length of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with the specified number of ",
  StyleBox["facets",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, ls, rs",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a rectangular bar that is asymmetrical about ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with left and right sides ",
  StyleBox["ls",
    FontSlant->"Italic"],
  " and ",
  StyleBox["rs",
    FontSlant->"Italic"],
  " units to either side of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rorg, lorg, rend, lend",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a tapered bar with ",
  StyleBox["rorg",
    FontSlant->"Italic"],
  " and ",
  StyleBox["lorg",
    FontSlant->"Italic"],
  " placing the left and right sides at the origin, and ",
  StyleBox["rend",
    FontSlant->"Italic"],
  " and ",
  StyleBox["lend",
    FontSlant->"Italic"],
  " specifying the geometry at the end.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a value of 4 for ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " yields a square bar, ",
  StyleBox["rad ",
    FontSlant->"Italic"],
  "/ sqrt(2) across the flats.  \[FilledSmallSquare]  ",
  StyleBox["Bar[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rad1, rad2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", facets",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a conical bar with radius ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  " at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and a radius of ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  " at the end.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Ends",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify whether to close the ends of the bar, and the ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify the angle of revolution that the bar should sweep out.  \
\[FilledSmallSquare]  ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.\n\
\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox["Faces \[Rule] True\nAngle \[Rule] {0, 2 Pi}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["  (3D)",
    FontFamily->"Times"],
  StyleBox["\nEnds  \[Rule] True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["  (3D)",
    FontFamily->"Times"],
  StyleBox["\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\[FilledSmallSquare]  See also: ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Body\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Body[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to define points and properties on a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " body. ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object containing information to be passed to ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " must be a positive integer specifying an index number for the body that \
is used to reference the body in other ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options. The default setting for all options is ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting for the options for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has the effect of leaving the value of an option that has already been \
specified unchanged; thus, running a command such as ",
  StyleBox["SetBodies[Body[3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Mass\[Rule]4.0]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not effect the current values of the inertia properties of other \
bodies.  \[FilledSmallSquare]  The formats for the options to ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are as follows.\n\[FilledSmallSquare]  ",
  StyleBox["Mech2D:\nPointList    \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x1, y1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x2, y2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n",
  StyleBox["InitialGuess \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X, Y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", Th",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n",
  StyleBox["Mass         \[Rule] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["M",
    FontSlant->"Italic"],
  "\n",
  StyleBox["Inertia      \[Rule] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ig",
    FontSlant->"Italic"],
  "\n",
  StyleBox["Centroid     \[Rule] {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["xg, yg",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["\[FilledSmallSquare]  ",
    FontFamily->"Times"],
  StyleBox["Mech3D:\nPointList    \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x1, y1, z1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x2, y2, z2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}\nInitialGuess \[Rule] {{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X, Y, Z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Eo, Ei, Ej, Ek",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}\nMass         \[Rule] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["M\n",
    FontSlant->"Italic"],
  StyleBox["Inertia      \[Rule] {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["\nCentroid     \[Rule] {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["xg, yg, zg",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n\[FilledSmallSquare]  See also: ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["BodyEnergy\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["BodyEnergy[",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontWeight->"Bold"],
  " returns the kinetic energy possessed by body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["BodyEnergy[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" returns the total kinetic energy of the entire system. ",
    FontFamily->"Times"],
  StyleBox["BodyEnergy",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the body's mass and inertia matrices pre- and post-multiplied by \
the body's velocity and angular velocity vectors.  \[FilledSmallSquare]  The \
",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " argument may take any of the forms accepted by ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Box\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Box[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["lpnt1, lpnt2",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a box with two opposing corners located at local points ",
  StyleBox["lpnt1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["lpnt2",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The sides of the box are aligned with the local axes of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to ",
  StyleBox["Rectangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to ",
  StyleBox["Cuboid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.  \
\[FilledSmallSquare]  The default option is ",
  StyleBox["Faces\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  \[FilledSmallSquare]  See also: ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["BuildMech\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies that parts of the mathematical mechanism model are built \
immediately. The default setting is ",
  StyleBox["BuildMech\[Rule]Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["BuildMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["level",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to force a build of the mechanism equations to the specified \
level at any time. ",
  StyleBox["level",
    FontSlant->"Italic"],
  " can be ",
  StyleBox["None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to force all of the system equations to be built before all \
of the user variables in the system have been defined.  \[FilledSmallSquare]  \
If the user introduces variables into the model that are not explicitly \
symbols (such as ",
  StyleBox["c[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["c[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...) they will not be identified by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " and the delayed equation building that occurs when velocity or \
acceleration solutions are requested will fail. In such cases, specifying ",
  StyleBox["BuildMech\[Rule]Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will cause all of the system equations to be built immediately.  \
\[FilledSmallSquare]\n",
  StyleBox["BuildMech[Clear]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes all current equations to be cleared, such that they will be \
rebuilt automatically the next time they are needed.  \[FilledSmallSquare]  ",
  
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may also be called with ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["VelocityTerms",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["AccelerationTerms",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Centrifugal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["MassMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as its argument to clear and rebuild the specified part of the model.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["ClearMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CamPlot\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, min, max",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object representing the cam profile, a 2D or 3D space curve, that is \
defined by the locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ". \n",
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, min, max",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, min, max",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object representing a 3D cam surface profile. The coordinates of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object returned by ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not evaluated until numeric values are available for the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system variables associated with the body on which ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " is located.  \[FilledSmallSquare]  ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object (or ",
  StyleBox["Graphics3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object) not a graphics primitive.  \[FilledSmallSquare]  ",
  StyleBox["CamPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["lpnt1, lpnt2,..., lpntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, min, max",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " plots several point loci on one body, all of which must be functions of ",
  
  StyleBox["alpha",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CamToCam1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToCam1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint1,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", locuspoint2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models two cam profiles that work against each other. The locus of ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " defines the first cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", while the locus of ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " defines the second cam surface as a function of the symbol ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ". (",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " must be defined as functions of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CamToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the surfaces of the two cam profiles lie tangent to each \
other. In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", two ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbol, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " pairs must be provided in place of ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and two more in place of ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CamToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", each ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " is a parametric function of two parameters, so as to define a surface in \
3D space.  \[FilledSmallSquare]  ",
  StyleBox["CamToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates three (2D) or five (3D) constraint equations and introduces two \
or four new variables, hence constraining one DOF in 2D or 3D.  \
\[FilledSmallSquare]  The first two (or three) equations constrain the points \
of contact on the two cams to be coincident, and the last one (or two) \
equation constrains the normal vectors of the two cams at the points of \
contact to be parallel, yielding three or five constraint equations.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["CamToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CamToCircle1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToCircle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point, radius",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam surface with a circular follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CamToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the surface of the cam profile lies tangent to a circle of \
specified ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". The circular follower lies on the left side of the cam profile if ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " is positive, when traveling along the locus in the direction of \
increasing ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates two constraint equations and introduces one new variable, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", hence constraining one DOF.  \[FilledSmallSquare]  A vector that is \
normal to the cam profile at the point of contact, and has length equal to ",
  StyleBox["radius",
    FontSlant->"Italic"],
  ", is set equal to the vector from the point of contact to the center of \
the circular follower; yielding two coupled constraint equations.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CamToLine1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam surface with a flat follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the surface of the cam profile lies tangent to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates two constraint equations and introduces one new variable, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", hence constraining one DOF.  \[FilledSmallSquare]  The first equation \
constrains the point of contact to lie on the line, and the second equation \
constrains the normal to the cam profile at the contact point to be \
orthogonal to the line.  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CamToPlane1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToPlane1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["plane",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam surface with a planar follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CamToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the surface of the 3D cam profile lies tangent to the ",
  StyleBox["plane",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates three constraint equations and introduces two new variables, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ", hence constraining one DOF.  \[FilledSmallSquare]  The first equation \
constrains the point of contact to lie on the plane, and the second and third \
equations constrain the normal to the cam profile at the contact point to be \
orthogonal to the plane.  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CamToPoint1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToPoint1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam surface with a point follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CamToPoint1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the specified ",
  StyleBox["point",
    FontSlant->"Italic"],
  " lies on the surface of the cam profile. In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", two ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbol, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " pairs must be provided. ",
  StyleBox["CamToPoint1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", each ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " is a parametric function of two parameters, so as to define a surface in \
3D space.  \[FilledSmallSquare]  ",
  StyleBox["CamToPoint1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates two (2D) or three (3D) constraint equations and introduces one \
or two new variables, hence constraining one DOF in 2D or 3D.  \
\[FilledSmallSquare]  The two (or three) equations constrain ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to be coincident with the contact point on the cam profile.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CamToSphere1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToSphere1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["beta, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point, radius",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a cam surface with a spherical follower. The locus of ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " defines the cam surface as a function of the symbols ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CamToSphere1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enforces that the surface of the spatial cam profile lies in tangent \
contact with a sphere of specified ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CamToSphere1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CamToSphere1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates three constraint equations and introduces two new variables, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " and ",
  StyleBox["beta",
    FontSlant->"Italic"],
  ", hence constraining one DOF.  \[FilledSmallSquare]  A vector that is \
normal to the cam profile at the point of contact, and has length equal to ",
  StyleBox["radius",
    FontSlant->"Italic"],
  ", is set equal to the vector from the point of contact to the center of \
the spherical follower; yielding three linked constraint equations.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Centrifugal\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Centrifugal[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the vector of centrifugal forces associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Centrifugal[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " returns the entire centrifugal load vector, in current velocity \
coordinates.  ",
    FontFamily->"Times"],
  "\[FilledSmallSquare]  The loads returned by ",
  StyleBox["Centrifugal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are not converted into ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["force",
    FontSlant->"Italic"],
  ", ",
  StyleBox["moment",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " coordinates. If the current solution method is set to ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the loads returned by ",
  StyleBox["Centrifugal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will be in Euler coordinates.  \[FilledSmallSquare]  The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " argument may take any of the forms accepted by ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Centroid\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the location vector of a body's centroid, in the body's \
local coordinates. The default setting is ",
  StyleBox["Centroid\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Centroid[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a point object corresponding to the centroid of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The centroid of each body is initially located at the local origin of the \
body, unless otherwise specified.  \[FilledSmallSquare]  The default setting \
",
  StyleBox["Centroid\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves the current centroid location unchanged.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CheckRules\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that determines whether solution rules passed into ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are assumed to be correct, or are checked against the constraints to see \
if they constitute a valid solution. The default setting is ",
  StyleBox["CheckRules\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When a list of rules is passed to ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time, the rules are normally used as initial guesses for the next \
solution attempt.  \[FilledSmallSquare]  If ",
  StyleBox["CheckRules\[Rule]False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified with a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option other than ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the supplied rules are assumed to represent a valid solution and only \
the highest order part of the requested solution will actually be calculated.\
\n\[FilledSmallSquare]  For example: ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Solution\[Rule]Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["CheckRules\[Rule]False]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to accept the values specified by the ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " for the location and velocity solutions, and simply calculate a new \
acceleration solution based on the given ",
  StyleBox["rules",
    FontSlant->"Italic"],
  ". \[FilledSmallSquare]  See also: ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CheckSystem\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CheckSystem[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " checks the current model for undefined variables or inconsistent \
constraint sets. ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " if all is well, ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and an error message otherwise."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " goes through the following procedure to test the current mechanism model: \
\n    1.  Look for new dependencies on location variables or the time \
variable in the constraint equations. If the user introduces a sym",
  StyleBox["bol ",
    FontFamily->"Times"],
  StyleBox["s",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" i",
    FontFamily->"Times"],
  "nto the model and then defin",
  StyleBox["es ",
    FontFamily->"Times"],
  StyleBox["s",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" to",
    FontFamily->"Times"],
  " be a function of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " location variables (such as ",
  StyleBox["s",
    FontSlant->"Italic"],
  " = ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") ",
  StyleBox["after",
    FontSlant->"Italic"],
  " ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to build the constraint equations, the model will fail because \
symbolic differentiation with respect to ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " was not possible in ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n    2.  Look for new dependencies on velocity, acceleration, or \
generalized force variables in the constraint equations. If the user \
introduces a symbol ",
  StyleBox["s",
    FontSlant->"Italic"],
  " into the model and then defines ",
  StyleBox["s",
    FontSlant->"Italic"],
  " to be a function of other ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " variables (such as ",
  StyleBox["s",
    FontSlant->"Italic"],
  " = ",
  StyleBox["X2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Lmb3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "), the model will fail. Systems that are kinematically dependent on \
higher-order terms are nonholonomic, and they are handled by ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and systems that are kinematically dependent on generalized forces are \
underconstrained, and handled by ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n    3.  Look for new dependencies on any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system variables in the mass matrix. Such a dependency makes no physical \
sense. \n    4.  Look for new dependencies on any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system variables in the applied load vector. Such dependencies are \
allowed, but they will confuse ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s variable tracking if they appear after ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to build the load vector. New dependencies on generalized force \
terms will cause the model to fail. \n    5.  Look for undefined symbols that \
are not ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system variables in any part of the model. \n    6.  Check to see that \
the vector of constraint equations evaluates to a vector of numbers at the \
current values of the initial guesses. If this fails, examine the result of ",
  
  StyleBox["Constraints[All]/.LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to see what the nonnumeric quantities are. \n    7.  Check to see that \
the constraint derivatives are numeric at the current values of the initial \
guesses. This may fail because differentiation resulted in an indeterminate \
expression, even though the constraints were OK. Examine ",
  StyleBox["Jacobian",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["VelocityTerms",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["AccelerationTerms",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for nonnumeric quantities.\n    8.  Check to see that the total applied \
load vector evaluates to a vector of numbers at the current values of the \
initial guesses. If this fails, examine the result of ",
  StyleBox["Loads[All]/.LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to see what the nonnumeric quantities are.\n    9.  Check to see that the \
load vector derivatives are numeric at the current values of the initial \
guesses. This may fail because differentiation resulted in indeterminate \
expressions, or because the current guesses are unacceptable. Lagrange \
multiplier guesses should usually be nonzero.\n    10.  Check that the \
constraint set shows some dependence on each of the dependent variables at \
the current initial guess state. If not, the model is singular. This may mean \
that the constraint set is inherently singular,  or merely that better \
initial guesses are needed. \n    11.  Check to see if the Jacobian of the \
current model is singular. If it is, ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " attempts to find the set of equations that are redundant and return their \
equation numbers. This may be due to poor initial guesses or inherently \
redundant constraints. \n\[FilledSmallSquare]  See also: ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ClearMech\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ClearMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " clears the entire ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " database and resets all internal variables to their initial states."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ClearMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " clears all variables that are directly created by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ", but definitions made by the user outside of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " contexts are not cleared.  \[FilledSmallSquare]  Settings made with ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are not affected by ",
  StyleBox["ClearMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["ClearMech[Constraints]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " clears only the internal variables associated with the constraints. ",
  StyleBox["ClearMech[Loads]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " clears only the loads.  \[FilledSmallSquare]  ",
  StyleBox["ClearMech[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equivalent to ",
  StyleBox["(ClearMech[]; SetSymbols[])",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ClearParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ClearParameters\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ClearParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " deletes the rules from the current parameters list that are associated \
with the given ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ClearParameters[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " deletes all rules in the current parameters list.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Closed\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies that the slope and curvature of the spline at the two ends \
shall be equal."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To actually close the spline upon itself, the ",
  StyleBox["EndConditions\[Rule]Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option must be specified and the last data point given to ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be identical to the first.  \[FilledSmallSquare]  See also: ",
  StyleBox["Natural",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CompositeInertia\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CompositeInertia[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid1, mass1, inertia1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...,\n",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroidn, massn, inertian",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid, mass, inertia",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of the inertia properties of a composite body ",
  StyleBox["B",
    FontSlant->"Italic"],
  " made up of the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " specified subcomponents. In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", arguments to ",
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can have the form ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroidn, massn, inertian, rotationn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to specify subcomponents that are rotated relative to the composite body \
",
  StyleBox["B",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Given a local reference frame ",
  StyleBox["XYZ_B",
    FontSlant->"Italic"],
  " affixed to the composite body ",
  StyleBox["B",
    FontSlant->"Italic"],
  ", each argument to ",
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the inertia properties of a subcomponent of ",
  StyleBox["B",
    FontSlant->"Italic"],
  ", in the ",
  StyleBox["XYZ_B",
    FontSlant->"Italic"],
  " reference frame.  \[FilledSmallSquare]  Each ",
  StyleBox["centroidi",
    FontSlant->"Italic"],
  " is specified by ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and each ",
  StyleBox["massi",
    FontSlant->"Italic"],
  " by a scalar.  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " each ",
  StyleBox["inertiai",
    FontSlant->"Italic"],
  " is specified by a scalar, while in ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " each ",
  StyleBox["inertiai",
    FontSlant->"Italic"],
  " is given as a list of the elements of the inertia matrix, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  All inertia properties are assumed to be \
centroidal.  \[FilledSmallSquare]  If the inertia properties of a 3D \
subcomponent are known in a non-",
  StyleBox["XYZ_B",
    FontSlant->"Italic"],
  " reference frame ",
  StyleBox["xyz_B",
    FontSlant->"Italic"],
  ", the ",
  StyleBox["rotationi",
    FontSlant->"Italic"],
  " argument is used to specify the rotation of the ",
  StyleBox["xyz_B",
    FontSlant->"Italic"],
  " reference frame, relative to ",
  StyleBox["XYZ_B",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["rotationi",
    FontSlant->"Italic"],
  " are specified by ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["angle",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["angle, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ").  \[FilledSmallSquare]  If any of the subcomponents are voids their mass \
and inertia properties must be negated so that the inertia of the \
subcomponent is subtracted from the composite body.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PrincipalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ConstantVelocity4\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ConstantVelocity4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a constant velocity joint. The origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to be coincident with the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the relative spin of the two axes is constrained to be equal. The \
relative spin of the axes is determined by the angle between the reference \
directions of each axis, and the cross product of the two axes. ",
  StyleBox["ConstantVelocity4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains four DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ConstantVelocity4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, ratio, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" causes the relative spin of ",
    FontFamily->"Times"],
  StyleBox["axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" to be ratio times the spin of",
    FontFamily->"Times"],
  StyleBox[" axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]  The symbol ",
    FontFamily->"Times"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" tracks the relative spin of ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]  The constant ",
    FontFamily->"Times"],
  StyleBox["C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  ", which sets the initial relative spin, is equal to the relative spin of ",
    
    FontFamily->"Times"],
  StyleBox["axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" when the spin of ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  " is zero.  \[FilledSmallSquare]  Constraint becomes singular if the two \
axes become parallel; use ",
    FontFamily->"Times"],
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  StyleBox["ConstantVelocity4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates five constraint equations and introduces one new variable, \
hence constraining four DOF.  \[FilledSmallSquare]  The first three equations \
in ",
  StyleBox["ConstantVelocity4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain the origins of the two axes to be coincident, and the fourth \
and fifth equations relate the axial displacement of the two parts of the CV \
joint to the value of the variable ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Constraint\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Constraint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, equation, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["extravar, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "...",
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a constraint object that contains a user-defined constraint \
equation(s). The equation can be a single equation or a list of equations, \
each of which must have the head ",
  StyleBox["Equal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["bnumi",
    FontSlant->"Italic"],
  " are an optional list of the body numbers of those bodies that are \
constrained by the ",
  StyleBox["equation",
    FontSlant->"Italic"],
  ". ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["extravar, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (or ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["extravar, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ) is an optional list of symbols that appear in the model (and their \
associated initial guesses), that are added to the model's dependent variable \
list and solved for."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This function is used to enter constraints directly as equations, when the \
desired relation is not attainable with the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " mechanical constraints.  \[FilledSmallSquare]  The list of body numbers, \
",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  "...",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be omitted if the same bodies are also constrained by other system \
constraints.\n\[FilledSmallSquare]  An ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["extravar, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " pair associated with a particular ",
  StyleBox["extravar",
    FontSlant->"Italic"],
  " may appear in only one constraint in a model. The same ",
  StyleBox["extravar",
    FontSlant->"Italic"],
  " in more than one constraint will generate an error in ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ConstraintCorrection\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ConstraintCorrection",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". With ",
  StyleBox["ConstraintCorrection\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", each body's location and velocity are corrected at each integration step \
so as to be consistent with the constraints."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The equations of motion solved by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " do not explicitly contain the kinematic constraints, therefore the \
cumulative errors in numerical integration may result in a solution that \
violates the constraints. ",
  StyleBox["ConstraintCorrection\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to correct the integration at each time step so that the result does not \
violate the constraints.  \[FilledSmallSquare]  ",
  StyleBox["ConstraintCorrection\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " slows ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by approximately a factor of two.  \[FilledSmallSquare]  See also: ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Constraints\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Constraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of constraint expressions that were generated by \
constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". The expressions returned are assumed to be set equal to zero to satisfy \
the constraint."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Constraints[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum1, cnum2, ..., cnumn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of all of the expressions in all of the specified \
constraints, ",
  StyleBox["cnumi",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Constraints[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["enum1 ",
    FontSlant->"Italic"],
  StyleBox["...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the specified subset of the equations, ",
  StyleBox["enumi",
    FontSlant->"Italic"],
  ", in constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Constraints[{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum1, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["enum ",
    FontSlant->"Italic"],
  StyleBox["...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum3, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["enum ",
    FontSlant->"Italic"],
  StyleBox["...",
    FontFamily->"Times"],
  StyleBox["}}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns several parts to several different constraints.  \
\[FilledSmallSquare]  ",
  StyleBox["Constraints[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire constraint vector, and ",
  StyleBox["Constraints[Euler]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" returns the Euler generalized constraints, if any exist",
    FontFamily->"Times"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Coordinates\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether the force and moment vectors returned are to be in \
",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " coordinates. The default setting is ",
  StyleBox["Coordinates\[Rule]Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the setting of the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option effects only the value of the force; the moment is a scalar, \
uneffected by the coordinate system.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the setting of the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option effects the direction, but not the magnitude, of both the force \
and moment vectors.  \[FilledSmallSquare]  ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also an option for cylindrical and spherical coordinate conversion \
functions in ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the base reference frame for the right-hand rule Cartesian \
coordinate system. Settings are ",
  StyleBox["XYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["YZX",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZXY",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The default setting is ",
  StyleBox["Coordinates\[Rule]XYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Corrector\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Corrector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["Corrector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " method uses an Adams-Moulton predictor-corrector integration algorithm."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When ",
  StyleBox["Method\[Rule]Corrector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified in ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", instead of the default setting of ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the integrator will always take a corrective Adams-Moulton step at each \
time step, regardless of the error estimate of the current step.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Predictor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CoupleSystem\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of the data object returned by ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The format of the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object: ",
  StyleBox["CoupleSystem[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  "counterlist, initialconditions, initialguesses, equations, Jacobian, \
compsyms",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Cross\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Cross[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the cross product of the direction vectors of the two ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector objects."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Cross",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a scalar.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Cross",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a vector.  \[FilledSmallSquare]  See also: ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Unit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Cubic\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the default setting for the ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies a cubic approximation of each section of the integrand."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Lower settings than ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may work better if the system being integrated exhibits sharp \
discontinuities in acceleration.  \[FilledSmallSquare]  The ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting uses cubic interpolation for the predictor step, and quartic \
interpolation for the corrector step.  \[FilledSmallSquare]  See also: ",
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CurveToCam1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToCam1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", locuspoint2, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["gamma, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["delta, guess",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the space curve defined by ",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " to lie tangent to the spatial surface defined by ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " (",
  StyleBox["locuspoint1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["locuspoint2",
    FontSlant->"Italic"],
  " must be defined as parametric functions of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["gamma",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["delta",
    FontSlant->"Italic"],
  "). ",
  StyleBox["CurveToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates four constraint equations and introduces three new variables, ",
  
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", ",
  StyleBox["gamma",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["delta",
    FontSlant->"Italic"],
  ", hence constraining one DOF.  \[FilledSmallSquare]  The points of contact \
on the cam surface and on the space curve are constrained to be coincident \
(three DOF) and the normal to the cam surface is constrained to be orthogonal \
to the direction vector of the space curve at the point of contact (one DOF) \
yielding four constraint equations.  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CurveToCylinder1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToCylinder1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis, radius",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the space curve defined by ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " to lie in tangent contact with a cylinder of specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and ",
  StyleBox["radius",
    FontSlant->"Italic"],
  ". ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CurveToCylinder1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToCylinder1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates two constraint equations and introduces one new variable, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", hence constraining one DOF.  \[FilledSmallSquare]  The first equation \
constrains the point of contact to lie ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " units away from the cylinder's ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and the second equation constrains the direction vector of the curve at \
the point of contact to be orthogonal to normal vector from the surface of \
the cylinder at the point of contact, yielding two constraint equations.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CurveToPlane1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToPlane1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the space curve defined by ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " to lie tangent to a plane specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CurveToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates two constraint equations and introduces one new variable, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", hence constraining one DOF.  \[FilledSmallSquare]  The first equation \
constrains the point of contact to lie in the plane, and the second equation \
constrains the direction vector of the curve at the point of contact to be \
orthogonal to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", yielding two constraint equations.  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CurveToPoint2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToPoint2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, locuspoint, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the space curve defined by ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  ". ",
  StyleBox["locuspoint",
    FontSlant->"Italic"],
  " must be defined as a parametric function of ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ". ",
  StyleBox["CurveToPoint2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CurveToPoint2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates three constraint equations and introduces one new variable, ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", hence constraining two DOF.  \[FilledSmallSquare]  The point of contact \
on the space curve is coincident with the point, yielding three linked \
constraint equations.  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CutOff\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") that specifies a cutoff value for the magnitude of an applied load. If ",
  
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is nonzero, the magnitude of the load drops to one half of the specified \
magnitude when the length of the direction vector of the load is equal to ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the magnitude of the load drops to zero when the length of the \
direction vector is zero."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " makes the magnitude of the applied force or moment equal to\n(",
  StyleBox["mag",
    FontSlant->"Italic"],
  " |",
  StyleBox["vec",
    FontSlant->"Italic"],
  "|) / (",
  StyleBox["cutoff",
    FontSlant->"Italic"],
  " + |",
  StyleBox["vec",
    FontSlant->"Italic"],
  "|), which is approximately equal to ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " for |",
  StyleBox["vec",
    FontSlant->"Italic"],
  "| >> ",
  StyleBox["cutoff",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  A very small positive number is normally \
specified for ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so that 0/0 errors will not occur if the length of the line of action \
goes to zero.  \[FilledSmallSquare]  See also: ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Cylindrical4\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Cylindrical4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to be parallel and coincident. ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains four DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a hinge or revolving bearing that can translate along its axis of \
rotation.  \[FilledSmallSquare]  The first two equations constrain the origin \
of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", and the second two equations constrain the two axes to be parallel.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["ParaRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CylindricalToXYZ\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CylindricalToXYZ[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius, angle, altitude",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converts the given point from cylindrical to Cartesian coordinates and \
returns ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["CylindricalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "By default, altitude is measured in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction and an angle of zero puts the point in the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " = 0 plane. ",
  StyleBox["Coordinates\[Rule]YZX",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes altitude to be measured in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction, and so on.  \[FilledSmallSquare]  More complicated coordinate \
reorientations require a rotation matrix.  \[FilledSmallSquare]  See also: ",
  StyleBox["SphericalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToCylindrical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["DDistanceDT\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DDistanceDT[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the time derivative of the absolute distance between the two \
points."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DDistanceDT[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equivalent to ",
  StyleBox["Dt[Distance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", except that the local coordinates of the points are assumed to have no \
implicit dependence on any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system variables.  \[FilledSmallSquare]  See also: ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["D2DistanceDT2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Diagnostics\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an element of the ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option setting for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Including ",
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the list of symbols specified by ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes two ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects to be included in the solution returned by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that represent the maximum error in any one of the integration variables \
at a given time, and the step size at that time.  \[FilledSmallSquare]  See \
also: ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["DirectedDistance1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DirectedDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", measured in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". ",
  StyleBox["DirectedDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is omitted, it is assumed to be the global origin.  \[FilledSmallSquare]  \
",
  StyleBox["DirectedDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the magnitude of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " for the distance specification.  \[FilledSmallSquare]  See also: ",
  StyleBox["DirectedPosition2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["DirectedPosition2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DirectedPosition2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus a vector that is parallel to the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units long. ",
  StyleBox["DirectedPosition2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DirectedPosition2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  If ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is omitted, it is assumed to be the global origin.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["DirectedPosition3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["DirectedPosition3\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DirectedPosition3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus a vector that is parallel to the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units long. ",
  StyleBox["DirectedPosition3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains three DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DirectedPosition3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, vector",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the location of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be equal to the location of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " plus the given vector.  \[FilledSmallSquare]  If ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is omitted, it is assumed to be the global origin.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["DirectedPosition2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Direction\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Direction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the direction vector of a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector object in global coordinates."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a built in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " symbol that is redefined by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " in such a way as to not interfere with its original operation in any way. \
 \[FilledSmallSquare]  ",
  StyleBox["Direction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Direction[Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", other ",
  StyleBox["Direction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args",
    FontSlant->"Italic"],
  "...",
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are interpreted as ",
  StyleBox["Direction[Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Unit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Distance\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Distance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the absolute distance between the two points."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Distance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the same result as ",
  StyleBox["Magnitude[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["DDistanceDT",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Dynamic\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for certain ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. Setting ",
  StyleBox["Solution\[Rule]Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes such functions to seek a solution for the location, velocity, \
acceleration, and dynamic loading of the current mechanism. ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also a setting for the ",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for Loads. Specifying ",
  StyleBox["Type\[Rule]Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return the total inertial load on a body."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The alternatives to the ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting for the ",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option are ",
  StyleBox["Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["D2DistanceDT2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["D2DistanceDT2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the second time derivative of the absolute distance between the \
two points."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["DDistanceDT[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equivalent to ",
  StyleBox["Dt[Distance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["2}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " except that the local coordinates of the points are assumed to have no \
implicit dependence on any ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system variables.  \[FilledSmallSquare]  See also: ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DDistanceDT",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Edge\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Edge[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates ",
  StyleBox["n-1",
    FontSlant->"Italic"],
  " lines passing from each local point to the next on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Edge[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnts1.",
    FontSlant->"Italic"],
  "..",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnts2.",
    FontSlant->"Italic"],
  "..",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates several sequences of lines."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Edge[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, ..., pointn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates ",
  StyleBox["n-1",
    FontSlant->"Italic"],
  " lines spanning several different bodies.  \[FilledSmallSquare]  The ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " primitive.  \[FilledSmallSquare]  ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["EndConditions\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the end conditions of the spline. ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be either ",
  StyleBox["Natural",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or a list of two vectors, specifying the tangency direction at the \
beginning and end of the spline, respectively."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["EndConditions\[Rule]{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x1, y1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x2, y2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly specifies the tangency vector at each end of the spline.  \
\[FilledSmallSquare]  The magnitude as well as the direction of the two \
vectors is significant.  \[FilledSmallSquare]  See also: ",
  StyleBox["Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Natural",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Ends\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Ends",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether or not the ends of the bar are to be closed. The \
default setting is ",
  StyleBox["Ends\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Ends\[Rule]False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes bar to generate an open ended tube, or a segment of a tube.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Euler\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes all subsequently built models to use ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " parameters and their derivatives to represent angular orientation and \
velocity."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The alternative to the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  With ",
  StyleBox["Method\[Rule]Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the orientation of a 2D body is specified by two parameters ",
  StyleBox["Ei",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Ej,",
    FontSlant->"Italic"],
  " which are related to the single angular coordinate ",
  StyleBox["theta",
    FontSlant->"Italic"],
  " by ",
  StyleBox["Ei = cos(Th)",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Ej = sin(Th)",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  A 2D body's angular velocity and acceleration are \
also specified by pairs of parameters, ",
  StyleBox["Eind",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Ejnd",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Eindd",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Ejndd",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the angular orientation of a body is always specified by four Euler \
parameters, and with the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method, the angular velocity and acceleration are specified by \
derivatives of the Euler parameters.  \[FilledSmallSquare]  See also: ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["EulerParameters\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["EulerParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the Euler parameters associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ei, ej",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eo, ei, ej, ek",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["EulerParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["matrix",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of values of the Euler parameters associated with the \
given rotation matrix.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EulerParameters[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the four Euler parameters associated with a rotation of ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about the axis ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The Euler parameters {",
  StyleBox["eo, ei, ej, ek",
    FontSlant->"Italic"],
  "} associated with {",
  StyleBox["ang, axis",
    FontSlant->"Italic"],
  "} are defined as ",
  StyleBox["eo = cos(ang/2)",
    FontSlant->"Italic"],
  ", {",
  StyleBox["ei, ej, ek",
    FontSlant->"Italic"],
  "} = ",
  StyleBox["axis sin(ang/2) / ",
    FontSlant->"Italic"],
  "||",
  StyleBox["axis",
    FontSlant->"Italic"],
  "||  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EulerParameters[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the two degenerate Euler parameters {",
  StyleBox["cos(ang), sin(ang)",
    FontSlant->"Italic"],
  "} associated with the angle ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Extrude\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Extrude[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2, ...,pointn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", vector, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " extrudes the sequence of ",
  StyleBox["n-1",
    FontSlant->"Italic"],
  " lines between the given points ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Extrude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Extrude[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum,",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["lpnt1, ..., lpntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["vector, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" extrudes the ",
    FontFamily->"Times"],
  StyleBox["n-1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" lines connecting the local points ",
    FontFamily->"Times"],
  StyleBox["lpnti",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" located on body ",
    FontFamily->"Times"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  "If the ",
  StyleBox["Magnitude\[Rule]Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is given the extrusion distance is equal to the length of the \
specified ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " times ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox["Faces     \[Rule] True\nMagnitude \[Rule] Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Revolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Faces\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics functions that specifies whether faces of polygons should be \
drawn. The default setting is ",
  StyleBox["Faces\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Faces\[Rule]False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics objects to be rendered as wire frames.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Facet\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Facet[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum,",
    FontSlant->"Italic"],
  " ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a filled polygon with vertices at each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["Facet[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnts1...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnts2...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...",
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates several polygons."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Facet[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, ..., pointn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates an ",
  StyleBox["n",
    FontSlant->"Italic"],
  " sided polygon with vertices on several different bodies.  \
\[FilledSmallSquare]  The ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Polygon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " primitive.  \[FilledSmallSquare]  ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["FindSwitchTime\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FindSwitchTime[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, snum, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks the point in time at which the the two constraints in ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " number ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " separated by switch time number ",
  StyleBox["snum",
    FontSlant->"Italic"],
  " are both satisfied. ",
  StyleBox["FindSwitchTime[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, snum, ",
    FontSlant->"Italic"],
  StyleBox["TangentConstraint\[Rule]True]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the switch point when the two constraints in question approach each \
other tangentially. ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also accepts the ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The switch time number ",
  StyleBox["snum",
    FontSlant->"Italic"],
  " specifies which stage of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is under consideration. For example, a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint with three constraints has two switch times, numberes 1 and 2, \
between the three constraints.  \[FilledSmallSquare]  See also: ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["FindTime\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FindTime[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eqn",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " seeks the solution to the current model that satisfies the given equation \
",
  StyleBox["eqn",
    FontSlant->"Italic"],
  " with time treated as a dependent variable. The equation must have the \
head ",
  StyleBox["Equal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify what level of solution is needed."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " examines the symbols in the specified equation and overrides the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option if a higher-order solution level than is requested must be used.  \
\[FilledSmallSquare]  For example, if the equation supplied to ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " contains velocity and lambda terms and ",
  StyleBox["Solution\[Rule]Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting to include all of the symbols in ",
  StyleBox["eq",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  If the equation contains only location and lambda \
terms and a dynamic solution is desired, ",
  StyleBox["Solution\[Rule]Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be specified because ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would choose to use ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default.  \[FilledSmallSquare]  ",
  StyleBox["FindTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " also accepts the ",
  StyleBox["MaxIterations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["DampingFactor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options.\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox[
  "DampingFactor \[Rule] 1\nMaxIterations \[Rule] 15\nSolution      \[Rule] \
Automatic\nZeroTest      \[Rule] (Abs[#]<10^-9&)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["FitDegree\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the degree of polynomial that is used to approximate each \
section of the integrand at each time step. Valid settings for ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are ",
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The default setting for ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Force\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Force[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, axis, mag",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load object that applies a force to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " along the specified ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Specifying ",
  StyleBox["Magnitude\[Rule]Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied force to be equal to the specified ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " times the length of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Force[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2,...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the force to body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " and also applies a force in the opposite direction to body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox["CutOff    \[Rule] 0\nMagnitude \[Rule] Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Free\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to omit the time specification so that time becomes a \
dependent variable. If ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is passed ",
  StyleBox["Time\[Rule]Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " instead of ",
  StyleBox["Time\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["number",
    FontSlant->"Italic"],
  ", time is considered to be a dependent variable to be solved for."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting can be used only in ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " when the system is built, not in ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["FreeSystem\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of the data object returned by ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The output format of the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object is ",
  StyleBox["FreeSystem[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["solutionty",
    FontSlant->"Italic"],
  StyleBox["pe,",
    FontFamily->"Times",
    FontSlant->"Italic"],
  " ",
  StyleBox["<>]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["solutiontype",
    FontSlant->"Italic"],
  " is the setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option in ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The second element of a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for nonlinear systems, and ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for linear ones.  \[FilledSmallSquare]  ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["FunctionOfTime\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["FunctionOfTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for several ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions that causes returned ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects to be explicitly functions of the current time variable."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["FunctionOfTime\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, a list of the form ",
  StyleBox["{InterpolatingFunction[<>][T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is returned.  \[FilledSmallSquare]  The default setting is ",
  StyleBox["FunctionOfTime\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Generalized\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Generalized[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of generalized forces, or Lagrange multipliers (",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times"],
  ") associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " in the current model. \n",
  StyleBox["Generalized",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also an element of the ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option setting. Specifying ",
  StyleBox["MakeRules\[Rule]{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "..., ",
  StyleBox["Generalized",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...} causes the generalized forces to be included in the interpolated \
rules returned."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Generalized[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire generalized force vector.  \[FilledSmallSquare]  The \
generalized force vector contains one Lagrange multiplier, ",
  StyleBox["Lmb",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["n",
    FontSlant->"Italic"],
  ", for each constraint equation in the current system.  \
\[FilledSmallSquare]  The value of the Lagrange multipliers cannot be \
directly interpreted as a force or moment without some understanding of the \
explicit form of the mechanism equations. Use the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to convert generalized loads into the reaction forces at each \
constraint.  \[FilledSmallSquare]  See also: ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Global\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Coordinates\[Rule]Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes results to be returned in the global coordinate system.  \
\[FilledSmallSquare]  The alternative to the ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Gravity\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Gravity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector, G",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load objects that apply a force of magnitude ",
  StyleBox["mass G",
    FontSlant->"Italic"],
  " in the direction of the specified ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " to the centroid of each body in the current model."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Gravity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector, G, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the gravitational force only to the bodies specified by their \
body numbers.  \[FilledSmallSquare]  When ",
  StyleBox["Gravity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called without an explicit body number specification, a list load \
objects is returned corresponding to each body in the current model. If new \
bodies are added to the model, ",
  StyleBox["Gravity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be re-run to reflect the changes.  \[FilledSmallSquare]  See also: ",
  
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GyroFilter\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GyroFilter[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a new set of inertia properties that have zero inertia in the \
direction of ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The vector\n",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be a principal axis of the inertia properties, and the two principal \
moments not associated with ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be equal."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Inertia[GyroFilter[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["inertia, vector",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox[".",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " always returns the zero vector, which shows that a body represented by \
the new inertia properties has no angular momentum if rotating about ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["GyroFilter",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is normally used to filter out components of the inertia tensor that are \
modeled as zero-torque spinning motion with ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  It is never necessary to use ",
  StyleBox["GyroFilter",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " if the gyro body is attached to the rest of the model by a zero-torque \
constraint, like a revolute or cylindrical joint.  \[FilledSmallSquare]  Use \
",
  StyleBox["Inertia\[Rule]GyroFilter[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["inertia",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " as an option for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GyroMoment\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GyroMoment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, vec, omega",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies a moment to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " to simulate the gyroscopic effects of the axially symmetric body spinning \
with angular speed ",
  StyleBox["omega",
    FontSlant->"Italic"],
  ", about an axis originating from the centroid of the body, parallel to ",
  StyleBox["vec",
    FontSlant->"Italic"],
  ". The constant angular velocity ",
  StyleBox["omega",
    FontSlant->"Italic"],
  " is relative to the local reference frame of ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify the inertia properties of the spinning body.  \
\[FilledSmallSquare]  If ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is unspecified, the inertia properties are taken from body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " produces meaningful results only if the vector ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " is parallel to a principal moment of inertia of the body, and if the \
other two principal moments are equal in magnitude. This implies that the \
body must be axially symmetric about the vector ",
  StyleBox["vec.  ",
    FontSlant->"Italic"],
  "\[FilledSmallSquare]  ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " essentially models body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " as if it were spinning at a constant velocity relative to its own local \
coordinates system.  \[FilledSmallSquare]  To model zero-torque motion, \
instead of constant velocity, use ",
  StyleBox["GyroFilter",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to remove the components of the inertia tensor that are aligned with ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " from the bodies inertia tensor that is passed to ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["GyroFilter",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["HeadSize\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["HeadSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Arrow",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the width of the arrowhead."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The default setting ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " makes the head of the arrow 1/5 of its length.  \[FilledSmallSquare]  See \
also: ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["IMatrix\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["IMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 2D (",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") or 3D (",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") identity matrix."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["RMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["IncludedAngle\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["IncludedAngle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the positive angle between the global direction vectors of the \
two ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector objects."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The range of ",
  StyleBox["IncludedAngle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is 0 - pi.  \[FilledSmallSquare]  See also: ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Inertia\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the centroidal rotational inertia of a body. The polar \
moment of inertia is specified by a scalar in ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the inertia is given as a list of six expressions corresponding to\n",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for the body. The inertia matrix is then of the form\n",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Ixy, Izx",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixy, Iyy, Iyz",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Izx, Iyz, Izz",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["Inertia\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Inertia[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the inertia (or inertia matrix) of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The inertia of each body is initially zero, unless otherwise specified.  \
\[FilledSmallSquare]  The default setting ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves the current inertia properties unchanged.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["InitialCondition\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions that specifies initial conditions to be used in subsequent \
solutions. ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should specify rules giving the values of current system dependent \
variables, or current parameters, or time. The default setting ",
  StyleBox["InitialCondition\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes the initial conditions from the current default initial guess, ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Any variables omitted from the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting are given values taken from the current initial guess or \
parameters lists.  \[FilledSmallSquare]  The setting for the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option takes a special form for ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["InitialGuess\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and other ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. With ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the initial guesses that are used for a body's location \
coordinates. The default setting is ",
  StyleBox["InitialGuess\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Guesses are given as a nested list of numbers of the form\n",
  StyleBox["InitialGuess\[Rule]{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X, Y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", Th",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and\n",
  StyleBox["InitialGuess\[Rule]{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X, Y, Z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Eo, Ei, Ej, Ek",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If no initial guess is specified for a body, the initial guess is in \
alignment with the global coordinate system.  \[FilledSmallSquare]  The \
default setting ",
  StyleBox["InitialGuess\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves the current guesses unchanged.  \[FilledSmallSquare]  ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also an option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is given as a list of rules, just as with ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", if the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " coordinate system is used, initial guess are still specified with ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", th",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Interference\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Interference",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Involute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Interference\[Rule]True ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "specifies that the involute locus shall blend into a straight line from \
the point where the involute meets the base circle to the center of the base \
circle."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["Interference",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is set to ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the natural equation of an involute tooth profile goes through a \
first-order singularity at the point where the tooth profile meets the base \
circle (when the value of the controlling parameter is zero) and then form a \
mirror image of the tooth for negative values of the controlling parameter.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Involute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["IntersectionPoint\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["IntersectionPoint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the point of intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " in global 2D space, or the point of intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and a plane that is normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " in global 3D space. In 3D, ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is typically a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IntersectionPoint[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1, axis2, offset",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a point that is located ",
  StyleBox["offset",
    FontSlant->"Italic"],
  " units to the left of both axes (such as the center point of a fillet \
between the two axes).  \[FilledSmallSquare]  See also: ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Involute\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Involute[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", baseradius, pitchradius, angle",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the equation of an involute gear tooth as a function of the \
parameter ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ". The involute has a base circle of ",
  StyleBox["baseradius",
    FontSlant->"Italic"],
  " centered at ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The involute profile is rotationally located such that the point where \
the profile intersects the pitch circle lies on a ray that passes through ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the direction of the specified ",
  StyleBox["angle",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Involute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Interference",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["pitchradius",
    FontSlant->"Italic"],
  " is negative then the profile spirals in the clockwise direction, \
otherwise it spirals in the counterclockwise direction.  \[FilledSmallSquare] \
 The involute locus travels from the base circle to the pitch circle, as ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " goes from 0 to sqrt(",
  StyleBox["pitchradius",
    FontSlant->"Italic"],
  "^2-",
  StyleBox["baseradius",
    FontSlant->"Italic"],
  "^2)/",
  StyleBox["baseradius",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  With the ",
  StyleBox["Interference",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option the locus travels from the base circle to the center of the gear \
as ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " goes from 0 to -1.  \[FilledSmallSquare]  See also: ",
  StyleBox["CamToCam1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Jacobian\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Jacobian[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the submatrix of the current Jacobian associated with constraint \
",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " and body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Jacobian[All, All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire Jacobian matrix of the current model.  \
\[FilledSmallSquare]  The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " argument may take any of the forms accepted by ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["KillMech\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["KillMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " completely removes the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages from the current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. All of the symbols in the ",
  StyleBox["Mech2D`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Mech3D`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " contexts are removed, as well as the contexts themselves."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Using ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " allows ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " to be reloaded with ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " without error.  \[FilledSmallSquare]  See also: ",
  StyleBox["ClearMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Kinematic\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for certain ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. Setting ",
  StyleBox["Solution\[Rule]Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes such functions to seek a solution for the location, velocity, and \
velocity-dependent loading of the current model."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting should be used when a model contains applied loads that are \
functions of mechanism velocity. If the ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is used in such cases, all velocities are set to zero.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LambdaGuess\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the initial guesses for the Lagrange multipliers. ",
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be set to a number that specifies the same guess for all Lagrange \
multipliers, or a list of numbers that specify guesses for each. The default \
setting is ",
  StyleBox["LambdaGuess\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Unspecified guesses for the Lagrange multipliers are initially set to one.\
\n\[FilledSmallSquare]  ",
  StyleBox["LambdaGuess\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves the current values of the guesses unchanged.  \[FilledSmallSquare] \
 See also: ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LastSolve\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the last solution rule returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The values returned by ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are used as the initial guesses at the next invocation of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LastSolve[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " includes the values that will be used the next time that initial guesses \
for the Lagrange multipliers are be needed, regardless of whether or not they \
were part of the last solution returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LeadScrew5\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LeadScrew5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, pitch, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a lead screw. ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to be parallel and coincident with ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the axial translation of the two axes is controlled per the ",
  StyleBox["pitch",
    FontSlant->"Italic"],
  " and relative rotation of the two parts of the screw. The relative angular \
orientation of the two parts is determined by the angle between the reference \
directions of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["LeadScrew5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains five DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The symbol ",
    FontFamily->"Times"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" tracks the spin of ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", relative to ",
    FontFamily->"Times"],
  StyleBox["axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]  Th",
    FontFamily->"Times"],
  "e constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is the distance from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " when the relative rotation between the two parts of the screw is zero.  \
\[FilledSmallSquare]  ",
  StyleBox["LeadScrew5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates six constraint equations and introduces one new variable, hence \
constraining five DOF.  \[FilledSmallSquare]  The first two equations in ",
  StyleBox["LeadScrew5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", the next two equations constrain the two axes to be parallel, the fifth \
equation relates the axial displacement of the screw to the rotational \
displacement, and the sixth relates the value of the variable ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " to the rotational displacement.  \[FilledSmallSquare]  See also: ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Line\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt1, lpnt2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " data object that specifies two local points on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " that define a line. The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be point numbers (positive integers) referencing points that were \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or they can be coordinates, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", of points in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses two ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " point objects to define the line."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used in place of a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector object, the vector from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " provides the direction of the vector.  \[FilledSmallSquare]  If a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used in place of a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " axis object, the line's origin (",
  StyleBox["point1",
    FontSlant->"Italic"],
  ") provides the origin of the axis and the direction of the line provides \
the direction of the axis.  \[FilledSmallSquare]  The rotational reference \
direction of a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object can not be explicitly specified.  \[FilledSmallSquare]  See also: \
",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Linear\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies a linear approximation of each section of the integrand."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is generally less accurate than the higher-degree fits.  \
\[FilledSmallSquare]  ",
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " works well with systems that have many force discontinuities because \
fewer backsteps are required to autoadjust the time step size when a \
discontinuity is encountered.  \[FilledSmallSquare]  See also: ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LineOnCylinder3\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineOnCylinder3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, rad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["LineOnCylinder3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains three DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineOnCylinder3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " becomes singular if ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " is set to zero. ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be used instead.  \[FilledSmallSquare]  The first two equations \
constrain the two axes to be parallel, the third equation constrains the two \
axes to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units apart.  \[FilledSmallSquare]  See also: ",
  StyleBox["LineToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParaRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LineToCircle1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineToCircle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, rad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to pass through the perimeter of a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ". The axis of the circle is specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and the center of the circle lies at the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["LineToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to model a shaft in a bearing with specified clearance.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["PointOnCircle2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LineToLine1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineToLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis1, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the minimum orthogonal distance between the two axes to be \
equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units.\n",
  StyleBox["LineToLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the two axes to intersect. ",
  StyleBox["LineToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["LineToLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint could also be thought of as",
  StyleBox[" a \"LineToCylinder1\" constraint in which a line in space is ",
    FontFamily->"Times"],
  "constrained to be in contact with a cylindrical surface with a specified ",
  
  StyleBox["axis",
    FontSlant->"Italic"],
  " and radius ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LineToPlane2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineToPlane2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie parallel to a plane that is normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from the plane in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["LineToPlane2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LineToPlane2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie within the plane normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is typically given a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.  \[FilledSmallSquare]  The first equation constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to be orthogonal, the second constrains the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie in the plane normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Load\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Load[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, mag",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load object that applies a load of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " directly to coordinate ",
  StyleBox["sym",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to add expressions directly to the model's load vector \
without any coordinate transformation so that loads may be applied directly \
to generalized coordinates.  \[FilledSmallSquare]  For example, if a \
coordinate ",
  StyleBox["len",
    FontSlant->"Italic"],
  " in a model represented the distance between two points,\n",
  StyleBox["Load[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["len, ",
    FontSlant->"Italic"],
  StyleBox["2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would apply a two unit force tending to separate the two points.  \
\[FilledSmallSquare]  If the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method is current in a 3D model, ",
  StyleBox["Load[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["omega, mag",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies a load (moment) directly to the angular velocity coordinate ",
  StyleBox["omega",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Gravity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Loads\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the total external load applied to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Type\[Rule]Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option may be specified to return the total reaction force applied by all \
constraints to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Type\[Rule]Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the total inertial load on the body."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Loads[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2,  ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " retuns the subset of the applied load vector associated with the ",
  StyleBox["bnumi",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Loads[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, ..., symn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the part of the load vector associated with the specified \
coordinates. The ",
  StyleBox["symi",
    FontSlant->"Italic"],
  " must be members of the current location coordinates ",
  StyleBox["Location[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or 3D angular velocity coordinates (",
  StyleBox["Wx2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wy2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...).  \[FilledSmallSquare]  For example:\n",
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["n, ",
    FontSlant->"Italic"],
  StyleBox["Type\[Rule]Applied] +\nLoads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["n, ",
    FontSlant->"Italic"],
  StyleBox["Type\[Rule]Dynamic] +\nLoads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["n, ",
    FontSlant->"Italic"],
  StyleBox["Type\[Rule]Reaction] /. SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["time",
    FontSlant->"Italic"],
  StyleBox[",Solution\[Rule]Dynamic]\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "should always return a zero vector.  \[FilledSmallSquare]  ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify whether the result should be in ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " coordinates. The default setting ",
  StyleBox["Coordinates\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the loads in the current default coordinate system.  \
\[FilledSmallSquare]  If ",
  StyleBox["Coordinates\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified and the current coordinate system is ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a list of seven loads is returned in Euler coordinates.  \
\[FilledSmallSquare]  If either the ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is specified, ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a two element list of the form ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["force, moment",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["BodyEnergy",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Local\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Coordinates\[Rule]Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes results to be returned relative to the local coordinate system of \
a body.  \[FilledSmallSquare]  The alternative to the ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting is ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LocalAxes\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LocalAxes[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, size",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a graphics object placing local ",
  StyleBox["xy",
    FontSlant->"Italic"],
  " or ",
  StyleBox["xyz",
    FontSlant->"Italic"],
  " axes of specified ",
  StyleBox["size",
    FontSlant->"Italic"],
  " at the origin of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["LocalAxes[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, ...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", size",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " places axes on several bodies. ",
  StyleBox["LocalAxes[All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["size",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " places axes on all bodies in the current model."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LocalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Arrow",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointLabel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Location\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for certain ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. Setting ",
  StyleBox["Solution\[Rule]Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes such functions to seek a solution for the location of the current \
mechanism. ",
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global coordinates, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X, Y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["X, Y, Z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", of the specified ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Location[Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Location[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum,",
    FontSlant->"Italic"],
  StyleBox[" ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the location and angular orientation coordinates of the specified \
bodies in a flat list.  \[FilledSmallSquare]  ",
  StyleBox["Location[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire vector of dependent variables.  \[FilledSmallSquare]  \
",
  StyleBox["Location[Rest]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the dependent variables that are generalized coordinates, such as \
the extra variables introduced by cam constraints.  \[FilledSmallSquare]  In \
",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the behavior of ",
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " varies depending on whether the current solution method is ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". With the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method, ",
  StyleBox["Location[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["{X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Ei2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Ej2}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", while with the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method, ",
  StyleBox["Location[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["{X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Th2}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " always represents angular orientation with four Euler parameters.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LockMech\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LockMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds a solution to the mechanism equations at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and then embeds the numerical values of the dependent variables into the \
mechanism equations so that they cannot be changed until a new system is \
built with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is useful when a mechanism is to be analyzed repeatedly through \
changing velocities, accelerations, or forces, at a constant location, \
velocity, or acceleration.  \[FilledSmallSquare]  The solution option is used \
to specify what order of dependent variables to lock.  \[FilledSmallSquare]  \
",
  StyleBox["Solution\[Rule]Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " locks the position and velocity of the model, so that accelerations and \
loads can still be calculated.  \[FilledSmallSquare]  Valid settings for ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  Using ",
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " significantly accelerates the operation of the higher-order and load \
solution blocks as it is no longer necessary to perform the replacement and \
evaluation of the unchanging variables.  \[FilledSmallSquare]  The default \
option is  ",
  StyleBox["Solution\[Rule]Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LocusPlot\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LocusPlot[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",...,",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rulesn",
    FontSlant->"Italic"],
  StyleBox["}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a graphics primitive representing the locus of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " as it moves through successive locations specified by the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LocusPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " simply returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " primitives.  \[FilledSmallSquare]  The required list of ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  " is of the form returned by ",
  StyleBox["SolveMech[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t1, t2, ti",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", n",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["MakeRules\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for several ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions that is used to specify which dependent variables to generate ",
  
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects for.\nThe default setting ",
  StyleBox["MakeRules\[Rule]{Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Generalized}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates rules for the location coordinates (",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...) and the generalized forces (",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...), if they are present, and also any system parameters. Settings for \
",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may be any subset of ",
  StyleBox["{Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Generalized}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The parameters and other constants are not interpolated.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Magnitude\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Magnitude[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the length of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also an option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Setting ",
  StyleBox["Magnitude\[Rule]Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied load to be equal to the length of the \
load vector times the given magnitude. The default setting is ",
  StyleBox["Magnitude\[Rule]Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Magnitude[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Magnitude[Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  Other ",
  StyleBox["Magnitude[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args...",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are interpreted as ",
  StyleBox["Magnitude[Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Distance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mass\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the mass of a body. The default setting is ",
  StyleBox["Mass\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Mass[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the mass of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The mass of each body is initially zero, unless otherwise specified.  \
\[FilledSmallSquare]  The default setting ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves the current mass unchanged.  \[FilledSmallSquare]  See also: ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["MassMatrix\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["MassMatrix[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the submatrix of the current system mass matrix associated with \
body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["MassMatrix[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" returns the entire system mass matrix.  \[FilledSmallSquare]",
    FontFamily->"Times"],
  "  The ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " argument may take any of the forms accepted by ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Centrifugal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["MaxError\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the maximum allowable estimated error in any \
dependent variable in a single time step. The default setting is ",
  StyleBox["MaxError\[Rule]0.0001",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is exceeded at any time step, the time step size is halved.  \
\[FilledSmallSquare]  The default error estimation algorithm used by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " assumes that the average magnitude of each of the dependent variables is \
near to one (which is clearly true for the Euler parameters or angular \
variables in units of radians).  \[FilledSmallSquare]  Setting ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to a larger value effectively relaxes the error estimation criteria that \
is used to adjust the time step size.  \[FilledSmallSquare]  The ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option can also be used to explicitly specify the error limits at which \
the time step size is halved or doubled, or when a corrective versus \
predictive step is taken.  \[FilledSmallSquare]  \n",
  StyleBox["MaxError\[Rule]{0.0001",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["0.00001",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["0.000001}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equivalent to the default setting.  \[FilledSmallSquare]  ",
  StyleBox["MaxError\[Rule]{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["a, b, c",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies that the time step size will be halved if the maximum error in \
the current step is greater than ",
  StyleBox["a",
    FontSlant->"Italic"],
  ". The step size will be doubled if the maximum error in any of the last ",
  StyleBox["2n",
    FontSlant->"Italic"],
  " steps drops below ",
  StyleBox["c,",
    FontSlant->"Italic"],
  " where ",
  StyleBox["n",
    FontSlant->"Italic"],
  " is the degree of the integrand fitting polynomial. An Adams-Moulton \
corrective step will be taken if the error in the current step is between ",
  StyleBox["a",
    FontSlant->"Italic"],
  " and ",
  StyleBox["b",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mech\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the symbol name for all ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " general messages."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["General",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["MechPrimitive\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["MechPrimitive",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of the ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " primitive generating functions that are returned by some ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics functions. ",
  StyleBox["MechPrimitive",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions will evaluate to a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives when all of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system symbols on which they depend are replaced by numbers."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " graphics functions return ",
  StyleBox["MechPrimitive",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects of the form: ",
  StyleBox["MechPrimitive[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["name, boolean, arg3, arg4,...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  All of the arguments of ",
  StyleBox["MechPrimitive",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " from argument three on must evaluate to numbers or lists of numbers for \
the entire ",
  StyleBox["MechPrimitive",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to evaluate to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives.  \[FilledSmallSquare]  See also: ",
  StyleBox["Sphere",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Torus",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Moment\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Moment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, mag",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object that applies a moment of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, vector, mag",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a load object that applies a moment of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ". In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", Specifying ",
  StyleBox["Magnitude\[Rule]Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied moment to be equal to the specified ",
  
  StyleBox["mag",
    FontSlant->"Italic"],
  " times the length of the direction ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Moment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2,...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the moment to body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " and also applies a moment in the opposite sense to body ",
  StyleBox["bnum2.\n",
    FontSlant->"Italic"],
  "\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox["CutOff    \[Rule] 0\nMagnitude \[Rule] Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Natural\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Natural",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies that the curvature of the spline shall be zero at the \
ends."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["Closed",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Omega\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Omega[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angular velocity of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the angular velocity is a vector of the form: {",
  StyleBox["Wx, Wy, Wz",
    FontSlant->"Italic"],
  "}.  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Omega",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a scalar.  \[FilledSmallSquare]  If the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method was specified with ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Omega",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angular velocity in terms o",
  StyleBox["f Euler pa",
    FontFamily->"Times"],
  "rameters and their derivatives.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Omega",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. The default setting is ",
  StyleBox["Coordinates\[Rule]Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Alpha",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["OriginLock2\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OriginLock2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " locks the position of body ",
  StyleBox["bnum1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  " to that of body ",
  StyleBox["bnum2. ",
    FontSlant->"Italic"],
  "The local origins of the two bodies are coincident. If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted, ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is located relative to the global origin. ",
  StyleBox["OriginLock2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OriginLock2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " forces the origin location of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to be equal to the origin location of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " plus the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  The first equation constrains the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate and the second constrains the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate.  \[FilledSmallSquare]  See also: ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["OriginLock3\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OriginLock3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " locks the position of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to that of body ",
  StyleBox["bnum2. ",
    FontSlant->"Italic"],
  "The local origins of the two bodies are coincident. If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted, ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is located relative to the global origin. ",
  StyleBox["OriginLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains three DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OriginLock3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " forces the origin location of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to be equal to the origin location of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " plus the given ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  The three equations in ",
  StyleBox["OriginLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain the ",
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinates, respectively.  \[FilledSmallSquare]  See also: ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["OrthogonalGears5\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OrthogonalGears5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, teeth1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, teeth2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pair of gears on orthogonal axes, such as a bevel gear set. The \
axes of the two gears, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", are constrained to be orthogonal, and the origins of these two axes are \
constrained to be coincident. The rotational positions of the two gears are \
related as per their respective tooth counts, ",
  StyleBox["teeth1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["teeth2. ",
    FontSlant->"Italic"],
  "Negating ",
  StyleBox["teeth1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["teeth2",
    FontSlant->"Italic"],
  " reverses the relative direction of rotation of the gears. ",
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains five DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OrthogonalGears5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, teeth1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, teeth2, dist, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " offsets the axes of the gears by ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units, such as the offset in a worm gear or spiral bevel gear set.  \
\[FilledSmallSquare]",
  StyleBox["  The symbol ",
    FontFamily->"Times"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" tracks the relative spin of ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]",
    FontFamily->"Times"],
  "  The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the two gears, is given by the \
formula ",
  StyleBox["C = teeth1 e1 + teeth2 e2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined in the following way. Place the two gears in any valid \
position. ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " is the projected angle, in radians, measured from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to the reference direction of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is the angle from ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to the reference direction of ",
  StyleBox["axis2.  ",
    FontSlant->"Italic"],
  "\[FilledSmallSquare]",
  StyleBox["\n",
    FontSlant->"Italic"],
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates six constraint equations and introduces one new variable, hence \
constraining five DOF.  \[FilledSmallSquare]  The first equation in ",
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be orthogonal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", the next two equations constrain the origins of the two axes to be \
adjacent, the fourth equation constrains the axes to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the fifth and sixth equations relate the value of the \
variable ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " to the relative rotation of the two gears.  \[FilledSmallSquare]  See \
also: ",
  StyleBox["ConstantVelocity4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Orthogonal1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Orthogonal1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be orthogonal to ",
  StyleBox["vector2. ",
    FontSlant->"Italic"],
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["Parallel1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["OrthoRevolute4\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OrthoRevolute4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and to be orthogonal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". Further, the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie directly adjacent to the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains four DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pair of hinges with orthogonal axes and a specified offset \
distance separating the two axes.  \[FilledSmallSquare]  ",
  StyleBox["OrthoRevolute4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " assumes the separation distance to be zero.  \[FilledSmallSquare]  The \
first equation in ",
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to be adjacent to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", the second equation constrains the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be adjacent to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", the third constrains the separation distance to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units, the fourth constrains the two axes to be orthogonal.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["ParaRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ParallelAxis\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ParallelAxis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vec, mass, inertia",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the parallel axes theorem to transform the inertia properties of a \
body into or out of a centroidal reference frame. Assuming that the given \
inertia properties are centroidal, ",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the inertia properties relative to a noncentroidal reference \
frame in which ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " is the vector from the origin of the noncentroidal frame to the centroid \
of the body."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The sign of the specified vector pointing to the centroid of the body is \
irrelevant.  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", inertia is specified by a scalar.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the inertia of the body is specified by a list of the elements of the \
inertia matrix: {",
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontSlant->"Italic"],
  "};  ",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " then returns the list {",
  StyleBox["Ixx', Iyy', ...",
    FontSlant->"Italic"],
  "} of inertia properties relative to the noncentroidal reference frame.  \
\[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParallelAxis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["centroid, mass, inertia, rotation",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify that the centroidal reference frame in which the \
specified inertia properties are calculated is rotated relative to the \
noncentroidal frame. The ",
  StyleBox["rotation",
    FontSlant->"Italic"],
  " of the centroidal frame is specified by ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["angle, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]\nTo transform noncentroidal inertia properties \
into a centroidal reference frame: ",
  StyleBox["vec",
    FontSlant->"Italic"],
  " is the vector (in the centroidal reference frame) from the centroid to \
the origin of the noncentroidal reference frame, ",
  StyleBox["rotation",
    FontSlant->"Italic"],
  " specifies the relative rotation (in the centroidal reference frame) of \
the noncentroidal frame, and a negative ",
  StyleBox["mass",
    FontSlant->"Italic"],
  " is specified.  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", simply negate ",
  StyleBox["mass",
    FontSlant->"Italic"],
  " to transform noncentroidal properties into a centroidal reference frame.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["CompositeInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PrincipalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ParallelGears4\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ParallelGears4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, rad2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a gear set. Constraint is identical to ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " except that the heads of the two axes are not constrained to be adjacent. \
Thus, the two gears can slide on their axes, relative to each other. ",
  StyleBox["ParallelGears4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains four DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ParallelGears4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is essentially ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the third equation dropped.  \[FilledSmallSquare]  See also: ",
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ParallelGears5\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ParallelGears5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, rad2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a gear set. The axes of the two gears, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " are constrained to be parallel and ",
  StyleBox["rad1+rad2",
    FontSlant->"Italic"],
  " units apart, and the heads of the two axes are constrained to be \
adjacent. The rotational positions of the gears are related as per their \
respective radii. ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains five DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The symbol ",
    FontFamily->"Times"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" tracks the spin of ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", relative to a vector spanning from ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" to ",
    FontFamily->"Times"],
  StyleBox["axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  "The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the gears, is given by the formula ",
  
  StyleBox["C = rad1 e1 + rad2 e2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined in the following way. Place the two gears in any valid \
position and construct a vector from the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis2. e1",
    FontSlant->"Italic"],
  " is the angle, in radians, measured from the constructed vector to the \
reference direction of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is measured from the vector to the reference direction of ",
  StyleBox["axis2.  ",
    FontSlant->"Italic"],
  "\[FilledSmallSquare]\n",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates six constraint equations and introduces one new variable, hence \
constraining five DOF.  \[FilledSmallSquare]  The first two equations in ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", the third equation constrains the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to lie adjacent to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", the fourth equation constrains the axes to be ",
  StyleBox["rad1+rad2",
    FontSlant->"Italic"],
  " units apart, and the fifth and sixth equations relate the value of the \
variable ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " to the rotational displacements of the gears.  \[FilledSmallSquare]  See \
also: ",
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Parallel1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parallel1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["vector2. ",
    FontSlant->"Italic"],
  StyleBox["Parallel1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parallel1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not sensitive to the sign of the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  The constraint is satisfied if the two vectors \
are pointing in exact opposite directions.  \[FilledSmallSquare]  See also: ",
  
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Parallel2\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parallel2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  " to be parallel in 3D space. ",
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parallel2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not sensitive to the sign of the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  The constraint is satisfied if the two vectors \
are pointing in exact opposite directions.  \[FilledSmallSquare]  See also: ",
  
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Parallel1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Parameterize\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parameterize[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes the given symbols (each of which must have a numeric value defined) \
unsets them and puts them in the parameters list with a current value equal \
to their previously defined value."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "For example, ",
  StyleBox["(c = 3.5; Parameterize[c])",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has the same effect as ",
  StyleBox["SetParameters[c\[Rule]3.5]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  Upon success, ",
  StyleBox["Parameterize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entir",
  StyleBox["e parameters l",
    FontFamily->"Times"],
  "ist.  \[FilledSmallSquare]  See also: ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Parameters\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Parameters[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the current ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " parameters list. ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also an element of the setting for the ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. ",
  StyleBox["MakeRules\[Rule]{Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the current parameters to be included in the returned rules. ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also an option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the value of the spline parameter at each knot point."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "As an option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be either a list of numbers in ascending order, equal in length to \
the number of data points given, or ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is equivalent to specifying a list of integers ascending from \
zero.  \[FilledSmallSquare]  Specifying the ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " allows the spacing of the knot points for the spline independent variable \
to be altered.  \[FilledSmallSquare]  See also: ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ParaRevolute4\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ParaRevolute[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from, and parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". Further, the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie directly adjacent to the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["ParaRevolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains four DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ParaRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pair of hinges with parallel axes and a specified offset \
distance separating the two axes.  \[FilledSmallSquare]  ",
  StyleBox["ParaRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " becomes singular if the separation distance is zero; use ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The first two equations in ",
  StyleBox["ParaRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to be parallel, the third constrains the origins of the two axes to be \
adjacent, and the fourth constrains the separation distance to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PathSystem\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of the data object returned by ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The format of the ",
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object is ",
  StyleBox["PathSystem[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " differentialequations, timesym, variables, initialconditions, parameters, \
primerules",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Plane\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Plane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt1, lpnt2, lpnt3",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object that specifies three local points on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " that define a plane. The ",
  StyleBox["lpnti",
    FontSlant->"Italic"],
  " can be point numbers (positive integers) referencing points that were \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or they can be coordinates ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of points in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Plane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2, point3",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses three ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " point objects to define the plane."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used in place of a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " vector object, the plane's normal provides the direction of the vector.  \
\[FilledSmallSquare]  If a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used in place of a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " axis object, the plane's origin (",
  StyleBox["point1",
    FontSlant->"Italic"],
  ") provides the origin of the axis, the plane normal provides the direction \
vector, and the line from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " provides the rotational reference vector of the axis.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlaneToCircle1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PlaneToCircle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, rad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains a plane that is normal to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie tangent to a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", centered at the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", with normal vector in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PlaneToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PlaneToCircle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, majrad, minrad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the plane that is normal to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie tangent to the surface of a torus of major radius ",
  StyleBox["majrad",
    FontSlant->"Italic"],
  " and minor radius ",
  StyleBox["minrad",
    FontSlant->"Italic"],
  ", centered at the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " with major axis specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["LineToCircle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PlaneToPlane3\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PlaneToPlane3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and constrains the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", in the direction of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PlaneToPlane3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains three DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PlaneToPlane3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two planes that are normal to the two specified axes to be \
coincident.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Point\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " data object that specifies a point on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a point number (positive integer) referencing a point that was \
defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or it can be the coordinates, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", of a point in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A simple vector ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " given in place of a ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is interpreted as ",
  StyleBox["Point[1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointAtIntersection3\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointAtIntersection3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie at the intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and a plane that is specified by ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PointAtIntersection3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains three DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is typically a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, but the plane may be specified by its origin and normal direction \
with any ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " axis object.  \[FilledSmallSquare]  See also: ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointLabel\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointLabel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " labels ",
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", just to the right of the local point.\n",
  StyleBox["PointLabel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " labels all of the points on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " that were defined with a body object."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The point label generated is of the form ",
  StyleBox["<",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  " ",
  StyleBox[">",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["LocalAxes",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointList\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify a list of local point coordinates on a body. ",
  StyleBox["PointList\[Rule]{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x1, y1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x2, y2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",...,",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["xn, yn",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (2D) or ",
  StyleBox["PointList\[Rule]{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x1, y1, z1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",...,",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["xn, yn, zn",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (3D) specifies ",
  StyleBox["n",
    FontSlant->"Italic"],
  " points on the body that are referenced by their point numbers 1 through ",
  
  StyleBox["n",
    FontSlant->"Italic"],
  ". The specified list replaces any points that are currently defined on the \
body. ",
  StyleBox["PointList\[Rule]{}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " removes all points currently on the body. The default setting ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves points that were previously defined unchanged. ",
  StyleBox["PointList[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontSlant->"Italic"],
  "] returns the local coordinates of point ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If no points are specified for a body, no default values are set for the \
points;  unspecified points are not set to zero.  \[FilledSmallSquare]  \
Referencing a point number of a point that has not been specified generates \
an error.  \[FilledSmallSquare]  The default setting ",
  StyleBox["PointList\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " leaves the current points table unchanged.  \[FilledSmallSquare]  See \
also: ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnCircle2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnCircle2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, rad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the perimeter of a circle of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", with axis specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The center of the circle lies at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PointOnCircle2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["axis",
    FontSlant->"Italic"],
  " may be specified by a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.  \[FilledSmallSquare]  If a ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is used, the circle lies in the plane, centered at the origin of \
the plane.  \[FilledSmallSquare]  ",
  StyleBox["PointOnCircle2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is singular if ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " becomes equal to zero; use",
  StyleBox[" Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The first equation constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie in the plane of the circle, the second equation constrains the \
distance between ",
  StyleBox["point",
    FontSlant->"Italic"],
  " and the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnPlanes2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnCone1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnCone1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, ang",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a cone of half angle ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ". The axis of the cone is specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and the vertex of the cone lies at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PointOnCone1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnCone1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " becomes singular as ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " approaches zero or as ",
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  " passes though the vertex of the cone.  \[FilledSmallSquare]  Use ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " instead.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnCylinder1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnCylinder1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnCylinder1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, rad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a cylinder of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ". The axis of the cylinder is specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PointOnCylinder1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["axis",
    FontSlant->"Italic"],
  " may be a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.  \[FilledSmallSquare]  ",
  StyleBox["PointOnCylinder1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is singular if ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " becomes equal to zero; use ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnCone1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnLines2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnLines2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie at the intersection of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PointOnLines2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnLines2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is essentially the same as two ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints.  \[FilledSmallSquare]  The first equation constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", and the second constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnLine1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a planar slider in which ",
  StyleBox["point",
    FontSlant->"Italic"],
  " is constrained to lie on ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " may be a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " places ",
  StyleBox["point",
    FontSlant->"Italic"],
  " ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units to the left of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["PointOnLine1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, dist, ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to move along a line that is rotated ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians counterclockwise relative to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and located ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units to the left of the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", measured perpendicular to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["DirectedDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnLine2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnLine2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a spatial slider in which ",
  StyleBox["point",
    FontSlant->"Italic"],
  " is constrained to lie on ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["axis",
    FontSlant->"Italic"],
  " may be specified by a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.  \[FilledSmallSquare]  The two equations constrain a vector from \
",
  StyleBox["point",
    FontSlant->"Italic"],
  " to the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " to be orthogonal to a pair of vectors that are mutually perpendicular to \
",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnCircle2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnPlanes2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnPlanes2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnPlanes2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the intersection of two planes specified by their axes. ",
  StyleBox["PointOnPlanes2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnPlanes2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is essentially just two ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints.  \[FilledSmallSquare]  The two axes are typically specified \
by ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects.  \[FilledSmallSquare]  The first equation constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the plane normal to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", and the second constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the plane normal to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnCircle2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnLine2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnPlane1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnPlane1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie within a plane specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " is typically a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnPlane1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, dist",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units away from the plane specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", in the direction of the plane's positive normal.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["DirectedDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointOnTorus1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointOnTorus1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, axis, majrad, minrad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie on the surface of a torus of major radius ",
  StyleBox["majrad",
    FontSlant->"Italic"],
  " and minor radius ",
  StyleBox["minrad",
    FontSlant->"Italic"],
  " that has its major axis specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The center of the torus is at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["PointOnTorus1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Note that ",
  StyleBox["PointOnTorus1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is inherently a very nonlinear constraint, and as such very good initial \
guesses are usually required.  \[FilledSmallSquare]  ",
  StyleBox["PointOnTorus1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is singular if ",
  StyleBox["majrad",
    FontSlant->"Italic"],
  " or ",
  StyleBox["minrad",
    FontSlant->"Italic"],
  " become equal to zero; use ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["PointOnCircle2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnCylinder2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointToLineDistance\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointToLineDistance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the shortest distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a negative return value indicates that ",
  StyleBox["point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  " lies to the right of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  If ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " is specified with a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, the shortest distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to the plane's normal is returned.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointToPlaneDistance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointToLocal\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointToLocal[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the local coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", in the coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When called with a ",
  StyleBox["point",
    FontFamily->"Times"],
  " specified in global coordinates, ",
  StyleBox["PointToLocal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is essentially the inverse function of ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  For example,\n",
  StyleBox[
  "Expand[Location[2, PointToLocal[2, {5.0, 8.0}] ], Trig\[Rule]True] \
-\[Rule] {5.0, 8.0}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PointToPlaneDistance\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PointToPlaneDistance[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the shortest distance from ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to a plane. The plane's normal is specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["axis",
    FontSlant->"Italic"],
  " is typically a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, but may be any axis object specifying the plane's normal and \
origin.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointToLineDistance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PolarToXY\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PolarToXY[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius, angle",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converts the given point from polar to Cartesian coordinates and returns \
",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PolarToXY",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " simply returns:  ",
  StyleBox["radius",
    FontSlant->"Italic"],
  " {",
  StyleBox["cos(angle), sin(angle)",
    FontSlant->"Italic"],
  "}.  \[FilledSmallSquare]  See also: ",
  StyleBox["XYToPolar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Predictor\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Predictor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["Predictor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " method uses an Adams-Bashforth predictor integration algorithm."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When ",
  StyleBox["Method\[Rule]Predictor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified in ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", instead of the default setting ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the integrator never takes a corrective Adams-Moulton step regardless of \
the error estimate of the current step.  \[FilledSmallSquare]  See also: ",
  StyleBox["Corrector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["PrincipalAxes\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["PrincipalAxes[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["I1, I2, I3",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1, axis2, axis3",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", where ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["I1, I2, I3",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are the principal moments of inertia and ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1, axis2, axis3",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are the corresponding principal axes of the body represented by the given \
inertia properties."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["axis3",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is actually the rotation matrix from the reference frame in which the \
inertia properties were specified to the principal axes reference frame.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["CentroidalInertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParallelAxis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ProjectedAngle\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ProjectedAngle[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1, vector2, vector3",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the counterclockwise angle measured from the direction of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " to the direction of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", as projected on a plane that is orthogonal to ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ProjectedAngle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns values in the range {-pi, pi}.  \[FilledSmallSquare]  See also: ",
  
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["IncludedAngle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ProjectedAngle1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ProjectedAngle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2, vector3, ang",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the angle of the projection of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  ", relative to the projection of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", to be equal to ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ", when the two vectors are projected onto a plane that is normal to ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  ". The sense of the angle is determined by the right-hand rule, relative to \
",
  StyleBox["vector3",
    FontSlant->"Italic"],
  ". ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ProjectedAngle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector, axis, ang",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the direction vector of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " in place of ",
  StyleBox["vector3",
    FontSlant->"Italic"],
  ", and uses the reference direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " in place of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  This alternate form is useful for projecting the \
vector onto a plane specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and measuring the angle relative to the primary axis of the plane.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ProjectOnLine\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ProjectOnLine[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " projects ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " onto ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " and returns the vector component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is in the direction of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".\n",
  StyleBox["ProjectOnLine[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " orthogonally projected onto ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ProjectOnLine[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1, vector2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the dot product of the ",
  StyleBox["vectori",
    FontSlant->"Italic"],
  ", divided by the magnitude of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["PointToLineDistance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ProjectOnPlane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ProjectOnPlane\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ProjectOnPlane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector1, vector2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " projects ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " onto a plane that is normal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " and returns the vector component of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " that is orthogonal to ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["ProjectOnPlane[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the coordinates of ",
  StyleBox["point",
    FontSlant->"Italic"],
  " orthogonally projected onto a plane that is normal to ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["axis",
    FontSlant->"Italic"],
  ", or ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", is typically specified with a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointToPlaneDistance",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ProjectOnLine",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Quadratic\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies a quadratic approximation of each section of the integrand."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is generally less accurate than ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", but faster.  \[FilledSmallSquare]  ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses quadratic interpolation for the predictor step, and cubic \
interpolation for the corrector step.  \[FilledSmallSquare]  See also: ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Quartic\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies a quartic approximation of each section of the integrand."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is generally more accurate than ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", but slower.  \[FilledSmallSquare]  ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses quartic interpolation for the predictor step, and quintic \
interpolation for the corrector step.  \[FilledSmallSquare]  See also: ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RackAndPinion2\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RackAndPinion2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, rad, axis, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a rack and pinion gear set. The center of the pinion (",
  StyleBox["point",
    FontSlant->"Italic"],
  ") is constrained to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units to the left of the rack (",
  StyleBox["axis",
    FontSlant->"Italic"],
  ") and the angular orientation of the rack and pinion are related as per \
the pinion radius. The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " sets the initial orientation of the rack and pinion. ",
  StyleBox["RackAndPinion2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " is the distance, in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", from the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point",
    FontSlant->"Italic"],
  " when the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the pinion is parallel to the rack.  \[FilledSmallSquare]  If the \
",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method is specified, ",
  StyleBox["RackAndPinion2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates three constraints, and adds one extra variable to the model. ",
  StyleBox["RackAndPinion2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point, rad, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to explicitly specify the name of the extra variable ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  ", and its initial guess. Otherwise, a symbol of the form ",
  StyleBox["Th",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  " is used.  \[FilledSmallSquare]  The first equation in ",
  StyleBox["RackAndPinion2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point",
    FontSlant->"Italic"],
  " to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units to the left of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". The second, and optional third, equations relate the axial displacement \
of the rack to the rotation of the pinion.  \[FilledSmallSquare]  See also: ",
  
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RackAndPinion4\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RackAndPinion4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, C",
    FontSlant->"Italic"],
  "] is identical to ",
  StyleBox["RackAndPinion5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " except that the heads of the two axes are not constrained to be adjacent. \
Thus, the pinion is free to slide on its axis, relative to the rack. ",
  StyleBox["RackAndPinion4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains four DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RackAndPinion4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is essentially ",
  StyleBox["RackAndPinion5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the fourth equation dropped.  \[FilledSmallSquare]  See also: ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LeadScrew5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RackAndPinion5\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RackAndPinion5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis2, C",
    FontSlant->"Italic"],
  "] models a rack and pinion gear set. ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " represents the rotational axis of the pinion, and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " represents the rack. ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is parallel to the cut of the teeth of the rack, and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and its reference direction lie in the plane of the rack. ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is constrained to lie ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units away from, and parallel to, ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", and the origins of the two axes are constrained to be adjacent. The \
rotational orientation of the pinion is related to that of the rack as per \
the pinion radius. The symbol ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " is used as the pinion rotation variable. ",
  StyleBox["RackAndPinion5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains five DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RackAndPinion5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates six constraint equations and introduces one new variable, hence \
constraining five DOF.  \[FilledSmallSquare]  The two equations in ",
  StyleBox["RackAndPinion5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", the third equation places the pinion axis ",
  StyleBox["rad",
    FontSlant->"Italic"],
  " units away from the rack, the fourth equation constrains the origin of \
the pinion to be adjacent to the origin of the rack, the fifth equation \
relates the axial displacement of the rack to the rotation of the pinion, and \
the sixth relates the value of the variable ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " to the rotation of the pinion.  \[FilledSmallSquare]  See also: ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["LeadScrew5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Reaction\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum, point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction loads applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", calculated about the specified ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". Loads are returned in the format: ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["force, moment",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the option ",
  StyleBox["Coordinates\[Rule]Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return the load vectors in local coordinates, relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is also a setting for the ",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction force applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", calculated about local point ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction force applied to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", calculated about the local origin of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  The constraint number specification, ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", can be replaced with any of the specific constraint equation \
specifications accepted by ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  Note that only the reaction moment is a function \
of the location of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". Reaction forces are not dependent on the point about which they are \
calculated.  \[FilledSmallSquare]  The default option setting is ",
  StyleBox["Coordinates\[Rule]Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]\n",
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, symbol",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to a particular ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  ", in consistent force or moment units. ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " must be a coordinate or parameter that occurs in the current model's \
constraint equations.  \[FilledSmallSquare]  The meaning of the quantity \
returned by ",
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, symbol",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " depends on the nature of the occurrence of ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " in the model. For example, if a parameter named ",
  StyleBox["len",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the length of a simple connecting link in the mechanism, the \
value of ",
  StyleBox["Reaction[All, len]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " corresponds to the tension in the connecting link.  \[FilledSmallSquare]  \
If ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " occurs in the model in a very complicated and interlinked manner the \
value returned by ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has little physical meaning.  \[FilledSmallSquare]  The alternatives to \
the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting for the ",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are ",
  StyleBox["Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ReferenceDirection\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ReferenceDirection[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reference direction associated with ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". This is a vector that is not parallel to the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The reference direction of an axis may be explicitly specified with ",
    FontFamily->"Times"],
  StyleBox["Axis[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["origin, dir, refdir",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ".  \[FilledSmallSquare]  Reference directions are used by some constraints \
to control the spin of a body about ",
    FontFamily->"Times"],
  StyleBox["axis",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  ".  \[FilledSmallSquare]  Unspecified reference directions are chosen \
automatically. For example,\n",
    FontFamily->"Times"],
  StyleBox["ReferenceDirection[Axis[{0,0,0},{1,0,0}]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" -\[Rule] ",
    FontFamily->"Times"],
  StyleBox["{0,1,0}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  "See also: ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Relative\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["Magnitude\[Rule]Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied load to be equal to the specified \
magnitude times the length of the vector used to specify the direction of the \
load."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Magnitude\[Rule]Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied load to be equal to the magnitude \
specified in the ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeAngle1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RelativeAngle1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, vector1, vector2 , ang",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the angle between ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " to be equal to ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ". ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is sensitive to the sign of ",
  StyleBox["ang",
    FontSlant->"Italic"],
  "; the direction angle of ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " is explicitly constrained to be ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians greater than the direction angle of ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  ", in the counterclockwise sense.  \[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", if ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " is omitted it is assumed to be the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis.  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not sensitive to the sign of ",
  StyleBox["ang",
    FontSlant->"Italic"],
  "; the included angle between ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["vector2",
    FontSlant->"Italic"],
  " is constrained to be equal to |",
  StyleBox["ang",
    FontSlant->"Italic"],
  "|.  \[FilledSmallSquare]  See also: ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeDistance1\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RelativeDistance1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a connecting link. The absolute distance from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is constrained to be equal to ",
  StyleBox["dist",
    FontSlant->"Italic"],
  ". ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " effectively constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie on a circle of radius ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " that is centered about ",
  StyleBox["point2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to lie on a sphere of radius ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " that is centered at ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is singular if ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " becomes equal to zero; use ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " instead.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnCircle2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeVelocity\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RelativeVelocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the velocity of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ", relative to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", in global coordinates."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RelativeVelocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a generalization of the ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function that can return the velocity of a point relative to some \
reference frame other than the global reference frame.  \[FilledSmallSquare]  \
",
  StyleBox["RelativeVelocity[1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is identical to ",
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeX1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RelativeX1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is omitted, the offset distance is measured relative to the global \
origin.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeY1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RelativeY1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["RelativeY1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is omitted, the offset distance is measured relative to the global \
origin.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RelativeZ1\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RelativeZ1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2, dist",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units greater than the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinate of ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["RelativeZ1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " is omitted, the offset distance is measured relative to the global \
origin.  \[FilledSmallSquare]  See also: ",
  StyleBox["PointOnPlane1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RequiredEquations",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies which equations, of a constraint that restrains more than \
one DOF, are to be retained in seeking the switch time. ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be a two element list; the first element applies to the first set \
of equations of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " pair, the second element applies to the second set. Allowable values for \
each element are the following: an integer, a list of integers (1 through the \
number of DOF's in the constraint), ",
  StyleBox["All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Sum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["RequiredEquations\[Rule]{All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Sum}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, all of the constraints in the associated side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint are included.  \[FilledSmallSquare]  ",
  StyleBox["Sum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes the sum of all equations in the associated side of the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint and uses the sum for a single constraint.  \
\[FilledSmallSquare]  Using the ",
  StyleBox["Sum",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting can lead to a singularity.  \[FilledSmallSquare]  The normal \
method of specifying ",
  StyleBox["RequiredEquations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is to specify ",
  StyleBox["All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for one side and specify a single integer equation number for the other.  \
\[FilledSmallSquare]  If equation numbers are specified for both sides of the \
",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the total number of equations specified must be equal to one plus the \
number of DOF's constrained by the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Revolute2",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolute2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a rotational joint. ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " is constrained to be coincident with ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used in 2D models to model a shaft in a bearing, or a revolving hinge. \
 \[FilledSmallSquare]  The two equations constrain the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinates of the two points to be coincident.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Revolute5",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolute5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " and constrains the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be coincident with the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains five DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a hinge or revolving bearing.  \[FilledSmallSquare]  The first \
three equations constrain the ",
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinates of the origins of the two axes to be coincident, and the last \
two equations constrain the two axes to be parallel.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Translate5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Revolve",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolve[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, point2, ..., pointn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", axis, facets",
    FontSlant->"Italic"],
  "] revolves the sequence of ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-1 lines between the specified ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  " about ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", using ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " segments. ",
  StyleBox["Revolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Revolve[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum,",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["lpnt1, ..., lpntn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["axis, facets",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" revolves the ",
    FontFamily->"Times"],
  StyleBox["n",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["-1 lines connecting the local points ",
    FontFamily->"Times"],
  StyleBox["lpnti",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" located on body ",
    FontFamily->"Times"],
  StyleBox["bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  StyleBox["Revolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not close the ends of the surface of revolution unless ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["pointn",
    FontSlant->"Italic"],
  " lie on the axis of revolution.\n\[FilledSmallSquare]  The default option \
settings are:\n",
  StyleBox["Angle \[Rule] {0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["2 Pi}\nFaces \[Rule] True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Extrude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RMatrix",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 2D orthogonal rotation matrix ",
  StyleBox["{{0, -1}, {1, 0}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["IMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Rotation",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Rotation[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angle of rotation associated with the orientation of 2D body \
",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", or the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, axis",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifying the angle and axis of rotation associated with 3D body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Rotation[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["matrix",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angle associated with the given 2D or 3D rotation matrix.  \
\[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotation[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ei",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["ej",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the angle of rotation represented by the Euler parameters, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ei, ej",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotation[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eo",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["ei",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["ej",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["ek",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, axis",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " where the given Euler parameters, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eo, ei, ej, ek",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", imply a rotation of ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about the vector ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["EulerParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationMatrix",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RotationLock1",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RotationLock1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2, ang",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the angular coordinate of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to be ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " units greater than the angular coordinate of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ". If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted, ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is oriented relative to the global coordinate system. ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " is omitted it defaults to zero, causing the two bodies to be rotationally \
aligned.  \[FilledSmallSquare]  Note that ",
  StyleBox["RotationLock1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum, integer",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " interprets ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " as ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ", not ",
  StyleBox["ang",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RotationLock3",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RotationLock3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " locks the angular orientation of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to that of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ". The angular orientation of ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is identical to that of ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ". If ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " is omitted, ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is oriented relative to the global coordinate system. ",
  StyleBox["RotationLock3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains three DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RotationLock3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontFamily->"Times",
    FontSlant->"Italic"],
  "}",
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the angular orientation of body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " to be rotated ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about the specified axis ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " relative to ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  The axis of rotation is specified in the local \
coordinate system of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["RotationLock3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum1, bnum2, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang1, axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ..., ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["angn, axisn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " successively rotates body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " by ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang1, axis1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", then ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang2, axis2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on. ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " is specified in the local coordinates of body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ", but ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " is specified in a new coordinate system created by rotating ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " through the first rotation;  thus ",
  StyleBox["axis3",
    FontSlant->"Italic"],
  " is specified in the local coordinates created by rotating ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " through the first then the second rotation, etc.  \[FilledSmallSquare]  \
Another way to describe the resulting rotation of ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is to say that ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " is first rotated ",
  StyleBox["angn",
    FontSlant->"Italic"],
  " about ",
  StyleBox["axisn",
    FontSlant->"Italic"],
  ", specified in ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " coordinates, then rotated ",
  StyleBox["ang(n-1)",
    FontSlant->"Italic"],
  " about ",
  StyleBox["axis(n-1)",
    FontSlant->"Italic"],
  ", also specified in ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  " coordinates, etc.  \[FilledSmallSquare]  See also: ",
  StyleBox["ProjectedAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["RotationMatrix",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["RotationMatrix[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the 2D/3D rotation matrix associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",",
    FontFamily->"Times"],
  StyleBox[" ",
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox["RotationMatrix[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["RotationMatrix[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ei, ej",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the rotation matrix associated with the angle or Euler \
parameters.  \[FilledSmallSquare]  The 2D rotation matrix is defined as {{",
  StyleBox["cos(ang), -sin(ang)",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["sin(ang), cos(ang)",
    FontSlant->"Italic"],
  "}}. In terms of 2D Euler parameters, the rotation matrix is simply {{",
  StyleBox["ei, -ej",
    FontSlant->"Italic"],
  "}, {",
  StyleBox["ej, ei",
    FontSlant->"Italic"],
  "}}.  \[FilledSmallSquare]\nIn ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ",",
  StyleBox[" RotationMatrix[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang, vector",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or",
  StyleBox[" RotationMatrix[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eo, ei, ej, ek",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the rotation matrix associated with a rotation of ",
  StyleBox["ang",
    FontSlant->"Italic"],
  " radians about ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ", or associated with the given Euler parameters.  \[FilledSmallSquare]  \
The 3D rotation matrix in terms of Euler parameters is defined as: \n",
  StyleBox["2",
    FontSlant->"Italic"],
  " {{",
  StyleBox["eo^2+ei^2-1/2,    ei ej - eo ek,        ei ek + eo ej       ",
    FontSlant->"Italic"],
  "}, \n      {",
  StyleBox["ei ej + eo ek,       eo^2+ej^2-1/2,    ej ek - eo ei        ",
    FontSlant->"Italic"],
  "}, \n      {",
  StyleBox["ei ek - eo ej,        ej ek + eo ei,        eo^2+ek^2-1/2  ",
    FontSlant->"Italic"],
  "}}.\n\[FilledSmallSquare]  See also: ",
  StyleBox["EulerParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SaveMech",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SaveMech[\"",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["file",
    FontSlant->"Italic"],
  StyleBox["\"]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " saves the entire state of the current ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " system in file such that it can be restored with ",
  StyleBox["Get[\"",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["file",
    FontSlant->"Italic"],
  StyleBox["\"]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When reloading a model has been saved with ",
  StyleBox["SaveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " it is not necessary to first call ",
  StyleBox["Needs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " on ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". Th",
    FontFamily->"Times"],
  "e necessary ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages are reloaded by simply by loading the saved model with ",
  StyleBox["Get",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SaveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attempts to save all references to user-defined variables upon which the \
current model depends.  \[FilledSmallSquare]  See also: ",
  StyleBox["KillMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SensitivitySystem",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of the data object returned by ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The format of the ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object is ",
  StyleBox["SensitivitySystem[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  "symbollist, initialconditions, Jacobian, constraintderivatives, variables",
    
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetBodies",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetBodies[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bodies",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " incorporates the local coordinates, initial guesses, and inertia \
properties provided by the ",
  StyleBox["bodies",
    FontSlant->"Italic"],
  " into the current mechanism model. The ",
  StyleBox["bodies",
    FontSlant->"Italic"],
  " must be a list or sequence of ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data objects that are built by the ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If any of the ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects received by ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " contains new point coordinate specifications ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatically rebuilds the entire system of constraint expressions in the \
current model so that the changed coordinates are reflected in the current \
model.  \[FilledSmallSquare]  If none of the ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects contains the ",
  StyleBox["PointList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " only updates the necessary mass properties or initial guesses.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetConstraints",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetConstraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["constraints",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the mathematical mechanism model represented by ",
  StyleBox["constraints",
    FontSlant->"Italic"],
  ". The constraints must be a list or sequence of ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data objects that are returned by any of the standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint functions. The ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to specify that the initial guesses shall be reset to the \
defaults, regardless of whether or not they must be. The ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option determines which system equations are built immediately."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "With ",
  StyleBox["BuildMech\[Rule]Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not immediately build the equations necessary for the velocity and \
acceleration solutions, or the generalized force solution; these equations \
are built automatically when ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is called with nondefault settings for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.  \[FilledSmallSquare]  ",
  StyleBox["BuildMech\[Rule]Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be used to immediately build all possible equations.  \
\[FilledSmallSquare]  ",
  StyleBox["BuildMech\[Rule]None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to prevent any equation building. If constraints are given \
that contain local point numbers of points that are not yet defined, ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is automatically set to ",
  StyleBox["None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with a warning.  \[FilledSmallSquare]  ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " goes through the following steps in testing the constraints for validity: \
\n    1.  Check that all of the extra variables in special constraints (cam \
constraints, 3D gear constraints, and the user-defined ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") are unique. \n    2.  Check that each constraint has a unique constraint \
number, ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". \n    3.  Check that the number of DOF's constrained is equal to the \
number of dependent variables. \n    4.  Check that all of the local points \
that are specified by point number have been defined, unless ",
  StyleBox["BuildMech\[Rule]None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified.\n    5.  Check that all of the symbols that are to be used \
as dependent variables are not protected and have no definition or \
attributes.\n\[FilledSmallSquare]  ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, which causes the constraint and load expressions to be compiled \
at build time. Setting ",
  StyleBox["Compiled\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can decrease run time by more than a factor of two for large systems.  \
\[FilledSmallSquare]  Some types of expressions cannot be compiled. If the \
evaluation of the compiled constraints fails, incorrect results will be \
returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " because ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " does not store the symbolic form of the constraints along with the \
compiled form.\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox[
  "BuildMech \[Rule] Location\nCompiled  \[Rule] False\nSetGuess  \[Rule] \
False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetCouple",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetCouple[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, eq,",
    FontSlant->"Italic"],
  " ",
  StyleBox["Time\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in which the value of the symbol ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " is sought that satisfies the equation ",
  StyleBox["eq",
    FontSlant->"Italic"],
  " at time = ",
  StyleBox["t",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetCouple[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, sym2, ..., symn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eq1, eq2, ..., eqn",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontSlant->"Italic"],
  StyleBox["Time\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the ",
  StyleBox["n",
    FontSlant->"Italic"],
  " equations to try to solve for ",
  StyleBox["n",
    FontSlant->"Italic"],
  " symbols.  \[FilledSmallSquare]  ",
  StyleBox["SetCouple[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["syms...",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["equations1, ",
    FontSlant->"Italic"],
  " ",
  StyleBox["Time\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t1, options1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["equations2, ",
    FontSlant->"Italic"],
  StyleBox["Time\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t2, options2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...",
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attempts to find the values of the ",
  StyleBox["syms",
    FontSlant->"Italic"],
  " that satisfy all of the ",
  StyleBox["equationsi",
    FontSlant->"Italic"],
  " at different points in time.  \[FilledSmallSquare]\nIf ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is unspecified, ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the initial guesses from the current model, as obtained from ",
  StyleBox["LastSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  If the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is specified with too low a setting (such as if ",
  StyleBox["Solution\[Rule]Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified but the equation ",
  StyleBox["eq",
    FontSlant->"Italic"],
  " contains velocity terms) ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatically adjusts to a higher-order solution.  \[FilledSmallSquare]  \
",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Time\[Rule]Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to force time to be considered to be a dependent variable, which \
adds one DOF to the model and requires one additional equation for each \
occurrence of ",
  StyleBox["Time\[Rule]Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox[
  "Solution     \[Rule] Automatic\nInitialGuess \[Rule] Automatic\nCompiled   \
  \[Rule] False\nTime         \[Rule] None\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\[FilledSmallSquare]  See also: ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetFree",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dropcon, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the mathematical equations required to find equilibrium conditions \
of the current model. The ",
  StyleBox["dropcon",
    FontSlant->"Italic"],
  " argument is used to specify the constraint number(s) that are dropped to \
make the system underconstrained. The ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option specifies whether to seek ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " equilibrium."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is unspecified, ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the current model initial guesses, as obtained from ",
  StyleBox["LastSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can also be specified in ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The format of ",
  StyleBox["dropcon",
    FontSlant->"Italic"],
  " is identical to that used by the ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function.  \[FilledSmallSquare]  If ",
  StyleBox["Solution\[Rule]Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, the model must have some nonzero applied loads for a static \
equilibrium position to exist.  \[FilledSmallSquare]  If ",
  StyleBox["Solution\[Rule]Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, the model must have velocity-dependent loads applied, or no \
equilibrium velocity can exist.  \[FilledSmallSquare]  If ",
  StyleBox["Solution\[Rule]Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, the model must have nonzero masses applied to at least one \
moving body with a command such as\n",
  StyleBox["SetBodies[Body[2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Mass\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["m",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox[
  "Solution         \[Rule] Static\nInitialGuess     \[Rule] Automatic\n\
InitialCondition \[Rule] Automatic\nCompiled         \[Rule] False\n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\[FilledSmallSquare]  See also: ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetGuess",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetGuess[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets the current values of the system initial guesses. Guesses are given \
as a sequence or list of ",
  StyleBox["rules",
    FontSlant->"Italic"],
  ", specifying the new values of the variables that are to have their \
current guesses changed. ",
  StyleBox["SetGuess[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " restores all of the initial guesses to their default values as specified \
with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not change the values of any of the permanent guesses set with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". Only the guesses that wi",
    FontFamily->"Times"],
  "ll be used for the very next solution attempt are changed.  \
\[FilledSmallSquare]  The default initial guesses that are used by ",
  StyleBox["SetGuess[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are the values previously specified with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to change the values of existing parameters, but not to \
introduce new ones; use ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetLoads",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetLoads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["loads",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " prepares the applied load vector and incorporates the given loads into \
the current model. Each load must have the head ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects are returned by all of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " forcing functions. The ",
  StyleBox["AddLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to specify whether the ",
  StyleBox["loads",
    FontSlant->"Italic"],
  " are to be added to or replace the current load vector. The ",
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option specifies the default initial guess for the Lagrange multipliers."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetLoads[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to apply no external loads, or to remove any existing loads.  \
\[FilledSmallSquare]  ",
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be set to a number, which is as the guess for all of the Lagrange \
multipliers, or a list of numbers equal in length to the number of DOF's in \
the current model.  \[FilledSmallSquare]  Loads applied to a body number that \
is not a member of the current model are ignored, with a warning message.  \
\[FilledSmallSquare]  If a load is given that contains local point numbers of \
points that are not yet defined, ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is automatically set to ",
  StyleBox["None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with a warning message. The undefined points must be defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " before a solution is attempted.\n\[FilledSmallSquare]  The default option \
settings are:\n",
  StyleBox[
  "AddLoads    \[Rule] False\nBuildMech   \[Rule] Static\nLambdaGuess \[Rule] \
Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetParameters",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetParameters[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " adds a sequence or list of ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " to the current parameters list and returns the entire parameters list. \
Each of the rules must be of the form ",
  StyleBox["Symbol\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["number",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "New rules that are associated with the same symbols as rules that are \
currently in the parameters list replace those in the current list.  \
\[FilledSmallSquare]  New parameters are given the ",
  StyleBox["Protected",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Constant",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attributes.  \[FilledSmallSquare]  The ",
  StyleBox["Constant",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attribute allows expressions containing parameters to be differentiated \
with ",
  StyleBox["Dt",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["ClearParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetPath",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetPath[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["constraints",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the differential equations necessary to find the time domain \
motion of a fully constrained nonholonomic system. Kinematic constraints in \
the current mechanism are replaced with the given velocity-dependent ",
  StyleBox["constraints",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify the initial location of each body in the model. ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that is solved with ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.  \[FilledSmallSquare]  The constraint number of the constraint \
that is passed to ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must match the constraint number of a constraint that is a member of the \
current system.  \[FilledSmallSquare]  See also: ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetSensitivity",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetSensitivity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["symbols",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the equations necessary to find the sensitivity of the current \
model to changes in the ",
  StyleBox["symbols",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that is solved with ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify the configuration of the mechanism at which the \
sensitivity are determined.  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetSymbols",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetSymbols[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used with the ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify the basis for the symbols that ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " creates. The ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to specify whether angular or Euler coordinates are used \
to represent the angular orientation and velocity of a mechanism body. \
Settings for ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be run at the beginning of a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " session because the symbol names specified with ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the effects of choosing a ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " versus ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method, are reflected throughout the function of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  Running ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has the effect of clearing the entire model, ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " calls ",
  StyleBox["ClearMech[Constraints]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ClearMech[Loads]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to specify whether the angular velocities and accelerations are \
calculated in local or global coordinates.  \[FilledSmallSquare]  The setting \
of the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option has no effect unless the ",
  StyleBox["Method\[Rule]Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is also specified, because Euler parameters are neither global nor \
local.\n\[FilledSmallSquare]  The default ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option settings are: \n",
  StyleBox["Method      \[Rule] Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n",
  StyleBox[
  "SymbolBasis \[Rule] \
{\"T\",{\"X\",\"Y\"},{\"Ei\",\"Ej\"},\"Th\",\"Lmb\",\"d\"}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n\[FilledSmallSquare]  The default ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option settings are:\n",
  StyleBox["Coordinates \[Rule] Global\nMethod      \[Rule] Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n",
  StyleBox[
  "SymbolBasis \[Rule] \
{\"T\",{\"X\",\"Y\",\"Z\"},{\"Eo\",\"Ei\",\"Ej\",\"Ek\"},\n                \
{\"Wx\",\"Wy\",\"Wz\"},\"Lmb\",\"d\"}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \n\[FilledSmallSquare]  See also: ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SkewSym",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SkewSym[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the skew-symmetric matrix associated with the direction vector of \
the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["vector",
    FontSlant->"Italic"],
  " object.\n",
  StyleBox["SkewSym[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["a1,a2,a3",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " -\[Rule] ",
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["0, -a3, a2",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["a3, 0, -a1",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["-a2, a1, 0",
    FontSlant->"Italic"],
  StyleBox["}}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SkewSym[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["SkewSym[Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Other ",
  StyleBox["SkewSym[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args...",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are interpreted as ",
  StyleBox["SkewSym[Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Cross",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Solution",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for certain ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions that specifies the level of solution sought. Valid settings for \
",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveCouple",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveCouple[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cpsys, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solves the coupled system built by ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["cpsys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of rules representing the solution to the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option can be used to specify the values of time for each segment of the \
linked equations independently.  \[FilledSmallSquare]  ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be a list of rules of length ",
  StyleBox["n",
    FontSlant->"Italic"],
  " for an ",
  StyleBox["n",
    FontSlant->"Italic"],
  " configuration ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The list of rules is of the form ",
  StyleBox["InitialCondition\[Rule]{Time\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t1",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Time\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t2",
    FontSlant->"Italic"],
  ", ...",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SetParameters\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the values in the current parameters list to be updated to the new \
values found by ",
  StyleBox["SolveCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  If ",
  StyleBox["linksys",
    FontSlant->"Italic"],
  " is a symbol that evaluates to a ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, ",
  StyleBox["linksys",
    FontSlant->"Italic"],
  " is updated with a new set of initial guesses as specified by the current \
solution of the ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox[
  "SetParameters    \[Rule] False\nInitialCondition \[Rule] Automatic\n\
DampingFactor    \[Rule] 1\nMaxIterations    \[Rule] 15\nZeroTest         \
\[Rule] (Abs[#]<10^-9&)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["CoupleSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveFree",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["freesys, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the solution to a free system built by ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The specified object ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of rules representing the solution to the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. ",
  StyleBox["SolveFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["freesys, endtime, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " integrates the equations of motion in the ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " and returns the time domain free response."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to specify the initial location variables for a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that is to be solved for free velocity, or the initial location \
and velocity for a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object that is to be solved for free acceleration.  \[FilledSmallSquare]  \
Values for parameters can be set with the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, in which case they override the values given in the current \
parameters list or contained in the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.  \[FilledSmallSquare]  The ",
  StyleBox["StartingStepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is effective only if ",
  StyleBox["StepSize\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The ",
  StyleBox["MaxIterations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used only when the system is nonlinear in terms of the Lagrange \
multipliers, so that an iterative solution must be used at each time step.  \
\[FilledSmallSquare]  If ",
  StyleBox["Interpolation\[Rule]False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified the solution data is returned as lists of numbers.\n\
\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox[
  "ConstraintCorrection \[Rule] False\nFitDegree            \[Rule] Cubic\n\
FunctionOfTime       \[Rule] True\nInitialCondition     \[Rule] Automatic\n\
Interpolation        \[Rule] True\nInterpolationOrder   \[Rule] 3\nMakeRules  \
          \[Rule] {Parameters, Location}\nMaxError             \[Rule] 0.0001\
\nMaxIterations        \[Rule] 15\nMaxSteps             \[Rule] 500\n\
MaxStepSize          \[Rule] Infinity\nMethod               \[Rule] Automatic\
\nStartingStepSize     \[Rule] Automatic\nStepSize             \[Rule] \
Automatic\nZeroTest             \[Rule] (Abs[#]<10^-9&)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveMech",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attempts to find a location solution to the current model at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of rules containing the global coordinates of each body.\n\
",
  StyleBox["SolveMech[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t1, t2,..., tn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a nested list of solution rules containing solution points at all \
of the ",
  StyleBox["ti",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to determine what order of solution to seek. ",
  StyleBox["Interpolation\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to interpolate the solution rules returned."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveMech[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t1, t2,..., tm",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["},",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["n >= m",
    FontSlant->"Italic"],
  ", returns a nested list of solution rules containing solution points at \
all of the ",
  StyleBox["ti",
    FontSlant->"Italic"],
  ", with the remaining ",
  StyleBox["n-m",
    FontSlant->"Italic"],
  " solution points interspersed evenly throughout the ",
  StyleBox["ti",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Solution\[Rule]Velocity]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the complete set of location and velocity solution rules, etc.  \
\[FilledSmallSquare]  ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes the supplied list (or nested list) of rules and uses them as \
initial guesses for the next solution attempt.  \[FilledSmallSquare]\nThe ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option can be used to prevent ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " from testing supplied initial guesses to see if they are valid, thus, ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Solution\[Rule]Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["CheckRules\[Rule]False]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " calculates the acceleration solution based on the location and velocity \
specified in the supplied ",
  StyleBox["rules",
    FontSlant->"Italic"],
  ", regardless of their validity.  \[FilledSmallSquare]  The ",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option should specify a function that returns ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " if applied to a number that is sufficiently close to zero.  \
\[FilledSmallSquare]  If the ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is specified, the ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects returned incorporate the first- or second-order information \
contained in the solution, if a velocity or acceleration solution was \
specified.  \[FilledSmallSquare]  The ",
  StyleBox["FunctionOfTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to cause the ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects returned to be explicitly functions of the time variable, ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox[
  "CheckRules         \[Rule] True\nDampingFactor      \[Rule] 1\n\
FunctionOfTime     \[Rule] True\nInterpolation      \[Rule] False\n\
InterpolationOrder \[Rule] Automatic\nMakeRules          \[Rule] {Location, \
Generalized, Parameters}\nMaxIterations      \[Rule] 15\nSolution           \
\[Rule] Location\nZeroTest           \[Rule] (Abs[#]<10^-9&)",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolvePath",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolvePath[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pathsys, endtime, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the solution to the nonholonomic system built by ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["pathsys",
    FontSlant->"Italic"],
  " object must have the head ",
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " integrates the equations of motion from the initial time to ",
  StyleBox["endtime",
    FontSlant->"Italic"]
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" accepts all of the options to ",
    FontFamily->"Times"],
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " rules representing the solution to the ",
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object.  \[FilledSmallSquare]  The integration block used by ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the same as that used by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveSensitivity",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SolveSensitivity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["senssys, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the solution to the sensitivity system built by ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["senssys",
    FontSlant->"Italic"],
  " must have the head ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of rules representing the solution to the ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The solution returned by ",
  StyleBox["SolveSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is apparently identical to the velocity solution returned by ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["..., ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Solution\[Rule]Velocity]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", but the values do not represent derivatives with respect to time, they \
represent derivatives with respect to the symbols supplied to ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["SensitivitySystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetSensitivity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Sphere",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Sphere[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, facets",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a sphere of radius ",
  StyleBox["rad",
    FontSlant->"Italic"],
  ", centered at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " divisions along either circumference. The axis of revolution of the \
sphere points in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Sphere",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Sphere[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["circfacets, polarfacets",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a sphere with ",
  StyleBox["circfacets",
    FontSlant->"Italic"],
  " segments around the equator, and ",
  StyleBox["polarfacets",
    FontSlant->"Italic"],
  " segments looping over the poles.\n\[FilledSmallSquare]  The default \
option settings are:\n",
  StyleBox["Angle \[Rule] {0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["2 Pi}\nFaces \[Rule] True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Torus",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Spherical3",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Spherical3[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, point2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to be coincident with ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " in 3D space. ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains three DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " essentially models a 3D ball-and-socket joint.  \[FilledSmallSquare]  The \
three equations in ",
  StyleBox["Spherical3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain the ",
  StyleBox["X",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Y",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " coordinates of the ",
  StyleBox["pointi",
    FontSlant->"Italic"],
  " to be equal.  \[FilledSmallSquare]  See also: ",
  StyleBox["DirectedPosition3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SphericalToXYZ\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SphericalToXYZ[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius, baseangle, altitudeangle",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converts the given point from spherical to Cartesian coordinates and \
returns ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SphericalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "By default, ",
  StyleBox["altitude_angle",
    FontSlant->"Italic"],
  " is measured in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction, and a ",
  StyleBox["base_angle",
    FontSlant->"Italic"],
  " of zero puts the point in the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " = 0 plane.  \[FilledSmallSquare]  ",
  StyleBox["Coordinates\[Rule]YZX",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["altitude_angle",
    FontSlant->"Italic"],
  " to be measured in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction, and so on.  \[FilledSmallSquare]  More complicated coordinate \
reorientations require a rotation matrix.  \[FilledSmallSquare]  See also: ",
  StyleBox["CylindricalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToSpherical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SplineFit",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SplineFit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["data, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object representing the data as a cubic spline."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["EndConditions",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options.  \[FilledSmallSquare]  The data are given as rectangular matrix \
of numbers, that is, a list of coordinates.  \[FilledSmallSquare]  For a 2D \
spline curve ",
  StyleBox["data",
    FontSlant->"Italic"],
  " is given as a list of 2D vectors; for a 3D spline ",
  StyleBox["data",
    FontSlant->"Italic"],
  " is a list of 3D vectors.\n\[FilledSmallSquare]  The default option \
settings are:\n",
  StyleBox["Parameters    \[Rule] Automatic\nEndConditions \[Rule] Natural",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SplineFunction",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SplineFunction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["range, internal",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " represents a spline created by ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts an argument within the ",
  StyleBox["range",
    FontSlant->"Italic"],
  " of the spline for evaluation at some point along the curve."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When given a single symbolic argument, an ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-dimension ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates to a list of ",
  StyleBox["n",
    FontSlant->"Italic"],
  " ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects. This is useful when the spline is to be passed to a function \
that requires two or three separate parametric functions in a list.  \
\[FilledSmallSquare]  ",
  StyleBox["SplineFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects can be used for ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " cam profiles.  \[FilledSmallSquare]  Cubic splines have zeroth-, first-, \
and second-order continuity.  \[FilledSmallSquare]  See also: ",
  StyleBox["SplineFit",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["StageSwitch",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["StageSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, test1, const1, test2, const2, ...",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used in place of a single constraint supplied to ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates each of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " in turn, and applies the ",
  StyleBox["consti",
    FontSlant->"Italic"],
  " corresponding to the first ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " that returns ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n",
  StyleBox["StageSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["test1, load1, test2, load2, ...",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used in place of a load supplied to ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions analogously to ",
  StyleBox["Which",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " when used with constraints.  \[FilledSmallSquare]  Each of the ",
  StyleBox["consti",
    FontSlant->"Italic"],
  " must be ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint objects that have the head ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " produces an error if any of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " fail to return ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time.  \[FilledSmallSquare]  When used with load objects, the ",
  StyleBox["loadi",
    FontSlant->"Italic"],
  " may be single loads or lists of loads.  \[FilledSmallSquare]  ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies ",
  StyleBox["all",
    FontSlant->"Italic"],
  " of the ",
  StyleBox["loadi",
    FontSlant->"Italic"],
  " to the model for which the corresponding ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " returns ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (unlike the behavior of ",
  StyleBox["Which",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ").  \[FilledSmallSquare]  If all of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " return ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", no loads are applied.  \[FilledSmallSquare]  See also: ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Static",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for certain ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. Setting ",
  StyleBox["Solution\[Rule]Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes such functions to seek a solution for the location and static \
loading of the current mechanism."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["Solution\[Rule]Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified with a model that has velocity-dependent loads, all \
velocities are set to zero.  \[FilledSmallSquare]  See also: ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Step",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Step[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " represents a step function. ",
  StyleBox["Step[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " return",
  StyleBox["s 1 i",
    FontFamily->"Times"],
  "f ",
  StyleBox["num >= ",
    FontSlant->"Italic"],
  "0 and retur",
  StyleBox["ns 0 if",
    FontFamily->"Times"],
  " ",
  StyleBox["num < ",
    FontSlant->"Italic"],
  "0; otherwise, ",
  StyleBox["Step[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["num",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is returned unevaluated. All derivatives of ",
  StyleBox["Step",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are equal to zero."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Step",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not defined f",
  StyleBox["or complex nu",
    FontFamily->"Times"],
  "mbers. "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["StepMech",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["StepMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " steps the constraint equations through one iteration of the \
Newton-Rhapson solution block with time set to ",
  StyleBox["t",
    FontSlant->"Italic"],
  ", regardless of any convergence criteria."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["StepMech[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses no value of time.  \[FilledSmallSquare]  ",
  StyleBox["StepMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to help diagnose nonconvergent models by examining the \
direction that Newton's method steps the solution vector.  \
\[FilledSmallSquare]  ",
  StyleBox["StepMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DampingFactor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options. \n\[FilledSmallSquare]  The default option settings are:\n",
  StyleBox["Solution      \[Rule] Location\nDampingFactor \[Rule] 1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["StepSize",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["StepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that sets the constant time-step size used by the numerical integration \
algorithm."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The default, ",
  StyleBox["StepSize\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", uses an adaptive algorithm that adjusts the time-step size up or down by \
a factor of two when necessary.  \[FilledSmallSquare]  Specifying a setting \
other than ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " disables the automatic adjustment of step size and uses the specified \
step size for the entire integration.  \[FilledSmallSquare]  See also: ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StartingStepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SymbolBasis",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is given as a nested list of strings that specifies the basis for the \
symbol names that will be hard coded into the model."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The last element in the ",
  StyleBox["SymbolBasis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " list ",
  StyleBox["\"d\"",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the postfix applied to symbol names to imply a time derivative.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SysBody",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of a system body data object returned by the ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The format of the ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object is ",
  StyleBox["SysBody[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ptcoord1, ptcoord2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", initialguess, mass, inertia, centroid, bnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SysCon",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of a system constraint object returned by all ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint functions."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The format of the ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object is ",
  StyleBox["SysCon[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["expr1, expr2, ...exprDOF",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",\n",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, pnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["xvar1, guess1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", cnum, DOF, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["swtime1, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",\n\"namestring\"",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SysLoad",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the head of a system load object returned by all ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load functions."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The format of the ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data object is ",
  StyleBox["SysLoad[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["force, moment",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[",\n",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, pnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", bnum,\"namestring\" ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Gravity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysBody",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SysPlot",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used by ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to carry a plot object that evaluates to a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object when numerical values are available for the coordinates of the cam \
body."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Graphics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object (or ",
  StyleBox["Graphics3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object), not a graphics primitive.  \[FilledSmallSquare]  ",
  StyleBox["SysPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not intended to be used external to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["CamPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["MechPrimitive",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Tangent",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Tangent[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, rad1, point2, rad2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a pair of lines tangent to two implied circles. If a circle of \
radius ",
  StyleBox["rad1",
    FontSlant->"Italic"],
  " is centered at ",
  StyleBox["point1",
    FontSlant->"Italic"],
  ", and another of radius ",
  StyleBox["rad2",
    FontSlant->"Italic"],
  " is centered at ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Tangent",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates two lines tangent to both circles representing a belt or chain \
between two pulleys."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Tangent",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of two ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects, so if only one of the two tangent lines is desired, one of the \
two parts of the list may be extracted.  \[FilledSmallSquare]  The list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives returned  are functions of mechanism location \
variables.  \[FilledSmallSquare]  See also: ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TangentConstraint",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TangentConstraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether or not the constraint pair in question comes into \
conjunction tangentially. The default setting is ",
  StyleBox["TangentConstraint\[Rule]False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TangentConstraint\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " implies that at the discreet point in time where both constraints are \
simultaneously valid, both the location ",
  StyleBox["and",
    FontSlant->"Italic"],
  " the velocity solutions are identical for either constraint.  \
\[FilledSmallSquare]  If this condition exists, ",
  StyleBox["TangentConstraint\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be used to find a valid solution.  \[FilledSmallSquare]  When ",
  StyleBox["TangentConstraint\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the location and velocity solutions at the switch point.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["FindSwitchTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Time",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Time",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the value of time. ",
  StyleBox["Time\[Rule]Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies that time is a dependent variable. The default setting is ",
  StyleBox["Time\[Rule]None",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The numeric value of time can also be specified with the ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option by including a rule for the current time variable.  \
\[FilledSmallSquare]  ",
  StyleBox["Time\[Rule]Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cannot be specified within the ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, but must be given as a separate option.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["Free",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["SetCouple",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TimeInterpolate",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TimeInterpolate[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["expr, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["rules1, rules2, ...",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns an ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object representing ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " as a function of time. Each of the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  " must be a list of rules containing numerical replacements for all of the \
subexpressions in ",
  StyleBox["expr",
    FontSlant->"Italic"],
  ", as well as a rule for the value of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["InterpolationOrder",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.  \[FilledSmallSquare]  If higher-order (velocity or acceleration) \
terms are included in the ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  ", ",
  StyleBox["TimeInterpolate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatically calculates the time derivatives of ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " and use the values of the higher-order terms supplied in ",
  StyleBox["rulesi",
    FontSlant->"Italic"],
  " to produce a higher-order ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]   The default option ",
  StyleBox["InterpolationOrder\[Rule]Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equivalent to three for zeroth- and first-order data and five for \
second-order data.  \[FilledSmallSquare]  See also: ",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TimeSwitch",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TimeSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, con0, time1, con1, ..., timen, conn",
    FontSlant->"Italic"],
  "] can be used in place of a single constraint supplied to ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies ",
  StyleBox["coni",
    FontSlant->"Italic"],
  " if ",
  StyleBox["timei ",
    FontSlant->"Italic"],
  "< ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " < ",
  StyleBox["time(i+1)",
    FontSlant->"Italic"],
  ". The first and last constraints are applied when ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " < ",
  StyleBox["time1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " >",
  StyleBox["timen",
    FontSlant->"Italic"],
  ".\n",
  StyleBox["TimeSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["load0, time1, load1, ..., timen, loadn",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used in place of a single forcing function supplied to ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies ",
  StyleBox["loadi",
    FontSlant->"Italic"],
  " if ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " < ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " < ",
  StyleBox["time(i+1)",
    FontSlant->"Italic"],
  ". The first and last ",
  StyleBox["loadi",
    FontSlant->"Italic"],
  " are applied when ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " < ",
  StyleBox["time1",
    FontSlant->"Italic"],
  " or ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " > ",
  StyleBox["timen",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " must evaluate to numbers in ascending order.  \[FilledSmallSquare]  When \
used with load objects, if a ",
  StyleBox["time0",
    FontSlant->"Italic"],
  " precedes ",
  StyleBox["load0",
    FontSlant->"Italic"],
  " then no load is applied by the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " before ",
  StyleBox["time0",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  Similarly, if a ",
  StyleBox["time(n+1)",
    FontSlant->"Italic"],
  " comes after ",
  StyleBox["loadn",
    FontSlant->"Italic"],
  ", then no load is applied after ",
  StyleBox["time(n+1)",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Torus",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Torus[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, majrad, minrad, facets",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a torus of specified major and minor radii, centered at the \
origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", with its major axis in the direction of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " segments around either axis. ",
  StyleBox["Torus",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Torus[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, majrad, minrad, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["majfac, minfac",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses ",
  StyleBox["majfac",
    FontSlant->"Italic"],
  " segments along the major circumference and ",
  StyleBox["minfac",
    FontSlant->"Italic"],
  " segments along the minor circumference.\n\[FilledSmallSquare]  The \
default option settings are:\n",
  StyleBox["Angle \[Rule] {0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["2 Pi}\nFaces \[Rule] True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Sphere",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Translate2",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Translate2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel and coincident with ",
  StyleBox["axis2.",
    FontSlant->"Italic"],
  " ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to model a prismatic joint, such as a piston in a cylinder.  \
\[FilledSmallSquare]  The first equation constrains to two axes to be \
parallel, the second constrains the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Translate5",
    FontFamily->"courier"],
  StyleBox["\t\t\t\t\t\t\t",
    FontFamily->"Courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Translate5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, axis2",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the two axes to be parallel and coincident, and constrains the \
projections of the reference directions of the two axes to be parallel. ",
  StyleBox["Translate5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains five DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Translate5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a prismatic joint; a slider that cannot rotate about any axis.  \
\[FilledSmallSquare]  The first two equations constrain the two axes to be \
parallel, the third and fourth equations constrain origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to lie on ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", and the fifth equation constrains the reference directions of the two \
axes to be aligned.  \[FilledSmallSquare]  See also: ",
  StyleBox["Cylindrical4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TwoGears1\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TwoGears1[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, point2, rad2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a gear set. Function is identical to ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", except ",
  StyleBox["TwoGears1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not constrain the distance between the axes of the two gears, only \
their angular orientations. ",
  StyleBox["TwoGears1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains one DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TwoGears1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used primarily when other constraints are already constraining the \
location of the axes of the two gears, so that ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would be redundant.  \[FilledSmallSquare]  See also: ",
  StyleBox["RackAndPinion2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TwoGears2\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TwoGears2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, point2, rad2, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a gear set. The axes of the two gears ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " are constrained to be ",
  StyleBox["rad1 + rad2",
    FontSlant->"Italic"],
  " units apart, and the rotational positions of the gears are related as per \
their respective radii. The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " sets the initial rotational positions of the gears. ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial rotation of the gears, is given by the formula\n",
  
  StyleBox["C = (rad1 e1 + rad2 e2) ",
    FontSlant->"Italic"],
  "where ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined in the following way. Place the two gears in any valid \
position and construct a vector from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " is the angle, measured in radians, from the constructed vector to the \
local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of gear 1 and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is the angle from the constructed vector to the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of gear 2.  \[FilledSmallSquare]  If the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method is specified ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates three constraints and add one extra variable to the model.  \
\[FilledSmallSquare]\n",
  StyleBox["TwoGears2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point2, rad2, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to explicitly specify the name of the extra variable and its \
initial guess. Otherwise, a symbol of the form ",
  StyleBox["Th",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  " is used.  \[FilledSmallSquare]  The first equation in ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the two points to lie ",
  StyleBox["rad1 + rad2",
    FontSlant->"Italic"],
  " units apart; the second, and optional 3rd,  equation relates the rotation \
of gear 1 to that of gear2.  \[FilledSmallSquare]  See also: ",
  StyleBox["RackAndPinion2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwoGears1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TwoPulleys2\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TwoPulleys2[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, point1, rad1, point2, rad2, dist, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a chain and sprocket or belt set. The axes of the two sprockets ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["point2",
    FontSlant->"Italic"],
  " are constrained to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the rotational positions of the sprockets are related as \
per their respective radii. The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  " sets the initial rotational position of the pulleys. ",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains two DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The radii of the two sprockets cannot be equal; use ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial rotation of the pulleys, is given by the formula \
",
  StyleBox["C = (rad1 e1 - rad2 e2)",
    FontSlant->"Italic"],
  " where ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined in the following way. Place the two sprockets in any valid \
position and construct a vector from ",
  StyleBox["point1",
    FontSlant->"Italic"],
  " to ",
  StyleBox["point2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " is the angle, measured in radians, from the constructed vector to the \
local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the first sprocket and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is the angle from the constructed vector to the ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis of the second sprocket.  \[FilledSmallSquare]  If the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method is specified, ",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates three constraints, and add one extra variable to the model.  \
\[FilledSmallSquare]\n",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["[cnum, point1, rad1, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym1, guess",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", point2, rad2, dist, C",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to explicitly specify the name of the extra variable, and its \
initial guess. Otherwise, a symbol of the form ",
  StyleBox["Th",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  " is used.  \[FilledSmallSquare]  The first equation in ",
  StyleBox["TwoPulleys2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains the two points to lie ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart; the second, and optional 3rd, equation relates the rotation \
of pulley1 to that of pulley2.  \[FilledSmallSquare]  See also: ",
  StyleBox["RackAndPinion2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["TwoGears2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TwoPulleys4\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TwoPulleys4[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["axis2, rad2, dist, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is identical to ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " except that the heads of the two axes are not constrained to be adjacent. \
Thus, the two pulleys are free to slide on their axes, relative to each \
other. ",
  StyleBox["TwoPulleys4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains four DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TwoPulleys4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is essentially ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the third equation dropped.  \[FilledSmallSquare]  See also: ",
  StyleBox["ParallelGears4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TwoPulleys5\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["TwoPulleys5[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, axis1, rad1, ",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["alpha, guess",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["axis2, rad2, dist, C",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " models a pair of pulleys and a belt. The axes of the two pulleys, ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", are constrained to be parallel and ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the origins of these two axes are constrained to be \
adjacent. The rotational positions of the two pulleys are related as per \
their respective radii. ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrains five DOF."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The symbol ",
    FontFamily->"Times"],
  StyleBox["alpha",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" tracks the spin of ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", relative to a vector spanning from ",
    FontFamily->"Times"],
  StyleBox["axis1",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" to ",
    FontFamily->"Times"],
  StyleBox["axis2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[".  \[FilledSmallSquare]  ",
    FontFamily->"Times"],
  "The constant ",
  StyleBox["C",
    FontSlant->"Italic"],
  ", which sets the initial positions of the pulleys, is given by the formula\
\n",
  StyleBox["C = rad1 e1 - rad2 e2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " are determined in the following way. Place the two pulleys in any valid \
orientation and construct a vector from the origin of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to that of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ". ",
  StyleBox["e1",
    FontSlant->"Italic"],
  " is the angle, in radians, measured from the constructed vector to the \
reference direction of ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["e2",
    FontSlant->"Italic"],
  " is the angle from the vector to the reference direction of ",
  StyleBox["axis2.  ",
    FontSlant->"Italic"],
  "\[FilledSmallSquare]",
  StyleBox["\n",
    FontSlant->"Italic"],
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates six constraint equations and introduces one new variable, hence \
constraining five DOF.  \[FilledSmallSquare]  The first two equations in ",
  StyleBox["TwoPulleys5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constrain ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  " to be parallel to ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  ", the third equation constrains the origin of ",
  StyleBox["axis2",
    FontSlant->"Italic"],
  " to lie adjacent to ",
  StyleBox["axis1",
    FontSlant->"Italic"],
  ", the fourth equation constrains the axes to be ",
  StyleBox["dist",
    FontSlant->"Italic"],
  " units apart, and the fifth and sixth equations relate the value of the \
variable ",
  StyleBox["alpha",
    FontSlant->"Italic"],
  " to the rotational displacements of the pulleys.  \[FilledSmallSquare]  \
See also: ",
  StyleBox["OrthogonalGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ParallelGears5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Type\t\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether ",
  StyleBox["Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " loads are returned. The default setting is ",
  StyleBox["Type\[Rule]Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  " See also: ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Unit\t\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Unit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a unit vector pointed in the direction of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " vector object."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Unit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Unit[Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  Other ",
  StyleBox["Unit[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args ...",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are interpreted as ",
  StyleBox["Unit[Line[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["args",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Direction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Vector\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Vector[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpnt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " data object that represents a vector in the local coordinate system of \
body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " can be a vector, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", in the local coordinate system of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", or it can be a point number (positive integer) referencing a coordinate \
that was defined with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A simple vector ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x",
    FontSlant->"Italic"],
  ", ",
  StyleBox["y",
    FontSlant->"Italic"],
  ", ",
  StyleBox["z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " given in place of a ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is interpreted as\n",
  StyleBox["Vector[1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Velocity\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for certain ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions. Setting ",
  StyleBox["Solution\[Rule]Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes such functions to seek a solution for the location and velocity of \
the current mechanism. ",
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the global velocity vector, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dX, dY",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dX, dY, dZ",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", of the specified ",
  StyleBox["point",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is interpreted as ",
  StyleBox["Velocity[Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Velocity[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum,",
    FontSlant->"Italic"],
  " ...",
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the velocity and angular velocity coordinates of the specified \
bodies.  \[FilledSmallSquare]  ",
  StyleBox["Velocity[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire vector of velocity coordinates.  \[FilledSmallSquare]  \
The behavior of ",
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " varies depending on whether the current solution method is ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", with the ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method, ",
  StyleBox["Velocity[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["{X2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Y2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Z2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Eo2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Ei2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Ej2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Ek2d}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  In ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", with the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method, ",
  StyleBox["Velocity[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["{X2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Y2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Z2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Wx2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Wy2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Wz2}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Velocity[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym...",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the velocity coordinates associated with the specified location \
coordinates ",
  StyleBox["sym",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["VelocityTerms\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["VelocityTerms[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the part of the right-hand term of the current velocity \
constraint expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Jacobian[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum,",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" All] . Velocity[All] + VelocityTerms[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire velocity constraint expression associated with \
constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  See also: ",
  StyleBox["AccelerationTerms",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Vertex\t\t\t\t\t\t\t",
    FontFamily->"courier"],
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Vertex[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pnt1, pnt2, ..., pntn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics primitives at each of the ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  ", on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". Each ",
  StyleBox["pnti",
    FontSlant->"Italic"],
  " can be either a local point number or local point coordinate, ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Vertex[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point1, ..., pointn",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates n points on several different bodies.  \[FilledSmallSquare]  \
The ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to the built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["Point",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " primitive.  \[FilledSmallSquare]  ",
  StyleBox["Vertex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["Edge",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Virtual",
    FontFamily->"courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Virtual",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes a Jacobian matrix based on virtual displacements to be \
generated, rather than a Jacobian based on an Euler transformation. The \
default setting is ",
  StyleBox["Virtual\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Setting ",
  StyleBox["Virtual\[Rule]False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to run more slowly, but ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the model equations more quickly.  \[FilledSmallSquare]  See also: \
",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Wheel",
    FontFamily->"courier"],
  "\t\t\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, rad, facets",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a 2D circular disk of specified radius and number of ",
  StyleBox["facets",
    FontSlant->"Italic"],
  ", centered at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["axis, rad, facets",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a 3D circular disk with the axis vector of the disk defined by \
",
  StyleBox["axis",
    FontSlant->"Italic"],
  " and the center of the disk located at the origin of ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". ",
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Faces",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Wheel",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives that are functions of mechanism location variables.  \
\[FilledSmallSquare]  In ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["point, rad",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a ",
  StyleBox["Circle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Disk",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " primitive located at ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  ",
  StyleBox["Wheel[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["..., ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["outrad, inrad",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", facets",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates an annular ring with the specified inner and outer radii.  \
\[FilledSmallSquare]  Specifying the option ",
  StyleBox["Angle\[Rule]{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["ang1, ang2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " generates a circular segment of the disk or ring starting and ending at \
the local angles ",
  StyleBox["ang1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["ang2",
    FontSlant->"Italic"],
  ".  \[FilledSmallSquare]  The perimeter of the disk is composed of ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " straight line segments. Thus, a ",
  StyleBox["facets",
    FontSlant->"Italic"],
  " value of 4 yields a square.\n\[FilledSmallSquare]  The default option \
settings are:\n",
  StyleBox["Angle\[Rule]{0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["2 Pi}\nFaces\[Rule]True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "\n\[FilledSmallSquare]  See also: ",
  StyleBox["Bar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Box",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Facet",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["XYToPolar",
    FontFamily->"Courier"],
  "\t\t\t\t\t\t\t",
  StyleBox["2D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["XYToPolar[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converts the given point from Cartesian to polar coordinates and returns \
",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius, angle",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["XYToPolar",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " simply returns:  {",
  StyleBox["(x^2 + y^2)^(1/2), arctan(x, y)",
    FontSlant->"Italic"],
  "}.  \[FilledSmallSquare]  See also: ",
  StyleBox["PolarToXY",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["XYZ",
    FontFamily->"courier"],
  "\t\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["XYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option that is used with coordinate conversion functions to specify the \
right-handed coordinate system ",
  StyleBox["X-Y-Z",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also:  ",
  StyleBox["CylindricalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToCylindrical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToSpherical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["XYZToCylindrical",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"],
  " "
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["XYToCylindrical[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converts the given point from Cartesian to cylindrical coordinates and \
returns ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius, angle, altitude",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["XYZToCylindrical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "By default, ",
  StyleBox["altitude",
    FontSlant->"Italic"],
  " is measured in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction, and an ",
  StyleBox["angle",
    FontSlant->"Italic"],
  " of zero results from a ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of zero.  \[FilledSmallSquare]  ",
  StyleBox["Coordinates\[Rule]YZX",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["altitude",
    FontSlant->"Italic"],
  " to be measured in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction, etc.  \[FilledSmallSquare]  More complicated coordinate \
re-orientations require a rotation matrix.  \[FilledSmallSquare]  See also: ",
  
  StyleBox["CylindricalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToSpherical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["XYZToSpherical",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["XYToSpherical[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converts the given point from Cartesian to spherical coordinates and \
returns ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["radius, baseangle, altitudeangle",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["XYToSpherical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "By default, ",
  StyleBox["altitude_angle",
    FontSlant->"Italic"],
  " is measured in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction and a ",
  StyleBox["base_angle",
    FontSlant->"Italic"],
  " of zero results from a ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " coordinate of zero.  \[FilledSmallSquare]  ",
  StyleBox["Coordinates\[Rule]YZX",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["altitude_angle",
    FontSlant->"Italic"],
  " to be measured in the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction, etc.  \[FilledSmallSquare]  More complicated coordinate \
re-orientations require a rotation matrix.  \[FilledSmallSquare]  See also: ",
  
  StyleBox["SphericalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToCylindrical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["YZX",
    FontFamily->"courier"],
  "\t\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["YZX",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option that is used with coordinate conversion functions to specify the \
right-handed coordinate system ",
  StyleBox["Y-Z-X",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also:  ",
  StyleBox["CylindricalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToCylindrical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToSpherical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ZXY",
    FontFamily->"courier"],
  "\t\t\t\t\t\t\t\t",
  StyleBox["3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["ZXY",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option that is used with coordinate conversion functions to specify the \
right-handed coordinate system ",
  StyleBox["Z-X-Y",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also:  ",
  StyleBox["CylindricalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SphericalToXYZ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToCylindrical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["XYZToSpherical",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechPostIterate",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechPostIterate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a function that is applied to the iteration counter at each iteration \
of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s iterative solution block."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechPostIterate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has no definition by default.  \[FilledSmallSquare]  Setting ",
  StyleBox["$MechPostIterate = Print",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the iteration count to be printed at each step.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$MechPreSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechPreSolve",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechPreSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is applied to the numeric value of the time variable before each run of \
the location solution block."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechPreSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has no definition by default.  \[FilledSmallSquare]  Setting ",
  StyleBox["$MechPreSolve = Print",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the value of time to be printed each time ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " converges one solution.  \[FilledSmallSquare]  ",
  StyleBox["$MechPreSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to perform various tasks before a solution is sought, such as \
to update the initial guesses with ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to predetermined values that are known to be close to the solution being \
sought.  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["$MechPostIterate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechPrimeRules",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechPrimeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of replacement rules for all of the current ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " dependent variables to convert them to explicit functions of time with \
the ",
  StyleBox["Derivative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " operator replacing ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s symbolic derivatives. For example,\n",
  StyleBox["$MechPrimeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[LongRightArrow] ",
  StyleBox["{X2\[Rule]X2[T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ..., ",
  StyleBox["Y3d\[Rule]Y3'[T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["$MechTimeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechProcessFunction",
    FontFamily->"courier"],
  "\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechProcessFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a function that is applied to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s internal lists of modeling equations as they are generated. ",
  StyleBox["$MechProcessFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is initially set equal to ",
  StyleBox["Chop",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechProcessFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is set to ",
  StyleBox["Chop",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by default.  \[FilledSmallSquare]  See also: ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechTimeRules",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechTimeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of replacement rules for all of the current ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " dependent variables to convert them to explicit functions of time. For \
example,\n",
  StyleBox["$MechTimeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[LongRightArrow] ",
  StyleBox["{X2\[Rule]X2[T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ..., ",
  StyleBox["Y3d\[Rule]Y3d[T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "See also: ",
  StyleBox["$MechPrimeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechVariables",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechVariables",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of the names of all of the user variables that are present \
in the current model. Changes in the values of these variables affect the \
model."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The names returned by ",
  StyleBox["$MechVariables",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " represent all of the symbols that have been recognized by the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " variable management scheme.  \[FilledSmallSquare]  Variables that are not \
listed by ",
  StyleBox["$MechVariables",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are not made local when ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " generates constraint and load equations, thus any assignments for such \
variables become embedded in new internal expressions as they are generated.  \
\[FilledSmallSquare]  See also: ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["$MechVersion",
    FontFamily->"courier"],
  "\t\t\t\t\t\t",
  StyleBox["2D/3D",
    FontWeight->"Plain"]
}], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["$MechVersion",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the version number of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages."
}], "Text",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "For the version referenced in this manual, ",
  StyleBox["$MechVersion",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the string ",
  StyleBox["\"1.3\"",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  GroupPageBreakWithin->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsection"],

Cell[TextData[{
  "Craig, R. R., ",
  StyleBox["Structural Dynamics, An Introduction to Computer Methods",
    FontSlant->"Italic"],
  ", John Wiley & Sons, New York, 1981."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Crandall, S. H., Karnopp, D. C., Kurtz, E. F., and Pridmore-Brown, D. C., \
",
  StyleBox["Dynamics of Mechanical and Electromechanical systems",
    FontSlant->"Italic"],
  ", Krieger Publishing, Florida, 1968."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Haug, Edward J., ",
  StyleBox["Computer-Aided Kinematics and Dynamics of Mechanical Systems",
    FontSlant->"Italic"],
  ", Allyn and Bacon, Massachusetts, 1989."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Kreyszig, E., ",
  StyleBox["Advanced Engineering Mathematics",
    FontSlant->"Italic"],
  ", John Wiley & Sons, New York, 1988."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Shampine, L. F., and Gordon, M. K., ",
  StyleBox[
  "Computer Solution of Ordinary Differential Equations: The Initial Value \
Problem",
    FontSlant->"Italic"],
  ", Freeman, San Francisco, 1975."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowSize->{432, 636},
WindowMargins->{{Automatic, 126}, {Automatic, 23}},
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 34, 0, 53, "Section"],

Cell[CellGroupData[{
Cell[1790, 55, 173, 7, 48, "Subsection"],
Cell[1966, 64, 1484, 56, 148, "Special2"],
Cell[3453, 122, 387, 7, 99, "Input"],
Cell[3843, 131, 589, 20, 78, "Special2"]
}, Closed]],

Cell[CellGroupData[{
Cell[4469, 156, 128, 5, 32, "Subsection"],

Cell[CellGroupData[{
Cell[4622, 165, 200, 8, 44, "Subsubsection"],
Cell[4825, 175, 822, 33, 74, "Text"],
Cell[5650, 210, 366, 10, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6053, 225, 196, 7, 44, "Subsubsection"],
Cell[6252, 234, 1304, 50, 132, "Text"],
Cell[7559, 286, 1893, 75, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9489, 366, 201, 7, 44, "Subsubsection"],
Cell[9693, 375, 482, 17, 72, "Text"],
Cell[10178, 394, 1132, 44, 57, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11347, 443, 194, 7, 44, "Subsubsection"],
Cell[11544, 452, 566, 19, 73, "Text"],
Cell[12113, 473, 990, 35, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13140, 513, 193, 7, 44, "Subsubsection"],
Cell[13336, 522, 391, 16, 34, "Text"],
Cell[13730, 540, 1767, 69, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15534, 614, 193, 7, 44, "Subsubsection"],
Cell[15730, 623, 1502, 63, 113, "Text"],
Cell[17235, 688, 1688, 69, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18960, 762, 193, 7, 44, "Subsubsection"],
Cell[19156, 771, 505, 17, 70, "Text"],
Cell[19664, 790, 2014, 76, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21715, 871, 193, 7, 70, "Subsubsection"],
Cell[21911, 880, 629, 24, 70, "Text"],
Cell[22543, 906, 399, 17, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22979, 928, 195, 7, 70, "Subsubsection"],
Cell[23177, 937, 819, 31, 70, "Text"],
Cell[23999, 970, 1032, 38, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25068, 1013, 193, 7, 70, "Subsubsection"],
Cell[25264, 1022, 1257, 46, 70, "Text"],
Cell[26524, 1070, 774, 27, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27335, 1102, 192, 7, 70, "Subsubsection"],
Cell[27530, 1111, 2577, 111, 70, "Text"],
Cell[30110, 1224, 2255, 92, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32402, 1321, 191, 7, 70, "Subsubsection"],
Cell[32596, 1330, 1100, 45, 70, "Text"],
Cell[33699, 1377, 3709, 140, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37445, 1522, 192, 7, 70, "Subsubsection"],
Cell[37640, 1531, 1584, 63, 70, "Text"],
Cell[39227, 1596, 4414, 171, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43678, 1772, 196, 7, 70, "Subsubsection"],
Cell[43877, 1781, 346, 14, 70, "Text"],
Cell[44226, 1797, 819, 26, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45082, 1828, 191, 7, 70, "Subsubsection"],
Cell[45276, 1837, 953, 39, 70, "Text"],
Cell[46232, 1878, 1261, 49, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47530, 1932, 195, 7, 70, "Subsubsection"],
Cell[47728, 1941, 1431, 58, 70, "Text"],
Cell[49162, 2001, 2233, 75, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51432, 2081, 193, 7, 70, "Subsubsection"],
Cell[51628, 2090, 1576, 64, 70, "Text"],
Cell[53207, 2156, 1791, 67, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55035, 2228, 195, 7, 70, "Subsubsection"],
Cell[55233, 2237, 2386, 93, 70, "Text"],
Cell[57622, 2332, 1268, 39, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58927, 2376, 193, 7, 70, "Subsubsection"],
Cell[59123, 2385, 1587, 58, 70, "Text"],
Cell[60713, 2445, 946, 29, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61696, 2479, 193, 7, 70, "Subsubsection"],
Cell[61892, 2488, 1226, 47, 70, "Text"],
Cell[63121, 2537, 848, 26, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64006, 2568, 194, 7, 44, "Subsubsection"],
Cell[64203, 2577, 1566, 63, 132, "Text"],
Cell[65772, 2642, 920, 29, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66729, 2676, 197, 7, 44, "Subsubsection"],
Cell[66929, 2685, 1547, 60, 132, "Text"],
Cell[68479, 2747, 1060, 35, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[69576, 2787, 193, 7, 44, "Subsubsection"],
Cell[69772, 2796, 1661, 65, 153, "Text"],
Cell[71436, 2863, 1007, 32, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72480, 2900, 197, 7, 70, "Subsubsection"],
Cell[72680, 2909, 418, 16, 70, "Text"],
Cell[73101, 2927, 1309, 47, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74447, 2979, 194, 7, 70, "Subsubsection"],
Cell[74644, 2988, 805, 29, 70, "Text"],
Cell[75452, 3019, 692, 24, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[76181, 3048, 196, 7, 70, "Subsubsection"],
Cell[76380, 3057, 653, 21, 70, "Text"],
Cell[77036, 3080, 1809, 59, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78882, 3144, 197, 7, 70, "Subsubsection"],
Cell[79082, 3153, 573, 21, 70, "Text"],
Cell[79658, 3176, 5749, 166, 762, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[85444, 3347, 195, 7, 70, "Subsubsection"],
Cell[85642, 3356, 327, 11, 53, "Text"],
Cell[85972, 3369, 1472, 50, 120, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[87481, 3424, 199, 7, 44, "Subsubsection"],
Cell[87683, 3433, 454, 17, 53, "Text"],
Cell[88140, 3452, 462, 17, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[88639, 3474, 192, 7, 44, "Subsubsection"],
Cell[88834, 3483, 478, 17, 72, "Text"],
Cell[89315, 3502, 550, 17, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89902, 3524, 200, 7, 44, "Subsubsection"],
Cell[90105, 3533, 1543, 59, 132, "Text"],
Cell[91651, 3594, 3311, 125, 216, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94999, 3724, 198, 7, 70, "Subsubsection"],
Cell[95200, 3733, 1089, 35, 70, "Text"],
Cell[96292, 3770, 2680, 91, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[99009, 3866, 196, 7, 70, "Subsubsection"],
Cell[99208, 3875, 1822, 68, 70, "Text"],
Cell[101033, 3945, 1428, 48, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102498, 3998, 202, 7, 70, "Subsubsection"],
Cell[102703, 4007, 530, 17, 70, "Text"],
Cell[103236, 4026, 1066, 32, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104339, 4063, 197, 7, 70, "Subsubsection"],
Cell[104539, 4072, 525, 18, 70, "Text"],
Cell[105067, 4092, 2674, 103, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107778, 4200, 197, 7, 70, "Subsubsection"],
Cell[107978, 4209, 661, 25, 70, "Text"],
Cell[108642, 4236, 1753, 61, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110432, 4302, 195, 7, 70, "Subsubsection"],
Cell[110630, 4311, 542, 20, 70, "Text"],
Cell[111175, 4333, 779, 27, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[111991, 4365, 196, 7, 70, "Subsubsection"],
Cell[112190, 4374, 317, 12, 70, "Text"],
Cell[112510, 4388, 941, 36, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113488, 4429, 193, 7, 70, "Subsubsection"],
Cell[113684, 4438, 439, 16, 70, "Text"],
Cell[114126, 4456, 781, 33, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114944, 4494, 193, 7, 70, "Subsubsection"],
Cell[115140, 4503, 537, 20, 70, "Text"],
Cell[115680, 4525, 807, 27, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116524, 4557, 194, 7, 70, "Subsubsection"],
Cell[116721, 4566, 1525, 62, 70, "Text"],
Cell[118249, 4630, 990, 30, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119276, 4665, 197, 7, 70, "Subsubsection"],
Cell[119476, 4674, 1094, 42, 70, "Text"],
Cell[120573, 4718, 1004, 29, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121614, 4752, 194, 7, 70, "Subsubsection"],
Cell[121811, 4761, 1006, 39, 70, "Text"],
Cell[122820, 4802, 937, 29, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[123794, 4836, 194, 7, 70, "Subsubsection"],
Cell[123991, 4845, 979, 39, 70, "Text"],
Cell[124973, 4886, 697, 21, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[125707, 4912, 192, 7, 70, "Subsubsection"],
Cell[125902, 4921, 928, 31, 70, "Text"],
Cell[126833, 4954, 1109, 43, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[127979, 5002, 193, 7, 70, "Subsubsection"],
Cell[128175, 5011, 577, 23, 70, "Text"],
Cell[128755, 5036, 746, 25, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[129538, 5066, 197, 7, 70, "Subsubsection"],
Cell[129738, 5075, 797, 31, 70, "Text"],
Cell[130538, 5108, 830, 27, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131405, 5140, 197, 7, 70, "Subsubsection"],
Cell[131605, 5149, 392, 14, 70, "Text"],
Cell[132000, 5165, 1107, 42, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133144, 5212, 197, 7, 70, "Subsubsection"],
Cell[133344, 5221, 396, 16, 70, "Text"],
Cell[133743, 5239, 978, 35, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134758, 5279, 201, 7, 70, "Subsubsection"],
Cell[134962, 5288, 729, 29, 70, "Text"],
Cell[135694, 5319, 911, 34, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136642, 5358, 198, 7, 70, "Subsubsection"],
Cell[136843, 5367, 782, 29, 70, "Text"],
Cell[137628, 5398, 942, 35, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[138607, 5438, 198, 7, 70, "Subsubsection"],
Cell[138808, 5447, 784, 29, 70, "Text"],
Cell[139595, 5478, 896, 32, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[140528, 5515, 195, 7, 70, "Subsubsection"],
Cell[140726, 5524, 426, 16, 70, "Text"],
Cell[141155, 5542, 1642, 66, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142834, 5613, 194, 7, 70, "Subsubsection"],
Cell[143031, 5622, 364, 13, 70, "Text"],
Cell[143398, 5637, 804, 32, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144239, 5674, 193, 7, 70, "Subsubsection"],
Cell[144435, 5683, 1042, 36, 70, "Text"],
Cell[145480, 5721, 692, 29, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146209, 5755, 197, 7, 70, "Subsubsection"],
Cell[146409, 5764, 401, 14, 53, "Text"],
Cell[146813, 5780, 1241, 48, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[148091, 5833, 192, 7, 44, "Subsubsection"],
Cell[148286, 5842, 1775, 76, 93, "Text"],
Cell[150064, 5920, 1158, 43, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151259, 5968, 197, 7, 44, "Subsubsection"],
Cell[151459, 5977, 729, 25, 93, "Text"],
Cell[152191, 6004, 1070, 40, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[153298, 6049, 189, 7, 44, "Subsubsection"],
Cell[153490, 6058, 459, 17, 54, "Text"],
Cell[153952, 6077, 462, 17, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[154451, 6099, 193, 7, 44, "Subsubsection"],
Cell[154647, 6108, 589, 21, 73, "Text"],
Cell[155239, 6131, 1759, 63, 136, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157035, 6199, 199, 7, 44, "Subsubsection"],
Cell[157237, 6208, 968, 42, 54, "Text"],
Cell[158208, 6252, 2388, 92, 136, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160633, 6349, 190, 7, 44, "Subsubsection"],
Cell[160826, 6358, 953, 39, 74, "Text"],
Cell[161782, 6399, 1771, 66, 138, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163590, 6470, 193, 7, 70, "Subsubsection"],
Cell[163786, 6479, 445, 16, 70, "Text"],
Cell[164234, 6497, 422, 16, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164693, 6518, 193, 7, 70, "Subsubsection"],
Cell[164889, 6527, 1726, 74, 70, "Text"],
Cell[166618, 6603, 1182, 44, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167837, 6652, 198, 7, 70, "Subsubsection"],
Cell[168038, 6661, 1166, 41, 70, "Text"],
Cell[169207, 6704, 735, 25, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169979, 6734, 194, 7, 70, "Subsubsection"],
Cell[170176, 6743, 811, 30, 70, "Text"],
Cell[170990, 6775, 2349, 79, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[173376, 6859, 195, 7, 44, "Subsubsection"],
Cell[173574, 6868, 843, 33, 93, "Text"],
Cell[174420, 6903, 507, 21, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174964, 6929, 193, 7, 44, "Subsubsection"],
Cell[175160, 6938, 867, 37, 74, "Text"],
Cell[176030, 6977, 1239, 43, 136, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[177306, 7025, 192, 7, 44, "Subsubsection"],
Cell[177501, 7034, 857, 31, 93, "Text"],
Cell[178361, 7067, 710, 29, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179108, 7101, 196, 7, 44, "Subsubsection"],
Cell[179307, 7110, 313, 12, 34, "Text"],
Cell[179623, 7124, 1444, 56, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[181104, 7185, 198, 7, 70, "Subsubsection"],
Cell[181305, 7194, 460, 15, 70, "Text"],
Cell[181768, 7211, 942, 35, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182747, 7251, 197, 7, 70, "Subsubsection"],
Cell[182947, 7260, 1200, 44, 70, "Text"],
Cell[184150, 7306, 1154, 35, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185341, 7346, 192, 7, 70, "Subsubsection"],
Cell[185536, 7355, 298, 12, 70, "Text"],
Cell[185837, 7369, 686, 25, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[186560, 7399, 193, 7, 70, "Subsubsection"],
Cell[186756, 7408, 612, 22, 70, "Text"],
Cell[187371, 7432, 1263, 44, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188671, 7481, 193, 7, 70, "Subsubsection"],
Cell[188867, 7490, 1310, 51, 70, "Text"],
Cell[190180, 7543, 1819, 63, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192036, 7611, 193, 7, 70, "Subsubsection"],
Cell[192232, 7620, 1026, 37, 70, "Text"],
Cell[193261, 7659, 2006, 64, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[195304, 7728, 194, 7, 70, "Subsubsection"],
Cell[195501, 7737, 325, 12, 70, "Text"],
Cell[195829, 7751, 385, 14, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196251, 7770, 193, 7, 70, "Subsubsection"],
Cell[196447, 7779, 387, 16, 70, "Text"],
Cell[196837, 7797, 297, 13, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[197171, 7815, 197, 7, 70, "Subsubsection"],
Cell[197371, 7824, 462, 17, 70, "Text"],
Cell[197836, 7843, 427, 17, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[198300, 7865, 193, 7, 70, "Subsubsection"],
Cell[198496, 7874, 1910, 73, 70, "Text"],
Cell[200409, 7949, 641, 23, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[201087, 7977, 200, 7, 70, "Subsubsection"],
Cell[201290, 7986, 828, 25, 70, "Text"],
Cell[202121, 8013, 859, 30, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203017, 8048, 196, 7, 70, "Subsubsection"],
Cell[203216, 8057, 1700, 68, 133, "Text"],
Cell[204919, 8127, 1946, 73, 120, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[206902, 8205, 193, 7, 44, "Subsubsection"],
Cell[207098, 8214, 548, 18, 72, "Text"],
Cell[207649, 8234, 798, 25, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[208484, 8264, 201, 7, 44, "Subsubsection"],
Cell[208688, 8273, 834, 32, 93, "Text"],
Cell[209525, 8307, 742, 27, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[210304, 8339, 191, 7, 44, "Subsubsection"],
Cell[210498, 8348, 1591, 60, 70, "Text"],
Cell[212092, 8410, 1032, 34, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[213161, 8449, 194, 7, 70, "Subsubsection"],
Cell[213358, 8458, 495, 20, 70, "Text"],
Cell[213856, 8480, 665, 24, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[214558, 8509, 194, 7, 44, "Subsubsection"],
Cell[214755, 8518, 606, 22, 73, "Text"],
Cell[215364, 8542, 574, 24, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215975, 8571, 195, 7, 44, "Subsubsection"],
Cell[216173, 8580, 602, 20, 73, "Text"],
Cell[216778, 8602, 737, 27, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[217552, 8634, 197, 7, 44, "Subsubsection"],
Cell[217752, 8643, 702, 22, 93, "Text"],
Cell[218457, 8667, 574, 19, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[219068, 8691, 195, 7, 44, "Subsubsection"],
Cell[219266, 8700, 566, 20, 74, "Text"],
Cell[219835, 8722, 595, 18, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220467, 8745, 193, 7, 70, "Subsubsection"],
Cell[220663, 8754, 1239, 44, 70, "Text"],
Cell[221905, 8800, 1839, 60, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[223781, 8865, 192, 7, 70, "Subsubsection"],
Cell[223976, 8874, 1526, 60, 70, "Text"],
Cell[225505, 8936, 1292, 47, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[226834, 8988, 192, 7, 70, "Subsubsection"],
Cell[227029, 8997, 530, 20, 70, "Text"],
Cell[227562, 9019, 802, 27, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[228401, 9051, 196, 7, 70, "Subsubsection"],
Cell[228600, 9060, 699, 29, 70, "Text"],
Cell[229302, 9091, 806, 28, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230145, 9124, 194, 7, 70, "Subsubsection"],
Cell[230342, 9133, 796, 29, 70, "Text"],
Cell[231141, 9164, 389, 13, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[231567, 9182, 194, 7, 70, "Subsubsection"],
Cell[231764, 9191, 820, 30, 70, "Text"],
Cell[232587, 9223, 664, 23, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[233288, 9251, 193, 7, 70, "Subsubsection"],
Cell[233484, 9260, 749, 29, 70, "Text"],
Cell[234236, 9291, 1420, 58, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[235693, 9354, 192, 7, 44, "Subsubsection"],
Cell[235888, 9363, 533, 22, 53, "Text"],
Cell[236424, 9387, 1632, 57, 136, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[238093, 9449, 193, 7, 44, "Subsubsection"],
Cell[238289, 9458, 781, 28, 93, "Text"],
Cell[239073, 9488, 3818, 138, 248, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242928, 9631, 193, 7, 44, "Subsubsection"],
Cell[243124, 9640, 297, 12, 34, "Text"],
Cell[243424, 9654, 623, 21, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[244084, 9680, 195, 7, 70, "Subsubsection"],
Cell[244282, 9689, 1209, 49, 70, "Text"],
Cell[245494, 9740, 542, 20, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[246073, 9765, 194, 7, 70, "Subsubsection"],
Cell[246270, 9774, 1245, 50, 70, "Text"],
Cell[247518, 9826, 3921, 155, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251476, 9986, 194, 7, 70, "Subsubsection"],
Cell[251673, 9995, 832, 30, 70, "Text"],
Cell[252508, 10027, 1742, 53, 168, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[254287, 10085, 195, 7, 44, "Subsubsection"],
Cell[254485, 10094, 1034, 43, 72, "Text"],
Cell[255522, 10139, 974, 38, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[256533, 10182, 195, 7, 44, "Subsubsection"],
Cell[256731, 10191, 2029, 78, 193, "Text"],
Cell[258763, 10271, 382, 14, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[259182, 10290, 195, 7, 44, "Subsubsection"],
Cell[259380, 10299, 992, 37, 93, "Text"],
Cell[260375, 10338, 1327, 54, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[261739, 10397, 192, 7, 70, "Subsubsection"],
Cell[261934, 10406, 700, 28, 54, "Text"],
Cell[262637, 10436, 625, 22, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[263299, 10463, 196, 7, 44, "Subsubsection"],
Cell[263498, 10472, 434, 17, 53, "Text"],
Cell[263935, 10491, 684, 25, 41, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[264656, 10521, 194, 7, 44, "Subsubsection"],
Cell[264853, 10530, 518, 17, 73, "Text"],
Cell[265374, 10549, 2651, 81, 248, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268062, 10635, 192, 7, 44, "Subsubsection"],
Cell[268257, 10644, 293, 11, 34, "Text"],
Cell[268553, 10657, 208, 9, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[268798, 10671, 197, 7, 44, "Subsubsection"],
Cell[268998, 10680, 753, 25, 112, "Text"],
Cell[269754, 10707, 1223, 45, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271014, 10757, 192, 7, 44, "Subsubsection"],
Cell[271209, 10766, 1438, 61, 113, "Text"],
Cell[272650, 10829, 1426, 52, 136, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[274113, 10886, 193, 7, 44, "Subsubsection"],
Cell[274309, 10895, 464, 17, 53, "Text"],
Cell[274776, 10914, 207, 9, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[275020, 10928, 193, 7, 44, "Subsubsection"],
Cell[275216, 10937, 387, 16, 34, "Text"],
Cell[275606, 10955, 1832, 72, 106, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[277475, 11032, 194, 7, 44, "Subsubsection"],
Cell[277672, 11041, 812, 30, 70, "Text"],
Cell[278487, 11073, 1340, 54, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[279864, 11132, 194, 7, 70, "Subsubsection"],
Cell[280061, 11141, 789, 29, 70, "Text"],
Cell[280853, 11172, 1458, 61, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[282348, 11238, 197, 7, 70, "Subsubsection"],
Cell[282548, 11247, 1382, 48, 70, "Text"],
Cell[283933, 11297, 3127, 110, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[287097, 11412, 197, 7, 70, "Subsubsection"],
Cell[287297, 11421, 562, 22, 70, "Text"],
Cell[287862, 11445, 383, 17, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[288282, 11467, 195, 7, 70, "Subsubsection"],
Cell[288480, 11476, 893, 35, 70, "Text"],
Cell[289376, 11513, 1435, 48, 120, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[290848, 11566, 196, 7, 44, "Subsubsection"],
Cell[291047, 11575, 814, 24, 131, "Text"],
Cell[291864, 11601, 2771, 87, 264, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[294672, 11693, 195, 7, 44, "Subsubsection"],
Cell[294870, 11702, 955, 32, 112, "Text"],
Cell[295828, 11736, 541, 20, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[296406, 11761, 195, 7, 70, "Subsubsection"],
Cell[296604, 11770, 1084, 38, 70, "Text"],
Cell[297691, 11810, 2788, 96, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[300516, 11911, 192, 7, 70, "Subsubsection"],
Cell[300711, 11920, 556, 22, 70, "Text"],
Cell[301270, 11944, 606, 21, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[301913, 11970, 192, 7, 44, "Subsubsection"],
Cell[302108, 11979, 520, 20, 54, "Text"],
Cell[302631, 12001, 606, 21, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[303274, 12027, 196, 7, 44, "Subsubsection"],
Cell[303473, 12036, 496, 15, 72, "Text"],
Cell[303972, 12053, 680, 24, 58, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[304689, 12082, 196, 7, 44, "Subsubsection"],
Cell[304888, 12091, 1002, 35, 113, "Text"],
Cell[305893, 12128, 993, 32, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[306923, 12165, 194, 7, 44, "Subsubsection"],
Cell[307120, 12174, 828, 32, 92, "Text"],
Cell[307951, 12208, 1217, 39, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[309205, 12252, 196, 7, 70, "Subsubsection"],
Cell[309404, 12261, 313, 12, 70, "Text"],
Cell[309720, 12275, 941, 36, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[310698, 12316, 190, 7, 70, "Subsubsection"],
Cell[310891, 12325, 1384, 52, 70, "Text"],
Cell[312278, 12379, 1227, 45, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[313542, 12429, 195, 7, 44, "Subsubsection"],
Cell[313740, 12438, 785, 29, 92, "Text"],
Cell[314528, 12469, 925, 33, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[315490, 12507, 194, 7, 44, "Subsubsection"],
Cell[315687, 12516, 869, 35, 73, "Text"],
Cell[316559, 12553, 555, 19, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[317151, 12577, 193, 7, 44, "Subsubsection"],
Cell[317347, 12586, 1196, 48, 93, "Text"],
Cell[318546, 12636, 915, 38, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[319498, 12679, 199, 7, 44, "Subsubsection"],
Cell[319700, 12688, 683, 26, 70, "Text"],
Cell[320386, 12716, 632, 24, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[321055, 12745, 196, 7, 70, "Subsubsection"],
Cell[321254, 12754, 886, 35, 70, "Text"],
Cell[322143, 12791, 502, 20, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[322682, 12816, 195, 7, 44, "Subsubsection"],
Cell[322880, 12825, 2211, 85, 192, "Text"],
Cell[325094, 12912, 657, 17, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[325788, 12934, 195, 7, 44, "Subsubsection"],
Cell[325986, 12943, 770, 29, 73, "Text"],
Cell[326759, 12974, 1587, 60, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[328383, 13039, 193, 7, 44, "Subsubsection"],
Cell[328579, 13048, 781, 29, 92, "Text"],
Cell[329363, 13079, 738, 27, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[330138, 13111, 197, 7, 44, "Subsubsection"],
Cell[330338, 13120, 692, 26, 73, "Text"],
Cell[331033, 13148, 999, 42, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[332069, 13195, 194, 7, 70, "Subsubsection"],
Cell[332266, 13204, 638, 26, 70, "Text"],
Cell[332907, 13232, 757, 28, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[333701, 13265, 193, 7, 70, "Subsubsection"],
Cell[333897, 13274, 894, 38, 70, "Text"],
Cell[334794, 13314, 1410, 55, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[336241, 13374, 193, 7, 70, "Subsubsection"],
Cell[336437, 13383, 587, 23, 70, "Text"],
Cell[337027, 13408, 1040, 42, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[338104, 13455, 195, 7, 44, "Subsubsection"],
Cell[338302, 13464, 565, 20, 73, "Text"],
Cell[338870, 13486, 1116, 41, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[340023, 13532, 194, 7, 44, "Subsubsection"],
Cell[340220, 13541, 811, 34, 74, "Text"],
Cell[341034, 13577, 746, 28, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[341817, 13610, 194, 7, 44, "Subsubsection"],
Cell[342014, 13619, 866, 32, 92, "Text"],
Cell[342883, 13653, 972, 36, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[343892, 13694, 201, 7, 44, "Subsubsection"],
Cell[344096, 13703, 462, 19, 53, "Text"],
Cell[344561, 13724, 899, 34, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[345497, 13763, 196, 7, 70, "Subsubsection"],
Cell[345696, 13772, 484, 19, 53, "Text"],
Cell[346183, 13793, 748, 26, 73, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[346968, 13824, 199, 7, 44, "Subsubsection"],
Cell[347170, 13833, 507, 19, 53, "Text"],
Cell[347680, 13854, 542, 20, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[348259, 13879, 192, 7, 44, "Subsubsection"],
Cell[348454, 13888, 576, 23, 54, "Text"],
Cell[349033, 13913, 454, 18, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[349524, 13936, 195, 7, 44, "Subsubsection"],
Cell[349722, 13945, 534, 20, 73, "Text"],
Cell[350259, 13967, 750, 26, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[351046, 13998, 194, 7, 44, "Subsubsection"],
Cell[351243, 14007, 1289, 50, 93, "Text"],
Cell[352535, 14059, 766, 29, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[353338, 14093, 195, 7, 44, "Subsubsection"],
Cell[353536, 14102, 626, 22, 72, "Text"],
Cell[354165, 14126, 441, 17, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[354643, 14148, 196, 7, 44, "Subsubsection"],
Cell[354842, 14157, 952, 33, 111, "Text"],
Cell[355797, 14192, 1013, 35, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[356847, 14232, 197, 7, 44, "Subsubsection"],
Cell[357047, 14241, 986, 40, 92, "Text"],
Cell[358036, 14283, 735, 28, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[358808, 14316, 195, 7, 70, "Subsubsection"],
Cell[359006, 14325, 1033, 40, 70, "Text"],
Cell[360042, 14367, 635, 26, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[360714, 14398, 195, 7, 44, "Subsubsection"],
Cell[360912, 14407, 539, 20, 73, "Text"],
Cell[361454, 14429, 802, 29, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[362293, 14463, 193, 7, 44, "Subsubsection"],
Cell[362489, 14472, 533, 20, 54, "Text"],
Cell[363025, 14494, 800, 29, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[363862, 14528, 195, 7, 44, "Subsubsection"],
Cell[364060, 14537, 913, 30, 111, "Text"],
Cell[364976, 14569, 2283, 83, 152, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[367296, 14657, 195, 7, 44, "Subsubsection"],
Cell[367494, 14666, 851, 29, 93, "Text"],
Cell[368348, 14697, 628, 24, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[369013, 14726, 195, 7, 70, "Subsubsection"],
Cell[369211, 14735, 1516, 50, 70, "Text"],
Cell[370730, 14787, 1305, 40, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[372072, 14832, 194, 7, 70, "Subsubsection"],
Cell[372269, 14841, 1386, 54, 133, "Text"],
Cell[373658, 14897, 4179, 145, 328, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[377874, 15047, 197, 7, 44, "Subsubsection"],
Cell[378074, 15056, 522, 19, 53, "Text"],
Cell[378599, 15077, 1370, 50, 91, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[380006, 15132, 194, 7, 44, "Subsubsection"],
Cell[380203, 15141, 722, 26, 92, "Text"],
Cell[380928, 15169, 466, 17, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[381431, 15191, 198, 7, 70, "Subsubsection"],
Cell[381632, 15200, 648, 26, 70, "Text"],
Cell[382283, 15228, 1637, 63, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[383957, 15296, 201, 7, 70, "Subsubsection"],
Cell[384161, 15305, 689, 26, 70, "Text"],
Cell[384853, 15333, 1480, 59, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[386370, 15397, 200, 7, 44, "Subsubsection"],
Cell[386573, 15406, 486, 19, 53, "Text"],
Cell[387062, 15427, 1190, 45, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[388289, 15477, 196, 7, 44, "Subsubsection"],
Cell[388488, 15486, 759, 32, 73, "Text"],
Cell[389250, 15520, 458, 17, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[389745, 15542, 196, 7, 44, "Subsubsection"],
Cell[389944, 15551, 759, 32, 73, "Text"],
Cell[390706, 15585, 458, 17, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[391201, 15607, 193, 7, 44, "Subsubsection"],
Cell[391397, 15616, 759, 32, 73, "Text"],
Cell[392159, 15650, 371, 13, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[392567, 15668, 244, 9, 44, "Subsubsection"],
Cell[392814, 15679, 1316, 42, 172, "Text"],
Cell[394133, 15723, 1608, 50, 152, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[395778, 15778, 235, 9, 44, "Subsubsection"],
Cell[396016, 15789, 593, 23, 54, "Text"],
Cell[396612, 15814, 594, 20, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[397243, 15839, 235, 9, 44, "Subsubsection"],
Cell[397481, 15850, 726, 29, 74, "Text"],
Cell[398210, 15881, 784, 28, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[399031, 15914, 233, 9, 70, "Subsubsection"],
Cell[399267, 15925, 930, 39, 74, "Text"],
Cell[400200, 15966, 1904, 72, 122, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[402141, 16043, 233, 9, 44, "Subsubsection"],
Cell[402377, 16054, 319, 12, 34, "Text"],
Cell[402699, 16068, 297, 13, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[403033, 16086, 237, 9, 44, "Subsubsection"],
Cell[403273, 16097, 752, 29, 73, "Text"],
Cell[404028, 16128, 2600, 109, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[406665, 16242, 237, 9, 44, "Subsubsection"],
Cell[406905, 16253, 862, 32, 92, "Text"],
Cell[407770, 16287, 893, 35, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[408700, 16327, 237, 9, 44, "Subsubsection"],
Cell[408940, 16338, 922, 35, 92, "Text"],
Cell[409865, 16375, 3926, 153, 216, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[413828, 16533, 241, 9, 70, "Subsubsection"],
Cell[414072, 16544, 414, 16, 53, "Text"],
Cell[414489, 16562, 2629, 93, 201, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[417155, 16660, 237, 9, 44, "Subsubsection"],
Cell[417395, 16671, 639, 25, 54, "Text"],
Cell[418037, 16698, 1089, 39, 89, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[419163, 16742, 244, 9, 44, "Subsubsection"],
Cell[419410, 16753, 327, 12, 54, "Text"],
Cell[419740, 16767, 878, 32, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[420655, 16804, 238, 9, 44, "Subsubsection"],
Cell[420896, 16815, 777, 28, 93, "Text"],
Cell[421676, 16845, 1265, 44, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[422978, 16894, 241, 9, 70, "Subsubsection"],
Cell[423222, 16905, 1047, 32, 70, "Text"],
Cell[424272, 16939, 3703, 105, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[428012, 17049, 238, 9, 70, "Subsubsection"],
Cell[428253, 17060, 759, 32, 70, "Text"],
Cell[429015, 17094, 3919, 143, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[432971, 17242, 236, 9, 70, "Subsubsection"],
Cell[433210, 17253, 958, 34, 70, "Text"],
Cell[434171, 17289, 2580, 84, 264, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[436788, 17378, 237, 9, 44, "Subsubsection"],
Cell[437028, 17389, 796, 27, 113, "Text"],
Cell[437827, 17418, 1326, 44, 105, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[439190, 17467, 237, 9, 44, "Subsubsection"],
Cell[439430, 17478, 1085, 36, 133, "Text"],
Cell[440518, 17516, 1752, 53, 216, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[442307, 17574, 240, 9, 44, "Subsubsection"],
Cell[442550, 17585, 632, 23, 73, "Text"],
Cell[443185, 17610, 963, 32, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[444185, 17647, 236, 9, 44, "Subsubsection"],
Cell[444424, 17658, 1118, 38, 132, "Text"],
Cell[445545, 17698, 746, 26, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[446328, 17729, 241, 9, 70, "Subsubsection"],
Cell[446572, 17740, 768, 29, 70, "Text"],
Cell[447343, 17771, 519, 17, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[447899, 17793, 239, 9, 44, "Subsubsection"],
Cell[448141, 17804, 1010, 38, 113, "Text"],
Cell[449154, 17844, 2907, 98, 296, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[452098, 17947, 233, 9, 44, "Subsubsection"],
Cell[452334, 17958, 1356, 58, 74, "Text"],
Cell[453693, 18018, 1127, 46, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[454857, 18069, 237, 9, 44, "Subsubsection"],
Cell[455097, 18080, 929, 40, 74, "Text"],
Cell[456029, 18122, 210, 9, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[456276, 18136, 240, 9, 44, "Subsubsection"],
Cell[456519, 18147, 827, 32, 74, "Text"],
Cell[457349, 18181, 2310, 79, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[459696, 18265, 238, 9, 70, "Subsubsection"],
Cell[459937, 18276, 1210, 44, 70, "Text"],
Cell[461150, 18322, 2563, 67, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[463750, 18394, 238, 9, 70, "Subsubsection"],
Cell[463991, 18405, 1376, 50, 70, "Text"],
Cell[465370, 18457, 3928, 121, 440, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[469335, 18583, 238, 9, 44, "Subsubsection"],
Cell[469576, 18594, 821, 30, 93, "Text"],
Cell[470400, 18626, 1174, 42, 73, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[471611, 18673, 243, 9, 44, "Subsubsection"],
Cell[471857, 18684, 879, 32, 70, "Text"],
Cell[472739, 18718, 977, 32, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[473753, 18755, 232, 9, 70, "Subsubsection"],
Cell[473988, 18766, 950, 38, 70, "Text"],
Cell[474941, 18806, 1227, 46, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[476205, 18857, 236, 9, 70, "Subsubsection"],
Cell[476444, 18868, 578, 23, 70, "Text"],
Cell[477025, 18893, 835, 33, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[477897, 18931, 195, 7, 44, "Subsubsection"],
Cell[478095, 18940, 800, 31, 74, "Text"],
Cell[478898, 18973, 1011, 36, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[479946, 19014, 238, 9, 44, "Subsubsection"],
Cell[480187, 19025, 458, 17, 53, "Text"],
Cell[480648, 19044, 1042, 33, 136, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[481727, 19082, 241, 9, 44, "Subsubsection"],
Cell[481971, 19093, 668, 24, 73, "Text"],
Cell[482642, 19119, 1015, 33, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[483694, 19157, 240, 9, 44, "Subsubsection"],
Cell[483937, 19168, 1247, 47, 133, "Text"],
Cell[485187, 19217, 1953, 72, 120, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[487177, 19294, 235, 9, 44, "Subsubsection"],
Cell[487415, 19305, 577, 20, 73, "Text"],
Cell[487995, 19327, 591, 22, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[488623, 19354, 235, 9, 44, "Subsubsection"],
Cell[488861, 19365, 1093, 47, 74, "Text"],
Cell[489957, 19414, 271, 11, 25, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[490265, 19430, 237, 9, 44, "Subsubsection"],
Cell[490505, 19441, 496, 17, 72, "Text"],
Cell[491004, 19460, 1054, 34, 136, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[492095, 19499, 237, 9, 44, "Subsubsection"],
Cell[492335, 19510, 371, 13, 53, "Text"],
Cell[492709, 19525, 875, 28, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[493621, 19558, 240, 9, 44, "Subsubsection"],
Cell[493864, 19569, 501, 17, 72, "Text"],
Cell[494368, 19588, 496, 18, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[494901, 19611, 236, 9, 44, "Subsubsection"],
Cell[495140, 19622, 330, 12, 53, "Text"],
Cell[495473, 19636, 1121, 44, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[496631, 19685, 235, 9, 44, "Subsubsection"],
Cell[496869, 19696, 316, 11, 53, "Text"],
Cell[497188, 19709, 2240, 92, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[499465, 19806, 236, 9, 44, "Subsubsection"],
Cell[499704, 19817, 305, 11, 53, "Text"],
Cell[500012, 19830, 1757, 74, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[501806, 19909, 236, 9, 44, "Subsubsection"],
Cell[502045, 19920, 484, 17, 73, "Text"],
Cell[502532, 19939, 812, 31, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[503381, 19975, 233, 9, 44, "Subsubsection"],
Cell[503617, 19986, 846, 31, 92, "Text"],
Cell[504466, 20019, 829, 28, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[505332, 20052, 244, 9, 44, "Subsubsection"],
Cell[505579, 20063, 528, 17, 73, "Text"],
Cell[506110, 20082, 1048, 30, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[507195, 20117, 235, 9, 44, "Subsubsection"],
Cell[507433, 20128, 572, 20, 74, "Text"],
Cell[508008, 20150, 828, 28, 73, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[508873, 20183, 242, 9, 44, "Subsubsection"],
Cell[509118, 20194, 967, 36, 93, "Text"],
Cell[510088, 20232, 1328, 43, 120, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[511453, 20280, 239, 9, 44, "Subsubsection"],
Cell[511695, 20291, 2134, 92, 173, "Text"],
Cell[513832, 20385, 1022, 39, 72, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[514891, 20429, 233, 9, 44, "Subsubsection"],
Cell[515127, 20440, 898, 35, 93, "Text"],
Cell[516028, 20477, 1218, 46, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[517283, 20528, 236, 9, 44, "Subsubsection"],
Cell[517522, 20539, 573, 23, 54, "Text"],
Cell[518098, 20564, 617, 20, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[518752, 20589, 236, 9, 44, "Subsubsection"],
Cell[518991, 20600, 569, 18, 73, "Text"],
Cell[519563, 20620, 818, 25, 88, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[520418, 20650, 192, 7, 44, "Subsubsection"],
Cell[520613, 20659, 755, 26, 94, "Text"],
Cell[521371, 20687, 621, 21, 56, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[522029, 20713, 192, 7, 44, "Subsubsection"],
Cell[522224, 20722, 887, 30, 111, "Text"],
Cell[523114, 20754, 2731, 96, 232, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[525882, 20855, 194, 7, 44, "Subsubsection"],
Cell[526079, 20864, 921, 30, 111, "Text"],
Cell[527003, 20896, 2847, 96, 248, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[529887, 20997, 194, 7, 44, "Subsubsection"],
Cell[530084, 21006, 940, 34, 93, "Text"],
Cell[531027, 21042, 450, 16, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[531514, 21063, 194, 7, 44, "Subsubsection"],
Cell[531711, 21072, 1116, 39, 130, "Text"],
Cell[532830, 21113, 2811, 99, 249, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[535678, 21217, 192, 7, 44, "Subsubsection"],
Cell[535873, 21226, 686, 28, 54, "Text"],
Cell[536562, 21256, 290, 13, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[536889, 21274, 192, 7, 44, "Subsubsection"],
Cell[537084, 21283, 419, 16, 53, "Text"],
Cell[537506, 21301, 1307, 54, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[538850, 21360, 192, 7, 70, "Subsubsection"],
Cell[539045, 21369, 1220, 49, 70, "Text"],
Cell[540268, 21420, 992, 43, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[541297, 21468, 194, 7, 70, "Subsubsection"],
Cell[541494, 21477, 1267, 50, 70, "Text"],
Cell[542764, 21529, 5017, 208, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[547818, 21742, 197, 7, 70, "Subsubsection"],
Cell[548018, 21751, 474, 17, 70, "Text"],
Cell[548495, 21770, 739, 27, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[549271, 21802, 192, 7, 70, "Subsubsection"],
Cell[549466, 21811, 1177, 50, 70, "Text"],
Cell[550646, 21863, 1111, 41, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[551794, 21909, 196, 8, 70, "Subsubsection"],
Cell[551993, 21919, 545, 18, 70, "Text"],
Cell[552541, 21939, 657, 26, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[553235, 21970, 199, 8, 70, "Subsubsection"],
Cell[553437, 21980, 1195, 47, 70, "Text"],
Cell[554635, 22029, 2803, 106, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[557475, 22140, 198, 8, 70, "Subsubsection"],
Cell[557676, 22150, 576, 23, 70, "Text"],
Cell[558255, 22175, 409, 15, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[558701, 22195, 194, 8, 70, "Subsubsection"],
Cell[558898, 22205, 446, 16, 70, "Text"],
Cell[559347, 22223, 487, 21, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[559871, 22249, 210, 9, 70, "Subsubsection"],
Cell[560084, 22260, 796, 31, 70, "Text"],
Cell[560883, 22293, 995, 37, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[561915, 22335, 201, 8, 70, "Subsubsection"],
Cell[562119, 22345, 798, 31, 70, "Text"],
Cell[562920, 22378, 1010, 37, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[563967, 22420, 194, 8, 70, "Subsubsection"],
Cell[564164, 22430, 446, 16, 70, "Text"],
Cell[564613, 22448, 487, 21, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[565137, 22474, 194, 8, 70, "Subsubsection"],
Cell[565334, 22484, 446, 16, 70, "Text"],
Cell[565783, 22502, 487, 21, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[566307, 22528, 206, 8, 70, "Subsubsection"],
Cell[566516, 22538, 352, 12, 70, "Text"],
Cell[566871, 22552, 621, 21, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[567529, 22578, 203, 8, 70, "Subsubsection"],
Cell[567735, 22588, 294, 9, 70, "Text"],
Cell[568032, 22599, 1103, 34, 70, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[569172, 22638, 205, 8, 70, "Subsubsection"],
Cell[569380, 22648, 939, 34, 70, "Text"],
Cell[570322, 22684, 215, 9, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[570574, 22698, 208, 8, 44, "Subsubsection"],
Cell[570785, 22708, 544, 19, 74, "Text"],
Cell[571332, 22729, 504, 20, 40, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[571873, 22754, 204, 8, 44, "Subsubsection"],
Cell[572080, 22764, 750, 27, 92, "Text"],
Cell[572833, 22793, 216, 9, 24, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[573086, 22807, 204, 8, 44, "Subsubsection"],
Cell[573293, 22817, 351, 10, 72, "Text"],
Cell[573647, 22829, 859, 26, 104, "SmallText"]
}, Open  ]],

Cell[CellGroupData[{
Cell[574543, 22860, 202, 8, 44, "Subsubsection"],
Cell[574748, 22870, 286, 11, 34, "Text"],
Cell[575037, 22883, 345, 13, 24, "SmallText"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[575431, 22902, 32, 0, 31, "Subsection"],
Cell[575466, 22904, 237, 7, 42, "Special2"],
Cell[575706, 22913, 295, 8, 59, "Special2"],
Cell[576004, 22923, 247, 7, 42, "Special2"],
Cell[576254, 22932, 213, 7, 42, "Special2"],
Cell[576470, 22941, 282, 9, 42, "Special2"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

